diff -pruN 5.5-3/access.c 5.9-0ubuntu2/access.c
--- 5.5-3/access.c	2019-07-11 17:51:22.000000000 +0000
+++ 5.9-0ubuntu2/access.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2019 The strace developers.
+ * Copyright (c) 2014-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -9,26 +9,42 @@
 
 #include <fcntl.h>
 
-#include "xlat/access_flags.h"
+#include "xlat/access_modes.h"
+#include "xlat/faccessat_flags.h"
 
-static int
+static void
 decode_access(struct tcb *tcp, int offset)
 {
 	printpath(tcp, tcp->u_arg[offset]);
 	tprints(", ");
-	printflags(access_flags, tcp->u_arg[offset + 1], "?_OK");
+	printflags(access_modes, tcp->u_arg[offset + 1], "?_OK");
+}
 
+SYS_FUNC(access)
+{
+	decode_access(tcp, 0);
 	return RVAL_DECODED;
 }
 
-SYS_FUNC(access)
+static void
+decode_faccessat(struct tcb *tcp)
 {
-	return decode_access(tcp, 0);
+	print_dirfd(tcp, tcp->u_arg[0]);
+	tprints(", ");
+	decode_access(tcp, 1);
 }
 
+
 SYS_FUNC(faccessat)
 {
-	print_dirfd(tcp, tcp->u_arg[0]);
+	decode_faccessat(tcp);
+	return RVAL_DECODED;
+}
+
+SYS_FUNC(faccessat2)
+{
+	decode_faccessat(tcp);
 	tprints(", ");
-	return decode_access(tcp, 1);
+	printflags(faccessat_flags, tcp->u_arg[3], "AT_???");
+	return RVAL_DECODED;
 }
diff -pruN 5.5-3/aclocal.m4 5.9-0ubuntu2/aclocal.m4
--- 5.5-3/aclocal.m4	2020-02-06 16:23:31.000000000 +0000
+++ 5.9-0ubuntu2/aclocal.m4	2020-09-24 09:18:55.000000000 +0000
@@ -1,6 +1,6 @@
-# generated automatically by aclocal 1.16.1 -*- Autoconf -*-
+# generated automatically by aclocal 1.16.2 -*- Autoconf -*-
 
-# Copyright (C) 1996-2018 Free Software Foundation, Inc.
+# Copyright (C) 1996-2020 Free Software Foundation, Inc.
 
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -20,7 +20,7 @@ You have another version of autoconf.  I
 If you have problems, you may need to regenerate the build system entirely.
 To do so, use the procedure documented by the package, typically 'autoreconf'.])])
 
-# Copyright (C) 2002-2018 Free Software Foundation, Inc.
+# Copyright (C) 2002-2020 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -35,7 +35,7 @@ AC_DEFUN([AM_AUTOMAKE_VERSION],
 [am__api_version='1.16'
 dnl Some users find AM_AUTOMAKE_VERSION and mistake it for a way to
 dnl require some minimum version.  Point them to the right macro.
-m4_if([$1], [1.16.1], [],
+m4_if([$1], [1.16.2], [],
       [AC_FATAL([Do not call $0, use AM_INIT_AUTOMAKE([$1]).])])dnl
 ])
 
@@ -51,14 +51,74 @@ m4_define([_AM_AUTOCONF_VERSION], [])
 # Call AM_AUTOMAKE_VERSION and AM_AUTOMAKE_VERSION so they can be traced.
 # This function is AC_REQUIREd by AM_INIT_AUTOMAKE.
 AC_DEFUN([AM_SET_CURRENT_AUTOMAKE_VERSION],
-[AM_AUTOMAKE_VERSION([1.16.1])dnl
+[AM_AUTOMAKE_VERSION([1.16.2])dnl
 m4_ifndef([AC_AUTOCONF_VERSION],
   [m4_copy([m4_PACKAGE_VERSION], [AC_AUTOCONF_VERSION])])dnl
 _AM_AUTOCONF_VERSION(m4_defn([AC_AUTOCONF_VERSION]))])
 
+# Copyright (C) 2011-2020 Free Software Foundation, Inc.
+#
+# This file is free software; the Free Software Foundation
+# gives unlimited permission to copy and/or distribute it,
+# with or without modifications, as long as this notice is preserved.
+
+# AM_PROG_AR([ACT-IF-FAIL])
+# -------------------------
+# Try to determine the archiver interface, and trigger the ar-lib wrapper
+# if it is needed.  If the detection of archiver interface fails, run
+# ACT-IF-FAIL (default is to abort configure with a proper error message).
+AC_DEFUN([AM_PROG_AR],
+[AC_BEFORE([$0], [LT_INIT])dnl
+AC_BEFORE([$0], [AC_PROG_LIBTOOL])dnl
+AC_REQUIRE([AM_AUX_DIR_EXPAND])dnl
+AC_REQUIRE_AUX_FILE([ar-lib])dnl
+AC_CHECK_TOOLS([AR], [ar lib "link -lib"], [false])
+: ${AR=ar}
+
+AC_CACHE_CHECK([the archiver ($AR) interface], [am_cv_ar_interface],
+  [AC_LANG_PUSH([C])
+   am_cv_ar_interface=ar
+   AC_COMPILE_IFELSE([AC_LANG_SOURCE([[int some_variable = 0;]])],
+     [am_ar_try='$AR cru libconftest.a conftest.$ac_objext >&AS_MESSAGE_LOG_FD'
+      AC_TRY_EVAL([am_ar_try])
+      if test "$ac_status" -eq 0; then
+        am_cv_ar_interface=ar
+      else
+        am_ar_try='$AR -NOLOGO -OUT:conftest.lib conftest.$ac_objext >&AS_MESSAGE_LOG_FD'
+        AC_TRY_EVAL([am_ar_try])
+        if test "$ac_status" -eq 0; then
+          am_cv_ar_interface=lib
+        else
+          am_cv_ar_interface=unknown
+        fi
+      fi
+      rm -f conftest.lib libconftest.a
+     ])
+   AC_LANG_POP([C])])
+
+case $am_cv_ar_interface in
+ar)
+  ;;
+lib)
+  # Microsoft lib, so override with the ar-lib wrapper script.
+  # FIXME: It is wrong to rewrite AR.
+  # But if we don't then we get into trouble of one sort or another.
+  # A longer-term fix would be to have automake use am__AR in this case,
+  # and then we could set am__AR="$am_aux_dir/ar-lib \$(AR)" or something
+  # similar.
+  AR="$am_aux_dir/ar-lib $AR"
+  ;;
+unknown)
+  m4_default([$1],
+             [AC_MSG_ERROR([could not determine $AR interface])])
+  ;;
+esac
+AC_SUBST([AR])dnl
+])
+
 # AM_AUX_DIR_EXPAND                                         -*- Autoconf -*-
 
-# Copyright (C) 2001-2018 Free Software Foundation, Inc.
+# Copyright (C) 2001-2020 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -110,7 +170,7 @@ am_aux_dir=`cd "$ac_aux_dir" && pwd`
 
 # AM_CONDITIONAL                                            -*- Autoconf -*-
 
-# Copyright (C) 1997-2018 Free Software Foundation, Inc.
+# Copyright (C) 1997-2020 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -141,7 +201,7 @@ AC_CONFIG_COMMANDS_PRE(
 Usually this means the macro was only invoked conditionally.]])
 fi])])
 
-# Copyright (C) 1999-2018 Free Software Foundation, Inc.
+# Copyright (C) 1999-2020 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -332,7 +392,7 @@ _AM_SUBST_NOTMAKE([am__nodep])dnl
 
 # Generate code to set up dependency tracking.              -*- Autoconf -*-
 
-# Copyright (C) 1999-2018 Free Software Foundation, Inc.
+# Copyright (C) 1999-2020 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -371,7 +431,9 @@ AC_DEFUN([_AM_OUTPUT_DEPENDENCY_COMMANDS
   done
   if test $am_rc -ne 0; then
     AC_MSG_FAILURE([Something went wrong bootstrapping makefile fragments
-    for automatic dependency tracking.  Try re-running configure with the
+    for automatic dependency tracking.  If GNU make was not used, consider
+    re-running the configure script with MAKE="gmake" (or whatever is
+    necessary).  You can also try re-running configure with the
     '--disable-dependency-tracking' option to at least be able to build
     the package (albeit without support for automatic dependency tracking).])
   fi
@@ -398,7 +460,7 @@ AC_DEFUN([AM_OUTPUT_DEPENDENCY_COMMANDS]
 
 # AM_EXTRA_RECURSIVE_TARGETS                                -*- Autoconf -*-
 
-# Copyright (C) 2012-2018 Free Software Foundation, Inc.
+# Copyright (C) 2012-2020 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -415,7 +477,7 @@ AC_DEFUN([AM_EXTRA_RECURSIVE_TARGETS], [
 
 # Do all the work for Automake.                             -*- Autoconf -*-
 
-# Copyright (C) 1996-2018 Free Software Foundation, Inc.
+# Copyright (C) 1996-2020 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -612,7 +674,7 @@ for _am_header in $config_headers :; do
 done
 echo "timestamp for $_am_arg" >`AS_DIRNAME(["$_am_arg"])`/stamp-h[]$_am_stamp_count])
 
-# Copyright (C) 2001-2018 Free Software Foundation, Inc.
+# Copyright (C) 2001-2020 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -633,7 +695,7 @@ if test x"${install_sh+set}" != xset; th
 fi
 AC_SUBST([install_sh])])
 
-# Copyright (C) 2003-2018 Free Software Foundation, Inc.
+# Copyright (C) 2003-2020 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -655,7 +717,7 @@ AC_SUBST([am__leading_dot])])
 # Add --enable-maintainer-mode option to configure.         -*- Autoconf -*-
 # From Jim Meyering
 
-# Copyright (C) 1996-2018 Free Software Foundation, Inc.
+# Copyright (C) 1996-2020 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -690,7 +752,7 @@ AC_MSG_CHECKING([whether to enable maint
 
 # Check to see how 'make' treats includes.	            -*- Autoconf -*-
 
-# Copyright (C) 2001-2018 Free Software Foundation, Inc.
+# Copyright (C) 2001-2020 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -733,7 +795,7 @@ AC_SUBST([am__quote])])
 
 # Fake the existence of programs that GNU maintainers use.  -*- Autoconf -*-
 
-# Copyright (C) 1997-2018 Free Software Foundation, Inc.
+# Copyright (C) 1997-2020 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -772,7 +834,7 @@ fi
 
 # Helper functions for option handling.                     -*- Autoconf -*-
 
-# Copyright (C) 2001-2018 Free Software Foundation, Inc.
+# Copyright (C) 2001-2020 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -801,7 +863,7 @@ AC_DEFUN([_AM_SET_OPTIONS],
 AC_DEFUN([_AM_IF_OPTION],
 [m4_ifset(_AM_MANGLE_OPTION([$1]), [$2], [$3])])
 
-# Copyright (C) 1999-2018 Free Software Foundation, Inc.
+# Copyright (C) 1999-2020 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -848,7 +910,7 @@ AC_LANG_POP([C])])
 # For backward compatibility.
 AC_DEFUN_ONCE([AM_PROG_CC_C_O], [AC_REQUIRE([AC_PROG_CC])])
 
-# Copyright (C) 2001-2018 Free Software Foundation, Inc.
+# Copyright (C) 2001-2020 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -867,7 +929,7 @@ AC_DEFUN([AM_RUN_LOG],
 
 # Check to make sure that the build environment is sane.    -*- Autoconf -*-
 
-# Copyright (C) 1996-2018 Free Software Foundation, Inc.
+# Copyright (C) 1996-2020 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -948,7 +1010,7 @@ AC_CONFIG_COMMANDS_PRE(
 rm -f conftest.file
 ])
 
-# Copyright (C) 2009-2018 Free Software Foundation, Inc.
+# Copyright (C) 2009-2020 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -1008,7 +1070,7 @@ AC_SUBST([AM_BACKSLASH])dnl
 _AM_SUBST_NOTMAKE([AM_BACKSLASH])dnl
 ])
 
-# Copyright (C) 2001-2018 Free Software Foundation, Inc.
+# Copyright (C) 2001-2020 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -1036,7 +1098,7 @@ fi
 INSTALL_STRIP_PROGRAM="\$(install_sh) -c -s"
 AC_SUBST([INSTALL_STRIP_PROGRAM])])
 
-# Copyright (C) 2006-2018 Free Software Foundation, Inc.
+# Copyright (C) 2006-2020 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -1055,7 +1117,7 @@ AC_DEFUN([AM_SUBST_NOTMAKE], [_AM_SUBST_
 
 # Check how to create a tarball.                            -*- Autoconf -*-
 
-# Copyright (C) 2004-2018 Free Software Foundation, Inc.
+# Copyright (C) 2004-2020 Free Software Foundation, Inc.
 #
 # This file is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -1186,13 +1248,47 @@ AC_SUBST([am__tar])
 AC_SUBST([am__untar])
 ]) # _AM_PROG_TAR
 
+m4_include([xlat/btrfs_compress_types.m4])
+m4_include([xlat/close_range_flags.m4])
+m4_include([xlat/loop_flags_options.m4])
+m4_include([xlat/rtnl_ifla_xdp_attached_mode.m4])
+m4_include([xlat/rtnl_ifla_xdp_attrs.m4])
+m4_include([xlat/rtnl_link_attrs.m4])
+m4_include([xlat/rtnl_tc_action_attrs.m4])
+m4_include([xlat/rtnl_tca_stab_attrs.m4])
+m4_include([xlat/rtnl_tca_stats_attrs.m4])
+m4_include([xlat/st_check_enums.m4])
+m4_include([xlat/sysctl_kern.m4])
+m4_include([xlat/sysctl_net.m4])
+m4_include([xlat/sysctl_net_core.m4])
+m4_include([xlat/sysctl_net_ipv4.m4])
+m4_include([xlat/sysctl_net_ipv4_conf.m4])
+m4_include([xlat/sysctl_net_ipv4_route.m4])
+m4_include([xlat/sysctl_net_ipv6.m4])
+m4_include([xlat/sysctl_net_ipv6_route.m4])
+m4_include([xlat/sysctl_net_unix.m4])
+m4_include([xlat/sysctl_root.m4])
+m4_include([xlat/sysctl_vm.m4])
+m4_include([xlat/v4l2_buf_types.m4])
+m4_include([xlat/v4l2_colorspaces.m4])
+m4_include([xlat/v4l2_control_types.m4])
+m4_include([xlat/v4l2_fields.m4])
+m4_include([xlat/v4l2_framesize_types.m4])
+m4_include([xlat/v4l2_memories.m4])
+m4_include([xlat/v4l2_tuner_types.m4])
+m4_include([xlat/waitid_types.m4])
+m4_include([types/check-btrfs.m4])
 m4_include([types/check-cryptouser.m4])
 m4_include([types/check-evdev.m4])
 m4_include([types/check-io_uring.m4])
+m4_include([types/check-loop.m4])
+m4_include([types/check-openat2.m4])
 m4_include([types/check-rtnl_link.m4])
 m4_include([types/check-rtnl_mdb.m4])
 m4_include([types/check-rtnl_neightbl.m4])
 m4_include([types/check-rtnl_route.m4])
+m4_include([types/check-tee.m4])
+m4_include([types/check-v4l2.m4])
 m4_include([types/st_check_types.m4])
 m4_include([m4/ax_code_coverage.m4])
 m4_include([m4/ax_prog_cc_for_build.m4])
diff -pruN 5.5-3/affinity.c 5.9-0ubuntu2/affinity.c
--- 5.5-3/affinity.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/affinity.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,6 +1,7 @@
 /*
  * Copyright (c) 2002-2004 Roland McGrath <roland@redhat.com>
  * Copyright (c) 2009-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2014-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -82,7 +83,8 @@ SYS_FUNC(sched_setaffinity)
 	const int pid = tcp->u_arg[0];
 	const unsigned int len = tcp->u_arg[1];
 
-	tprintf("%d, %u, ", pid, len);
+	printpid(tcp, pid, PT_TGID);
+	tprintf(", %u, ", len);
 	print_affinitylist(tcp, tcp->u_arg[2], len);
 
 	return RVAL_DECODED;
@@ -94,7 +96,8 @@ SYS_FUNC(sched_getaffinity)
 	const unsigned int len = tcp->u_arg[1];
 
 	if (entering(tcp)) {
-		tprintf("%d, %u, ", pid, len);
+		printpid(tcp, pid, PT_TGID);
+		tprintf(", %u, ", len);
 	} else {
 		print_affinitylist(tcp, tcp->u_arg[2], tcp->u_rval);
 	}
diff -pruN 5.5-3/ar-lib 5.9-0ubuntu2/ar-lib
--- 5.5-3/ar-lib	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/ar-lib	2020-09-24 09:18:59.000000000 +0000
@@ -0,0 +1,271 @@
+#! /bin/sh
+# Wrapper for Microsoft lib.exe
+
+me=ar-lib
+scriptversion=2019-07-04.01; # UTC
+
+# Copyright (C) 2010-2020 Free Software Foundation, Inc.
+# Written by Peter Rosin <peda@lysator.liu.se>.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2, or (at your option)
+# any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
+
+# As a special exception to the GNU General Public License, if you
+# distribute this file as part of a program that contains a
+# configuration script generated by Autoconf, you may include it under
+# the same distribution terms that you use for the rest of that program.
+
+# This file is maintained in Automake, please report
+# bugs to <bug-automake@gnu.org> or send patches to
+# <automake-patches@gnu.org>.
+
+
+# func_error message
+func_error ()
+{
+  echo "$me: $1" 1>&2
+  exit 1
+}
+
+file_conv=
+
+# func_file_conv build_file
+# Convert a $build file to $host form and store it in $file
+# Currently only supports Windows hosts.
+func_file_conv ()
+{
+  file=$1
+  case $file in
+    / | /[!/]*) # absolute file, and not a UNC file
+      if test -z "$file_conv"; then
+	# lazily determine how to convert abs files
+	case `uname -s` in
+	  MINGW*)
+	    file_conv=mingw
+	    ;;
+	  CYGWIN* | MSYS*)
+	    file_conv=cygwin
+	    ;;
+	  *)
+	    file_conv=wine
+	    ;;
+	esac
+      fi
+      case $file_conv in
+	mingw)
+	  file=`cmd //C echo "$file " | sed -e 's/"\(.*\) " *$/\1/'`
+	  ;;
+	cygwin | msys)
+	  file=`cygpath -m "$file" || echo "$file"`
+	  ;;
+	wine)
+	  file=`winepath -w "$file" || echo "$file"`
+	  ;;
+      esac
+      ;;
+  esac
+}
+
+# func_at_file at_file operation archive
+# Iterate over all members in AT_FILE performing OPERATION on ARCHIVE
+# for each of them.
+# When interpreting the content of the @FILE, do NOT use func_file_conv,
+# since the user would need to supply preconverted file names to
+# binutils ar, at least for MinGW.
+func_at_file ()
+{
+  operation=$2
+  archive=$3
+  at_file_contents=`cat "$1"`
+  eval set x "$at_file_contents"
+  shift
+
+  for member
+  do
+    $AR -NOLOGO $operation:"$member" "$archive" || exit $?
+  done
+}
+
+case $1 in
+  '')
+     func_error "no command.  Try '$0 --help' for more information."
+     ;;
+  -h | --h*)
+    cat <<EOF
+Usage: $me [--help] [--version] PROGRAM ACTION ARCHIVE [MEMBER...]
+
+Members may be specified in a file named with @FILE.
+EOF
+    exit $?
+    ;;
+  -v | --v*)
+    echo "$me, version $scriptversion"
+    exit $?
+    ;;
+esac
+
+if test $# -lt 3; then
+  func_error "you must specify a program, an action and an archive"
+fi
+
+AR=$1
+shift
+while :
+do
+  if test $# -lt 2; then
+    func_error "you must specify a program, an action and an archive"
+  fi
+  case $1 in
+    -lib | -LIB \
+    | -ltcg | -LTCG \
+    | -machine* | -MACHINE* \
+    | -subsystem* | -SUBSYSTEM* \
+    | -verbose | -VERBOSE \
+    | -wx* | -WX* )
+      AR="$AR $1"
+      shift
+      ;;
+    *)
+      action=$1
+      shift
+      break
+      ;;
+  esac
+done
+orig_archive=$1
+shift
+func_file_conv "$orig_archive"
+archive=$file
+
+# strip leading dash in $action
+action=${action#-}
+
+delete=
+extract=
+list=
+quick=
+replace=
+index=
+create=
+
+while test -n "$action"
+do
+  case $action in
+    d*) delete=yes  ;;
+    x*) extract=yes ;;
+    t*) list=yes    ;;
+    q*) quick=yes   ;;
+    r*) replace=yes ;;
+    s*) index=yes   ;;
+    S*)             ;; # the index is always updated implicitly
+    c*) create=yes  ;;
+    u*)             ;; # TODO: don't ignore the update modifier
+    v*)             ;; # TODO: don't ignore the verbose modifier
+    *)
+      func_error "unknown action specified"
+      ;;
+  esac
+  action=${action#?}
+done
+
+case $delete$extract$list$quick$replace,$index in
+  yes,* | ,yes)
+    ;;
+  yesyes*)
+    func_error "more than one action specified"
+    ;;
+  *)
+    func_error "no action specified"
+    ;;
+esac
+
+if test -n "$delete"; then
+  if test ! -f "$orig_archive"; then
+    func_error "archive not found"
+  fi
+  for member
+  do
+    case $1 in
+      @*)
+        func_at_file "${1#@}" -REMOVE "$archive"
+        ;;
+      *)
+        func_file_conv "$1"
+        $AR -NOLOGO -REMOVE:"$file" "$archive" || exit $?
+        ;;
+    esac
+  done
+
+elif test -n "$extract"; then
+  if test ! -f "$orig_archive"; then
+    func_error "archive not found"
+  fi
+  if test $# -gt 0; then
+    for member
+    do
+      case $1 in
+        @*)
+          func_at_file "${1#@}" -EXTRACT "$archive"
+          ;;
+        *)
+          func_file_conv "$1"
+          $AR -NOLOGO -EXTRACT:"$file" "$archive" || exit $?
+          ;;
+      esac
+    done
+  else
+    $AR -NOLOGO -LIST "$archive" | tr -d '\r' | sed -e 's/\\/\\\\/g' \
+      | while read member
+        do
+          $AR -NOLOGO -EXTRACT:"$member" "$archive" || exit $?
+        done
+  fi
+
+elif test -n "$quick$replace"; then
+  if test ! -f "$orig_archive"; then
+    if test -z "$create"; then
+      echo "$me: creating $orig_archive"
+    fi
+    orig_archive=
+  else
+    orig_archive=$archive
+  fi
+
+  for member
+  do
+    case $1 in
+    @*)
+      func_file_conv "${1#@}"
+      set x "$@" "@$file"
+      ;;
+    *)
+      func_file_conv "$1"
+      set x "$@" "$file"
+      ;;
+    esac
+    shift
+    shift
+  done
+
+  if test -n "$orig_archive"; then
+    $AR -NOLOGO -OUT:"$archive" "$orig_archive" "$@" || exit $?
+  else
+    $AR -NOLOGO -OUT:"$archive" "$@" || exit $?
+  fi
+
+elif test -n "$list"; then
+  if test ! -f "$orig_archive"; then
+    func_error "archive not found"
+  fi
+  $AR -NOLOGO -LIST "$archive" || exit $?
+fi
diff -pruN 5.5-3/basic_filters.c 5.9-0ubuntu2/basic_filters.c
--- 5.5-3/basic_filters.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/basic_filters.c	2020-04-17 20:43:15.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -165,6 +165,7 @@ lookup_class(const char *s)
 		{ "%fstatfs",	TRACE_FSTATFS	},
 		{ "%%statfs",	TRACE_STATFS_LIKE	},
 		{ "%pure",	TRACE_PURE	},
+		{ "%clock",	TRACE_CLOCK	},
 		/* legacy class names */
 		{ "desc",	TRACE_DESC	},
 		{ "file",	TRACE_FILE	},
diff -pruN 5.5-3/block.c 5.9-0ubuntu2/block.c
--- 5.5-3/block.c	2018-12-30 15:35:21.000000000 +0000
+++ 5.9-0ubuntu2/block.c	2020-08-25 14:29:30.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2009, 2010 Jeff Mahoney <jeffm@suse.com>
  * Copyright (c) 2011-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2011-2018 The strace developers.
+ * Copyright (c) 2011-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -179,7 +179,7 @@ MPERS_PRINTER_DECL(int, block_ioctl, str
 			PRINT_FIELD_U(", ", buts, buf_nr);
 			PRINT_FIELD_U(", ", buts, start_lba);
 			PRINT_FIELD_U(", ", buts, end_lba);
-			PRINT_FIELD_U(", ", buts, pid);
+			PRINT_FIELD_TGID(", ", buts, pid, tcp);
 			return 0;
 		} else {
 			struct_blk_user_trace_setup buts;
diff -pruN 5.5-3/bpf_attr_check.c 5.9-0ubuntu2/bpf_attr_check.c
--- 5.5-3/bpf_attr_check.c	2020-02-06 16:24:00.000000000 +0000
+++ 5.9-0ubuntu2/bpf_attr_check.c	2020-09-24 09:19:42.000000000 +0000
@@ -90,6 +90,13 @@
 		      "BPF_MAP_CREATE_struct.btf_value_type_id offset mismatch");
 # endif /* HAVE_UNION_BPF_ATTR_BTF_VALUE_TYPE_ID */
 
+# ifdef HAVE_UNION_BPF_ATTR_BTF_VMLINUX_VALUE_TYPE_ID
+	static_assert(sizeof_field(struct BPF_MAP_CREATE_struct, btf_vmlinux_value_type_id) == sizeof_field(union bpf_attr, btf_vmlinux_value_type_id),
+		      "BPF_MAP_CREATE_struct.btf_vmlinux_value_type_id size mismatch");
+	static_assert(offsetof(struct BPF_MAP_CREATE_struct, btf_vmlinux_value_type_id) == offsetof(union bpf_attr, btf_vmlinux_value_type_id),
+		      "BPF_MAP_CREATE_struct.btf_vmlinux_value_type_id offset mismatch");
+# endif /* HAVE_UNION_BPF_ATTR_BTF_VMLINUX_VALUE_TYPE_ID */
+
 static_assert(BPF_MAP_CREATE_struct_size == expected_BPF_MAP_CREATE_struct_size,
 	      "BPF_MAP_CREATE_struct_size mismatch");
 
@@ -408,6 +415,13 @@ static_assert(BPF_OBJ_PIN_struct_size ==
 		      "BPF_PROG_ATTACH_struct.attach_flags offset mismatch");
 # endif /* HAVE_UNION_BPF_ATTR_ATTACH_FLAGS */
 
+# ifdef HAVE_UNION_BPF_ATTR_REPLACE_BPF_FD
+	static_assert(sizeof_field(struct BPF_PROG_ATTACH_struct, replace_bpf_fd) == sizeof_field(union bpf_attr, replace_bpf_fd),
+		      "BPF_PROG_ATTACH_struct.replace_bpf_fd size mismatch");
+	static_assert(offsetof(struct BPF_PROG_ATTACH_struct, replace_bpf_fd) == offsetof(union bpf_attr, replace_bpf_fd),
+		      "BPF_PROG_ATTACH_struct.replace_bpf_fd offset mismatch");
+# endif /* HAVE_UNION_BPF_ATTR_REPLACE_BPF_FD */
+
 static_assert(BPF_PROG_ATTACH_struct_size == expected_BPF_PROG_ATTACH_struct_size,
 	      "BPF_PROG_ATTACH_struct_size mismatch");
 
@@ -850,6 +864,13 @@ static_assert(BPF_TASK_FD_QUERY_struct_s
 		      "bpf_map_info_struct.ifindex offset mismatch");
 # endif /* HAVE_STRUCT_BPF_MAP_INFO_IFINDEX */
 
+# ifdef HAVE_STRUCT_BPF_MAP_INFO_BTF_VMLINUX_VALUE_TYPE_ID
+	static_assert(sizeof_field(struct bpf_map_info_struct, btf_vmlinux_value_type_id) == sizeof_field(struct bpf_map_info, btf_vmlinux_value_type_id),
+		      "bpf_map_info_struct.btf_vmlinux_value_type_id size mismatch");
+	static_assert(offsetof(struct bpf_map_info_struct, btf_vmlinux_value_type_id) == offsetof(struct bpf_map_info, btf_vmlinux_value_type_id),
+		      "bpf_map_info_struct.btf_vmlinux_value_type_id offset mismatch");
+# endif /* HAVE_STRUCT_BPF_MAP_INFO_BTF_VMLINUX_VALUE_TYPE_ID */
+
 # ifdef HAVE_STRUCT_BPF_MAP_INFO_BTF_ID
 	static_assert(sizeof_field(struct bpf_map_info_struct, btf_id) == sizeof_field(struct bpf_map_info, btf_id),
 		      "bpf_map_info_struct.btf_id size mismatch");
@@ -1094,4 +1115,125 @@ static_assert(bpf_map_info_struct_size =
 static_assert(bpf_prog_info_struct_size == expected_bpf_prog_info_struct_size,
 	      "bpf_prog_info_struct_size mismatch");
 
+# ifdef HAVE_UNION_BPF_ATTR_BATCH_IN_BATCH
+	static_assert(sizeof_field(struct BPF_MAP_LOOKUP_BATCH_struct, in_batch) == sizeof_field(union bpf_attr, batch.in_batch),
+		      "BPF_MAP_LOOKUP_BATCH_struct.in_batch size mismatch");
+	static_assert(offsetof(struct BPF_MAP_LOOKUP_BATCH_struct, in_batch) == offsetof(union bpf_attr, batch.in_batch),
+		      "BPF_MAP_LOOKUP_BATCH_struct.in_batch offset mismatch");
+# endif /* HAVE_UNION_BPF_ATTR_BATCH_IN_BATCH */
+
+# ifdef HAVE_UNION_BPF_ATTR_BATCH_OUT_BATCH
+	static_assert(sizeof_field(struct BPF_MAP_LOOKUP_BATCH_struct, out_batch) == sizeof_field(union bpf_attr, batch.out_batch),
+		      "BPF_MAP_LOOKUP_BATCH_struct.out_batch size mismatch");
+	static_assert(offsetof(struct BPF_MAP_LOOKUP_BATCH_struct, out_batch) == offsetof(union bpf_attr, batch.out_batch),
+		      "BPF_MAP_LOOKUP_BATCH_struct.out_batch offset mismatch");
+# endif /* HAVE_UNION_BPF_ATTR_BATCH_OUT_BATCH */
+
+# ifdef HAVE_UNION_BPF_ATTR_BATCH_KEYS
+	static_assert(sizeof_field(struct BPF_MAP_LOOKUP_BATCH_struct, keys) == sizeof_field(union bpf_attr, batch.keys),
+		      "BPF_MAP_LOOKUP_BATCH_struct.keys size mismatch");
+	static_assert(offsetof(struct BPF_MAP_LOOKUP_BATCH_struct, keys) == offsetof(union bpf_attr, batch.keys),
+		      "BPF_MAP_LOOKUP_BATCH_struct.keys offset mismatch");
+# endif /* HAVE_UNION_BPF_ATTR_BATCH_KEYS */
+
+# ifdef HAVE_UNION_BPF_ATTR_BATCH_VALUES
+	static_assert(sizeof_field(struct BPF_MAP_LOOKUP_BATCH_struct, values) == sizeof_field(union bpf_attr, batch.values),
+		      "BPF_MAP_LOOKUP_BATCH_struct.values size mismatch");
+	static_assert(offsetof(struct BPF_MAP_LOOKUP_BATCH_struct, values) == offsetof(union bpf_attr, batch.values),
+		      "BPF_MAP_LOOKUP_BATCH_struct.values offset mismatch");
+# endif /* HAVE_UNION_BPF_ATTR_BATCH_VALUES */
+
+# ifdef HAVE_UNION_BPF_ATTR_BATCH_COUNT
+	static_assert(sizeof_field(struct BPF_MAP_LOOKUP_BATCH_struct, count) == sizeof_field(union bpf_attr, batch.count),
+		      "BPF_MAP_LOOKUP_BATCH_struct.count size mismatch");
+	static_assert(offsetof(struct BPF_MAP_LOOKUP_BATCH_struct, count) == offsetof(union bpf_attr, batch.count),
+		      "BPF_MAP_LOOKUP_BATCH_struct.count offset mismatch");
+# endif /* HAVE_UNION_BPF_ATTR_BATCH_COUNT */
+
+# ifdef HAVE_UNION_BPF_ATTR_BATCH_MAP_FD
+	static_assert(sizeof_field(struct BPF_MAP_LOOKUP_BATCH_struct, map_fd) == sizeof_field(union bpf_attr, batch.map_fd),
+		      "BPF_MAP_LOOKUP_BATCH_struct.map_fd size mismatch");
+	static_assert(offsetof(struct BPF_MAP_LOOKUP_BATCH_struct, map_fd) == offsetof(union bpf_attr, batch.map_fd),
+		      "BPF_MAP_LOOKUP_BATCH_struct.map_fd offset mismatch");
+# endif /* HAVE_UNION_BPF_ATTR_BATCH_MAP_FD */
+
+# ifdef HAVE_UNION_BPF_ATTR_BATCH_ELEM_FLAGS
+	static_assert(sizeof_field(struct BPF_MAP_LOOKUP_BATCH_struct, elem_flags) == sizeof_field(union bpf_attr, batch.elem_flags),
+		      "BPF_MAP_LOOKUP_BATCH_struct.elem_flags size mismatch");
+	static_assert(offsetof(struct BPF_MAP_LOOKUP_BATCH_struct, elem_flags) == offsetof(union bpf_attr, batch.elem_flags),
+		      "BPF_MAP_LOOKUP_BATCH_struct.elem_flags offset mismatch");
+# endif /* HAVE_UNION_BPF_ATTR_BATCH_ELEM_FLAGS */
+
+# ifdef HAVE_UNION_BPF_ATTR_BATCH_FLAGS
+	static_assert(sizeof_field(struct BPF_MAP_LOOKUP_BATCH_struct, flags) == sizeof_field(union bpf_attr, batch.flags),
+		      "BPF_MAP_LOOKUP_BATCH_struct.flags size mismatch");
+	static_assert(offsetof(struct BPF_MAP_LOOKUP_BATCH_struct, flags) == offsetof(union bpf_attr, batch.flags),
+		      "BPF_MAP_LOOKUP_BATCH_struct.flags offset mismatch");
+# endif /* HAVE_UNION_BPF_ATTR_BATCH_FLAGS */
+
+static_assert(BPF_MAP_LOOKUP_BATCH_struct_size == expected_BPF_MAP_LOOKUP_BATCH_struct_size,
+	      "BPF_MAP_LOOKUP_BATCH_struct_size mismatch");
+
+# ifdef HAVE_UNION_BPF_ATTR_LINK_CREATE_PROG_FD
+	static_assert(sizeof_field(struct BPF_LINK_CREATE_struct, prog_fd) == sizeof_field(union bpf_attr, link_create.prog_fd),
+		      "BPF_LINK_CREATE_struct.prog_fd size mismatch");
+	static_assert(offsetof(struct BPF_LINK_CREATE_struct, prog_fd) == offsetof(union bpf_attr, link_create.prog_fd),
+		      "BPF_LINK_CREATE_struct.prog_fd offset mismatch");
+# endif /* HAVE_UNION_BPF_ATTR_LINK_CREATE_PROG_FD */
+
+# ifdef HAVE_UNION_BPF_ATTR_LINK_CREATE_TARGET_FD
+	static_assert(sizeof_field(struct BPF_LINK_CREATE_struct, target_fd) == sizeof_field(union bpf_attr, link_create.target_fd),
+		      "BPF_LINK_CREATE_struct.target_fd size mismatch");
+	static_assert(offsetof(struct BPF_LINK_CREATE_struct, target_fd) == offsetof(union bpf_attr, link_create.target_fd),
+		      "BPF_LINK_CREATE_struct.target_fd offset mismatch");
+# endif /* HAVE_UNION_BPF_ATTR_LINK_CREATE_TARGET_FD */
+
+# ifdef HAVE_UNION_BPF_ATTR_LINK_CREATE_ATTACH_TYPE
+	static_assert(sizeof_field(struct BPF_LINK_CREATE_struct, attach_type) == sizeof_field(union bpf_attr, link_create.attach_type),
+		      "BPF_LINK_CREATE_struct.attach_type size mismatch");
+	static_assert(offsetof(struct BPF_LINK_CREATE_struct, attach_type) == offsetof(union bpf_attr, link_create.attach_type),
+		      "BPF_LINK_CREATE_struct.attach_type offset mismatch");
+# endif /* HAVE_UNION_BPF_ATTR_LINK_CREATE_ATTACH_TYPE */
+
+# ifdef HAVE_UNION_BPF_ATTR_LINK_CREATE_FLAGS
+	static_assert(sizeof_field(struct BPF_LINK_CREATE_struct, flags) == sizeof_field(union bpf_attr, link_create.flags),
+		      "BPF_LINK_CREATE_struct.flags size mismatch");
+	static_assert(offsetof(struct BPF_LINK_CREATE_struct, flags) == offsetof(union bpf_attr, link_create.flags),
+		      "BPF_LINK_CREATE_struct.flags offset mismatch");
+# endif /* HAVE_UNION_BPF_ATTR_LINK_CREATE_FLAGS */
+
+static_assert(BPF_LINK_CREATE_struct_size == expected_BPF_LINK_CREATE_struct_size,
+	      "BPF_LINK_CREATE_struct_size mismatch");
+
+# ifdef HAVE_UNION_BPF_ATTR_LINK_UPDATE_LINK_FD
+	static_assert(sizeof_field(struct BPF_LINK_UPDATE_struct, link_fd) == sizeof_field(union bpf_attr, link_update.link_fd),
+		      "BPF_LINK_UPDATE_struct.link_fd size mismatch");
+	static_assert(offsetof(struct BPF_LINK_UPDATE_struct, link_fd) == offsetof(union bpf_attr, link_update.link_fd),
+		      "BPF_LINK_UPDATE_struct.link_fd offset mismatch");
+# endif /* HAVE_UNION_BPF_ATTR_LINK_UPDATE_LINK_FD */
+
+# ifdef HAVE_UNION_BPF_ATTR_LINK_UPDATE_NEW_PROG_FD
+	static_assert(sizeof_field(struct BPF_LINK_UPDATE_struct, new_prog_fd) == sizeof_field(union bpf_attr, link_update.new_prog_fd),
+		      "BPF_LINK_UPDATE_struct.new_prog_fd size mismatch");
+	static_assert(offsetof(struct BPF_LINK_UPDATE_struct, new_prog_fd) == offsetof(union bpf_attr, link_update.new_prog_fd),
+		      "BPF_LINK_UPDATE_struct.new_prog_fd offset mismatch");
+# endif /* HAVE_UNION_BPF_ATTR_LINK_UPDATE_NEW_PROG_FD */
+
+# ifdef HAVE_UNION_BPF_ATTR_LINK_UPDATE_FLAGS
+	static_assert(sizeof_field(struct BPF_LINK_UPDATE_struct, flags) == sizeof_field(union bpf_attr, link_update.flags),
+		      "BPF_LINK_UPDATE_struct.flags size mismatch");
+	static_assert(offsetof(struct BPF_LINK_UPDATE_struct, flags) == offsetof(union bpf_attr, link_update.flags),
+		      "BPF_LINK_UPDATE_struct.flags offset mismatch");
+# endif /* HAVE_UNION_BPF_ATTR_LINK_UPDATE_FLAGS */
+
+# ifdef HAVE_UNION_BPF_ATTR_LINK_UPDATE_OLD_PROG_FD
+	static_assert(sizeof_field(struct BPF_LINK_UPDATE_struct, old_prog_fd) == sizeof_field(union bpf_attr, link_update.old_prog_fd),
+		      "BPF_LINK_UPDATE_struct.old_prog_fd size mismatch");
+	static_assert(offsetof(struct BPF_LINK_UPDATE_struct, old_prog_fd) == offsetof(union bpf_attr, link_update.old_prog_fd),
+		      "BPF_LINK_UPDATE_struct.old_prog_fd offset mismatch");
+# endif /* HAVE_UNION_BPF_ATTR_LINK_UPDATE_OLD_PROG_FD */
+
+static_assert(BPF_LINK_UPDATE_struct_size == expected_BPF_LINK_UPDATE_struct_size,
+	      "BPF_LINK_UPDATE_struct_size mismatch");
+
 #endif /* HAVE_LINUX_BPF_H */
diff -pruN 5.5-3/bpf_attr.h 5.9-0ubuntu2/bpf_attr.h
--- 5.5-3/bpf_attr.h	2019-12-10 09:44:00.000000000 +0000
+++ 5.9-0ubuntu2/bpf_attr.h	2020-04-18 13:47:17.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2018 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -49,11 +49,12 @@ struct BPF_MAP_CREATE_struct {
 	uint32_t btf_fd;
 	uint32_t btf_key_type_id;
 	uint32_t btf_value_type_id;
+	uint32_t btf_vmlinux_value_type_id;
 };
 
 # define BPF_MAP_CREATE_struct_size \
 	sizeof(struct BPF_MAP_CREATE_struct)
-# define expected_BPF_MAP_CREATE_struct_size 60
+# define expected_BPF_MAP_CREATE_struct_size 64
 
 struct BPF_MAP_LOOKUP_ELEM_struct {
 	uint32_t map_fd;
@@ -150,11 +151,12 @@ struct BPF_PROG_ATTACH_struct {
 	uint32_t attach_bpf_fd;
 	uint32_t attach_type;
 	uint32_t attach_flags;
+	uint32_t replace_bpf_fd;
 };
 
 # define BPF_PROG_ATTACH_struct_size \
 	sizeof(struct BPF_PROG_ATTACH_struct)
-# define expected_BPF_PROG_ATTACH_struct_size 16
+# define expected_BPF_PROG_ATTACH_struct_size 20
 
 struct BPF_PROG_DETACH_struct {
 	uint32_t target_fd;
@@ -298,6 +300,7 @@ struct bpf_map_info_struct {
 	uint32_t map_flags;
 	char     name[BPF_OBJ_NAME_LEN];
 	uint32_t ifindex;
+	uint32_t btf_vmlinux_value_type_id;
 	/*
 	 * The kernel UAPI is broken by Linux commit
 	 * v4.16-rc1~123^2~109^2~5^2~4 .
@@ -358,4 +361,50 @@ struct bpf_prog_info_struct {
 	sizeof(struct bpf_prog_info_struct)
 # define expected_bpf_prog_info_struct_size 208
 
+struct BPF_MAP_LOOKUP_BATCH_struct /* batch */ {
+	uint64_t ATTRIBUTE_ALIGNED(8) in_batch;
+	uint64_t ATTRIBUTE_ALIGNED(8) out_batch;
+	uint64_t ATTRIBUTE_ALIGNED(8) keys;
+	uint64_t ATTRIBUTE_ALIGNED(8) values;
+	uint32_t count;
+	uint32_t map_fd;
+	uint64_t ATTRIBUTE_ALIGNED(8) elem_flags;
+	uint64_t ATTRIBUTE_ALIGNED(8) flags;
+};
+
+# define BPF_MAP_LOOKUP_BATCH_struct_size \
+	sizeof(struct BPF_MAP_LOOKUP_BATCH_struct)
+# define expected_BPF_MAP_LOOKUP_BATCH_struct_size 56
+
+# define BPF_MAP_LOOKUP_AND_DELETE_BATCH_struct BPF_MAP_LOOKUP_BATCH_struct
+# define BPF_MAP_LOOKUP_AND_DELETE_BATCH_struct_size BPF_MAP_LOOKUP_BATCH_struct_size
+
+# define BPF_MAP_UPDATE_BATCH_struct BPF_MAP_LOOKUP_BATCH_struct
+# define BPF_MAP_UPDATE_BATCH_struct_size BPF_MAP_LOOKUP_BATCH_struct_size
+
+# define BPF_MAP_DELETE_BATCH_struct BPF_MAP_LOOKUP_BATCH_struct
+# define BPF_MAP_DELETE_BATCH_struct_size BPF_MAP_LOOKUP_BATCH_struct_size
+
+struct BPF_LINK_CREATE_struct /* link_create */ {
+	uint32_t prog_fd;
+	uint32_t target_fd;
+	uint32_t attach_type;
+	uint32_t flags;
+};
+
+# define BPF_LINK_CREATE_struct_size \
+	sizeof(struct BPF_LINK_CREATE_struct)
+# define expected_BPF_LINK_CREATE_struct_size 16
+
+struct BPF_LINK_UPDATE_struct /* link_update */ {
+	uint32_t link_fd;
+	uint32_t new_prog_fd;
+	uint32_t flags;
+	uint32_t old_prog_fd;
+};
+
+# define BPF_LINK_UPDATE_struct_size \
+	sizeof(struct BPF_LINK_UPDATE_struct)
+# define expected_BPF_LINK_UPDATE_struct_size 16
+
 #endif /* !STRACE_BPF_ATTR_H */
diff -pruN 5.5-3/bpf.c 5.9-0ubuntu2/bpf.c
--- 5.5-3/bpf.c	2019-12-10 09:44:00.000000000 +0000
+++ 5.9-0ubuntu2/bpf.c	2020-08-25 14:29:30.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2015-2017 Dmitry V. Levin <ldv@altlinux.org>
  * Copyright (c) 2017 Quentin Monnet <quentin.monnet@6wind.com>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -224,6 +224,14 @@ BEGIN_BPF_CMD_DECODER(BPF_MAP_CREATE)
 	PRINT_FIELD_FD(", ", attr, btf_fd, tcp);
 	PRINT_FIELD_U(", ", attr, btf_key_type_id);
 	PRINT_FIELD_U(", ", attr, btf_value_type_id);
+
+	/*
+	 * The following field was introduced by Linux commit
+	 * v5.6-rc1~151^2~46^2~37^2~5.
+	 */
+	if (len <= offsetof(struct BPF_MAP_CREATE_struct, btf_vmlinux_value_type_id))
+		break;
+	PRINT_FIELD_U(", ", attr, btf_vmlinux_value_type_id);
 }
 END_BPF_CMD_DECODER(RVAL_DECODED | RVAL_FD)
 
@@ -281,7 +289,7 @@ BEGIN_BPF_CMD_DECODER(BPF_PROG_LOAD)
 	tprints(", insns=");
 	print_ebpf_prog(tcp, attr.insns, attr.insn_cnt);
 
-	tprintf(", license=");
+	tprints(", license=");
 	print_big_u64_addr(attr.license);
 	printstr(tcp, attr.license);
 
@@ -290,7 +298,7 @@ BEGIN_BPF_CMD_DECODER(BPF_PROG_LOAD)
 		break;
 	PRINT_FIELD_U(", ", attr, log_level);
 	PRINT_FIELD_U(", ", attr, log_size);
-	tprintf(", log_buf=");
+	tprints(", log_buf=");
 	print_big_u64_addr(attr.log_buf);
 	printstr_ex(tcp, attr.log_buf, attr.log_size, QUOTE_0_TERMINATED);
 
@@ -358,7 +366,7 @@ END_BPF_CMD_DECODER(RVAL_DECODED | RVAL_
 
 BEGIN_BPF_CMD_DECODER(BPF_OBJ_PIN)
 {
-	tprintf("{pathname=");
+	tprints("{pathname=");
 	print_big_u64_addr(attr.pathname);
 	printpath(tcp, attr.pathname);
 
@@ -381,6 +389,14 @@ BEGIN_BPF_CMD_DECODER(BPF_PROG_ATTACH)
 	PRINT_FIELD_XVAL(", ", attr, attach_type, bpf_attach_type, "BPF_???");
 	PRINT_FIELD_FLAGS(", ", attr, attach_flags, bpf_attach_flags,
 			  "BPF_F_???");
+
+	/*
+	 * The following field was introduced by Linux commit
+	 * v5.6-rc1~151^2~199^2~7^2~3.
+	 */
+	if (len <= offsetof(struct BPF_PROG_ATTACH_struct, replace_bpf_fd))
+		break;
+	PRINT_FIELD_FD(", ", attr, replace_bpf_fd, tcp);
 }
 END_BPF_CMD_DECODER(RVAL_DECODED)
 
@@ -522,6 +538,11 @@ print_bpf_map_info(struct tcb * const tc
 	if (len <= offsetof(struct bpf_map_info_struct, ifindex))
 		goto print_bpf_map_info_end;
 	PRINT_FIELD_IFINDEX(", ", info, ifindex);
+	/*
+	 * btf_vmlinux_value_type_id field was crammed in
+	 * by Linux commit v5.6-rc1~151^2~46^2~37^2~5.
+	 */
+	PRINT_FIELD_U(", ", info, btf_vmlinux_value_type_id);
 	PRINT_FIELD_DEV(", ", info, netns_dev);
 	PRINT_FIELD_U(", ", info, netns_ino);
 
@@ -823,7 +844,7 @@ BEGIN_BPF_CMD_DECODER(BPF_OBJ_GET_INFO_B
 		if (saved && (saved->info_len != attr.info_len))
 			tprintf(" => %u", attr.info_len);
 
-		tprintf(", info=");
+		tprints(", info=");
 	}
 
 	print_bpf_obj_info(tcp, attr.bpf_fd, attr.info, attr.info_len, saved);
@@ -873,7 +894,7 @@ BEGIN_BPF_CMD_DECODER(BPF_RAW_TRACEPOINT
 {
 	enum { TP_NAME_SIZE = 128 };
 
-	tprintf("{raw_tracepoint={name=");
+	tprints("{raw_tracepoint={name=");
 	print_big_u64_addr(attr.name);
 	printstr_ex(tcp, attr.name, TP_NAME_SIZE, QUOTE_0_TERMINATED);
 
@@ -906,7 +927,7 @@ BEGIN_BPF_CMD_DECODER(BPF_TASK_FD_QUERY)
 	if (entering(tcp)) {
 		set_tcb_priv_ulong(tcp, attr.buf_len);
 
-		PRINT_FIELD_U("{task_fd_query={", attr, pid);
+		PRINT_FIELD_TGID("{task_fd_query={", attr, pid, tcp);
 		PRINT_FIELD_FD(", ", attr, fd, tcp);
 		PRINT_FIELD_U(", ", attr, flags);
 		PRINT_FIELD_U(", ", attr, buf_len);
@@ -920,7 +941,7 @@ BEGIN_BPF_CMD_DECODER(BPF_TASK_FD_QUERY)
 		tprintf(" => %u", attr.buf_len);
 
 	const unsigned int buf_len = MIN(saved_buf_len, attr.buf_len);
-	tprintf(", buf=");
+	tprints(", buf=");
 	print_big_u64_addr(attr.buf);
 	printstr_ex(tcp, attr.buf, buf_len, QUOTE_0_TERMINATED);
 	PRINT_FIELD_U(", ", attr, prog_id);
@@ -933,6 +954,112 @@ BEGIN_BPF_CMD_DECODER(BPF_TASK_FD_QUERY)
 }
 END_BPF_CMD_DECODER(RVAL_DECODED)
 
+BEGIN_BPF_CMD_DECODER(BPF_MAP_LOOKUP_BATCH)
+{
+	if (entering(tcp)) {
+		set_tcb_priv_ulong(tcp, attr.count);
+
+		PRINT_FIELD_ADDR64("{batch={", attr, in_batch);
+		PRINT_FIELD_ADDR64(", ", attr, out_batch);
+		PRINT_FIELD_ADDR64(", ", attr, keys);
+		PRINT_FIELD_ADDR64(", ", attr, values);
+		PRINT_FIELD_U(", ", attr, count);
+		PRINT_FIELD_FD(", ", attr, map_fd, tcp);
+		PRINT_FIELD_FLAGS(", ", attr, elem_flags,
+				  bpf_map_lookup_elem_flags, "BPF_???");
+		PRINT_FIELD_X(", ", attr, flags);
+
+		tprints("}");
+	} else {
+		unsigned long count = get_tcb_priv_ulong(tcp);
+
+		if (count != attr.count) {
+			PRINT_FIELD_U("=> {batch={", attr, count);
+			tprints("}}");
+		}
+
+		return RVAL_DECODED;
+	}
+}
+END_BPF_CMD_DECODER(0)
+
+#define decode_BPF_MAP_LOOKUP_AND_DELETE_BATCH decode_BPF_MAP_LOOKUP_BATCH
+
+BEGIN_BPF_CMD_DECODER(BPF_MAP_UPDATE_BATCH)
+{
+	if (entering(tcp)) {
+		set_tcb_priv_ulong(tcp, attr.count);
+
+		PRINT_FIELD_ADDR64("{batch={", attr, keys);
+		PRINT_FIELD_ADDR64(", ", attr, values);
+		PRINT_FIELD_U(", ", attr, count);
+		PRINT_FIELD_FD(", ", attr, map_fd, tcp);
+		PRINT_FIELD_FLAGS(", ", attr, elem_flags,
+				  bpf_map_lookup_elem_flags, "BPF_???");
+		PRINT_FIELD_X(", ", attr, flags);
+
+		tprints("}");
+	} else {
+		unsigned long count = get_tcb_priv_ulong(tcp);
+
+		if (count != attr.count) {
+			PRINT_FIELD_U("=> {batch={", attr, count);
+			tprints("}}");
+		}
+
+		return RVAL_DECODED;
+	}
+}
+END_BPF_CMD_DECODER(0)
+
+BEGIN_BPF_CMD_DECODER(BPF_MAP_DELETE_BATCH)
+{
+	if (entering(tcp)) {
+		set_tcb_priv_ulong(tcp, attr.count);
+
+		PRINT_FIELD_ADDR64("{batch={", attr, keys);
+		PRINT_FIELD_U(", ", attr, count);
+		PRINT_FIELD_FD(", ", attr, map_fd, tcp);
+		PRINT_FIELD_FLAGS(", ", attr, elem_flags,
+				  bpf_map_lookup_elem_flags, "BPF_???");
+		PRINT_FIELD_X(", ", attr, flags);
+
+		tprints("}");
+	} else {
+		unsigned long count = get_tcb_priv_ulong(tcp);
+
+		if (count != attr.count) {
+			PRINT_FIELD_U("=> {batch={", attr, count);
+			tprints("}}");
+		}
+
+		return RVAL_DECODED;
+	}
+}
+END_BPF_CMD_DECODER(0)
+
+BEGIN_BPF_CMD_DECODER(BPF_LINK_CREATE)
+{
+	PRINT_FIELD_FD("{link_create={", attr, prog_fd, tcp);
+	PRINT_FIELD_FD(", ", attr, target_fd, tcp);
+	PRINT_FIELD_XVAL(", ", attr, attach_type, bpf_attach_type, "BPF_???");
+	PRINT_FIELD_X(", ", attr, flags);
+	tprints("}");
+}
+END_BPF_CMD_DECODER(RVAL_DECODED | RVAL_FD)
+
+BEGIN_BPF_CMD_DECODER(BPF_LINK_UPDATE)
+{
+	PRINT_FIELD_FD("{link_update={", attr, link_fd, tcp);
+	PRINT_FIELD_FD(", ", attr, new_prog_fd, tcp);
+	PRINT_FIELD_FLAGS(", ", attr, flags, bpf_attach_flags,
+			  "BPF_F_???");
+	if (attr.flags & BPF_F_REPLACE)
+		PRINT_FIELD_FD(", ", attr, old_prog_fd, tcp);
+	tprints("}");
+}
+END_BPF_CMD_DECODER(RVAL_DECODED)
+
 SYS_FUNC(bpf)
 {
 	static const bpf_cmd_decoder_t bpf_cmd_decoders[] = {
@@ -960,6 +1087,12 @@ SYS_FUNC(bpf)
 		BPF_CMD_ENTRY(BPF_MAP_LOOKUP_AND_DELETE_ELEM),
 		BPF_CMD_ENTRY(BPF_MAP_FREEZE),
 		BPF_CMD_ENTRY(BPF_BTF_GET_NEXT_ID),
+		BPF_CMD_ENTRY(BPF_MAP_LOOKUP_BATCH),
+		BPF_CMD_ENTRY(BPF_MAP_LOOKUP_AND_DELETE_BATCH),
+		BPF_CMD_ENTRY(BPF_MAP_UPDATE_BATCH),
+		BPF_CMD_ENTRY(BPF_MAP_DELETE_BATCH),
+		BPF_CMD_ENTRY(BPF_LINK_CREATE),
+		BPF_CMD_ENTRY(BPF_LINK_UPDATE),
 	};
 
 	const unsigned int cmd = tcp->u_arg[0];
diff -pruN 5.5-3/btrfs.c 5.9-0ubuntu2/btrfs.c
--- 5.5-3/btrfs.c	2019-05-21 14:53:06.000000000 +0000
+++ 5.9-0ubuntu2/btrfs.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2016 Jeff Mahoney <jeffm@suse.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -33,6 +33,7 @@ typedef struct btrfs_ioctl_vol_args_v2
 #ifdef HAVE_LINUX_BTRFS_H
 
 # include "print_fields.h"
+# include "types/btrfs.h"
 # include <linux/fs.h>
 
 /*
@@ -833,7 +834,7 @@ MPERS_PRINTER_DECL(int, btrfs_ioctl,
 	}
 
 	case BTRFS_IOC_LOGICAL_INO: { /* RW */
-		struct btrfs_ioctl_logical_ino_args args;
+		struct_btrfs_ioctl_logical_ino_args args;
 
 		if (entering(tcp))
 			tprints(", ");
@@ -849,23 +850,12 @@ MPERS_PRINTER_DECL(int, btrfs_ioctl,
 			PRINT_FIELD_U("{", args, logical);
 			PRINT_FIELD_U(", ", args, size);
 
-			if (!IS_ARRAY_ZERO(args.reserved)) {
-				tprints(", reserved=[");
-				for (size_t i = 0; i < 3; ++i)
-					tprintf("%s%#" PRI__x64,
-						i ? ", " : "",
-						args.reserved[i]);
-				tprints("]");
-			}
+			if (!IS_ARRAY_ZERO(args.reserved))
+				PRINT_FIELD_X_ARRAY(", ", args, reserved);
 
-			tprintf(", flags=");
-			printflags64(btrfs_logical_ino_args_flags,
-# ifdef HAVE_STRUCT_BTRFS_IOCTL_LOGICAL_INO_ARGS_FLAGS
-				     args.flags
-# else
-				     args.reserved[3]
-# endif
-				     , "BTRFS_LOGICAL_INO_ARGS_???");
+			tprints(", flags=");
+			printflags64(btrfs_logical_ino_args_flags, args.flags,
+				     "BTRFS_LOGICAL_INO_ARGS_???");
 			PRINT_FIELD_ADDR64(", ", args, inodes);
 			tprints("}");
 			return 0;
diff -pruN 5.5-3/capability.c 5.9-0ubuntu2/capability.c
--- 5.5-3/capability.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/capability.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,7 +2,7 @@
  * Copyright (c) 2000 Wichert Akkerman <wakkerma@debian.org>
  * Copyright (c) 2011 Denys Vlasenko <dvlasenk@redhat.com>
  * Copyright (c) 2005-2015 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2014-2018 The strace developers.
+ * Copyright (c) 2014-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -70,7 +70,9 @@ print_cap_header(struct tcb *const tcp,
 	tprints("{version=");
 	printxval(cap_version, h->version,
 		  "_LINUX_CAPABILITY_VERSION_???");
-	tprintf(", pid=%d}", h->pid);
+	tprints(", pid=");
+	printpid(tcp, h->pid, PT_TGID);
+	tprints("}");
 }
 
 static void
diff -pruN 5.5-3/caps1.h 5.9-0ubuntu2/caps1.h
--- 5.5-3/caps1.h	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/caps1.h	2020-09-06 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2015-2020 Dmitry V. Levin <ldv@altlinux.org>
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -11,3 +11,6 @@ CAP_SYSLOG,
 CAP_WAKE_ALARM,
 CAP_BLOCK_SUSPEND,
 CAP_AUDIT_READ,
+CAP_PERFMON,
+CAP_BPF,
+CAP_CHECKPOINT_RESTORE,
diff -pruN 5.5-3/ChangeLog 5.9-0ubuntu2/ChangeLog
--- 5.5-3/ChangeLog	2020-02-06 16:24:03.000000000 +0000
+++ 5.9-0ubuntu2/ChangeLog	2020-09-24 09:19:47.000000000 +0000
@@ -1,3 +1,5247 @@
+2020-09-24  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Prepare for 5.9 release.
+	* NEWS: Update for 5.9 release.
+
+2020-09-23  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Update copyright headers.
+	Headers updated automatically using maint/update_copyright_years.sh
+	script.
+
+2020-09-23  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Fix preprocessor indentation.
+	Indent the C preprocessor directives to reflect their nesting
+	using the following script:
+
+	$ cppi -l $(git grep -El '^[[:space:]]*#[[:space:]]*(if|ifdef|ifndef|elif|else|endif|define|pragma)[[:space:]]' |grep -v '\.sh$') |while read f; do
+		cppi < "$f" > "$f".cppi; mv "$f".cppi "$f"
+	done
+
+2020-09-23  Gleb Fotengauer-Malinovskiy  <glebfm@altlinux.org>
+
+	Update ioctl entries from linux v5.9.
+	* linux/32/ioctls_inc_align16.h: Update from linux v5.9-rc6
+	using ioctls_gen.sh.
+	* linux/32/ioctls_inc_align32.h: Likewise.
+	* linux/32/ioctls_inc_align64.h: Likewise.
+	* linux/64/ioctls_inc.h: Likewise.
+	* linux/x32/ioctls_inc0.h: Likewise.
+	* NEWS: Mention this.
+	* tests/ioctl_v4l2.c (main): Skip conflicting ioctl command
+	VBG_IOCTL_ACQUIRE_GUEST_CAPABILITIES.
+
+	maint: update for linux v5.9.
+	* maint/ioctls_gen.sh: Add arch/<arch>/include/generated/uapi and
+	arch/<arch>/include/generated directories to INCLUDES.
+	* maint/ioctls_sym.sh: Add workaround definitions of
+	__no_kasan_or_inline and __no_sanitize_or_inline macros.
+
+2020-09-23  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	strace.1.in: mention --seccomp-bpf in "A traced process runs slowly" bug
+	As it is worth mentioning here, probably.
+
+	* strace.1.in (.SH BUGS): Refer to --seccomp-bpf option description in
+	"A traced process runs slowly" bug.
+
+2020-09-23  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	NEWS: provide a Fedora bug number for the --pidns-translation entry.
+
+2020-09-23  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	tee: use types/ directory for the type definitions header.
+	Also, switch ioctl_tee test to system header usage, to double-check
+	things.
+
+	* tee.h: Rename to...
+	* types/tee.h: ...this.  Remove "xlat/tee_ioctl_cmds.h",
+	"xlat/tee_ioctl_gen_caps.h", "xlat/tee_ioctl_impl_ids.h",
+	"xlat/tee_ioctl_login_types.h", "xlat/tee_ioctl_max_arg_size.h",
+	"xlat/tee_ioctl_origins.h", "xlat/tee_ioctl_optee_caps.h",
+	"xlat/tee_ioctl_param_attr_types.h", "xlat/tee_ioctl_shm_flags.h"
+	includes.  Add header guard.
+	[!HAVE_STRUCT_TEE_IOCTL_BUF_DATA, !HAVE_STRUCT_TEE_IOCTL_CANCEL_ARG,
+	!HAVE_STRUCT_TEE_IOCTL_CLOSE_SESSION_ARG,
+	!HAVE_STRUCT_TEE_IOCTL_SHM_ALLOC_DATA,
+	!HAVE_STRUCT_TEE_IOCTL_SHM_REGISTER_FD_DATA,
+	!HAVE_STRUCT_TEE_IOCTL_SHM_REGISTER_DATA,
+	!HAVE_STRUCT_TEE_IOCTL_VERSION_DATA, !HAVE_STRUCT_TEE_IOCTL_PARAM,
+	!HAVE_STRUCT_TEE_IOCTL_INVOKE_ARG, !HAVE_STRUCT_TEE_IOCL_SUPP_RECV_ARG,
+	!HAVE_STRUCT_TEE_IOCL_SUPP_SEND_ARG,
+	!HAVE_STRUCT_TEE_IOCTL_OPEN_SESSION_ARG]: Remove ifdefs.
+	(struct tee_ioctl_buf_data): Change to...
+	(typedef struct_tee_ioctl_buf_data): ...this.
+	(struct tee_ioctl_cancel_arg): Change to...
+	(typedef struct_tee_ioctl_cancel_arg): ...this.
+	(struct tee_ioctl_close_session_arg): Change to...
+	(typedef struct_tee_ioctl_close_session_arg): ...this.
+	(struct tee_ioctl_shm_alloc_data): Change to...
+	(typedef struct_tee_ioctl_shm_alloc_data): ...this.
+	(struct tee_ioctl_shm_register_fd_data): Change to...
+	(typedef struct_tee_ioctl_shm_register_fd_data): ...this.
+	(struct tee_ioctl_shm_register_data): Change to...
+	(typedef struct_tee_ioctl_shm_register_data): ...this.
+	(struct tee_ioctl_version_data): Change to...
+	(typedef struct_tee_ioctl_version_data): ...this.
+	(struct tee_ioctl_param): Change to...
+	(typedef struct_tee_ioctl_param): ...this.
+	(struct tee_ioctl_invoke_arg): Change to...
+	(typedef struct_tee_ioctl_invoke_arg): ...this.  Change params field
+	type from struct tee_ioctl_param to struct_tee_ioctl_param.
+	(struct tee_iocl_supp_recv_arg): Change to...
+	(typedef struct_tee_iocl_supp_recv_arg): ...this.  Change params field
+	type from struct tee_ioctl_param to struct_tee_ioctl_param.
+	(struct tee_iocl_supp_send_arg): Change to...
+	(typedef struct_tee_iocl_supp_send_arg): ...this.  Change params field
+	type from struct tee_ioctl_param to struct_tee_ioctl_param.
+	(struct tee_ioctl_open_session_arg): Change to...
+	(typedef struct_tee_ioctl_open_session_arg): ...this.  Change params
+	field type from struct tee_ioctl_param to struct_tee_ioctl_param.
+	[TEE_IOCTL_PARAM_SIZE]: Move to tee.c.
+	* Makefile.am (libstrace_a_SOURCES): Remove tee.h.
+	* configure.ac (AC_CHECK_HEADERS([linux/tee.h])): Remove in favour of
+	auto-generated checks courtesy of types/tee.h.
+	* tee.c: Remove "tee.h" include.  Add "types/tee.h",
+	"xlat/tee_ioctl_cmds.h" (under XLAT_MACROS_ONLY definition),
+	"xlat/tee_ioctl_gen_caps.h", "xlat/tee_ioctl_impl_ids.h",
+	"xlat/tee_ioctl_login_types.h", "xlat/tee_ioctl_max_arg_size.h",
+	"xlat/tee_ioctl_origins.h", "xlat/tee_ioctl_optee_caps.h",
+	"xlat/tee_ioctl_param_attr_types.h", "xlat/tee_ioctl_shm_flags.h"
+	includes.
+	[TEE_IOCTL_PARAM_SIZE]: Move from tee.h.
+	(tee_print_buf, tee_fetch_buf_data): Change the buf argument type
+	from struct tee_ioctl_buf_data to struct_tee_ioctl_buf_data.
+	(tee_print_param_fn): Change the param variable type from
+	struct tee_ioctl_param to struct_tee_ioctl_param.
+	(tee_print_params): Change the param_buffer variable type from
+	struct tee_ioctl_param to struct_tee_ioctl_param.
+	(tee_version): Change the version variable type from
+	struct tee_ioctl_version_data to struct_tee_ioctl_version_data.
+	(tee_open_session): Change the buf_data variable type from
+	struct_tee ioctl_buf_data to struct_tee_ioctl_buf_data.  Change
+	the open_session variable type from struct tee_ioctl_open_session_arg
+	to struct_tee_ioctl_open_session_arg.
+	(tee_invoke): Change the buf_data variable type from
+	struct_tee ioctl_buf_data to struct_tee_ioctl_buf_data.  Change
+	the invoke variable type from struct tee_ioctl_invoke_arg to
+	struct_tee_ioctl_invoke_arg.
+	(tee_cancel): Change the cancel variable type from
+	struct tee_ioctl_cancel_arg to struct_tee_ioctl_cancel_arg.
+	(tee_close_session): Change the close_session variable type from
+	struct tee_ioctl_close_session_arg to
+	struct_tee_ioctl_close_session_arg.
+	(tee_suppl_recv): Change the buf_data variable type from
+	struct_tee ioctl_buf_data to struct_tee_ioctl_buf_data.  Change
+	the supp_recv variable type from struct tee_iocl_supp_recv_arg
+	to struct_tee_iocl_supp_recv_arg.
+	(tee_suppl_send): Change the buf_data variable type from
+	struct_tee ioctl_buf_data to struct_tee_ioctl_buf_data.  Change
+	the supp_send variable type from struct tee_iocl_supp_send_arg
+	to struct_tee_iocl_supp_send_arg.
+	(tee_shm_alloc): Change the shm_alloc variable type from
+	struct tee_ioctl_shm_alloc_data to struct_tee_ioctl_shm_alloc_data.
+	(tee_shm_register_fd): Change the shm_register_fd variable type from
+	struct tee_ioctl_shm_register_fd_data to
+	struct_tee_ioctl_shm_register_fd_data.
+	(tee_shm_register): Change the shm_register variable type from
+	struct tee_ioctl_shm_register_data to
+	struct_tee_ioctl_shm_register_data.
+	* tests/ioctl_tee.c: Put the contents under HAVE_LINUX_TEE_H ifdef.
+	Remove "tee.h" include.  Add <linux/tee.h> include.
+	[!TEE_IOCTL_PARAM_ATTR_META] (TEE_IOCTL_PARAM_ATTR_META): New
+	definition.
+	[!HAVE_STRUCT_TEE_IOCTL_SHM_REGISTER_FD_DATA] (struct
+	tee_ioctl_shm_register_fd_data): New type definition.
+	[!HAVE_STRUCT_TEE_IOCTL_SHM_REGISTER_DATA] (struct
+	tee_ioctl_shm_register_data): Likewise.
+	[!TEE_IOC_SHM_REGISTER_FD] (TEE_IOC_SHM_REGISTER_FD): New definition.
+	[!TEE_IOC_SHM_REGISTER] (TEE_IOC_SHM_REGISTER): Likewise.
+	* xlat/tee_ioctl_cmds.in (TEE_IOC_VERSION): Change type in the _IOR
+	macro argument from struct tee_ioctl_version_data to
+	struct_tee_ioctl_version_data.
+	(TEE_IOC_SHM_ALLOC): Change the type in the _IOWR macro argument from
+	struct tee_ioctl_shm_alloc_data to struct_tee_ioctl_shm_alloc_data.
+	(TEE_IOC_OPEN_SESSION): Change the type in the _IOR macro argument from
+	struct tee_ioctl_buf_data to struct_tee_ioctl_buf_data.
+	(TEE_IOC_INVOKE): Change the type in the _IOR macro argument from
+	struct tee_ioctl_buf_data to struct_tee_ioctl_buf_data.
+	(TEE_IOC_CANCEL): Change the type in the _IOR macro argument from
+	struct tee_ioctl_cancel_arg to struct_tee_ioctl_cancel_arg.
+	(TEE_IOC_CLOSE_SESSION): Change the type in the _IOR macro argument
+	from struct tee_ioctl_close_session_arg
+	to struct_tee_ioctl_close_session_arg.
+	(TEE_IOC_SUPPL_RECV): Change the type in the _IOR macro argument
+	from struct tee_ioctl_buf_data to struct_tee_ioctl_buf_data.
+	(TEE_IOC_SUPPL_SEND): Change the type in the _IOR macro argument
+	from struct tee_ioctl_buf_data to struct_tee_ioctl_buf_data.
+	(TEE_IOC_SHM_REGISTER_FD): Change the type in the _IOWR macro argument
+	from struct tee_ioctl_shm_register_fd_data
+	to struct_tee_ioctl_shm_register_fd_data.
+	(TEE_IOC_SHM_REGISTER): Change the type in the _IOWR macro argument
+	from struct tee_ioctl_shm_register_data
+	to struct_tee_ioctl_shm_register_data.
+
+2020-09-23  Elvira Khabirova  <lineprinter0@gmail.com>
+
+	Implement decoding of TEE_* ioctls.
+	* tee.c: New file.
+	* tee.h: Likewise.
+	* Makefile.am (libstrace_a_SOURCES): Add them.
+	* configure.ac (AC_CHECK_HEADERS): Add linux/tee.h.
+	* defs.h (DECL_IOCTL): Add tee.
+	* ioctl.c (ioctl_decode): Add 0xa4 (tee) case.
+	* xlat/tee_ioctl_cmds.in: New file.
+	* xlat/tee_ioctl_gen_caps.in: Likewise.
+	* xlat/tee_ioctl_impl_ids.in: Likewise.
+	* xlat/tee_ioctl_login_types.in: Likewise.
+	* xlat/tee_ioctl_max_arg_size.in: Likewise.
+	* xlat/tee_ioctl_optee_caps.in: Likewise.
+	* xlat/tee_ioctl_origins.in: Likewise.
+	* xlat/tee_ioctl_param_attr_types.in: Likewise.
+	* xlat/tee_ioctl_shm_flags.in: Likewise.
+	* tests/gen_tests.in (ioctl_tee): New entry.
+	* tests/ioctl_tee.c: New file.
+	* tests/.gitignore: Add ioctl_tee.
+	* tests/pure_executables.list: Likewise.
+	* NEWS: Mention the change.
+
+2020-09-20  Dmitry V. Levin  <ldv@altlinux.org>
+
+	xlat: update KVM_* constants.
+	* xlat/kvm_cap.in (KVM_CAP_STEAL_TIME): New constant introduced by Linux
+	kernel commit v5.9-rc5~6^2~16^2~3.
+
+2020-09-19  Dmitry V. Levin  <ldv@altlinux.org>
+
+	semctl: decode struct arguments of IPC_* and SEM_* commands.
+	* ipc_semctl.c: New file.
+	* Makefile.am (libstrace_a_SOURCES): Add it.
+	* ipc_defs.h (NAME_OF_STRUCT_SEMID_DS): New macro.
+	* ipc_sem.c: Stop including "xlat/semctl_flags.h".
+	(SYS_FUNC(semctl)): Remove.
+	* tests/ipc_sem.c (str_ipc_info): New macro.
+	(print_semid_ds, print_sem_info): New functions.
+	(main): Use them to check decoding IPC_INFO, SEM_INFO, IPC_SET,
+	IPC_STAT, SEM_STAT, and SEM_STAT_ANY semctl syscall commands.
+	* NEWS: Mention this change.
+
+2020-09-19  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: disable shmctl IPC_STAT test with a bogus address on glibc >= 2.32
+	Starting with commit glibc-2.32~80, on every 32-bit architecture where
+	32-bit time_t support is enabled, glibc tries to retrieve the data
+	provided in the third argument of shmctl call.  This results to
+	segfaults inside glibc when shmctl is called with a bogus address.
+
+	* tests/ipc_shm.c [GLIBC_PREREQ_GE(2, 32) && __TIMESIZE != 64]
+	(TEST_SHMCTL_BOGUS_ADDR): Define to 0.
+	(main): Conditionalize on TEST_SHMCTL_BOGUS_ADDR the shmctl IPC_STAT
+	invocation with a bogus address.
+
+2020-09-19  Dmitry V. Levin  <ldv@altlinux.org>
+
+	shmctl: decode some commands on entering syscall.
+	* ipc_shmctl.c (SYS_FUNC(shmctl)): Handle all commands except IPC_INFO,
+	IPC_STAT, SHM_INFO, SHM_STAT, and SHM_STAT_ANY on entering syscall.
+
+	shmctl: decode struct shminfo argument of IPC_INFO command.
+	* ipc_defs.h (NAME_OF_STRUCT_SHMINFO): New macro.
+	* ipc_shmctl.c (struct_shm_ipc_info_t): New typedef.  Mpersify it.
+	(print_ipc_info): New function.
+	(SYS_FUNC(shmctl)): Use it to decode struct shminfo argument
+	of IPC_INFO command.
+	* tests/ipc_shm.c (str_ipc_info): New macro.
+	(print_ipc_info): New function.
+	(main): Use it to check decoding of IPC_INFO command.
+	* NEWS: Mention this change.
+
+	shmctl: decode struct shm_info argument of SHM_INFO command.
+	* ipc_shmctl.c (struct_shm_info_t): New typedef.  Mpersify it.
+	(print_shm_info): New function.
+	(SYS_FUNC(shmctl)): Use it to decode struct shm_info argument
+	of SHM_INFO command.
+	* tests/ipc_shm.c (print_shm_info): New function.
+	(main): Use it to check decoding of SHM_INFO command.
+	* NEWS: Mention this change.
+
+	shmctl: fix printing of struct shmid_ds argument of IPC_SET command.
+	* ipc_shmctl.c (print_shmid_ds) <cmd == IPC_SET>: Do not print
+	misleading ellipsis.
+	* tests/ipc_shm.c (main): Update expected output.
+
+	shmctl: decode struct shmid_ds argument of SHM_STAT and SHM_STAT_ANY commands
+	* ipc_shmctl.c (print_shmid_ds): Handle SHM_STAT and SHM_STAT_ANY.
+	* tests/ipc_shm.c (print_shmid_ds): New function.
+	(main): Use it to update expected output.
+	* NEWS: Mention this change.
+
+	shmctl: consistently use macros from print_fields.h.
+	* ipc_shmctl.c (key): Define.
+	(print_shmid_ds): Use PRINT_FIELD_U instead of tprintf.
+
+	msgctl: decode some commands on entering syscall.
+	* ipc_msgctl.c (SYS_FUNC(msgctl)): Handle all commands except IPC_INFO,
+	IPC_STAT, MSG_INFO, MSG_STAT, and MSG_STAT_ANY on entering syscall.
+
+	msgctl: decode struct msginfo argument of IPC_INFO and MSG_INFO commands
+	* ipc_msgctl.c (print_msginfo): New function.
+	(SYS_FUNC(msgctl)): Use it to decode struct msginfo argument of IPC_INFO
+	and MSG_INFO commands.
+	* tests/ipc_msg.c (print_msginfo): New function.
+	(main): Use it to check decoding of IPC_INFO and MSG_INFO commands.
+	* NEWS: Mention this change.
+
+	msgctl: print struct msqid_ds.msg_qbytes of IPC_SET command.
+	* ipc_msgctl.c (print_msqid_ds) <cmd == IPC_SET>: Print
+	struct msqid_ds.msg_qbytes.
+	* tests/ipc_msg.c (main): Update expected output.
+
+	msgctl: decode struct msqid_ds argument of MSG_STAT and MSG_STAT_ANY commands
+	* ipc_msgctl.c (print_msqid_ds): Handle MSG_STAT and MSG_STAT_ANY.
+	* tests/ipc_msg.c (print_msqid_ds): New function.
+	(main): Use it to update expected output.
+	* NEWS: Mention this change.
+
+	msgctl: consistently use macros from print_fields.h.
+	* ipc_msgctl.c (key): Define.
+	(print_msqid_ds): Use PRINT_FIELD_U instead of tprintf.
+
+2020-09-18  Dmitry V. Levin  <ldv@altlinux.org>
+
+	ci: add a git status check.
+	* ci/run-build-and-tests.sh: Check that "git status" does not report
+	any differences or untracked files.
+	[$CHECK == coverage]: Remove ./codecov.bash after use.
+	* .gitignore: Add "/travis_wait_*.log".
+
+	.gitignore: ignore files generated by gcov.
+	* .gitignore: Add *.gcov.
+
+2020-09-18  Elvira Khabirova  <lineprinter0@gmail.com>
+
+	xlat: fix file descriptor closing typo.
+	* xlat/gen.sh (gen_header): Replace 3>- with 3>&-.
+
+	Fixes: v5.7~28 "xlat: generate m4 checks for enumerations"
+
+2020-09-14  Elvira Khabirova  <lineprinter0@gmail.com>
+
+	.gitignore: add missing files that should be ignored.
+	ar-lib is an autotools helper script.
+	tags, TAGS, cscope.* and ncscope.* are files generated by ctags and cscope,
+	source code analysers and navigation tools.
+
+	* .gitignore: Add /ar-lib, /cscope.*, /ncscope.*, /tags and /TAGS.
+
+2020-09-12  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests/ipc_msg.c: disable TEST_MSGCTL_BOGUS_ADDR on glibc >= 2.32.
+	Starting with commit glibc-2.32~83, on every 32-bit architecture where
+	32-bit time_t support is enabled, glibc tries to retrieve the data
+	provided in the third argument of msgctl call.  This results to
+	segfaults inside glibc if TEST_MSGCTL_BOGUS_ADDR is enabled.
+
+	* tests/ipc_msg.c [GLIBC_PREREQ_GE(2, 32) && __TIMESIZE != 64]
+	(TEST_MSGCTL_BOGUS_ADDR): Define to 0.
+
+	Reported-by: Ruinland ChuanTzu Tsai <ruinland@andestech.com>
+
+2020-09-12  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Introduce GLIBC_PREREQ_GE and GLIBC_PREREQ_LT macros.
+	* gcc_compat.h (GLIBC_PREREQ_GE, GLIBC_PREREQ_LT): New macros.
+	* tests/ipc_msg.c: Use GLIBC_PREREQ_LT instead of manual checking
+	for __GLIBC__ and __GLIBC_MINOR__.
+	* tests/readahead.c: Likewise.
+
+2020-09-06  Dmitry V. Levin  <ldv@altlinux.org>
+
+	ci: re-enable testing with the latest mainline kernel headers.
+	There should be no issues with v5.9-rc4.
+	This reverts commit 1c84f0b04d0fd8d37afd29a4c959fb8c863bcfdb.
+
+	* .github/workflows/ci.yml (env): Remove KBRANCH.
+	* .gitlab-ci.yml (variables): Likewise.
+	* .travis.yml (env:global): Likewise.
+
+2020-09-06  Dmitry V. Levin  <ldv@altlinux.org>
+
+	types/v4l2.h: update definition of struct_v4l2_create_buffers.
+	* types/v4l2.h (struct_v4l2_create_buffers): Add "flags" field and
+	update "reserved" field to sync with changes introduced by Linux kernel
+	commit v5.9-rc1~94^2~295.
+
+	xlat: update V4L2_FMT_FLAG_* constants.
+	* xlat/v4l2_format_description_flags.in
+	(V4L2_FMT_FLAG_ENC_CAP_FRAME_INTERVAL): New constant introduced by Linux
+	kernel commit v5.9-rc1~94^2~283.
+	* NEWS: Mention this change.
+	* tests/ioctl_v4l2-success.c (fmtdesc_flags): Update expected output.
+
+	xlat: update RTPROT_* constants.
+	* xlat/routing_protocols.in (RTPROT_KEEPALIVED): New constant introduced
+	by Linux kernel commit v5.9-rc1~133^2~449.
+	* NEWS: Mention this change.
+
+	xlat: update PTP_PEROUT_* constants.
+	* xlat/rtnl_neigh_attrs.in (PTP_PEROUT_DUTY_CYCLE): New constant
+	introduced by Linux kernel commit v5.9-rc1~133^2~199^2~2.
+	(PTP_PEROUT_PHASE): New constant introduced by Linux kernel commit
+	v5.9-rc1~133^2~199^2~1.
+	* NEWS: Mention this change.
+
+	xlat: update NDA_* constants.
+	* xlat/rtnl_neigh_attrs.in (NDA_FDB_EXT_ATTRS): New constant introduced
+	by Linux kernel commit v5.9-rc1~133^2~430^2~2.
+	* NEWS: Mention this change.
+
+	xlat: update KVM_* constants.
+	* xlat/kvm_cap.in (KVM_CAP_LAST_CPU): New constant introduced by Linux
+	kernel commit v5.9-rc1~121^2~108.
+	(KVM_CAP_SMALLER_MAXPHYADDR): New constant introduced by Linux kernel
+	commit v5.9-rc1~121^2~15.
+	(KVM_CAP_S390_DIAG318): New constant introduced by Linux kernel commit
+	v5.9-rc1~121^2^2.
+	* NEWS: Mention this change.
+
+	xlat: update IORING_FEAT_* constants.
+	* xlat/uring_setup_features.in (IORING_FEAT_POLL_32BITS): New constant
+	introduced by Linux kernel commit v5.9-rc1~212^2~116.
+	* NEWS: Mention this change.
+
+	xlat: update INET_DIAG_REQ_* constants.
+	* linux/inet_diag.h (INET_DIAG_REQ_SK_BPF_STORAGES): New constant
+	introduced by Linux kernel commit v5.7-rc1~146^2~287^2^2.
+	(INET_DIAG_REQ_PROTOCOL): New constant introduced by Linux kernel commit
+	v5.9-rc1~133^2~292^2~3.
+	* xlat/inet_diag_req_attrs.in: Likewise.
+	* NEWS: Mention this change.
+
+	xlat: update IFLA_* constants.
+	* xlat/rtnl_link_attrs.in (IFLA_PROTO_DOWN_REASON): New constant
+	introduced by Linux kernel commit v5.9-rc1~133^2~77.
+	* NEWS: Mention this change.
+
+	xlat: update IPV6_* constants.
+	* xlat/sock_ip_options.in (IPV6_RECVERR_RFC4884): New constant
+	introduced by Linux kernel commit v5.9-rc1~133^2~130^2.
+	* NEWS: Mention this change.
+
+	xlat: update IP_* constants.
+	* xlat/sock_ip_options.in (IP_RECVERR_RFC4884): New constant introduced
+	by Linux kernel commit v5.9-rc1~133^2~200.
+	* NEWS: Mention this change.
+
+	xlat: update FAN_* constants.
+	* xlat/fan_init_flags.in (FAN_REPORT_DIR_FID): New constant introduced
+	by Linux kernel commit v5.9-rc1~110^2~6.
+	(FAN_REPORT_NAME): New constant introduced by Linux kernel commit
+	v5.9-rc1~110^2~4.
+	* NEWS: Mention this change.
+	* tests/fanotify_init.c (main): Update expected output.
+
+	xlat: update CAP_* constants.
+	* caps1.h (CAP_CHECKPOINT_RESTORE): New constant introduced
+	by Linux kernel commit v5.9-rc1~161^2~6.
+	* xlat/cap.in (CAP_CHECKPOINT_RESTORE): Likewise.
+	* xlat/cap_mask1.in (1<<CAP_CHECKPOINT_RESTORE): Likewise.
+	* NEWS: Mention this change.
+	* tests/caps.awk: Update expected output.
+	* tests/caps-abbrev.awk: Likewise.
+
+	xlat: update BPF_* constants.
+	* xlat/bpf_attach_type.in (BPF_CGROUP_INET_SOCK_RELEASE): New constant
+	introduced by Linux kernel commit v5.9-rc1~133^2~259^2~18.
+	(BPF_XDP_CPUMAP): New constant introduced by Linux kernel commit
+	v5.9-rc1~133^2~164^2~22.
+	(BPF_SK_LOOKUP): New constant introduced by Linux kernel commit
+	v5.9-rc1~133^2~164^2~14^2~13.
+	(BPF_XDP): New constant introduced by Linux kernel commit
+	v5.9-rc1~133^2~23^2~28^2~5.
+	* xlat/bpf_commands.in (BPF_LINK_DETACH): New constant introduced
+	by Linux kernel commit v5.9-rc1~133^2~23^2~6^2~4.
+	* xlat/bpf_prog_types.in (BPF_PROG_TYPE_SK_LOOKUP): New constant
+	introduced by Linux kernel commit v5.9-rc1~133^2~164^2~14^2~13.
+	* NEWS: Mention this change.
+	* tests/bpf.c (BPF_PROG_LOAD_checks, BPF_PROG_QUERY_checks): Update.
+	* tests/kernel_version.c (print_bpf_attr, main): Likewise.
+
+2020-09-06  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Implement decoding of close_range syscall.
+	Introduced by Linux kernel commit v5.9-rc1~160.
+
+	* close_range.c: New file.
+	* Makefile.am (libstrace_a_SOURCES): Add it.
+	* configure.ac (AC_CHECK_HEADERS): Add linux/close_range.h.
+	* xlat/close_range_flags.in: New file.
+	* pathtrace.c (pathtrace_match_set): Handle SEN_close_range.
+	* linux/syscallent-common.h [BASE_NR + 436]: Wire up close_range.
+	* NEWS: Mention this change.
+	* tests/close_range.c: New file.
+	* tests/close_range-P.c: Likewise.
+	* tests/close_range-y.c: Likewise.
+	* tests/close_range-yy.c: Likewise.
+	* tests/gen_tests.in (close_range. close_range-P, close_range-y,
+	close_range-yy): New entries.
+	* tests/pure_executables.list: Add close_range, close_range-P,
+	close_range-y, and close_range-yy.
+	* tests/.gitignore: Likewise.
+
+2020-09-03  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	tests: reduce looping_threads iteration duration to 1/16th of TIMEOUT_DURATION
+	* tests/looping_threads.test (timeout_8): Rename to...
+	(timeout_16): ...this, reduce value by half.
+	Use $timeout_16 instead of $timeout_8.
+
+	Complements: v5.7~4 "tests: increase default TIMEOUT_DURATION"
+
+2020-09-03  Eugene Syromyatnikov  <evgsyr@gmail.com>
+	    Tom Stellard  <tstellar@redhat.com>
+
+	strace.spec.in: use %make_build/%make_install macros.
+	As suggested in [1][2].
+
+	[1] https://src.fedoraproject.org/fork/tstellar/rpms/strace/c/c7358b588cb5f2893dec3b7daa84e63d9389773a.patch
+	[2] https://fedoraproject.org/wiki/Changes/UseMakeBuildInstallMacro
+
+	* strace.spec.in [?!__make] (%__make): New definition.
+	[?!__install] (%__install): Likewise.
+	[?!make_build] (%make_build): Likewise.
+	[?!make_install] (%make_install): Likewise.
+	(%build, %check): Use %make_build.
+	(%install): Use %make_install.
+
+2020-09-03  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	mpers_test.sh: check proper handling of sized integer types.
+	The commit v5.6~62 ("v4l2: always decode VIDIOC_*_EXT_CTRLS ioctl
+	commands") unraveled a possibility of buggy handling of sized integer
+	types in some libc implementations[1][2].  Add checks for these types
+	to mpers_test.sh to catch such issues early.
+
+	[1] https://strace.io/logs/strace/2020-04-22#17477;
+	[2] https://lists.strace.io/pipermail/strace-devel/2020-August/010213.html
+
+	* mpers_test.sh: Add checks for (u)int{8,16,32,64}_t types.
+
+	Complements: v5.6~62 "v4l2: always decode VIDIOC_*_EXT_CTRLS ioctl commands"
+
+2020-08-25  Ákos Uzonyi  <uzonyi.akos@gmail.com>
+
+	Add tests for PID namespace translation.
+	* Makefile.am (CODE_COVERAGE_IGNORE_PATTERN): Add test directories.
+	* tests/.gitignore: Add new test executables.
+	* tests/Makefile.am (check_PROGRAMS): Add new test executables.
+	(DECODER_TESTS) Add new test files.
+	(libtests_a_SOURCES): Add trie_for_tests.c, xmalloc_for_tests.c.
+	* tests/gen_tests.in: Add new tests.
+	* tests/trie_test.c: New file.
+	* tests/trie_for_tests.c: New file.
+	* tests/xmalloc_for_tests.c: New file.
+	* tests/pidns-cache.c: New file.
+	* tests/pidns-cache.test: New file.
+	* tests/fcntl--pidns-translation.c: New file.
+	* tests/fcntl64--pidns-translation.c: New file.
+	* tests/fork--pidns-translation.awk: New file.
+	* tests/fork--pidns-translation.c: New file.
+	* tests/fork--pidns-translation.test: New file.
+	* tests/getpgrp--pidns-translation.c: New file.
+	* tests/getpid--pidns-translation.c: New file.
+	* tests/getsid--pidns-translation.c: New file.
+	* tests/gettid--pidns-translation.c: New file.
+	* tests/gettid--pidns-translation.test: New file.
+	* tests/ioctl_block--pidns-translation.c: New file.
+	* tests/ioctl_block--pidns-translation.test: New file.
+	* tests/ioprio--pidns-translation.c: New file.
+	* tests/kill--pidns-translation.c: New file.
+	* tests/migrate_pages--pidns-translation.c: New file.
+	* tests/move_pages--pidns-translation.c: New file.
+	* tests/net-sockaddr--pidns-translation.c: New file.
+	* tests/netlink_audit--pidns-translation.c: New file.
+	* tests/netlink_audit--pidns-translation.test: New file.
+	* tests/pidfd_open--pidns-translation.c: New file.
+	* tests/pidfd_send_signal--pidns-translation.c: New file.
+	* tests/prlimit64--pidns-translation.c: New file.
+	* tests/process_vm_readv--pidns-translation.c: New file.
+	* tests/process_vm_writev--pidns-translation.c: New file.
+	* tests/rt_sigqueueinfo--pidns-translation.c: New file.
+	* tests/rt_tgsigqueueinfo--pidns-translation.c: New file.
+	* tests/sched_xetaffinity--pidns-translation.c: New file.
+	* tests/sched_xetattr--pidns-translation.c: New file.
+	* tests/sched_xetparam--pidns-translation.c: New file.
+	* tests/sched_xetscheduler--pidns-translation.c: New file.
+	* tests/signal_receive--pidns-translation.c: New file.
+	* tests/so_peercred--pidns-translation.c: New file.
+	* tests/tkill--pidns-translation.c: New file.
+	* tests/tgkill--pidns-translation.c: New file.
+	* tests/xet_robust_list--pidns-translation.c: New file.
+	* tests/xetpgid--pidns-translation.c: New file.
+	* tests/xetpriority--pidns-translation.c: New file.
+	* tests/fcntl-common.c: Print PID translation string after PIDs.
+	* tests/fcntl.c: Likewise.
+	* tests/fcntl64.c: Likewise.
+	* tests/getpgrp.c: Likewise.
+	* tests/getpid.c: Likewise.
+	* tests/getsid.c: Likewise.
+	* tests/gettid.c: Likewise.
+	* tests/ioctl_block.c: Likewise.
+	* tests/ioprio.c: Likewise.
+	* tests/kcmp.c: Likewise.
+	* tests/kill.c: Likewise.
+	* tests/migrate_pages.c: Likewise.
+	* tests/move_pages.c: Likewise.
+	* tests/net-sockaddr.c: Likewise.
+	* tests/netlink_audit.c: Likewise.
+	* tests/pidfd_open.c: Likewise.
+	* tests/pidfd_send_signal.c: Likewise.
+	* tests/prlimit64.c: Likewise.
+	* tests/process_vm_readv_writev.c: Likewise.
+	* tests/rt_sigqueueinfo.c: Likewise.
+	* tests/rt_tgsigqueueinfo.c: Likewise.
+	* tests/sched_xetaffinity.c: Likewise.
+	* tests/sched_xetattr.c: Likewise.
+	* tests/sched_xetparam.c: Likewise.
+	* tests/sched_xetscheduler.c: Likewise.
+	* tests/signal_receive.c: Likewise.
+	* tests/so_peercred.c: Likewise.
+	* tests/tgkill.c: Likewise.
+	* tests/tkill.c: Likewise.
+	* tests/xet_robust_list.c: Likewise.
+	* tests/xetpgid.c: Likewise.
+	* tests/xetpriority.c: Likewise.
+
+	Implement testing framework for pidns.
+	* tests/pidns.c: New file.
+	* tests/pidns.h: New file.
+	* tests/Makefile.am (libtests_a_SOURCES): Add pidns.c, pidns.h.
+	* tests/init.sh (test_pidns, test_pidns_run_strace): New functions.
+
+	Use get_proc_pid for /proc paths.
+	* mmap_cache.c (mmap_cache_rebuild_if_invalid): Use proc pid instead of
+	tcp->pid for /proc path.
+	* util.c (getfdproto): Likewise.
+	(pidfd_get_pid): Likewise.
+	* pathtrace.c (getfdpath_pid): Likewise.
+	* strace.c (attach_tcb): Likewise.
+
+	Use printpid in decoders.
+	* getpid.c: New file.
+	* Makefile.am (libstrace_a_SOURCES): Add it.
+	* linux/dummy.h (sys_getpid, sys_getppid, sys_gettid,
+	sys_setpgid, sys_setpgrp): Remove.
+	* util.c (printfd_pid_tracee_ns): Implement using translate_pid.
+	* defs.h (printnum_pid): New function definition.
+	(printfd_pid_tracee_ns): Update documentation
+	* util.c: (printnum_pid): New function.
+	* print_fields.h (PRINT_FIELD_TID): New macro.
+	(PRINT_FIELD_TGID): Likewise.
+	(PRINT_FIELD_PGID): Likewise.
+	(PRINT_FIELD_SID): Likewise.
+	* affinity.c: Print PIDs with printpid.
+	* block.c: Likewise.
+	* bpf.c: Likewise.
+	* capability.c: Likewise.
+	* clone.c: Likewise.
+	* fcntl.c: Likewise.
+	* get_robust_list.c: Likewise.
+	* ioprio.c: Likewise.
+	* kcmp.c: Likewise.
+	* msghdr.c: Likewise.
+	* net.c: Likewise.
+	* netlink.c: Likewise.
+	* numa.c: Likewise.
+	* pidfd_open.c: Likewise.
+	* printsiginfo.c: Likewise.
+	* process.c: Likewise.
+	* process_vm.c: Likewise.
+	* resource.c: Likewise.
+	* sched.c: Likewise.
+	* signal.c: Likewise.
+	* sockaddr.c: Likewise.
+	* wait.c: Likewise.
+	* kcmp.c (SYS_FUNC(kcmp)): Fix KCMP_FILE pid arguments.
+	* tests/kcmp.c (printpidfd): Print path if VERBOSE_FD.
+	(main): Use our real pid if real fds are used.
+
+2020-08-25  Ákos Uzonyi  <uzonyi.akos@gmail.com>
+
+	PID namespace translation support.
+	* defs.h (pidns_translation): New variable.
+	(tcb): Add pid_ns field.
+	(RVAL_MASK): Change value from 013 to 017.
+	(RVAL_TID, RVAL_SID, RVAL_TGID, RVAL_PGID): New definitions.
+	(pid_type): New enum.
+	(pidns_init, translate_pid, get_proc_pid, printpid, printpid_tgid_pgid):
+	New function declarations.
+	* largefile_wrappers.h (fstat_fd): New macro.
+	* pidns.c: New file.
+	* trie.c: New file.
+	* trie.h: New file.
+	* Makefile.am (libstrace_a_SOURCES): Add trie.c, trie.h, pidns.c.
+	* strace.c (pidns_translation): New variable.
+	(init): Add --pidns-translation option.
+	* syscall.c (syscall_exiting_trace): Handle RVAL_* return values.
+	* NEWS: Mention this.
+	* strace.1.in: Add description for new option.
+
+	Co-Authored-by: Eugene Syromyatnikov <evgsyr@gmail.com>
+
+2020-08-25  Ákos Uzonyi  <uzonyi.akos@gmail.com>
+
+	tests/mknod.c: add workaround for ppc bug in travis.
+	On ppc travis builds syscall(mknod) sometimes does not fail with EEXISTS
+	as expected, but returns successfully. This commit uses sprintrc for
+	errno printing, which handles successful return values too.
+
+	* tests/mknod.c (main): Use sprintrc for printing errno.
+
+2020-08-21  Elvira Khabirova  <lineprinter0@gmail.com>
+
+	tests: check -n/--syscall-number option.
+	* tests/strace-n.c: New file.
+	* tests/gen_tests.in (strace-n): New entry.
+	* tests/pure_executables.list: Add strace-n.
+	* tests/.gitignore: Likewise.
+
+	strace: add an option for printing syscall numbers.
+	* print_syscall_number.c: New file.
+	* Makefile.am (libstrace_a_SOURCES): Add it.
+	* defs.h (struct tcb): Add true_scno field.
+	(print_syscall_number): New function declaration.
+	* strace.c: Add -n/--syscall-number option.
+	(printleader): Call print_syscall_number.
+	* syscall.c (get_scno): Assign tcp->true_scno.
+	* tests/options-syntax.test: Check with -c/--summary-only.
+	* strace.1.in: Document new option.
+	* NEWS: Mention the new option.
+
+2020-08-06  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Post-release administrivia.
+	* NEWS: Add a header line for the next release.
+	* debian/changelog.in: Add a changelog entry for 5.8-1.
+	* strace.spec.in: Likewise.
+
+	Prepare for 5.8 release.
+	* NEWS: Update for 5.8 release.
+
+2020-08-04  Dmitry V. Levin  <ldv@altlinux.org>
+
+	ci: use kernel headers from Linux kernel v5.8.
+	When Linux kernel merge window opens, changes of all sorts start to pour
+	down, breaking UAPI in various ways.  This does not work for strace,
+	we need a stable UAPI.
+
+	* .github/workflows/ci.yml (env): Add KBRANCH.
+	* .gitlab-ci.yml (variables): Likewise.
+	* .travis.yml (env:global): Likewise.
+
+2020-08-03  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Update copyright headers.
+	Headers updated automatically using maint/update_copyright_years.sh
+	script.
+
+2020-08-01  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: check decoding of tgkill syscall.
+	* tests/tgkill.c: New file.
+	* tests/gen_tests.in (tgkill): New entry.
+	* tests/pure_executables.list: Add tgkill.
+	* tests/.gitignore: Likewise.
+
+	tests: check decoding of tkill syscall.
+	* tests/tkill.c: New file.
+	* tests/gen_tests.in (tkill): New entry.
+	* tests/pure_executables.list: Add tkill.
+	* tests/.gitignore: Likewise.
+
+2020-08-01  Ákos Uzonyi  <uzonyi.akos@gmail.com>
+
+	Introduce SYS_FUNC(tkill)
+	This is going to be needed to implement pidns support
+	in tkill syscall decoder.
+
+	syscallent*.h files are updated automatically by:
+	  git grep -l 'SEN(kill).*"tkill"' |
+	  xargs sed -i '/"tkill"/ s/SEN(kill)/SEN(tkill)/'
+
+	* signal.c (SYS_FUNC(tkill)): New syscall decoder.
+	* linux/32/syscallent.h: Use SEN(tkill) for "tkill" syscall.
+	* linux/64/syscallent.h: Likewise.
+	* linux/alpha/syscallent.h: Likewise.
+	* linux/arm/syscallent.h: Likewise.
+	* linux/avr32/syscallent.h: Likewise.
+	* linux/bfin/syscallent.h: Likewise.
+	* linux/hppa/syscallent.h: Likewise.
+	* linux/i386/syscallent.h: Likewise.
+	* linux/ia64/syscallent.h: Likewise.
+	* linux/m68k/syscallent.h: Likewise.
+	* linux/microblaze/syscallent.h: Likewise.
+	* linux/mips/syscallent-n32.h: Likewise.
+	* linux/mips/syscallent-n64.h: Likewise.
+	* linux/mips/syscallent-o32.h: Likewise.
+	* linux/powerpc/syscallent.h: Likewise.
+	* linux/powerpc64/syscallent.h: Likewise.
+	* linux/s390/syscallent.h: Likewise.
+	* linux/s390x/syscallent.h: Likewise.
+	* linux/sh/syscallent.h: Likewise.
+	* linux/sh64/syscallent.h: Likewise.
+	* linux/sparc/syscallent.h: Likewise.
+	* linux/sparc64/syscallent.h: Likewise.
+	* linux/x32/syscallent.h: Likewise.
+	* linux/x86_64/syscallent.h: Likewise.
+	* linux/xtensa/syscallent.h: Likewise.
+
+2020-08-01  Ákos Uzonyi  <uzonyi.akos@gmail.com>
+
+	Add "struct tcb *" parameters to various functions.
+	This is going to be needed to implement pidns support.
+
+	* defs.h (print_sockaddr): Add a "struct tcb *" parameter.
+	* printsiginfo.h (printsiginfo): Likewise.
+	* fcntl.c (print_struct_flock64): Likewise.  All callers updated.
+	* print_fields.h (PRINT_FIELD_SOCKADDR): Likewise.   All callers updated.
+	* printsiginfo.c (printsigsource, print_si_info, printsiginfo): Likewise.
+	All callers updated.
+	* sockaddr.c (print_sockaddr_data_un, print_sockaddr_data_in,
+	print_sockaddr_data_in6, print_sockaddr_data_ax25,
+	print_sockaddr_data_ipx, print_sockaddr_data_x25,
+	print_sockaddr_data_nl, print_sockaddr_data_ll,
+	print_sockaddr_data_bt, sockaddr_printer, print_sockaddr): Likewise.
+	All callers updated.
+
+2020-07-30  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Use tprints instead of tprintf in a few more places.
+	* bpf.c (BPF_PROG_LOAD, BPF_OBJ_PIN, BPF_OBJ_GET_INFO_BY_FD,
+	BPF_RAW_TRACEPOINT_OPEN, BPF_TASK_FD_QUERY, BPF_MAP_LOOKUP_BATCH,
+	BPF_MAP_UPDATE_BATCH, BPF_MAP_DELETE_BATCH): Replace tprintf
+	with tprints for printing strings without format specifiers.
+	* btrfs.c (btrfs_ioctl): Likewise.
+	* ioctl.c (evdev_decode_number): Likewise.
+	* perf_ioctl.c (perf_ioctl): Likewise.
+	* rtnl_addr.c (decode_ifa_cacheinfo): Likewise.
+	* v4l2.c (print_v4l2_capability, print_v4l2_requestbuffers,
+	print_v4l2_streamparm): Likewise.
+
+2020-07-24  Janosch Frank  <frankja@linux.ibm.com>
+
+	s390x: sthyi: Fix section size requirement and error.
+	Some old z/VM instances report only 40 bytes for the partition
+	section, as they don't report the last three struct members.
+
+	Let's lower the size check of that section to 40 to accommodate them.
+
+	Also we expect a section to be at least x bytes, so we should make
+	that clear in the error message.
+
+	Reviewed-by: Eugene Syromyatnikov <evgsyr@gmail.com>
+
+2020-07-21  Ákos Uzonyi  <uzonyi.akos@gmail.com>
+
+	Remove tcb parameter of read_int_from_file.
+	* defs.h (read_int_from_file): Remove tcb parameter.
+	* util.c (read_int_from_file): Likewise.
+	* msghdr.c (get_optmem_max): Remove tcb parameter of read_int_from_file.
+
+2020-07-18  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Consistently print process ids as signed integers.
+	* block.c (block_ioctl): Print struct_blk_user_trace_setup.pid using
+	PRINT_FIELD_D instead of PRINT_FIELD_U.
+	* bpf.c (BPF_TASK_FD_QUERY): Print task_fd_query.pid using PRINT_FIELD_D
+	instead of PRINT_FIELD_U.
+	* ipc_msgctl.c (print_msqid_ds): Print msqid_ds.msg_lspid
+	and msqid_ds.msg_lrpid using PRINT_FIELD_D.
+	* ipc_shmctl.c (print_shmid_ds): Print shmid_ds.shm_cpid and shm_lpid
+	using PRINT_FIELD_D.
+	* msghdr.c (print_scm_creds): Print ucred.pid using PRINT_FIELD_D
+	instead of PRINT_FIELD_U.
+	* netlink.c (print_nlmsghdr): Print nlmsghdr.nlmsg_pid using %d format
+	instead of %u.
+	* tests/bpf.c (BPF_TASK_FD_QUERY_checks): Update expected output.
+	* tests/ioctl_block.c (main): Update expected output.
+	* tests/ipc_msg.c (main): Likewise.
+	* tests/ipc_shm.c (main): Likewise.
+	* tests/net-yy-netlink.c (main): Likewise.
+	* tests/netlink_protocol.c (test_nlmsgerr): Likewise.
+
+	Introduce PRINT_FIELD_NUMERIC_UMODE_T.
+	* print_fields.h (PRINT_FIELD_NUMERIC_UMODE_T): New macro.
+	* ipc_msgctl.c (print_msqid_ds): Use it instead of print_numeric_umode_t.
+	* ipc_shmctl.c (print_shmid_ds): Likewise.
+	* open.c (print_open_how): Use it instead of print_numeric_ll_umode_t.
+
+	Fix printing of syscall return value in octal mode.
+	* defs.h (print_numeric_long_umask): Remove.
+	* printmode.c (print_numeric_long_umask): Likewise.
+	* syscall.c (syscall_exiting_trace) <case RVAL_OCTAL>: Fix printing
+	of tcp->u_rval when sizeof(tcp->u_rval) > sizeof(long) or when
+	sizeof(tcp->u_rval) > current_klongsize.
+
+	Rename print_numeric_umode_t_64 to print_numeric_ll_umode_t.
+	* printmode.c (print_numeric_umode_t_64): Rename
+	to print_numeric_ll_umode_t, change the type of its argument
+	to unsigned long long.
+	* defs.h: Likewise.
+	* open.c (print_open_how): Use print_numeric_ll_umode_t instead of
+	print_numeric_umode_t_64.
+
+2020-07-17  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Use PRINT_FIELD_UID instead of printuid where appropriate.
+	* ipc_msgctl.c: Include "print_fields.h".
+	(print_msqid_ds): Use PRINT_FIELD_UID instead of printuid.
+	* ipc_shmctl.c: Include "print_fields.h".
+	(print_shmid_ds): Use PRINT_FIELD_UID instead of printuid.
+	* statx.c (SYS_FUNC(statx)): Use PRINT_FIELD_UID instead of printuid.
+
+	printsiginfo: fix printing of siginfo_t.si_pid and siginfo_t.si_uid.
+	* printsiginfo.c (printsigsource): Print siginfo_t.si_pid using
+	PRINT_FIELD_D, print siginfo_t.si_uid using PRINT_FIELD_UID.
+	* tests/clone_ptrace.c (main): Update expected output.
+	* tests/orphaned_process_group.c (main): Likewise.
+	* tests/pidfd_send_signal.c (main): Likewise.
+	* tests/ptrace.c (test_peeksiginfo): Likewise.
+	* tests/rt_sigqueueinfo.c (main): Likewise.
+	* tests/rt_tgsigqueueinfo.c (main): Likewise.
+	* tests/siginfo.c (main): Likewise.
+	* tests/waitid.c (sprint_siginfo): Likewise.
+
+	statx: use PRINT_FIELD_FLAGS.
+	* statx.c (SYS_FUNC(statx)): Use PRINT_FIELD_FLAGS instead of
+	printflags.
+
+2020-07-17  Ákos Uzonyi  <uzonyi.akos@gmail.com>
+
+	kcmp: fix KCMP_FILE decoding.
+	* kcmp.c (SYS_FUNC(kcmp)): Fix KCMP_FILE pid arguments.
+
+	Fixes: v4.20~66 ("kcmp: output fds using a separate function")
+
+2020-07-13  Dmitry V. Levin  <ldv@altlinux.org>
+
+	fcntl: use print_fields.h macros.
+	* fcntl.c: Include "print_fields.h".
+	(print_struct_flock64, print_f_owner_ex): Use PRINT_FIELD_* macros
+	from print_fields.h.
+
+	evdev_mpers: use print_fields.h macros.
+	* evdev_mpers.c: Include "print_fields.h".
+	(decode_envelope, ff_effect_ioctl): Use PRINT_FIELD_* macros
+	from print_fields.h.
+	* tests/ioctl_evdev.c (print_ffe_common): Update expected output.
+
+2020-07-12  Dmitry V. Levin  <ldv@altlinux.org>
+
+	ustat: use print_fields.h macros.
+	* ustat.c: Include "print_fields.h".
+	(SYS_FUNC(ustat)): Use PRINT_FIELD_* macros from print_fields.h.
+
+	file_ioctl: use print_fields.h macros.
+	* file_ioctl.c: Include "print_fields.h".
+	(print_file_dedupe_range_info, print_fiemap_extent, file_ioctl): Use
+	PRINT_FIELD_* macros from print_fields.h.
+
+	evdev: use print_fields.h macros.
+	* evdev.c (abs_ioctl, keycode_V2_ioctl): Use PRINT_FIELD_* macros
+	from print_fields.h.
+
+	evdev: fix formatting of struct input_id.
+	* evdev.c (getid_ioctl): Use PRINT_FIELD_U.
+	* tests/ioctl_evdev.c (main): Update expected output.
+
+	btrfs: use PRINT_FIELD_X_ARRAY.
+	* types/btrfs.h: New file.
+	* btrfs.c: Include "types/btrfs.h".
+	(btrfs_ioctl): Use struct_btrfs_ioctl_logical_ino_args and
+	PRINT_FIELD_X_ARRAY.
+	* configure.ac (AC_CHECK_MEMBERS): Remove
+	struct btrfs_ioctl_search_args_v2.buf_size and
+	struct btrfs_ioctl_logical_ino_args.flags.
+
+2020-07-10  Dmitry V. Levin  <ldv@altlinux.org>
+
+	travis: reintroduce ppc64le and s390x builds.
+	Let's give travis another chance.
+	This reverts commits 86a53f791ad34a825b8633eb0272d954647ce705
+	and 36f32a255db09886f7f9ba08ec712b8742f0c312.
+
+	* .travis.yml (arch: ppc64le, arch: s390x): New entries.
+
+2020-07-10  Dmitry V. Levin  <ldv@altlinux.org>
+
+	README.md: migrate from travis-ci.org to travis-ci.com.
+
+2020-07-08  Dmitry V. Levin  <ldv@altlinux.org>
+
+	evdev: fix formatting of struct input_keymap_entry.scancode.
+	* evdev.c (keycode_V2_ioctl): Use PRINT_FIELD_X_ARRAY.
+	* tests/ioctl_evdev.c (main): Update expected output.
+
+	x86_64/arch_kvm: use PRINT_FIELD_X_ARRAY.
+	* linux/x86_64/arch_kvm.c (arch_print_kvm_sregs): Use PRINT_FIELD_X_ARRAY.
+
+	loop: implement decoding of LOOP_CONFIGURE ioctl command.
+	* types/loop.h: New file.
+	* loop.c: Include it instead of <linux/ioctl.h> and <linux/loop.h>.
+	(ecode_loop_config): New function.
+	(loop_ioctl): Use it to decode LOOP_CONFIGURE ioctl command.
+	* NEWS: Mention this change.
+	* tests/ioctl_loop.c: Check it.
+
+2020-07-08  Dmitry V. Levin  <ldv@altlinux.org>
+
+	loop: factor out print_loop_info64.
+	It is going to be used to implement LOOP_CONFIGURE decoding.
+
+	* loop.c (print_loop_info64): New function.
+	(decode_loop_info64): Use it.
+
+2020-07-08  Dmitry V. Levin  <ldv@altlinux.org>
+
+	loop: use print_fields.h macros.
+	* loop.c (decode_loop_info, decode_loop_info64): Use PRINT_FIELD_*
+	macros from print_fields.h.
+
+	print_fields: introduce PRINT_FIELD_U_ARRAY and PRINT_FIELD_X_ARRAY.
+	* print_fields.h: Include "static_assert.h".
+	(PRINT_FIELD_UINT_ARRAY, PRINT_FIELD_U_ARRAY, PRINT_FIELD_X_ARRAY):
+	New macros.
+	(PRINT_FIELD_COOKIE): Rewrite using PRINT_FIELD_U_ARRAY.
+
+2020-07-06  Gleb Fotengauer-Malinovskiy  <glebfm@altlinux.org>
+
+	Update ioctl entries from linux v5.8.
+	* linux/32/ioctls_inc_align16.h: Update from linux v5.8-rc4
+	using ioctls_gen.sh.
+	* linux/32/ioctls_inc_align32.h: Likewise.
+	* linux/32/ioctls_inc_align64.h: Likewise.
+	* linux/64/ioctls_inc.h: Likewise.
+	* linux/x32/ioctls_inc0.h: Likewise.
+	* linux/powerpc/ioctls_arch0.h: Likewise.
+	* NEWS: Mention this.
+	* tests/ioctl_loop.c (main): Update.
+
+2020-07-04  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Implement decoding of faccessat2 syscall.
+	Introduced by Linux kernel commit v5.8-rc1~203^2.
+
+	* xlat/faccessat_flags.in: New file.
+	* access.c: Include "xlat/faccessat_flags.h".
+	(decode_access): Change return type to void.
+	(SYS_FUNC(access)): Return RVAL_DECODED.
+	(decode_faccessat): New function.
+	(SYS_FUNC(faccessat)): Use it.
+	(SYS_FUNC(faccessat2)): New function.
+	* pathtrace.c (pathtrace_match_set): Handle SEN_faccessat2.
+	* linux/syscallent-common.h [BASE_NR + 439]: Wire up faccessat2.
+	* NEWS: Mention this change.
+	* tests/faccessat2.c: New file.
+	* tests/faccessat2-P.c: Likewise.
+	* tests/faccessat2-y.c: Likewise.
+	* tests/faccessat2-yy.c: Likewise.
+	* tests/faccessat2.test: New test.
+	* tests/Makefile.am (DECODER_TESTS): Add faccessat2.test.
+	* tests/gen_tests.in (faccessat2-P, faccessat2-y, faccessat2-yy): New
+	entries.
+	* tests/pure_executables.list: Add faccessat2, faccessat2-P,
+	faccessat2-y, and faccessat2-yy.
+	* tests/.gitignore: Likewise.
+
+2020-07-04  Dmitry V. Levin  <ldv@altlinux.org>
+
+	xlat: rename access_flags to access_modes.
+	Since faccessat2 syscall has both "mode" and "flags" arguments,
+	rename access_flags to access_modes to avoid confusion.
+
+	* xlat/access_flags.in: Rename to ...
+	* xlat/access_modes.in: ... this file, add fallback definitions.
+	(EFF_ONLY_OK, EX_OK): Remove non-Linux constants.
+	* access.c: Include "xlat/access_modes.h" instead of
+	"xlat/access_flags.h".
+	(decode_access): Replace access_flags woth access_modes.
+
+2020-07-04  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: check decoding of faccessat syscall in -P, -y, and -yy modes.
+	* tests/faccessat.c: Rewrite.
+	* tests/faccessat-P.c: New file.
+	* tests/faccessat-y.c: Likewise.
+	* tests/faccessat-yy.c: Likewise.
+	* tests/faccessat.test: New test.
+	* tests/Makefile.am (DECODER_TESTS): Add faccessat.test.
+	* tests/gen_tests.in (faccessat): Remove.
+	(faccessat-P, faccessat-y, faccessat-yy): New entries.
+	* tests/pure_executables.list: Add faccessat-P, faccessat-y,
+	and faccessat-yy.
+	* tests/.gitignore: Likewise.
+
+2020-06-30  Dmitry V. Levin  <ldv@altlinux.org>
+
+	xlat: update BPF_* constants.
+	* xlat/bpf_attach_type.in (BPF_TRACE_ITER): New constant introduced
+	by Linux kernel commit v5.8-rc1~165^2~185^2~16^2~19.
+	(BPF_CGROUP_INET4_GETPEERNAME, BPF_CGROUP_INET6_GETPEERNAME,
+	BPF_CGROUP_INET4_GETSOCKNAME, BPF_CGROUP_INET6_GETSOCKNAME): New
+	constants introduced by Linux kernel commit v5.8-rc1~165^2~130^2~8^2~3.`
+	(BPF_XDP_DEVMAP): New constant introduced by Linux kernel commit
+	v5.8-rc1~165^2~6^2~9^2~3.
+	* xlat/bpf_commands.in (BPF_LINK_GET_FD_BY_ID, BPF_LINK_GET_NEXT_ID):
+	New constants introduced by Linux kernel commit
+	v5.8-rc1~165^2~343^2~16^2~7.
+	(BPF_ENABLE_STATS): New constant introduced by Linux kernel commit
+	v5.8-rc1~165^2~343^2~3^2~2.
+	(BPF_ITER_CREATE): New constant introduced by Linux kernel commit
+	v5.8-rc1~165^2~185^2~16^2~15.
+	* xlat/bpf_map_types.in (BPF_MAP_TYPE_RINGBUF): New constant introduced
+	by Linux kernel commit v5.8-rc1~165^2~6^2~12^2~4.
+	* NEWS: Mention this change.
+	* tests/bpf.c: Update.
+
+2020-06-29  Ákos Uzonyi  <uzonyi.akos@gmail.com>
+
+	.gitignore: add missing files that should be ignored.
+	* .gitignore: Add .dirstamp.
+	* tests/.gitignore: Add setpgrp-exec and stack-fcall-attach.
+
+2020-06-29  Dmitry V. Levin  <ldv@altlinux.org>
+
+	xlat: update STATX_* constants.
+	* xlat/statx_attrs.in (STATX_ATTR_MOUNT_ROOT): New constant introduced
+	by Linux kernel commit v5.8-rc1~203^2~4.
+	* xlat/statx_masks.in (STATX_MNT_ID): New constant introduced by Linux
+	kernel commit v5.8-rc1~203^2~5.
+	* NEWS: Mention this change.
+	* tests/xstatx.c (main): Update expected output.
+
+	xlat: update TCA_* constants.
+	* xlat/rtnl_tc_attrs.in (TCA_DUMP_FLAGS): New constant introduced
+	by Linux kernel commit v5.8-rc1~165^2~183^2~3.
+	* rtnl_tc.c (tcmsg_nla_decoders): Add TCA_DUMP_FLAGS.
+	* NEWS: Mention this change.
+
+	xlat: update RTC_* constants.
+	* xlat/rtc_vl_flags.in (RTC_VL_BACKUP_SWITCH): New constant introduced
+	by Linux kernel commit v5.8-rc1~100^2~23.
+	* NEWS: Mention this change.
+
+2020-06-28  Dmitry V. Levin  <ldv@altlinux.org>
+
+	xlat: update NDA_* constants.
+	* xlat/rtnl_neigh_attrs.in (NDA_NH_ID): New constant introduced by Linux
+	kernel commit v5.8-rc1~165^2~141^2~3.
+	* rtnl_neigh.c (ndmsg_nla_decoders): Add NDA_NH_ID.
+	* NEWS: Mention this change.
+
+	xlat: update *_MAGIC constants.
+	* xlat/fsmagic.in (DEVMEM_MAGIC): New constant introduced by Linux
+	kernel commit v5.8-rc1~104^2~8.
+	* NEWS: Mention this change.
+
+	xlat: update LOOP_* constants.
+	* xlat/loop_cmds.in (LOOP_CONFIGURE): New constant introduced by Linux
+	kernel commit v5.8-rc1~191^2~11.
+	* NEWS: Mention this change.
+
+	xlat: update KVM_* constants.
+	* xlat/kvm_cap.in (KVM_CAP_HALT_POLL): New constant introduced by Linux
+	kernel commit v5.8-rc1~168^2~136.
+	(KVM_CAP_ASYNC_PF_INT): New constant introduced by Linux kernel commit
+	v5.8-rc1~168^2~14.
+	* NEWS: Mention this change.
+
+	xlat: update KEYCTL_* constants.
+	* xlat/keyctl_commands.in (KEYCTL_WATCH_KEY): New constant introduced
+	by Linux kernel commit v5.8-rc1~22^2~6.
+	* xlat/keyctl_caps1.in (KEYCTL_CAPS1_NOTIFICATIONS): Likewise.
+	* NEWS: Mention this change.
+
+	xlat: update IORING_* constants.
+	* xlat/uring_ops.in (IORING_OP_TEE): New constant introduced by Linux
+	kernel commit v5.8-rc1~190^2~14.
+	* tests/io_uring_register.c: Update expected output.
+
+	xlat: update INET_DIAG_* constants.
+	* linux/inet_diag.h (INET_DIAG_MD5SIG): New constant introduced
+	by Linux kernel commit v4.14-rc1~130^2~39^2.
+	(INET_DIAG_ULP_INFO): New constant introduced by Linux kernel commit
+	v5.4-rc1~131^2~103^2~1.
+	(INET_DIAG_SK_BPF_STORAGES): New constant introduced by Linux kernel
+	commit v5.7-rc1~146^2~287^2^2.
+	(INET_DIAG_CGROUP_ID): New constant introduced by Linux kernel commit
+	v5.8-rc1~165^2~383^2~1.
+	(INET_DIAG_BC_CGROUP_COND): New constant introduced by Linux kernel
+	commit v5.8-rc1~165^2~383^2.
+	* xlat/inet_diag_attrs.in (INET_DIAG_MD5SIG, INET_DIAG_ULP_INFO,
+	INET_DIAG_SK_BPF_STORAGES, INET_DIAG_CGROUP_ID): Likewise.
+	* xlat/inet_diag_bytecodes.in (INET_DIAG_BC_CGROUP_COND): Likewise.
+	* xlat/inet_diag_extended_flags.in (1<<(INET_DIAG_MD5SIG-1),
+	1<<(INET_DIAG_ULP_INFO-1), 1<<(INET_DIAG_SK_BPF_STORAGES-1),
+	1<<(INET_DIAG_CGROUP_ID-1)): Likewise.
+	* NEWS: Mention this change.
+
+	xlat: update ETH_* constants.
+	* xlat/ethernet_protocols.in (ETH_P_MRP): New constant introduced
+	by Linux kernel commit v5.8-rc1~165^2~412^2~10.
+	* NEWS: Mention this change.
+
+	xlat: update CAP_* constants.
+	* caps1.h (CAP_PERFMON): New constant introduced by Linux kernel commit
+	v5.8-rc1~224^2~14^2~55.
+	(CAP_BPF): New constant introduced by Linux kernel commit
+	v5.8-rc1~165^2~181^2^2~2.
+	* xlat/cap.in (CAP_PERFMON, CAP_BPF): Likewise.
+	* xlat/cap_mask1.in (1<<CAP_PERFMON, 1<<CAP_BPF): Likewise.
+	* NEWS: Mention this change.
+	* tests/caps.awk: Update expected output.
+	* tests/caps-abbrev.awk: Likewise.
+
+	xlat: update AUDIT_* constants.
+	* xlat/nl_audit_types.in (AUDIT_EVENT_LISTENER): New constant introduced
+	by Linux kernel commit v5.8-rc1~188^2~5.
+	* NEWS: Mention this change.
+
+2020-06-27  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: workaround LTO in strace -k tests.
+	Link time optimization in gcc 10 became too smart, resulting to most
+	of function calls in strace -k tests being optimized out,
+	subsequently breaking these tests.
+
+	Make the functions more complex to bypass unwanted side effects
+	of link time optimization in strace -k tests.
+
+	* tests/stack-fcall.h: Include <unistd.h> and "scno.h".
+	(COMPLEX_BODY): New macro.
+	* tests/stack-fcall-0.c (f0): Use it.
+	* tests/stack-fcall-1.c (f1): Likewise.
+	* tests/stack-fcall-2.c (f2): Likewise.
+	* tests/stack-fcall-3.c (f3): Likewise.  Rewrite switch.
+	* tests/stack-fcall.c (main): Call f0 in a loop.
+
+2020-06-16  Ákos Uzonyi  <uzonyi.akos@gmail.com>
+
+	Modify %process class: trace syscalls associated with process lifecycle.
+	The description is rephrased as:
+	"Trace system calls associated with process lifecycle
+	(creation, exec, termination)."
+
+	kill, tkill, tgkill, pidfd_send_signal and rt_sigqueueinfo are added,
+	arch_prctl and unshare are removed from the %process class.
+
+	syscallent*.h files are updated automatically by:
+	find linux -name syscallent*.h -exec \
+	sed -i -r -e '
+	    /(arch_prctl|unshare)/ {
+	        s/(\{[^,]*,\t[^,]*)TP\|/\1/
+	        s/(\{[^,]*,\t[^,]*)\|TP/\1/
+	        s/(\{[^,]*,\t[^,]*)TP,/\10,/
+	    }
+	' -e '
+	    /(kill|pidfd_send_signal|rt_sigqueueinfo)/ {
+	        s/(\{[^,]*,\t[^0][^,]*)/\1|TP/
+	        s/(\{[^,]*,\s*)0/\1TP/
+	    }
+	' {} +
+
+	[ldv: document this change in NEWS.]
+
+	* strace.1.in: Rephrase %process description.
+	* linux/32/syscallent.h: Add TP flag to *kill, pidfd_send_signal and
+	rt_sigqueueinfo; remove TP flag from arch_prctl and unshare.
+	* linux/64/syscallent.h: Likewise.
+	* linux/alpha/syscallent.h: Likewise.
+	* linux/arm/syscallent.h: Likewise.
+	* linux/avr32/syscallent.h: Likewise.
+	* linux/bfin/syscallent.h: Likewise.
+	* linux/hppa/syscallent.h: Likewise.
+	* linux/i386/syscallent.h: Likewise.
+	* linux/ia64/syscallent.h: Likewise.
+	* linux/m68k/syscallent.h: Likewise.
+	* linux/microblaze/syscallent.h: Likewise.
+	* linux/mips/syscallent-compat.h: Likewise.
+	* linux/mips/syscallent-n32.h: Likewise.
+	* linux/mips/syscallent-n64.h: Likewise.
+	* linux/mips/syscallent-o32.h: Likewise.
+	* linux/powerpc/syscallent.h: Likewise.
+	* linux/powerpc64/syscallent.h: Likewise.
+	* linux/s390/syscallent.h: Likewise.
+	* linux/s390x/syscallent.h: Likewise.
+	* linux/sh/syscallent.h: Likewise.
+	* linux/sh64/syscallent.h: Likewise.
+	* linux/sparc/syscallent.h: Likewise.
+	* linux/sparc64/syscallent.h: Likewise.
+	* linux/syscallent-common.h: Likewise.
+	* linux/x32/syscallent.h: Likewise.
+	* linux/x86_64/syscallent.h: Likewise.
+	* linux/xtensa/syscallent.h: Likewise.
+	* NEWS: Mention this change.
+
+2020-06-16  Ákos Uzonyi  <uzonyi.akos@gmail.com>
+
+	tests/inject-nf.test: replace getpid with geteuid.
+	Since we treat PIDs as signed integers, large values (>=2^31) will
+	cause overflow when we use printpid.
+	UIDs are treated as unsigned integers, so geteuid is a good alternative.
+	(getuid would be problematic, as it does not exists on alpha).
+	Also, on systems where geteuid32 exists, geteuid returns maximum 16 bit
+	values, so we have to use geteuid32 in this case.
+
+	[ldv: geteuid syscall was introduced on Alpha by Linux kernel commit
+	v5.1-rc1~160^2~3^2~1, so this test will not work on old Alpha kernels.]
+
+	* tests/inject-nf.c: Replace getpid with either geteuid32 or geteuid.
+	[__alpha__]: Remove.
+	[__NR_geteuid32]: New condition.
+	* tests/inject-nf.test (SYSCALL): Replace getpid with '/^geteuid(32)?$'.
+	Remove alpha workaround.
+
+2020-06-16  Dmitry V. Levin  <ldv@altlinux.org>
+
+	travis: remove s390x builds.
+	They are currently unusable, permanently failing without any reason
+	whatsoever.
+
+	* .travis.yml (arch: s390x): Remove.
+
+2020-06-16  Dmitry V. Levin  <ldv@altlinux.org>
+
+	ci: re-enable testing with the latest mainline kernel headers.
+	There should be no issues with v5.8-rc1.
+	This reverts commit 734066585ba865740ab45651bc6e3e8ab249927f.
+
+	* .github/workflows/ci.yml (env): Remove KBRANCH.
+	* .gitlab-ci.yml (variables): Likewise.
+	* .travis.yml (env:global): Likewise.
+
+2020-06-16  Chris Packham  <chris.packham@alliedtelesis.co.nz>
+	    Dmitry V. Levin  <ldv@altlinux.org>
+
+	io_uring: Add io_cqring_offset flags.
+	Add support for displaying struct io_cqring_offsets.flags introduced
+	by Linux kernel commits v5.8-rc1~190^2~22 and v5.8-rc1~190^2~21.
+
+	* types/io_uring.h (struct_io_cqring_offsets): Replace resv array
+	with flags, resv1, and resv2 fields.
+	* xlat/uring_cqring_flags.in: New file.
+	* configure.ac (AC_CHECK_MEMBERS): Check struct io_cqring_offsets.flags.
+	* io_uring.c: Include "xlat/uring_cqring_flags.h".
+	(SYS_FUNC(io_uring_setup)): Replace printing of the resv array
+	of struct io_cqring_offsets with flags, resv1, and resv2 fields.
+	* tests/io_uring_setup.c: Check it.
+
+	Resolves: https://github.com/strace/strace/issues/138
+
+2020-06-16  Chris Packham  <chris.packham@alliedtelesis.co.nz>
+
+	io_uring: Remove struct io_cqring_offsets compile time asserts.
+	The generated types/check-io_uring.c already checks the kernel's struct
+	io_cqring_offsets for compatibility with the strace definition so
+	there's no need for manual checks.
+
+	* io_uring.c [HAVE_STRUCT_IO_CQRING_OFFSETS]: Remove static_asserts.
+
+2020-06-16  Dmitry V. Levin  <ldv@altlinux.org>
+
+	types: skip field lines that start with comments.
+	This allows to exclude certain fields from type checks by placing
+	comments at the beginning of the corresponding lines.
+
+	* types/find_last_type_fields.awk: Skip lines starting with spaces
+	followed by "/".
+
+2020-06-14  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Add statx syscall to %fstat trace class.
+	statx syscall with AT_EMPTY_PATH flag is similar to newfstatat/fstatat64
+	syscall with AT_EMPTY_PATH flag.
+
+	* linux/32/syscallent.h (statx): Add TFST flag.
+	* linux/64/syscallent.h: Likewise.
+	* linux/alpha/syscallent.h: Likewise.
+	* linux/arm/syscallent.h: Likewise.
+	* linux/hppa/syscallent.h: Likewise.
+	* linux/i386/syscallent.h: Likewise.
+	* linux/ia64/syscallent.h: Likewise.
+	* linux/m68k/syscallent.h: Likewise.
+	* linux/microblaze/syscallent.h: Likewise.
+	* linux/mips/syscallent-n32.h: Likewise.
+	* linux/mips/syscallent-n64.h: Likewise.
+	* linux/mips/syscallent-o32.h: Likewise.
+	* linux/powerpc/syscallent.h: Likewise.
+	* linux/powerpc64/syscallent.h: Likewise.
+	* linux/s390/syscallent.h: Likewise.
+	* linux/s390x/syscallent.h: Likewise.
+	* linux/sh/syscallent.h: Likewise.
+	* linux/sparc/syscallent.h: Likewise.
+	* linux/sparc64/syscallent.h: Likewise.
+	* linux/x32/syscallent.h: Likewise.
+	* linux/x86_64/syscallent.h: Likewise.
+	* linux/xtensa/syscallent.h: Likewise.
+	* strace.1.in (.SS Filtering): Document it.
+	* NEWS: Mention this fix.
+	* tests/trace_fstat.in (statx): New entry.
+
+2020-06-13  Ákos Uzonyi  <uzonyi.akos@gmail.com>
+
+	Move ilog* functions from util.c to defs.h.
+	* util.c (ILOG2_ITER_, ilog2_klong, ilog2_64, ilog2_32): Move ...
+	* defs.h: ... here.
+
+	print_fields.h: add PRINT_FIELD_LEN macro.
+	* print_fields.h (PRINT_FIELD_LEN): New macro.
+	* net.c: (print_get_linger, print_get_ucred, print_tpacket_stats):
+	Rewrite using PRINT_FIELD_LEN.
+
+2020-06-10  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Move make-dist and make-dsc scripts to maint/
+	* make-dsc: Rename to maint/make-dsc.
+	* make-dist: Rename to maint/make-dist.
+	* maint/README-release: Update.
+	* dist/INSTALL: Likewise.
+
+2020-06-07  Sven Schnelle  <svens@stackframe.org>
+
+	tests: clone3 might return EBADF with invalid cgroup.
+	Both on s390 and x86 linux-5.7 return EBADF when an invalid cgroup
+	is supplied, so add that to the list of possible return values.
+
+
+	* tests/clone3.c (main): Add EBADF to the list of possible
+	CLONE_INTO_CGROUP return values.
+
+2020-06-03  Dmitry V. Levin  <ldv@altlinux.org>
+
+	ci: use kernel headers from Linux kernel v5.7.
+	When Linux kernel merge window opens, changes of all sorts start to pour
+	down, breaking UAPI in various ways.  This does not work for strace,
+	we need a stable UAPI.
+
+	* .github/workflows/ci.yml (env): Add KBRANCH.
+	* .gitlab-ci.yml (variables): Likewise.
+	* .travis.yml (env:global): Likewise.
+
+2020-06-02  Dmitry V. Levin  <ldv@altlinux.org>
+
+	s390: use a more appropriate regset type.
+	* linux/s390/arch_regs.c (s390_regset): Change the type from
+	struct user_regs_struct to s390_regs, the latter is the subset of
+	struct user_regs_struct used by the kernel, it's also the type
+	used on s390x.
+
+2020-06-02  Steve Langasek  <steve.langasek@ubuntu.com>
+
+	tests/perf_event_open: avoid unaligned access on ARM.
+	The test suite already handles alignment requirements on POWER and
+	Sparc, add ARM to the list as well.  Not all ARM environments raise
+	SIGBUS on unaligned access, but some do.
+
+	* tests/perf_event_open.c (ATTR_REC) [ARM]: Use aligned access.
+
+2020-06-02  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests/wait4: invoke wait4 syscall directly instead of using libc wait4.
+	glibc-2.31.9000-312-g600f00b747ff42eb0aa778536d3ef602e8bcd550 introduced
+	a change in its wait4 implementation that makes it unsuitable for the
+	wait4 test.
+
+	* tests/wait4.c: Include "kernel_rusage.h" instead of <sys/resource.h>.
+	(sprint_rusage): Replace struct rusage with kernel_rusage_t,
+	cast member values from kernel_long_t to unsigned long long
+	using zero_extend_signed_to_ull, update format strings.
+	(k_wait4): New function.
+	(do_wait4, main): Use it instead of wait4.
+
+2020-06-02  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Post-release administrivia.
+	* NEWS: Add a header line for the next release.
+	* debian/changelog.in: Add a changelog entry for 5.7-1.
+	* strace.spec.in: Likewise.
+
+2020-06-01  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Prepare for 5.7 release.
+	* NEWS: Update for 5.7 release.
+
+	.mailmap: add more entries to avoid duplication in CREDITS.
+
+	Update copyright headers.
+	Headers updated automatically using maint/update_copyright_years.sh
+	script.
+
+2020-06-01  Gleb Fotengauer-Malinovskiy  <glebfm@altlinux.org>
+
+	Update ioctl entries from linux v5.7.
+	* linux/32/ioctls_inc_align16.h: Update from linux v5.7
+	using ioctls_gen.sh.
+	* linux/32/ioctls_inc_align32.h: Likewise.
+	* linux/32/ioctls_inc_align64.h: Likewise.
+	* linux/64/ioctls_inc.h: Likewise.
+	* linux/s390/ioctls_arch0.h: Likewise.
+	* linux/s390x/ioctls_arch0.h: Likewise.
+	* linux/x32/ioctls_inc0.h: Likewise.
+	* NEWS: Mention this.
+
+2020-05-31  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: increase default TIMEOUT_DURATION.
+	* tests/init.sh (TIMEOUT_DURATION): Increase from 600 to 1500.
+	* .travis.yml (matrix): Remove TIMEOUT_DURATION.
+
+2020-05-31  Dmitry V. Levin  <ldv@altlinux.org>
+
+	configure.ac: robustify linux headers checks.
+	Some linux headers used to require other headers to be included
+	beforehand.  While these linux headers are no longer insufficient
+	nowadays, configure checks need to handle old headers properly.
+
+	* configure.ac (AC_CHECK_TYPES): Include <sys/socket.h> before
+	<linux/fib_rules.h>.
+	(AC_CHECK_HEADERS): Include <sys/socket.h> and <linux/types.h>
+	before linux/if_addr.h, linux/if_link.h, linux/neighbour.h.
+	Include <linux/types.h> before other linux headers.
+
+2020-05-31  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Include <linux/types.h> before <linux/fiemap.h> and <linux/hiddev.h>
+	<linux/fiemap.h> and <linux/hiddev.h> used to require <linux/types.h>
+	to be included beforehand.
+
+	* file_ioctl.c [HAVE_LINUX_FIEMAP_H]: Include <linux/types.h>
+	before <linux/fiemap.h>.
+	* tests/file_ioctl.c: Likewise.
+	* tests/ioctl.c: Include <linux/types.h> before <linux/hiddev.h>.
+
+2020-05-31  Dmitry V. Levin  <ldv@altlinux.org>
+
+	debian/rules: fix build-udeb/Makefile target.
+	* debian/rules (build-udeb/Makefile): Rename --without-stacktrace
+	to --disable-stacktrace.
+
+2020-05-30  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Turn getfdpath and printfd functions into static inline wrappers.
+	* defs.h (printfd): Copy here from util.c, turn into an inline wrapper.
+	(getfdpath): Copy here from pathtrace.c, turn into an inline wrapper.
+	* pathtrace.c (getfdpath): Remove.
+	* util.c (printfd): Remove.
+
+2020-05-30  Ákos Uzonyi  <uzonyi.akos@gmail.com>
+
+	tests/pidfd_getfd.c: test decoding of targetfd.
+	* tests/pidfd_getfd.c (k_pidfd_getfd): Rename pid argument to pidfd.
+	(main): Test decoding of targetfd.
+	* tests/gen_tests.in: Add "-e signal=none" argument to pidfd_getfd
+	tests.
+
+2020-05-30  Ákos Uzonyi  <uzonyi.akos@gmail.com>
+
+	pidfd_getfd: fix decoder.
+	The decoder incorrectly assumed the first argument being a pid,
+	but actually it is a pidfd.
+
+	The patch also makes the decoder be able to decode the targetfd
+	(-y and -yy options).
+
+	* pidfd_getfd.c: Include "number_set.h".
+	(SYS_FUNC(pidfd_getfd)): Rewrite using pidfd_get_pid.
+
+	Fixes: v5.6~46 "Implement pidfd_getfd syscall decoding"
+
+2020-05-30  Ákos Uzonyi  <uzonyi.akos@gmail.com>
+
+	util.c: add pidfd_get_pid.
+	* defs.h (pidfd_get_pid): New function declaration.
+	* utils.c (pidfd_get_pid): New function, returns the pid of a pidfd.
+	(printpidfd): Rewrite using pidfd_get_pid.
+	(printfd_pid): Change printpidfd arguments.
+
+2020-05-30  Ákos Uzonyi  <uzonyi.akos@gmail.com>
+
+	Rename print_pid_fd to printfd_pid_tracee_ns.
+	To avoid confusion with the new printfd_pid fucntion.
+
+	defs.h (print_pid_fd): Rename to printfd_pid_tracee_ns.
+	util.c: Likewise.  All users updated.
+
+2020-05-30  Ákos Uzonyi  <uzonyi.akos@gmail.com>
+
+	util.c: add printfd_pid.
+	defs.h (printfd_pid): New function definition.
+	util.c (printfd_pid): New function printing the fd of an other process.
+	(printfd): Rewritten using printfd_pid.
+
+	pathtrace.c: add getfdpath_pid.
+	* defs.h (getfdpath_pid): New function definition.
+	* pathtrace.c (getfdpath_pid): New function, returns the path
+	associated with fd of the process with pid.
+	(getfdpath): Rewrite using getfdpath_pid.
+
+2020-05-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	xlat: annotate btrfs_compress_types with #enum.
+	* xlat/btrfs_compress_types.in: Add #enum, #include <stdio.h>,
+	and #include <linux/btrfs.h>
+	* configure.ac (AC_CHECK_DECL(BTRFS_COMPRESS_*)): Remove.
+
+2020-05-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	xlat: annotate rtnl_ifla_xdp_attached_mode with #enum.
+	And use proper checks in tests/nlattr_ifla_xdp.c.
+
+	* xlat/rtnl_ifla_xdp_attached_mode.in: Add #enum, #include <netinet/in.h>,
+	and #include <linux/rtnetlink.h> annotations.
+	* tests/nlattr_ifla_xdp.c [!XDP_ATTACHED_NONE] (XDP_ATTACHED_NONE):
+	Remove.
+	[!XDP_ATTACHED_MULTI] (XDP_ATTACHED_MULTI): Remove.
+	[!HAVE_DECL_XDP_ATTACHED_NONE] (XDP_ATTACHED_NONE): New enum definition.
+	[!HAVE_DECL_XDP_ATTACHED_MULTI] (XDP_ATTACHED_MULTI): Likewise.
+
+2020-05-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	rtnl_link: support IFLA_XDP_EXPECTED_FD attribute decoding.
+	Introduced by Linux commit v5.7-rc1~146^2~10^2~13^2~3.
+
+	* xlat/rtnl_ifla_xdp_attrs.in: Add #enum, #include <netlink/in.h>,
+	and #include <linux/rtnetlink.h> annotations.
+	(IFLA_XDP_EXPECTED_FD): New constant.
+	* rtnl_link.c (ifla_xdp_nla_decoders): Add [IFLA_XDP_EXPECTED_FD], set
+	value to decode_nla_fd.
+	* tests/nlattr_ifla_xdp-y.c: New file.
+	* tests/.gitignore: Add nlattr_ifla_xdp-y.
+	* tests/Makefile.am (check_PROGRAMS): Likewise.
+	* tests/gen_tests.in: Add nlattr_ifla_xdp-y test.
+	* tests/nlattr_ifla_xdp.c: Include "xlat/rtnl_ifla_xdp_attrs.h" under
+	XLAT_MACROS_ONLY definition.
+	(IFLA_XDP_FD, IFLA_XDP_ATTACHED, IFLA_XDP_PROG_ID, IFLA_XDP_DRV_PROG_ID,
+	IFLA_XDP_SKB_PROG_ID, IFLA_XDP_HW_PROG_ID): Remove.
+	[!FD9_PATH] (FD9_PATH): New macro, define to empty string.
+	(main): Add checks for IFLA_XDP_EXPECTED_FD.
+
+2020-05-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	tests: support -y mode for sockfd printing.
+	* tests/test_nlattr.h [!PRINT_SOCK] (PRINT_SOCK): New macro, define to 0.
+	(print_sockfd): New function.
+	(TEST_NLATTR_EX_): Call print_sockfd for sock fd printing.
+
+	rtnl_tc_action: implement TCA_ACT_HW_STATS and TCA_ACT_USED_HW_STATS decoding
+	* xlat/rtnl_tca_act_hw_stats.in: New file.
+	* rtnl_tc_action.c: Include "xlat/rtnl_tca_act_hw_stats.h".
+	(decode_tca_act_hw_stats): New function.
+	(tcamsg_nla_decoders): Add [TCA_ACT_HW_STATS]
+	and [TCA_ACT_USED_HW_STATS], set them to decode_tca_act_hw_stats.
+	* tests/nlattr_tcamsg.c: Add checks, update expected output.
+	* xlat/rtnl_tc_action_attrs.in (TCA_ACT_HW_STATS): New constant,
+	introduced by Linux commit v5.7-rc1~146^2~230^2 and renamed in Linux
+	commit v5.7-rc1~146^2~101.
+	(TCA_ACT_USED_HW_STATS): New constant, introduced by Linux commit
+	v5.7-rc1~146^2~25^2.
+
+	xlat: annotate rtnl_tca_stab_attrs with #enum.
+	* xlat/rtnl_tca_stab_attrs.in: Add #enum, #include <linux/types.h>,
+	 #include <linux/pkt_sched.h>.
+	* configure.ac (AC_CHECK_DECLS(TCA_STAB_DATA)): Remove.
+
+	xlat: annotate rtnl_tca_stats_attrs with #enum.
+	* xlat/rtnl_tca_stats_attrs.in: Add #enum, #include <linux/gen_stats.h>.
+	* configure.ac (AC_CHECK_DECL(TCA_STATS_PKT64)): Remove.
+
+	xlat: add #enum to v4l2 xlats.
+	* xlat/v4l2_buf_types.in: Add #enum, #include <sys/time.h>, #include
+	<linux/ioctl.h>, #include <linux/types.h>, and #include
+	<linux/videodev2.h>.
+	* xlat/v4l2_colorspaces.in: Likewise.
+	* xlat/v4l2_control_types.in: Likewise.
+	* xlat/v4l2_fields.in: Likewise.
+	* xlat/v4l2_framesize_types.in: Likewise.
+	* xlat/v4l2_memories.in: Likewise.
+	* xlat/v4l2_tuner_types.in: Likewise.
+	* configure.ac (AC_CHECK_DECL(V4L2_*)): Remove.
+
+	xlat: annotate rtnl_link_attrs with #enum.
+	* xlat/rtnl_link_attrs.in: Add #enum, #include <sys/socket.h>, #include
+	<linux/rtnetlink.h>.
+	* configure.ac (AC_CHECK_DECL(IFLA_*)): Remove.
+
+	xlat: annotate rtnl_tc_action_attrs with #enum.
+	* xlat/rtnl_tc_action_attrs.in: Add #enum, #include <linux/pkt_cls.h>
+	* configure.ac (AC_CHECK_DECL(TCA_ACT_*)): Remove.
+
+	xlat: annotate sysctl xlats with #enum.
+	* configure.ac (AC_CHECK_DECL(CTL_* KERN_* NET_* VM_*)): Remove.
+	* xlat/sysctl_kern.in: Add #enum, #include <sys/types.h>, #include
+	<linux/sysctl.h> descriptors.
+	* xlat/sysctl_net.in: Likewise.
+	* xlat/sysctl_net_core.in: Likewise.
+	* xlat/sysctl_net_ipv4.in: Likewise.
+	* xlat/sysctl_net_ipv4_conf.in: Likewise.
+	* xlat/sysctl_net_ipv4_route.in: Likewise.
+	* xlat/sysctl_net_ipv6.in: Likewise.
+	* xlat/sysctl_net_ipv6_route.in: Likewise.
+	* xlat/sysctl_net_unix.in: Likewise.
+	* xlat/sysctl_root.in: Likewise.
+	* xlat/sysctl_vm.in: Likewise.
+
+2020-05-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	configure: annotate waitid_types with #enum.
+	This also syncs up the configure checks with the actual list of xlat
+	values.
+
+	* xlat/waitid_types.in: Add #enum, #include <sys/types.h>, and #include
+	<sys/wait.h>.
+	* configure.ac (AC_CHECK_DECL(P_*)): Remove.
+
+	Complements: v5.4~82 "xlat: update waitid_types"
+
+2020-05-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	xlat: mark loop_flags_options as #enum.
+	* xlat/loop_flags_options.in: Add #enum and #include <linux/loop.h>
+	descriptors.
+	* configure.ac (AC_CHECK_DECLS(LO_FLAGS_*)): Remove.
+
+	xlat: generate m4 checks for enumerations.
+	* xlat/gen.sh (print_m4_record, gen_m4_entry): New functions.
+	(print_xlat_pair): Accept macro name in the third argument.
+	(print_xlat, print_xlat_pair): Call print_m4_record.
+	(cond_xlat): Pass $m to print_xlat_pair call. Set first_enum to 0.
+	(gen_header, gen_make, gen_git): Output the "generating ..." line
+	to stderr.
+	(gen_header): Get output_m4 as the fourth parameter, redirect fd 3
+	to stdout, set enum to 1 if #enum is present and $output_m4 is set,
+	append #include argument to includes, generate $output_m4 is $enum
+	is set to 1, pass macro name to print_xlat_pair call, close fd 3.
+	(gen_git): Add st_check_enums.m4 and "/*.m4".
+	(main): Allow passing $output_m4 as the third argument, pass m4 file
+	name as the fourth argument to gen_header calls, pipe gen_header output
+	to gen_m4_entry in case of no-argument invocation, redirect gen_header
+	output to /dev/null in case of single-file invocation.
+	* Makefile.am (ACLOCAL_AMFLAGS): Add "-I xlat".
+	* configure.ac: Add st_CHECK_ENUMS.
+
+2020-05-30  Pierre Marsais  <pierre.marsais@lse.epita.fr>
+
+	configure.ac: remove unused checks.
+	Those unused configure.ac checks were found with the following commands:
+
+	$ ./bootstrap
+	$ ./configure
+	$ grep '^#undef HAVE' config.h.in | cut -d' ' -f2 | sort >in_configure
+	$ find -iname '*.[ch]' -exec ifnames \{\} + | grep ^HAVE | \
+	  cut -d' ' -f1 | sort >in_source
+	$ comm -23 in_configure in_source | grep -vE '^HAVE_(UNION|STRUCT)'
+
+	* configure.ac (AC_CHECK_FUNCS): Remove utimensat, the last user was
+	removed by commit 589cff6.  Remove strsignal, the last user was
+	removed by commit 2c4fb90.
+	(AC_CHECK_HEADERS): Remove sys/conf.h, the last user was removed by
+	commit 811bda6.  Remove inttypes.h, the last user was removed by commit
+	a6d91de.  Remove stropts.h, the last user was removed by commit a56a81c.
+	(AC_CHECK_DECLS): remove P_PPID, P_PGID, P_SID, P_CID, P_UID, P_GID,
+	P_ALL, and P_LWPID, the last user was removed by commit 7da9d19.
+
+2020-05-29  Dmitry V. Levin  <ldv@altlinux.org>
+
+	maint: remove ioctl duplicates generated from linux/dma-buf.h.
+	Starting with commit v5.7-rc4~13^2~2^2~7, linux/dma-buf.h defines
+	DMA_BUF_SET_NAME_A and DMA_BUF_SET_NAME_B constants, and
+	DMA_BUF_SET_NAME equals to one of them.
+
+	* maint/ioctls_sym.sh: Edit linux/dma-buf.h to omit DMA_BUF_SET_NAME.
+
+2020-05-29  Dmitry V. Levin  <ldv@altlinux.org>
+
+	maint: force time64 based definitions in linux/videodev2.h.
+	Starting with commit v5.6-rc1~93^2~103, linux/videodev2.h provides either
+	time32 or time64 based definitions depending on the flavour provided by
+	libc headers.  While media/v4l2-ioctl.h already provides time32 based
+	definitions, linux/videodev2.h has to be twisted to force time64 based
+	definitions.
+
+	* maint/ioctls_sym.sh: Edit linux/videodev2.h to force time64 based API.
+
+2020-05-29  Dmitry V. Levin  <ldv@altlinux.org>
+
+	xlat: add 1<<_UFFDIO_WRITEPROTECT to uffd_register_ioctl_flags.
+	* xlat/uffd_register_ioctl_flags.in (1<<_UFFDIO_WRITEPROTECT): New
+	constant introduced by Linux kernel commit v5.7-rc1~58^2~113.
+
+2020-05-28  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Replace struct v4l2_event with a reliable alternative definition.
+	Since the definition of struct v4l2_event provided by the kernel depends
+	on the flavour of struct timespec provided by libc, we cannot use the
+	definition provided by the kernel, neither in the decoder nor in tests.
+
+	* kernel_v4l2_types.h: Include "kernel_timespec.h".
+	(kernel_v4l2_event_t): New type.
+	* linux/32/ioctls_inc_align16.h (VIDIOC_DQEVENT): Update.
+	* linux/32/ioctls_inc_align32.h: Likewise.
+	* linux/32/ioctls_inc_align64.h: Likewise.
+	* xlat/v4l2_ioctl_cmds.in (VIDIOC_DQEVENT): Redefine.
+	* v4l2.c (kernel_v4l2_event_t): Mpersify.
+
+2020-05-28  Dmitry V. Levin  <ldv@altlinux.org>
+
+	v4l2: move redefinitions of v4l2_buffer based constants to xlat.
+	* kernel_v4l2_types.h: Include "types/v4l2.h".
+	* v4l2.c (VIDIOC_QUERYBUF, VIDIOC_QBUF, VIDIOC_DQBUF,
+	VIDIOC_PREPARE_BUF): Move redefinitions ...
+	* xlat/v4l2_ioctl_cmds.in: ... here.
+	* tests/ioctl_v4l2.c: Include "xlat/v4l2_ioctl_cmds.h"
+	in XLAT_MACROS_ONLY mode.
+	(VIDIOC_QUERYBUF, VIDIOC_QBUF, VIDIOC_DQBUF, VIDIOC_PREPARE_BUF): Remove.
+	(main): Check for HAVE_STRUCT_V4L2_FRMSIZEENUM,
+	HAVE_STRUCT_V4L2_FRMIVALENUM, and HAVE_STRUCT_V4L2_CREATE_BUFFERS
+	instead of VIDIOC_ENUM_FRAMESIZES, VIDIOC_ENUM_FRAMEINTERVALS, and
+	VIDIOC_CREATE_BUFS as the latter are always defined now.
+	* tests/ioctl_v4l2-success.c: Likewise.
+
+2020-05-27  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Update NEWS.
+
+	tests: robustify strace-D.test against personality mismatch issues.
+	* tests/print_ppid_tracerpid.c: New file.
+	* tests/.gitignore: Add print_ppid_tracerpid.
+	* tests/Makefile.am (check_PROGRAMS): Likewise.
+	* tests/strace-D.test: Use print_ppid_tracerpid instead of
+	"sed -r -n '/^(P|Tracer)Pid:/p' /proc/self/status" to avoid
+	unrelated issues caused by potential personality mismatch.
+
+	tests: robustify pc.test against personality mismatch issues.
+	* tests/pc.test: Pass --quiet=attach,personality option to strace
+	to suppress some unrelated diagnostics that can confuse scripts
+	that parse strace output.
+
+2020-05-27  Dmitry V. Levin  <ldv@altlinux.org>
+
+	ci: re-enable testing with the latest mainline kernel headers.
+	There should be no issues with v5.7-rc7.
+	This reverts commit dc6a196f3a83103e8ba21b6809246d37356ffd3d.
+
+	* .github/workflows/ci.yml (env): Remove KBRANCH.
+	* .gitlab-ci.yml (variables): Likewise.
+	* .travis.yml (env:global): Likewise.
+
+2020-05-27  Dmitry V. Levin  <ldv@altlinux.org>
+
+	clone: implement decoding of cgroup field in struct clone_args.
+	* configure.ac (AC_CHECK_MEMBERS): Check for struct clone_args.cgroup
+	instead of struct clone_args.set_tid_size.
+	* clone.c (struct strace_clone_args): Add cgroup field.
+	(SYS_FUNC(clone3)): Decode cgroup field of struct clone_args introduced
+	by Linux kernel commit v5.7-rc1~107^2~9.
+	* NEWS: Mention this change.
+	* tests/clone3.c: Check HAVE_STRUCT_CLONE_ARGS_CGROUP instead of
+	HAVE_STRUCT_CLONE_ARGS_SET_TID_SIZE.
+	(struct test_clone_args): Add cgroup field.
+	(main): Check decoding of cgroup field.
+
+	xlat: update CLONE_* constants.
+	* xlat/clone3_flags.in (CLONE_INTO_CGROUP): New constant, introduced
+	by Linux kernel commit v5.7-rc1~107^2~9.
+	* NEWS: Mention this.
+	* tests/clone3.c (main): Update the expected output.
+
+	x32: workaround syscall(2) limitations in PTRACE_GET_SYSCALL_INFO check.
+	* ptrace_syscall_info.c (test_ptrace_get_syscall_info)
+	[SIZEOF_KERNEL_LONG_T > SIZEOF_LONG]: Cast elements of info.entry.args
+	array to (unsigned long).
+	* tests/ptrace_syscall_info.c (test_entry): Likewise.
+
+2020-05-27  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: silence compilation warnings in pc.test.
+	Silence the following compilation warnings produced by fresh gcc+glibc:
+
+	In file included from pc.c:9:
+	pc.c: In function 'main':
+	pc.c:30:9: warning: argument 2 is null but the corresponding size argument 3 value is 16 [-Wnonnull]
+	   30 |  assert(write(-1, NULL, 2 * sizeof(void *)) < 0);
+	      |         ^~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+	In file included from pc.c:12:
+	/usr/include/unistd.h:367:16: note: in a call to function 'write' declared with attribute 'read_only (2, 3)'
+	  367 | extern ssize_t write (int __fd, const void *__buf, size_t __n) __wur
+	      |                ^~~~~
+
+	* tests/pc.c (main): Use 8UL instead of NULL as a marker.
+	* tests/pc.test: Update expected output.
+
+2020-05-26  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Replace struct v4l2_buffer with a reliable alternative definition.
+	Starting with Linux kernel commit v5.6-rc1~93^2~102, the definition
+	of struct v4l2_buffer provided by the kernel depends on the flavour
+	of struct timeval provided by libc.  This effectively means that we
+	cannot use the definition provided by the kernel, neither in the decoder
+	nor in tests.
+
+	* kernel_v4l2_types.h: New file.
+	* Makefile.am (libstrace_a_SOURCES): Add it.
+	* types/v4l2.h (struct_v4l2_buffer): Remove.
+	* v4l2.c: Include "kernel_v4l2_types.h".
+	Replace struct_v4l2_buffer with kernel_v4l2_buffer_t.
+	(VIDIOC_QUERYBUF, VIDIOC_QBUF, VIDIOC_DQBUF, VIDIOC_PREPARE_BUF):
+	Redefine.
+	(print_v4l2_buffer): Use print_timeval64_data_size to print timestamp
+	field.
+	* linux/32/ioctls_inc_align16.h (VIDIOC_QUERYBUF, VIDIOC_QBUF,
+	VIDIOC_DQBUF, VIDIOC_PREPARE_BUF): Update.
+	* linux/32/ioctls_inc_align32.h: Likewise.
+	* linux/32/ioctls_inc_align64.h: Likewise.
+	* xlat/v4l2_ioctl_cmds.in (VIDIOC_QUERYBUF, VIDIOC_QBUF,
+	VIDIOC_DQBUF, VIDIOC_PREPARE_BUF): Comment out.
+	* tests/ioctl_v4l2.c: Include "kernel_v4l2_types.h".
+	(main): Replace struct_v4l2_buffer with kernel_v4l2_buffer_t.
+	(VIDIOC_QUERYBUF, VIDIOC_QBUF, VIDIOC_DQBUF, VIDIOC_PREPARE_BUF):
+	Redefine.
+	* tests/ioctl_v4l2-success.c: Likewise.
+
+	Resolves: https://github.com/strace/strace/issues/133
+
+2020-05-26  Dmitry V. Levin  <ldv@altlinux.org>
+
+	configure: move AM_PROG_AR after AC_USE_SYSTEM_EXTENSIONS.
+	This fixes the following autoreconf warning:
+	configure.ac:41: warning: AC_COMPILE_IFELSE was called before AC_USE_SYSTEM_EXTENSIONS
+
+	* configure.ac: Move AM_PROG_AR after AC_USE_SYSTEM_EXTENSIONS.
+
+	Fixes: v5.6-65-g81e11a9b8 "configure: check AR variable for 'ar' tool"
+
+2020-05-02  Mike Gilbert  <floppym@gentoo.org>
+
+	configure: check AR variable for 'ar' tool.
+	Without this, automake always hardcodes 'AR = ar' in Makefile.in
+
+	Bug: https://bugs.gentoo.org/720712
+
+2020-05-02  Dmitry V. Levin  <ldv@altlinux.org>
+
+	configure.ac: do not check for perl.
+	The last user of this check was removed by commit v4.7~160.
+
+	* configure.ac (AC_PATH_PROG): Remove perl.
+
+	Complements: v4.7~160 "Manual removal of non-Linux source, documentation, etc."
+
+2020-04-27  Dmitry V. Levin  <ldv@altlinux.org>
+
+	configure.ac: fix dladdr check.
+	* configure.ac: Check for the library providing dladdr using
+	AC_SEARCH_LIBS instead of AC_CHECK_LIB to handle the case when dladdr
+	is a part of libc.
+
+2020-04-24  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Rewrite decoders of dup, dup2, and dup3 syscalls.
+	* dup.c: New file.
+	* Makefile.am (libstrace_a_SOURCES): Add it.
+	* desc.c (do_dup2, SYS_FUNC(dup), SYS_FUNC(dup2), SYS_FUNC(dup3)):
+	Remove.
+
+	tests: check decoding of dup3 syscall in -y, -yy, and -P modes.
+	* tests/dup3.c: Rewrite.
+	* tests/dup3-P.c: New file.
+	* tests/dup3-y.c: Likewise.
+	* tests/dup3-yy.c: Likewise.
+	* tests/gen_tests.in (dup3): Add 7>>/dev/full.
+	(dup3-P, dup3-y, dup3-yy): New entries.
+	* tests/pure_executables.list: Add dup3-P, dup3-y, and dup3-yy.
+	* tests/.gitignore: Likewise.
+
+	tests: check decoding of dup2 syscall in -y, -yy, and -P modes.
+	* tests/dup2.c: Rewrite.
+	* tests/dup2-P.c: New file.
+	* tests/dup2-y.c: Likewise.
+	* tests/dup2-yy.c: Likewise.
+	* tests/gen_tests.in (dup2): Add 9>>/dev/full.
+	(dup2-P, dup2-y, dup2-yy): New entries.
+	* tests/pure_executables.list: Add dup2-P, dup2-y, and dup2-yy.
+	* tests/.gitignore: Likewise.
+
+	tests: check decoding of dup syscall in -y, -yy, and -P modes.
+	* tests/dup.c: Rewrite.
+	* tests/dup-P.c: New file.
+	* tests/dup-y.c: Likewise.
+	* tests/dup-yy.c: Likewise.
+	* tests/gen_tests.in (dup): Add 9>>/dev/full.
+	(dup-P, dup-y, dup-yy): New entries.
+	* tests/pure_executables.list: Add dup-P, dup-y, and dup-yy.
+	* tests/.gitignore: Likewise.
+
+2020-04-24  Niklas Cathor  <niklas.cathor@gmx.de>
+
+	strace.1: fix description of "open" example.
+	* strace.1.in (DESCRIPTION): In the example of "open" syscall with three
+	arguments, the rest of the sentence talks about the `flag` and the
+	`mode` arguments, not just about the `mode`.
+
+	Resolves: https://gitlab.com/strace/strace/merge_requests/1
+
+2020-04-24  Dmitry V. Levin  <ldv@altlinux.org>
+
+	github: add gcc-10 jobs.
+	* .github/workflows/ci.yml (gcc10-x86_64-kheaders, gcc10-x86_64-dw,
+	gcc10-x86_64-unwind, gcc10-x32-kheaders, gcc10-x32-nostacktrace,
+	gcc10-x86-kheaders, gcc10-x86-nostacktrace): New jobs.
+
+2020-04-23  Maxim Akhmedov  <max42@yandex-team.ru>
+	    Dmitry V. Levin  <ldv@altlinux.org>
+
+	Implement interval specification in syscall tampering expressions.
+	Before this change, strace allows syscall tampering only for syscalls
+	with 1) fixed invocation index or 2) all invocations starting from n-th
+	(possibly with some step).
+
+	These two options do not cover a useful scenario of testing
+	retrying/backoffing policy of traced program, which may be done by
+	introducing delays/errors on first n invocations, and then stopping
+	tampering.
+
+	This change adds possibility to invoke strace like the following:
+
+	  strace -e inject=recvfrom:delay_exit=100000:when=3,100 ./bin
+
+	which results in invocations from third to hundredth (inclusive) being
+	tampered.  Formally, syntax now looks like `when=first[..last][+step]`.
+
+	This change does not affect the existing behavior.
+
+	* defs.h (INJECT_LAST_INF): New macro.
+	(struct inject_opts): Add "last" field.
+	* filter_qualify.c (parse_inject_token) <when>: Add interval support.
+	(qualify_inject_common): Initialize struct inject_opts.last.
+	* syscall.c (tamper_with_syscall_entering): Handle
+	struct inject_opts.last.
+	* strace.1.in (Tampering): Document the new feature.
+	* strace.c (usage): Likewise.
+	* NEWS: Mention this change.
+	* tests/qual_fault-syntax.test: Check handling of invalid "when"
+	intervals.
+	* tests/qual_inject-syntax.test: Likewise.
+	* tests/qual_fault.c (last): New variable.
+	(main): Take "last" argument, handle it.
+	* tests/qual_fault.test: Check handling of valid "when" intervals.
+
+	Resolves: https://github.com/strace/strace/pull/136
+
+2020-04-21  Dmitry V. Levin  <ldv@altlinux.org>
+
+	pathtrace: fix matching of openat2 syscall.
+	* pathtrace.c (pathtrace_match_set): Handle SEN_openat2.
+
+	Fixes: v5.6~48 "open: implement openat2 syscall decoding"
+
+2020-04-19  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	xlat: add BTRFS_COMPRESS_ZSTD to btrfs_compress_types.
+	* xlat/btrfs_compress_types.in (BTRFS_COMPRESS_ZSTD): New constant,
+	introduced by Linux commit v4.14-rc1~22^2~1.
+	* tests/btrfs.c (BTRFS_COMPRESS_TYPES): Change value to 3.
+
+2020-04-19  Alistair Francis  <alistair.francis@wdc.com>
+
+	tests/xetitimer: Use syscalls instead of libc functions.
+	The new glibc implementation for y2038 safe arches (32-bit arch with
+	64-bit time_t) will set the itimerval struct inside libc instead of
+	inside the kernel. This is because the kernel expects a 32-bit version
+	of timeval while libc exposes a 64-bit version. As libc sets this, when
+	we pass a faulting pointer we will get a segfault instead of the kernel
+	reporint EFAULT back.
+
+	To avoid a seg fault let's use the kernel's equivalent of struct
+	__kernel_old_itimerval in the tests and call the syscall directly
+	instead of using libc. This way we can trigger the kernels EFAULT
+	response correctly.
+
+
+	* tests/xetitimer.c: Include "kernel_timeval.h"
+	(kernel_old_itimerval_t): New type.
+	(main): Use it instead of struct itimerval, replace getitimer with
+	syscall(__NR_getitimer), replace setitimer with syscall(__NR_setitimer).
+
+2020-04-19  Alistair Francis  <alistair.francis@wdc.com>
+	    Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests/semtimedop: Skip tests if semtimedop syscall is not available.
+	New y2038 safe 32-bit architectures don't have the __NR_semtimedop
+	syscall, so let's skip the test.
+
+
+	* tests/semtimedop.c: Include "scno.h".
+	[!(__NR_semtimedop || __NR_socketcall)]: Skip the test.
+
+2020-04-19  Alistair Francis  <alistair.francis@wdc.com>
+
+	tests/xettimeofday: Skip tests if __NR_gettimeofday syscall is not defined
+	New y2038 safe 32-bit architectures don't have the
+	__NR_gettimeofday/__NR_settimeofday syscalls, so let's skip the test.
+
+
+	* tests/xettimeofday.c: Include "scno.h".
+	[!__NR_gettimeofday]: Skip the test.
+
+2020-04-19  Alistair Francis  <alistair.francis@wdc.com>
+
+	tests/wait4: Skip tests if __NR_wait4 syscall is not defined.
+	New y2038 safe 32-bit architectures don't have the __NR_wait4 syscall,
+	so let's skip the test.
+
+
+	* tests/wait4.c: Include "scno.h".
+	[!__NR_wait4]: Skip the test.
+
+2020-04-19  Alistair Francis  <alistair.francis@wdc.com>
+
+	tests/msg_control: Use old time structures for old timestamps.
+	The SO_TIMESTAMP_OLD returns a timeval that matches the struct
+	kernel_old_timeval_t instead of the struct timeval. This is different
+	on new 32-bit architectures (like RV32) where timeval uses 64-bit time_t
+	while kernel_old_timeval_t uses 32-bit.
+
+	To fix overflow errors let's use kernel_old_timeval_t instead of
+	the libc struct timeval.
+
+
+	Likewise, SO_TIMESTAMPNS_OLD and SO_TIMESTAMPING_OLD return
+	kernel_old_timespec_t.
+
+	* tests/msg_control.c: Include "kernel_timeval.h" and
+	"kernel_old_timespec.h".
+	(test_scm_timestamp_old): Replace struct timeval with
+	kernel_old_timeval_t.
+	(test_scm_timestampns_old, test_scm_timestamping_old): Replace
+	struct timespec with kernel_old_timespec_t.
+
+2020-04-19  Alistair Francis  <alistair.francis@wdc.com>
+
+	tests/sockopt-timestamp: Use old time structures for old timestamps.
+	The SO_TIMESTAMP_OLD returns a timeval that matches the struct
+	kernel_old_timeval_t instead of the struct timeval. This is different
+	on new 32-bit architectures (like RV32) where timeval uses 64-bit time_t
+	while kernel_old_timeval_t uses 32-bit.
+
+	To fix overflow errors let's use kernel_old_timeval_t instead of
+	the libc struct timeval.
+
+
+	Likewise, SO_TIMESTAMPNS_OLD returns kernel_old_timespec_t.
+
+	* tests/sockopt-timestamp.c: Include "kernel_timeval.h" and
+	"kernel_old_timespec.h".
+	(print_timestamp_old): Replace struct timeval with kernel_old_timeval_t.
+	(print_timestampns_old): Replace struct timespec with
+	kernel_old_timespec_t.
+
+2020-04-19  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Rework printing of SO_TIMESTAMPNS_OLD and SO_TIMESTAMPING_OLD timestamps
+	On architectures with 32-bit kernel_long_t the kernel sends 32-bit
+	timespecs in SO_TIMESTAMPNS_OLD and SO_TIMESTAMPING_OLD messages.
+	Unfortunately, this applies to all 32-bit architectures including
+	those (like RV32) that do not define __ARCH_WANT_TIME32_SYSCALLS.
+
+	* print_timespec.c: Remove.
+	* Makefile.am (libstrace_a_SOURCES): Remove it.
+	* linux/arch_defs_.h (ARCH_TIMESIZE): Remove.
+	(MIN_KLONGSIZE, HAVE_ARCH_TIMESPEC32): New macros.
+	* linux/x32/arch_defs_.h (ARCH_TIMESIZE): Remove.
+	* defs.h (print_timespec32_data_size, print_timespec32_array_data_size):
+	Declare for [HAVE_ARCH_TIMESPEC32].
+	* kernel_timespec.h (kernel_timespec32_t): Define for
+	[HAVE_ARCH_TIMESPEC32].
+	* print_timespec32.c (TIMESPEC_T, PRINT_TIMESPEC_DATA_SIZE,
+	PRINT_TIMESPEC_ARRAY_DATA_SIZE): Define for [HAVE_ARCH_TIMESPEC32].
+	* msghdr.c (PRINT_TIMESPEC_DATA_SIZE, PRINT_TIMESPEC_ARRAY_DATA_SIZE):
+	Define.
+	(print_scm_timestampns_old): Use PRINT_TIMESPEC_DATA_SIZE
+	instead of print_struct_timespec_data_size.
+	(print_scm_timestamping_old): Use PRINT_TIMESPEC_ARRAY_DATA_SIZE
+	instead of print_struct_timespec_array_data_size.
+
+2020-04-19  Alistair Francis  <alistair.francis@wdc.com>
+
+	tests/waitid: Correctly use the long types from the rusage struct.
+	The kernel's rusage struct uses the kernel's __kernel_old_timeval which
+	means that even for 32-bit archs with 64-bit time_t (like RV32) the time
+	values are 32-bit.
+
+	We can fix this by making sure we don't use libc's rusage struct and
+	instead use our own with the kernel's old timeval.
+
+
+	* configure.ac (AC_CHECK_MEMBERS): Do not check for members of struct
+	rusage.
+	* tests/waitid.c: Include "kernel_rusage.h" instead of <sys/resource.h>.
+	(RU_MAXRSS, RU_IXRSS, RU_IDRSS, RU_ISRSS, RU_MINFLT, RU_MAJFLT,
+	RU_NSWAP, RU_INBLOCK, RU_OUBLOCK, RU_MSGSND, RU_MSGRCV, RU_NSIGNALS,
+	RU_NVCSW, RU_NIVCSW): Remove.
+	(sprint_rusage): Replace struct rusage with kernel_rusage_t.
+	Use the respective ru_* field names instead of removed macros.
+	(do_waitid, main): Replace struct rusage with kernel_rusage_t.
+
+	This partially reverts commit v5.6~192.
+
+2020-04-19  Alistair Francis  <alistair.francis@wdc.com>
+	    Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests/getrusage: Correctly use the long types from the rusage struct.
+	The kernel's rusage struct uses the kernel's __kernel_old_timeval which
+	means that even for 32-bit archs with 64-bit time_t (like RV32) the time
+	values are 32-bit.
+
+	We can fix this by making sure we don't use libc's rusage struct and
+	instead use our own with the kernel's old timeval.
+
+
+	* tests/getrusage.c: Include "kernel_rusage.h".
+	(invoke_print): Replace struct rusage with kernel_rusage_t,
+	cast member values from kernel_long_t to unsigned long long
+	using zero_extend_signed_to_ull, update format strings.
+
+2020-04-19  Alistair Francis  <alistair.francis@wdc.com>
+	    Dmitry V. Levin  <ldv@altlinux.org>
+
+	kernel_rusage.h: introduce kernel_rusage_t.
+
+	* printrusage.c: Include "kernel_rusage.h" instead of "kernel_timeval.h".
+	(rusage_t): Rename to kernel_rusage_t, move the definition to ...
+	* kernel_rusage.h: ... new file.
+	* Makefile.am (libstrace_a_SOURCES): Add it.
+
+2020-04-19  Alistair Francis  <alistair.francis@wdc.com>
+	    Dmitry V. Levin  <ldv@altlinux.org>
+
+	time: Protect the print_timezone() function.
+	To avoid the following error:
+	time.c:17:1: error: 'print_timezone' defined but not used [-Werror=unused-function]
+
+	ensure that print_timezone is only defined if we are going to use it.
+
+
+	* time.c (print_timezone): Place under
+	[HAVE_ARCH_TIME32_SYSCALLS || HAVE_ARCH_OLD_TIME64_SYSCALLS] guard.
+
+	Complements: v5.6~28 "linux/32: move wait4 and [gs]ettimeofday from syscallent.h to syscallent-time32.h"
+
+2020-04-18  Kemeng Shi  <shikemeng@huawei.com>
+
+	tests: correct error message in io_uring_register test.
+	* tests/io_uring_register.c (main): If path_full failed to open,
+	print its name instead of mistakenly used path_null.
+
+2020-04-18  Paul Chaignon  <paul@cilium.io>
+
+	bpf: support new commands BPF_LINK_{CREATE,UPDATE}
+	* xlat/bpf_commands.in (BPF_LINK_CREATE): New constant introduced by Linux
+	commit v5.7-rc1~146^2~10^2^2~3.
+	(BPF_LINK_UPDATE): New constant introduced by Linux commit
+	v5.7-rc1~146^2~10^2^2~2.
+	* bpf.c (BEGIN_BPF_CMD_DECODER(BPF_LINK_CREATE),
+	BEGIN_BPF_CMD_DECODER(BPF_LINK_UPDATE)): Decode the new commands.
+	(SYS_FUNC(bpf)): Decode the new commands.
+	* bpf_attr.h (BPF_LINK_CREATE_struct): New structure introduced by Linux
+	commit v5.7-rc1~146^2~10^2^2~3.
+	(BPF_LINK_UPDATE_struct): New structure introduced by Linux commit
+	v5.7-rc1~146^2~10^2^2~2.
+	(BPF_LINK_CREATE_struct_size, BPF_LINK_UPDATE_struct_size): New macros.
+	* NEWS: Mention this.
+	* tests/bpf.c (BPF_LINK_CREATE_checks, BPF_LINK_UPDATE_checks): Tests for
+	the new commands.
+
+2020-04-18  Dmitry V. Levin  <ldv@altlinux.org>
+
+	types: do not generate TYPES_M4_FILES variable.
+	* types/gen.sh (gen_makefile): Do not generate TYPES_M4_FILES variable,
+	it isn't used anywhere.
+
+2020-04-17  Ákos Uzonyi  <uzonyi.akos@gmail.com>
+
+	Add test for %clock trace class.
+	* tests/Makefile.am (EXTRA_DIST): Add trace_clock.in.
+	* tests/gen_tests.in (trace_clock): New entry.
+	* tests/trace_clock.in: New file.
+
+2020-04-17  Ákos Uzonyi  <uzonyi.akos@gmail.com>
+
+	Add %clock trace class.
+	The %clock class includes the syscalls that read or modify system clock.
+
+	linux/*/syscallent*.h part is updated automatically by:
+	sed -i -r '
+	    /"(.*adjtime.*|.*clock_([gs]et|adj).*|.*[gs]ettimeofday.*|time)"/ {
+	        s/(\{[^,]*,\t[^0][^,]*)/\1|TCL/
+	        s/(\{[^,]*,\s*)0/\1TCL/
+	    }
+	' linux/*/syscallent*.h
+
+	* basic_filters.c (loopup_class): Add %clock member to syscall_class[].
+	* linux/32/syscallent-time32.h: Add TCL flag to clock related syscalls.
+	* linux/64/syscallent.h: Likewise.
+	* linux/alpha/syscallent.h: Likewise.
+	* linux/arm/syscallent.h: Likewise.
+	* linux/avr32/syscallent.h: Likewise.
+	* linux/bfin/syscallent.h: Likewise.
+	* linux/hppa/syscallent.h: Likewise.
+	* linux/i386/syscallent.h: Likewise.
+	* linux/ia64/syscallent.h: Likewise.
+	* linux/m68k/syscallent.h: Likewise.
+	* linux/microblaze/syscallent.h: Likewise.
+	* linux/mips/syscallent-compat.h: Likewise.
+	* linux/mips/syscallent-n32.h: Likewise.
+	* linux/mips/syscallent-n64.h: Likewise.
+	* linux/mips/syscallent-o32.h: Likewise.
+	* linux/powerpc/syscallent.h: Likewise.
+	* linux/powerpc64/syscallent.h: Likewise.
+	* linux/s390/syscallent.h: Likewise.
+	* linux/s390x/syscallent.h: Likewise.
+	* linux/sh/syscallent.h: Likewise.
+	* linux/sh64/syscallent.h: Likewise.
+	* linux/sparc/syscallent.h: Likewise.
+	* linux/sparc64/syscallent.h: Likewise.
+	* linux/x32/syscallent.h: Likewise.
+	* linux/x86_64/syscallent.h: Likewise.
+	* linux/xtensa/syscallent.h: Likewise.
+	* strace.1.in: Add %clock description.
+	* strace.c (usage): Add %clock group to help message.
+	* sysent.h (TRACE_CLOCK): New definition.
+	* sysent_shorthand_defs.h (TC): Likewise.
+	* sysent_shorthand_undefs.h (TC): Add undef.
+	* NEWS: Mention this.
+
+2020-04-17  Ákos Uzonyi  <uzonyi.akos@gmail.com>
+
+	sysent_shorthand_undefs.h: add missing undefs.
+	Add undefs that were missing from sysent_shorthand_undefs.h
+	(mirroring defs in sysent_shorthand_defs.h).
+
+	* sysent_shorthand_undefs.h (PU): Add undef.
+	(TSD): Likewise.
+	(TC): Likewise.
+
+	Fixes: v4.21~29 "Add pure syscall flag"
+	Fixes: v5.3~36 "Add seccomp filter syscall flag"
+	Fixes: v5.5~100 "Implement %creds trace class"
+
+2020-04-17  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: use create_tmpfile.
+	* tests/fchmod.c (main): Use create_tmpfile instead of open+unlink.
+	* tests/preadv.c: Likewise.
+	* tests/sendfile.c: Likewise.
+	* tests/sendfile64.c: Likewise.
+	* tests/fcntl-common.c (create_sample): Use create_tmpfile instead of
+	mkstemp.
+
+2020-04-17  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: introduce create_tmpfile function.
+	There are few cases in tests where a file is created and immediately
+	unlinked.  Add a function to perform this action in a more systematic
+	way.
+
+	* tests/tests.h (create_tmpfile): New prototype.
+	* tests/create_tmpfile.c: New file.
+	* tests/Makefile.am (libtests_a_SOURCES): Add create_tmpfile.c.
+
+2020-04-16  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Extend memory caching of umove* functions.
+	* ucopy.c (cached_raddr): Double the size.
+	(get_next_unused_idx, lookup_cached_raddr_idx, set_cached_raddr_idx):
+	New functions.
+	(vm_read_mem): Use them.  When the data to be fetched resides in
+	up to 4 adjacent memory pages, fetch these pages and cache them.
+	* tests/umovestr_cached_adjacent.c: New file.
+	* tests/pure_executables.list: Add umovestr_cached_adjacent.
+	* tests/.gitignore: Likewise.
+	* tests/umovestr_cached.test: Handle the first argument.
+	* tests/gen_tests.in (umovestr_cached_adjacent): New test.
+
+2020-04-15  Dmitry V. Levin  <ldv@altlinux.org>
+
+	filter_seccomp: implement on systems without <linux/seccomp.h>
+	Provide fallback definitions required to implement seccomp-assisted
+	syscall filtering.
+
+	* filter_seccomp.c [!HAVE_LINUX_SECCOMP_H]: Include
+	"xlat/prctl_options.h", "xlat/seccomp_mode.h" and
+	"xlat/seccomp_ret_action.h" in XLAT_MACROS_ONLY mode, remove #warning.
+	[!HAVE_LINUX_SECCOMP_H] (struct seccomp_data): Define.
+	[!HAVE_LINUX_SECCOMP_H] (check_seccomp_filter_properties,
+	init_seccomp_filter, seccomp_filter_restart_operator): Remove stubs.
+
+	Complements: v5.3~7 "Introduce seccomp-assisted syscall filtering"
+
+2020-04-15  Dmitry V. Levin  <ldv@altlinux.org>
+
+	x86_64: provide a fallback definition of __X32_SYSCALL_BIT.
+	Make sure __X32_SYSCALL_BIT is defined on __x86_64__,
+	move fallback definitions from various files to x86_64/arch_defs_.h.
+
+	* linux/x86_64/arch_defs_.h [!__X32_SYSCALL_BIT] (__X32_SYSCALL_BIT):
+	Define.
+	* linux/x86_64/arch_get_personality.c [!__X32_SYSCALL_BIT]
+	(__X32_SYSCALL_BIT): Remove.
+	* linux/x86_64/get_scno.c: Likewise.
+	* tests/filter_seccomp-flag.c [__x86_64__]: Likewise.
+
+	Complements: v5.3~7 "Introduce seccomp-assisted syscall filtering"
+
+2020-04-15  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	xlat: add UFFDIO_COPY_MODE_WP to uffd_copy_flags.
+	* xlat/uffd_copy_flags.in (UFFDIO_COPY_MODE_WP): New constant,
+	introduced by Linux commit v5.7-rc1~58^2~121.
+	(UFFDIO_COPY_MODE_DONTWAKE): Add fall-back value.
+	* tests/ioctl_uffdio.c: Add a check for the new flag.
+
+	xlat: update mremap_flags.
+	* xlat/mremap_flags.in: Add fallback values.
+	(MREMAP_DONTUNMAP): New constant, introduced by Linux commit
+	v5.7-rc1~124^2~49.
+
+	xlat: update lwtunnel_encap_types.
+	* xlat/lwtunnel_encap_types.in (LWTUNNEL_ENCAP_SEG6_LOCAL): New
+	constant, introduced by Linux commit v4.14-rc1~130^2~348^2~2.
+	(LWTUNNEL_ENCAP_RPL): New constant, introduced by Linux commit
+	v5.7-rc1~146^2~38^2.
+
+	xlat: add XDP_FLAGS_REPLACE to xdp_flags.
+	* xlat/xdp_flags.in: Add leading zeroes to fallback values.
+	(XDP_FLAGS_REPLACE): New constant, introduced by Linux commit
+	v5.7-rc1~146^2~10^2~13^2~3.
+
+	xlat: add FAN_DIR_MODIFY to fan_event_flags.
+	* xlat/fan_event_flags.in (FAN_DIR_MODIFY): New constant, introduced
+	by Linux commit v5.7-rc1~72^2~5.
+	* tests/fanotify_mark.c: Update expected output.
+
+	xlat: update v4l2_pix_fmts.
+	* xlat/v4l2_pix_fmts.in (V4L2_PIX_FMT_SBGGR14, V4L2_PIX_FMT_SGBRG14,
+	V4L2_PIX_FMT_SGRBG14, V4L2_PIX_FMT_SRGGB14): New constants, introduced
+	by Linux commit v5.7-rc1~193^2~35.
+	(V4L2_PIX_FMT_Y14): New constant, introduced by Linux commit
+	v5.7-rc1~193^2~34.
+
+	xlat: update uring_ops.
+	* xlat/uring_ops.in (IORING_OP_SPLICE): New constant, introduced
+	by Linux commit v5.7-rc1~201^2~46.
+	(IORING_OP_PROVIDE_BUFFERS): New constant, introduced by Linux commit
+	v5.7-rc1~201^2~23.
+	(IORING_OP_REMOVE_BUFFERS): New constant, introduced by Linux commit
+	v5.7-rc1~201^2~18.
+	* tests/io_uring_register.c: Update expected output.
+
+	xlat: add SECCOMP_FILTER_FLAG_TSYNC_ESRCH to seccomp_filter_flags.
+	* xlat/seccomp_filter_flags.in: Use (1<<BIT) syntax.
+	(SECCOMP_FILTER_FLAG_TSYNC_ESRCH): New constant, introduced by Linux
+	commit v5.7-rc1~198^2~1.
+	* tests/seccomp-filter.c: Update expected output.
+	* tests/seccomp-filter-v.c: Likewise.
+
+	xlat: add IORING_FEAT_FAST_POLL to uring_setup_features.
+	* xlat/uring_setup_features.in (IORING_FEAT_FAST_POLL): New constant,
+	introduced by Linux commit v5.7-rc1~201^2~36.
+
+	xlat: add V4L2_CID_USER_ATMEL_ISC_BASE to v4l2_control_id_bases.
+	* xlat/v4l2_control_id_bases.in (V4L2_CID_USER_ATMEL_ISC_BASE): New
+	constant, introdued by Linux commit v5.7-rc1~193^2~219.
+
+	xlat: add KVM_CAP_S390_PROTECTED and KVM_CAP_PPC_SECURE_GUEST to kvm_cap
+	* xlat/kvm_cap.in (KVM_CAP_S390_PROTECTED): New constant, introduced
+	by Linux commit v5.7-rc1~121^2~15^2~4.
+	(KVM_CAP_PPC_SECURE_GUEST): New constant, introduced by Linux commit
+	v5.7-rc1~121^2~12^2.
+
+	xlat: add PERF_SAMPLE_BRANCH_HW_INDEX to perf_branch_sample_type.
+	* xlat/perf_branch_sample_type.in (PERF_SAMPLE_BRANCH_HW_INDEX): New
+	constant, introduced by Linux commit v5.7-rc1~180^2~23.
+	* tests/perf_event_open.c: Update expected output.
+
+2020-04-15  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	tests: allow passing arguments to netlink_sock_diag.test.
+	And remove netlink_sock_diag-v.sh, since it is no longer needed.
+
+	* tests/netlink_sock_diag.test: Pass script's arguments to
+	run_strace_match_diff call.
+	* tests/gen_tests.in (nlattr_packet_diag_msg): Call
+	netlink_sock_diag.test with -v instead of netlink_sock_diag-v.sh..
+	* tests/netlink_sock_diag-v.sh: Remove.
+	* tests/Makefile.am (EXTRA_DIST): Remove netlink_sock_diag-v.sh.
+
+2020-04-15  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	tests: use the FLAG macro instead of a locally defined one in clone3 test
+	* tests/clone3.c (_): Remove.
+	(enum validity_flags): Use FLAG() instead of _().
+
+2020-04-15  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	clone: add more elaborate comments for struct strace_clone_args field.
+	Try to capture field semantics and type.
+
+	* clone.c (struct strace_clone_args): Add/extend comments for the
+	fields.
+
+2020-04-14  Fabrice Fontaine  <fontaine.fabrice@gmail.com>
+
+	ptrace_syscall_info.c: fix build without fork.
+	Build without fork fails on:
+
+	ptrace_syscall_info.c:33:27: error: 'expected_entry_size' defined but not used [-Werror=unused-const-variable=]
+	 static const unsigned int expected_entry_size =
+	                           ^~~~~~~~~~~~~~~~~~~
+	ptrace_syscall_info.c:31:27: error: 'expected_none_size' defined but not used [-Werror=unused-const-variable=]
+	 static const unsigned int expected_none_size =
+	                           ^~~~~~~~~~~~~~~~~~
+	ptrace_syscall_info.c:24:1: error: 'kill_tracee' defined but not used [-Werror=unused-function]
+	 kill_tracee(pid_t pid)
+	 ^~~~~~~~~~~
+
+	Fixes:
+	 - http://autobuild.buildroot.org/results/ffc81d3798379a9c34c7a708ebbdea27409f755d
+
+
+	* ptrace_syscall_info.c (kill_tracee, expected_none_size,
+	expected_entry_size): Move definitions under [HAVE_FORK] guard.
+
+	Resolves: https://github.com/strace/strace/pull/135
+
+2020-04-13  Paul Chaignon  <paul@cilium.io>
+
+	bpf: update BPF_* constants.
+	* xlat/bpf_attach_types.in (BPF_MODIFY_RETURN): New constant introduced by
+	Linux kernel commit v5.7-rc1~146^2~174^2~45^2~4.
+	(BPF_LSM_MAC): New constant introduced by Linux kernel commit
+	v5.7-rc1~146^2~10^2~9^2~7.
+	* xlat/bpf_prog_types.in (BPF_PROG_TYPE_LSM): New constant introduced by
+	Linux kernel commit v5.7-rc1~146^2~10^2~9^2~7.
+	* NEWS: Mention this.
+	* tests/bpf.c (BPF_PROG_LOAD_checks, BPF_PROG_QUERY_checks): Update checks
+	and their expected output.
+	* tests/kernel_version.c (print_bpf_attr, main): Likewise.
+
+2020-04-12  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Makefile.am: move almost all of strace_SOURCES to libstrace_a_SOURCES.
+	There is no need to track files that are used conditionally.
+
+	* Makefile.am (strace_SOURCES): Move all except strace.c ...
+	(libstrace_a_SOURCES): ... here.
+
+2020-04-12  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Rewrite decoders of getdents, getdents64, and readdir syscalls.
+	The old approach of allocating memory for all dentries returned by
+	getdents/getdents64 was problematic, fix it by fetching and printing
+	dentries sequentially.
+
+	* dirent_types.c: New file.
+	* xgetdents.c: Likewise.
+	* xgetdents.h: Likewise.
+	* Makefile.am (strace_SOURCES): Add them.
+	* dirent.c: Include "xgetdents.h" and "print_fields.h".
+	(header_size): New variable.
+	(print_dentry_head, decode_dentry_head, decode_dentry_tail): New
+	functions.
+	(print_old_dirent): Rewrite using print_dentry_head.
+	(SYS_FUNC(getdents)): Rewrite using xgetdents, decode_dentry_head,
+	and decode_dentry_tail.
+	* dirent64.c: Include "xgetdents.h", "kernel_dirent.h"
+	and "print_fields.h" instead of "defs.h", <dirent.h>
+	and "xlat/dirent_types.h".
+	(decode_dentry_head, decode_dentry_tail): New functions.
+	(SYS_FUNC(getdents64)): Rewrite using xgetdents, decode_dentry_head,
+	and decode_dentry_tail.
+
+	Resolves: https://github.com/strace/strace/issues/19
+	Resolves: https://github.com/strace/strace/pull/20
+
+2020-04-11  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Guard against invalid return values of getdents/getdents64 syscalls.
+	The kernel is not expected to return more bytes than requested.
+	If this ever happens, treat it as an error.
+
+	* dirent.c (SYS_FUNC(getdents)): Treat the return value greater than
+	the third argument of syscall as an error.
+	* dirent64.c (SYS_FUNC(getdents64)): Likewise.
+
+2020-04-11  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Print the second argument of getdents/getdents64 syscalls in abbrev mode
+	* dirent.c (SYS_FUNC(getdents)) [!abbrev(tcp)]: Print u_arg[1] along
+	with the number of entries.
+	* dirent64.c (SYS_FUNC(getdents64)) [!abbrev(tcp)]: Likewise.
+	* tests/xgetdents.c (ls): Update expected output.
+
+	tests: check abbreviated decoding of getdents and getdents64 syscalls.
+	* tests/getdents-v.c: New file.
+	* tests/getdents64-v.c: Likewise.
+	* tests/pure_executables.list: Add getdents-v and getdents64-v.
+	* tests/.gitignore: Likewise.
+	* tests/gen_tests.in (getdents-v, getdents64-v): New entries.
+	(getdents, getdents64): Update.
+	* tests/getdents.c (print_dirent): Define only if [VERBOSE].
+	* tests/getdents64.c (print_dirent): Likewise.
+	* tests/xgetdents.c (str_d_type): Likewise.
+	(ls): Handle [!VERBOSE] case.
+	(main) [VERBOSE]: Add "-v" to dname.
+
+	tests: refactor getdents and getdents64 tests.
+	* tests/xgetdents.c: New file.
+	* tests/Makefile.am (EXTRA_DIST): Add xgetdents.c.
+	* tests/getdents.c: Rewrite using xgetdents.c.
+	* tests/getdents64.c: Likewise.
+
+2020-04-11  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Move kernel_dirent64 definition to kernel_dirent.h.
+	... and rename kernel_dirent64 type to kernel_dirent64_t
+
+	* tests/getdents64.c: Include "kernel_dirent.h", rename kernel_dirent64
+	to kernel_dirent64_t.
+	(kernel_dirent64_t): Move ...
+	* kernel_dirent.h: ... here.
+
+2020-04-11  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Move kernel_dirent definition from kernel_types.h to a separate header.
+	... and rename kernel_dirent type to kernel_dirent_t
+
+	* kernel_types.h (kernel_dirent): Rename to kernel_dirent_t, move ...
+	* kernel_dirent.h: ... to new file.
+	* Makefile.am (strace_SOURCES): Add it.
+	* dirent.c: Include "kernel_dirent.h", rename kernel_dirent
+	to kernel_dirent_t.
+	* tests/getdents.c: Likewise.
+
+2020-04-09  Eugene Syromyatnikov  <evgsyr@gmail.com>
+	    Dmitry V. Levin  <ldv@altlinux.org>
+
+	strace: fix -E/--env options affecting strace environment.
+	The current approach with putenv() during parsing has a problem:
+	it changes strace's own environment which may affect its behaviour
+	in an unacceptable way.
+
+	As a solution, let's apply an approach similar to path tracing option
+	parsing: collect the provided optarg's in an array, then construct
+	a new environment and pass it to startup_child().
+
+	* strace.c (struct exec_params): Add env field.
+	(exec_or_die): Call execve() instead of execv(); pass params->env
+	as the third argument.
+	(startup_child): Add env parameter, set params_for_tracee.env to it.
+	(remove_from_env, add_to_env, update_env, make_env): New functions.
+	(init): Add env_changes, env_change_size, env_change_count local
+	variables; store optarg in env_changes array on -E option occurrence;
+	construct new environment using make_env and pass it to startup_child
+	in the second argument.
+	* tests/strace-E-override.test: New test.
+	* tests/Makefile.am (MISC_TESTS): Add strace-E-override.test.
+
+2020-04-09  Eugene Syromyatnikov  <evgsyr@gmail.com>
+	    Dmitry V. Levin  <ldv@altlinux.org>
+
+	xmalloc: add xallocarray.
+	Add a wrapper around malloc with calloc interface.
+
+	* xmalloc.h (xallocarray): New function declaration.
+	* xmalloc.c (xallocarray): New function.
+
+2020-04-09  Eugene Syromiatnikov  <esyr@redhat.com>
+	    Dmitry V. Levin  <ldv@altlinux.org>
+
+	strace: move pathtrace_select calls to a later initialisation stage.
+	Since path name resolution is specific to the tracing backend
+	(especially when tracees are remote), let's first collect the list
+	of paths to trace in a temporary array and add it later during the
+	initialisation.
+
+	* strace.c (init): Add pathtrace_paths temporary array, with its
+	element count stored in pathtrace_count and size in pathtrace_size.
+	(init) <case 'P'>: Store argument in pathtrace_paths, grow it if needed.
+	(init): Iterate over pathtrace_paths and call pathtrace_select for each
+	element.  Free the array.
+	* tests/options-syntax.test: Check that path name resolution happens
+	but not too early.
+
+2020-04-09  Eugene Syromyatnikov  <evgsyr@gmail.com>
+	    Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: check -E/--env unset behaviour.
+	* tests/strace-E-unset.test: Likewise.
+	* tests/strace-E-unset.expected: New file.
+	* tests/Makefile.am (MISC_TESTS): Add strace-E-unset.test.
+	(EXTRA_DIST): Add strace-E-unset.expected.
+
+2020-04-09  Eugene Syromyatnikov  <evgsyr@gmail.com>
+	    Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: add support for negative match patterns to match_grep.
+	For the cases when we want that some patterns do not appear in the
+	output.
+
+	* tests/init.sh (match_grep): Add rc and negated local variables; set
+	negated to 1 if pattern starts with "!", otherwise to 0; fail if negated
+	pattern has been matched.
+
+2020-04-09  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Post-release administrivia.
+	* NEWS: Add a header line for the next release.
+	* debian/changelog.in: Add a changelog entry for 5.6-1.
+	* strace.spec.in: Likewise.
+
+2020-04-07  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Prepare for 5.6 release.
+	* NEWS: Update for 5.6 release.
+
+	.mailmap: add more entries to avoid duplication in CREDITS.
+
+2020-04-07  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: cleanup temporary files left by read-write test executable.
+	This test executable is invoked by 19 tests, leaving about 100M
+	of data in temporary files.
+
+	In each of these tests read-write is invoked twice: the first time by
+	run_prog and the second time by run_strace.  Since the temporary file
+	created during the first invocation is used by strace during the second
+	invocation, this file can only be cleaned up at the end of the second
+	invocation.
+
+	* tests/read-write.c (main): If the temporary file was not created,
+	unlink it before the exit.
+
+2020-04-07  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: rewrite redirect.test without a busy loop.
+	* tests/redirect.test: Invoke $SLEEP_A_BIT while waiting
+	for synchronization with the tracer.
+
+2020-04-06  Dmitry V. Levin  <ldv@altlinux.org>
+
+	README.md: add github CI status badge.
+
+2020-04-06  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	strace: make -yy equivalent to --decode-fds=all.
+	With inclusion of device file and, later, pidfd decoding into -yy
+	semantics, it is clear that one cannot rely on stability of set
+	of file descriptor decoding features enabled by -yy.  State that
+	formally by aliasing -yy to --decode-fds=all.  Those who want only
+	specific FD decoding capabilities being enabled know that they need
+	it and can resort to --decode-fds=SET syntax.
+
+	* strace.1.in (.SS Output formatting): Change -yy alias
+	to --decode-fds=all, update the -yy option description.
+	* strace.c (usage): Likewise; expand --decode-fds description.
+	(init): Change yyflag_qual value to "all".
+
+2020-04-06  Dmitry V. Levin  <ldv@altlinux.org>
+
+	travis: remove build jobs covered by github actions.
+	* .travis.yml: Remove all bionic build jobs on x86_64, x86, and x32 except
+	the first one which is probably the fasted and is kept for reference.
+	Remove all gcc-8 and gcc-9 jobs since the corresponding repositories
+	are broken.
+
+2020-04-06  Dmitry V. Levin  <ldv@altlinux.org>
+
+	github: add CI action.
+	Somewhat similar to Travis CI, this runs "make distcheck" on Ubuntu
+	18.04 using gcc-9, gcc-7, clang-9, and clang-6 on x86_64, x86, and x32
+	architectures.
+
+	Compared with Travis CI, GitHub Actions service currently provides
+	a significantly better parallelism as well as (unsurprisingly)
+	better integration with github.
+
+	However, GitHub Actions cannot replace Travis CI completely as
+	the latter can build on aarch64, s390x, and ppc64le architectures.
+
+	* .github/workflows/source-code-check.yml: Remove.
+	* .github/workflows/ci.yml: New file.
+
+2020-04-06  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: fix poll-P.test.
+	All invocations of poll-P executable must have a properly created
+	descriptor 9.
+
+	* tests/poll-P.test: Fix run_prog invocations.
+
+	Fixes: v4.21~122 "tests: check path tracing of poll syscall"
+
+2020-04-06  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: remove poll-P and ppoll-P from pure_executables.list.
+	Since these executables have to be invoked in a special way,
+	it was not correct to include them into pure_executables.list.
+
+	* tests/pure_executables.list: Move poll-P and ppoll-P ...
+	* tests/Makefile.am (check_PROGRAMS): ... here.
+
+	Fixes: v4.21~122 "tests: check path tracing of poll syscall"
+	Fixes: v4.21~121 "tests: check path tracing of ppoll syscall"
+
+2020-04-06  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: workaround clang compilation warning.
+	Silence the following incorrect compilation warning produced by clang:
+
+	tests/io_uring_register.c:271:10: error: format specifies type 'unsigned short' but the argument has type 'int' [-Werror,-Wformat]
+	                        probe->ops[i].flags & (typeof(probe->ops[i].flags)) ~1,
+	                        ^~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+	* tests/io_uring_register.c (main): Cast the whole
+	struct io_uring_probe_op.flags based expression
+	to the type of the first operand.
+
+	Complements: v5.5-183-g8b6487f9a "tests: fix clang compilation warning"
+
+2020-04-05  Dmitry V. Levin  <ldv@altlinux.org>
+
+	travis: update coverage configuration.
+	* .travis.yml [$CHECK == coverage]: Change dist from trusty to bionic,
+	change the compiler from gcc to gcc-9, change STACKTRACE from libunwind
+	to libdw.
+	* ci/run-build-and-tests.sh [$CHECK == coverage] (GCOV): New variable,
+	pass its value to ./codecov.bash.
+
+2020-04-05  Dmitry V. Levin  <ldv@altlinux.org>
+
+	ci: workaround unusable codecov-python.
+	As codecov-python, starting with commit
+	v2.0.15-44-g9f50cca7e5c5e0bb5e2859db238da08e3195e105 released almost
+	a month ago, became an utterly unusable pile of garbage, switch to
+	codecov-bash that still works.
+
+	* ci/install-dependencies.sh [$CHECK == coverage]: Do not install
+	lcov, python-pip, python-setuptools, and codecov.  Download
+	https://codecov.io/bash and save it as codecov.bash.
+	* ci/run-build-and-tests.sh [$CHECK == coverage] (ac_cv_prog_LCOV,
+	ac_cv_prog_GENHTML): New variables, export them.
+	[[$CHECK == coverage]: Invoke codecov.bash instead of codecov.
+
+2020-04-05  Dmitry V. Levin  <ldv@altlinux.org>
+
+	ci: use twice as many cpus for tests.
+	Since many tests sleep a lot, running more of them in parallel
+	increases overall performance.
+
+	* ci/run-build-and-tests.sh (j2): New variable.
+	Use it instead of $j for "make check" and "make distcheck".
+
+2020-04-05  Dmitry V. Levin  <ldv@altlinux.org>
+
+	ci: use -Og instead of -O0 for coverage builds.
+	Also, do not apply this debugging optimization level to tests.
+
+	* ci/run-build-and-tests.sh [$CHECK == coverage] (CFLAGS,
+	CFLAGS_FOR_BUILD): Remove.
+	[$CHECK == coverage]: Specify CFLAGS='-g -Og' to "make all".
+
+2020-04-05  Dmitry V. Levin  <ldv@altlinux.org>
+
+	travis: switch from clang 7 to clang-9.
+	* .travis.yml (matrix): Switch all clang 7 builds to clang-9.
+
+2020-04-05  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	NEWS: mention libdw symbol-to-address cache introduction.
+	Complements: v5.5-178-g2101456 "unwind-libdw: add caching"
+
+2020-04-05  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: fix clang compilation warning.
+	Silence the following compilation warning produced by clang:
+
+	tests/io_uring_register.c:271:10: error: format specifies type 'unsigned short' but the argument has type 'int' [-Werror,-Wformat]
+	                        probe->ops[i].flags & ~1,
+	                        ^~~~~~~~~~~~~~~~~~~~~~~~
+
+	* tests/io_uring_register.c (main): Cast the second operand
+	of struct io_uring_probe_op.flags based expression to the type
+	of the first operand.
+
+2020-04-05  Paul Chaignon  <paul.chaignon@gmail.com>
+
+	bpf: support new commands BPF_MAP_*_BATCH.
+	* xlat/bpf_commands.in (BPF_MAP_LOOKUP_BATCH): New constant introduced
+	by Linux commit v5.6-rc1~151^2~46^2~23^2~7.
+	(BPF_MAP_LOOKUP_AND_DELETE_BATCH): New constant introduced by Linux
+	commit v5.6-rc1~151^2~46^2~23^2~4.
+	(BPF_MAP_UPDATE_BATCH, BPF_MAP_DELETE_BATCH): New constants introduced
+	by Linux commit v5.6-rc1~151^2~46^2~23^2~6.
+	* bpf.c (BEGIN_BPF_CMD_DECODER(BPF_MAP_LOOKUP_BATCH),
+	BEGIN_BPF_CMD_DECODER(BPF_MAP_UPDATE_BATCH),
+	BEGIN_BPF_CMD_DECODER(BPF_MAP_DELETE_BATCH)): Decode the new commands.
+	(decode_BPF_MAP_LOOKUP_AND_DELETE_BATCH): New macro.
+	(SYS_FUNC(bpf)): Decode the new commands.
+	* bpf_attr.h (BPF_MAP_LOOKUP_BATCH_struct,
+	BPF_MAP_LOOKUP_AND_DELETE_BATCH_struct, BPF_MAP_UPDATE_BATCH_struct,
+	BPF_MAP_DELETE_BATCH_struct): New structs introduced by Linux commit
+	v5.6-rc1~151^2~46^2~23^2~7.
+	(BPF_MAP_LOOKUP_BATCH_struct_size,
+	BPF_MAP_LOOKUP_AND_DELETE_BATCH_struct_size,
+	BPF_MAP_UPDATE_BATCH_struct_size, BPF_MAP_DELETE_BATCH_struct_size): New
+	macros.
+	* NEWS: Mention this.
+	* tests/bpf.c (BPF_MAP_LOOKUP_BATCH_checks, BPF_MAP_UPDATE_BATCH_checks,
+	BPF_MAP_DELETE_BATCH_checks): Tests for the new commands.
+
+2020-04-05  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	Print PIDs associated with pidfds.
+	* number_set.h (decode_fd_bits): Add DECODE_FD_PIDFD to enum.
+	* filter_qualify.c (decode_fd_str_to_uint) <decode_fd_strs>: Add pidfd
+	argument name and value.
+	* util.c (printpidfd): New function.
+	(printfd): Call printpidfd if DECODE_FD_PIDFD is set.
+	* strace.c (init) <yyflag_qual>: Add pidfd.
+	(usage): Document pidfd option argument.
+	* strace.1.in (.SS Output format): Likewise.
+	* tests/pidfd_getfd-yy.c: New file.
+	* tests/pidfd_open--decode-fd-pidfd.c: Likewise.
+	* tests/pidfd_open--decode-fd-socket.c: Likewise.
+	* tests/pidfd_open-yy.c: Likewise.
+	* tests/.gitignore: Add pidfd_getfd-yy, pidfd_open--decode-fd-pidfd,
+	pidfd_open--decode-fd-socket, and pidfd_open-yy.
+	* tests/pure_executables.list: Likewise.
+	* tests/gen_tests.in: Add pidfd_getfd-yy, pidfd_open--decode-fd-pidfd,
+	pidfd_open--decode-fd-socket, and pidfd_open-yy tests.
+	* tests/pidfd_getfd.c [!PRINT_PIDFD] (PRINT_PIDFD): New macro, define
+	to 0.
+	(main) [PRINT_PIDFD]: New variable pidfd_str, print expected pidfd
+	string to it.
+	(main) [!PRINT_PIDFD]: New variable pidfd_str, set it to PIDFD_PATH.
+	(main): Print pidfd_str instead of PIDFD_PATH.
+	* tests/pidfd_open.c (main) [PRINT_PIDFD]: Print pidfd using "<pid:%d>"
+	format.
+	* NEWS: Mention the change.
+
+2020-04-03  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Update copyright headers.
+	Headers updated automatically using maint/update_copyright_years.sh
+	script.
+
+2020-04-03  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Fix preprocessor indentation.
+	Indent the C preprocessor directives to reflect their nesting
+	using the following script:
+
+	$ cppi -l $(git grep -El '^[[:space:]]*#[[:space:]]*(if|ifdef|ifndef|elif|else|endif|define|pragma)[[:space:]]' |grep -v '\.sh$') |while read f; do
+		cppi < "$f" > "$f".cppi; mv "$f".cppi "$f"
+	done
+
+2020-04-03  Jann Horn  <jannh@google.com>
+
+	unwind-libdw: add caching.
+	libdw's address-to-symbol logic is quite slow. Since when stracing a
+	process, it is normal to see the same call sites over and over again,
+	let's address that by adding a straightforward N-way associative cache
+	in front of libdw.
+
+	The cache parameters could probably use some fine-tuning,
+	but ought to be good enough for now.
+
+	The resulting performance improvement:
+
+	$ time ./strace-orig -o /dev/null -k bash -c 'for i in {0..10000}; do echo; done' >/dev/null
+
+	real	0m12,014s
+	user	0m11,512s
+	sys	0m0,575s
+	$ time ./strace-cache -o /dev/null -k bash -c 'for i in {0..10000}; do echo; done' >/dev/null
+
+	real	0m0,765s
+	user	0m0,451s
+	sys	0m0,371s
+
+	Reviewed-By: Masatake YAMATO <yamato@redhat.com>
+
+	* unwind-libdw.c: Include "static_assert.h".
+	(STRACE_UW_CACHE_SIZE, STRACE_UW_CACHE_ASSOC): New macros.
+	(struct cache_entry): New type.
+	(struct ctx): Add "cache" field, extend the type of "last_proc_updating"
+	field.
+	(mapping_generation): Extend the type, initialize to 1.
+	(uwcache_clock): New variable.
+	(tcb_init): Initialize struct ctx.cache.
+	(truct frame_user_data): Add "ctx" field.
+	(find_bucket): New function.
+	(frame_callback): Use it.
+	(tcb_walk): Initialize user_data.ctx.
+
+2020-04-02  Dmitry V. Levin  <ldv@altlinux.org>
+
+	sparc, sparc64: wire up former vserver syscall.
+	... because Linux kernel arch/sparc/kernel/syscalls/syscall.tbl
+	still lists it.
+
+	* linux/sparc/syscallent.h [267]: Add vserver entry.
+	* linux/sparc64/syscallent.h [267]: Add vserver entry.
+
+2020-04-02  Dmitry V. Levin  <ldv@altlinux.org>
+
+	hppa: wire up kexec_file_load syscall.
+	... introduced on hppa by Linux kernel commit v5.4-rc1~188^2~3.
+
+	* linux/hppa/syscallent.h [355]: Add kexec_file_load entry.
+	* NEWS: Mention this.
+
+2020-04-02  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	hdio: implement HDIO_DRIVE_CMD ioctl command decoding.
+	* xlat/hdio_drive_cmds.in: New file.
+	* hdio.c: Include "xlat/hdio_drive_cmds.h".
+	(print_hdio_drive_cmd): New function.
+	(hdio_ioctl): Call print_hdio_drive_cmd if code is HDIO_DRIVE_CMD.
+	* tests/ioctl_hdio.c (main) <unsupp_cmds>: Remove HDIO_DRIVE_CMD.
+	(main): Add HDIO_DRIVE_CMD checks.
+
+	Closes: https://github.com/strace/strace/issues/83
+
+2020-04-02  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	hdio: factor out the HDIO_GETGEO handler into a separate function.
+	And update it up to the current coding style.
+
+	* hdio.c: Include "print_fields.h".
+	(print_hdio_getgeo): New function.
+	(hdio_ioctl) <case HDIO_GETGEO>: Call print_hdio_getgeo instead
+	of decoding in place.
+
+2020-04-02  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	tests: check decoding of HDIO_* ioctls.
+	* tests/.gitignore: Add ioctl_hdio, ioctl_hdio-success,
+	ioctl_hdio-success-Xabbrev, ioctl_hdio-success-Xraw,
+	ioctl_hdio-success-Xverbose, ioctl_hdio-success-v,
+	ioctl_hdio-success-v-Xabbrev, ioctl_hdio-success-v-Xraw,
+	ioctl_hdio-success-v-Xverbose, ioctl_hdio-Xabbrev,
+	ioctl_hdio-Xraw, ioctl_hdio-Xverbose, ioctl_hdio-v,
+	ioctl_hdio-v-Xabbrev, ioctl_hdio-v-Xraw, and ioctl_hdio-v-Xverbose.
+	* tests/Makefile.am (check_PROGRAMS): Add ioctl_hdio-success,
+	ioctl_hdio-success-Xabbrev, ioctl_hdio-success-Xraw,
+	ioctl_hdio-success-Xverbose, ioctl_hdio-success-v,
+	ioctl_hdio-success-v-Xabbrev, ioctl_hdio-success-v-Xraw,
+	and ioctl_hdio-success-v-Xverbose.
+	* tests/gen_tests.in (ioctl_hdio, ioctl_hdio-Xabbrev, ioctl_hdio-Xraw,
+	ioctl_hdio-Xverbose, ioctl_hdio-v, ioctl_hdio-v-Xabbrev,
+	ioctl_hdio-v-Xraw, ioctl_hdio-v-Xverbose, ioctl_hdio-success,
+	ioctl_hdio-success-Xabbrev, ioctl_hdio-success-Xraw,
+	ioctl_hdio-success-Xverbose, ioctl_hdio-success-v,
+	ioctl_hdio-success-v-Xabbrev, ioctl_hdio-success-v-Xraw,
+	ioctl_hdio-success-v-Xverbose): New tests.
+	* tests/ioctl_hdio.c: New file.
+	* tests/ioctl_hdio-Xabbrev.c: Likewise.
+	* tests/ioctl_hdio-Xraw.c: Likewise.
+	* tests/ioctl_hdio-Xverbose.c: Likewise.
+	* tests/ioctl_hdio-success.c: Likewise.
+	* tests/ioctl_hdio-success-Xabbrev.c: Likewise.
+	* tests/ioctl_hdio-success-Xraw.c: Likewise.
+	* tests/ioctl_hdio-success-Xverbose.c: Likewise.
+	* tests/ioctl_hdio-success-v.c: Likewise.
+	* tests/ioctl_hdio-success-v-Xabbrev.c: Likewise.
+	* tests/ioctl_hdio-success-v-Xraw.c: Likewise.
+	* tests/ioctl_hdio-success-v-Xverbose.c: Likewise.
+	* tests/ioctl_hdio-v.c: Likewise.
+	* tests/ioctl_hdio-v-Xabbrev.c: Likewise.
+	* tests/ioctl_hdio-v-Xraw.c: Likewise.
+	* tests/ioctl_hdio-v-Xverbose.c: Likewise.
+	* tests/pure_executables.list: Add ioctl_hdio, ioctl_hdio-Xabbrev,
+	ioctl_hdio-Xraw, ioctl_hdio-Xverbose, ioctl_hdio-v,
+	ioctl_hdio-v-Xabbrev, ioctl_hdio-v-Xraw, and ioctl_hdio-v-Xverbose.
+
+2020-04-02  Dmitry V. Levin  <ldv@altlinux.org>
+
+	linux/32: move wait4 and [gs]ettimeofday from syscallent.h to syscallent-time32.h
+	According to Linux kernel include/uapi/asm-generic/unistd.h, starting
+	with commit v5.1-rc1~160^2~1^2~3 __NR_wait4, __NR_gettimeofday, and
+	__NR_settimeofday are placed under __ARCH_WANT_TIME32_SYSCALLS and
+	therefore should belong to syscallent-time32.h along with other 32-bit
+	time_t based syscalls.
+
+	* linux/32/syscallent.h [169, 170, 260]: Move entries ...
+	* linux/32/syscallent-time32.h: ... here.
+	* time.c (SYS_FUNC(gettimeofday), SYS_FUNC(settimeofday)): Place under
+	[HAVE_ARCH_TIME32_SYSCALLS || HAVE_ARCH_OLD_TIME64_SYSCALLS] guard.
+	* wait.c (SYS_FUNC(wait4)): Likewise.
+
+	Complements: v5.5-39-gcc7e89011 "linux/32: Split 32-bit time_t based syscalls into a separate header"
+
+2020-04-02  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: fix another race condition in strace-DD.test.
+	Apparently, timeout(1) utility first sends its signal to the child
+	process, then installs a signal handler, and finally sends its signal to
+	the process group.  This creates a race between timeout(1) and strace,
+	the latter can manage to handle tracee syscall exit trap before a signal
+	to the process group is delivered.
+
+	* tests/setpgrp-exec.c: New file.
+	* tests/strace-DD.test: Rewrite without use of timeout(1).
+	* tests/strace-DD.expected: Remove.
+	* tests/Makefile.am (check_PROGRAMS): Add setpgrp-exec.
+	(EXTRA_DIST): Remove strace-DD.expected.
+
+	Fixes: v5.4~106 "tests: check -DD and -DDD options"
+
+2020-04-01  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: add a workaround for trace_creds test on mips o32.
+	Since every mips o32 executable used by trace_creds test invokes
+	prctl(PR_GET_FP_MODE) on their own and these calls are not filtered out
+	by %creds, they have to be filtered out manually before comparison.
+
+	* tests/init.sh (test_pure_prog_set) [$STRACE_ARCH == mips &&
+	$MIPS_ABI == o32 && $NAME == *creds]: Filter out prctl(PR_GET_FP_MODE)
+	from the strace log before comparison.
+
+2020-04-01  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Lift experimental status from --seccomp-bpf feature.
+	* strace.1.in (.SH OPTIONS) <--seccomp-bpf>: Remove " (experimental)".
+
+	strace.1: enhance --seccomp-bpf description.
+	* strace.1.in (.SH OPTIONS) <--seccomp-bpf>: Reword for clarity.
+
+2020-04-01  Dmitry V. Levin  <ldv@altlinux.org>
+
+	strace.1: fix --seccomp-bpf description.
+	* strace.1.in (.SH OPTIONS) <--seccomp-bpf>: Remove the claim that this
+	option implies -f, document that --seccomp-bpf has no effect unless
+	-f/--follow-forks is also specified.
+
+	Complements: v5.5-38-g2a7ba2a97 "strace: disable seccomp-bpf instead of enabling following forks"
+
+2020-04-01  Dmitry V. Levin  <ldv@altlinux.org>
+
+	ci: use kernel headers from Linux kernel v5.6.
+	When Linux kernel merge window opens, changes of all sorts start to pour
+	down, breaking UAPI in various ways.  This does not work for strace,
+	we need a stable UAPI.
+
+	* .gitlab-ci.yml (variables): Add KBRANCH.
+	* .travis.yml (env:global): Likewise.
+
+2020-03-31  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: fix get*id-creds tests on mips.
+	Apparently, mips executables may invoke prctl(PR_GET_FP_MODE) on their
+	own.  Since these calls are not filtered out by %creds, they have to be
+	dealt with before comparison.
+
+	* tests/getuid.test [$STRACE_ARCH == mips]: Filter out
+	prctl(PR_GET_FP_MODE) from the log of %creds tests.
+
+2020-03-31  Gleb Fotengauer-Malinovskiy  <glebfm@altlinux.org>
+
+	Update ioctl entries from linux v5.6.
+	* linux/32/ioctls_inc_align16.h: Update from linux v5.6
+	using ioctls_gen.sh.
+	* linux/32/ioctls_inc_align32.h: Likewise.
+	* linux/32/ioctls_inc_align64.h: Likewise.
+	* linux/64/ioctls_inc.h: Likewise.
+	* linux/x32/ioctls_inc0.h: Likewise.
+	* linux/s390/ioctls_arch0.h: Likewise.
+	* linux/s390x/ioctls_arch0.h: Likewise.
+	* NEWS: Mention this.
+
+	maint: update for linux v5.6.
+	* maint/ioctls_sym.sh: Add workarounds for media/v4l2-ioctl.h and
+	sound/pcm.h headers.
+
+2020-03-31  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	Update NEWS.
+
+2020-03-31  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: fix race condition in strace-D.test.
+	* tests/strace-D.test (test_parent_tracer_pid): Wait for the tracer
+	completion before checking its log.
+
+	Fixes: v5.4~110 "tests: check -D option"
+
+2020-03-31  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: fix race condition in strace-DDD.test.
+	* tests/tracer_ppid_pgid_sid.c (main): Print tracer pid.
+	* tests/strace-DDD.test: Check tracer pid, wait for the tracer
+	completion before checking its log.
+
+	Reported-by: Eugene Syromyatnikov <evgsyr@gmail.com>
+	Fixes: v5.4~106 "tests: check -DD and -DDD options"
+
+2020-03-31  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: fix race condition in strace-DD.test.
+	Apparently, $SLEEP_A_BIT might be insufficient for the tracer
+	to complete.
+
+	* tests/strace-DD.test: Find out the tracer pid and wait for the tracer
+	completion before checking its log.
+
+	Suggested-by: Eugene Syromyatnikov <evgsyr@gmail.com>
+	Fixes: v5.4~106 "tests: check -DD and -DDD options"
+
+2020-03-31  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: split getxxid test.
+	getxxid used to test alpha-specific getxgid, getxuid, and getxgid
+	syscalls.  Now each of these syscalls has its own test.
+	This hopefully fixes trace_creds test on alpha.
+
+	* tests/getxxid.c: Split into getxpid.c, getxuid.c, and getxgid.c.
+	* tests/gen_tests.in (getxxid): Remove.
+	(getxgid, getxpid, getxuid): New tests.
+	* tests/pure_executables.list: Replace getxxid with getxgid, getxpid,
+	and getxuid.
+	* tests/.gitignore: Likewise.
+
+2020-03-30  Dmitry V. Levin  <ldv@altlinux.org>
+
+	ia64: rename getpagesize syscall entry to old_getpagesize.
+	... to match the Linux kernel that introduced __NR_old_getpagesize
+	by commit v5.0-rc1~164^2~4.
+
+	* linux/ia64/syscallent.h [BASE_NR + 147]: Rename "getpagesize"
+	to "old_getpagesize".
+
+2020-03-30  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: disable umovestr_cached.test on mips o32 unless PTRACE_GET_SYSCALL_INFO works
+	If PTRACE_GET_SYSCALL_INFO does not work, then the test has to be
+	skipped on mips o32 because only the first four syscall arguments are
+	obtained from registers on that architecture, remaining syscall
+	arguments have to be fetched from the tracee memory.
+
+	* tests/umovestr_cached.test [$STRACE_ARCH == mips && $MIPS_ABI == o32]:
+	Skip the test if PTRACE_GET_SYSCALL_INFO does not work.
+
+2020-03-30  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: re-enable umovestr_cached.test on ia64 if PTRACE_GET_SYSCALL_INFO works
+	If PTRACE_GET_SYSCALL_INFO works, then the exception made for ia64
+	earlier is not relevant.
+
+	* tests/umovestr_cached.test [$STRACE_ARCH == ia64]: Do not skip
+	the test if PTRACE_GET_SYSCALL_INFO works.
+
+	Complements: v5.3~23 "tests: disable umovestr_cached.test on ia64"
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	Implement pidfd_getfd syscall decoding.
+	Introduced by Linux commit v5.6-rc1~122^2~4 and wired up in Linux commit
+	v5.6-rc1~122^2~3.
+
+	* pidfd_getfd.c: New file.
+	* Makefile.am (strace_SOURCES): Add it.
+	* linux/syscallent-common.h ([BASE_NR + 438]): Wire up pidfd_getfd.
+	* tests/pidfd_getfd.c: New file.
+	* tests/pidfd_getfd-y.c: Likewise.
+	* tests/.gitignore: Add pidfd_getfd and pidfd_getfd-y.
+	* tests/pure_executables.list: Likewise.
+	* tests/gen_tests.in: Add pidfd_getfd and pidfd_getfd-y tests.
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	Move printpidfd from kcmp.c to util.c.
+	And rename it to print_pid_fd in an attempt to minimise confusion with
+	the kernel's pidfd concept.
+
+	* kcmp (PRINT_FIELD_PIDFD, SYS_FUNC(kcmp)): Change printpidfd calls to
+	print_pid_fd.
+	(printpidfd): Move it...
+	* util.c (print_pid_fd): ...here. Drop the static qualifier, update
+	the comment describing why this is a stub.
+	* defs.h (print_pid_fd): New declaration.
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	open: implement openat2 syscall decoding.
+	Introduced by Linux commit v5.6-rc1~133^2~2.
+
+	* configure.ac (AC_CHECK_HEADERS): Check for linux/openat2.h.
+	* defs.h (print_numeric_umode_t_64): New declaration.
+	* linux/syscallent-common.h ([BASE_NR + 437]): Wire up openat2.
+	* types/openat2.h: New file.
+	* open.c: Include "print_fields.h", "types/openat2.h",
+	and "xlat/open_resolve_flags.h".
+	(sprint_open_modes64): Rename from sprint_open_modes, change argument
+	type to uint64_t.
+	(sprint_open_modes): New function, a wrapper for sprint_open_modes64
+	with argument type of unsigned int.
+	(tprint_open_modes64): Rename from tprint_open_modes, change argument
+	type to uint64_t, call sprint_open_modes64 instead of sprint_open_modes.
+	(tprint_open_modes): New function, a wrapper for tprint_open_modes64
+	with an argument of type unsigned int.
+	(print_open_how): New function.
+	(SYS_FUNC(openat2)): New decoder.
+	* printmode.c (print_numeric_umode_t_64): New function.
+	* tests/openat2.c: New file.
+	* tests/openat2-Xabbrev.c: Likewise.
+	* tests/openat2-Xraw.c: Likewise.
+	* tests/openat2-Xverbose.c: Likewise.
+	* tests/openat2-v.c: Likewise.
+	* tests/openat2-v-y.c: Likewise.
+	* tests/openat2-v-y-Xabbrev.c: Likewise.
+	* tests/openat2-v-y-Xraw.c: Likewise.
+	* tests/openat2-v-y-Xverbose.c: Likewise.
+	* tests/openat2-y.c: Likewise.
+	* tests/.gitignore: Add openat2, openat2-Xabbrev, openat2-Xraw,
+	openat2-Xverbose, openat2-v, openat2-v-y, openat2-v-y-Xabbrev,
+	openat2-v-y-Xraw, openat2-v-y-Xverbose, openat2-y.
+	* tests/pure_executables.list: Likewise.
+	* tests/gen_tests.in: Add openat2, openat2-Xabbrev, openat2-Xraw,
+	openat2-Xverbose, openat2-v, openat2-v-y, openat2-v-y-Xabbrev,
+	openat2-v-y-Xraw, openat2-v-y-Xverbose, openat2-y tests.
+	* xlat/open_resolve_flags.in: New file.
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	Move print_nonzero_bytes from clone.c to util.c.
+	As it is to be used elsewhere.
+
+	* clone.c (print_nonzero_bytes): Move it...
+	* util.c (print_nonzero_bytes): ...here.  Remove static qualifier.
+	* defs.h (print_nonzero_bytes): New declaration.
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	travis: remove ppc64le builds.
+	They are currently unusable, permanently failing with
+	"Disk quota exceeded" error diagnostics.
+
+	* .travis.yml (arch: ppc64le): Remove.
+
+2020-03-30  Dmitry V. Levin  <ldv@altlinux.org>
+
+	xtensa: switch to PTRACE_GETREGS API.
+	Implement PTRACE_GETREGS API introduced on xtensa by Linux kernel commit
+	v2.6.13-rc1~68^2~366.
+
+	* configure.ac [xtensa]: Remove arch_enable_Werror=no.
+	* linux/xtensa/get_syscall_result.c: Remove.
+	* Makefile.am (EXTRA_DIST): Remove it.
+	* linux/xtensa/arch_regs.c (xtensa_regs): New variable.
+	(ARCH_REGS_FOR_GETREGS, ARCH_PC_REG, ARCH_SP_REG): New macros.
+	(xtensa_a2, ARCH_PC_PEEK_ADDR, ARCH_SP_PEEK_ADDR): Remove.
+	* linux/xtensa/get_error.c (arch_get_error): Use xtensa_regs.a[2].
+	* linux/xtensa/get_syscall_args.c (arch_get_syscall_args): Use
+	xtensa_regs.a.
+	* linux/xtensa/set_error.c (arch_set_error, arch_set_success): Use
+	xtensa_regs.a[2].
+	* NEWS: Mention this change.
+
+2020-03-30  Dmitry V. Levin  <ldv@altlinux.org>
+
+	sh64: switch to PTRACE_GETREGS API.
+	Implement PTRACE_GETREGS API introduced on sh64 by Linux kernel commit
+	v2.6.28-rc1~99^2~56.
+
+	* configure.ac [sh64]: Remove arch_enable_Werror=no.
+	* linux/sh64/arch_regs.h: Remove.
+	* linux/sh64/get_syscall_result.c: Likewise.
+	* Makefile.am (EXTRA_DIST): Remove them.
+	* linux/sh64/arch_regs.c (sh64_regs): New variable.
+	(ARCH_REGS_FOR_GETREGS, ARCH_PC_REG, ARCH_SP_REG): New macros.
+	(sh64_r9, ARCH_PC_PEEK_ADDR, ARCH_SP_PEEK_ADDR): Remove.
+	* linux/sh64/get_error.c (arch_get_error): Use sh64_regs.regs[9].
+	* linux/sh64/get_scno.c (arch_get_scno): Use sh64_regs.regs[9].
+	* linux/sh64/get_syscall_args.c (arch_get_syscall_args): Use sh64_regs.regs.
+	* linux/sh64/set_error.c (arch_set_error, arch_set_success): Use
+	sh64_regs.gr[9].
+	* linux/sh64/set_scno.c (arch_set_scno): Use sh64_regs.regs[9].
+	* NEWS: Mention this change.
+
+2020-03-30  Dmitry V. Levin  <ldv@altlinux.org>
+
+	sh: switch to PTRACE_GETREGS API.
+	Implement PTRACE_GETREGS API introduced on sh by Linux kernel commit
+	v2.6.28-rc1~99^2~56.
+
+	* configure.ac [sh]: Remove arch_enable_Werror=no.
+	* linux/sh/get_syscall_result.c: Remove.
+	* Makefile.am (EXTRA_DIST): Remove it.
+	* linux/sh/arch_regs.c (sh_regs): New variable.
+	(ARCH_REGS_FOR_GETREGS, ARCH_PC_REG, ARCH_SP_REG): New macros.
+	(sh_r0, ARCH_PC_PEEK_ADDR, ARCH_SP_PEEK_ADDR): Remove.
+	* linux/sh/arch_getrval2.c (getrval2): Use sh_regs.regs[1].
+	* linux/sh/get_error.c (arch_get_error): Use sh_regs.regs[0].
+	* linux/sh/get_scno.c (arch_get_scno): Use sh_regs.regs[3].
+	* linux/sh/get_syscall_args.c (arch_get_syscall_args): Use sh_regs.regs.
+	* linux/sh/set_error.c (arch_set_error, arch_set_success): Use
+	sh_regs.gr[0].
+	* linux/sh/set_scno.c (arch_set_scno): Use sh_regs.regs[3].
+	* NEWS: Mention this change.
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	v4l2: use PRINT_FIELD_* macros, add abbreviating in print_v4l2_queryctrl
+	* v4l2.c (print_v4l2_queryctrl): Use PRINT_FIELD_XVAL for the type field
+	printing; use PRINT_FIELD_D for minimum, maximum, step, and
+	default_value fields printing; use PRINT_FIELD_FLAGS for the flags field
+	printing; print minimum, maximum, step, default_value, and flags fields
+	only if abbrev(tcp) is not set.
+	* tests/ioctl_v4l2-success.c: Update expected output.
+
+	Suggested-by: Philippe De Muyter <phdm@macqel.be>
+	References: https://github.com/strace/strace/issues/63
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	v4l2: simplify print_v4l2_queryctrl and use print_v4l2_cid.
+	Instead of fragile hacks aroung V4L2_CTRL_FLAG_NEXT_CTRL flag, (always)
+	save the id field on entering, restore it later on exiting, and print it
+	second time only if it has changed.  That also simplifies the flow
+	with clear entering/exiting code parts separation.
+
+	The usage of print_v4l2_cid for id field printing has introduced several
+	(anticipated) output formatting changes, hence the changes in expected
+	output.
+
+	* v4l2.c (print_v4l2_queryctrl): Save c.id on entering, print it using
+	print_v4l2_cid with next_flags set to true, and return 0; remove
+	"entering(tcp) || get_tcb_priv_ulong(tcp)" logic; restore the entering
+	id value  into entry_id variable on exiting, compare it to the exiting
+	c.id value and print c.id again if it is different; do not check if tcp
+	is exiting; always return RVAL_IOCTL_DECODED at the end of the function.
+	* tests/ioctl_v4l2.c: Update expected output.
+	* tests/ioctl_v4l2-success.c: Likewise.
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	v4l2: add support for V4L2_CTRL_FLAG_NEXT_* flags printing to print_v4l2_cid
+	* v4l2.c: Move "xlat/v4l2_control_query_flags.h" inclusion before
+	print_v4l2_cid.
+	(print_v4l2_cid): Remove const qualifier from cid, add bool next_flags
+	argument; print v4l2_control_query_flags and NAND them from cid if they
+	are present.
+	(print_v4l2_control): Pass false as next_flags to the print_v4l2_cid
+	call.
+
+	References: https://github.com/strace/strace/issues/63
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	xlat: add generation of flags-related fields.
+	Generate known flags mask and maximum string length.
+
+	* xlat.h (struct xlat): Add fields flags_strsz and flags_mask.
+	* xlat/gen.sh (print_xlat, print_xlat_pair): Add generation of
+	XLAT_VAL_n and XLAT_STR_n macros.
+	(gen_header): Generate flags_strsz and flags_mask fields' values using
+	the generated XLAT_VAL_n and XLAT_STR_n macros, undefine them
+	afterwards.
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	v4l2: handle -Xraw in print_v4l2_cid.
+	Print class ID as simple hex value in that case.
+
+	* v4l2.c (print_v4l2_cid): Print cid as hex and return if
+	xlat_verbose(xlat_verbosity) == XLAT_STYLE_RAW.
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	v4l2: use xsprintf instead of asprintf in print_v4l2_cid.
+	Avoid an allocation and steamline code a bit.
+
+	* v4l2.c (print_v4l2_cid): Change tmp_str to a stack-allocated char array,
+	print to it with xsprintf, eliminate no longer needed free() call.
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	v4l2: provide V4L2_CTRL_FLAG_NEXT_CTRL in an xlat.
+	* xlat/v4l2_control_query_flags.in: New file.
+	* v4l2.c: Include "xlat/v4l2_control_query_flags.h".
+	(print_v4l2_queryctrl): Remove "ifdef V4L2_CTRL_FLAG_NEXT_CTRL" guard.
+	* tests/ioctl_v4l2.c [!V4L2_CTRL_FLAG_NEXT_CTRL]
+	(V4L2_CTRL_FLAG_NEXT_CTRL): New macro.
+	(main) [!V4L2_CTRL_FLAG_NEXT_CTRL]: Remove.
+
+	References: https://bugzilla.redhat.com/show_bug.cgi?id=1758201
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	v4l2: decode frame intervals/sizes unconditionally.
+	* configure.ac (AC_CHECK_TYPES): Check for struct v4l2_frmsizeenum
+	and struct v4l2_frmivalenum.
+	* types/v4l2.h (struct_v4l2_frmsize_discrete, struct_v4l2_frmsize_stepwise,
+	struct_v4l2_frmsizeenum, struct_v4l2_frmival_stepwise,
+	struct_v4l2_frmivalenum): New type definitions.
+	v4l2.c: Remove "ifdef VIDIOC_ENUM_FRAMESIZES" guards.
+	* xlat/v4l2_ioctl_cmds.in (VIDIOC_ENUM_FRAMESIZES,
+	VIDIOC_ENUM_FRAMEINTERVALS): Uncomment.
+
+	References: https://bugzilla.redhat.com/show_bug.cgi?id=1758201
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	v4l2: always decode VIDIOC_*_EXT_CTRLS ioctl commands.
+	* types/v4l2.h (struct_v4l2_area, struct_v4l2_ext_control,
+	struct_v4l2_ext_controls): New type definitions.
+	* v4l2.c (print_v4l2_ext_control, print_v4l2_ext_controls): Do not guard
+	with VIDIOC_S_EXT_CTRLS anymore.
+	(v4l2_ioctl) <case VIDIOC_S_EXT_CTRLS, case VIDIOC_TRY_EXT_CTRLS, case
+	VIDIOC_G_EXT_CTRLS>: Likewise.
+	(print_v4l2_ext_control): Do not guard size and string field printing
+	with HAVE_STRUCT_V4L2_EXT_CONTROL_STRING.
+	* xlat/v4l2_ioctl_cmds.in (VIDIOC_G_EXT_CTRLS, VIDIOC_S_EXT_CTRLS,
+	VIDIOC_TRY_EXT_CTRLS): Uncomment.
+
+	References: https://bugzilla.redhat.com/show_bug.cgi?id=1758201
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	v4l2: bundle struct v4l2_format and related types.
+	* configure.ac (AC_CHECK_TYPES): Check for struct v4l2_meta_format,
+	struct v4l2_pix_format_mplane, struct v4l2_plane_pix_format,
+	and struct v4l2_sdr_format.
+	* types/v4l2.h (struct_v4l2_clip, struct_v4l2_format): Typedef to an anonymous
+	type definition.
+	(struct_v4l2_pix_format, struct_v4l2_plane_pix_format,
+	struct_v4l2_pix_format_mplane, struct_v4l2_window,
+	struct_v4l2_vbi_format, struct_v4l2_sliced_vbi_format,
+	struct_v4l2_sliced_vbi_cap, struct_v4l2_sdr_format,
+	struct_v4l2_meta_format): New typedefs.
+	* v4l2.c (print_v4l2_format_fmt): Remove guard macros, decode
+	fmt.win.global_alpha and fmt.sdr.buffersize only when they are non-zero.
+
+	References: https://bugzilla.redhat.com/show_bug.cgi?id=1758201
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	v4l2: provide struct v4l2_capability definition.
+	* types/v4l2.h (struct_v4l2_capability): New typedef.
+	* v4l2.c: Check struct v4l2_capability
+	with CHECK_V4L2_STRUCT_RESERVED_SIZE.
+	(print_v4l2_capability): Change type of caps variable
+	to struct_v4l2_capability; drop HAVE_STRUCT_V4L2_CAPABILITY_DEVICE_CAPS
+	guard; print device_caps field only if it's non-zero.
+
+	References: https://bugzilla.redhat.com/show_bug.cgi?id=1758201
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	v4l2: bundle struct v4l2_create_buffers definition.
+	* configure.ac (AC_CHECK_TYPES): Add a check for
+	struct v4l2_create_buffers definition.
+	* types/v4l2.h: New file.
+	* v4l2.c (DEF_MPERS_TYPE(struct_v4l2_create_buffers)): Remove
+	VIDIOC_CREATE_BUFS guard.
+	(struct_v4l2_create_buffers): Remove typedef.
+	(struct_v4l2_buffer, struct_v4l2_clip, struct_v4l2_ext_control,
+	struct_v4l2_ext_controls, struct_v4l2_format, struct_v4l2_framebuffer,
+	struct_v4l2_input, struct_v4l2_standard): Move to types/v4l2.h.
+	[HAVE_STRUCT_V4L2_CREATE_BUFFERS]: Check struct v4l2_create_buffers
+	with CHECK_V4L2_STRUCT_RESERVED_SIZE.
+	* xlat/v4l2_ioctl_cmds.in (VIDIOC_CREATE_BUFS): Uncomment.
+
+	References: https://bugzilla.redhat.com/show_bug.cgi?id=1758201
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	v4l2: add V4L2 ioctl command constant macros.
+	For now, only those that we support, and only for those we don't
+	conditionalise in code, since the fall-back definitions require
+	the relevant type definitions, and not all of them are always
+	available.
+
+	* xlat/v4l2_ioctl_cmds.in: New file.
+	* v4l2.c: Include "xlat/v4l2_ioctl_cmds.h" under XLAT_MACRO_ONLY
+	definition.
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	v4l2: add shorthand macros for v4l2 type checks.
+	Some wrappers for common static_assert checks.
+
+	* v4l2.c (CHECK_V4L2_STRUCT_SIZE, CHECK_V4L2_RESERVED_SIZE.
+	CHECK_V4L2_STRUCT_RESERVED_SIZE): New macros.
+
+	References: https://bugzilla.redhat.com/show_bug.cgi?id=1758201
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	v4l2: improve buffer flag decoding.
+	* xlat/v4l2_buf_flags.in: Add fallback values.
+	* xlat/v4l2_buf_flags_masks.in: New file.
+	* xlat/v4l2_buf_flags_ts_src.in: Likewise.
+	* xlat/v4l2_buf_flags_ts_type.in: Likewise.
+	* v4l2.c: Include xlat/v4l2_buf_flags_ts_type.h,
+	xlat/v4l2_buf_flags_ts_src.h, xlat/v4l2_buf_flags_masks.h.
+	(print_v4l2_buffer_flags): New function.
+	(print_v4l2_buffer): Call print_v4l2_buffer_flags for printing flags field.
+	* tests/ioctl_v4l2-success.c: Update expected output.
+
+	References: https://github.com/strace/strace/issues/63
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	v4l2: use standard kernel version printing routine.
+	The way kernel version is printed in print_v4l2_capability was
+	non-standard, didn't respect xlat styles, and was incorrect for major
+	values 256 and greater.  Moreover, there is a routine that exists
+	specifically for this purpose now.  Let's use it and solve all
+	the aforementioned issues.
+
+	* v4l2.c (print_v4l2_capability): Use print_kernel_version for the
+	kernel version printing.
+	* tests/ioctl_v4l2-success.c: Update the expected output.
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	tests: add v4l2 ioctl success injection-based tests.
+	* tests/ioctl_v4l2-success.c: New file.
+	* tests/ioctl_v4l2-success-Xabbrev.c: Likewise.
+	* tests/ioctl_v4l2-success-Xraw.c: Likewise.
+	* tests/ioctl_v4l2-success-Xverbose.c: Likewise.
+	* tests/ioctl_v4l2-success-v.c: Likewise.
+	* tests/ioctl_v4l2-success-v-Xabbrev.c: Likewise.
+	* tests/ioctl_v4l2-success-v-Xraw.c: Likewise.
+	* tests/ioctl_v4l2-success-v-Xverbose.c: Likewise.
+	* tests/.gitignore: Add ioctl_v4l2-success,
+	ioctl_v4l2-success-Xabbrev, ioctl_v4l2-success-Xraw,
+	ioctl_v4l2-success-Xverbose, ioctl_v4l2-success-v,
+	ioctl_v4l2-success-v-Xabbrev, ioctl_v4l2-success-v-Xraw,
+	ioctl_v4l2-success-v-Xverbose.
+	* tests/Makefile.am (check_PROGRAMS): Likewise.
+	* tests/gen_tests.in: Add ioctl_v4l2-success,
+	ioctl_v4l2-success-Xabbrev, ioctl_v4l2-success-Xraw,
+	ioctl_v4l2-success-Xverbose, ioctl_v4l2-success-v,
+	ioctl_v4l2-success-v-Xabbrev, ioctl_v4l2-success-v-Xraw tests,
+	* tests/tests.h (struct strval32): New type, similar to struct strval64.
+
+	tests: use ioctl-success.sh for ioctl_perf-success test.
+	* tests/ioctl_perf-success.test: Remove.
+	* tests/Makefile.am (DECODER_TESTS): Remove it.
+	* tests/gen_tests.in: Add ioctl_perf-success test.
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	tests: always check ioctl_perf-success.
+	It makes little sense to conditionalise this test, since it bundles
+	all the required definitions and types in case of absense of them
+	in the kernel headers.
+
+	* tests/ioctl_perf-success.c: Remove HAVE_LINUX_PERF_EVENT_H guard,
+	update directives' indentation.
+	(include <linux/perf_event.h>): Put under HAVE_LINUX_PERF_EVENT_H guard.
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	tests: add a runner for ioctl decoder tests that use success injection.
+	* tests/ioctl-success.sh: New file.
+	* tests/Makefile.am (EXTRA_DIST): Add it.
+
+	v4l2: print capability and rxsubchans fields of struct v4l2_tuner as flags
+	* v4l2.c (print_v4l2_tuner): Use printflags instead of printxval
+	for printing capability and rxsubchans fields of struct v4l2_tuner.
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	v4l2: comment unknown tuner types with "V4L2_TUNER_???" and not "V4L2_TUNER_TYPE_???"
+	All the xlat constants include only "V4L2_TUNER_" part.
+
+	* v4l2.c (print_v4l2_tuner) <printxval(v4l2_tuner_types, ...)>: Change
+	the last argument from V4L2_TUNER_TYPE_???" to "V4L2_TUNER_???"
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	v4l2: do not print struct v4l2_control.value field name second time on exiting
+	To conform the output formatting in other places.
+
+	* v4l2.c (print_v4l2_control): Do not print "value=" on exiting to
+	prefix the changed value.
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	v4l2: print exiting structure fields as a separate structure.
+	To conform with the output formatting in other places.
+
+	* v4l2.c (print_v4l2_format, print_v4l2_streamparm): Close the structure
+	with "}" before the arrow and open it again with "{".
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	v4l2: print struct v4l2_standard.framelines as unsigned.
+	Since it is defined that way.
+
+	* v4l2.c (print_v4l2_standard): Print framelines as unsigned.
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	v4l2: print struct v4l2_outputparm.outputmode using v4l2_capture_modes flags
+	As it is treated the same way as struct v4l2_captureparm.capturemode.
+
+	* v4l2.c (print_v4l2_streamparm): Print struct
+	v4l2_outputparm.outputmode using v4l2_capture_modes flags.
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	v4l2: print struct v4l2_{capture,output}parm.extendedmode as hex.
+	As it is likely to be treated similarly to capturemode/outputmode, which
+	are bit sets.
+
+	* v4l2.c (print_v4l2_streamparm): Print extendedmode field as hex.
+	* tests/ioctl_v4l2.c: Update expected output.
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	tests/fill_memory: add 16-bit-wide and 32-bit-wide memory-filling routines
+	* tests/tests.h (fill_memory16_ex, fill_memory16, fill_memory32_ex,
+	fill_memory32): New declarations.
+	* tests/fill_memory.c (fill_memory16_ex, fill_memory16,
+	fill_memory32_ex, fill_memory32): New functions.
+
+	tests: move struct strval64 definition to tests.h.
+	* tests/fanotify_mark.c (struct strval64): Move it...
+	* tests/tests.h: ...here. Include <stdint.h>.
+
+	v4l2: remove spaces around "=" in struct v4l2_buffer.timestamp output.
+	* v4l2.c (print_v4l2_buffer): Remove spaces around equality sign
+	in ", timestamp = ".
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	v4l2: print struct v4l2_vbi_format.flags as flags.
+	Since V4L2_VBI_UNSYNC and V4L2_VBI_INTERLACED are treated as independent
+	bits in code.
+
+	* v4l2.c (print_v4l2_format_fmt): Use printflags instead of printxval
+	for f->fmt.vbi.flags printing.
+
+	Fixes: v4.17~103 "v4l2: Implement decoding of the remaining V4L2_BUF_TYPE_* types"
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	v4l2: print struct v4l2_vbi_format.start elements as signed integers.
+	Since they are defined in videodev2.h that way.
+
+	* v4l2.c (dprint_ioctl_v4l2): Print struct v4l2_vbi_format.start
+	elements using %d and not %u.
+	* tests/ioctl_v4l2.c (print_v4l2_format_fmt): Likewise.
+
+	Fixes: v4.17~103 "v4l2: Implement decoding of the remaining V4L2_BUF_TYPE_* types"
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	tests/ioctl_v4l2: add checks for decoding unknown/unsupported commands.
+	* tests/ioctl_v4l2.c: Include <stdint.h>.
+	(main): Add checks for decoding of unknown and unsupported ioctl
+	commands that have 'V' command type.
+
+2020-03-30  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	ioctl: re-define broken _IOC_SIZE on sparc.
+	_IOC_SIZE macro definition on sparc breaks the invariant
+
+	     _IOC_SIZE(_IOC(dir, type, nr, size)) == size
+
+	for _IOC_DIR(val) that contains neither _IOC_READ nor _IOC_WRITE,
+	so it is unsuitable for strace's purposes. Re-define it in a way
+	that preserves the aforementioned invariant.
+
+	* ioctl.c [SPARC || SPARC64] (_IOC_SIZE): Re-define.
+
+2020-03-29  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	v4l2: short-circuit handling of unknown buffer types.
+	We do not need to call print_v4l2_format_fmt on exiting to get empty
+	output again.
+
+	* v4l2.c (print_v4l2_format_fmt): Add a default branch that returns
+	false.
+
+2020-03-29  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	tests/ioctl_v4l2: increase coverage a bit.
+	Try to hit some previously missed branches.
+
+	* tests/ioctl_v4l2.c (init_v4l2_format): Set num_planes to 1 if buffer
+	type is V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE; set clipcount to 3 if
+	buffer type is V4L2_BUF_TYPE_VIDEO_OVERLAY.
+	(dprint_ioctl_v4l2): Update expected output.
+
+2020-03-29  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	xlat: add KEY_SELECTIVE_SCREENSHOT to evdev_keycode.
+	* xlat/evdev_keycode.in (KEY_SELECTIVE_SCREENSHOT): New constant,
+	introduced by Linux commit v5.5-rc5-51-g3b059da9835c and updated
+	in Linux commit v5.5-rc5-55-gfbf66796a0ae.
+
+2020-03-29  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	debian/control: remove ppc64el from gcc-multilib architectures.
+	Little-endian POWER ISA has no 32-bit compat on Linux (and strace has
+	no mpers support on ppc64le), so gcc-multilib package is not needed
+	there.
+
+	* debian/control (Build-Depends): Remove ppc64el from the list
+	of gcc-multilib architectures.
+
+	Suggested-by: Dmitry V. Levin <ldv@altlinux.org>
+	Fixes: v4.23~364 "debian: enable mpers support for ppc64el and s390x"
+
+2020-03-29  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	strace: warn about -S option uselessness in absence of -c/-C.
+	* strace.c (init): Add sortby_set local variable.
+	(init) <case 'S'>: Set sortby_set to true.
+	(init): Warn if sortby_set is set and cflag is not.
+	* tests/options-syntax.test: Add a check.
+
+2020-03-28  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	io_uring: add support for IORING_{UN,}REGISTER_PERSONALITY commands.
+	Introduced by Linux commit v5.6-rc1~123^2~5.
+
+	* xlat/uring_register_opcodes.in (IORING_REGISTER_PERSONALITY,
+	IORING_UNREGISTER_PERSONALITY): New constants.
+	* tests/io_uring_register.c: Update expected output.
+
+2020-03-28  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	io_uring: support IORING_REGISTER_PROBE io_uring_register command.
+	Introduced by Linux commit v5.6-rc1~123^2~22.
+
+	* xlat/uring_op_flags.in: New file.
+	* xlat/uring_ops.in: Likewise.
+	* xlat/uring_register_opcodes.in (IORING_REGISTER_PROBE): New constant.
+	* types/io_uring.h (struct_io_uring_probe_op, struct_io_uring_probe):
+	New type definitions.
+	* io_uring.c: Include "xlat/uring_op_flags.h", "xlat/uring_ops.h".
+	(print_io_uring_probe_op, print_io_uring_probe): New functions.
+	(SYS_FUNC(io_uring_register)): Add rc variable; print fd and opcode
+	on entering only, call print_io_uring_probe if opcode
+	is IORING_REGISTER_PROBE; print nargs if rc is non-zero or if it is
+	exiting; return rc in the end.
+	* tests/io_uring_register.c [HAVE_STRUCT_IO_URING_PROBE]: Add checks.
+
+2020-03-28  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	io_uring: de-indent some code in io_uring_setup decoder.
+	* io_uring.c (SYS_FUNC(io_uring_setup)): De-indent code in the exiting
+	path.
+
+2020-03-28  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Fix various typos found using codespell tool.
+	* NEWS: Replace "Enchanced" with "Enhanced".
+	* list.h: Replace "embedded withing" with "embedded within".
+	* maint/gen-contributors-list.sh: Replace "contributer"
+	with "contributor".
+	* tests/futex.c: Replace "succeedes" with "succeeds".
+	* tests/nsyscalls-d.test: Replace "debug ouput" with "debug output".
+	* tests/s390_sthyi.c: Replace "descriptior" with "descriptor".
+
+2020-03-28  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: fix strace-DDD.test for the case when strace has a process subreaper
+	The test used to assume that the process reaper has pid 1, which is not
+	necessarily the case, e.g. there might be a process subreaper different
+	from pid 1.
+
+	* tests/get_process_reaper.c: New file.
+	* tests/Makefile.am (check_PROGRAMS): Add get_process_reaper.
+	* tests/.gitignore: Likewise.
+	* tests/strace-DDD.test: Invoke get_process_reaper to find out
+	the process reaper id, use the latter in subsequent checks
+	instead of pid 1.
+
+	References: https://bugs.debian.org/947396
+	Resolves: https://github.com/strace/strace/issues/129
+
+2020-03-28  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	tests/ioctl_v4l2.c: whitespace fix.
+
+2020-03-28  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	tests: add ARG_XLAT_KNOWN and ARG_XLAT_UNKNOWN macros.
+	An amalgam of ARG_STR and XLAT_KNOWN/XLAT_UNKNOWN.
+
+	* tests/tests.h (ARG_XLAT_KNOWN, ARG_XLAT_UNKNOWN): New macros.
+
+2020-03-28  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	tests: add v4l2 ioctl -v tests.
+	* tests/ioctl_v4l2-v.c: New file.
+	* tests/ioctl_v4l2-v-Xabbrev.c: Likewise.
+	* tests/ioctl_v4l2-v-Xraw.c: Likewise.
+	* tests/ioctl_v4l2-v-Xverbose.c: Likewise.
+	* tests/.gitignore: Add ioctl_v4l2-v, ioctl_v4l2-v-Xabbrev,
+	ioctl_v4l2-v-Xraw, ioctl_v4l2-v-Xverbose.
+	* tests/pure_executables.list: Likewise.
+	* tests/gen_tests.in (ioctl_v4l2-v, ioctl_v4l2-v-Xabbrev,
+	ioctl_v4l2-v-Xraw, ioctl_v4l2-v-Xverbose): New tests.
+
+	v4l2: do not fancy-print fourcc if -Xraw is set.
+	* v4l2.c (print_pixelformat): Print fourcc as a hexadecimal value and
+	return.
+	* tests/ioctl_v4l2.c (dprint_ioctl_v4l2, main): Update expected output.
+
+	tests: add ioctl_v4l2 xlat style tests.
+	* tests/ioctl_v4l2-Xabbrev.c: New file.
+	* tests/ioctl_v4l2-Xraw.c: Likewise.
+	* tests/ioctl_v4l2-Xverbose.c: Likewise.
+	* tests/.gitignore: Add ioctl_v4l2-Xabbrev, ioctl_v4l2-Xraw,
+	ioctl_v4l2-Xverbose.
+	* tests/pure_executables.list: Likewise.
+	* tests/gen_tests.in (ioctl_v4l2-Xabbrev, ioctl_v4l2-Xraw,
+	ioctl_v4l2-Xverbose): New tests.
+	* tests/tests.h: (XLAT_SEL, ABBR, RAW, VERB, NABBR, NRAW, NVERB): New
+	macros.
+	* tests/ioctl_v4l2.c (dprint_ioctl_v4l2): Change request
+	to XLAT_SEL(reqval, reqstr); use XLAT_SEL(buf_type, buf_type_string)
+	in printed strings.
+	(print_ioctl_v4l2): Pass XLAT_SEL(request, #request) instead of the
+	second argument.
+	(main): Update expected output.
+
+2020-03-28  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	tests: move XLAT_FMT and XLAT_ARGS macros from sock_filter-v.c to tests.h
+	In preparation of using elsewhere.
+
+	* tests/sock_filter-v.c (XLAT_FMT, XLAT_ARGS): Move ...
+	* tests/tests.h: ... here, replacing HEX_FMT with "%#x".
+
+2020-03-27  Dmitry V. Levin  <ldv@altlinux.org>
+
+	hppa: switch to PTRACE_GETREGS API.
+	Implement PTRACE_GETREGS API introduced on hppa by Linux kernel commit
+	v4.7-rc1~58^2~10.
+
+	* configure.ac [hppa]: Remove arch_enable_Werror=no.
+	* linux/hppa/get_syscall_result.c: Remove.
+	* Makefile.am (EXTRA_DIST): Remove it.
+	* linux/hppa/arch_regs.c (hppa_regs): New variable.
+	(ARCH_REGS_FOR_GETREGS, ARCH_PC_REG, ARCH_SP_REG): New macros.
+	(hppa_r28, PT_GR20, PT_GR28, ARCH_PC_PEEK_ADDR, ARCH_SP_PEEK_ADDR):
+	Remove.
+	* linux/hppa/get_error.c (arch_get_error): Use hppa_regs.gr[28].
+	* linux/hppa/get_scno.c (arch_get_scno): Use hppa_regs.gr[20].
+	* linux/hppa/get_syscall_args.c (arch_get_syscall_args): Use
+	hppa_regs.gr.
+	* linux/hppa/set_error.c (arch_set_error, arch_set_success): Use
+	hppa_regs.gr[28].
+	* linux/hppa/set_scno.c (arch_set_scno): Use hppa_regs.gr[20].
+	* NEWS: Mention this change.
+
+2020-03-26  Dmitry V. Levin  <ldv@altlinux.org>
+
+	build: enable compiler -Werror option by default.
+	If gcc is 4.8+ or clang is 6.0+, and the architecture implements either
+	PTRACE_GETREGS or PTRACE_GETREGSET, enable compiler -Werror option
+	by default.
+
+	* configure.ac: Call st_WARN_CFLAGS and AX_PROG_CC_FOR_BUILD after
+	architecture checks.
+	(arch_enable_Werror): New variable, defined to "yes" on all architectures
+	except alpha, bfin, hppa, microblaze, sh, sh64, and xtensa.
+	* m4/st_warn_cflags.m4 (st_cv_cc_enable_Werror, st_cv_enable_Werror):
+	Compute new cached variables.
+	(AC_ARG_ENABLE(gcc-Werror)): Default to $st_cv_enable_Werror
+	if no option was given, do not add -Werror to WARN_CFLAGS.
+	[enable_gcc_Werror == yes]: Add -Werror to WARN_CFLAGS.
+	* m4/ax_prog_cc_for_build.m4 (AX_PROG_CC_FOR_BUILD): Redirect
+	st_cv_enable_Werror and st_cv_cc_enable_Werror using pushdef/popdef.
+	* ci/run-build-and-tests.sh (DISTCHECK_CONFIGURE_FLAGS): Add
+	--enable-gcc-Werror unconditionally.
+
+2020-03-26  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: workaround clang compilation warnings.
+	Silence the following incorrect compilation warnings produced by clang:
+
+	tests/filter_seccomp-flag.c:39:28: warning: variable 'sysent1' is not needed and will not be emitted [-Wunneeded-internal-declaration]
+	static const struct_sysent sysent1[] = {
+	tests/filter_seccomp-flag.c:45:28: warning: variable 'sysent2' is not needed and will not be emitted [-Wunneeded-internal-declaration]
+	static const struct_sysent sysent2[] = {
+
+	* tests/filter_seccomp-flag.c (sysent1, sysent2): Remove static
+	qualifier.
+
+2020-03-26  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: fix musl compilation warnings.
+	Silence the following types of compilation warnings generated by gcc
+	with musl system headers:
+
+	tests/net-sockaddr.c: In function 'check_x25':
+	tests/net-sockaddr.c:430:19: warning: passing argument 2 of 'connect' from incompatible pointer type [-Wincompatible-pointer-types]
+	  rc = connect(-1, x25, sizeof(c_x25) - 1);
+	                   ^~~
+	In file included from tests/net-sockaddr.c:16:0:
+	/opt/musl/include/sys/socket.h:332:5: note: expected 'const struct sockaddr *' but argument is of type 'struct sockaddr_x25 *'
+	 int connect (int, const struct sockaddr *, socklen_t);
+	     ^~~~~~~
+
+	tests/so_error.c: In function 'reserve_ephemeral_port':
+	tests/so_error.c:40:16: warning: passing argument 2 of 'bind' from incompatible pointer type [-Wincompatible-pointer-types]
+	   if (bind(sd, &addr, sizeof(addr)) == 0)
+	                ^
+	In file included from /opt/musl/include/netinet/in.h:10:0,
+	                 from tests/so_error.c:14:
+	/opt/musl/include/sys/socket.h:331:5: note: expected 'const struct sockaddr *' but argument is of type 'struct sockaddr_in *'
+	 int bind (int, const struct sockaddr *, socklen_t);
+	     ^~~~
+
+	* tests/net-sockaddr.c (check_x25): Pass a pointer of type 'void *' as
+	the second argument of connect() call.
+	* tests/so_error.c (main): Likewise.
+	(reserve_ephemeral_port): Pass a pointer of type 'void *' as the second
+	argument of bind() call.
+
+2020-03-23  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	count: store average time as struct timespec.
+	* count.c (struct call_counts): Change the type of time_avg field
+	to struct timespec, all users updated.
+
+	util: change the integer type in ts_mul and ts_div to uint64_t.
+	* defs.h (ts_mul, ts_div): Change the type of the last argument
+	to uint64_t.
+	* util.c (ts_mul, ts_div): Likewise.
+
+2020-03-23  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	count: use dashes in option argument names.
+	Dashes are more common among long optiona arguments, so let's support
+	(and prefer) them.
+
+	* count.c (column_aliases): Add variants with dashes for aliases with
+	underscores.
+	* strace.1.in (.SS Statistics): Use dashes in column names in -S and -U
+	option descriptions.
+	* strace.c (usage): Likewise.
+	* tests/options-syntax.test: Add checks.
+	* tests/strace-S.test: Use dashes in some column names.
+
+2020-03-23  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	count: add information about minimum and maximum call duration.
+	* count.c (struct call_counts): Add time_min, time_max fields.
+	(max_ts): New constant.
+	(enum count_summary_columns): Add CSC_TIME_MIN, CSC_TIME_MAX.
+	(count_syscall): Fill time_min field with max_ts in counts
+	initialisation, update time_min and time_max.
+	(min_time_cmp, max_time_cmp): New functions.
+	(set_sortby): Add keys for them.
+	(set_count_summary_columns): Add support for time_min and time_max
+	fields printing.
+	* strace.1.in (.SH OPTIONS) <-S, -U>: Document it.
+	* strace.c (usage): Likewise.
+	* tests/strace-S.test: Add checks.
+	* tests/options-syntax.test: Likewise.
+
+	Closes: https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=240945
+	Closes: https://github.com/strace/strace/issues/32
+
+2020-03-23  Eugene Syromyatnikov  <evgsyr@gmail.com>
+	    Dmitry V. Levin  <ldv@altlinux.org>
+
+	count: add ability to select columns being shown.
+	* count.c (set_count_summary_columns): New function.
+	* defs.h (set_count_summary_columns): New declaration.
+	* strace.c (init) <columns_set>: New local variable.
+	(init) <optstring>: Add "U:".
+	(init) <longopts>: Add "summary-columns" long option.
+	(init) <case 'U'>: Pass option argument to set_count_summary_columns.
+	(usage): Document it. Add missing -O/-S options to synopsis.
+	* strace.1.in (.SS Statistics): Likewise.
+	* strace.c (usage): Likewise.
+	* tests/options-syntax.test: Add option syntax checks.
+
+2020-03-23  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	count: factor out column alias names.
+	Since any column can be sorted now, we can maintain just an alias
+	to column mapping, which is also going to be used for column selection
+	functionality.
+
+	* count.c (column_aliases): New static constant array.
+	(sort_func): New typedef.
+	(sortfun): Change type to sort_func.
+	(set_sortby): Replace alias to sort function mapping with an
+	column-indexed array of sorting functions in sort_fns, ajust the code
+	accordingly.
+	* tests/options-syntax.test: Add checks.
+
+2020-03-23  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	count: add ability to sort on avg_time field.
+	For completeness.
+
+	* count.c (avg_time_cmp): New function.
+	(set_sortby): Add sort keys for avg_time sorting.
+	* strace.1.in (.SH OPTIONS) <-S>: Document it.
+	* strace.c (usage): Likewise.
+	* tests/strace-S.test: Add check.
+
+2020-03-23  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	count: refactor statistics calculation/output.
+	In preparation to extension.
+
+	* count.c (enum count_summary_columns): New enumeration type.
+	(struct call_counts): Add time_avg field.
+	(DEF_COLUMNS): New macro.
+	(columns, visible): New variables.
+	(num_chars): New function.
+	(call_summary_pers): Calculate aggregate data first, then output table
+	based on columns configuration.
+
+2020-03-23  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	xlat: wire up PR_SET_IO_FLUSHER and PR_GET_IO_FLUSHER prctl options.
+	* xlat/prctl_options.in (PR_SET_IO_FLUSHER, PR_GET_IO_FLUSHER): New
+	constants, introduced by Linux kernel commit v5.6-rc1~122^2.
+	* prctl.c (SYS_FUNC(prctl)): Wire up PR_SET_IO_FLUSHER
+	and PR_GET_IO_FLUSHER options.
+
+	xlat: sort prctl_options entries, add #sorted.
+	* xlat/prctl_options.in: Sort the entries, align the values, add #sorted,
+	add comments about PR_SET_VMA and PR_SET_PTRACER.
+
+2020-03-23  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	rtc: decode RTC Voltage Low value as flags.
+	Introduced by Linux kernel commit v5.6-rc1~71^2~57
+
+	* xlat/rtc_vl_flags.in: New file.
+	* rtc.c (decode_rtc_vl): New function.
+	(rtc_ioctl) <case RTC_VL_READ>: Call it instead of printnum_int.
+
+2020-03-23  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	rtc: bundle ioctl number definitions.
+	This makes decoding more reliable as it no longer depends
+	on definitions of these ioctl commands the kernel headers.
+
+	* xlat/rtc_ioctl_cmds.in: New file.
+	* rtc.c: Include <xlat/rtc_ioctl_cmds.h>.
+	(rtc_ioctl): Remove RTC_VL_READ and RTC_VL_CLR guards.
+
+2020-03-23  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	sched: implement utilisation clamping fields decoding.
+	And also handle the piggybacked SCHED_FLAG_KEEP_PARAMS flag
+	introduced by Linux kernel commit v5.3-rc1~201^2~5.
+
+	* xlat/sched_flags.in (SCHED_FLAG_KEEP_PARAMS,
+	SCHED_FLAG_UTIL_CLAMP_MIN, SCHED_FLAG_UTIL_CLAMP_MAX): New constants.
+	* sched_attr.h (struct sched_attr): Add sched_util_min and
+	sched_util_max fields.
+	(SCHED_ATTR_SIZE_VER1): New macro.
+	* sched.c (print_sched_attr): Do not print sched_policy field if
+	SCHED_FLAG_KEEP_PARAMS flag is set in sched_setattr; do not print
+	sched_nice, sched_priority, sched_runtime, sched_deadline,
+	and sched_period fields if SCHED_FLAG_KEEP_PARAMS flag is set
+	in sched_setattr; print sched_util_min and sched_util_max field if
+	size is at least PRINT_FIELD_U; use attr.size instead of usize in
+	sched_getattr for determining whether ellipsis is needed to be printed.
+	* tests/sched_xetattr.c: Update expected output, add checks.
+
+2020-03-23  Eugene Syromyatnikov  <evgsyr@gmail.com>
+	    Dmitry V. Levin  <ldv@altlinux.org>
+
+	sched: add SCHED_FLAG_KEEP_POLICY flag support.
+	Introduced by Linux kernel commit v5.3-rc1~201^2~6.
+
+	* xlat/sched_flags.in (SCHED_FLAG_KEEP_POLICY): New constant.
+	* sched.c (print_sched_attr): Add is_set variable, set it to true
+	if passed usize is zero, print policy if it is sched_getattr,
+	it is negative, or if SCHED_FLAG_KEEP_POLICY is not set.
+	* tests/sched_xetattr.c: Update expected output, add a check.
+
+2020-03-23  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	sched: refactor print_sched_attr.
+	Steamline it a bit and convert to PRINT_FIELD_* macros usage,
+	in anticipation of the upcoming changes.
+
+	* sched.c: Include "print_fields.h".
+	(PRINT_SCHED_FIELD): Remove macro.
+	(print_sched_attr): Use PRINT_FIELD_* macros for printing fields, use
+	goto instead of size-checking condition block.
+
+2020-03-20  Dmitry V. Levin  <ldv@altlinux.org>
+
+	github: check source code for whitespace errors on every push and pull request
+	* .github/workflows/source-code-check.yml: New file.
+
+2020-03-20  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	rtnl_link: decode IFLA_PERM_ADDRESS attribute.
+	Introduced by Linux commit v5.6-rc1~151^2~262^2~4.
+
+	* configure.ac (AC_CHECK_DECLS): Check for IFLA_PERM_ADDRESS.
+	* rtnl_link.c (ifinfomsg_nla_decoders): Wire up IFLA_PERM_ADDRESS
+	attribute using decode_nla_hwaddr.
+	* xlat/rtnl_link_attrs.in (IFLA_PERM_ADDRESS): New constant.
+
+2020-03-20  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	rtnl_link: use the family from ifinfomsg.
+	* rtnl_link.c (decode_ifla_hwaddr): New function,
+	decode_nla_hwaddr_family wrapper that passes the value from
+	struct ifinfomsg (passed in opaque data) to it.
+	(ifinfomsg_nla_decoders) <IFLA_ADDRESS, IFLA_BROADCAST>: Use
+	decode_ifla_hwaddr as decoder.
+	(decode_ifinfomsg): Pass ifinfo as opaque_data in decode_nlattr call.
+
+	nlattr: implement generic hardware address nlattr decoder.
+	* nlattr.c (decode_nla_hwaddr): New function.
+	* nlattr.h (DECL_NLA(hwaddr)): New declaration.
+	(NLA_HWADDR_FAMILY_OFFSET): New macro.
+	(decode_nla_hwaddr_family, decode_nla_hwaddr_nofamily): New functions.
+	* rtnl_link.c (ifla_info_data_bridge_nla_decoders) <IFLA_BR_GROUP_ADDR>:
+	Use nlattr_hwaddr_nofamily.
+	* rtnl_neigh.c (decode_neigh_lladdr): Remove.
+	(ndmsg_nla_decoders) <NDA_LLADDR>: Change decoder
+	from decode_neigh_lladdr to decode_nla_hwaddr_nofamily.
+	* tests/nlattr_ifla_linkinfo.c: Update expected output.
+	* tests/nlattr_ndmsg.c: Likewise.
+
+2020-03-19  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	print_mac: avoid passing sizes greater than MAX_ADDR_LEN to sprint_mac_addr
+	As sprint_mac_addr (rightfully) bails out on those, simply print those
+	as strings.
+
+	* print_mac.c (print_mac_addr, print_hwaddr): Print address raw and
+	avoid calling sprint_mac_addr if the size is greater than MAX_ADDR_LEN.
+
+2020-03-19  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	print_mac: do not limit address length for hwaddr families 806..819.
+	It seems that it has been overlooked.
+
+	* print_mac.c (hwaddr_sizes): Initialise array with default value of 255
+	up to ARPHRD_VSOCKMON.
+
+	Fixes: v4.23~129 "sock: guess ifr_hwaddr size in SIOCSIFHWADDR/SIOCGIFHWADDR"
+
+2020-03-19  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	rtnl_link: add IFLA_PROP_LIST and IFLA_ALT_IFNAME attribute type support
+	Introduced by Linux commit v5.5-rc1~174^2~448^2~4.
+
+	* configure.ac (AC_CHECK_DECLS): Check for IFLA_PROP_LIST
+	and IFLA_ALT_IFNAME.
+	* rtnl_link.c (decode_ifla_prop_list_attr, decode_ifla_prop_list): New
+	functions.
+	(ifinfomsg_nla_decoders): Decode IFLA_PROP_LIST with
+	decode_ifla_prop_list, decode IFLA_ALT_IFNAME with decode_nla_str.
+	* tests/nlattr_ifinfomsg.c: Add checks.
+	* xlat/rtnl_link_attrs.in (IFLA_PROP_LIST, IFLA_ALT_IFNAME): New
+	constants.
+
+2020-03-19  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	nlattr: use QUOTE_EXPECT_TRAILING_0 in decode_nla_str.
+	In order to signify the absence of the trailing \0 in string
+	and print embedded \0 at the same time.
+
+	* nlattr.c (decode_nla_str): Provide
+	QUOTE_OMIT_TRAILING_0 | QUOTE_EXPECT_TRAILING_0 flags instead
+	of QUOTE_0_TERMINATED flag to printstr_ex call.
+
+2020-03-19  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	util: add a separate flag for printing ellipsis in absence of \0 in strings
+	In cases where we know the size of the string to be printed
+	(for example, in decode_nla_str and likely somewhere else),
+	it is probably better to print embedded \0's (so, do not pass
+	QUOTE_0_TERMINATED).  Unfortunately, printstr_ex doesn't have a separate
+	flag for printing ellipsis in case no \0 occurred at all, so let's
+	introduce it.
+
+	* defs.h (QUOTE_EXPECT_TRAILING_0): New macro.
+	(QUOTE_0_TERMINATED, QUOTE_OMIT_LEADING_TRAILING_QUOTES,
+	QUOTE_OMIT_TRAILING_0): Document.
+	(QUOTE_FORCE_HEX, QUOTE_EMIT_COMMENT): Update values, document.
+	* util.c (printstr_ex): Print ellipsis not only on QUOTE_0_TERMINATED,
+	but also on QUOTE_EXPECT_TRAILING_0.
+
+2020-03-16  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	xlat: add IPPROTO_ETHERNET to inet_protocols.
+	* xlat/inet_protocols.in (IPPROTO_ETHERNET): New constant, introduced
+	by Linux commit v5.6-rc6~23^2~9.
+
+2020-03-15  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: robustify read-write test.
+	* tests/read-write.c (main): Explicitly close descriptors 4 and 5 that
+	might be inherited from the parent process.
+
+2020-03-10  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Robustify <linux/if_bridge.h> configure checks.
+	Prior to Linux kernel commit v3.18-rc5~22^2~32 <linux/if_bridge.h> was
+	incomplete: it used struct in6_addr but didn't include a header with a
+	definition.  Apply the same workaround in configure checks as in other
+	parts of strace: include <netinet/in.h> before <linux/if_bridge.h>.
+
+	* configure.ac: Include <netinet/in.h> before <linux/if_bridge.h>.
+	* types/gen.sh (gen_m4_check): Specify INCLUDES parameter in the
+	generated AC_CHECK_HEADERS invocation.
+
+2020-03-10  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	xlat: change style argument type of print_xlat_ex to uint32_t.
+	...and add some documentation. Otherwise, clang complains about it:
+
+	    warning: implicit conversion from enumeration type
+	    'enum xlat_style_private_flags' to different enumeration type
+	    'enum xlat_style' [-Wenum-conversion]
+	                    print_xlat_ex(cid, "V4L2_CID_???", PXF_DEFAULT_STR);
+	                    ~~~~~~~~~~~~~                      ^~~~~~~~~~~~~~~
+
+	* defs.h (print_xlat_ex): Change the type of style argument to uint32_t,
+	add doxydoc.
+	* xlat.c (print_xlat_ex): Change the type of style argument to uint32_t.
+
+2020-03-09  Dmitry V. Levin  <ldv@altlinux.org>
+
+	util: define either ilog2_64 or ilog2_32.
+	Depending on the value of SIZEOF_KERNEL_LONG_T, either ilog2_64 or
+	ilog2_32 is used as an implementation of ilog2_klong.  Do not define
+	the other one to pacify clang that otherwise complains with either
+
+	  util.c:1060:1: warning: unused function 'ilog2_32' [-Wunused-function]
+	  ilog2_32(uint32_t val)
+
+	or
+
+	  util.c:1038:1: warning: unused function 'ilog2_64' [-Wunused-function]
+	  ilog2_64(uint64_t val)
+
+	* util.c (ilog2_64): Define only for [SIZEOF_KERNEL_LONG_T > 4].
+	(ilog2_32): Define only for [SIZEOF_KERNEL_LONG_T == 4].
+
+2020-03-09  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: include <signal.h> instead of <sys/signal.h>
+	<sys/signal.h> is an old stub that exists for compatibility with some
+	ancient systems, it just includes <signal.h>.
+
+	* tests/prctl-pdeathsig.c: Include <signal.h> instead of <sys/signal.h>.
+
+2020-03-09  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Assume that prctl() and <sys/prctl.h> are always available.
+	They were introduced in the GNU libc back in 1997,
+	so we can safely use them without further checks.
+
+	* configure.ac (AC_CHECK_FUNCS): Remove prctl.
+	* strace.c: Include <sys/prctl.h> unconditionally.
+	(startup_child): Do not test for HAVE_PRCTL.
+	* tests/prctl-name.c: Include <sys/prctl.h> unconditionally, do not test
+	for HAVE_PRCTL.
+	* tests/prctl-seccomp-filter-v.c: Likewise.
+	* tests/prctl-seccomp-strict.c: Likewise.
+	* tests/printpath-umovestr-undumpable.c: Likewise.
+	* tests/printstrn-umoven-undumpable.c: Likewise.
+	* tests/set_ptracer_any.c: Likewise.
+	* tests/seccomp-filter-v.c: Include <sys/prctl.h> unconditionally.
+
+2020-03-09  Dmitry V. Levin  <ldv@altlinux.org>
+
+	strace.1: fix typo.
+	* strace.1.in (.SH HISTORY): Fix spelling of OpenRISC.
+
+	Resolves: https://github.com/strace/strace/issues/128
+
+2020-03-06  Dmitry V. Levin  <ldv@altlinux.org>
+
+	print_timeval: do not use struct timeval provided by libc.
+	Use kernel_old_timeval_t provided by our kernel_timeval.h instead of
+	struct timeval provided by libc to avoid potential issues if libc
+	changes the definition of struct timeval to use 64-bit types on 32-bit
+	systems.
+
+	* print_timeval.c: Include "kernel_timeval.h".
+	(timeval_t): Change from struct timeval to kernel_old_timeval_t.
+
+	Complements: v5.5-8-g94d56c9c3 "printrusage: bundle rusage_t definition"
+
+2020-03-06  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Move kernel_old_timeval definition to kernel_timeval.h.
+	It's going to be used later in print_timeval.c
+
+	* kernel_timeval.h: Include "kernel_types.h".
+	(kernel_old_timeval_t): New type.
+	* printrusage.c: Include "kernel_timeval.h".
+	(struct kernel_old_timeval): Remove.
+	(rusage_t): Replace struct kernel_old_timeval with kernel_old_timeval_t.
+
+2020-03-06  Dmitry V. Levin  <ldv@altlinux.org>
+
+	printrusage: fix kernel_old_timeval definition to match the kernel.
+	The type of struct kernel_old_timeval.tv_usec field is the same
+	kernel_long_t as the type of tv_sec field, with one notable exception:
+	sparc64 is the only 64-bit architecture where tv_usec field is 32-bit.
+
+	* printrusage.c (struct kernel_old_timeval) [__sparc__ && __arch64__]:
+	Change the type of tv_usec field from long to int.
+	[!(__sparc__ && __arch64__)]: Change the type of tv_usec field
+	from long to kernel_long_t.
+
+	Fixes: v5.5-8-g94d56c9c3 "printrusage: bundle rusage_t definition"
+
+2020-03-06  Alistair Francis  <alistair.francis@wdc.com>
+
+	printrusage: fix kernel_old_timeval typo.
+	The timeval struct should contain a tv_sec and tv_usec type,
+	fix the typo to indicate that it's usec and not nsec.
+
+	This member is never directly accessed here so there are no other
+	changes required.
+
+
+	* printrusage.c (struct kernel_old_timeval): Rename tv_nsec to tv_usec.
+
+	Fixes: v5.5-8-g94d56c9c3 "printrusage: bundle rusage_t definition"
+
+2020-03-02  Paul Chaignon  <paul.chaignon@gmail.com>
+	    Eugene Syromyatnikov  <evgsyr@gmail.com>
+	    Dmitry V. Levin  <ldv@altlinux.org>
+
+	bpf: implement decoding of BPF_PROG_ATTACH replace_bpf_fd field.
+	* bpf_attr.h (BPF_PROG_ATTACH_struct): Add replace_bpf_fd field
+	introduced by Linux kernel commit v5.6-rc1~151^2~199^2~7^2~3.
+	(expected_BPF_PROG_ATTACH_struct_size): Update.
+	* bpf.c (BEGIN_BPF_CMD_DECODER(BPF_PROG_ATTACH)): Decode the new field.
+	* NEWS: Mention this.
+	* tests/bpf.c (BPF_PROG_ATTACH_checks): Check it.
+
+	bpf: update BPF_* constants.
+	* xlat/bpf_attach_flags.in (BPF_F_REPLACE): New constant introduced
+	by Linux kernel commit v5.6-rc1~151^2~199^2~7^2~3.
+	* xlat/bpf_map_types.in (BPF_MAP_TYPE_STRUCT_OPS): New constant
+	introduced by Linux kernel commit v5.6-rc1~151^2~46^2~37^2~5.
+	* xlat/bpf_prog_types.in (BPF_PROG_TYPE_STRUCT_OPS): New constant
+	introduced by Linux kernel commit v5.6-rc1~151^2~46^2~37^2~6.
+	(BPF_PROG_TYPE_EXT): New constant introduced by Linux kernel commit
+	v5.6-rc1~151^2~46^2~1^2~2.
+	* NEWS: Mention this.
+	* tests/bpf.c (BPF_MAP_CREATE_checks, BPF_PROG_LOAD_checks,
+	BPF_PROG_QUERY_checks): Update checks and their expected output.
+	* tests/kernel_version.c (print_bpf_attr, main): Likewise.
+
+2020-03-02  Eugene Syromyatnikov  <evgsyr@gmail.com>
+	    Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests/bpf: add a guard against untested bpf_map_types updates.
+	* tests/bpf.c: Include "xlat/bpf_map_types.h", add a static_assert
+	for bpf_map_types_xdata.
+	(BPF_MAP_CREATE_checks): Update the first check.
+
+	bpf: implement decoding of struct bpf_map_info.btf_vmlinux_value_type_id field
+	* bpf_attr.h (struct bpf_map_info_struct): Insert
+	btf_vmlinux_value_type_id field between ifindex and netns_dev fields
+	introduced by Linux kernel commit v5.6-rc1~151^2~46^2~37^2~5.
+	* bpf.c (print_bpf_map_info): Print btf_vmlinux_value_type_id field.
+	* tests/bpf-obj_get_info_by_fd.c [VERBOSE] (main): Print
+	btf_vmlinux_value_type_id field if the structure is big enough.
+
+2020-03-02  Paul Chaignon  <paul.chaignon@gmail.com>
+	    Eugene Syromyatnikov  <evgsyr@gmail.com>
+	    Dmitry V. Levin  <ldv@altlinux.org>
+
+	bpf: implement decoding of BPF_MAP_CREATE btf_vmlinux_value_type_id field
+	* bpf_attr.h (BPF_MAP_CREATE_struct): Add btf_vmlinux_value_type_id
+	field introduced by Linux kernel commit v5.6-rc1~151^2~46^2~37^2~5.
+	(expected_BPF_MAP_CREATE_struct_size): Update.
+	* bpf.c (BEGIN_BPF_CMD_DECODER(BPF_MAP_CREATE)): Decode the new field.
+	* NEWS: Mention this.
+	* tests/bpf-obj_get_info_by_fd.c (print_map_create): Update expected
+	output.
+	* tests/bpf.c (BPF_MAP_CREATE_checks): Add a check that includes
+	btf_vmlinux_value_type_id field.
+
+2020-03-01  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	ioctl: add HIDIOCGRAWUNIQ ioctl number decoding.
+	* ioctl.c (hiddev_decode_number): Decode HIDIOCGRAWUNIQ introduced
+	by Linux kernel commit v5.6-rc1~198^2~1^2.
+
+	ioctl: fix indentation in switch clauses.
+	* ioctl.c: Fix indentation in switch clauses, no code changes.
+
+	xlat: update AUDIT_* constants.
+	* xlat/nl_audit_types.in: Add #sorted.
+	(AUDIT_BPF): New constant, introduced by Linux kernel commit
+	v5.6-rc1~151^2~199^2~47.
+
+	xlat: update CLONE_* constants.
+	* xlat/clone3_flags.in (CLONE_NEWTIME): New constant, introduced
+	by Linux kernel commit v5.6-rc1~177^2~41.
+	* xlat/setns_types.in (CLONE_NEWTIME): Likewise.
+	* xlat/unshare_flags.in (CLONE_NEWTIME): Likewise.
+	* tests/clone3.c (main): Update the expected output.
+	* tests/unshare.c (main): Likewise.
+
+	xlat/unshare_flags: reorder and provide fallback definitions for constants
+	* xlat/unshare_flags.in: Provide fallback definitions for constants,
+	reorder in the ascending order, add #sorted.
+	* tests/unshare.c (main): Update the expected output.
+
+	xlat: update GRND_* constants.
+	* xlat/getrandom_flags.in (GRND_INSECURE): New constant, introduced
+	by Linux kernel commit v5.6-rc1~91^2~20.
+
+	xlat: update IPPROTO_* constants.
+	* xlat/inet_protocols.in (IPPROTO_MPTCP): New constant, introduced
+	by Linux kernel commit v5.6-rc1~151^2~118^2~8.
+
+	xlat: update RTM_F_* constants.
+	* xlat/routing_flags.in: Add #sorted.
+	(RTM_F_NOTIFY, RTM_F_CLONED, RTM_F_EQUALIZE, RTM_F_PREFIX,
+	RTM_F_LOOKUP_TABLE): Add fallback definitions.
+	(RTM_F_FIB_MATCH): New constant, introduced by Linux kernel commit
+	v4.13-rc1~157^2~364^2~2.
+	(RTM_F_OFFLOAD, RTM_F_TRAP): New constants, introduced by Linux kernel
+	commit v5.6-rc1~151^2~91^2~7.
+
+	io_uring: decode IORING_REGISTER_EVENTFD_ASYNC io_uring_reginster command
+	* xlat/uring_register_opcodes.in (IORING_REGISTER_EVENTFD_ASYNC): New
+	constant introduced by Linux kernel commit v5.6-rc1~123^2~28.
+	* io_uring.c (io_uring_register): Handle IORING_REGISTER_EVENTFD_ASYNC
+	along with IORING_REGISTER_FILES and IORING_REGISTER_EVENTFD.
+	* tests/io_uring_register.c (main): Check it, update expected output.
+
+	xlat: update KVM_* constants.
+	* xlat/kvm_cap.in (KVM_CAP_S390_VCPU_RESETS): New constant, introduced
+	by Linux kernel commit v5.6-rc1~39^2~3^2~3.
+
+	xlat: add ZONEFS_MAGIC to fsmagic.
+	* xlat/fsmagic.in (ZONEFS_MAGIC): New constant, introduced by Linux
+	kernel commit v5.6-rc1~2^2~1.
+
+2020-02-26  Alistair Francis  <alistair.francis@wdc.com>
+
+	tests/clock_nanosleep: Skip test if __NR_clock_nanosleep isn't defined.
+	Modern (added since Linux kernel 5.1+) 32-bit architectures don't have
+	the __NR_clock_nanosleep syscall, if we don't have the syscall let's
+	skip the test.
+
+
+	* tests/clock_nanosleep.c [!__NR_clock_nanosleep]: Skip the test.
+
+2020-02-26  Alistair Francis  <alistair.francis@wdc.com>
+	    Dmitry V. Levin  <ldv@altlinux.org>
+
+	linux/32: Split 32-bit time_t based syscalls into a separate header.
+
+	Starting with Linux kernel v5.1, new 32-bit architectures
+	do not implement old 32-bit time_t based system calls, so
+	they should not have the corresponding syscallent records.
+
+	* linux/32/syscallent-time32.h: New file, generated using the following
+	command: grep 'timex\?32)' linux/32/syscallent.h
+	* Makefile.am (EXTRA_DIST): Add it.
+	* linux/32/syscallent.h: Replace entries for 32-bit time_t based
+	syscalls with stub comments using the following command:
+	sed -i '/timex\?32)/ s/\(^\[[^]]\+\]\)[^"]*"\([^"]\+\)".*/\/\* \1 \2 \*\//'
+	[HAVE_ARCH_TIME32_SYSCALLS]: Include "32/syscallent-time32.h".
+
+2020-02-24  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	strace: disable seccomp-bpf instead of enabling following forks.
+	It is in line with the rest of the checks that disable seccomp-bpf
+	usage if it is impossible.
+
+	* strace.c (init) <if (seccomp_filtering)>: Rephrase the error
+	if followfork is not set; set seccomp_filtering to false; do not set
+	followfork to true.
+	* tests/options-syntax.test: Update the expected output.
+
+2020-02-24  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	strace: warn about uselessness of -A/--output-separately in absence of -o
+	* strace.c (init) <if (!outfname)>: Print warnings if output_separately
+	and/or open_append.
+	* tests/options-syntax.test: Check this.
+
+	Update NEWS.
+
+	strace: add a long option alias for -t.
+	* strace.c (tflag): Remove.
+	(tflag_scale, tflag_width, tflag_format): New static variables.
+	(printleader): Rewrite time stamp printing to allow custom format
+	and precision.
+	(printleader) <if (rflag)>: Use tflag_format instead of tflag
+	as an indicator for presence of absolute timestamps.
+	(parse_ts_arg): New function.
+	(init) <tflag_str, ttflag_str, tttflag_str>: New static constants.
+	(init) <tflag_long_set, tflag_short>: New variables.
+	(init) <enum>: Add GETOPT_TS.
+	(init) <longopts>: Add "absolute-timestamps" and "timestamps" long
+	options.
+	(init) <case 't'>: Increment tflag_short instead of tflag.
+	(init) <case GETOPT_TS>: Handle the new option using parse_ts_arg.
+	(init): Check if tflag_short is set; if tflag_long_set is set as well,
+	then bail out, otherwise call parse_ts_arg with the appropriate
+	argument; update the message that mentions -t.
+	(usage): Document it.
+	* strace.1.in (.SS Output format): Likewise.
+	* tests/gen_tests.in (strace--absolute-timestamps,
+	strace--absolute-timestamps-format-time,
+	strace--absolute-timestamps-format-time-precision-s,
+	strace--absolute-timestamps-format-time-precision-ms,
+	strace--absolute-timestamps-format-time-precision-us,
+	strace--absolute-timestamps-format-time-precision-ns,
+	strace--absolute-timestamps-format-unix-precision-s,
+	strace--absolute-timestamps-format-unix-precision-ms,
+	strace--absolute-timestamps-format-unix-precision-us,
+	strace--absolute-timestamps-format-unix-precision-ns,
+	strace--relative-timestamps, strace--relative-timestamps-s,
+	strace--relative-timestamps-ms, strace--relative-timestamps-us,
+	strace--relative-timestamps-ns, strace--timestamps,
+	strace--timestamps-time, strace--timestamps-time-s,
+	strace--timestamps-time-ms, strace--timestamps-time-us,
+	strace--timestamps-time-ns, strace--timestamps-unix-s,
+	strace--timestamps-unix-ms, strace--timestamps-unix-us,
+	strace--timestamps-unix-ns): New tests.
+	* tests/options-syntax.test: Add new checks.
+	* tests/strace-t.test: Get the option to check via command-line
+	arguments.
+	* tests/strace-tt.test: Get the precision and option to check
+	via command-line arguments.
+	* tests/strace-ttt.test: Get the precision and option to check
+	via command-line arguments, generate subsec_re appropriately.
+
+2020-02-24  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	strace: establish -qqq as an alias for --quiet=all.
+	Addition of thread-execve and path-resolution quiet flags introduced
+	discrepancy between the -qq and --quiet=all settings; let's establish
+	that -qqq is the ultimate quietness setting and leave the more
+	fine-grained control to the -e quiet/--quiet option.
+
+	* strace.c (init) <qqqflag_qual>: New static constant.
+	(init) Supply qqqflag_qual to qualify_quiet if qflag_short is set to 3
+	or higher.
+	(usage): Document it.
+	* strace.1.in: Likewise.
+	* tests/threads-execve--quiet-thread-execve.c: New file.
+	* tests/threads-execve-q.c: Likewise.
+	* tests/threads-execve-qq.c: Likewise.
+	* tests/threads-execve-qqq.c: Likewise.
+	* tests/.gitignore: Add threads-execve--quiet-thread-execve,
+	threads-execve-q, threads-execve-qq, threads-execve-qqq.
+	* tests/Makefile.am (check_PROGRAMS): Likewise.
+	(threads_execve__quiet_thread_execve_LDADD, threads_execve_q_LDADD,
+	threads_execve_qq_LDADD, threads_execve_qqq_LDADD): New variables.
+	* tests/gen_tests.in (threads-execve--quiet-thread-execve,
+	threads-execve-q, threads-execve-qq, threads-execve-qqq): New tests.
+	* tests/threads-execve.c [!PRINT_EXITED] (PRINT_EXITED): New macro.
+	[!PRINT_SUPERSEDED] (PRINT_SUPERSEDED): Likewise.
+	(thread): Put "superseded by execve in pid"... message printing under
+	PRINT_SUPERSEDED.
+	(main): Put "+++ exited with 0 +++" message printing under PRINT_EXITED.
+	* tests/threads-execve.test: Inject the arguments supplied to the tests
+	into the strace's arguments.
+
+2020-02-24  Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: fix require_min_nproc on systems without nproc.
+	* tests/init.sh (require_min_nproc): Fix typo in the check for nproc
+	that manifests itself in "set -e" mode.
+
+	Fixes: v5.4~59 "tests: skip a few tests on systems with nproc == 1"
+
+2020-02-24  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	strace: add a long option alias for -y.
+	Provide a new qualifier, decode-fds, and add (hopefully) sensible
+	handling for it.
+
+	* defs.h (show_fd_path): Remove declaration.
+	(qualify_decode_fd): New declaration.
+	* filter_qualify.c (decode_fd_set, decode_fd_set_updated): New
+	variables.
+	(decode_fd_str_to_uint, qualify_decode_fd): New functions.
+	(qual_options): Add "decode-fd" and "decode-fds" that are handled
+	by qualify_decode_fd.
+	* number_set.h (enum decode_fd_bits): New enumeration.
+	(decode_fd_set_updated, decode_fd_set): New declarations.
+	* strace.c (show_fd_path): Remove.
+	(init) <yflag_qual, yyflag_qual>: New static constants.
+	(init) <yflag_short>: New local variable.
+	(init) <enum>: Add GETOPT_QUAL_FD.
+	(init) <longopts>: Add "decode-fds" long option.
+	(init) <case 'y'>: Increment yflag_short instead of show_fd_path.
+	(init) <case GETOPT_QUAL_FD>: Call qualify_decode_fd with either optarg
+	or yflag_qual is the former is NULL.
+	(init): Check if yflag_short is set, if decode_fd_set_updated is set
+	as well, bail out, call qualify_decode_fd with the appropriate set
+	otherwise; update the message that mentions -y.
+	(usage): Document it.
+	* strace.1.in (.SS Output format): Likewise.
+	* util.c: Include "number_set.h".
+	(printfd): Rewrite using appropriate is_number_in_set checks.
+	* tests/dev--decode-fds-dev.c: New file.
+	* tests/dev--decode-fds-path.c: Likewise.
+	* tests/dev--decode-fds-socket.c: Likewise.
+	* tests/net--decode-fds-dev-netlink.c: Likewise.
+	* tests/net--decode-fds-none-netlink.c: Likewise.
+	* tests/net--decode-fds-path-netlink.c: Likewise.
+	* tests/net--decode-fds-socket-netlink.c: Likewise.
+	* tests/pidfd_open--decode-fd-path.c: Likewise.
+	* tests/.gitignore: Add dev--decode-fds-dev, dev--decode-fds-path,
+	dev--decode-fds-socket, net--decode-fds-dev-netlink,
+	net--decode-fds-none-netlink, net--decode-fds-path-netlink,
+	net--decode-fds-socket-netlink, and pidfd_open--decode-fd-path.
+	* tests/pure_executables.list: Likewise.
+	* tests/dev-yy.c [!PRINT_DEVNUM] (PRINT_DEVNUM): New macro, define to 1.
+	(DEV_FMT): New macro.
+	(main): Parametrize the output using DEV_FMT in accordance with
+	PRINT_DEVNUM value.
+	* tests/gen_tests.in (dev--decode-fds-dev, dev--decode-fds-path,
+	dev--decode-fds-socket, net--decode-fds-dev-netlink,
+	net--decode-fds-none-netlink, net--decode-fds-path-netlink,
+	net--decode-fds-socket-netlink, pidfd_open--decode-fd-path): New tests.
+	(open_tree-P): Use the long option.
+	* tests/net-yy-netlink.c [!PRINT_SOCK] (PRINT_SOCK): New macro, define
+	to 2.
+	(FMT_UNBOUND, FMT_BOUND, ARG_UNBOUND, ARG_BOUND): New macros, defined
+	based on PRINT_SOCK value.
+	(main): Parametrize the output using FMT_UNBOUND, FMT_BOUND,
+	ARG_UNBOUND, and ARG_BOUND.
+	* tests/net-yy-netlink.test: Append options passed to the test instead
+	of "-yy".
+	* tests/options-syntax.test: Add checks, update expected output.
+
+2020-02-24  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	strace: add a long option aliases for -f and -ff.
+	Introduce a new option, --output-separately, and make -ff an alias
+	for a combination of -f and this new option.
+
+	* defs.h (followfork): Change type to bool.
+	(output_separately): New declaration.
+	* strace.c (followfork): Change type to bool.
+	(output_separately): New variable.
+	(outf_perror, printleader, after_successful_attach, droptcb, init,
+	print_event_exit, print_syscall_resume): Use output_separately
+	instead of followfork check.
+	(init) <followfork_short>: New local variable.
+	(init) <enum>: Add GETOPT_FOLLOWFORKS and GETOPT_OUTPUT_SEPARATELY.
+	(init) <longopts>: Add "follow-forks" and "output-separately" long
+	options.
+	(init) <case 'f'>: Increase followfork_short instead of followfork.
+	(init) <case GETOPT_FOLLOWFORKS>: Set followfork to true.
+	(init) <case GETOPT_OUTPUT_SEPARATELY>: Set output_separately to true.
+	(init): Fail if either both followfork_short and followfork are set,
+	or followfork_short >= 2 and output_separately is set;
+	set followfork/output_separately appropriately otherwise;
+	update the error messages that mention -f/-ff options with the aliases.
+	(init) <if (seccomp_filtering)>: Set followfork to true and not 1.
+	(usage): Document it.
+	* strace.1.in (.SS Tracing): Likewise.
+	* tests/strace--follow-forks-output-separately.expected: New file.
+	* tests/Makefile.am (EXTRA_DIST): Add it.
+	* tests/delay.test: Use --follow-forks instead of -f.
+	* tests/gen_tests.in: Add strace--follow-forks-output-separately test.
+	* tests/looping_threads.test: Use --follow-forks instead of -f.
+	* tests/options-syntax.test: Add --follow-forks-related syntax checks,
+	update the expected output.
+	* tests/strace-ff.test: Add -efu as the interpreter argument; set the
+	arguments to ff_opt variable ("-ff" being the default) and use it
+	instead of -ff in the strace call; put set +f before "set -- "$LOG".*".
+
+2020-02-24  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	tests/syntax: add suffixes to produced log/exp files.
+	In order to enable inspection of them.
+
+	* tests/syntax.sh (log_sfx): New functions.
+	(check_exit_status_and_stderr, check_exit_status_and_stderr_using_grep):
+	Get suffix from the first argument, append it to LOG/EXP usage instances;
+	open-code dump_log_and_fail_with in order to print the file with the
+	suffix.
+	check_e, check_e_using_grep, check_h): Assign log_sfx result to sfx,
+	append it to LOG/EXP usage instances, pass it to
+	check_exit_status_and_stderr/check_exit_status_and_stderr_using_grep.
+
+2020-02-19  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	strace: add arguments to --syscall-times and --relative-timestamps.
+	* defs.h (Tflag_scale, Tflag_width): New declarations.
+	* strace.c (Tflag_scale, Tflag_width, rflag_scale, rflag_width): New
+	variables.
+	(printleader): Parametrise relative timestamp printing with rflag_width
+	and rflag_scale.
+	(init) <longopts>: Change second field of "relative-timestamps" and
+	"syscall-times" from no_argument to optional_argument.
+	(init) <case 'r', case 'T'>: Handle optarg, fail if the scale variable
+	is set to -1.
+	(usage): Document it.
+	* strace.1.in (.SS Output format): Likewise.
+	* syscall.c (syscall_exiting_trace): Parametrise syscall time printing
+	* with Tflag_width and Tflag_scale.
+	* tests/gen_tests.in (strace--relative-timestamps-s,
+	strace--relative-timestamps-ms, strace--relative-timestamps-us,
+	strace--relative-timestamps-ns): New tests.
+	* tests/options-syntax.test: New checks for --relative-timestamps and
+	--syscall-times option syntax.
+	* tests/strace--relative-timestamps-ms.expected: New file.
+	* tests/strace--relative-timestamps-ns.expected: Likewise.
+	* tests/strace--relative-timestamps-s.expected: Likewise.
+	* tests/strace--relative-timestamps-us.expected: Likewise.
+	* tests/strace--syscall-times-ms.expected: Likewise.
+	* tests/strace--syscall-times-ns.expected: Likewise.
+	* tests/strace--syscall-times-s.expected: Likewise.
+	* tests/strace--syscall-times-us.expected: Likewise.
+	* tests/Makefile.am (EXTRA_DIST): Add them.
+
+2020-02-19  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	util: factor out time scale parsing.
+	In preparation of using elsewhere.
+
+	* defs.h (str2timescale_ex): New declaration.
+	(str2timescale_optarg, str2timescale_sfx): New macros.
+	* util.c (str2timescale_ex): New function.
+	(parse_ts): Remove units, unit, assign str2timescale_sfx result to a new
+	variable scale and use it instead of unit->val.
+
+2020-02-19  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	pathtrace: add a quiet flag for path resolution messages.
+	And also quote the paths.
+
+	* number_set.h (enum quiet_bits): Add QUIET_PATH_RESOLVE.
+	* filter_qualify.c (quietstr_to_uint) <quiet_strs>: Add a string
+	representation for QUIET_PATH_RESOLVE.
+	* pathtrace.c (pathtrace_select_set): Put "Requested path"... message
+	under QUIET_PATH_RESOLVE flag check; process path and rpath with
+	string_quote.
+	* strace.c (usage): Document it.
+	* strace.1.in (.SS Output format) <-e quiet>: Likewise.
+
+2020-02-19  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	strace: add a quiet flag for "superseded by execve" messages.
+	* filter_qualify.c (quietstr_to_uint) <quiet_strs>: Add
+	a string representation for QUIET_THREAD_EXECVE,
+	* number_set.h (enum quiet_bits): Add QUIET_THREAD_EXECVE.
+	* strace.c (maybe_switch_tcbs): Put message printing under
+	QUIET_THREAD_EXECVE flag check.
+	(usage): Document it.
+	* strace.1.in (.SS Output format) <-e quiet>: Likewise.
+	* tests/maybe_switch_current_tcp--quiet-thread-execve.c: New file.
+	* tests/.gitignore: Add maybe_switch_current_tcp--quiet-thread-execve.
+	* tests/pure_executables.list: Likewise.
+	* tests/Makefile.am (maybe_switch_current_tcp__quiet_thread_execve_LDADD):
+	New variable.
+	* tests/gen_tests.in (maybe_switch_current_tcp--quiet-thread-execve):
+	New test.
+	* tests/maybe_switch_current_tcp.c [!QUIET_MSG] (QUIET_MSG): New macro.
+	(thread): Print "superseded"... message only is QUIET_MSG is 0.
+
+2020-02-19  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	syscall: print personality switch messages in tcb's output.
+	Personality switch is a rather normal event, it's unclear why it has
+	been always treated as a diagnostics/error information.  Having it under
+	qflag makes even less sense, as it was impossible to get
+	this information when the -o option was used.  With this change,
+	it is at least possible to get it with something like
+
+	    strace -f -o out --quiet=none PROG
+
+	One caveat, though, is its rather odd format, with square brackets,
+	"PID=", and a dot, but it seems that we're stuck with it forever, as it
+	traces back for decades, albeit with a prefix change in commit
+	v4.11~509 ("Consistently use error_msg instead of fprintf(stderr)").
+
+	* syscall.c (update_personality): Use printleader/tprintf/line_ended
+	instead of error_msg.
+	* tests/bexecve.test: Add --quiet=personality to strace invocations.
+	* tests/strace-ff.test: Likewise.
+
+2020-02-19  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	strace: respect quietness setting when reporting unknown tracees.
+	Since the situations where these processes can appear are relatively
+	normal, it makes little sense to print them irrespective of quietness
+	setting.
+
+	* strace.c (maybe_allocate_tcb): Put the message about exit of unknown
+	process under QUIET_EXIT check; put message about detach of unknown
+	process under QUIET_ATTACH check.
+	* tests/clone_parent--quiet-exit.c: New file.
+	* tests/clone_parent-q.c: Likewise.
+	* tests/clone_parent-qq.c: Likewise.
+	* tests/clone_ptrace--quiet-attach.c: Likewise.
+	* tests/clone_ptrace--quiet-exit.c: Likewise.
+	* tests/clone_ptrace-q.c: Likewise.
+	* tests/clone_ptrace-qq.c: Likewise.
+	* tests/.gitignore: Add clone_parent--quiet-exit, clone_parent-q,
+	clone_parent-qq, clone_ptrace--quiet-attach, clone_ptrace--quiet-exit,
+	clone_ptrace-q, and clone_ptrace-qq.
+	* tests/Makefile.am (check_PROGRAMS): Likewise.
+	* tests/gen_tests.in: Add clone_parent--quiet-exit, clone_parent-q,
+	clone_parent-qq, clone_ptrace--quiet-attach, clone_ptrace--quiet-exit,
+	clone_ptrace-q, and clone_ptrace-qq tests.
+	* tests/clone_parent.c [!QUIET_MSG] (QUIET_MSG): New macro.
+	(main): Print exit messages only if QUIET_MSG set to zero.
+	* tests/clone_ptrace.c [!QUIET_ATTACH] (QUIET_ATTACH): New macro.
+	[!QUIET_EXIT] (QUIET_EXIT): Likewise.
+	(main): Print information about unknown pid detach only if QUIET_ATTACH
+	is 0; print information about process exiting only if QUIET_EXIT is 0.
+	* tests/clone_ptrace.test: Add the first argument to args, add
+	"--quiet=personality" if it is empty.
+
+2020-02-19  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	strace: add long option aliases for -r, -T, and -O.
+	The last trivial ones.
+
+	* strace.c (init) <longopts>: Add "summary-syscall-overhead" as an alias
+	for 'O', "relative-timestamps" as an alias for 'r', and "syscall-times"
+	as an alias for 'T'.
+	(usage): Document it.
+	* strace.1.in: Likewise.
+	* tests/count.test: Add --summary-syscall-overhead checks.
+	* tests/gen_tests.in: Add strace--relative-timestamps and
+	strace--syscall-times tests.
+	* tests/strace-T.test: Allow passing option to check as the first
+	* argument.
+	* tests/strace-r.test: Likewise.
+	* tests/strace--relative-timestamps.expected: New file.
+	* tests/strace--syscall-times.expected: Likewise.
+	* tests/Makefile.am (EXTRA_DIST): Add them.
+
+2020-02-19  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	strace.1: document possible quialifier aliases.
+	* strace.1.in (.SS General) <-e expr>: Document possible aliases
+	for quialifiers.
+
+2020-02-19  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	strace: add long option aliases for -q.
+	Provide a new qualifier, quiet, and add a (hopefully) sensible handling
+	for it.
+
+	* defs.h (qflag): Remove declaration.
+	(qualify_quiet): New declaration.
+	* filter_qualify.c (quiet_set, quiet_set_updated): New variables.
+	(quietstr_to_uint, qualify_quiet): New functions.
+	(qual_options): Add "quiet", "silence", "silent", "q" that are handled
+	by qualify_quiet.
+	* number_set.h (enum quiet_bits): New enumeration.
+	(quiet_set_updated, quiet_set): New declarations.
+	* strace.c (qflag): Remove.
+	(detach, attach_tcb, maybe_allocate_tcb): Change qflag check to
+	is_number_in_set(QUIET_ATTACH, quiet_set).
+	(init) <qflag_qual, qqflag_qual>: New static constants.
+	(init) <enum>: Add GETOPT_QUAL_QUIET.
+	(init) <longopts>: Add "quiet", "silent", "silence".
+	(init) <case 'q'>: Increment qflag_short instead of qflag.
+	(init) <case GETOPT_QUAL_QUIET>: Call qualify_quiet with either optarg
+	or qflag_qual is the former is NULL.
+	(init) <if (outfname && argc)>: Check qflag_short and quiet_set_updated
+	instead of qflag for changing the default quietness setting.
+	(init): Check if qflag_short is set, if quiet_set_updated is set as well,
+	bail out, call qualify_quiet with the appropriate set otherwise.
+	(print_exited): Change qflag check to
+	is_number_in_set(QUIET_EXIT, quiet_set).
+	(usage): Document it.
+	* strace.1.in: Likewise.
+	* syscall.c (update_personality): Change qflag check to
+	is_number_in_set(QUIET_PERSONALITY, quiet_set).
+	* tests/clone-flags.test: Use --silence=exits instead of -qq.
+	* tests/count-f.test: Use -e silent=attach instead of -q.
+	* tests/options-syntax.test: Add checks.
+	* tests/strace-D.test: Use -e q=attach instead of -q.
+
+2020-02-19  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	strace: add long option aliases for -x.
+	* defs.h (enum xflag_opts): New enumeration.
+	* strace.c (xflag_str): New static variable.
+	(init) <xflag_long>: New variable.
+	(init) <enum>: Add GETOPT_HEX_STR.
+	(init) <longopts>: Add "string-in-hex" long option.
+	(init) <case GETOPT_HEX_STR>: Parse the argument using find_arg_val.
+	(init): Fail if both xflag_long and xflag are set; copy xflag_long
+	to xflag if only the former is set.
+	(usage): Document it.
+	* strace.1.in: Likewise.
+	* tests/gen_tests.in (strace--strings-in-hex,
+	strace--strings-in-hex-all, strace--strings-in-hex-non-ascii, strace-x,
+	strace-xx): New tests.
+	* tests/pure_executables.list: Add them.
+	* tests/.gitignore: Likewise.
+	* tests/options-syntax.test: Add checks.
+	* tests/strace--strings-in-hex-all.c: New file.
+	* tests/strace--strings-in-hex-non-ascii.c: Likewise.
+	* tests/strace--strings-in-hex.c: Likewise.
+	* tests/strace-x.c: Likewise.
+	* tests/strace-xx.c: Likewise.
+
+	strace: add long option aliases for -z and -Z.
+	* strace.c (init) <longopts>: Add "successful-only" and "failed-only"
+	long options for -z and -Z, respectively.
+	(init): Update the related error message.
+	(usage): Document it.
+	* strace.1.in: Likewise.
+	* tests/options-syntax.test: Add checks, update expected output.
+	* tests/status-failed-long.c: New file.
+	* tests/status-failed-status.c: Likewise.
+	* tests/status-successful-long.c: Likewise.
+	* tests/status-successful-status.c: Likewise.
+	* tests/.gitignore: Add them.
+	* tests/pure_executables.list: Likewise
+	* tests/gen_tests.in (status-failed-long, status-failed-status,
+	status-successful-long, status-successful-status): New tests.
+
+2020-02-19  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	strace: add --daemonize long option alias for -D.
+	Don't fail those who provide --daemonise or --daemonized as well.
+
+	Since multiple -D instances change behaviour and with long options
+	the last instance wins, it is better just to forbid the simultaneous
+	usage of the short and long option variants.
+
+	* strace.c (daemonize_str): New static constant.
+	(init) <daemonized_tracer_long>: New variable.
+	(init) <enum>: Add GETOPT_DAEMONIZE.
+	(init) <longopts>: Add "daemonize" long option variants.
+	(init) <case GETOPT_DAEMONIZE>: Use find_arg_val for argument parsing.
+	(init): Fail if both daemonized_tracer_long and daemonized_tracer are
+	set; copy daemonized_tracer_long to daemonized_tracer if only the former
+	is set; update the error messages that mention -D option with the alias.
+	(usage): Document it.
+	* strace.1.in: Likewise.
+	* tests/options-syntax.test: Add checks, update existing ones.
+
+2020-02-19  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	strace: mention long option aliases in error messages.
+	If a user has provided a long option alias, current error messages could
+	be confusing otherwise.
+
+	* strace.c (init): Augment error messages with long option aliases where
+	appropriate.
+	* tests/options-syntax.test: Update expected output.
+
+2020-02-19  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	strace: print long options in the option error message.
+	If a long option alias is used with incorrect argument, it's better show it
+	in the error message instead of the short option equivalent.
+
+	* strace.c (error_opt_arg): Add lopt argument, print its name
+	if it is non-NULL.
+	(init): Add lopt_idx variable, pass it to getopt_long, set loop-local
+	lopt variable to an option pointer based on lopt_idx; pass lopt
+	in error_opt_arg calls.
+	* tests/options-syntax.test: Update expected output.
+
+2020-02-19  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	strace: add a long option alias for -I.
+	And add more human-comprehensible values for it.
+
+	* strace.c (parse_interruptible_arg): New function.
+	(init) <longopts>: Add "interruptible" long option alias for 'I'.
+	(init) <case 'I'>: Call parse_interruptible_arg.
+	(usage): Document new long option alias and values.
+	* strace.1.in (parse_interruptible_arg): Likewise.
+	* tests/options-syntax.test: Add checks for the new syntax.
+	* tests/sigblock.test: Introduce -I syntax variety.
+	* tests/sigign.test: Likewise.
+
+2020-02-19  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	filter_qualify: rewrite statusstr_to_uint using find_xlat_val.
+	* filter_qualify.c (*statuses): Move inside statusstr_to_uint, change
+	the type to const struct xlat_data[], change the initialisation
+	accordingly.
+	(statusstr_to_uint): Call find_arg_val instead of open-coding search
+	in a string array.
+
+2020-02-19  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	util: rewrite parse_ts suffix matching using find_xlat_val.
+	A known behavioural change is that suffix can have any case, which
+	matches other places of option argument parsing.
+
+	* util.c (parse_ts): Change type of units to struct xlat_data[]; move
+	definition of units variable to its first usage, change its type
+	to const struct xlat_data *; use find_xlat_val instead of open-coding
+	search in units array.
+
+2020-02-19  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	util: introduce find_xlat_val and find_arg_val.
+	The commonly open-coded snippet throughout the code, especially in the
+	argument parsing code, is searching in a string-value pair array of
+	string, so let's provide a function (or, more precisely, two functions,
+	one generic and another one that targets specifically argument parsing)
+	that does precisely that, on top of existing string-value pair
+	struct xlat_data type.
+
+	* defs.h (enum find_xlat_flag_bits, enum find_xlat_flags): New
+	enumerations.
+	(find_xlat_val_ex, find_arg_val_): New declarations.
+	(find_xlat_val, find_xlat_val_case, find_arg_val): New macros.
+	* util.c (find_xlat_val_ex, find_arg_val_): New functions.
+
+2020-02-19  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	syscall: handle fd printing regardless of show_fd_path setting.
+	As of now, the way the higher 32 bits of the syscall return value
+	are printed depends on the show_fd_path (-y) setting: if it is set,
+	they are trimmed, which is pretty inconsistent.
+
+	* syscall.c (syscall_exiting_trace) <case RVAL_FD>: Check if tcp->u_rval
+	fits in int before passing it to printfd instead of a (redundant) show_fd_path
+	check (that is also done inside printfd itself).
+	* tests/bpf-success-long-y.c: New file.
+	* tests/bpf-success-long-y.test: New test.
+	* tests/.gitignore: Add bpf-success-long-y.
+	* tests/Makefile.am (check_PROGRAMS): Likewise.
+	(DECODER_TESTS): Add bpf-success-long-y.test.
+	* tests/bpf.c [!FD0_PATH] (FD0_PATH): New macro.
+	[INJECT_RETVAL] (sys_bpf): Print INJECT_RETVAL as long.
+	(BPF_MAP_CREATE_checks, BPF_OBJ_PIN_checks, BPF_OBJ_PIN_checks,
+	BPF_PROG_ATTACH_checks, BPF_RAW_TRACEPOINT_OPEN_checks,
+	BPF_TASK_FD_QUERY_checks): Append FD0_PATH to places where fd 0
+	is printed.
+	(print_BPF_PROG_QUERY_attr4, print_BPF_PROG_QUERY_attr5): Do not
+	conditionalise part of the strings with INJECT_RETVAL > 0, as we always
+	inject positive values so far.
+
+2020-02-19  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	tests/io_uring_register: properly handle big endian architectures.
+	tests/io_uring_register.c (BE_LE): New macro.
+	(main): Use BE_LE to select the address to print based on endianness.
+
+	Fixes: v5.5~41 "io_uring: add support for IORING_REGISTER_FILES_UPDATE"
+
+2020-02-12  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	strace: typo in usage (s/milliseconds/microseconds/)
+	* strace.c (usage): s/milliseconds/microseconds/
+
+	Fixes: v5.5~14 "strace: describe -e options in the help message"
+
+2020-02-12  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	printrusage: bundle rusage_t definition.
+	* printrusage.c (struct kernel_old_timeval, rusage_t): New type
+	definitions.
+	* configure.ac (AC_CHECK_MEMBERS): Check for __ru_maxrss_word,
+	__ru_ixrss_word, __ru_idrss_word, __ru_isrss_word, __ru_minflt_word,
+	__ru_majflt_word, __ru_nswap_word, __ru_inblock_word, __ru_oublock_word,
+	__ru_msgsnd_word, __ru_msgrcv_word, __ru_nsignals_word, __ru_nvcsw_word,
+	and __ru_nivcsw_word members of struct rusage.
+	* tests/waitid.c (RU_MAXRSS, RU_IXRSS, RU_IDRSS, RU_ISRSS, RU_MINFLT,
+	RU_MAJFLT, RU_NSWAP, RU_INBLOCK, RU_OUBLOCK, RU_MSGSND, RU_MSGRCV,
+	RU_NSIGNALS, RU_NVCSW, RU_NIVCSW): New macros.
+	(sprint_rusage): Use them instead of the respective ru_* field names.
+
+	Resolves: https://github.com/strace/strace/issues/122
+
+2020-02-10  Eugene Syromyatnikov  <evgsyr@gmail.com>
+	    Dmitry V. Levin  <ldv@altlinux.org>
+
+	tests: fail if patterns file is not readable in match_grep.
+	Otherwise, the test will not fail if the patterns file is missing.
+
+	* tests/init.sh (match_grep): Fail in case of non-zero exit status
+	of the read loop.
+
+2020-02-10  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	tests: turn clone_parent into a generated test.
+	clone_parent.tests does nothing, only sources clone_ptrace.
+
+	* tests/clone_parent.test: Remove.
+	* tests/Makefile.am (MISC_TESTS): Remove clone_parent.test.
+	* tests/gen_tests.in (clone_parent): New entry.
+
+2020-02-10  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	tests: support --trace syntax in run_strace_match_{diff,grep}
+	* tests/init.sh (run_strace_match_diff, run_strace_match_grep): Do not
+	add -e trace option if --trace is provided already.
+
+2020-02-10  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	strace --help: document long option aliases of -w and -X options.
+	* strace.c (usage): Document --summary-wall-clock as the long option
+	alias of -w option; document --const-print-style as the long option
+	alias of -X option.
+
+	Fixes: v5.5~11 "Add long option aliases to some options"
+
+2020-02-10  Eugene Syromyatnikov  <evgsyr@gmail.com>
+
+	strace --help: add missing newline before "Miscellaneous:"
+	* strace (usage): Add newline before "Miscellaneous:".
+
+	Fixes: v5.5~14 "strace: describe -e options in the help message"
+
+2020-02-10  MaJun  <majun258@linux.alibaba.com>
+
+	csky abiv1: fix compilation error.
+	struct pt_regs has no member r1, only a1.
+
+	* linux/csky/get_scno.c (arch_get_scno) [!__CSKYABIV2__]: Replace
+	csky_regs.r1 with csky_regs.a1.
+	* linux/csky/set_scno.c (arch_set_scno) [!__CSKYABIV2__]: Likewise.
+	* NEWS: Mention this fix.
+
+	Fixes: v5.1~99 "Add C-SKY architecture support"
+
+2020-02-10  Dmitry V. Levin  <ldv@altlinux.org>
+
+	Post-release administrivia.
+	* NEWS: Add a header line for the next release.
+	* debian/changelog.in: Add a changelog entry for 5.5-1.
+	* strace.spec.in: Likewise.
+
 2020-02-06  Dmitry V. Levin  <ldv@altlinux.org>
 
 	Prepare for 5.5 release.
diff -pruN 5.5-3/clone.c 5.9-0ubuntu2/clone.c
--- 5.5-3/clone.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/clone.c	2020-08-25 14:29:30.000000000 +0000
@@ -114,14 +114,14 @@ SYS_FUNC(clone)
 		 */
 		if ((flags & (CLONE_PARENT_SETTID|CLONE_PIDFD|CLONE_CHILD_SETTID
 			      |CLONE_CHILD_CLEARTID|CLONE_SETTLS)) == 0)
-			return RVAL_DECODED;
+			return RVAL_DECODED | RVAL_TID;
 	} else {
 		if (flags & (CLONE_PARENT_SETTID|CLONE_PIDFD)) {
 			kernel_ulong_t addr = tcp->u_arg[ARG_PTID];
 
 			tprints(", parent_tid=");
 			if (flags & CLONE_PARENT_SETTID)
-				printnum_int(tcp, addr, "%u");
+				printnum_pid(tcp, addr, PT_TID);
 			else
 				printnum_fd(tcp, addr);
 		}
@@ -134,89 +134,24 @@ SYS_FUNC(clone)
 			printaddr(tcp->u_arg[ARG_CTID]);
 		}
 	}
-	return 0;
+	return RVAL_TID;
 }
 
 
 struct strace_clone_args {
 	uint64_t flags;
-	uint64_t /* int * */ pidfd;
-	uint64_t /* int * */ child_tid;
-	uint64_t /* int * */ parent_tid;
-	uint64_t /* int */   exit_signal;
-	uint64_t stack;
+	uint64_t /* fd * */    pidfd;
+	uint64_t /* pid_t * */ child_tid;
+	uint64_t /* pid_t * */ parent_tid;
+	uint64_t /* int */     exit_signal;
+	uint64_t /* void * */  stack;
 	uint64_t stack_size;
-	uint64_t tls;
-	uint64_t set_tid;
+	uint64_t /* struct user_desc * / void * */ tls;
+	uint64_t /* pid_t * */ set_tid;
 	uint64_t set_tid_size;
+	uint64_t cgroup;
 };
 
-/**
- * Print a region of tracee memory only in case non-zero bytes are present
- * there.  It almost fits into printstr_ex, but it has some pretty specific
- * behaviour peculiarities (like printing of ellipsis on error) to readily
- * integrate it there.
- *
- * Since it is expected to be used for printing tail of a structure in tracee's
- * memory, it accepts a combination of start_addr/start_offs/total_len and does
- * the relevant calculations itself.
- *
- * @param prefix     A string printed in cases something is going to be printed.
- * @param start_addr Address of the beginning of a structure (whose tail
- *                   is supposedly to be printed) in tracee's memory.
- * @param start_offs Offset from the beginning of the structure where the tail
- *                   data starts.
- * @param total_len  Total size of the tracee's memory region containing
- *                   the structure and the tail data.
- *                   Caller is responsible for imposing a sensible (usually
- *                   mandated by the kernel interface, like get_pagesize())
- *                   limit here.
- * @param style      Passed to string_quote as "style" parameter.
- * @return           Returns true is anything was printed, false otherwise.
- */
-static bool
-print_nonzero_bytes(struct tcb *const tcp, const char *prefix,
-		    const kernel_ulong_t start_addr,
-		    const unsigned int start_offs,
-		    const unsigned int total_len,
-		    const unsigned int style)
-{
-	if (start_offs >= total_len)
-		return false;
-
-	const kernel_ulong_t addr = start_addr + start_offs;
-	const unsigned int len = total_len - start_offs;
-	const unsigned int size = MIN(len, max_strlen);
-
-	char *str = malloc(len);
-
-	if (!str) {
-		error_func_msg("memory exhausted when tried to allocate"
-                               " %u bytes", len);
-		tprintf("%s???", prefix);
-		return true;
-	}
-
-	bool ret = true;
-
-	if (umoven(tcp, addr, len, str)) {
-		tprintf("%s???", prefix);
-	} else if (is_filled(str, 0, len)) {
-		ret = false;
-	} else {
-		tprints(prefix);
-		tprintf("/* bytes %u..%u */ ", start_offs, total_len - 1);
-
-		print_quoted_string(str, size, style);
-
-		if (size < len)
-			tprints("...");
-	}
-
-	free(str);
-	return ret;
-}
-
 SYS_FUNC(clone3)
 {
 	static const size_t minsz = offsetofend(struct strace_clone_args, tls);
@@ -281,6 +216,10 @@ SYS_FUNC(clone3)
 			PRINT_FIELD_U(", ", arg, set_tid_size);
 		}
 
+		if (fetch_size > offsetof(struct strace_clone_args, cgroup)
+		    && (arg.cgroup || arg.flags & CLONE_INTO_CGROUP))
+			PRINT_FIELD_U(", ", arg, cgroup);
+
 		if (size > fetch_size)
 			print_nonzero_bytes(tcp, ", ", addr, fetch_size,
 					    MIN(size, get_pagesize()),
@@ -290,7 +229,7 @@ SYS_FUNC(clone3)
 
 		if ((arg.flags & (CLONE_PIDFD | CLONE_PARENT_SETTID)) ||
 		    (size > fetch_size))
-			return 0;
+			return RVAL_TID;
 
 		goto out;
 	}
@@ -317,7 +256,7 @@ SYS_FUNC(clone3)
 
 	if (arg.flags & CLONE_PARENT_SETTID) {
 		tprintf("%sparent_tid=", pfx);
-		printnum_int(tcp, arg.parent_tid, "%d"); /* TID */
+		printnum_pid(tcp, arg.parent_tid, PT_TID);
 		pfx = ", ";
 	}
 
@@ -340,7 +279,7 @@ SYS_FUNC(clone3)
 out:
 	tprintf(", %" PRI_klu, size);
 
-	return RVAL_DECODED;
+	return RVAL_DECODED | RVAL_TID;
 }
 
 
@@ -361,5 +300,5 @@ SYS_FUNC(unshare)
 
 SYS_FUNC(fork)
 {
-	return RVAL_DECODED;
+	return RVAL_DECODED | RVAL_TGID;
 }
diff -pruN 5.5-3/close_range.c 5.9-0ubuntu2/close_range.c
--- 5.5-3/close_range.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/close_range.c	2020-09-06 08:00:00.000000000 +0000
@@ -0,0 +1,22 @@
+/*
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
+#include "defs.h"
+#ifdef HAVE_LINUX_CLOSE_RANGE_H
+# include <linux/close_range.h>
+#endif
+#include "xlat/close_range_flags.h"
+
+SYS_FUNC(close_range)
+{
+	printfd(tcp, tcp->u_arg[0]);
+	tprints(", ");
+	printfd(tcp, tcp->u_arg[1]);
+	tprints(", ");
+	printflags(close_range_flags, tcp->u_arg[2], "CLOSE_RANGE_???");
+	return RVAL_DECODED;
+}
diff -pruN 5.5-3/compile 5.9-0ubuntu2/compile
--- 5.5-3/compile	2020-02-06 16:23:34.000000000 +0000
+++ 5.9-0ubuntu2/compile	2020-09-24 09:18:59.000000000 +0000
@@ -3,7 +3,7 @@
 
 scriptversion=2018-03-07.03; # UTC
 
-# Copyright (C) 1999-2018 Free Software Foundation, Inc.
+# Copyright (C) 1999-2020 Free Software Foundation, Inc.
 # Written by Tom Tromey <tromey@cygnus.com>.
 #
 # This program is free software; you can redistribute it and/or modify
@@ -53,7 +53,7 @@ func_file_conv ()
 	  MINGW*)
 	    file_conv=mingw
 	    ;;
-	  CYGWIN*)
+	  CYGWIN* | MSYS*)
 	    file_conv=cygwin
 	    ;;
 	  *)
@@ -67,7 +67,7 @@ func_file_conv ()
 	mingw/*)
 	  file=`cmd //C echo "$file " | sed -e 's/"\(.*\) " *$/\1/'`
 	  ;;
-	cygwin/*)
+	cygwin/* | msys/*)
 	  file=`cygpath -m "$file" || echo "$file"`
 	  ;;
 	wine/*)
diff -pruN 5.5-3/config.h.in 5.9-0ubuntu2/config.h.in
--- 5.5-3/config.h.in	2020-02-06 16:23:34.000000000 +0000
+++ 5.9-0ubuntu2/config.h.in	2020-09-24 09:18:59.000000000 +0000
@@ -72,14 +72,54 @@
    if you don't. */
 #undef HAVE_DECL_BTRFS_COMPRESS_ZLIB
 
+/* Define to 1 if you have the declaration of `BTRFS_COMPRESS_ZSTD', and to 0
+   if you don't. */
+#undef HAVE_DECL_BTRFS_COMPRESS_ZSTD
+
+/* Define to 1 if you have the declaration of `CLOSE_RANGE_UNSHARE', and to 0
+   if you don't. */
+#undef HAVE_DECL_CLOSE_RANGE_UNSHARE
+
+/* Define to 1 if you have the declaration of `CTL_ABI', and to 0 if you
+   don't. */
+#undef HAVE_DECL_CTL_ABI
+
 /* Define to 1 if you have the declaration of `CTL_ARLAN', and to 0 if you
    don't. */
 #undef HAVE_DECL_CTL_ARLAN
 
+/* Define to 1 if you have the declaration of `CTL_BUS', and to 0 if you
+   don't. */
+#undef HAVE_DECL_CTL_BUS
+
+/* Define to 1 if you have the declaration of `CTL_CPU', and to 0 if you
+   don't. */
+#undef HAVE_DECL_CTL_CPU
+
+/* Define to 1 if you have the declaration of `CTL_DEBUG', and to 0 if you
+   don't. */
+#undef HAVE_DECL_CTL_DEBUG
+
+/* Define to 1 if you have the declaration of `CTL_DEV', and to 0 if you
+   don't. */
+#undef HAVE_DECL_CTL_DEV
+
 /* Define to 1 if you have the declaration of `CTL_FRV', and to 0 if you
    don't. */
 #undef HAVE_DECL_CTL_FRV
 
+/* Define to 1 if you have the declaration of `CTL_FS', and to 0 if you don't.
+   */
+#undef HAVE_DECL_CTL_FS
+
+/* Define to 1 if you have the declaration of `CTL_KERN', and to 0 if you
+   don't. */
+#undef HAVE_DECL_CTL_KERN
+
+/* Define to 1 if you have the declaration of `CTL_NET', and to 0 if you
+   don't. */
+#undef HAVE_DECL_CTL_NET
+
 /* Define to 1 if you have the declaration of `CTL_PM', and to 0 if you don't.
    */
 #undef HAVE_DECL_CTL_PM
@@ -96,22 +136,274 @@
    don't. */
 #undef HAVE_DECL_CTL_SUNRPC
 
+/* Define to 1 if you have the declaration of `CTL_VM', and to 0 if you don't.
+   */
+#undef HAVE_DECL_CTL_VM
+
+/* Define to 1 if you have the declaration of `IFLA_ADDRESS', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_ADDRESS
+
 /* Define to 1 if you have the declaration of `IFLA_AF_SPEC', and to 0 if you
    don't. */
 #undef HAVE_DECL_IFLA_AF_SPEC
 
+/* Define to 1 if you have the declaration of `IFLA_ALT_IFNAME', and to 0 if
+   you don't. */
+#undef HAVE_DECL_IFLA_ALT_IFNAME
+
+/* Define to 1 if you have the declaration of `IFLA_BROADCAST', and to 0 if
+   you don't. */
+#undef HAVE_DECL_IFLA_BROADCAST
+
+/* Define to 1 if you have the declaration of `IFLA_CARRIER', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_CARRIER
+
+/* Define to 1 if you have the declaration of `IFLA_CARRIER_CHANGES', and to 0
+   if you don't. */
+#undef HAVE_DECL_IFLA_CARRIER_CHANGES
+
+/* Define to 1 if you have the declaration of `IFLA_CARRIER_DOWN_COUNT', and
+   to 0 if you don't. */
+#undef HAVE_DECL_IFLA_CARRIER_DOWN_COUNT
+
+/* Define to 1 if you have the declaration of `IFLA_CARRIER_UP_COUNT', and to
+   0 if you don't. */
+#undef HAVE_DECL_IFLA_CARRIER_UP_COUNT
+
+/* Define to 1 if you have the declaration of `IFLA_COST', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_COST
+
+/* Define to 1 if you have the declaration of `IFLA_EVENT', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_EVENT
+
+/* Define to 1 if you have the declaration of `IFLA_EXT_MASK', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_EXT_MASK
+
+/* Define to 1 if you have the declaration of `IFLA_GROUP', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_GROUP
+
+/* Define to 1 if you have the declaration of `IFLA_GSO_MAX_SEGS', and to 0 if
+   you don't. */
+#undef HAVE_DECL_IFLA_GSO_MAX_SEGS
+
+/* Define to 1 if you have the declaration of `IFLA_GSO_MAX_SIZE', and to 0 if
+   you don't. */
+#undef HAVE_DECL_IFLA_GSO_MAX_SIZE
+
+/* Define to 1 if you have the declaration of `IFLA_IFALIAS', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_IFALIAS
+
+/* Define to 1 if you have the declaration of `IFLA_IFNAME', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_IFNAME
+
+/* Define to 1 if you have the declaration of `IFLA_IF_NETNSID', and to 0 if
+   you don't. */
+#undef HAVE_DECL_IFLA_IF_NETNSID
+
+/* Define to 1 if you have the declaration of `IFLA_LINK', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_LINK
+
+/* Define to 1 if you have the declaration of `IFLA_LINKINFO', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_LINKINFO
+
+/* Define to 1 if you have the declaration of `IFLA_LINKMODE', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_LINKMODE
+
+/* Define to 1 if you have the declaration of `IFLA_LINK_NETNSID', and to 0 if
+   you don't. */
+#undef HAVE_DECL_IFLA_LINK_NETNSID
+
+/* Define to 1 if you have the declaration of `IFLA_MAP', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_MAP
+
+/* Define to 1 if you have the declaration of `IFLA_MASTER', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_MASTER
+
+/* Define to 1 if you have the declaration of `IFLA_MAX_MTU', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_MAX_MTU
+
+/* Define to 1 if you have the declaration of `IFLA_MIN_MTU', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_MIN_MTU
+
+/* Define to 1 if you have the declaration of `IFLA_MTU', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_MTU
+
+/* Define to 1 if you have the declaration of `IFLA_NET_NS_FD', and to 0 if
+   you don't. */
+#undef HAVE_DECL_IFLA_NET_NS_FD
+
+/* Define to 1 if you have the declaration of `IFLA_NET_NS_PID', and to 0 if
+   you don't. */
+#undef HAVE_DECL_IFLA_NET_NS_PID
+
+/* Define to 1 if you have the declaration of `IFLA_NEW_IFINDEX', and to 0 if
+   you don't. */
+#undef HAVE_DECL_IFLA_NEW_IFINDEX
+
+/* Define to 1 if you have the declaration of `IFLA_NEW_NETNSID', and to 0 if
+   you don't. */
+#undef HAVE_DECL_IFLA_NEW_NETNSID
+
+/* Define to 1 if you have the declaration of `IFLA_NUM_RX_QUEUES', and to 0
+   if you don't. */
+#undef HAVE_DECL_IFLA_NUM_RX_QUEUES
+
+/* Define to 1 if you have the declaration of `IFLA_NUM_TX_QUEUES', and to 0
+   if you don't. */
+#undef HAVE_DECL_IFLA_NUM_TX_QUEUES
+
+/* Define to 1 if you have the declaration of `IFLA_NUM_VF', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_NUM_VF
+
+/* Define to 1 if you have the declaration of `IFLA_OPERSTATE', and to 0 if
+   you don't. */
+#undef HAVE_DECL_IFLA_OPERSTATE
+
+/* Define to 1 if you have the declaration of `IFLA_PAD', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_PAD
+
+/* Define to 1 if you have the declaration of `IFLA_PERM_ADDRESS', and to 0 if
+   you don't. */
+#undef HAVE_DECL_IFLA_PERM_ADDRESS
+
+/* Define to 1 if you have the declaration of `IFLA_PHYS_PORT_ID', and to 0 if
+   you don't. */
+#undef HAVE_DECL_IFLA_PHYS_PORT_ID
+
+/* Define to 1 if you have the declaration of `IFLA_PHYS_PORT_NAME', and to 0
+   if you don't. */
+#undef HAVE_DECL_IFLA_PHYS_PORT_NAME
+
+/* Define to 1 if you have the declaration of `IFLA_PHYS_SWITCH_ID', and to 0
+   if you don't. */
+#undef HAVE_DECL_IFLA_PHYS_SWITCH_ID
+
 /* Define to 1 if you have the declaration of `IFLA_PORT_SELF', and to 0 if
    you don't. */
 #undef HAVE_DECL_IFLA_PORT_SELF
 
+/* Define to 1 if you have the declaration of `IFLA_PRIORITY', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_PRIORITY
+
+/* Define to 1 if you have the declaration of `IFLA_PROMISCUITY', and to 0 if
+   you don't. */
+#undef HAVE_DECL_IFLA_PROMISCUITY
+
+/* Define to 1 if you have the declaration of `IFLA_PROP_LIST', and to 0 if
+   you don't. */
+#undef HAVE_DECL_IFLA_PROP_LIST
+
 /* Define to 1 if you have the declaration of `IFLA_PROTINFO', and to 0 if you
    don't. */
 #undef HAVE_DECL_IFLA_PROTINFO
 
+/* Define to 1 if you have the declaration of `IFLA_PROTO_DOWN', and to 0 if
+   you don't. */
+#undef HAVE_DECL_IFLA_PROTO_DOWN
+
+/* Define to 1 if you have the declaration of `IFLA_PROTO_DOWN_REASON', and to
+   0 if you don't. */
+#undef HAVE_DECL_IFLA_PROTO_DOWN_REASON
+
+/* Define to 1 if you have the declaration of `IFLA_QDISC', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_QDISC
+
+/* Define to 1 if you have the declaration of `IFLA_STATS', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_STATS
+
+/* Define to 1 if you have the declaration of `IFLA_STATS64', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_STATS64
+
+/* Define to 1 if you have the declaration of `IFLA_TXQLEN', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_TXQLEN
+
+/* Define to 1 if you have the declaration of `IFLA_UNSPEC', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_UNSPEC
+
+/* Define to 1 if you have the declaration of `IFLA_VFINFO_LIST', and to 0 if
+   you don't. */
+#undef HAVE_DECL_IFLA_VFINFO_LIST
+
+/* Define to 1 if you have the declaration of `IFLA_VF_PORTS', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_VF_PORTS
+
+/* Define to 1 if you have the declaration of `IFLA_WEIGHT', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_WEIGHT
+
+/* Define to 1 if you have the declaration of `IFLA_WIRELESS', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_WIRELESS
+
 /* Define to 1 if you have the declaration of `IFLA_XDP', and to 0 if you
    don't. */
 #undef HAVE_DECL_IFLA_XDP
 
+/* Define to 1 if you have the declaration of `IFLA_XDP_ATTACHED', and to 0 if
+   you don't. */
+#undef HAVE_DECL_IFLA_XDP_ATTACHED
+
+/* Define to 1 if you have the declaration of `IFLA_XDP_DRV_PROG_ID', and to 0
+   if you don't. */
+#undef HAVE_DECL_IFLA_XDP_DRV_PROG_ID
+
+/* Define to 1 if you have the declaration of `IFLA_XDP_EXPECTED_FD', and to 0
+   if you don't. */
+#undef HAVE_DECL_IFLA_XDP_EXPECTED_FD
+
+/* Define to 1 if you have the declaration of `IFLA_XDP_FD', and to 0 if you
+   don't. */
+#undef HAVE_DECL_IFLA_XDP_FD
+
+/* Define to 1 if you have the declaration of `IFLA_XDP_FLAGS', and to 0 if
+   you don't. */
+#undef HAVE_DECL_IFLA_XDP_FLAGS
+
+/* Define to 1 if you have the declaration of `IFLA_XDP_HW_PROG_ID', and to 0
+   if you don't. */
+#undef HAVE_DECL_IFLA_XDP_HW_PROG_ID
+
+/* Define to 1 if you have the declaration of `IFLA_XDP_PROG_ID', and to 0 if
+   you don't. */
+#undef HAVE_DECL_IFLA_XDP_PROG_ID
+
+/* Define to 1 if you have the declaration of `IFLA_XDP_SKB_PROG_ID', and to 0
+   if you don't. */
+#undef HAVE_DECL_IFLA_XDP_SKB_PROG_ID
+
+/* Define to 1 if you have the declaration of `IFLA_XDP_UNSPEC', and to 0 if
+   you don't. */
+#undef HAVE_DECL_IFLA_XDP_UNSPEC
+
+/* Define to 1 if you have the declaration of `KERN_ACCT', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_ACCT
+
 /* Define to 1 if you have the declaration of `KERN_ACPI_VIDEO_FLAGS', and to
    0 if you don't. */
 #undef HAVE_DECL_KERN_ACPI_VIDEO_FLAGS
@@ -120,10 +412,42 @@
    if you don't. */
 #undef HAVE_DECL_KERN_BOOTLOADER_TYPE
 
+/* Define to 1 if you have the declaration of `KERN_CADPID', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_CADPID
+
 /* Define to 1 if you have the declaration of `KERN_COMPAT_LOG', and to 0 if
    you don't. */
 #undef HAVE_DECL_KERN_COMPAT_LOG
 
+/* Define to 1 if you have the declaration of `KERN_CORE_PATTERN', and to 0 if
+   you don't. */
+#undef HAVE_DECL_KERN_CORE_PATTERN
+
+/* Define to 1 if you have the declaration of `KERN_CORE_USES_PID', and to 0
+   if you don't. */
+#undef HAVE_DECL_KERN_CORE_USES_PID
+
+/* Define to 1 if you have the declaration of `KERN_CTLALTDEL', and to 0 if
+   you don't. */
+#undef HAVE_DECL_KERN_CTLALTDEL
+
+/* Define to 1 if you have the declaration of `KERN_DOMAINNAME', and to 0 if
+   you don't. */
+#undef HAVE_DECL_KERN_DOMAINNAME
+
+/* Define to 1 if you have the declaration of `KERN_HOTPLUG', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_HOTPLUG
+
+/* Define to 1 if you have the declaration of `KERN_HPPA_PWRSW', and to 0 if
+   you don't. */
+#undef HAVE_DECL_KERN_HPPA_PWRSW
+
+/* Define to 1 if you have the declaration of `KERN_HPPA_UNALIGNED', and to 0
+   if you don't. */
+#undef HAVE_DECL_KERN_HPPA_UNALIGNED
+
 /* Define to 1 if you have the declaration of `KERN_HZ_TIMER', and to 0 if you
    don't. */
 #undef HAVE_DECL_KERN_HZ_TIMER
@@ -132,10 +456,42 @@
    if you don't. */
 #undef HAVE_DECL_KERN_IA64_UNALIGNED
 
+/* Define to 1 if you have the declaration of `KERN_IEEE_EMULATION_WARNINGS',
+   and to 0 if you don't. */
+#undef HAVE_DECL_KERN_IEEE_EMULATION_WARNINGS
+
 /* Define to 1 if you have the declaration of `KERN_MAX_LOCK_DEPTH', and to 0
    if you don't. */
 #undef HAVE_DECL_KERN_MAX_LOCK_DEPTH
 
+/* Define to 1 if you have the declaration of `KERN_MAX_THREADS', and to 0 if
+   you don't. */
+#undef HAVE_DECL_KERN_MAX_THREADS
+
+/* Define to 1 if you have the declaration of `KERN_MODPROBE', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_MODPROBE
+
+/* Define to 1 if you have the declaration of `KERN_MSGMAX', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_MSGMAX
+
+/* Define to 1 if you have the declaration of `KERN_MSGMNB', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_MSGMNB
+
+/* Define to 1 if you have the declaration of `KERN_MSGMNI', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_MSGMNI
+
+/* Define to 1 if you have the declaration of `KERN_MSGPOOL', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_MSGPOOL
+
+/* Define to 1 if you have the declaration of `KERN_NAMETRANS', and to 0 if
+   you don't. */
+#undef HAVE_DECL_KERN_NAMETRANS
+
 /* Define to 1 if you have the declaration of `KERN_NGROUPS_MAX', and to 0 if
    you don't. */
 #undef HAVE_DECL_KERN_NGROUPS_MAX
@@ -144,10 +500,42 @@
    you don't. */
 #undef HAVE_DECL_KERN_NMI_WATCHDOG
 
+/* Define to 1 if you have the declaration of `KERN_NODENAME', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_NODENAME
+
+/* Define to 1 if you have the declaration of `KERN_OSRELEASE', and to 0 if
+   you don't. */
+#undef HAVE_DECL_KERN_OSRELEASE
+
+/* Define to 1 if you have the declaration of `KERN_OSREV', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_OSREV
+
+/* Define to 1 if you have the declaration of `KERN_OSTYPE', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_OSTYPE
+
+/* Define to 1 if you have the declaration of `KERN_OVERFLOWGID', and to 0 if
+   you don't. */
+#undef HAVE_DECL_KERN_OVERFLOWGID
+
+/* Define to 1 if you have the declaration of `KERN_OVERFLOWUID', and to 0 if
+   you don't. */
+#undef HAVE_DECL_KERN_OVERFLOWUID
+
+/* Define to 1 if you have the declaration of `KERN_PANIC', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_PANIC
+
 /* Define to 1 if you have the declaration of `KERN_PANIC_ON_NMI', and to 0 if
    you don't. */
 #undef HAVE_DECL_KERN_PANIC_ON_NMI
 
+/* Define to 1 if you have the declaration of `KERN_PANIC_ON_OOPS', and to 0
+   if you don't. */
+#undef HAVE_DECL_KERN_PANIC_ON_OOPS
+
 /* Define to 1 if you have the declaration of `KERN_PANIC_ON_WARN', and to 0
    if you don't. */
 #undef HAVE_DECL_KERN_PANIC_ON_WARN
@@ -156,6 +544,30 @@
    you don't. */
 #undef HAVE_DECL_KERN_PANIC_PRINT
 
+/* Define to 1 if you have the declaration of `KERN_PIDMAX', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_PIDMAX
+
+/* Define to 1 if you have the declaration of `KERN_PPC_HTABRECLAIM', and to 0
+   if you don't. */
+#undef HAVE_DECL_KERN_PPC_HTABRECLAIM
+
+/* Define to 1 if you have the declaration of `KERN_PPC_L2CR', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_PPC_L2CR
+
+/* Define to 1 if you have the declaration of `KERN_PPC_POWERSAVE_NAP', and to
+   0 if you don't. */
+#undef HAVE_DECL_KERN_PPC_POWERSAVE_NAP
+
+/* Define to 1 if you have the declaration of `KERN_PPC_ZEROPAGED', and to 0
+   if you don't. */
+#undef HAVE_DECL_KERN_PPC_ZEROPAGED
+
+/* Define to 1 if you have the declaration of `KERN_PRINTK', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_PRINTK
+
 /* Define to 1 if you have the declaration of `KERN_PRINTK_RATELIMIT', and to
    0 if you don't. */
 #undef HAVE_DECL_KERN_PRINTK_RATELIMIT
@@ -164,30 +576,102 @@
    and to 0 if you don't. */
 #undef HAVE_DECL_KERN_PRINTK_RATELIMIT_BURST
 
+/* Define to 1 if you have the declaration of `KERN_PROF', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_PROF
+
 /* Define to 1 if you have the declaration of `KERN_PTY', and to 0 if you
    don't. */
 #undef HAVE_DECL_KERN_PTY
 
+/* Define to 1 if you have the declaration of `KERN_RANDOM', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_RANDOM
+
 /* Define to 1 if you have the declaration of `KERN_RANDOMIZE', and to 0 if
    you don't. */
 #undef HAVE_DECL_KERN_RANDOMIZE
 
+/* Define to 1 if you have the declaration of `KERN_REALROOTDEV', and to 0 if
+   you don't. */
+#undef HAVE_DECL_KERN_REALROOTDEV
+
+/* Define to 1 if you have the declaration of `KERN_RTSIGMAX', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_RTSIGMAX
+
+/* Define to 1 if you have the declaration of `KERN_RTSIGNR', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_RTSIGNR
+
+/* Define to 1 if you have the declaration of `KERN_S390_USER_DEBUG_LOGGING',
+   and to 0 if you don't. */
+#undef HAVE_DECL_KERN_S390_USER_DEBUG_LOGGING
+
+/* Define to 1 if you have the declaration of `KERN_SECUREMASK', and to 0 if
+   you don't. */
+#undef HAVE_DECL_KERN_SECUREMASK
+
+/* Define to 1 if you have the declaration of `KERN_SEM', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_SEM
+
 /* Define to 1 if you have the declaration of `KERN_SETUID_DUMPABLE', and to 0
    if you don't. */
 #undef HAVE_DECL_KERN_SETUID_DUMPABLE
 
+/* Define to 1 if you have the declaration of `KERN_SG_BIG_BUFF', and to 0 if
+   you don't. */
+#undef HAVE_DECL_KERN_SG_BIG_BUFF
+
+/* Define to 1 if you have the declaration of `KERN_SHMALL', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_SHMALL
+
+/* Define to 1 if you have the declaration of `KERN_SHMMAX', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_SHMMAX
+
+/* Define to 1 if you have the declaration of `KERN_SHMMNI', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_SHMMNI
+
+/* Define to 1 if you have the declaration of `KERN_SHMPATH', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_SHMPATH
+
+/* Define to 1 if you have the declaration of `KERN_SPARC_REBOOT', and to 0 if
+   you don't. */
+#undef HAVE_DECL_KERN_SPARC_REBOOT
+
 /* Define to 1 if you have the declaration of `KERN_SPARC_SCONS_PWROFF', and
    to 0 if you don't. */
 #undef HAVE_DECL_KERN_SPARC_SCONS_PWROFF
 
+/* Define to 1 if you have the declaration of `KERN_SPARC_STOP_A', and to 0 if
+   you don't. */
+#undef HAVE_DECL_KERN_SPARC_STOP_A
+
 /* Define to 1 if you have the declaration of `KERN_SPIN_RETRY', and to 0 if
    you don't. */
 #undef HAVE_DECL_KERN_SPIN_RETRY
 
+/* Define to 1 if you have the declaration of `KERN_SYSRQ', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_SYSRQ
+
+/* Define to 1 if you have the declaration of `KERN_TAINTED', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_TAINTED
+
 /* Define to 1 if you have the declaration of `KERN_UNKNOWN_NMI_PANIC', and to
    0 if you don't. */
 #undef HAVE_DECL_KERN_UNKNOWN_NMI_PANIC
 
+/* Define to 1 if you have the declaration of `KERN_VERSION', and to 0 if you
+   don't. */
+#undef HAVE_DECL_KERN_VERSION
+
 /* Define to 1 if you have the declaration of `LO_FLAGS_AUTOCLEAR', and to 0
    if you don't. */
 #undef HAVE_DECL_LO_FLAGS_AUTOCLEAR
@@ -208,6 +692,22 @@
    you don't. */
 #undef HAVE_DECL_LO_FLAGS_USE_AOPS
 
+/* Define to 1 if you have the declaration of `NET_802', and to 0 if you
+   don't. */
+#undef HAVE_DECL_NET_802
+
+/* Define to 1 if you have the declaration of `NET_ATALK', and to 0 if you
+   don't. */
+#undef HAVE_DECL_NET_ATALK
+
+/* Define to 1 if you have the declaration of `NET_AX25', and to 0 if you
+   don't. */
+#undef HAVE_DECL_NET_AX25
+
+/* Define to 1 if you have the declaration of `NET_BRIDGE', and to 0 if you
+   don't. */
+#undef HAVE_DECL_NET_BRIDGE
+
 /* Define to 1 if you have the declaration of `NET_CIPSOV4_CACHE_BUCKET_SIZE',
    and to 0 if you don't. */
 #undef HAVE_DECL_NET_CIPSOV4_CACHE_BUCKET_SIZE
@@ -224,6 +724,10 @@
    and to 0 if you don't. */
 #undef HAVE_DECL_NET_CIPSOV4_RBM_STRICTVALID
 
+/* Define to 1 if you have the declaration of `NET_CORE', and to 0 if you
+   don't. */
+#undef HAVE_DECL_NET_CORE
+
 /* Define to 1 if you have the declaration of `NET_CORE_AEVENT_ETIME', and to
    0 if you don't. */
 #undef HAVE_DECL_NET_CORE_AEVENT_ETIME
@@ -240,14 +744,122 @@
    0 if you don't. */
 #undef HAVE_DECL_NET_CORE_DESTROY_DELAY
 
-/* Define to 1 if you have the declaration of `NET_CORE_WARNINGS', and to 0 if
-   you don't. */
-#undef HAVE_DECL_NET_CORE_WARNINGS
+/* Define to 1 if you have the declaration of `NET_CORE_DEV_WEIGHT', and to 0
+   if you don't. */
+#undef HAVE_DECL_NET_CORE_DEV_WEIGHT
+
+/* Define to 1 if you have the declaration of `NET_CORE_DIVERT_VERSION', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_CORE_DIVERT_VERSION
+
+/* Define to 1 if you have the declaration of `NET_CORE_FASTROUTE', and to 0
+   if you don't. */
+#undef HAVE_DECL_NET_CORE_FASTROUTE
+
+/* Define to 1 if you have the declaration of `NET_CORE_HOT_LIST_LENGTH', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_CORE_HOT_LIST_LENGTH
+
+/* Define to 1 if you have the declaration of `NET_CORE_LO_CONG', and to 0 if
+   you don't. */
+#undef HAVE_DECL_NET_CORE_LO_CONG
+
+/* Define to 1 if you have the declaration of `NET_CORE_MAX_BACKLOG', and to 0
+   if you don't. */
+#undef HAVE_DECL_NET_CORE_MAX_BACKLOG
+
+/* Define to 1 if you have the declaration of `NET_CORE_MOD_CONG', and to 0 if
+   you don't. */
+#undef HAVE_DECL_NET_CORE_MOD_CONG
+
+/* Define to 1 if you have the declaration of `NET_CORE_MSG_BURST', and to 0
+   if you don't. */
+#undef HAVE_DECL_NET_CORE_MSG_BURST
+
+/* Define to 1 if you have the declaration of `NET_CORE_MSG_COST', and to 0 if
+   you don't. */
+#undef HAVE_DECL_NET_CORE_MSG_COST
+
+/* Define to 1 if you have the declaration of `NET_CORE_NO_CONG', and to 0 if
+   you don't. */
+#undef HAVE_DECL_NET_CORE_NO_CONG
+
+/* Define to 1 if you have the declaration of `NET_CORE_NO_CONG_THRESH', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_CORE_NO_CONG_THRESH
+
+/* Define to 1 if you have the declaration of `NET_CORE_OPTMEM_MAX', and to 0
+   if you don't. */
+#undef HAVE_DECL_NET_CORE_OPTMEM_MAX
+
+/* Define to 1 if you have the declaration of `NET_CORE_RMEM_DEFAULT', and to
+   0 if you don't. */
+#undef HAVE_DECL_NET_CORE_RMEM_DEFAULT
+
+/* Define to 1 if you have the declaration of `NET_CORE_RMEM_MAX', and to 0 if
+   you don't. */
+#undef HAVE_DECL_NET_CORE_RMEM_MAX
+
+/* Define to 1 if you have the declaration of `NET_CORE_SOMAXCONN', and to 0
+   if you don't. */
+#undef HAVE_DECL_NET_CORE_SOMAXCONN
+
+/* Define to 1 if you have the declaration of `NET_CORE_WARNINGS', and to 0 if
+   you don't. */
+#undef HAVE_DECL_NET_CORE_WARNINGS
+
+/* Define to 1 if you have the declaration of `NET_CORE_WMEM_DEFAULT', and to
+   0 if you don't. */
+#undef HAVE_DECL_NET_CORE_WMEM_DEFAULT
+
+/* Define to 1 if you have the declaration of `NET_CORE_WMEM_MAX', and to 0 if
+   you don't. */
+#undef HAVE_DECL_NET_CORE_WMEM_MAX
 
 /* Define to 1 if you have the declaration of `NET_DCCP', and to 0 if you
    don't. */
 #undef HAVE_DECL_NET_DCCP
 
+/* Define to 1 if you have the declaration of `NET_DECNET', and to 0 if you
+   don't. */
+#undef HAVE_DECL_NET_DECNET
+
+/* Define to 1 if you have the declaration of `NET_ECONET', and to 0 if you
+   don't. */
+#undef HAVE_DECL_NET_ECONET
+
+/* Define to 1 if you have the declaration of `NET_ETHER', and to 0 if you
+   don't. */
+#undef HAVE_DECL_NET_ETHER
+
+/* Define to 1 if you have the declaration of `NET_IPV4', and to 0 if you
+   don't. */
+#undef HAVE_DECL_NET_IPV4
+
+/* Define to 1 if you have the declaration of `NET_IPV4_ALWAYS_DEFRAG', and to
+   0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ALWAYS_DEFRAG
+
+/* Define to 1 if you have the declaration of `NET_IPV4_AUTOCONFIG', and to 0
+   if you don't. */
+#undef HAVE_DECL_NET_IPV4_AUTOCONFIG
+
+/* Define to 1 if you have the declaration of `NET_IPV4_CONF', and to 0 if you
+   don't. */
+#undef HAVE_DECL_NET_IPV4_CONF
+
+/* Define to 1 if you have the declaration of
+   `NET_IPV4_CONF_ACCEPT_REDIRECTS', and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_CONF_ACCEPT_REDIRECTS
+
+/* Define to 1 if you have the declaration of
+   `NET_IPV4_CONF_ACCEPT_SOURCE_ROUTE', and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_CONF_ACCEPT_SOURCE_ROUTE
+
+/* Define to 1 if you have the declaration of `NET_IPV4_CONF_ARPFILTER', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_CONF_ARPFILTER
+
 /* Define to 1 if you have the declaration of `NET_IPV4_CONF_ARP_ACCEPT', and
    to 0 if you don't. */
 #undef HAVE_DECL_NET_IPV4_CONF_ARP_ACCEPT
@@ -264,42 +876,418 @@
    to 0 if you don't. */
 #undef HAVE_DECL_NET_IPV4_CONF_ARP_NOTIFY
 
+/* Define to 1 if you have the declaration of `NET_IPV4_CONF_BOOTP_RELAY', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_CONF_BOOTP_RELAY
+
 /* Define to 1 if you have the declaration of
    `NET_IPV4_CONF_FORCE_IGMP_VERSION', and to 0 if you don't. */
 #undef HAVE_DECL_NET_IPV4_CONF_FORCE_IGMP_VERSION
 
+/* Define to 1 if you have the declaration of `NET_IPV4_CONF_FORWARDING', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_CONF_FORWARDING
+
+/* Define to 1 if you have the declaration of `NET_IPV4_CONF_LOG_MARTIANS',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_CONF_LOG_MARTIANS
+
+/* Define to 1 if you have the declaration of `NET_IPV4_CONF_MC_FORWARDING',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_CONF_MC_FORWARDING
+
+/* Define to 1 if you have the declaration of `NET_IPV4_CONF_MEDIUM_ID', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_CONF_MEDIUM_ID
+
+/* Define to 1 if you have the declaration of `NET_IPV4_CONF_NOPOLICY', and to
+   0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_CONF_NOPOLICY
+
+/* Define to 1 if you have the declaration of `NET_IPV4_CONF_NOXFRM', and to 0
+   if you don't. */
+#undef HAVE_DECL_NET_IPV4_CONF_NOXFRM
+
 /* Define to 1 if you have the declaration of
    `NET_IPV4_CONF_PROMOTE_SECONDARIES', and to 0 if you don't. */
 #undef HAVE_DECL_NET_IPV4_CONF_PROMOTE_SECONDARIES
 
+/* Define to 1 if you have the declaration of `NET_IPV4_CONF_PROXY_ARP', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_CONF_PROXY_ARP
+
+/* Define to 1 if you have the declaration of `NET_IPV4_CONF_RP_FILTER', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_CONF_RP_FILTER
+
+/* Define to 1 if you have the declaration of
+   `NET_IPV4_CONF_SECURE_REDIRECTS', and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_CONF_SECURE_REDIRECTS
+
+/* Define to 1 if you have the declaration of `NET_IPV4_CONF_SEND_REDIRECTS',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_CONF_SEND_REDIRECTS
+
+/* Define to 1 if you have the declaration of `NET_IPV4_CONF_SHARED_MEDIA',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_CONF_SHARED_MEDIA
+
+/* Define to 1 if you have the declaration of `NET_IPV4_CONF_TAG', and to 0 if
+   you don't. */
+#undef HAVE_DECL_NET_IPV4_CONF_TAG
+
+/* Define to 1 if you have the declaration of `NET_IPV4_DEFAULT_TTL', and to 0
+   if you don't. */
+#undef HAVE_DECL_NET_IPV4_DEFAULT_TTL
+
+/* Define to 1 if you have the declaration of `NET_IPV4_DYNADDR', and to 0 if
+   you don't. */
+#undef HAVE_DECL_NET_IPV4_DYNADDR
+
+/* Define to 1 if you have the declaration of `NET_IPV4_FIB_HASH', and to 0 if
+   you don't. */
+#undef HAVE_DECL_NET_IPV4_FIB_HASH
+
+/* Define to 1 if you have the declaration of `NET_IPV4_FORWARD', and to 0 if
+   you don't. */
+#undef HAVE_DECL_NET_IPV4_FORWARD
+
+/* Define to 1 if you have the declaration of
+   `NET_IPV4_ICMP_DESTUNREACH_RATE', and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ICMP_DESTUNREACH_RATE
+
+/* Define to 1 if you have the declaration of `NET_IPV4_ICMP_ECHOREPLY_RATE',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ICMP_ECHOREPLY_RATE
+
+/* Define to 1 if you have the declaration of `NET_IPV4_ICMP_ECHO_IGNORE_ALL',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ICMP_ECHO_IGNORE_ALL
+
+/* Define to 1 if you have the declaration of
+   `NET_IPV4_ICMP_ECHO_IGNORE_BROADCASTS', and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ICMP_ECHO_IGNORE_BROADCASTS
+
 /* Define to 1 if you have the declaration of
    `NET_IPV4_ICMP_ERRORS_USE_INBOUND_IFADDR', and to 0 if you don't. */
 #undef HAVE_DECL_NET_IPV4_ICMP_ERRORS_USE_INBOUND_IFADDR
 
+/* Define to 1 if you have the declaration of
+   `NET_IPV4_ICMP_IGNORE_BOGUS_ERROR_RESPONSES', and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ICMP_IGNORE_BOGUS_ERROR_RESPONSES
+
+/* Define to 1 if you have the declaration of `NET_IPV4_ICMP_PARAMPROB_RATE',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ICMP_PARAMPROB_RATE
+
+/* Define to 1 if you have the declaration of `NET_IPV4_ICMP_RATELIMIT', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ICMP_RATELIMIT
+
+/* Define to 1 if you have the declaration of `NET_IPV4_ICMP_RATEMASK', and to
+   0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ICMP_RATEMASK
+
+/* Define to 1 if you have the declaration of
+   `NET_IPV4_ICMP_SOURCEQUENCH_RATE', and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ICMP_SOURCEQUENCH_RATE
+
+/* Define to 1 if you have the declaration of `NET_IPV4_ICMP_TIMEEXCEED_RATE',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ICMP_TIMEEXCEED_RATE
+
+/* Define to 1 if you have the declaration of `NET_IPV4_IGMP_MAX_MEMBERSHIPS',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_IGMP_MAX_MEMBERSHIPS
+
 /* Define to 1 if you have the declaration of `NET_IPV4_IGMP_MAX_MSF', and to
    0 if you don't. */
 #undef HAVE_DECL_NET_IPV4_IGMP_MAX_MSF
 
+/* Define to 1 if you have the declaration of `NET_IPV4_INET_PEER_GC_MAXTIME',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_INET_PEER_GC_MAXTIME
+
+/* Define to 1 if you have the declaration of `NET_IPV4_INET_PEER_GC_MINTIME',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_INET_PEER_GC_MINTIME
+
+/* Define to 1 if you have the declaration of `NET_IPV4_INET_PEER_MAXTTL', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_INET_PEER_MAXTTL
+
+/* Define to 1 if you have the declaration of `NET_IPV4_INET_PEER_MINTTL', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_INET_PEER_MINTTL
+
+/* Define to 1 if you have the declaration of `NET_IPV4_INET_PEER_THRESHOLD',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_INET_PEER_THRESHOLD
+
+/* Define to 1 if you have the declaration of `NET_IPV4_IPFRAG_HIGH_THRESH',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_IPFRAG_HIGH_THRESH
+
+/* Define to 1 if you have the declaration of `NET_IPV4_IPFRAG_LOW_THRESH',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_IPFRAG_LOW_THRESH
+
 /* Define to 1 if you have the declaration of `NET_IPV4_IPFRAG_MAX_DIST', and
    to 0 if you don't. */
 #undef HAVE_DECL_NET_IPV4_IPFRAG_MAX_DIST
 
 /* Define to 1 if you have the declaration of
+   `NET_IPV4_IPFRAG_SECRET_INTERVAL', and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_IPFRAG_SECRET_INTERVAL
+
+/* Define to 1 if you have the declaration of `NET_IPV4_IPFRAG_TIME', and to 0
+   if you don't. */
+#undef HAVE_DECL_NET_IPV4_IPFRAG_TIME
+
+/* Define to 1 if you have the declaration of `NET_IPV4_IP_MASQ_DEBUG', and to
+   0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_IP_MASQ_DEBUG
+
+/* Define to 1 if you have the declaration of `NET_IPV4_LOCAL_PORT_RANGE', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_LOCAL_PORT_RANGE
+
+/* Define to 1 if you have the declaration of `NET_IPV4_NEIGH', and to 0 if
+   you don't. */
+#undef HAVE_DECL_NET_IPV4_NEIGH
+
+/* Define to 1 if you have the declaration of `NET_IPV4_NETFILTER', and to 0
+   if you don't. */
+#undef HAVE_DECL_NET_IPV4_NETFILTER
+
+/* Define to 1 if you have the declaration of `NET_IPV4_NONLOCAL_BIND', and to
+   0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_NONLOCAL_BIND
+
+/* Define to 1 if you have the declaration of `NET_IPV4_NO_PMTU_DISC', and to
+   0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_NO_PMTU_DISC
+
+/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE', and to 0 if
+   you don't. */
+#undef HAVE_DECL_NET_IPV4_ROUTE
+
+/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_ERROR_BURST',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ROUTE_ERROR_BURST
+
+/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_ERROR_COST', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ROUTE_ERROR_COST
+
+/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_FLUSH', and to 0
+   if you don't. */
+#undef HAVE_DECL_NET_IPV4_ROUTE_FLUSH
+
+/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_GC_ELASTICITY',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ROUTE_GC_ELASTICITY
+
+/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_GC_INTERVAL',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ROUTE_GC_INTERVAL
+
+/* Define to 1 if you have the declaration of
+   `NET_IPV4_ROUTE_GC_MIN_INTERVAL', and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ROUTE_GC_MIN_INTERVAL
+
+/* Define to 1 if you have the declaration of
    `NET_IPV4_ROUTE_GC_MIN_INTERVAL_MS', and to 0 if you don't. */
 #undef HAVE_DECL_NET_IPV4_ROUTE_GC_MIN_INTERVAL_MS
 
+/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_GC_THRESH', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ROUTE_GC_THRESH
+
+/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_GC_TIMEOUT', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ROUTE_GC_TIMEOUT
+
+/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_MAX_DELAY', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ROUTE_MAX_DELAY
+
+/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_MAX_SIZE', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ROUTE_MAX_SIZE
+
+/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_MIN_ADVMSS', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ROUTE_MIN_ADVMSS
+
+/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_MIN_DELAY', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ROUTE_MIN_DELAY
+
+/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_MIN_PMTU', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ROUTE_MIN_PMTU
+
+/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_MTU_EXPIRES',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ROUTE_MTU_EXPIRES
+
+/* Define to 1 if you have the declaration of `NET_IPV4_ROUTE_REDIRECT_LOAD',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ROUTE_REDIRECT_LOAD
+
+/* Define to 1 if you have the declaration of
+   `NET_IPV4_ROUTE_REDIRECT_NUMBER', and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ROUTE_REDIRECT_NUMBER
+
+/* Define to 1 if you have the declaration of
+   `NET_IPV4_ROUTE_REDIRECT_SILENCE', and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ROUTE_REDIRECT_SILENCE
+
+/* Define to 1 if you have the declaration of
+   `NET_IPV4_ROUTE_SECRET_INTERVAL', and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_ROUTE_SECRET_INTERVAL
+
+/* Define to 1 if you have the declaration of `NET_IPV4_TCP_FIN_TIMEOUT', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_TCP_FIN_TIMEOUT
+
+/* Define to 1 if you have the declaration of `NET_IPV4_TCP_KEEPALIVE_INTVL',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_TCP_KEEPALIVE_INTVL
+
+/* Define to 1 if you have the declaration of `NET_IPV4_TCP_KEEPALIVE_PROBES',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_TCP_KEEPALIVE_PROBES
+
+/* Define to 1 if you have the declaration of `NET_IPV4_TCP_KEEPALIVE_TIME',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_TCP_KEEPALIVE_TIME
+
+/* Define to 1 if you have the declaration of `NET_IPV4_TCP_MAX_KA_PROBES',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_TCP_MAX_KA_PROBES
+
+/* Define to 1 if you have the declaration of `NET_IPV4_TCP_RETRANS_COLLAPSE',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_TCP_RETRANS_COLLAPSE
+
+/* Define to 1 if you have the declaration of `NET_IPV4_TCP_RETRIES1', and to
+   0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_TCP_RETRIES1
+
+/* Define to 1 if you have the declaration of `NET_IPV4_TCP_RETRIES2', and to
+   0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_TCP_RETRIES2
+
+/* Define to 1 if you have the declaration of `NET_IPV4_TCP_SACK', and to 0 if
+   you don't. */
+#undef HAVE_DECL_NET_IPV4_TCP_SACK
+
+/* Define to 1 if you have the declaration of `NET_IPV4_TCP_SYN_RETRIES', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_TCP_SYN_RETRIES
+
+/* Define to 1 if you have the declaration of `NET_IPV4_TCP_TIMESTAMPS', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_TCP_TIMESTAMPS
+
+/* Define to 1 if you have the declaration of `NET_IPV4_TCP_WINDOW_SCALING',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV4_TCP_WINDOW_SCALING
+
 /* Define to 1 if you have the declaration of
    `NET_IPV4_TCP_WORKAROUND_SIGNED_WINDOWS', and to 0 if you don't. */
 #undef HAVE_DECL_NET_IPV4_TCP_WORKAROUND_SIGNED_WINDOWS
 
+/* Define to 1 if you have the declaration of `NET_IPV6', and to 0 if you
+   don't. */
+#undef HAVE_DECL_NET_IPV6
+
+/* Define to 1 if you have the declaration of `NET_IPV6_BINDV6ONLY', and to 0
+   if you don't. */
+#undef HAVE_DECL_NET_IPV6_BINDV6ONLY
+
+/* Define to 1 if you have the declaration of `NET_IPV6_CONF', and to 0 if you
+   don't. */
+#undef HAVE_DECL_NET_IPV6_CONF
+
+/* Define to 1 if you have the declaration of `NET_IPV6_ICMP', and to 0 if you
+   don't. */
+#undef HAVE_DECL_NET_IPV6_ICMP
+
+/* Define to 1 if you have the declaration of `NET_IPV6_IP6FRAG_HIGH_THRESH',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV6_IP6FRAG_HIGH_THRESH
+
+/* Define to 1 if you have the declaration of `NET_IPV6_IP6FRAG_LOW_THRESH',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV6_IP6FRAG_LOW_THRESH
+
+/* Define to 1 if you have the declaration of
+   `NET_IPV6_IP6FRAG_SECRET_INTERVAL', and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV6_IP6FRAG_SECRET_INTERVAL
+
+/* Define to 1 if you have the declaration of `NET_IPV6_IP6FRAG_TIME', and to
+   0 if you don't. */
+#undef HAVE_DECL_NET_IPV6_IP6FRAG_TIME
+
 /* Define to 1 if you have the declaration of `NET_IPV6_MLD_MAX_MSF', and to 0
    if you don't. */
 #undef HAVE_DECL_NET_IPV6_MLD_MAX_MSF
 
+/* Define to 1 if you have the declaration of `NET_IPV6_NEIGH', and to 0 if
+   you don't. */
+#undef HAVE_DECL_NET_IPV6_NEIGH
+
+/* Define to 1 if you have the declaration of `NET_IPV6_ROUTE', and to 0 if
+   you don't. */
+#undef HAVE_DECL_NET_IPV6_ROUTE
+
+/* Define to 1 if you have the declaration of `NET_IPV6_ROUTE_FLUSH', and to 0
+   if you don't. */
+#undef HAVE_DECL_NET_IPV6_ROUTE_FLUSH
+
+/* Define to 1 if you have the declaration of `NET_IPV6_ROUTE_GC_ELASTICITY',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV6_ROUTE_GC_ELASTICITY
+
+/* Define to 1 if you have the declaration of `NET_IPV6_ROUTE_GC_INTERVAL',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV6_ROUTE_GC_INTERVAL
+
+/* Define to 1 if you have the declaration of
+   `NET_IPV6_ROUTE_GC_MIN_INTERVAL', and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV6_ROUTE_GC_MIN_INTERVAL
+
 /* Define to 1 if you have the declaration of
    `NET_IPV6_ROUTE_GC_MIN_INTERVAL_MS', and to 0 if you don't. */
 #undef HAVE_DECL_NET_IPV6_ROUTE_GC_MIN_INTERVAL_MS
 
+/* Define to 1 if you have the declaration of `NET_IPV6_ROUTE_GC_THRESH', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV6_ROUTE_GC_THRESH
+
+/* Define to 1 if you have the declaration of `NET_IPV6_ROUTE_GC_TIMEOUT', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV6_ROUTE_GC_TIMEOUT
+
+/* Define to 1 if you have the declaration of `NET_IPV6_ROUTE_MAX_SIZE', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV6_ROUTE_MAX_SIZE
+
+/* Define to 1 if you have the declaration of `NET_IPV6_ROUTE_MIN_ADVMSS', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV6_ROUTE_MIN_ADVMSS
+
+/* Define to 1 if you have the declaration of `NET_IPV6_ROUTE_MTU_EXPIRES',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_IPV6_ROUTE_MTU_EXPIRES
+
+/* Define to 1 if you have the declaration of `NET_IPX', and to 0 if you
+   don't. */
+#undef HAVE_DECL_NET_IPX
+
 /* Define to 1 if you have the declaration of `NET_IRDA', and to 0 if you
    don't. */
 #undef HAVE_DECL_NET_IRDA
@@ -312,14 +1300,38 @@
    don't. */
 #undef HAVE_DECL_NET_NETFILTER
 
+/* Define to 1 if you have the declaration of `NET_NETROM', and to 0 if you
+   don't. */
+#undef HAVE_DECL_NET_NETROM
+
+/* Define to 1 if you have the declaration of `NET_ROSE', and to 0 if you
+   don't. */
+#undef HAVE_DECL_NET_ROSE
+
+/* Define to 1 if you have the declaration of `NET_SCTP', and to 0 if you
+   don't. */
+#undef HAVE_DECL_NET_SCTP
+
 /* Define to 1 if you have the declaration of `NET_TCP_ABC', and to 0 if you
    don't. */
 #undef HAVE_DECL_NET_TCP_ABC
 
+/* Define to 1 if you have the declaration of `NET_TCP_ABORT_ON_OVERFLOW', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_TCP_ABORT_ON_OVERFLOW
+
+/* Define to 1 if you have the declaration of `NET_TCP_ADV_WIN_SCALE', and to
+   0 if you don't. */
+#undef HAVE_DECL_NET_TCP_ADV_WIN_SCALE
+
 /* Define to 1 if you have the declaration of `NET_TCP_ALLOWED_CONG_CONTROL',
    and to 0 if you don't. */
 #undef HAVE_DECL_NET_TCP_ALLOWED_CONG_CONTROL
 
+/* Define to 1 if you have the declaration of `NET_TCP_APP_WIN', and to 0 if
+   you don't. */
+#undef HAVE_DECL_NET_TCP_APP_WIN
+
 /* Define to 1 if you have the declaration of `NET_TCP_AVAIL_CONG_CONTROL',
    and to 0 if you don't. */
 #undef HAVE_DECL_NET_TCP_AVAIL_CONG_CONTROL
@@ -344,33 +1356,137 @@
    0 if you don't. */
 #undef HAVE_DECL_NET_TCP_DMA_COPYBREAK
 
-/* Define to 1 if you have the declaration of `NET_TCP_FRTO_RESPONSE', and to
+/* Define to 1 if you have the declaration of `NET_TCP_DSACK', and to 0 if you
+   don't. */
+#undef HAVE_DECL_NET_TCP_DSACK
+
+/* Define to 1 if you have the declaration of `NET_TCP_ECN', and to 0 if you
+   don't. */
+#undef HAVE_DECL_NET_TCP_ECN
+
+/* Define to 1 if you have the declaration of `NET_TCP_FACK', and to 0 if you
+   don't. */
+#undef HAVE_DECL_NET_TCP_FACK
+
+/* Define to 1 if you have the declaration of `NET_TCP_FRTO', and to 0 if you
+   don't. */
+#undef HAVE_DECL_NET_TCP_FRTO
+
+/* Define to 1 if you have the declaration of `NET_TCP_FRTO_RESPONSE', and to
+   0 if you don't. */
+#undef HAVE_DECL_NET_TCP_FRTO_RESPONSE
+
+/* Define to 1 if you have the declaration of `NET_TCP_LOW_LATENCY', and to 0
+   if you don't. */
+#undef HAVE_DECL_NET_TCP_LOW_LATENCY
+
+/* Define to 1 if you have the declaration of `NET_TCP_MAX_ORPHANS', and to 0
+   if you don't. */
+#undef HAVE_DECL_NET_TCP_MAX_ORPHANS
+
+/* Define to 1 if you have the declaration of `NET_TCP_MAX_SSTHRESH', and to 0
+   if you don't. */
+#undef HAVE_DECL_NET_TCP_MAX_SSTHRESH
+
+/* Define to 1 if you have the declaration of `NET_TCP_MAX_SYN_BACKLOG', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_TCP_MAX_SYN_BACKLOG
+
+/* Define to 1 if you have the declaration of `NET_TCP_MAX_TW_BUCKETS', and to
+   0 if you don't. */
+#undef HAVE_DECL_NET_TCP_MAX_TW_BUCKETS
+
+/* Define to 1 if you have the declaration of `NET_TCP_MEM', and to 0 if you
+   don't. */
+#undef HAVE_DECL_NET_TCP_MEM
+
+/* Define to 1 if you have the declaration of `NET_TCP_MODERATE_RCVBUF', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_TCP_MODERATE_RCVBUF
+
+/* Define to 1 if you have the declaration of `NET_TCP_MTU_PROBING', and to 0
+   if you don't. */
+#undef HAVE_DECL_NET_TCP_MTU_PROBING
+
+/* Define to 1 if you have the declaration of `NET_TCP_NO_METRICS_SAVE', and
+   to 0 if you don't. */
+#undef HAVE_DECL_NET_TCP_NO_METRICS_SAVE
+
+/* Define to 1 if you have the declaration of `NET_TCP_ORPHAN_RETRIES', and to
+   0 if you don't. */
+#undef HAVE_DECL_NET_TCP_ORPHAN_RETRIES
+
+/* Define to 1 if you have the declaration of `NET_TCP_REORDERING', and to 0
+   if you don't. */
+#undef HAVE_DECL_NET_TCP_REORDERING
+
+/* Define to 1 if you have the declaration of `NET_TCP_RFC1337', and to 0 if
+   you don't. */
+#undef HAVE_DECL_NET_TCP_RFC1337
+
+/* Define to 1 if you have the declaration of `NET_TCP_RMEM', and to 0 if you
+   don't. */
+#undef HAVE_DECL_NET_TCP_RMEM
+
+/* Define to 1 if you have the declaration of `NET_TCP_SLOW_START_AFTER_IDLE',
+   and to 0 if you don't. */
+#undef HAVE_DECL_NET_TCP_SLOW_START_AFTER_IDLE
+
+/* Define to 1 if you have the declaration of `NET_TCP_STDURG', and to 0 if
+   you don't. */
+#undef HAVE_DECL_NET_TCP_STDURG
+
+/* Define to 1 if you have the declaration of `NET_TCP_SYNACK_RETRIES', and to
    0 if you don't. */
-#undef HAVE_DECL_NET_TCP_FRTO_RESPONSE
+#undef HAVE_DECL_NET_TCP_SYNACK_RETRIES
 
-/* Define to 1 if you have the declaration of `NET_TCP_MAX_SSTHRESH', and to 0
+/* Define to 1 if you have the declaration of `NET_TCP_SYNCOOKIES', and to 0
    if you don't. */
-#undef HAVE_DECL_NET_TCP_MAX_SSTHRESH
+#undef HAVE_DECL_NET_TCP_SYNCOOKIES
 
-/* Define to 1 if you have the declaration of `NET_TCP_MODERATE_RCVBUF', and
+/* Define to 1 if you have the declaration of `NET_TCP_SYN_TAILDROP', and to 0
+   if you don't. */
+#undef HAVE_DECL_NET_TCP_SYN_TAILDROP
+
+/* Define to 1 if you have the declaration of `NET_TCP_TSO_WIN_DIVISOR', and
    to 0 if you don't. */
-#undef HAVE_DECL_NET_TCP_MODERATE_RCVBUF
+#undef HAVE_DECL_NET_TCP_TSO_WIN_DIVISOR
 
-/* Define to 1 if you have the declaration of `NET_TCP_MTU_PROBING', and to 0
+/* Define to 1 if you have the declaration of `NET_TCP_TW_RECYCLE', and to 0
    if you don't. */
-#undef HAVE_DECL_NET_TCP_MTU_PROBING
+#undef HAVE_DECL_NET_TCP_TW_RECYCLE
 
-/* Define to 1 if you have the declaration of `NET_TCP_NO_METRICS_SAVE', and
-   to 0 if you don't. */
-#undef HAVE_DECL_NET_TCP_NO_METRICS_SAVE
+/* Define to 1 if you have the declaration of `NET_TCP_TW_REUSE', and to 0 if
+   you don't. */
+#undef HAVE_DECL_NET_TCP_TW_REUSE
 
-/* Define to 1 if you have the declaration of `NET_TCP_SLOW_START_AFTER_IDLE',
-   and to 0 if you don't. */
-#undef HAVE_DECL_NET_TCP_SLOW_START_AFTER_IDLE
+/* Define to 1 if you have the declaration of `NET_TCP_WMEM', and to 0 if you
+   don't. */
+#undef HAVE_DECL_NET_TCP_WMEM
 
-/* Define to 1 if you have the declaration of `NET_TCP_TSO_WIN_DIVISOR', and
+/* Define to 1 if you have the declaration of `NET_TR', and to 0 if you don't.
+   */
+#undef HAVE_DECL_NET_TR
+
+/* Define to 1 if you have the declaration of `NET_UNIX', and to 0 if you
+   don't. */
+#undef HAVE_DECL_NET_UNIX
+
+/* Define to 1 if you have the declaration of `NET_UNIX_DELETE_DELAY', and to
+   0 if you don't. */
+#undef HAVE_DECL_NET_UNIX_DELETE_DELAY
+
+/* Define to 1 if you have the declaration of `NET_UNIX_DESTROY_DELAY', and to
+   0 if you don't. */
+#undef HAVE_DECL_NET_UNIX_DESTROY_DELAY
+
+/* Define to 1 if you have the declaration of `NET_UNIX_MAX_DGRAM_QLEN', and
    to 0 if you don't. */
-#undef HAVE_DECL_NET_TCP_TSO_WIN_DIVISOR
+#undef HAVE_DECL_NET_UNIX_MAX_DGRAM_QLEN
+
+/* Define to 1 if you have the declaration of `NET_X25', and to 0 if you
+   don't. */
+#undef HAVE_DECL_NET_X25
 
 /* Define to 1 if you have the declaration of `PTRACE_PEEKUSER', and to 0 if
    you don't. */
@@ -384,18 +1500,6 @@
    */
 #undef HAVE_DECL_P_ALL
 
-/* Define to 1 if you have the declaration of `P_CID', and to 0 if you don't.
-   */
-#undef HAVE_DECL_P_CID
-
-/* Define to 1 if you have the declaration of `P_GID', and to 0 if you don't.
-   */
-#undef HAVE_DECL_P_GID
-
-/* Define to 1 if you have the declaration of `P_LWPID', and to 0 if you
-   don't. */
-#undef HAVE_DECL_P_LWPID
-
 /* Define to 1 if you have the declaration of `P_PGID', and to 0 if you don't.
    */
 #undef HAVE_DECL_P_PGID
@@ -404,17 +1508,9 @@
    */
 #undef HAVE_DECL_P_PID
 
-/* Define to 1 if you have the declaration of `P_PPID', and to 0 if you don't.
-   */
-#undef HAVE_DECL_P_PPID
-
-/* Define to 1 if you have the declaration of `P_SID', and to 0 if you don't.
-   */
-#undef HAVE_DECL_P_SID
-
-/* Define to 1 if you have the declaration of `P_UID', and to 0 if you don't.
-   */
-#undef HAVE_DECL_P_UID
+/* Define to 1 if you have the declaration of `P_PIDFD', and to 0 if you
+   don't. */
+#undef HAVE_DECL_P_PIDFD
 
 /* Define to 1 if you have the declaration of `sys_errlist', and to 0 if you
    don't. */
@@ -428,18 +1524,94 @@
    don't. */
 #undef HAVE_DECL_TCA_ACT_FLAGS
 
+/* Define to 1 if you have the declaration of `TCA_ACT_HW_STATS', and to 0 if
+   you don't. */
+#undef HAVE_DECL_TCA_ACT_HW_STATS
+
+/* Define to 1 if you have the declaration of `TCA_ACT_INDEX', and to 0 if you
+   don't. */
+#undef HAVE_DECL_TCA_ACT_INDEX
+
+/* Define to 1 if you have the declaration of `TCA_ACT_KIND', and to 0 if you
+   don't. */
+#undef HAVE_DECL_TCA_ACT_KIND
+
+/* Define to 1 if you have the declaration of `TCA_ACT_OPTIONS', and to 0 if
+   you don't. */
+#undef HAVE_DECL_TCA_ACT_OPTIONS
+
 /* Define to 1 if you have the declaration of `TCA_ACT_PAD', and to 0 if you
    don't. */
 #undef HAVE_DECL_TCA_ACT_PAD
 
+/* Define to 1 if you have the declaration of `TCA_ACT_STATS', and to 0 if you
+   don't. */
+#undef HAVE_DECL_TCA_ACT_STATS
+
+/* Define to 1 if you have the declaration of `TCA_ACT_UNSPEC', and to 0 if
+   you don't. */
+#undef HAVE_DECL_TCA_ACT_UNSPEC
+
+/* Define to 1 if you have the declaration of `TCA_ACT_USED_HW_STATS', and to
+   0 if you don't. */
+#undef HAVE_DECL_TCA_ACT_USED_HW_STATS
+
+/* Define to 1 if you have the declaration of `TCA_STAB_BASE', and to 0 if you
+   don't. */
+#undef HAVE_DECL_TCA_STAB_BASE
+
 /* Define to 1 if you have the declaration of `TCA_STAB_DATA', and to 0 if you
    don't. */
 #undef HAVE_DECL_TCA_STAB_DATA
 
+/* Define to 1 if you have the declaration of `TCA_STAB_UNSPEC', and to 0 if
+   you don't. */
+#undef HAVE_DECL_TCA_STAB_UNSPEC
+
+/* Define to 1 if you have the declaration of `TCA_STATS_APP', and to 0 if you
+   don't. */
+#undef HAVE_DECL_TCA_STATS_APP
+
+/* Define to 1 if you have the declaration of `TCA_STATS_BASIC', and to 0 if
+   you don't. */
+#undef HAVE_DECL_TCA_STATS_BASIC
+
+/* Define to 1 if you have the declaration of `TCA_STATS_BASIC_HW', and to 0
+   if you don't. */
+#undef HAVE_DECL_TCA_STATS_BASIC_HW
+
+/* Define to 1 if you have the declaration of `TCA_STATS_PAD', and to 0 if you
+   don't. */
+#undef HAVE_DECL_TCA_STATS_PAD
+
 /* Define to 1 if you have the declaration of `TCA_STATS_PKT64', and to 0 if
    you don't. */
 #undef HAVE_DECL_TCA_STATS_PKT64
 
+/* Define to 1 if you have the declaration of `TCA_STATS_QUEUE', and to 0 if
+   you don't. */
+#undef HAVE_DECL_TCA_STATS_QUEUE
+
+/* Define to 1 if you have the declaration of `TCA_STATS_RATE_EST', and to 0
+   if you don't. */
+#undef HAVE_DECL_TCA_STATS_RATE_EST
+
+/* Define to 1 if you have the declaration of `TCA_STATS_RATE_EST64', and to 0
+   if you don't. */
+#undef HAVE_DECL_TCA_STATS_RATE_EST64
+
+/* Define to 1 if you have the declaration of `TCA_STATS_UNSPEC', and to 0 if
+   you don't. */
+#undef HAVE_DECL_TCA_STATS_UNSPEC
+
+/* Define to 1 if you have the declaration of `V4L2_BUF_TYPE_META_CAPTURE',
+   and to 0 if you don't. */
+#undef HAVE_DECL_V4L2_BUF_TYPE_META_CAPTURE
+
+/* Define to 1 if you have the declaration of `V4L2_BUF_TYPE_META_OUTPUT', and
+   to 0 if you don't. */
+#undef HAVE_DECL_V4L2_BUF_TYPE_META_OUTPUT
+
 /* Define to 1 if you have the declaration of `V4L2_BUF_TYPE_SDR_CAPTURE', and
    to 0 if you don't. */
 #undef HAVE_DECL_V4L2_BUF_TYPE_SDR_CAPTURE
@@ -496,14 +1668,34 @@
    and to 0 if you don't. */
 #undef HAVE_DECL_V4L2_COLORSPACE_470_SYSTEM_M
 
+/* Define to 1 if you have the declaration of `V4L2_COLORSPACE_BT2020', and to
+   0 if you don't. */
+#undef HAVE_DECL_V4L2_COLORSPACE_BT2020
+
 /* Define to 1 if you have the declaration of `V4L2_COLORSPACE_BT878', and to
    0 if you don't. */
 #undef HAVE_DECL_V4L2_COLORSPACE_BT878
 
+/* Define to 1 if you have the declaration of `V4L2_COLORSPACE_DCI_P3', and to
+   0 if you don't. */
+#undef HAVE_DECL_V4L2_COLORSPACE_DCI_P3
+
+/* Define to 1 if you have the declaration of `V4L2_COLORSPACE_DEFAULT', and
+   to 0 if you don't. */
+#undef HAVE_DECL_V4L2_COLORSPACE_DEFAULT
+
 /* Define to 1 if you have the declaration of `V4L2_COLORSPACE_JPEG', and to 0
    if you don't. */
 #undef HAVE_DECL_V4L2_COLORSPACE_JPEG
 
+/* Define to 1 if you have the declaration of `V4L2_COLORSPACE_OPRGB', and to
+   0 if you don't. */
+#undef HAVE_DECL_V4L2_COLORSPACE_OPRGB
+
+/* Define to 1 if you have the declaration of `V4L2_COLORSPACE_RAW', and to 0
+   if you don't. */
+#undef HAVE_DECL_V4L2_COLORSPACE_RAW
+
 /* Define to 1 if you have the declaration of `V4L2_COLORSPACE_REC709', and to
    0 if you don't. */
 #undef HAVE_DECL_V4L2_COLORSPACE_REC709
@@ -612,18 +1804,6 @@
    you don't. */
 #undef HAVE_DECL_V4L2_FIELD_TOP
 
-/* Define to 1 if you have the declaration of `V4L2_FRMIVAL_TYPE_CONTINUOUS',
-   and to 0 if you don't. */
-#undef HAVE_DECL_V4L2_FRMIVAL_TYPE_CONTINUOUS
-
-/* Define to 1 if you have the declaration of `V4L2_FRMIVAL_TYPE_DISCRETE',
-   and to 0 if you don't. */
-#undef HAVE_DECL_V4L2_FRMIVAL_TYPE_DISCRETE
-
-/* Define to 1 if you have the declaration of `V4L2_FRMIVAL_TYPE_STEPWISE',
-   and to 0 if you don't. */
-#undef HAVE_DECL_V4L2_FRMIVAL_TYPE_STEPWISE
-
 /* Define to 1 if you have the declaration of `V4L2_FRMSIZE_TYPE_CONTINUOUS',
    and to 0 if you don't. */
 #undef HAVE_DECL_V4L2_FRMSIZE_TYPE_CONTINUOUS
@@ -652,22 +1832,6 @@
    if you don't. */
 #undef HAVE_DECL_V4L2_MEMORY_USERPTR
 
-/* Define to 1 if you have the declaration of `V4L2_PRIORITY_BACKGROUND', and
-   to 0 if you don't. */
-#undef HAVE_DECL_V4L2_PRIORITY_BACKGROUND
-
-/* Define to 1 if you have the declaration of `V4L2_PRIORITY_INTERACTIVE', and
-   to 0 if you don't. */
-#undef HAVE_DECL_V4L2_PRIORITY_INTERACTIVE
-
-/* Define to 1 if you have the declaration of `V4L2_PRIORITY_RECORD', and to 0
-   if you don't. */
-#undef HAVE_DECL_V4L2_PRIORITY_RECORD
-
-/* Define to 1 if you have the declaration of `V4L2_PRIORITY_UNSET', and to 0
-   if you don't. */
-#undef HAVE_DECL_V4L2_PRIORITY_UNSET
-
 /* Define to 1 if you have the declaration of `V4L2_TUNER_ANALOG_TV', and to 0
    if you don't. */
 #undef HAVE_DECL_V4L2_TUNER_ANALOG_TV
@@ -680,14 +1844,42 @@
    you don't. */
 #undef HAVE_DECL_V4L2_TUNER_RADIO
 
+/* Define to 1 if you have the declaration of `V4L2_TUNER_RF', and to 0 if you
+   don't. */
+#undef HAVE_DECL_V4L2_TUNER_RF
+
+/* Define to 1 if you have the declaration of `V4L2_TUNER_SDR', and to 0 if
+   you don't. */
+#undef HAVE_DECL_V4L2_TUNER_SDR
+
 /* Define to 1 if you have the declaration of `VM_BLOCK_DUMP', and to 0 if you
    don't. */
 #undef HAVE_DECL_VM_BLOCK_DUMP
 
+/* Define to 1 if you have the declaration of `VM_DIRTY_BACKGROUND', and to 0
+   if you don't. */
+#undef HAVE_DECL_VM_DIRTY_BACKGROUND
+
+/* Define to 1 if you have the declaration of `VM_DIRTY_EXPIRE_CS', and to 0
+   if you don't. */
+#undef HAVE_DECL_VM_DIRTY_EXPIRE_CS
+
+/* Define to 1 if you have the declaration of `VM_DIRTY_RATIO', and to 0 if
+   you don't. */
+#undef HAVE_DECL_VM_DIRTY_RATIO
+
+/* Define to 1 if you have the declaration of `VM_DIRTY_WB_CS', and to 0 if
+   you don't. */
+#undef HAVE_DECL_VM_DIRTY_WB_CS
+
 /* Define to 1 if you have the declaration of `VM_HUGETLB_GROUP', and to 0 if
    you don't. */
 #undef HAVE_DECL_VM_HUGETLB_GROUP
 
+/* Define to 1 if you have the declaration of `VM_HUGETLB_PAGES', and to 0 if
+   you don't. */
+#undef HAVE_DECL_VM_HUGETLB_PAGES
+
 /* Define to 1 if you have the declaration of `VM_LAPTOP_MODE', and to 0 if
    you don't. */
 #undef HAVE_DECL_VM_LAPTOP_MODE
@@ -696,10 +1888,42 @@
    if you don't. */
 #undef HAVE_DECL_VM_LEGACY_VA_LAYOUT
 
+/* Define to 1 if you have the declaration of `VM_LOWMEM_RESERVE_RATIO', and
+   to 0 if you don't. */
+#undef HAVE_DECL_VM_LOWMEM_RESERVE_RATIO
+
 /* Define to 1 if you have the declaration of `VM_MAX_MAP_COUNT', and to 0 if
    you don't. */
 #undef HAVE_DECL_VM_MAX_MAP_COUNT
 
+/* Define to 1 if you have the declaration of `VM_MIN_FREE_KBYTES', and to 0
+   if you don't. */
+#undef HAVE_DECL_VM_MIN_FREE_KBYTES
+
+/* Define to 1 if you have the declaration of `VM_NR_PDFLUSH_THREADS', and to
+   0 if you don't. */
+#undef HAVE_DECL_VM_NR_PDFLUSH_THREADS
+
+/* Define to 1 if you have the declaration of `VM_OVERCOMMIT_MEMORY', and to 0
+   if you don't. */
+#undef HAVE_DECL_VM_OVERCOMMIT_MEMORY
+
+/* Define to 1 if you have the declaration of `VM_OVERCOMMIT_RATIO', and to 0
+   if you don't. */
+#undef HAVE_DECL_VM_OVERCOMMIT_RATIO
+
+/* Define to 1 if you have the declaration of `VM_PAGEBUF', and to 0 if you
+   don't. */
+#undef HAVE_DECL_VM_PAGEBUF
+
+/* Define to 1 if you have the declaration of `VM_PAGE_CLUSTER', and to 0 if
+   you don't. */
+#undef HAVE_DECL_VM_PAGE_CLUSTER
+
+/* Define to 1 if you have the declaration of `VM_SWAPPINESS', and to 0 if you
+   don't. */
+#undef HAVE_DECL_VM_SWAPPINESS
+
 /* Define to 1 if you have the declaration of `VM_SWAP_TOKEN_TIMEOUT', and to
    0 if you don't. */
 #undef HAVE_DECL_VM_SWAP_TOKEN_TIMEOUT
@@ -708,6 +1932,26 @@
    0 if you don't. */
 #undef HAVE_DECL_VM_VFS_CACHE_PRESSURE
 
+/* Define to 1 if you have the declaration of `XDP_ATTACHED_DRV', and to 0 if
+   you don't. */
+#undef HAVE_DECL_XDP_ATTACHED_DRV
+
+/* Define to 1 if you have the declaration of `XDP_ATTACHED_HW', and to 0 if
+   you don't. */
+#undef HAVE_DECL_XDP_ATTACHED_HW
+
+/* Define to 1 if you have the declaration of `XDP_ATTACHED_MULTI', and to 0
+   if you don't. */
+#undef HAVE_DECL_XDP_ATTACHED_MULTI
+
+/* Define to 1 if you have the declaration of `XDP_ATTACHED_NONE', and to 0 if
+   you don't. */
+#undef HAVE_DECL_XDP_ATTACHED_NONE
+
+/* Define to 1 if you have the declaration of `XDP_ATTACHED_SKB', and to 0 if
+   you don't. */
+#undef HAVE_DECL_XDP_ATTACHED_SKB
+
 /* Define to 1 if you have the <demangle.h> header file. */
 #undef HAVE_DEMANGLE_H
 
@@ -786,6 +2030,9 @@
 /* Define to 1 if you have the <linux/btrfs.h> header file. */
 #undef HAVE_LINUX_BTRFS_H
 
+/* Define to 1 if you have the <linux/close_range.h> header file. */
+#undef HAVE_LINUX_CLOSE_RANGE_H
+
 /* Define to 1 if you have the <linux/cryptouser.h> header file. */
 #undef HAVE_LINUX_CRYPTOUSER_H
 
@@ -834,6 +2081,9 @@
 /* Define to 1 if you have the <linux/kvm.h> header file. */
 #undef HAVE_LINUX_KVM_H
 
+/* Define to 1 if you have the <linux/loop.h> header file. */
+#undef HAVE_LINUX_LOOP_H
+
 /* Define to 1 if you have the <linux/memfd.h> header file. */
 #undef HAVE_LINUX_MEMFD_H
 
@@ -909,6 +2159,9 @@
 /* Define to 1 if you have the <linux/nsfs.h> header file. */
 #undef HAVE_LINUX_NSFS_H
 
+/* Define to 1 if you have the <linux/openat2.h> header file. */
+#undef HAVE_LINUX_OPENAT2_H
+
 /* Define to 1 if you have the <linux/perf_event.h> header file. */
 #undef HAVE_LINUX_PERF_EVENT_H
 
@@ -927,12 +2180,18 @@
 /* Define to 1 if you have the <linux/securebits.h> header file. */
 #undef HAVE_LINUX_SECUREBITS_H
 
+/* Define to 1 if you have the <linux/tee.h> header file. */
+#undef HAVE_LINUX_TEE_H
+
 /* Define to 1 if you have the <linux/userfaultfd.h> header file. */
 #undef HAVE_LINUX_USERFAULTFD_H
 
 /* Define to 1 if you have the <linux/utsname.h> header file. */
 #undef HAVE_LINUX_UTSNAME_H
 
+/* Define to 1 if you have the <linux/videodev2.h> header file. */
+#undef HAVE_LINUX_VIDEODEV2_H
+
 /* Define to 1 if you have mpers_name mpers support */
 #undef HAVE_M32_MPERS
 
@@ -990,9 +2249,6 @@
 /* Define to 1 if you have the <paths.h> header file. */
 #undef HAVE_PATHS_H
 
-/* Define to 1 if you have the `prctl' function. */
-#undef HAVE_PRCTL
-
 /* Define to 1 if you have the `preadv' function. */
 #undef HAVE_PREADV
 
@@ -1053,12 +2309,6 @@
 /* Define to 1 if you have the `strndup' function. */
 #undef HAVE_STRNDUP
 
-/* Define to 1 if you have the <stropts.h> header file. */
-#undef HAVE_STROPTS_H
-
-/* Define to 1 if you have the `strsignal' function. */
-#undef HAVE_STRSIGNAL
-
 /* Define to 1 if the system has the type `struct blk_user_trace_setup'. */
 #undef HAVE_STRUCT_BLK_USER_TRACE_SETUP
 
@@ -1077,6 +2327,10 @@
 /* Define to 1 if `btf_value_type_id' is a member of `struct bpf_map_info'. */
 #undef HAVE_STRUCT_BPF_MAP_INFO_BTF_VALUE_TYPE_ID
 
+/* Define to 1 if `btf_vmlinux_value_type_id' is a member of `struct
+   bpf_map_info'. */
+#undef HAVE_STRUCT_BPF_MAP_INFO_BTF_VMLINUX_VALUE_TYPE_ID
+
 /* Define to 1 if `id' is a member of `struct bpf_map_info'. */
 #undef HAVE_STRUCT_BPF_MAP_INFO_ID
 
@@ -1233,16 +2487,16 @@
    */
 #undef HAVE_STRUCT_BTRFS_IOCTL_FS_INFO_ARGS_NODESIZE
 
-/* Define to 1 if `flags' is a member of `struct
+/* Define to 1 if the system has the type `struct
    btrfs_ioctl_logical_ino_args'. */
-#undef HAVE_STRUCT_BTRFS_IOCTL_LOGICAL_INO_ARGS_FLAGS
+#undef HAVE_STRUCT_BTRFS_IOCTL_LOGICAL_INO_ARGS
 
-/* Define to 1 if `buf_size' is a member of `struct
-   btrfs_ioctl_search_args_v2'. */
-#undef HAVE_STRUCT_BTRFS_IOCTL_SEARCH_ARGS_V2_BUF_SIZE
+/* Define to 1 if `inodes' is a member of `struct
+   btrfs_ioctl_logical_ino_args'. */
+#undef HAVE_STRUCT_BTRFS_IOCTL_LOGICAL_INO_ARGS_INODES
 
-/* Define to 1 if `set_tid_size' is a member of `struct clone_args'. */
-#undef HAVE_STRUCT_CLONE_ARGS_SET_TID_SIZE
+/* Define to 1 if `cgroup' is a member of `struct clone_args'. */
+#undef HAVE_STRUCT_CLONE_ARGS_CGROUP
 
 /* Define to 1 if the system has the type `struct crypto_report_aead'. */
 #undef HAVE_STRUCT_CRYPTO_REPORT_AEAD
@@ -1359,8 +2613,11 @@
 /* Define to 1 if the system has the type `struct io_cqring_offsets'. */
 #undef HAVE_STRUCT_IO_CQRING_OFFSETS
 
-/* Define to 1 if `resv' is a member of `struct io_cqring_offsets'. */
-#undef HAVE_STRUCT_IO_CQRING_OFFSETS_RESV
+/* Define to 1 if `cqes' is a member of `struct io_cqring_offsets'. */
+#undef HAVE_STRUCT_IO_CQRING_OFFSETS_CQES
+
+/* Define to 1 if `flags' is a member of `struct io_cqring_offsets'. */
+#undef HAVE_STRUCT_IO_CQRING_OFFSETS_FLAGS
 
 /* Define to 1 if the system has the type `struct io_sqring_offsets'. */
 #undef HAVE_STRUCT_IO_SQRING_OFFSETS
@@ -1389,6 +2646,18 @@
 /* Define to 1 if `wq_fd' is a member of `struct io_uring_params'. */
 #undef HAVE_STRUCT_IO_URING_PARAMS_WQ_FD
 
+/* Define to 1 if the system has the type `struct io_uring_probe'. */
+#undef HAVE_STRUCT_IO_URING_PROBE
+
+/* Define to 1 if the system has the type `struct io_uring_probe_op'. */
+#undef HAVE_STRUCT_IO_URING_PROBE_OP
+
+/* Define to 1 if `ops' is a member of `struct io_uring_probe'. */
+#undef HAVE_STRUCT_IO_URING_PROBE_OPS
+
+/* Define to 1 if `resv2' is a member of `struct io_uring_probe_op'. */
+#undef HAVE_STRUCT_IO_URING_PROBE_OP_RESV2
+
 /* Define to 1 if the system has the type `struct kcmp_epoll_slot'. */
 #undef HAVE_STRUCT_KCMP_EPOLL_SLOT
 
@@ -1414,6 +2683,12 @@
    kvm_userspace_memory_region'. */
 #undef HAVE_STRUCT_KVM_USERSPACE_MEMORY_REGION
 
+/* Define to 1 if the system has the type `struct loop_config'. */
+#undef HAVE_STRUCT_LOOP_CONFIG
+
+/* Define to 1 if `__reserved' is a member of `struct loop_config'. */
+#undef HAVE_STRUCT_LOOP_CONFIG___RESERVED
+
 /* Define to 1 if the system has the type `struct mmsghdr'. */
 #undef HAVE_STRUCT_MMSGHDR
 
@@ -1435,6 +2710,12 @@
 /* Define to 1 if the system has the type `struct netconfmsg'. */
 #undef HAVE_STRUCT_NETCONFMSG
 
+/* Define to 1 if the system has the type `struct open_how'. */
+#undef HAVE_STRUCT_OPEN_HOW
+
+/* Define to 1 if `resolve' is a member of `struct open_how'. */
+#undef HAVE_STRUCT_OPEN_HOW_RESOLVE
+
 /* Define to 1 if `aux_sample_size' is a member of `struct perf_event_attr'.
    */
 #undef HAVE_STRUCT_PERF_EVENT_ATTR_AUX_SAMPLE_SIZE
@@ -1602,6 +2883,79 @@
 /* Define to 1 if the system has the type `struct tc_sizespec'. */
 #undef HAVE_STRUCT_TC_SIZESPEC
 
+/* Define to 1 if the system has the type `struct tee_iocl_supp_recv_arg'. */
+#undef HAVE_STRUCT_TEE_IOCL_SUPP_RECV_ARG
+
+/* Define to 1 if `params' is a member of `struct tee_iocl_supp_recv_arg'. */
+#undef HAVE_STRUCT_TEE_IOCL_SUPP_RECV_ARG_PARAMS
+
+/* Define to 1 if the system has the type `struct tee_iocl_supp_send_arg'. */
+#undef HAVE_STRUCT_TEE_IOCL_SUPP_SEND_ARG
+
+/* Define to 1 if `params' is a member of `struct tee_iocl_supp_send_arg'. */
+#undef HAVE_STRUCT_TEE_IOCL_SUPP_SEND_ARG_PARAMS
+
+/* Define to 1 if the system has the type `struct tee_ioctl_buf_data'. */
+#undef HAVE_STRUCT_TEE_IOCTL_BUF_DATA
+
+/* Define to 1 if `buf_len' is a member of `struct tee_ioctl_buf_data'. */
+#undef HAVE_STRUCT_TEE_IOCTL_BUF_DATA_BUF_LEN
+
+/* Define to 1 if the system has the type `struct tee_ioctl_cancel_arg'. */
+#undef HAVE_STRUCT_TEE_IOCTL_CANCEL_ARG
+
+/* Define to 1 if `session' is a member of `struct tee_ioctl_cancel_arg'. */
+#undef HAVE_STRUCT_TEE_IOCTL_CANCEL_ARG_SESSION
+
+/* Define to 1 if the system has the type `struct
+   tee_ioctl_close_session_arg'. */
+#undef HAVE_STRUCT_TEE_IOCTL_CLOSE_SESSION_ARG
+
+/* Define to 1 if `session' is a member of `struct
+   tee_ioctl_close_session_arg'. */
+#undef HAVE_STRUCT_TEE_IOCTL_CLOSE_SESSION_ARG_SESSION
+
+/* Define to 1 if the system has the type `struct tee_ioctl_invoke_arg'. */
+#undef HAVE_STRUCT_TEE_IOCTL_INVOKE_ARG
+
+/* Define to 1 if `params' is a member of `struct tee_ioctl_invoke_arg'. */
+#undef HAVE_STRUCT_TEE_IOCTL_INVOKE_ARG_PARAMS
+
+/* Define to 1 if the system has the type `struct tee_ioctl_open_session_arg'.
+   */
+#undef HAVE_STRUCT_TEE_IOCTL_OPEN_SESSION_ARG
+
+/* Define to 1 if `params' is a member of `struct tee_ioctl_open_session_arg'.
+   */
+#undef HAVE_STRUCT_TEE_IOCTL_OPEN_SESSION_ARG_PARAMS
+
+/* Define to 1 if the system has the type `struct tee_ioctl_param'. */
+#undef HAVE_STRUCT_TEE_IOCTL_PARAM
+
+/* Define to 1 if `c' is a member of `struct tee_ioctl_param'. */
+#undef HAVE_STRUCT_TEE_IOCTL_PARAM_C
+
+/* Define to 1 if the system has the type `struct tee_ioctl_shm_alloc_data'.
+   */
+#undef HAVE_STRUCT_TEE_IOCTL_SHM_ALLOC_DATA
+
+/* Define to 1 if `id' is a member of `struct tee_ioctl_shm_alloc_data'. */
+#undef HAVE_STRUCT_TEE_IOCTL_SHM_ALLOC_DATA_ID
+
+/* Define to 1 if the system has the type `struct
+   tee_ioctl_shm_register_data'. */
+#undef HAVE_STRUCT_TEE_IOCTL_SHM_REGISTER_DATA
+
+/* Define to 1 if `id' is a member of `struct tee_ioctl_shm_register_data'. */
+#undef HAVE_STRUCT_TEE_IOCTL_SHM_REGISTER_DATA_ID
+
+/* Define to 1 if the system has the type `struct tee_ioctl_version_data'. */
+#undef HAVE_STRUCT_TEE_IOCTL_VERSION_DATA
+
+/* Define to 1 if `gen_caps' is a member of `struct tee_ioctl_version_data'.
+   */
+#undef HAVE_STRUCT_TEE_IOCTL_VERSION_DATA_GEN_CAPS
+
 /* Define to 1 if `max_beb_per1024' is a member of `struct ubi_attach_req'. */
 #undef HAVE_STRUCT_UBI_ATTACH_REQ_MAX_BEB_PER1024
 
@@ -1614,12 +2968,48 @@
 /* Define to 1 if `domainname' is a member of `struct utsname'. */
 #undef HAVE_STRUCT_UTSNAME_DOMAINNAME
 
+/* Define to 1 if the system has the type `struct v4l2_area'. */
+#undef HAVE_STRUCT_V4L2_AREA
+
+/* Define to 1 if `height' is a member of `struct v4l2_area'. */
+#undef HAVE_STRUCT_V4L2_AREA_HEIGHT
+
+/* Define to 1 if the system has the type `struct v4l2_capability'. */
+#undef HAVE_STRUCT_V4L2_CAPABILITY
+
 /* Define to 1 if `device_caps' is a member of `struct v4l2_capability'. */
 #undef HAVE_STRUCT_V4L2_CAPABILITY_DEVICE_CAPS
 
+/* Define to 1 if `reserved' is a member of `struct v4l2_capability'. */
+#undef HAVE_STRUCT_V4L2_CAPABILITY_RESERVED
+
+/* Define to 1 if the system has the type `struct v4l2_clip'. */
+#undef HAVE_STRUCT_V4L2_CLIP
+
+/* Define to 1 if `next' is a member of `struct v4l2_clip'. */
+#undef HAVE_STRUCT_V4L2_CLIP_NEXT
+
+/* Define to 1 if the system has the type `struct v4l2_create_buffers'. */
+#undef HAVE_STRUCT_V4L2_CREATE_BUFFERS
+
+/* Define to 1 if `reserved' is a member of `struct v4l2_create_buffers'. */
+#undef HAVE_STRUCT_V4L2_CREATE_BUFFERS_RESERVED
+
+/* Define to 1 if the system has the type `struct v4l2_ext_controls'. */
+#undef HAVE_STRUCT_V4L2_EXT_CONTROLS
+
+/* Define to 1 if `controls' is a member of `struct v4l2_ext_controls'. */
+#undef HAVE_STRUCT_V4L2_EXT_CONTROLS_CONTROLS
+
 /* Define to 1 if `string' is a member of `struct v4l2_ext_control'. */
 #undef HAVE_STRUCT_V4L2_EXT_CONTROL_STRING
 
+/* Define to 1 if the system has the type `struct v4l2_format'. */
+#undef HAVE_STRUCT_V4L2_FORMAT
+
+/* Define to 1 if `fmt' is a member of `struct v4l2_format'. */
+#undef HAVE_STRUCT_V4L2_FORMAT_FMT
+
 /* Define to 1 if `fmt.pix_mp' is a member of `struct v4l2_format'. */
 #undef HAVE_STRUCT_V4L2_FORMAT_FMT_PIX_MP
 
@@ -1629,9 +3019,83 @@
 /* Define to 1 if `fmt.sliced' is a member of `struct v4l2_format'. */
 #undef HAVE_STRUCT_V4L2_FORMAT_FMT_SLICED
 
+/* Define to 1 if the system has the type `struct v4l2_frmivalenum'. */
+#undef HAVE_STRUCT_V4L2_FRMIVALENUM
+
+/* Define to 1 if `reserved' is a member of `struct v4l2_frmivalenum'. */
+#undef HAVE_STRUCT_V4L2_FRMIVALENUM_RESERVED
+
+/* Define to 1 if the system has the type `struct v4l2_frmival_stepwise'. */
+#undef HAVE_STRUCT_V4L2_FRMIVAL_STEPWISE
+
+/* Define to 1 if `step' is a member of `struct v4l2_frmival_stepwise'. */
+#undef HAVE_STRUCT_V4L2_FRMIVAL_STEPWISE_STEP
+
+/* Define to 1 if the system has the type `struct v4l2_frmsizeenum'. */
+#undef HAVE_STRUCT_V4L2_FRMSIZEENUM
+
+/* Define to 1 if `reserved' is a member of `struct v4l2_frmsizeenum'. */
+#undef HAVE_STRUCT_V4L2_FRMSIZEENUM_RESERVED
+
+/* Define to 1 if the system has the type `struct v4l2_frmsize_discrete'. */
+#undef HAVE_STRUCT_V4L2_FRMSIZE_DISCRETE
+
+/* Define to 1 if `height' is a member of `struct v4l2_frmsize_discrete'. */
+#undef HAVE_STRUCT_V4L2_FRMSIZE_DISCRETE_HEIGHT
+
+/* Define to 1 if the system has the type `struct v4l2_frmsize_stepwise'. */
+#undef HAVE_STRUCT_V4L2_FRMSIZE_STEPWISE
+
+/* Define to 1 if `step_height' is a member of `struct v4l2_frmsize_stepwise'.
+   */
+#undef HAVE_STRUCT_V4L2_FRMSIZE_STEPWISE_STEP_HEIGHT
+
+/* Define to 1 if the system has the type `struct v4l2_meta_format'. */
+#undef HAVE_STRUCT_V4L2_META_FORMAT
+
+/* Define to 1 if the system has the type `struct v4l2_pix_format'. */
+#undef HAVE_STRUCT_V4L2_PIX_FORMAT
+
+/* Define to 1 if the system has the type `struct v4l2_pix_format_mplane'. */
+#undef HAVE_STRUCT_V4L2_PIX_FORMAT_MPLANE
+
+/* Define to 1 if `xfer_func' is a member of `struct v4l2_pix_format'. */
+#undef HAVE_STRUCT_V4L2_PIX_FORMAT_XFER_FUNC
+
+/* Define to 1 if the system has the type `struct v4l2_plane_pix_format'. */
+#undef HAVE_STRUCT_V4L2_PLANE_PIX_FORMAT
+
+/* Define to 1 if `reserved' is a member of `struct v4l2_plane_pix_format'. */
+#undef HAVE_STRUCT_V4L2_PLANE_PIX_FORMAT_RESERVED
+
+/* Define to 1 if the system has the type `struct v4l2_sdr_format'. */
+#undef HAVE_STRUCT_V4L2_SDR_FORMAT
+
 /* Define to 1 if `buffersize' is a member of `struct v4l2_sdr_format'. */
 #undef HAVE_STRUCT_V4L2_SDR_FORMAT_BUFFERSIZE
 
+/* Define to 1 if the system has the type `struct v4l2_sliced_vbi_cap'. */
+#undef HAVE_STRUCT_V4L2_SLICED_VBI_CAP
+
+/* Define to 1 if `reserved' is a member of `struct v4l2_sliced_vbi_cap'. */
+#undef HAVE_STRUCT_V4L2_SLICED_VBI_CAP_RESERVED
+
+/* Define to 1 if the system has the type `struct v4l2_sliced_vbi_format'. */
+#undef HAVE_STRUCT_V4L2_SLICED_VBI_FORMAT
+
+/* Define to 1 if `reserved' is a member of `struct v4l2_sliced_vbi_format'.
+   */
+#undef HAVE_STRUCT_V4L2_SLICED_VBI_FORMAT_RESERVED
+
+/* Define to 1 if the system has the type `struct v4l2_vbi_format'. */
+#undef HAVE_STRUCT_V4L2_VBI_FORMAT
+
+/* Define to 1 if `reserved' is a member of `struct v4l2_vbi_format'. */
+#undef HAVE_STRUCT_V4L2_VBI_FORMAT_RESERVED
+
+/* Define to 1 if the system has the type `struct v4l2_window'. */
+#undef HAVE_STRUCT_V4L2_WINDOW
+
 /* Define to 1 if `global_alpha' is a member of `struct v4l2_window'. */
 #undef HAVE_STRUCT_V4L2_WINDOW_GLOBAL_ALPHA
 
@@ -1662,9 +3126,6 @@
 /* Define to 1 if you have the `sync_file_range' function. */
 #undef HAVE_SYNC_FILE_RANGE
 
-/* Define to 1 if you have the <sys/conf.h> header file. */
-#undef HAVE_SYS_CONF_H
-
 /* Define to 1 if you have the <sys/eventfd.h> header file. */
 #undef HAVE_SYS_EVENTFD_H
 
@@ -1707,6 +3168,30 @@
 /* Define to 1 if `attach_type' is a member of `union bpf_attr'. */
 #undef HAVE_UNION_BPF_ATTR_ATTACH_TYPE
 
+/* Define to 1 if `batch.count' is a member of `union bpf_attr'. */
+#undef HAVE_UNION_BPF_ATTR_BATCH_COUNT
+
+/* Define to 1 if `batch.elem_flags' is a member of `union bpf_attr'. */
+#undef HAVE_UNION_BPF_ATTR_BATCH_ELEM_FLAGS
+
+/* Define to 1 if `batch.flags' is a member of `union bpf_attr'. */
+#undef HAVE_UNION_BPF_ATTR_BATCH_FLAGS
+
+/* Define to 1 if `batch.in_batch' is a member of `union bpf_attr'. */
+#undef HAVE_UNION_BPF_ATTR_BATCH_IN_BATCH
+
+/* Define to 1 if `batch.keys' is a member of `union bpf_attr'. */
+#undef HAVE_UNION_BPF_ATTR_BATCH_KEYS
+
+/* Define to 1 if `batch.map_fd' is a member of `union bpf_attr'. */
+#undef HAVE_UNION_BPF_ATTR_BATCH_MAP_FD
+
+/* Define to 1 if `batch.out_batch' is a member of `union bpf_attr'. */
+#undef HAVE_UNION_BPF_ATTR_BATCH_OUT_BATCH
+
+/* Define to 1 if `batch.values' is a member of `union bpf_attr'. */
+#undef HAVE_UNION_BPF_ATTR_BATCH_VALUES
+
 /* Define to 1 if `bpf_fd' is a member of `union bpf_attr'. */
 #undef HAVE_UNION_BPF_ATTR_BPF_FD
 
@@ -1737,6 +3222,10 @@
 /* Define to 1 if `btf_value_type_id' is a member of `union bpf_attr'. */
 #undef HAVE_UNION_BPF_ATTR_BTF_VALUE_TYPE_ID
 
+/* Define to 1 if `btf_vmlinux_value_type_id' is a member of `union bpf_attr'.
+   */
+#undef HAVE_UNION_BPF_ATTR_BTF_VMLINUX_VALUE_TYPE_ID
+
 /* Define to 1 if `dummy' is a member of `union bpf_attr'. */
 #undef HAVE_UNION_BPF_ATTR_DUMMY
 
@@ -1797,6 +3286,33 @@
 /* Define to 1 if `line_info_rec_size' is a member of `union bpf_attr'. */
 #undef HAVE_UNION_BPF_ATTR_LINE_INFO_REC_SIZE
 
+/* Define to 1 if `link_create.attach_type' is a member of `union bpf_attr'.
+   */
+#undef HAVE_UNION_BPF_ATTR_LINK_CREATE_ATTACH_TYPE
+
+/* Define to 1 if `link_create.flags' is a member of `union bpf_attr'. */
+#undef HAVE_UNION_BPF_ATTR_LINK_CREATE_FLAGS
+
+/* Define to 1 if `link_create.prog_fd' is a member of `union bpf_attr'. */
+#undef HAVE_UNION_BPF_ATTR_LINK_CREATE_PROG_FD
+
+/* Define to 1 if `link_create.target_fd' is a member of `union bpf_attr'. */
+#undef HAVE_UNION_BPF_ATTR_LINK_CREATE_TARGET_FD
+
+/* Define to 1 if `link_update.flags' is a member of `union bpf_attr'. */
+#undef HAVE_UNION_BPF_ATTR_LINK_UPDATE_FLAGS
+
+/* Define to 1 if `link_update.link_fd' is a member of `union bpf_attr'. */
+#undef HAVE_UNION_BPF_ATTR_LINK_UPDATE_LINK_FD
+
+/* Define to 1 if `link_update.new_prog_fd' is a member of `union bpf_attr'.
+   */
+#undef HAVE_UNION_BPF_ATTR_LINK_UPDATE_NEW_PROG_FD
+
+/* Define to 1 if `link_update.old_prog_fd' is a member of `union bpf_attr'.
+   */
+#undef HAVE_UNION_BPF_ATTR_LINK_UPDATE_OLD_PROG_FD
+
 /* Define to 1 if `log_buf' is a member of `union bpf_attr'. */
 #undef HAVE_UNION_BPF_ATTR_LOG_BUF
 
@@ -1884,6 +3400,9 @@
 /* Define to 1 if `raw_tracepoint.prog_fd' is a member of `union bpf_attr'. */
 #undef HAVE_UNION_BPF_ATTR_RAW_TRACEPOINT_PROG_FD
 
+/* Define to 1 if `replace_bpf_fd' is a member of `union bpf_attr'. */
+#undef HAVE_UNION_BPF_ATTR_REPLACE_BPF_FD
+
 /* Define to 1 if `start_id' is a member of `union bpf_attr'. */
 #undef HAVE_UNION_BPF_ATTR_START_ID
 
@@ -1967,9 +3486,6 @@
 /* Define to 1 if you have the <ustat.h> header file. */
 #undef HAVE_USTAT_H
 
-/* Define to 1 if you have the `utimensat' function. */
-#undef HAVE_UTIMENSAT
-
 /* Define to 1 if the system provides _Static_assert */
 #undef HAVE__STATIC_ASSERT
 
diff -pruN 5.5-3/configure 5.9-0ubuntu2/configure
--- 5.5-3/configure	2020-02-06 16:23:33.000000000 +0000
+++ 5.9-0ubuntu2/configure	2020-09-24 09:18:58.000000000 +0000
@@ -1,6 +1,6 @@
 #! /bin/sh
 # Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.69 for strace 5.5.
+# Generated by GNU Autoconf 2.69 for strace 5.9.
 #
 # Report bugs to <strace-devel@lists.strace.io>.
 #
@@ -582,8 +582,8 @@ MAKEFLAGS=
 # Identity of this package.
 PACKAGE_NAME='strace'
 PACKAGE_TARNAME='strace'
-PACKAGE_VERSION='5.5'
-PACKAGE_STRING='strace 5.5'
+PACKAGE_VERSION='5.9'
+PACKAGE_STRING='strace 5.9'
 PACKAGE_BUGREPORT='strace-devel@lists.strace.io'
 PACKAGE_URL='https://strace.io'
 
@@ -674,13 +674,24 @@ libdw_LDFLAGS
 libdw_CFLAGS
 libdw_CPPFLAGS
 READELF
-PERL
 mq_LIBS
 clock_LIBS
 timer_LIBS
 dl_LIBS
 SIZEOF_KERNEL_LONG_T
 SIZEOF_LONG
+ac_ct_AR
+AR
+WARN_CFLAGS_FOR_BUILD
+LDFLAGS_FOR_BUILD
+CPPFLAGS_FOR_BUILD
+CFLAGS_FOR_BUILD
+BUILD_OBJEXT
+BUILD_EXEEXT
+CPP_FOR_BUILD
+ac_ct_CC_FOR_BUILD
+CC_FOR_BUILD
+WARN_CFLAGS
 MIPS_ABI
 arch_native
 cc_flags_mx32
@@ -706,16 +717,6 @@ SED
 EGREP
 GREP
 RANLIB
-WARN_CFLAGS_FOR_BUILD
-LDFLAGS_FOR_BUILD
-CPPFLAGS_FOR_BUILD
-CFLAGS_FOR_BUILD
-BUILD_OBJEXT
-BUILD_EXEEXT
-CPP_FOR_BUILD
-ac_ct_CC_FOR_BUILD
-CC_FOR_BUILD
-WARN_CFLAGS
 CPP
 am__fastdepCC_FALSE
 am__fastdepCC_TRUE
@@ -818,10 +819,10 @@ enable_option_checking
 enable_silent_rules
 enable_maintainer_mode
 enable_dependency_tracking
-enable_gcc_Werror
 with_gcov
 enable_code_coverage
 enable_arm_oabi
+enable_gcc_Werror
 enable_stacktrace
 with_libdw
 with_libunwind
@@ -1382,7 +1383,7 @@ if test "$ac_init_help" = "long"; then
   # Omit some internal or obsolete options to make the list less imposing.
   # This message is too long to be a string in the A/UX 3.1 sh.
   cat <<_ACEOF
-\`configure' configures strace 5.5 to adapt to many kinds of systems.
+\`configure' configures strace 5.9 to adapt to many kinds of systems.
 
 Usage: $0 [OPTION]... [VAR=VALUE]...
 
@@ -1452,7 +1453,7 @@ fi
 
 if test -n "$ac_init_help"; then
   case $ac_init_help in
-     short | recursive ) echo "Configuration of strace 5.5:";;
+     short | recursive ) echo "Configuration of strace 5.9:";;
    esac
   cat <<\_ACEOF
 
@@ -1469,9 +1470,9 @@ Optional Features:
                           do not reject slow dependency extractors
   --disable-dependency-tracking
                           speeds up one-time build
-  --enable-gcc-Werror     turn on gcc's -Werror option
   --enable-code-coverage  Whether to enable code coverage support
   --enable-arm-oabi       enable OABI support on ARM EABI
+  --enable-gcc-Werror     turn on gcc's -Werror option
   --enable-stacktrace=yes|no|check
                           whether to enable stack tracing support, default is
                           check
@@ -1575,7 +1576,7 @@ fi
 test -n "$ac_init_help" && exit $ac_status
 if $ac_init_version; then
   cat <<\_ACEOF
-strace configure 5.5
+strace configure 5.9
 generated by GNU Autoconf 2.69
 
 Copyright (C) 2012 Free Software Foundation, Inc.
@@ -1666,52 +1667,6 @@ fi
 
 } # ac_fn_c_try_cpp
 
-# ac_fn_c_try_link LINENO
-# -----------------------
-# Try to link conftest.$ac_ext, and return whether this succeeded.
-ac_fn_c_try_link ()
-{
-  as_lineno=${as_lineno-"$1"} as_lineno_stack=as_lineno_stack=$as_lineno_stack
-  rm -f conftest.$ac_objext conftest$ac_exeext
-  if { { ac_try="$ac_link"
-case "(($ac_try" in
-  *\"* | *\`* | *\\*) ac_try_echo=\$ac_try;;
-  *) ac_try_echo=$ac_try;;
-esac
-eval ac_try_echo="\"\$as_me:${as_lineno-$LINENO}: $ac_try_echo\""
-$as_echo "$ac_try_echo"; } >&5
-  (eval "$ac_link") 2>conftest.err
-  ac_status=$?
-  if test -s conftest.err; then
-    grep -v '^ *+' conftest.err >conftest.er1
-    cat conftest.er1 >&5
-    mv -f conftest.er1 conftest.err
-  fi
-  $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
-  test $ac_status = 0; } && {
-	 test -z "$ac_c_werror_flag" ||
-	 test ! -s conftest.err
-       } && test -s conftest$ac_exeext && {
-	 test "$cross_compiling" = yes ||
-	 test -x conftest$ac_exeext
-       }; then :
-  ac_retval=0
-else
-  $as_echo "$as_me: failed program was:" >&5
-sed 's/^/| /' conftest.$ac_ext >&5
-
-	ac_retval=1
-fi
-  # Delete the IPA/IPO (Inter Procedural Analysis/Optimization) information
-  # created by the PGI compiler (conftest_ipa8_conftest.oo), as it would
-  # interfere with the next link command; also delete a directory that is
-  # left behind by Apple's compiler.  We do this before executing the actions.
-  rm -rf conftest.dSYM conftest_ipa8_conftest.oo
-  eval $as_lineno_stack; ${as_lineno_stack:+:} unset as_lineno
-  as_fn_set_status $ac_retval
-
-} # ac_fn_c_try_link
-
 # ac_fn_c_check_header_mongrel LINENO HEADER VAR INCLUDES
 # -------------------------------------------------------
 # Tests whether HEADER exists, giving a warning if it cannot be compiled using
@@ -2059,6 +2014,52 @@ rm -f conftest.val
 
 } # ac_fn_c_compute_int
 
+# ac_fn_c_try_link LINENO
+# -----------------------
+# Try to link conftest.$ac_ext, and return whether this succeeded.
+ac_fn_c_try_link ()
+{
+  as_lineno=${as_lineno-"$1"} as_lineno_stack=as_lineno_stack=$as_lineno_stack
+  rm -f conftest.$ac_objext conftest$ac_exeext
+  if { { ac_try="$ac_link"
+case "(($ac_try" in
+  *\"* | *\`* | *\\*) ac_try_echo=\$ac_try;;
+  *) ac_try_echo=$ac_try;;
+esac
+eval ac_try_echo="\"\$as_me:${as_lineno-$LINENO}: $ac_try_echo\""
+$as_echo "$ac_try_echo"; } >&5
+  (eval "$ac_link") 2>conftest.err
+  ac_status=$?
+  if test -s conftest.err; then
+    grep -v '^ *+' conftest.err >conftest.er1
+    cat conftest.er1 >&5
+    mv -f conftest.er1 conftest.err
+  fi
+  $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
+  test $ac_status = 0; } && {
+	 test -z "$ac_c_werror_flag" ||
+	 test ! -s conftest.err
+       } && test -s conftest$ac_exeext && {
+	 test "$cross_compiling" = yes ||
+	 test -x conftest$ac_exeext
+       }; then :
+  ac_retval=0
+else
+  $as_echo "$as_me: failed program was:" >&5
+sed 's/^/| /' conftest.$ac_ext >&5
+
+	ac_retval=1
+fi
+  # Delete the IPA/IPO (Inter Procedural Analysis/Optimization) information
+  # created by the PGI compiler (conftest_ipa8_conftest.oo), as it would
+  # interfere with the next link command; also delete a directory that is
+  # left behind by Apple's compiler.  We do this before executing the actions.
+  rm -rf conftest.dSYM conftest_ipa8_conftest.oo
+  eval $as_lineno_stack; ${as_lineno_stack:+:} unset as_lineno
+  as_fn_set_status $ac_retval
+
+} # ac_fn_c_try_link
+
 # ac_fn_c_check_func LINENO FUNC VAR
 # ----------------------------------
 # Tests whether FUNC exists, setting the cache variable VAR accordingly
@@ -2315,7 +2316,7 @@ cat >config.log <<_ACEOF
 This file contains any messages produced by compilers while
 running configure, to aid debugging if configure makes a mistake.
 
-It was created by strace $as_me 5.5, which was
+It was created by strace $as_me 5.9, which was
 generated by GNU Autoconf 2.69.  Invocation command line was
 
   $ $0 $@
@@ -3186,7 +3187,7 @@ fi
 
 # Define the identity of the package.
  PACKAGE='strace'
- VERSION='5.5'
+ VERSION='5.9'
 
 
 cat >>confdefs.h <<_ACEOF
@@ -4848,134 +4849,242 @@ ac_link='$CC -o conftest$ac_exeext $CFLA
 ac_compiler_gnu=$ac_cv_c_compiler_gnu
 
 
-if test x${gl_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
+if test -n "$ac_tool_prefix"; then
+  # Extract the first word of "${ac_tool_prefix}ranlib", so it can be a program name with args.
+set dummy ${ac_tool_prefix}ranlib; ac_word=$2
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+$as_echo_n "checking for $ac_word... " >&6; }
+if ${ac_cv_prog_RANLIB+:} false; then :
   $as_echo_n "(cached) " >&6
 else
-
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-
-int
-main ()
-{
-
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
+  if test -n "$RANLIB"; then
+  ac_cv_prog_RANLIB="$RANLIB" # Let the user override the test.
 else
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
-fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
+as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
+for as_dir in $PATH
+do
+  IFS=$as_save_IFS
+  test -z "$as_dir" && as_dir=.
+    for ac_exec_ext in '' $ac_executable_extensions; do
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+    ac_cv_prog_RANLIB="${ac_tool_prefix}ranlib"
+    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+    break 2
+  fi
+done
+  done
+IFS=$as_save_IFS
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
-  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+fi
+RANLIB=$ac_cv_prog_RANLIB
+if test -n "$RANLIB"; then
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $RANLIB" >&5
+$as_echo "$RANLIB" >&6; }
 else
-  gl_unknown_warnings_are_errors=
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
+$as_echo "no" >&6; }
 fi
 
 
 fi
-
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Wall" >&5
-$as_echo_n "checking whether $CC handles -Wall... " >&6; }
-if ${gl_cv_warn_CFLAGS__Wall+:} false; then :
+if test -z "$ac_cv_prog_RANLIB"; then
+  ac_ct_RANLIB=$RANLIB
+  # Extract the first word of "ranlib", so it can be a program name with args.
+set dummy ranlib; ac_word=$2
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+$as_echo_n "checking for $ac_word... " >&6; }
+if ${ac_cv_prog_ac_ct_RANLIB+:} false; then :
   $as_echo_n "(cached) " >&6
 else
+  if test -n "$ac_ct_RANLIB"; then
+  ac_cv_prog_ac_ct_RANLIB="$ac_ct_RANLIB" # Let the user override the test.
+else
+as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
+for as_dir in $PATH
+do
+  IFS=$as_save_IFS
+  test -z "$as_dir" && as_dir=.
+    for ac_exec_ext in '' $ac_executable_extensions; do
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+    ac_cv_prog_ac_ct_RANLIB="ranlib"
+    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+    break 2
+  fi
+done
+  done
+IFS=$as_save_IFS
 
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Wall"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-
-int
-main ()
-{
-
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Wall=yes
+fi
+fi
+ac_ct_RANLIB=$ac_cv_prog_ac_ct_RANLIB
+if test -n "$ac_ct_RANLIB"; then
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_ct_RANLIB" >&5
+$as_echo "$ac_ct_RANLIB" >&6; }
 else
-  gl_cv_warn_CFLAGS__Wall=no
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
+$as_echo "no" >&6; }
 fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Wall" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Wall" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Wall" = xyes; then :
-  as_fn_append WARN_CFLAGS " -Wall"
+  if test "x$ac_ct_RANLIB" = x; then
+    RANLIB=":"
+  else
+    case $cross_compiling:$ac_tool_warned in
+yes:)
+{ $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: using cross tools not prefixed with host triplet" >&5
+$as_echo "$as_me: WARNING: using cross tools not prefixed with host triplet" >&2;}
+ac_tool_warned=yes ;;
+esac
+    RANLIB=$ac_ct_RANLIB
+  fi
+else
+  RANLIB="$ac_cv_prog_RANLIB"
 fi
 
 
-if test x${gl_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
 
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
 
-int
-main ()
-{
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for grep that handles long lines and -e" >&5
+$as_echo_n "checking for grep that handles long lines and -e... " >&6; }
+if ${ac_cv_path_GREP+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  if test -z "$GREP"; then
+  ac_path_GREP_found=false
+  # Loop through the user's path and test for each of PROGNAME-LIST
+  as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
+for as_dir in $PATH$PATH_SEPARATOR/usr/xpg4/bin
+do
+  IFS=$as_save_IFS
+  test -z "$as_dir" && as_dir=.
+    for ac_prog in grep ggrep; do
+    for ac_exec_ext in '' $ac_executable_extensions; do
+      ac_path_GREP="$as_dir/$ac_prog$ac_exec_ext"
+      as_fn_executable_p "$ac_path_GREP" || continue
+# Check for GNU ac_path_GREP and select it if it is found.
+  # Check for GNU $ac_path_GREP
+case `"$ac_path_GREP" --version 2>&1` in
+*GNU*)
+  ac_cv_path_GREP="$ac_path_GREP" ac_path_GREP_found=:;;
+*)
+  ac_count=0
+  $as_echo_n 0123456789 >"conftest.in"
+  while :
+  do
+    cat "conftest.in" "conftest.in" >"conftest.tmp"
+    mv "conftest.tmp" "conftest.in"
+    cp "conftest.in" "conftest.nl"
+    $as_echo 'GREP' >> "conftest.nl"
+    "$ac_path_GREP" -e 'GREP$' -e '-(cannot match)-' < "conftest.nl" >"conftest.out" 2>/dev/null || break
+    diff "conftest.out" "conftest.nl" >/dev/null 2>&1 || break
+    as_fn_arith $ac_count + 1 && ac_count=$as_val
+    if test $ac_count -gt ${ac_path_GREP_max-0}; then
+      # Best one so far, save it but keep looking for a better one
+      ac_cv_path_GREP="$ac_path_GREP"
+      ac_path_GREP_max=$ac_count
+    fi
+    # 10*(2^10) chars as input seems more than enough
+    test $ac_count -gt 10 && break
+  done
+  rm -f conftest.in conftest.tmp conftest.nl conftest.out;;
+esac
 
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
+      $ac_path_GREP_found && break 3
+    done
+  done
+  done
+IFS=$as_save_IFS
+  if test -z "$ac_cv_path_GREP"; then
+    as_fn_error $? "no acceptable grep could be found in $PATH$PATH_SEPARATOR/usr/xpg4/bin" "$LINENO" 5
+  fi
 else
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
+  ac_cv_path_GREP=$GREP
 fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
-  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_path_GREP" >&5
+$as_echo "$ac_cv_path_GREP" >&6; }
+ GREP="$ac_cv_path_GREP"
+
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for egrep" >&5
+$as_echo_n "checking for egrep... " >&6; }
+if ${ac_cv_path_EGREP+:} false; then :
+  $as_echo_n "(cached) " >&6
 else
-  gl_unknown_warnings_are_errors=
-fi
+  if echo a | $GREP -E '(a|b)' >/dev/null 2>&1
+   then ac_cv_path_EGREP="$GREP -E"
+   else
+     if test -z "$EGREP"; then
+  ac_path_EGREP_found=false
+  # Loop through the user's path and test for each of PROGNAME-LIST
+  as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
+for as_dir in $PATH$PATH_SEPARATOR/usr/xpg4/bin
+do
+  IFS=$as_save_IFS
+  test -z "$as_dir" && as_dir=.
+    for ac_prog in egrep; do
+    for ac_exec_ext in '' $ac_executable_extensions; do
+      ac_path_EGREP="$as_dir/$ac_prog$ac_exec_ext"
+      as_fn_executable_p "$ac_path_EGREP" || continue
+# Check for GNU ac_path_EGREP and select it if it is found.
+  # Check for GNU $ac_path_EGREP
+case `"$ac_path_EGREP" --version 2>&1` in
+*GNU*)
+  ac_cv_path_EGREP="$ac_path_EGREP" ac_path_EGREP_found=:;;
+*)
+  ac_count=0
+  $as_echo_n 0123456789 >"conftest.in"
+  while :
+  do
+    cat "conftest.in" "conftest.in" >"conftest.tmp"
+    mv "conftest.tmp" "conftest.in"
+    cp "conftest.in" "conftest.nl"
+    $as_echo 'EGREP' >> "conftest.nl"
+    "$ac_path_EGREP" 'EGREP$' < "conftest.nl" >"conftest.out" 2>/dev/null || break
+    diff "conftest.out" "conftest.nl" >/dev/null 2>&1 || break
+    as_fn_arith $ac_count + 1 && ac_count=$as_val
+    if test $ac_count -gt ${ac_path_EGREP_max-0}; then
+      # Best one so far, save it but keep looking for a better one
+      ac_cv_path_EGREP="$ac_path_EGREP"
+      ac_path_EGREP_max=$ac_count
+    fi
+    # 10*(2^10) chars as input seems more than enough
+    test $ac_count -gt 10 && break
+  done
+  rm -f conftest.in conftest.tmp conftest.nl conftest.out;;
+esac
 
+      $ac_path_EGREP_found && break 3
+    done
+  done
+  done
+IFS=$as_save_IFS
+  if test -z "$ac_cv_path_EGREP"; then
+    as_fn_error $? "no acceptable egrep could be found in $PATH$PATH_SEPARATOR/usr/xpg4/bin" "$LINENO" 5
+  fi
+else
+  ac_cv_path_EGREP=$EGREP
+fi
 
+   fi
 fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_path_EGREP" >&5
+$as_echo "$ac_cv_path_EGREP" >&6; }
+ EGREP="$ac_cv_path_EGREP"
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Wempty-body" >&5
-$as_echo_n "checking whether $CC handles -Wempty-body... " >&6; }
-if ${gl_cv_warn_CFLAGS__Wempty_body+:} false; then :
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for ANSI C header files" >&5
+$as_echo_n "checking for ANSI C header files... " >&6; }
+if ${ac_cv_header_stdc+:} false; then :
   $as_echo_n "(cached) " >&6
 else
-
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Wempty-body"
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
+#include <stdlib.h>
+#include <stdarg.h>
+#include <string.h>
+#include <float.h>
 
 int
 main ()
@@ -4985,189 +5094,147 @@ main ()
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Wempty_body=yes
+if ac_fn_c_try_compile "$LINENO"; then :
+  ac_cv_header_stdc=yes
 else
-  gl_cv_warn_CFLAGS__Wempty_body=no
+  ac_cv_header_stdc=no
 fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
+rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Wempty_body" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Wempty_body" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Wempty_body" = xyes; then :
-  as_fn_append WARN_CFLAGS " -Wempty-body"
-fi
+if test $ac_cv_header_stdc = yes; then
+  # SunOS 4.x string.h does not declare mem*, contrary to ANSI.
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+#include <string.h>
 
+_ACEOF
+if (eval "$ac_cpp conftest.$ac_ext") 2>&5 |
+  $EGREP "memchr" >/dev/null 2>&1; then :
 
-if test x${gl_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
 else
+  ac_cv_header_stdc=no
+fi
+rm -f conftest*
 
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+fi
+
+if test $ac_cv_header_stdc = yes; then
+  # ISC 2.0.2 stdlib.h does not declare free, contrary to ANSI.
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
+#include <stdlib.h>
 
-int
-main ()
-{
-
-  ;
-  return 0;
-}
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
-fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
+if (eval "$ac_cpp conftest.$ac_ext") 2>&5 |
+  $EGREP "free" >/dev/null 2>&1; then :
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
-  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
 else
-  gl_unknown_warnings_are_errors=
+  ac_cv_header_stdc=no
 fi
-
+rm -f conftest*
 
 fi
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Wformat-security" >&5
-$as_echo_n "checking whether $CC handles -Wformat-security... " >&6; }
-if ${gl_cv_warn_CFLAGS__Wformat_security+:} false; then :
-  $as_echo_n "(cached) " >&6
+if test $ac_cv_header_stdc = yes; then
+  # /bin/cc in Irix-4.0.5 gets non-ANSI ctype macros unless using -ansi.
+  if test "$cross_compiling" = yes; then :
+  :
 else
-
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Wformat-security"
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
+#include <ctype.h>
+#include <stdlib.h>
+#if ((' ' & 0x0FF) == 0x020)
+# define ISLOWER(c) ('a' <= (c) && (c) <= 'z')
+# define TOUPPER(c) (ISLOWER(c) ? 'A' + ((c) - 'a') : (c))
+#else
+# define ISLOWER(c) \
+		   (('a' <= (c) && (c) <= 'i') \
+		     || ('j' <= (c) && (c) <= 'r') \
+		     || ('s' <= (c) && (c) <= 'z'))
+# define TOUPPER(c) (ISLOWER(c) ? ((c) | 0x40) : (c))
+#endif
 
+#define XOR(e, f) (((e) && !(f)) || (!(e) && (f)))
 int
 main ()
 {
-
-  ;
+  int i;
+  for (i = 0; i < 256; i++)
+    if (XOR (islower (i), ISLOWER (i))
+	|| toupper (i) != TOUPPER (i))
+      return 2;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Wformat_security=yes
+if ac_fn_c_try_run "$LINENO"; then :
+
 else
-  gl_cv_warn_CFLAGS__Wformat_security=no
+  ac_cv_header_stdc=no
+fi
+rm -f core *.core core.conftest.* gmon.out bb.out conftest$ac_exeext \
+  conftest.$ac_objext conftest.beam conftest.$ac_ext
 fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Wformat_security" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Wformat_security" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Wformat_security" = xyes; then :
-  as_fn_append WARN_CFLAGS " -Wformat-security"
 fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_header_stdc" >&5
+$as_echo "$ac_cv_header_stdc" >&6; }
+if test $ac_cv_header_stdc = yes; then
 
+$as_echo "#define STDC_HEADERS 1" >>confdefs.h
 
-if test x${gl_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-
-int
-main ()
-{
+fi
 
-  ;
-  return 0;
-}
+# On IRIX 5.3, sys/types and inttypes.h are conflicting.
+for ac_header in sys/types.h sys/stat.h stdlib.h string.h memory.h strings.h \
+		  inttypes.h stdint.h unistd.h
+do :
+  as_ac_Header=`$as_echo "ac_cv_header_$ac_header" | $as_tr_sh`
+ac_fn_c_check_header_compile "$LINENO" "$ac_header" "$as_ac_Header" "$ac_includes_default
+"
+if eval test \"x\$"$as_ac_Header"\" = x"yes"; then :
+  cat >>confdefs.h <<_ACEOF
+#define `$as_echo "HAVE_$ac_header" | $as_tr_cpp` 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
-fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
-  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+
+done
+
+
+
+  ac_fn_c_check_header_mongrel "$LINENO" "minix/config.h" "ac_cv_header_minix_config_h" "$ac_includes_default"
+if test "x$ac_cv_header_minix_config_h" = xyes; then :
+  MINIX=yes
 else
-  gl_unknown_warnings_are_errors=
+  MINIX=
 fi
 
 
-fi
+  if test "$MINIX" = yes; then
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Wignored-qualifiers" >&5
-$as_echo_n "checking whether $CC handles -Wignored-qualifiers... " >&6; }
-if ${gl_cv_warn_CFLAGS__Wignored_qualifiers+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+$as_echo "#define _POSIX_SOURCE 1" >>confdefs.h
 
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Wignored-qualifiers"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
 
-int
-main ()
-{
+$as_echo "#define _POSIX_1_SOURCE 2" >>confdefs.h
 
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Wignored_qualifiers=yes
-else
-  gl_cv_warn_CFLAGS__Wignored_qualifiers=no
-fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Wignored_qualifiers" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Wignored_qualifiers" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Wignored_qualifiers" = xyes; then :
-  as_fn_append WARN_CFLAGS " -Wignored-qualifiers"
-fi
+$as_echo "#define _MINIX 1" >>confdefs.h
 
+  fi
 
-if test x${gl_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
+
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether it is safe to define __EXTENSIONS__" >&5
+$as_echo_n "checking whether it is safe to define __EXTENSIONS__... " >&6; }
+if ${ac_cv_safe_to_define___extensions__+:} false; then :
   $as_echo_n "(cached) " >&6
 else
-
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 
+#         define __EXTENSIONS__ 1
+          $ac_includes_default
 int
 main ()
 {
@@ -5176,885 +5243,823 @@ main ()
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
+if ac_fn_c_try_compile "$LINENO"; then :
+  ac_cv_safe_to_define___extensions__=yes
 else
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
-fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
-
+  ac_cv_safe_to_define___extensions__=no
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
-  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
-else
-  gl_unknown_warnings_are_errors=
+rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
 fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_safe_to_define___extensions__" >&5
+$as_echo "$ac_cv_safe_to_define___extensions__" >&6; }
+  test $ac_cv_safe_to_define___extensions__ = yes &&
+    $as_echo "#define __EXTENSIONS__ 1" >>confdefs.h
 
+  $as_echo "#define _ALL_SOURCE 1" >>confdefs.h
 
-fi
+  $as_echo "#define _GNU_SOURCE 1" >>confdefs.h
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Wimplicit-fallthrough=5" >&5
-$as_echo_n "checking whether $CC handles -Wimplicit-fallthrough=5... " >&6; }
-if ${gl_cv_warn_CFLAGS__Wimplicit_fallthrough_5+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+  $as_echo "#define _POSIX_PTHREAD_SEMANTICS 1" >>confdefs.h
 
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Wimplicit-fallthrough=5"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+  $as_echo "#define _TANDEM_SOURCE 1" >>confdefs.h
 
-int
-main ()
-{
 
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Wimplicit_fallthrough_5=yes
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for a sed that does not truncate output" >&5
+$as_echo_n "checking for a sed that does not truncate output... " >&6; }
+if ${ac_cv_path_SED+:} false; then :
+  $as_echo_n "(cached) " >&6
 else
-  gl_cv_warn_CFLAGS__Wimplicit_fallthrough_5=no
-fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
+            ac_script=s/aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa/bbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb/
+     for ac_i in 1 2 3 4 5 6 7; do
+       ac_script="$ac_script$as_nl$ac_script"
+     done
+     echo "$ac_script" 2>/dev/null | sed 99q >conftest.sed
+     { ac_script=; unset ac_script;}
+     if test -z "$SED"; then
+  ac_path_SED_found=false
+  # Loop through the user's path and test for each of PROGNAME-LIST
+  as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
+for as_dir in $PATH
+do
+  IFS=$as_save_IFS
+  test -z "$as_dir" && as_dir=.
+    for ac_prog in sed gsed; do
+    for ac_exec_ext in '' $ac_executable_extensions; do
+      ac_path_SED="$as_dir/$ac_prog$ac_exec_ext"
+      as_fn_executable_p "$ac_path_SED" || continue
+# Check for GNU ac_path_SED and select it if it is found.
+  # Check for GNU $ac_path_SED
+case `"$ac_path_SED" --version 2>&1` in
+*GNU*)
+  ac_cv_path_SED="$ac_path_SED" ac_path_SED_found=:;;
+*)
+  ac_count=0
+  $as_echo_n 0123456789 >"conftest.in"
+  while :
+  do
+    cat "conftest.in" "conftest.in" >"conftest.tmp"
+    mv "conftest.tmp" "conftest.in"
+    cp "conftest.in" "conftest.nl"
+    $as_echo '' >> "conftest.nl"
+    "$ac_path_SED" -f conftest.sed < "conftest.nl" >"conftest.out" 2>/dev/null || break
+    diff "conftest.out" "conftest.nl" >/dev/null 2>&1 || break
+    as_fn_arith $ac_count + 1 && ac_count=$as_val
+    if test $ac_count -gt ${ac_path_SED_max-0}; then
+      # Best one so far, save it but keep looking for a better one
+      ac_cv_path_SED="$ac_path_SED"
+      ac_path_SED_max=$ac_count
+    fi
+    # 10*(2^10) chars as input seems more than enough
+    test $ac_count -gt 10 && break
+  done
+  rm -f conftest.in conftest.tmp conftest.nl conftest.out;;
+esac
 
+      $ac_path_SED_found && break 3
+    done
+  done
+  done
+IFS=$as_save_IFS
+  if test -z "$ac_cv_path_SED"; then
+    as_fn_error $? "no acceptable sed could be found in \$PATH" "$LINENO" 5
+  fi
+else
+  ac_cv_path_SED=$SED
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Wimplicit_fallthrough_5" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Wimplicit_fallthrough_5" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Wimplicit_fallthrough_5" = xyes; then :
-  as_fn_append WARN_CFLAGS " -Wimplicit-fallthrough=5"
+
 fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_path_SED" >&5
+$as_echo "$ac_cv_path_SED" >&6; }
+ SED="$ac_cv_path_SED"
+  rm -f conftest.sed
 
 
-if test x${gl_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
 
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
 
-int
-main ()
-{
+	# allow to override gcov location
 
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
+# Check whether --with-gcov was given.
+if test "${with_gcov+set}" = set; then :
+  withval=$with_gcov; _AX_CODE_COVERAGE_GCOV_PROG_WITH=$with_gcov
 else
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
+  _AX_CODE_COVERAGE_GCOV_PROG_WITH=gcov
 fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
-  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+
+	{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether to build with code coverage support" >&5
+$as_echo_n "checking whether to build with code coverage support... " >&6; }
+	# Check whether --enable-code-coverage was given.
+if test "${enable_code_coverage+set}" = set; then :
+  enableval=$enable_code_coverage;
 else
-  gl_unknown_warnings_are_errors=
+  enable_code_coverage=no
 fi
 
 
+	 if test x$enable_code_coverage = xyes; then
+  CODE_COVERAGE_ENABLED_TRUE=
+  CODE_COVERAGE_ENABLED_FALSE='#'
+else
+  CODE_COVERAGE_ENABLED_TRUE='#'
+  CODE_COVERAGE_ENABLED_FALSE=
 fi
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Winit-self" >&5
-$as_echo_n "checking whether $CC handles -Winit-self... " >&6; }
-if ${gl_cv_warn_CFLAGS__Winit_self+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+	CODE_COVERAGE_ENABLED=$enable_code_coverage
 
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Winit-self"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+	{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $enable_code_coverage" >&5
+$as_echo "$enable_code_coverage" >&6; }
 
-int
-main ()
-{
+	if  test "$enable_code_coverage" = "yes" ; then :
 
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Winit_self=yes
+		# check for gcov
+		if test -n "$ac_tool_prefix"; then
+  # Extract the first word of "${ac_tool_prefix}$_AX_CODE_COVERAGE_GCOV_PROG_WITH", so it can be a program name with args.
+set dummy ${ac_tool_prefix}$_AX_CODE_COVERAGE_GCOV_PROG_WITH; ac_word=$2
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+$as_echo_n "checking for $ac_word... " >&6; }
+if ${ac_cv_prog_GCOV+:} false; then :
+  $as_echo_n "(cached) " >&6
 else
-  gl_cv_warn_CFLAGS__Winit_self=no
-fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
+  if test -n "$GCOV"; then
+  ac_cv_prog_GCOV="$GCOV" # Let the user override the test.
+else
+as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
+for as_dir in $PATH
+do
+  IFS=$as_save_IFS
+  test -z "$as_dir" && as_dir=.
+    for ac_exec_ext in '' $ac_executable_extensions; do
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+    ac_cv_prog_GCOV="${ac_tool_prefix}$_AX_CODE_COVERAGE_GCOV_PROG_WITH"
+    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+    break 2
+  fi
+done
+  done
+IFS=$as_save_IFS
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Winit_self" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Winit_self" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Winit_self" = xyes; then :
-  as_fn_append WARN_CFLAGS " -Winit-self"
+fi
+GCOV=$ac_cv_prog_GCOV
+if test -n "$GCOV"; then
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $GCOV" >&5
+$as_echo "$GCOV" >&6; }
+else
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
+$as_echo "no" >&6; }
 fi
 
 
-if test x${gl_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
+fi
+if test -z "$ac_cv_prog_GCOV"; then
+  ac_ct_GCOV=$GCOV
+  # Extract the first word of "$_AX_CODE_COVERAGE_GCOV_PROG_WITH", so it can be a program name with args.
+set dummy $_AX_CODE_COVERAGE_GCOV_PROG_WITH; ac_word=$2
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+$as_echo_n "checking for $ac_word... " >&6; }
+if ${ac_cv_prog_ac_ct_GCOV+:} false; then :
   $as_echo_n "(cached) " >&6
 else
-
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-
-int
-main ()
-{
-
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
+  if test -n "$ac_ct_GCOV"; then
+  ac_cv_prog_ac_ct_GCOV="$ac_ct_GCOV" # Let the user override the test.
 else
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
-fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
+as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
+for as_dir in $PATH
+do
+  IFS=$as_save_IFS
+  test -z "$as_dir" && as_dir=.
+    for ac_exec_ext in '' $ac_executable_extensions; do
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+    ac_cv_prog_ac_ct_GCOV="$_AX_CODE_COVERAGE_GCOV_PROG_WITH"
+    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+    break 2
+  fi
+done
+  done
+IFS=$as_save_IFS
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
-  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+fi
+ac_ct_GCOV=$ac_cv_prog_ac_ct_GCOV
+if test -n "$ac_ct_GCOV"; then
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_ct_GCOV" >&5
+$as_echo "$ac_ct_GCOV" >&6; }
 else
-  gl_unknown_warnings_are_errors=
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
+$as_echo "no" >&6; }
 fi
 
-
+  if test "x$ac_ct_GCOV" = x; then
+    GCOV=":"
+  else
+    case $cross_compiling:$ac_tool_warned in
+yes:)
+{ $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: using cross tools not prefixed with host triplet" >&5
+$as_echo "$as_me: WARNING: using cross tools not prefixed with host triplet" >&2;}
+ac_tool_warned=yes ;;
+esac
+    GCOV=$ac_ct_GCOV
+  fi
+else
+  GCOV="$ac_cv_prog_GCOV"
 fi
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Winitializer-overrides" >&5
-$as_echo_n "checking whether $CC handles -Winitializer-overrides... " >&6; }
-if ${gl_cv_warn_CFLAGS__Winitializer_overrides+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+		if test "X$GCOV" = "X:"; then :
+  as_fn_error $? "gcov is needed to do coverage" "$LINENO" 5
+fi
 
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Winitializer-overrides"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
 
-int
-main ()
-{
+				if  test "$GCC" = "no" ; then :
 
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Winitializer_overrides=yes
-else
-  gl_cv_warn_CFLAGS__Winitializer_overrides=no
-fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
+			as_fn_error $? "not compiling with gcc, which is required for gcov code coverage" "$LINENO" 5
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Winitializer_overrides" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Winitializer_overrides" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Winitializer_overrides" = xyes; then :
-  as_fn_append WARN_CFLAGS " -Winitializer-overrides"
-fi
 
-
-if test x${gl_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
+		# Extract the first word of "lcov", so it can be a program name with args.
+set dummy lcov; ac_word=$2
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+$as_echo_n "checking for $ac_word... " >&6; }
+if ${ac_cv_prog_LCOV+:} false; then :
   $as_echo_n "(cached) " >&6
 else
-
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-
-int
-main ()
-{
-
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
+  if test -n "$LCOV"; then
+  ac_cv_prog_LCOV="$LCOV" # Let the user override the test.
 else
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
-fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
+as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
+for as_dir in $PATH
+do
+  IFS=$as_save_IFS
+  test -z "$as_dir" && as_dir=.
+    for ac_exec_ext in '' $ac_executable_extensions; do
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+    ac_cv_prog_LCOV="lcov"
+    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+    break 2
+  fi
+done
+  done
+IFS=$as_save_IFS
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
-  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+fi
+LCOV=$ac_cv_prog_LCOV
+if test -n "$LCOV"; then
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $LCOV" >&5
+$as_echo "$LCOV" >&6; }
 else
-  gl_unknown_warnings_are_errors=
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
+$as_echo "no" >&6; }
 fi
 
 
-fi
-
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Wlogical-op" >&5
-$as_echo_n "checking whether $CC handles -Wlogical-op... " >&6; }
-if ${gl_cv_warn_CFLAGS__Wlogical_op+:} false; then :
+		# Extract the first word of "genhtml", so it can be a program name with args.
+set dummy genhtml; ac_word=$2
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+$as_echo_n "checking for $ac_word... " >&6; }
+if ${ac_cv_prog_GENHTML+:} false; then :
   $as_echo_n "(cached) " >&6
 else
-
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Wlogical-op"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-
-int
-main ()
-{
-
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Wlogical_op=yes
-else
-  gl_cv_warn_CFLAGS__Wlogical_op=no
-fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
-
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Wlogical_op" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Wlogical_op" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Wlogical_op" = xyes; then :
-  as_fn_append WARN_CFLAGS " -Wlogical-op"
-fi
-
-
-if test x${gl_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
+  if test -n "$GENHTML"; then
+  ac_cv_prog_GENHTML="$GENHTML" # Let the user override the test.
 else
+as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
+for as_dir in $PATH
+do
+  IFS=$as_save_IFS
+  test -z "$as_dir" && as_dir=.
+    for ac_exec_ext in '' $ac_executable_extensions; do
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+    ac_cv_prog_GENHTML="genhtml"
+    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+    break 2
+  fi
+done
+  done
+IFS=$as_save_IFS
 
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-
-int
-main ()
-{
-
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
 fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
-
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
-  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+GENHTML=$ac_cv_prog_GENHTML
+if test -n "$GENHTML"; then
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $GENHTML" >&5
+$as_echo "$GENHTML" >&6; }
 else
-  gl_unknown_warnings_are_errors=
-fi
-
-
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
+$as_echo "no" >&6; }
 fi
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Wmissing-parameter-type" >&5
-$as_echo_n "checking whether $CC handles -Wmissing-parameter-type... " >&6; }
-if ${gl_cv_warn_CFLAGS__Wmissing_parameter_type+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
 
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Wmissing-parameter-type"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
 
-int
-main ()
-{
+		if  test -z "$LCOV" ; then :
 
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Wmissing_parameter_type=yes
-else
-  gl_cv_warn_CFLAGS__Wmissing_parameter_type=no
-fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
+			as_fn_error $? "To enable code coverage reporting you must have lcov installed" "$LINENO" 5
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Wmissing_parameter_type" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Wmissing_parameter_type" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Wmissing_parameter_type" = xyes; then :
-  as_fn_append WARN_CFLAGS " -Wmissing-parameter-type"
-fi
-
 
-if test x${gl_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-
-int
-main ()
-{
+		if  test -z "$GENHTML" ; then :
 
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
-fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
+			as_fn_error $? "Could not find genhtml from the lcov package" "$LINENO" 5
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
-  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
-else
-  gl_unknown_warnings_are_errors=
-fi
 
+						CODE_COVERAGE_CPPFLAGS="-DENABLE_COVERAGE_GCOV -DNDEBUG"
+		CODE_COVERAGE_CFLAGS="-O0 -g -fprofile-arcs -ftest-coverage"
+		CODE_COVERAGE_CXXFLAGS="-O0 -g -fprofile-arcs -ftest-coverage"
+		CODE_COVERAGE_LIBS="-lgcov"
+		CODE_COVERAGE_LDFLAGS="$CODE_COVERAGE_LIBS"
 
-fi
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Wnested-externs" >&5
-$as_echo_n "checking whether $CC handles -Wnested-externs... " >&6; }
-if ${gl_cv_warn_CFLAGS__Wnested_externs+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
 
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Wnested-externs"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
 
-int
-main ()
-{
 
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Wnested_externs=yes
-else
-  gl_cv_warn_CFLAGS__Wnested_externs=no
-fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Wnested_externs" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Wnested_externs" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Wnested_externs" = xyes; then :
-  as_fn_append WARN_CFLAGS " -Wnested-externs"
-fi
 
+		CODE_COVERAGE_RULES_CHECK='
+	-$(A''M_V_at)$(MAKE) $(AM_MAKEFLAGS) -k check
+	$(A''M_V_at)$(MAKE) $(AM_MAKEFLAGS) code-coverage-capture
+'
+		CODE_COVERAGE_RULES_CAPTURE='
+	$(code_coverage_v_lcov_cap)$(LCOV) $(code_coverage_quiet) $(addprefix --directory ,$(CODE_COVERAGE_DIRECTORY)) --capture --output-file "$(CODE_COVERAGE_OUTPUT_FILE).tmp" --test-name "$(call code_coverage_sanitize,$(PACKAGE_NAME)-$(PACKAGE_VERSION))" --no-checksum --compat-libtool $(CODE_COVERAGE_LCOV_SHOPTS) $(CODE_COVERAGE_LCOV_OPTIONS)
+	$(code_coverage_v_lcov_ign)$(LCOV) $(code_coverage_quiet) $(addprefix --directory ,$(CODE_COVERAGE_DIRECTORY)) --remove "$(CODE_COVERAGE_OUTPUT_FILE).tmp" "/tmp/*" $(CODE_COVERAGE_IGNORE_PATTERN) --output-file "$(CODE_COVERAGE_OUTPUT_FILE)" $(CODE_COVERAGE_LCOV_SHOPTS) $(CODE_COVERAGE_LCOV_RMOPTS)
+	-@rm -f $(CODE_COVERAGE_OUTPUT_FILE).tmp
+	$(code_coverage_v_genhtml)LANG=C $(GENHTML) $(code_coverage_quiet) $(addprefix --prefix ,$(CODE_COVERAGE_DIRECTORY)) --output-directory "$(CODE_COVERAGE_OUTPUT_DIRECTORY)" --title "$(PACKAGE_NAME)-$(PACKAGE_VERSION) Code Coverage" --legend --show-details "$(CODE_COVERAGE_OUTPUT_FILE)" $(CODE_COVERAGE_GENHTML_OPTIONS)
+	@echo "file://$(abs_builddir)/$(CODE_COVERAGE_OUTPUT_DIRECTORY)/index.html"
+'
+		CODE_COVERAGE_RULES_CLEAN='
+clean: code-coverage-clean
+distclean: code-coverage-clean
+code-coverage-clean:
+	-$(LCOV) --directory $(top_builddir) -z
+	-rm -rf $(CODE_COVERAGE_OUTPUT_FILE) $(CODE_COVERAGE_OUTPUT_FILE).tmp $(CODE_COVERAGE_OUTPUT_DIRECTORY)
+	-find . \( -name "*.gcda" -o -name "*.gcno" -o -name "*.gcov" \) -delete
+'
 
-if test x${gl_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
 else
 
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-
-int
-main ()
-{
+		CODE_COVERAGE_RULES_CHECK='
+	@echo "Need to reconfigure with --enable-code-coverage"
+'
+		CODE_COVERAGE_RULES_CAPTURE="$CODE_COVERAGE_RULES_CHECK"
+		CODE_COVERAGE_RULES_CLEAN=''
 
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
 fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
-  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
-else
-  gl_unknown_warnings_are_errors=
-fi
+CODE_COVERAGE_RULES='
+# Code coverage
+#
+# Optional:
+#  - CODE_COVERAGE_DIRECTORY: Top-level directory for code coverage reporting.
+#    Multiple directories may be specified, separated by whitespace.
+#    (Default: $(top_builddir))
+#  - CODE_COVERAGE_OUTPUT_FILE: Filename and path for the .info file generated
+#    by lcov for code coverage. (Default:
+#    $(PACKAGE_NAME)-$(PACKAGE_VERSION)-coverage.info)
+#  - CODE_COVERAGE_OUTPUT_DIRECTORY: Directory for generated code coverage
+#    reports to be created. (Default:
+#    $(PACKAGE_NAME)-$(PACKAGE_VERSION)-coverage)
+#  - CODE_COVERAGE_BRANCH_COVERAGE: Set to 1 to enforce branch coverage,
+#    set to 0 to disable it and leave empty to stay with the default.
+#    (Default: empty)
+#  - CODE_COVERAGE_LCOV_SHOPTS_DEFAULT: Extra options shared between both lcov
+#    instances. (Default: based on $CODE_COVERAGE_BRANCH_COVERAGE)
+#  - CODE_COVERAGE_LCOV_SHOPTS: Extra options to shared between both lcov
+#    instances. (Default: $CODE_COVERAGE_LCOV_SHOPTS_DEFAULT)
+#  - CODE_COVERAGE_LCOV_OPTIONS_GCOVPATH: --gcov-tool pathtogcov
+#  - CODE_COVERAGE_LCOV_OPTIONS_DEFAULT: Extra options to pass to the
+#    collecting lcov instance. (Default: $CODE_COVERAGE_LCOV_OPTIONS_GCOVPATH)
+#  - CODE_COVERAGE_LCOV_OPTIONS: Extra options to pass to the collecting lcov
+#    instance. (Default: $CODE_COVERAGE_LCOV_OPTIONS_DEFAULT)
+#  - CODE_COVERAGE_LCOV_RMOPTS_DEFAULT: Extra options to pass to the filtering
+#    lcov instance. (Default: empty)
+#  - CODE_COVERAGE_LCOV_RMOPTS: Extra options to pass to the filtering lcov
+#    instance. (Default: $CODE_COVERAGE_LCOV_RMOPTS_DEFAULT)
+#  - CODE_COVERAGE_GENHTML_OPTIONS_DEFAULT: Extra options to pass to the
+#    genhtml instance. (Default: based on $CODE_COVERAGE_BRANCH_COVERAGE)
+#  - CODE_COVERAGE_GENHTML_OPTIONS: Extra options to pass to the genhtml
+#    instance. (Default: $CODE_COVERAGE_GENHTML_OPTIONS_DEFAULT)
+#  - CODE_COVERAGE_IGNORE_PATTERN: Extra glob pattern of files to ignore
+#
+# The generated report will be titled using the $(PACKAGE_NAME) and
+# $(PACKAGE_VERSION). In order to add the current git hash to the title,
+# use the git-version-gen script, available online.
 
+# Optional variables
+CODE_COVERAGE_DIRECTORY ?= $(top_builddir)
+CODE_COVERAGE_OUTPUT_FILE ?= $(PACKAGE_NAME)-$(PACKAGE_VERSION)-coverage.info
+CODE_COVERAGE_OUTPUT_DIRECTORY ?= $(PACKAGE_NAME)-$(PACKAGE_VERSION)-coverage
+CODE_COVERAGE_BRANCH_COVERAGE ?=
+CODE_COVERAGE_LCOV_SHOPTS_DEFAULT ?= $(if $(CODE_COVERAGE_BRANCH_COVERAGE),\
+--rc lcov_branch_coverage=$(CODE_COVERAGE_BRANCH_COVERAGE))
+CODE_COVERAGE_LCOV_SHOPTS ?= $(CODE_COVERAGE_LCOV_SHOPTS_DEFAULT)
+CODE_COVERAGE_LCOV_OPTIONS_GCOVPATH ?= --gcov-tool "$(GCOV)"
+CODE_COVERAGE_LCOV_OPTIONS_DEFAULT ?= $(CODE_COVERAGE_LCOV_OPTIONS_GCOVPATH)
+CODE_COVERAGE_LCOV_OPTIONS ?= $(CODE_COVERAGE_LCOV_OPTIONS_DEFAULT)
+CODE_COVERAGE_LCOV_RMOPTS_DEFAULT ?=
+CODE_COVERAGE_LCOV_RMOPTS ?= $(CODE_COVERAGE_LCOV_RMOPTS_DEFAULT)
+CODE_COVERAGE_GENHTML_OPTIONS_DEFAULT ?=\
+$(if $(CODE_COVERAGE_BRANCH_COVERAGE),\
+--rc genhtml_branch_coverage=$(CODE_COVERAGE_BRANCH_COVERAGE))
+CODE_COVERAGE_GENHTML_OPTIONS ?= $(CODE_COVERAGE_GENHTML_OPTIONS_DEFAULT)
+CODE_COVERAGE_IGNORE_PATTERN ?=
 
-fi
+code_coverage_v_lcov_cap = $(code_coverage_v_lcov_cap_$(V))
+code_coverage_v_lcov_cap_ = $(code_coverage_v_lcov_cap_$(AM_DEFAULT_VERBOSITY))
+code_coverage_v_lcov_cap_0 = @echo "  LCOV   --capture"\
+ $(CODE_COVERAGE_OUTPUT_FILE);
+code_coverage_v_lcov_ign = $(code_coverage_v_lcov_ign_$(V))
+code_coverage_v_lcov_ign_ = $(code_coverage_v_lcov_ign_$(AM_DEFAULT_VERBOSITY))
+code_coverage_v_lcov_ign_0 = @echo "  LCOV   --remove /tmp/*"\
+ $(CODE_COVERAGE_IGNORE_PATTERN);
+code_coverage_v_genhtml = $(code_coverage_v_genhtml_$(V))
+code_coverage_v_genhtml_ = $(code_coverage_v_genhtml_$(AM_DEFAULT_VERBOSITY))
+code_coverage_v_genhtml_0 = @echo "  GEN   " $(CODE_COVERAGE_OUTPUT_DIRECTORY);
+code_coverage_quiet = $(code_coverage_quiet_$(V))
+code_coverage_quiet_ = $(code_coverage_quiet_$(AM_DEFAULT_VERBOSITY))
+code_coverage_quiet_0 = --quiet
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Wold-style-declaration" >&5
-$as_echo_n "checking whether $CC handles -Wold-style-declaration... " >&6; }
-if ${gl_cv_warn_CFLAGS__Wold_style_declaration+:} false; then :
+# sanitizes the test-name: replaces with underscores: dashes and dots
+code_coverage_sanitize = $(subst -,_,$(subst .,_,$(1)))
+
+# Use recursive makes in order to ignore errors during check
+check-code-coverage:'"$CODE_COVERAGE_RULES_CHECK"'
+
+# Capture code coverage data
+code-coverage-capture: code-coverage-capture-hook'"$CODE_COVERAGE_RULES_CAPTURE"'
+
+# Hook rule executed before code-coverage-capture, overridable by the user
+code-coverage-capture-hook:
+
+'"$CODE_COVERAGE_RULES_CLEAN"'
+
+GITIGNOREFILES ?=
+GITIGNOREFILES += $(CODE_COVERAGE_OUTPUT_FILE) $(CODE_COVERAGE_OUTPUT_DIRECTORY)
+
+A''M_DISTCHECK_CONFIGURE_FLAGS ?=
+A''M_DISTCHECK_CONFIGURE_FLAGS += --disable-code-coverage
+
+.PHONY: check-code-coverage code-coverage-capture code-coverage-capture-hook code-coverage-clean
+'
+
+
+
+
+
+
+$as_echo "#define COPYRIGHT_YEAR \"2020\"" >>confdefs.h
+
+COPYRIGHT_YEAR=2020
+
+
+
+$as_echo "#define MANPAGE_DATE \"2020-09-23\"" >>confdefs.h
+
+MANPAGE_DATE=2020-09-23
+
+
+ { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether byte ordering is bigendian" >&5
+$as_echo_n "checking whether byte ordering is bigendian... " >&6; }
+if ${ac_cv_c_bigendian+:} false; then :
   $as_echo_n "(cached) " >&6
 else
+  ac_cv_c_bigendian=unknown
+    # See if we're dealing with a universal compiler.
+    cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+#ifndef __APPLE_CC__
+	       not a universal capable compiler
+	     #endif
+	     typedef int dummy;
 
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Wold-style-declaration"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+_ACEOF
+if ac_fn_c_try_compile "$LINENO"; then :
+
+	# Check for potential -arch flags.  It is not universal unless
+	# there are at least two -arch flags with different values.
+	ac_arch=
+	ac_prev=
+	for ac_word in $CC $CFLAGS $CPPFLAGS $LDFLAGS; do
+	 if test -n "$ac_prev"; then
+	   case $ac_word in
+	     i?86 | x86_64 | ppc | ppc64)
+	       if test -z "$ac_arch" || test "$ac_arch" = "$ac_word"; then
+		 ac_arch=$ac_word
+	       else
+		 ac_cv_c_bigendian=universal
+		 break
+	       fi
+	       ;;
+	   esac
+	   ac_prev=
+	 elif test "x$ac_word" = "x-arch"; then
+	   ac_prev=arch
+	 fi
+       done
+fi
+rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+    if test $ac_cv_c_bigendian = unknown; then
+      # See if sys/param.h defines the BYTE_ORDER macro.
+      cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
+#include <sys/types.h>
+	     #include <sys/param.h>
 
 int
 main ()
 {
+#if ! (defined BYTE_ORDER && defined BIG_ENDIAN \
+		     && defined LITTLE_ENDIAN && BYTE_ORDER && BIG_ENDIAN \
+		     && LITTLE_ENDIAN)
+	      bogus endian macros
+	     #endif
 
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Wold_style_declaration=yes
-else
-  gl_cv_warn_CFLAGS__Wold_style_declaration=no
-fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
-
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Wold_style_declaration" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Wold_style_declaration" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Wold_style_declaration" = xyes; then :
-  as_fn_append WARN_CFLAGS " -Wold-style-declaration"
-fi
-
-
-if test x${gl_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+if ac_fn_c_try_compile "$LINENO"; then :
+  # It does; now see whether it defined to BIG_ENDIAN or not.
+	 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
+#include <sys/types.h>
+		#include <sys/param.h>
 
 int
 main ()
 {
+#if BYTE_ORDER != BIG_ENDIAN
+		 not big endian
+		#endif
 
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
-fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
-
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
-  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+if ac_fn_c_try_compile "$LINENO"; then :
+  ac_cv_c_bigendian=yes
 else
-  gl_unknown_warnings_are_errors=
+  ac_cv_c_bigendian=no
 fi
-
-
+rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
 fi
+rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+    fi
+    if test $ac_cv_c_bigendian = unknown; then
+      # See if <limits.h> defines _LITTLE_ENDIAN or _BIG_ENDIAN (e.g., Solaris).
+      cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+#include <limits.h>
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Wold-style-definition" >&5
-$as_echo_n "checking whether $CC handles -Wold-style-definition... " >&6; }
-if ${gl_cv_warn_CFLAGS__Wold_style_definition+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+int
+main ()
+{
+#if ! (defined _LITTLE_ENDIAN || defined _BIG_ENDIAN)
+	      bogus endian macros
+	     #endif
 
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Wold-style-definition"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_compile "$LINENO"; then :
+  # It does; now see whether it defined to _BIG_ENDIAN or not.
+	 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
+#include <limits.h>
 
 int
 main ()
 {
+#ifndef _BIG_ENDIAN
+		 not big endian
+		#endif
 
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Wold_style_definition=yes
+if ac_fn_c_try_compile "$LINENO"; then :
+  ac_cv_c_bigendian=yes
 else
-  gl_cv_warn_CFLAGS__Wold_style_definition=no
+  ac_cv_c_bigendian=no
 fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
-
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Wold_style_definition" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Wold_style_definition" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Wold_style_definition" = xyes; then :
-  as_fn_append WARN_CFLAGS " -Wold-style-definition"
+rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
 fi
-
-
-if test x${gl_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+    fi
+    if test $ac_cv_c_bigendian = unknown; then
+      # Compile a test program.
+      if test "$cross_compiling" = yes; then :
+  # Try to guess by grepping values from an object file.
+	 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
+unsigned short int ascii_mm[] =
+		  { 0x4249, 0x4765, 0x6E44, 0x6961, 0x6E53, 0x7953, 0 };
+		unsigned short int ascii_ii[] =
+		  { 0x694C, 0x5454, 0x656C, 0x6E45, 0x6944, 0x6E61, 0 };
+		int use_ascii (int i) {
+		  return ascii_mm[i] + ascii_ii[i];
+		}
+		unsigned short int ebcdic_ii[] =
+		  { 0x89D3, 0xE3E3, 0x8593, 0x95C5, 0x89C4, 0x9581, 0 };
+		unsigned short int ebcdic_mm[] =
+		  { 0xC2C9, 0xC785, 0x95C4, 0x8981, 0x95E2, 0xA8E2, 0 };
+		int use_ebcdic (int i) {
+		  return ebcdic_mm[i] + ebcdic_ii[i];
+		}
+		extern int foo;
 
 int
 main ()
 {
-
+return use_ascii (foo) == use_ebcdic (foo);
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
-fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
-
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
-  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
-else
-  gl_unknown_warnings_are_errors=
-fi
-
-
+if ac_fn_c_try_compile "$LINENO"; then :
+  if grep BIGenDianSyS conftest.$ac_objext >/dev/null; then
+	      ac_cv_c_bigendian=yes
+	    fi
+	    if grep LiTTleEnDian conftest.$ac_objext >/dev/null ; then
+	      if test "$ac_cv_c_bigendian" = unknown; then
+		ac_cv_c_bigendian=no
+	      else
+		# finding both strings is unlikely to happen, but who knows?
+		ac_cv_c_bigendian=unknown
+	      fi
+	    fi
 fi
-
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Woverride-init" >&5
-$as_echo_n "checking whether $CC handles -Woverride-init... " >&6; }
-if ${gl_cv_warn_CFLAGS__Woverride_init+:} false; then :
-  $as_echo_n "(cached) " >&6
+rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
 else
-
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Woverride-init"
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
-
+$ac_includes_default
 int
 main ()
 {
 
+	     /* Are we little or big endian?  From Harbison&Steele.  */
+	     union
+	     {
+	       long int l;
+	       char c[sizeof (long int)];
+	     } u;
+	     u.l = 1;
+	     return u.c[sizeof (long int) - 1] == 1;
+
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Woverride_init=yes
+if ac_fn_c_try_run "$LINENO"; then :
+  ac_cv_c_bigendian=no
 else
-  gl_cv_warn_CFLAGS__Woverride_init=no
+  ac_cv_c_bigendian=yes
 fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
-
+rm -f core *.core core.conftest.* gmon.out bb.out conftest$ac_exeext \
+  conftest.$ac_objext conftest.beam conftest.$ac_ext
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Woverride_init" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Woverride_init" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Woverride_init" = xyes; then :
-  as_fn_append WARN_CFLAGS " -Woverride-init"
+
+    fi
 fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_c_bigendian" >&5
+$as_echo "$ac_cv_c_bigendian" >&6; }
+ case $ac_cv_c_bigendian in #(
+   yes)
+     $as_echo "#define WORDS_BIGENDIAN 1" >>confdefs.h
+;; #(
+   no)
+      ;; #(
+   universal)
 
+$as_echo "#define AC_APPLE_UNIVERSAL_BUILD 1" >>confdefs.h
 
-if test x${gl_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+     ;; #(
+   *)
+     as_fn_error $? "unknown endianness
+ presetting ac_cv_c_bigendian=no (or yes) will help" "$LINENO" 5 ;;
+ esac
 
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
 
-int
-main ()
-{
+arch_enable_Werror=yes
 
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
-fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for supported architecture" >&5
+$as_echo_n "checking for supported architecture... " >&6; }
+arch_m32=
+arch_mx32=
+cc_flags_m32=-m32
+cc_flags_mx32=-mx32
+case "$host_cpu" in
+aarch64*)
+	arch=aarch64
+	arch_m32=arm
+	cc_flags_m32=
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
-  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
-else
-  gl_unknown_warnings_are_errors=
-fi
+$as_echo "#define AARCH64 1" >>confdefs.h
 
+	;;
+alpha*)
+	arch=alpha
+	arch_enable_Werror=no
 
-fi
+$as_echo "#define ALPHA 1" >>confdefs.h
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Wsign-compare" >&5
-$as_echo_n "checking whether $CC handles -Wsign-compare... " >&6; }
-if ${gl_cv_warn_CFLAGS__Wsign_compare+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+	;;
+arc*)
+	arch=arc
 
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Wsign-compare"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+$as_echo "#define ARC 1" >>confdefs.h
 
-int
-main ()
-{
+	;;
+arm*)
+	arch=arm
 
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Wsign_compare=yes
-else
-  gl_cv_warn_CFLAGS__Wsign_compare=no
-fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
+$as_echo "#define ARM 1" >>confdefs.h
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Wsign_compare" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Wsign_compare" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Wsign_compare" = xyes; then :
-  as_fn_append WARN_CFLAGS " -Wsign-compare"
-fi
+	;;
+avr32*)
+	arch=avr32
 
+$as_echo "#define AVR32 1" >>confdefs.h
 
-if test x${gl_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+	;;
+bfin)
+	arch=bfin
+	arch_enable_Werror=no
 
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+$as_echo "#define BFIN 1" >>confdefs.h
 
-int
-main ()
-{
+	;;
+csky*)
+	arch=csky
 
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
-fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
+$as_echo "#define CSKY 1" >>confdefs.h
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
-  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
-else
-  gl_unknown_warnings_are_errors=
-fi
+	;;
+hppa*|parisc*)
+	arch=hppa
 
+$as_echo "#define HPPA 1" >>confdefs.h
 
-fi
+	;;
+i[3456]86|pentium)
+	arch=i386
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Wtype-limits" >&5
-$as_echo_n "checking whether $CC handles -Wtype-limits... " >&6; }
-if ${gl_cv_warn_CFLAGS__Wtype_limits+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+$as_echo "#define I386 1" >>confdefs.h
 
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Wtype-limits"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+	;;
+ia64)
+	arch=ia64
 
-int
-main ()
-{
+$as_echo "#define IA64 1" >>confdefs.h
 
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Wtype_limits=yes
-else
-  gl_cv_warn_CFLAGS__Wtype_limits=no
-fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
+	;;
+m68k)
+	arch=m68k
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Wtype_limits" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Wtype_limits" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Wtype_limits" = xyes; then :
-  as_fn_append WARN_CFLAGS " -Wtype-limits"
-fi
+$as_echo "#define M68K 1" >>confdefs.h
 
+	;;
+metag*)
+	arch=metag
 
-if test x${gl_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+$as_echo "#define METAG 1" >>confdefs.h
 
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+	;;
+microblaze*)
+	arch=microblaze
+	arch_enable_Werror=no
 
-int
-main ()
-{
+$as_echo "#define MICROBLAZE 1" >>confdefs.h
 
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
-fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
+	;;
+mips*)
+	arch=mips
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
-  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
-else
-  gl_unknown_warnings_are_errors=
-fi
+$as_echo "#define MIPS 1" >>confdefs.h
 
+	;;
+nios2*)
+	arch=nios2
 
-fi
+$as_echo "#define NIOS2 1" >>confdefs.h
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Wwrite-strings" >&5
-$as_echo_n "checking whether $CC handles -Wwrite-strings... " >&6; }
-if ${gl_cv_warn_CFLAGS__Wwrite_strings+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+	;;
+or1k*)
+	arch=or1k
 
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Wwrite-strings"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+$as_echo "#define OR1K 1" >>confdefs.h
+
+	;;
+powerpc*)
+
+$as_echo "#define POWERPC 1" >>confdefs.h
 
+	cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+#ifndef __LP64__
+# error 32 bit
+#endif
 int
 main ()
 {
@@ -6063,78 +6068,88 @@ main ()
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Wwrite_strings=yes
+if ac_fn_c_try_compile "$LINENO"; then :
+  arch=powerpc64
 else
-  gl_cv_warn_CFLAGS__Wwrite_strings=no
+  arch=powerpc
 fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
+rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+	if test "$arch" = "powerpc64"; then
+		# $ac_cv_c_bigendian is defined by AC_C_BIGENDIAN
+		case "$ac_cv_c_bigendian" in
+		no)
+			arch=powerpc64le
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Wwrite_strings" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Wwrite_strings" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Wwrite_strings" = xyes; then :
-  as_fn_append WARN_CFLAGS " -Wwrite-strings"
-fi
+$as_echo "#define POWERPC64LE 1" >>confdefs.h
 
+			;;
+		*)
+			arch_m32=powerpc
 
-# Check whether --enable-gcc-Werror was given.
-if test "${enable_gcc_Werror+set}" = set; then :
-  enableval=$enable_gcc_Werror; case $enableval in
-     yes) if test x${gl_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+$as_echo "#define POWERPC64 1" >>confdefs.h
 
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+			;;
+		esac
+	fi
+	;;
+riscv64*)
+	arch=riscv64
 
-int
-main ()
-{
+$as_echo "#define RISCV64 1" >>confdefs.h
 
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
-fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
+	;;
+s390)
+	arch=s390
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
-  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
-else
-  gl_unknown_warnings_are_errors=
-fi
+$as_echo "#define S390 1" >>confdefs.h
 
+	;;
+s390x)
+	arch=s390x
+	arch_m32=s390
+	cc_flags_m32=-m31
 
-fi
+$as_echo "#define S390X 1" >>confdefs.h
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror" >&5
-$as_echo_n "checking whether $CC handles -Werror... " >&6; }
-if ${gl_cv_warn_CFLAGS__Werror+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+	;;
+sh64*)
+	arch=sh64
 
-  gl_save_compiler_FLAGS="$CFLAGS"
-  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+$as_echo "#define SH64 1" >>confdefs.h
+
+	;;
+sh*)
+	arch=sh
+
+$as_echo "#define SH 1" >>confdefs.h
+
+	;;
+sparc64*)
+	arch=sparc64
+	arch_m32=sparc
+
+$as_echo "#define SPARC64 1" >>confdefs.h
+
+	;;
+sparc*)
+	arch=sparc
+
+$as_echo "#define SPARC 1" >>confdefs.h
+
+	;;
+tile*)
+	arch=tile
 
+$as_echo "#define TILE 1" >>confdefs.h
+
+	;;
+x86?64*)
+	arch_m32=i386
+	cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+#ifndef __ILP32__
+# error not x32
+#endif
 int
 main ()
 {
@@ -6143,457 +6158,303 @@ main ()
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS__Werror=yes
+if ac_fn_c_try_compile "$LINENO"; then :
+  arch=x32
 else
-  gl_cv_warn_CFLAGS__Werror=no
+  arch=x86_64
 fi
-rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-  CFLAGS="$gl_save_compiler_FLAGS"
-
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror" >&5
-$as_echo "$gl_cv_warn_CFLAGS__Werror" >&6; }
-if test "x$gl_cv_warn_CFLAGS__Werror" = xyes; then :
-  as_fn_append WARN_CFLAGS " -Werror"
-fi
-
- ;;
-     no)  ;;
-     *)   as_fn_error $? "bad value $enableval for gcc-Werror option" "$LINENO" 5 ;;
-   esac
+rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+	if test "$arch" = "x86_64"; then
+		arch_mx32=x32
 
-fi
+$as_echo "#define X86_64 1" >>confdefs.h
 
+	else
 
+$as_echo "#define X32 1" >>confdefs.h
 
+	fi
+	;;
+xtensa*)
+	arch=xtensa
 
+$as_echo "#define XTENSA 1" >>confdefs.h
 
+	;;
+*)
+	{ $as_echo "$as_me:${as_lineno-$LINENO}: result: NO!" >&5
+$as_echo "NO!" >&6; }
+	as_fn_error $? "architecture $host_cpu is not supported by strace" "$LINENO" 5
+	;;
+esac
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $arch" >&5
+$as_echo "$arch" >&6; }
 
-if test -n "${ac_c_decl_warn_flag+set}"; then :
-  st_saved_ac_c_decl_warn_flag="${ac_c_decl_warn_flag}"; unset ac_c_decl_warn_flag
-fi
+arch_native=$arch
 
-if test -n "${ac_c_preproc_warn_flag+set}"; then :
-  st_saved_ac_c_preproc_warn_flag="${ac_c_preproc_warn_flag}"; unset ac_c_preproc_warn_flag
-fi
+test -n "$arch_m32" ||
+	arch_m32=$arch
+test -n "$arch_mx32" ||
+	arch_mx32=$arch
 
-if test -n "${ac_c_werror_flag+set}"; then :
-  st_saved_ac_c_werror_flag="${ac_c_werror_flag}"; unset ac_c_werror_flag
-fi
 
-if test -n "${ac_compile+set}"; then :
-  st_saved_ac_compile="${ac_compile}"; unset ac_compile
-fi
 
-if test -n "${ac_compiler_gnu+set}"; then :
-  st_saved_ac_compiler_gnu="${ac_compiler_gnu}"; unset ac_compiler_gnu
-fi
 
-if test -n "${ac_cpp+set}"; then :
-  st_saved_ac_cpp="${ac_cpp}"; unset ac_cpp
-fi
 
-if test -n "${ac_cv_c_compiler_gnu+set}"; then :
-  st_saved_ac_cv_c_compiler_gnu="${ac_cv_c_compiler_gnu}"; unset ac_cv_c_compiler_gnu
-fi
 
-if test -n "${ac_cv_c_decl_report+set}"; then :
-  st_saved_ac_cv_c_decl_report="${ac_cv_c_decl_report}"; unset ac_cv_c_decl_report
-fi
 
-if test -n "${ac_link+set}"; then :
-  st_saved_ac_link="${ac_link}"; unset ac_link
-fi
+MIPS_ABI=
+if test "$arch" = mips; then
+	{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for _MIPS_SIM" >&5
+$as_echo_n "checking for _MIPS_SIM... " >&6; }
+if ${st_cv__MIPS_SIM+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  if ac_fn_c_compute_int "$LINENO" "_MIPS_SIM" "st_cv__MIPS_SIM"        ""; then :
 
-if test -n "${ac_tool_prefix+set}"; then :
-  st_saved_ac_tool_prefix="${ac_tool_prefix}"; unset ac_tool_prefix
+else
+  { { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
+$as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
+as_fn_error $? "_MIPS_SIM cannot be determined
+See \`config.log' for more details" "$LINENO" 5; }
 fi
 
-if test -n "${cross_compiling+set}"; then :
-  st_saved_cross_compiling="${cross_compiling}"; unset cross_compiling
 fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $st_cv__MIPS_SIM" >&5
+$as_echo "$st_cv__MIPS_SIM" >&6; }
 
-cross_compiling=no
-
-{ $as_echo "$as_me:${as_lineno-$LINENO}: looking for a C compiler that generates native executables" >&5
-$as_echo "$as_me: looking for a C compiler that generates native executables" >&6;}
-ac_ext=c
-ac_cpp='$CPP_FOR_BUILD $CPPFLAGS_FOR_BUILD'
-ac_compile='$CC_FOR_BUILD -c $CFLAGS_FOR_BUILD $CPPFLAGS_FOR_BUILD conftest.$ac_ext >&5'
-ac_link='$CC_FOR_BUILD -o conftest$ac_build_exeext $CFLAGS_FOR_BUILD $CPPFLAGS_FOR_BUILD $LDFLAGS_FOR_BUILD conftest.$ac_ext $LIBS >&5'
-ac_compiler_gnu=$ac_cv_c_compiler_gnu
-if test -n "$ac_tool_prefix"; then
-  # Extract the first word of "${ac_tool_prefix}gcc", so it can be a program name with args.
-set dummy ${ac_tool_prefix}gcc; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_prog_CC_FOR_BUILD+:} false; then :
+	# requires GCC >= 3.4
+	{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for MIPS ABI" >&5
+$as_echo_n "checking for MIPS ABI... " >&6; }
+if ${st_cv_mips_abi+:} false; then :
   $as_echo_n "(cached) " >&6
 else
-  if test -n "$CC_FOR_BUILD"; then
-  ac_cv_prog_CC_FOR_BUILD="$CC_FOR_BUILD" # Let the user override the test.
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+int i[_MIPS_SIM == _ABIO32 ? 1 : - 1];
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_compile "$LINENO"; then :
+  st_cv_mips_abi=o32
 else
-as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
-for as_dir in $PATH
-do
-  IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
-    for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_prog_CC_FOR_BUILD="${ac_tool_prefix}gcc"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
-    break 2
-  fi
-done
-  done
-IFS=$as_save_IFS
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+int i[_MIPS_SIM == _ABIN32 ? 1 : - 1];
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_compile "$LINENO"; then :
+  st_cv_mips_abi=n32
+else
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
 
+int
+main ()
+{
+int i[_MIPS_SIM == _ABI64 ? 1 : - 1];
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_compile "$LINENO"; then :
+  st_cv_mips_abi=n64
+else
+  st_cv_mips_abi=unknown
 fi
+rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
 fi
-CC_FOR_BUILD=$ac_cv_prog_CC_FOR_BUILD
-if test -n "$CC_FOR_BUILD"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $CC_FOR_BUILD" >&5
-$as_echo "$CC_FOR_BUILD" >&6; }
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
 fi
-
-
+rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
 fi
-if test -z "$ac_cv_prog_CC_FOR_BUILD"; then
-  ac_ct_CC_FOR_BUILD=$CC_FOR_BUILD
-  # Extract the first word of "gcc", so it can be a program name with args.
-set dummy gcc; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_prog_ac_ct_CC_FOR_BUILD+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-  if test -n "$ac_ct_CC_FOR_BUILD"; then
-  ac_cv_prog_ac_ct_CC_FOR_BUILD="$ac_ct_CC_FOR_BUILD" # Let the user override the test.
-else
-as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
-for as_dir in $PATH
-do
-  IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
-    for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_prog_ac_ct_CC_FOR_BUILD="gcc"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
-    break 2
-  fi
-done
-  done
-IFS=$as_save_IFS
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $st_cv_mips_abi" >&5
+$as_echo "$st_cv_mips_abi" >&6; }
 
+	case "$st_cv_mips_abi" in
+		o32)
+$as_echo "#define LINUX_MIPSO32 1" >>confdefs.h
+;;
+		n32)
+$as_echo "#define LINUX_MIPSN32 1" >>confdefs.h
+;;
+		n64)
+$as_echo "#define LINUX_MIPSN64 1" >>confdefs.h
+;;
+		*) as_fn_error $? "Unsupported _MIPS_SIM" "$LINENO" 5;;
+	esac
+	MIPS_ABI="$st_cv_mips_abi"
 fi
-fi
-ac_ct_CC_FOR_BUILD=$ac_cv_prog_ac_ct_CC_FOR_BUILD
-if test -n "$ac_ct_CC_FOR_BUILD"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_ct_CC_FOR_BUILD" >&5
-$as_echo "$ac_ct_CC_FOR_BUILD" >&6; }
+
+
+# Check whether --enable-arm-oabi was given.
+if test "${enable_arm_oabi+set}" = set; then :
+  enableval=$enable_arm_oabi;
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  enable_arm_oabi=no
 fi
 
-  if test "x$ac_ct_CC_FOR_BUILD" = x; then
-    CC_FOR_BUILD=""
-  else
-    case $cross_compiling:$ac_tool_warned in
-yes:)
-{ $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: using cross tools not prefixed with build triplet" >&5
-$as_echo "$as_me: WARNING: using cross tools not prefixed with build triplet" >&2;}
-ac_tool_warned=yes ;;
+case "$enable_arm_oabi" in
+	yes) enable_arm_oabi=1 ;;
+	no) enable_arm_oabi=0 ;;
+	*) as_fn_error $? "bad value $enable_arm_oabi for arm-oabi option" "$LINENO" 5 ;;
 esac
-    CC_FOR_BUILD=$ac_ct_CC_FOR_BUILD
-  fi
-else
-  CC_FOR_BUILD="$ac_cv_prog_CC_FOR_BUILD"
-fi
 
-if test -z "$CC_FOR_BUILD"; then
-          if test -n "$ac_tool_prefix"; then
-    # Extract the first word of "${ac_tool_prefix}cc", so it can be a program name with args.
-set dummy ${ac_tool_prefix}cc; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_prog_CC_FOR_BUILD+:} false; then :
+cat >>confdefs.h <<_ACEOF
+#define ENABLE_ARM_OABI $enable_arm_oabi
+_ACEOF
+
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC is fresh enough for -Werror" >&5
+$as_echo_n "checking whether $CC is fresh enough for -Werror... " >&6; }
+if ${st_cv_cc_enable_Werror+:} false; then :
   $as_echo_n "(cached) " >&6
 else
-  if test -n "$CC_FOR_BUILD"; then
-  ac_cv_prog_CC_FOR_BUILD="$CC_FOR_BUILD" # Let the user override the test.
-else
-as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
-for as_dir in $PATH
-do
-  IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
-    for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_prog_CC_FOR_BUILD="${ac_tool_prefix}cc"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
-    break 2
-  fi
-done
-  done
-IFS=$as_save_IFS
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
 
-fi
-fi
-CC_FOR_BUILD=$ac_cv_prog_CC_FOR_BUILD
-if test -n "$CC_FOR_BUILD"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $CC_FOR_BUILD" >&5
-$as_echo "$CC_FOR_BUILD" >&6; }
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
-fi
+#if defined __GNUC__ && defined __GNUC_MINOR__
+# define GNUC_PREREQ(maj, min) ((__GNUC__ << 16) + __GNUC_MINOR__ >= ((maj) << 16) + (min))
+#else
+# define GNUC_PREREQ(maj, min) 0
+#endif
 
+#if defined __clang__ && defined __clang_major__ && defined __clang_minor__
+# define CLANG_PREREQ(maj, min) ((__clang_major__ << 16) + __clang_minor__ >= ((maj) << 16) + (min))
+#else
+# define CLANG_PREREQ(maj, min) 0
+#endif
 
-  fi
-fi
-if test -z "$CC_FOR_BUILD"; then
-  # Extract the first word of "cc", so it can be a program name with args.
-set dummy cc; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_prog_CC_FOR_BUILD+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-  if test -n "$CC_FOR_BUILD"; then
-  ac_cv_prog_CC_FOR_BUILD="$CC_FOR_BUILD" # Let the user override the test.
+int
+main ()
+{
+int i[GNUC_PREREQ(4, 8) + CLANG_PREREQ(6, 0) > 0 ? 1 : - 1];
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_compile "$LINENO"; then :
+  st_cv_cc_enable_Werror=yes
 else
-  ac_prog_rejected=no
-as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
-for as_dir in $PATH
-do
-  IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
-    for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    if test "$as_dir/$ac_word$ac_exec_ext" = "/usr/ucb/cc"; then
-       ac_prog_rejected=yes
-       continue
-     fi
-    ac_cv_prog_CC_FOR_BUILD="cc"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
-    break 2
-  fi
-done
-  done
-IFS=$as_save_IFS
-
-if test $ac_prog_rejected = yes; then
-  # We found a bogon in the path, so make sure we never use it.
-  set dummy $ac_cv_prog_CC_FOR_BUILD
-  shift
-  if test $# != 0; then
-    # We chose a different compiler from the bogus one.
-    # However, it has the same basename, so the bogon will be chosen
-    # first if we set CC_FOR_BUILD to just the basename; use the full file name.
-    shift
-    ac_cv_prog_CC_FOR_BUILD="$as_dir/$ac_word${1+' '}$@"
-  fi
-fi
+  st_cv_cc_enable_Werror=no
 fi
+rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
 fi
-CC_FOR_BUILD=$ac_cv_prog_CC_FOR_BUILD
-if test -n "$CC_FOR_BUILD"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $CC_FOR_BUILD" >&5
-$as_echo "$CC_FOR_BUILD" >&6; }
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $st_cv_cc_enable_Werror" >&5
+$as_echo "$st_cv_cc_enable_Werror" >&6; }
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether to try $CC with -Werror by default" >&5
+$as_echo_n "checking whether to try $CC with -Werror by default... " >&6; }
+if ${st_cv_enable_Werror+:} false; then :
+  $as_echo_n "(cached) " >&6
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
-fi
-
-
+  if test "$st_cv_cc_enable_Werror" != yes; then
+		  st_cv_enable_Werror='no, the compiler is too old'
+		elif test "$arch_enable_Werror" != yes; then
+		  st_cv_enable_Werror='no, architecture is not ready'
+		else
+		  st_cv_enable_Werror=yes
+		fi
 fi
-if test -z "$CC_FOR_BUILD"; then
-  if test -n "$ac_tool_prefix"; then
-  for ac_prog in cl.exe
-  do
-    # Extract the first word of "$ac_tool_prefix$ac_prog", so it can be a program name with args.
-set dummy $ac_tool_prefix$ac_prog; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_prog_CC_FOR_BUILD+:} false; then :
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $st_cv_enable_Werror" >&5
+$as_echo "$st_cv_enable_Werror" >&6; }
+if test x${gl_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
   $as_echo_n "(cached) " >&6
 else
-  if test -n "$CC_FOR_BUILD"; then
-  ac_cv_prog_CC_FOR_BUILD="$CC_FOR_BUILD" # Let the user override the test.
-else
-as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
-for as_dir in $PATH
-do
-  IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
-    for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_prog_CC_FOR_BUILD="$ac_tool_prefix$ac_prog"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
-    break 2
-  fi
-done
-  done
-IFS=$as_save_IFS
 
-fi
-fi
-CC_FOR_BUILD=$ac_cv_prog_CC_FOR_BUILD
-if test -n "$CC_FOR_BUILD"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $CC_FOR_BUILD" >&5
-$as_echo "$CC_FOR_BUILD" >&6; }
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
-fi
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
 
+int
+main ()
+{
 
-    test -n "$CC_FOR_BUILD" && break
-  done
-fi
-if test -z "$CC_FOR_BUILD"; then
-  ac_ct_CC_FOR_BUILD=$CC_FOR_BUILD
-  for ac_prog in cl.exe
-do
-  # Extract the first word of "$ac_prog", so it can be a program name with args.
-set dummy $ac_prog; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_prog_ac_ct_CC_FOR_BUILD+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-  if test -n "$ac_ct_CC_FOR_BUILD"; then
-  ac_cv_prog_ac_ct_CC_FOR_BUILD="$ac_ct_CC_FOR_BUILD" # Let the user override the test.
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
 else
-as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
-for as_dir in $PATH
-do
-  IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
-    for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_prog_ac_ct_CC_FOR_BUILD="$ac_prog"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
-    break 2
-  fi
-done
-  done
-IFS=$as_save_IFS
-
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
 fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
 fi
-ac_ct_CC_FOR_BUILD=$ac_cv_prog_ac_ct_CC_FOR_BUILD
-if test -n "$ac_ct_CC_FOR_BUILD"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_ct_CC_FOR_BUILD" >&5
-$as_echo "$ac_ct_CC_FOR_BUILD" >&6; }
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
+  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
 else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+  gl_unknown_warnings_are_errors=
 fi
 
 
-  test -n "$ac_ct_CC_FOR_BUILD" && break
-done
-
-  if test "x$ac_ct_CC_FOR_BUILD" = x; then
-    CC_FOR_BUILD=""
-  else
-    case $cross_compiling:$ac_tool_warned in
-yes:)
-{ $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: using cross tools not prefixed with build triplet" >&5
-$as_echo "$as_me: WARNING: using cross tools not prefixed with build triplet" >&2;}
-ac_tool_warned=yes ;;
-esac
-    CC_FOR_BUILD=$ac_ct_CC_FOR_BUILD
-  fi
-fi
-
 fi
 
-
-test -z "$CC_FOR_BUILD" && { { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
-$as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
-as_fn_error $? "no acceptable C compiler found in \$PATH
-See \`config.log' for more details" "$LINENO" 5; }
-
-# Provide some information about the compiler.
-$as_echo "$as_me:${as_lineno-$LINENO}: checking for C compiler version" >&5
-set X $ac_compile
-ac_compiler=$2
-for ac_option in --version -v -V -qversion; do
-  { { ac_try="$ac_compiler $ac_option >&5"
-case "(($ac_try" in
-  *\"* | *\`* | *\\*) ac_try_echo=\$ac_try;;
-  *) ac_try_echo=$ac_try;;
-esac
-eval ac_try_echo="\"\$as_me:${as_lineno-$LINENO}: $ac_try_echo\""
-$as_echo "$ac_try_echo"; } >&5
-  (eval "$ac_compiler $ac_option >&5") 2>conftest.err
-  ac_status=$?
-  if test -s conftest.err; then
-    sed '10a\
-... rest of stderr output deleted ...
-         10q' conftest.err >conftest.er1
-    cat conftest.er1 >&5
-  fi
-  rm -f conftest.er1 conftest.err
-  $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
-  test $ac_status = 0; }
-done
-
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether we are using the GNU C compiler" >&5
-$as_echo_n "checking whether we are using the GNU C compiler... " >&6; }
-if ${ac_cv_c_compiler_gnu+:} false; then :
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Wall" >&5
+$as_echo_n "checking whether $CC handles -Wall... " >&6; }
+if ${gl_cv_warn_CFLAGS__Wall+:} false; then :
   $as_echo_n "(cached) " >&6
 else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Wall"
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 
 int
 main ()
 {
-#ifndef __GNUC__
-       choke me
-#endif
 
   ;
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
-  ac_compiler_gnu=yes
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Wall=yes
 else
-  ac_compiler_gnu=no
+  gl_cv_warn_CFLAGS__Wall=no
 fi
-rm -f core conftest.err conftest.$ac_build_objext conftest.$ac_ext
-ac_cv_c_compiler_gnu=$ac_compiler_gnu
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_c_compiler_gnu" >&5
-$as_echo "$ac_cv_c_compiler_gnu" >&6; }
-if test $ac_compiler_gnu = yes; then
-  GCC=yes
-else
-  GCC=
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Wall" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Wall" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Wall" = xyes; then :
+  as_fn_append WARN_CFLAGS " -Wall"
 fi
-ac_test_CFLAGS=${CFLAGS_FOR_BUILD+set}
-ac_save_CFLAGS=$CFLAGS_FOR_BUILD
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD accepts -g" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD accepts -g... " >&6; }
-if ${ac_cv_build_prog_cc_g+:} false; then :
+
+
+if test x${gl_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
   $as_echo_n "(cached) " >&6
 else
-  ac_save_c_werror_flag=$ac_c_werror_flag
-   ac_c_werror_flag=yes
-   ac_cv_build_prog_cc_g=no
-   CFLAGS_FOR_BUILD="-g"
-   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 
 int
@@ -6604,11 +6465,36 @@ main ()
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
-  ac_cv_build_prog_cc_g=yes
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
 else
-  CFLAGS_FOR_BUILD=""
-      cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
+  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Wempty-body" >&5
+$as_echo_n "checking whether $CC handles -Wempty-body... " >&6; }
+if ${gl_cv_warn_CFLAGS__Wempty_body+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Wempty-body"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 
 int
@@ -6619,12 +6505,33 @@ main ()
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Wempty_body=yes
+else
+  gl_cv_warn_CFLAGS__Wempty_body=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Wempty_body" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Wempty_body" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Wempty_body" = xyes; then :
+  as_fn_append WARN_CFLAGS " -Wempty-body"
+fi
 
+
+if test x${gl_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
 else
-  ac_c_werror_flag=$ac_save_c_werror_flag
-	 CFLAGS_FOR_BUILD="-g"
-	 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 
 int
@@ -6635,139 +6542,72 @@ main ()
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
-  ac_cv_build_prog_cc_g=yes
-fi
-rm -f core conftest.err conftest.$ac_build_objext conftest.$ac_ext
-fi
-rm -f core conftest.err conftest.$ac_build_objext conftest.$ac_ext
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
 fi
-rm -f core conftest.err conftest.$ac_build_objext conftest.$ac_ext
-   ac_c_werror_flag=$ac_save_c_werror_flag
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_build_prog_cc_g" >&5
-$as_echo "$ac_cv_build_prog_cc_g" >&6; }
-if test "$ac_test_CFLAGS" = set; then
-  CFLAGS_FOR_BUILD=$ac_save_CFLAGS
-elif test $ac_cv_build_prog_cc_g = yes; then
-  if test "$GCC" = yes; then
-    CFLAGS_FOR_BUILD="-g -O2"
-  else
-    CFLAGS_FOR_BUILD="-g"
-  fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
+  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
 else
-  if test "$GCC" = yes; then
-    CFLAGS_FOR_BUILD="-O2"
-  else
-    CFLAGS_FOR_BUILD=
-  fi
+  gl_unknown_warnings_are_errors=
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $CC_FOR_BUILD option to accept ISO C89" >&5
-$as_echo_n "checking for $CC_FOR_BUILD option to accept ISO C89... " >&6; }
-if ${ac_cv_build_prog_cc_c89+:} false; then :
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Wformat-security" >&5
+$as_echo_n "checking whether $CC handles -Wformat-security... " >&6; }
+if ${gl_cv_warn_CFLAGS__Wformat_security+:} false; then :
   $as_echo_n "(cached) " >&6
 else
-  ac_cv_build_prog_cc_c89=no
-ac_save_CC=$CC_FOR_BUILD
-cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-#include <stdarg.h>
-#include <stdio.h>
-struct stat;
-/* Most of the following tests are stolen from RCS 5.7's src/conf.sh.  */
-struct buf { int x; };
-FILE * (*rcsopen) (struct buf *, struct stat *, int);
-static char *e (p, i)
-     char **p;
-     int i;
-{
-  return p[i];
-}
-static char *f (char * (*g) (char **, int), char **p, ...)
-{
-  char *s;
-  va_list v;
-  va_start (v,p);
-  s = g (p, va_arg (v,int));
-  va_end (v);
-  return s;
-}
-
-/* OSF 4.0 Compaq cc is some sort of almost-ANSI by default.  It has
-   function prototypes and stuff, but not '\xHH' hex character constants.
-   These don't provoke an error unfortunately, instead are silently treated
-   as 'x'.  The following induces an error, until -std is added to get
-   proper ANSI mode.  Curiously '\x00'!='x' always comes out true, for an
-   array size at least.  It's necessary to write '\x00'==0 to get something
-   that's true only with -std.  */
-int osf4_cc_array ['\x00' == 0 ? 1 : -1];
 
-/* IBM C 6 for AIX is almost-ANSI by default, but it replaces macro parameters
-   inside strings and character constants.  */
-#define FOO(x) 'x'
-int xlc6_cc_array[FOO(a) == 'x' ? 1 : -1];
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Wformat-security"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
 
-int test (int i, double x);
-struct s1 {int (*f) (int a);};
-struct s2 {int (*f) (double a);};
-int pairnames (int, char **, FILE *(*)(struct buf *, struct stat *, int), int, int);
-int argc;
-char **argv;
 int
 main ()
 {
-return f (e, argv, 0) != argv[0]  ||  f (e, argv, 1) != argv[1];
+
   ;
   return 0;
 }
 _ACEOF
-for ac_arg in '' -qlanglvl=extc89 -qlanglvl=ansi -std \
-	-Ae "-Aa -D_HPUX_SOURCE" "-Xc -D__EXTENSIONS__"
-do
-  CC_FOR_BUILD="$ac_save_CC $ac_arg"
-  if ac_fn_c_try_compile "$LINENO"; then :
-  ac_cv_build_prog_cc_c89=$ac_arg
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Wformat_security=yes
+else
+  gl_cv_warn_CFLAGS__Wformat_security=no
 fi
-rm -f core conftest.err conftest.$ac_build_objext
-  test "x$ac_cv_build_prog_cc_c89" != "xno" && break
-done
-rm -f conftest.$ac_ext
-CC_FOR_BUILD=$ac_save_CC
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
 
 fi
-# AC_CACHE_VAL
-case "x$ac_cv_build_prog_cc_c89" in
-  x)
-    { $as_echo "$as_me:${as_lineno-$LINENO}: result: none needed" >&5
-$as_echo "none needed" >&6; } ;;
-  xno)
-    { $as_echo "$as_me:${as_lineno-$LINENO}: result: unsupported" >&5
-$as_echo "unsupported" >&6; } ;;
-  *)
-    CC_FOR_BUILD="$CC_FOR_BUILD $ac_cv_build_prog_cc_c89"
-    { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_build_prog_cc_c89" >&5
-$as_echo "$ac_cv_build_prog_cc_c89" >&6; } ;;
-esac
-if test "x$ac_cv_build_prog_cc_c89" != xno; then :
-
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Wformat_security" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Wformat_security" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Wformat_security" = xyes; then :
+  as_fn_append WARN_CFLAGS " -Wformat-security"
 fi
 
-ac_ext=c
-ac_cpp='$CPP_FOR_BUILD $CPPFLAGS_FOR_BUILD'
-ac_compile='$CC_FOR_BUILD -c $CFLAGS_FOR_BUILD $CPPFLAGS_FOR_BUILD conftest.$ac_ext >&5'
-ac_link='$CC_FOR_BUILD -o conftest$ac_build_exeext $CFLAGS_FOR_BUILD $CPPFLAGS_FOR_BUILD $LDFLAGS_FOR_BUILD conftest.$ac_ext $LIBS >&5'
-ac_compiler_gnu=$ac_cv_c_compiler_gnu
 
-ac_ext=c
-ac_cpp='$CPP_FOR_BUILD $CPPFLAGS_FOR_BUILD'
-ac_compile='$CC_FOR_BUILD -c $CFLAGS_FOR_BUILD $CPPFLAGS_FOR_BUILD conftest.$ac_ext >&5'
-ac_link='$CC_FOR_BUILD -o conftest$ac_build_exeext $CFLAGS_FOR_BUILD $CPPFLAGS_FOR_BUILD $LDFLAGS_FOR_BUILD conftest.$ac_ext $LIBS >&5'
-ac_compiler_gnu=$ac_cv_c_compiler_gnu
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD understands -c and -o together" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD understands -c and -o together... " >&6; }
-if ${am_cv_build_prog_cc_c_o+:} false; then :
+if test x${gl_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
   $as_echo_n "(cached) " >&6
 else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 
@@ -6779,3358 +6619,8044 @@ main ()
   return 0;
 }
 _ACEOF
-  # Make sure it works both with $CC and with simple cc.
-  # Following AC_PROG_CC_C_O, we do the test twice because some
-  # compilers refuse to overwrite an existing .o file with -o,
-  # though they will create one.
-  am_cv_build_prog_cc_c_o=yes
-  for am_i in 1 2; do
-    if { echo "$as_me:$LINENO: $CC_FOR_BUILD -c conftest.$ac_ext -o conftest2.$ac_build_objext" >&5
-   ($CC_FOR_BUILD -c conftest.$ac_ext -o conftest2.$ac_build_objext) >&5 2>&5
-   ac_status=$?
-   echo "$as_me:$LINENO: \$? = $ac_status" >&5
-   (exit $ac_status); } \
-         && test -f conftest2.$ac_build_objext; then
-      : OK
-    else
-      am_cv_build_prog_cc_c_o=no
-      break
-    fi
-  done
-  rm -f core conftest*
-  unset am_i
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $am_cv_build_prog_cc_c_o" >&5
-$as_echo "$am_cv_build_prog_cc_c_o" >&6; }
-if test "$am_cv_build_prog_cc_c_o" != yes; then
-   # Losing compiler, so override with the script.
-   # FIXME: It is wrong to rewrite CC.
-   # But if we don't then we get into trouble of one sort or another.
-   # A longer-term fix would be to have automake use am__CC in this case,
-   # and then we could set am__CC="\$(top_srcdir)/compile \$(CC)"
-   CC_FOR_BUILD="$am_aux_dir/compile $CC_FOR_BUILD"
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
+  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_unknown_warnings_are_errors=
 fi
-ac_ext=c
-ac_cpp='$CPP_FOR_BUILD $CPPFLAGS_FOR_BUILD'
-ac_compile='$CC_FOR_BUILD -c $CFLAGS_FOR_BUILD $CPPFLAGS_FOR_BUILD conftest.$ac_ext >&5'
-ac_link='$CC_FOR_BUILD -o conftest$ac_build_exeext $CFLAGS_FOR_BUILD $CPPFLAGS_FOR_BUILD $LDFLAGS_FOR_BUILD conftest.$ac_ext $LIBS >&5'
-ac_compiler_gnu=$ac_cv_c_compiler_gnu
 
 
-depcc="$CC_FOR_BUILD"   am_compiler_list=
+fi
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking dependency style of $depcc" >&5
-$as_echo_n "checking dependency style of $depcc... " >&6; }
-if ${am_cv_build_CC_dependencies_compiler_type+:} false; then :
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Wignored-qualifiers" >&5
+$as_echo_n "checking whether $CC handles -Wignored-qualifiers... " >&6; }
+if ${gl_cv_warn_CFLAGS__Wignored_qualifiers+:} false; then :
   $as_echo_n "(cached) " >&6
 else
-  if test -z "$AMDEP_TRUE" && test -f "$am_depcomp"; then
-  # We make a subdir and do the tests there.  Otherwise we can end up
-  # making bogus files that we don't know about and never remove.  For
-  # instance it was reported that on HP-UX the gcc test will end up
-  # making a dummy file named 'D' -- because '-MD' means "put the output
-  # in D".
-  rm -rf conftest.dir
-  mkdir conftest.dir
-  # Copy depcomp to subdir because otherwise we won't find it if we're
-  # using a relative directory.
-  cp "$am_depcomp" conftest.dir
-  cd conftest.dir
-  # We will build objects and dependencies in a subdirectory because
-  # it helps to detect inapplicable dependency modes.  For instance
-  # both Tru64's cc and ICC support -MD to output dependencies as a
-  # side effect of compilation, but ICC will put the dependencies in
-  # the current directory while Tru64 will put them in the object
-  # directory.
-  mkdir sub
-
-  am_cv_build_CC_dependencies_compiler_type=none
-  if test "$am_compiler_list" = ""; then
-     am_compiler_list=`sed -n 's/^#*\([a-zA-Z0-9]*\))$/\1/p' < ./depcomp`
-  fi
-  am__universal=false
-  case " $depcc " in #(
-     *\ -arch\ *\ -arch\ *) am__universal=true ;;
-     esac
 
-  for depmode in $am_compiler_list; do
-    # Setup a source with many dependencies, because some compilers
-    # like to wrap large dependency lists on column 80 (with \), and
-    # we should not choose a depcomp mode which is confused by this.
-    #
-    # We need to recreate these files for each test, as the compiler may
-    # overwrite some of them when testing with obscure command lines.
-    # This happens at least with the AIX C compiler.
-    : > sub/conftest.c
-    for i in 1 2 3 4 5 6; do
-      echo '#include "conftst'$i'.h"' >> sub/conftest.c
-      # Using ": > sub/conftst$i.h" creates only sub/conftst1.h with
-      # Solaris 10 /bin/sh.
-      echo '/* dummy */' > sub/conftst$i.h
-    done
-    echo "${am__include} ${am__quote}sub/conftest.Po${am__quote}" > confmf
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Wignored-qualifiers"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
 
-    # We check with '-c' and '-o' for the sake of the "dashmstdout"
-    # mode.  It turns out that the SunPro C++ compiler does not properly
-    # handle '-M -o', and we need to detect this.  Also, some Intel
-    # versions had trouble with output in subdirs.
-    am__obj=sub/conftest.${OBJEXT-o}
-    am__minus_obj="-o $am__obj"
-    case $depmode in
-    gcc)
-      # This depmode causes a compiler race in universal mode.
-      test "$am__universal" = false || continue
-      ;;
-    nosideeffect)
-      # After this tag, mechanisms are not by side-effect, so they'll
-      # only be used when explicitly requested.
-      if test "x$enable_dependency_tracking" = xyes; then
-	continue
-      else
-	break
-      fi
-      ;;
-    msvc7 | msvc7msys | msvisualcpp | msvcmsys)
-      # This compiler won't grok '-c -o', but also, the minuso test has
-      # not run yet.  These depmodes are late enough in the game, and
-      # so weak that their functioning should not be impacted.
-      am__obj=conftest.${OBJEXT-o}
-      am__minus_obj=
-      ;;
-    none) break ;;
-    esac
-    if depmode=$depmode \
-       source=sub/conftest.c object=$am__obj \
-       depfile=sub/conftest.Po tmpdepfile=sub/conftest.TPo \
-       $SHELL ./depcomp $depcc -c $am__minus_obj sub/conftest.c \
-         >/dev/null 2>conftest.err &&
-       grep sub/conftst1.h sub/conftest.Po > /dev/null 2>&1 &&
-       grep sub/conftst6.h sub/conftest.Po > /dev/null 2>&1 &&
-       grep $am__obj sub/conftest.Po > /dev/null 2>&1 &&
-       ${MAKE-make} -s -f confmf > /dev/null 2>&1; then
-      # icc doesn't choke on unknown options, it will just issue warnings
-      # or remarks (even with -Werror).  So we grep stderr for any message
-      # that says an option was ignored or not supported.
-      # When given -MP, icc 7.0 and 7.1 complain thusly:
-      #   icc: Command line warning: ignoring option '-M'; no argument required
-      # The diagnosis changed in icc 8.0:
-      #   icc: Command line remark: option '-MP' not supported
-      if (grep 'ignoring option' conftest.err ||
-          grep 'not supported' conftest.err) >/dev/null 2>&1; then :; else
-        am_cv_build_CC_dependencies_compiler_type=$depmode
-        break
-      fi
-    fi
-  done
+int
+main ()
+{
 
-  cd ..
-  rm -rf conftest.dir
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Wignored_qualifiers=yes
 else
-  am_cv_build_CC_dependencies_compiler_type=none
+  gl_cv_warn_CFLAGS__Wignored_qualifiers=no
 fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $am_cv_build_CC_dependencies_compiler_type" >&5
-$as_echo "$am_cv_build_CC_dependencies_compiler_type" >&6; }
-CCDEPMODE=depmode=$am_cv_build_CC_dependencies_compiler_type
-
- if
-  test "x$enable_dependency_tracking" != xno \
-  && test "$am_cv_build_CC_dependencies_compiler_type" = gcc3; then
-  am__fastdepCC_TRUE=
-  am__fastdepCC_FALSE='#'
-else
-  am__fastdepCC_TRUE='#'
-  am__fastdepCC_FALSE=
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Wignored_qualifiers" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Wignored_qualifiers" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Wignored_qualifiers" = xyes; then :
+  as_fn_append WARN_CFLAGS " -Wignored-qualifiers"
 fi
 
 
-ac_ext=c
-ac_cpp='$CPP_FOR_BUILD $CPPFLAGS_FOR_BUILD'
-ac_compile='$CC_FOR_BUILD -c $CFLAGS_FOR_BUILD $CPPFLAGS_FOR_BUILD conftest.$ac_ext >&5'
-ac_link='$CC_FOR_BUILD -o conftest$ac_build_exeext $CFLAGS_FOR_BUILD $CPPFLAGS_FOR_BUILD $LDFLAGS_FOR_BUILD conftest.$ac_ext $LIBS >&5'
-ac_compiler_gnu=$ac_cv_c_compiler_gnu
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking how to run the C preprocessor" >&5
-$as_echo_n "checking how to run the C preprocessor... " >&6; }
-# On Suns, sometimes $CPP names a directory.
-if test -n "$CPP_FOR_BUILD" && test -d "$CPP_FOR_BUILD"; then
-  CPP_FOR_BUILD=
-fi
-if test -z "$CPP_FOR_BUILD"; then
-  if ${ac_cv_build_prog_CPP+:} false; then :
+if test x${gl_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
   $as_echo_n "(cached) " >&6
 else
-      # Double quotes because CPP needs to be expanded
-    for CPP_FOR_BUILD in "$CC_FOR_BUILD -E" "$CC_FOR_BUILD -E -traditional-cpp" "/lib/cpp"
-    do
-      ac_preproc_ok=false
-for ac_c_preproc_warn_flag in '' yes
-do
-  # Use a header file that comes with gcc, so configuring glibc
-  # with a fresh cross-compiler works.
-  # Prefer <limits.h> to <assert.h> if __STDC__ is defined, since
-  # <limits.h> exists even on freestanding compilers.
-  # On the NeXT, cc -E runs the code through the compiler's parser,
-  # not just through cpp. "Syntax error" is here to catch this case.
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
-#ifdef __STDC__
-# include <limits.h>
-#else
-# include <assert.h>
-#endif
-		     Syntax error
-_ACEOF
-if ac_fn_c_try_cpp "$LINENO"; then :
 
-else
-  # Broken: fails on valid input.
-continue
-fi
-rm -f conftest.err conftest.i conftest.$ac_ext
+int
+main ()
+{
 
-  # OK, works on sane cases.  Now check whether nonexistent headers
-  # can be detected and how.
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-#include <ac_nonexistent.h>
+  ;
+  return 0;
+}
 _ACEOF
-if ac_fn_c_try_cpp "$LINENO"; then :
-  # Broken: success on invalid input.
-continue
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
 else
-  # Passes both tests.
-ac_preproc_ok=:
-break
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
 fi
-rm -f conftest.err conftest.i conftest.$ac_ext
-
-done
-# Because of `break', _AC_PREPROC_IFELSE's cleaning code was skipped.
-rm -f conftest.i conftest.err conftest.$ac_ext
-if $ac_preproc_ok; then :
-  break
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
+  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_unknown_warnings_are_errors=
 fi
 
-    done
-    ac_cv_build_prog_CPP=$CPP_FOR_BUILD
 
 fi
-  CPP_FOR_BUILD=$ac_cv_build_prog_CPP
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Wimplicit-fallthrough=5" >&5
+$as_echo_n "checking whether $CC handles -Wimplicit-fallthrough=5... " >&6; }
+if ${gl_cv_warn_CFLAGS__Wimplicit_fallthrough_5+:} false; then :
+  $as_echo_n "(cached) " >&6
 else
-  ac_cv_build_prog_CPP=$CPP_FOR_BUILD
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Wimplicit-fallthrough=5"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Wimplicit_fallthrough_5=yes
+else
+  gl_cv_warn_CFLAGS__Wimplicit_fallthrough_5=no
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $CPP_FOR_BUILD" >&5
-$as_echo "$CPP_FOR_BUILD" >&6; }
-ac_preproc_ok=false
-for ac_c_preproc_warn_flag in '' yes
-do
-  # Use a header file that comes with gcc, so configuring glibc
-  # with a fresh cross-compiler works.
-  # Prefer <limits.h> to <assert.h> if __STDC__ is defined, since
-  # <limits.h> exists even on freestanding compilers.
-  # On the NeXT, cc -E runs the code through the compiler's parser,
-  # not just through cpp. "Syntax error" is here to catch this case.
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Wimplicit_fallthrough_5" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Wimplicit_fallthrough_5" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Wimplicit_fallthrough_5" = xyes; then :
+  as_fn_append WARN_CFLAGS " -Wimplicit-fallthrough=5"
+fi
+
+
+if test x${gl_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
-#ifdef __STDC__
-# include <limits.h>
-#else
-# include <assert.h>
-#endif
-		     Syntax error
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
+  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Winit-self" >&5
+$as_echo_n "checking whether $CC handles -Winit-self... " >&6; }
+if ${gl_cv_warn_CFLAGS__Winit_self+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Winit-self"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Winit_self=yes
+else
+  gl_cv_warn_CFLAGS__Winit_self=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Winit_self" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Winit_self" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Winit_self" = xyes; then :
+  as_fn_append WARN_CFLAGS " -Winit-self"
+fi
+
+
+if test x${gl_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
+  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Winitializer-overrides" >&5
+$as_echo_n "checking whether $CC handles -Winitializer-overrides... " >&6; }
+if ${gl_cv_warn_CFLAGS__Winitializer_overrides+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Winitializer-overrides"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Winitializer_overrides=yes
+else
+  gl_cv_warn_CFLAGS__Winitializer_overrides=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Winitializer_overrides" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Winitializer_overrides" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Winitializer_overrides" = xyes; then :
+  as_fn_append WARN_CFLAGS " -Winitializer-overrides"
+fi
+
+
+if test x${gl_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
+  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Wlogical-op" >&5
+$as_echo_n "checking whether $CC handles -Wlogical-op... " >&6; }
+if ${gl_cv_warn_CFLAGS__Wlogical_op+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Wlogical-op"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Wlogical_op=yes
+else
+  gl_cv_warn_CFLAGS__Wlogical_op=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Wlogical_op" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Wlogical_op" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Wlogical_op" = xyes; then :
+  as_fn_append WARN_CFLAGS " -Wlogical-op"
+fi
+
+
+if test x${gl_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
+  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Wmissing-parameter-type" >&5
+$as_echo_n "checking whether $CC handles -Wmissing-parameter-type... " >&6; }
+if ${gl_cv_warn_CFLAGS__Wmissing_parameter_type+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Wmissing-parameter-type"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Wmissing_parameter_type=yes
+else
+  gl_cv_warn_CFLAGS__Wmissing_parameter_type=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Wmissing_parameter_type" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Wmissing_parameter_type" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Wmissing_parameter_type" = xyes; then :
+  as_fn_append WARN_CFLAGS " -Wmissing-parameter-type"
+fi
+
+
+if test x${gl_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
+  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Wnested-externs" >&5
+$as_echo_n "checking whether $CC handles -Wnested-externs... " >&6; }
+if ${gl_cv_warn_CFLAGS__Wnested_externs+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Wnested-externs"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Wnested_externs=yes
+else
+  gl_cv_warn_CFLAGS__Wnested_externs=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Wnested_externs" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Wnested_externs" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Wnested_externs" = xyes; then :
+  as_fn_append WARN_CFLAGS " -Wnested-externs"
+fi
+
+
+if test x${gl_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
+  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Wold-style-declaration" >&5
+$as_echo_n "checking whether $CC handles -Wold-style-declaration... " >&6; }
+if ${gl_cv_warn_CFLAGS__Wold_style_declaration+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Wold-style-declaration"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Wold_style_declaration=yes
+else
+  gl_cv_warn_CFLAGS__Wold_style_declaration=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Wold_style_declaration" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Wold_style_declaration" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Wold_style_declaration" = xyes; then :
+  as_fn_append WARN_CFLAGS " -Wold-style-declaration"
+fi
+
+
+if test x${gl_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
+  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Wold-style-definition" >&5
+$as_echo_n "checking whether $CC handles -Wold-style-definition... " >&6; }
+if ${gl_cv_warn_CFLAGS__Wold_style_definition+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Wold-style-definition"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Wold_style_definition=yes
+else
+  gl_cv_warn_CFLAGS__Wold_style_definition=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Wold_style_definition" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Wold_style_definition" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Wold_style_definition" = xyes; then :
+  as_fn_append WARN_CFLAGS " -Wold-style-definition"
+fi
+
+
+if test x${gl_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
+  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Woverride-init" >&5
+$as_echo_n "checking whether $CC handles -Woverride-init... " >&6; }
+if ${gl_cv_warn_CFLAGS__Woverride_init+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Woverride-init"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Woverride_init=yes
+else
+  gl_cv_warn_CFLAGS__Woverride_init=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Woverride_init" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Woverride_init" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Woverride_init" = xyes; then :
+  as_fn_append WARN_CFLAGS " -Woverride-init"
+fi
+
+
+if test x${gl_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
+  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Wsign-compare" >&5
+$as_echo_n "checking whether $CC handles -Wsign-compare... " >&6; }
+if ${gl_cv_warn_CFLAGS__Wsign_compare+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Wsign-compare"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Wsign_compare=yes
+else
+  gl_cv_warn_CFLAGS__Wsign_compare=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Wsign_compare" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Wsign_compare" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Wsign_compare" = xyes; then :
+  as_fn_append WARN_CFLAGS " -Wsign-compare"
+fi
+
+
+if test x${gl_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
+  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Wtype-limits" >&5
+$as_echo_n "checking whether $CC handles -Wtype-limits... " >&6; }
+if ${gl_cv_warn_CFLAGS__Wtype_limits+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Wtype-limits"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Wtype_limits=yes
+else
+  gl_cv_warn_CFLAGS__Wtype_limits=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Wtype_limits" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Wtype_limits" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Wtype_limits" = xyes; then :
+  as_fn_append WARN_CFLAGS " -Wtype-limits"
+fi
+
+
+if test x${gl_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
+  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Wwrite-strings" >&5
+$as_echo_n "checking whether $CC handles -Wwrite-strings... " >&6; }
+if ${gl_cv_warn_CFLAGS__Wwrite_strings+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Wwrite-strings"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Wwrite_strings=yes
+else
+  gl_cv_warn_CFLAGS__Wwrite_strings=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Wwrite_strings" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Wwrite_strings" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Wwrite_strings" = xyes; then :
+  as_fn_append WARN_CFLAGS " -Wwrite-strings"
+fi
+
+
+# Check whether --enable-gcc-Werror was given.
+if test "${enable_gcc_Werror+set}" = set; then :
+  enableval=$enable_gcc_Werror; case "$enable_gcc_Werror" in
+		yes|no|no,*) ;;
+		*) as_fn_error $? "bad value $enable_gcc_Werror for gcc-Werror option" "$LINENO" 5 ;;
+	       esac
+else
+  enable_gcc_Werror="$st_cv_enable_Werror"
+fi
+
+if test "$enable_gcc_Werror" = yes; then
+  if test x${gl_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Werror__Wunknown_warning_option" = xyes; then :
+  gl_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC handles -Werror" >&5
+$as_echo_n "checking whether $CC handles -Werror... " >&6; }
+if ${gl_cv_warn_CFLAGS__Werror+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS"
+  as_fn_append CFLAGS " $gl_unknown_warnings_are_errors -Werror"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS__Werror=yes
+else
+  gl_cv_warn_CFLAGS__Werror=no
+fi
+rm -f core conftest.err conftest.$ac_objext \
+    conftest$ac_exeext conftest.$ac_ext
+  CFLAGS="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS__Werror" >&5
+$as_echo "$gl_cv_warn_CFLAGS__Werror" >&6; }
+if test "x$gl_cv_warn_CFLAGS__Werror" = xyes; then :
+  as_fn_append WARN_CFLAGS " -Werror"
+fi
+
+
+fi
+
+
+
+
+
+if test -n "${ac_c_decl_warn_flag+set}"; then :
+  st_saved_ac_c_decl_warn_flag="${ac_c_decl_warn_flag}"; unset ac_c_decl_warn_flag
+fi
+
+if test -n "${ac_c_preproc_warn_flag+set}"; then :
+  st_saved_ac_c_preproc_warn_flag="${ac_c_preproc_warn_flag}"; unset ac_c_preproc_warn_flag
+fi
+
+if test -n "${ac_c_werror_flag+set}"; then :
+  st_saved_ac_c_werror_flag="${ac_c_werror_flag}"; unset ac_c_werror_flag
+fi
+
+if test -n "${ac_compile+set}"; then :
+  st_saved_ac_compile="${ac_compile}"; unset ac_compile
+fi
+
+if test -n "${ac_compiler_gnu+set}"; then :
+  st_saved_ac_compiler_gnu="${ac_compiler_gnu}"; unset ac_compiler_gnu
+fi
+
+if test -n "${ac_cpp+set}"; then :
+  st_saved_ac_cpp="${ac_cpp}"; unset ac_cpp
+fi
+
+if test -n "${ac_cv_c_compiler_gnu+set}"; then :
+  st_saved_ac_cv_c_compiler_gnu="${ac_cv_c_compiler_gnu}"; unset ac_cv_c_compiler_gnu
+fi
+
+if test -n "${ac_cv_c_decl_report+set}"; then :
+  st_saved_ac_cv_c_decl_report="${ac_cv_c_decl_report}"; unset ac_cv_c_decl_report
+fi
+
+if test -n "${ac_link+set}"; then :
+  st_saved_ac_link="${ac_link}"; unset ac_link
+fi
+
+if test -n "${ac_tool_prefix+set}"; then :
+  st_saved_ac_tool_prefix="${ac_tool_prefix}"; unset ac_tool_prefix
+fi
+
+if test -n "${cross_compiling+set}"; then :
+  st_saved_cross_compiling="${cross_compiling}"; unset cross_compiling
+fi
+
+cross_compiling=no
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: looking for a C compiler that generates native executables" >&5
+$as_echo "$as_me: looking for a C compiler that generates native executables" >&6;}
+ac_ext=c
+ac_cpp='$CPP_FOR_BUILD $CPPFLAGS_FOR_BUILD'
+ac_compile='$CC_FOR_BUILD -c $CFLAGS_FOR_BUILD $CPPFLAGS_FOR_BUILD conftest.$ac_ext >&5'
+ac_link='$CC_FOR_BUILD -o conftest$ac_build_exeext $CFLAGS_FOR_BUILD $CPPFLAGS_FOR_BUILD $LDFLAGS_FOR_BUILD conftest.$ac_ext $LIBS >&5'
+ac_compiler_gnu=$ac_cv_c_compiler_gnu
+if test -n "$ac_tool_prefix"; then
+  # Extract the first word of "${ac_tool_prefix}gcc", so it can be a program name with args.
+set dummy ${ac_tool_prefix}gcc; ac_word=$2
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+$as_echo_n "checking for $ac_word... " >&6; }
+if ${ac_cv_prog_CC_FOR_BUILD+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  if test -n "$CC_FOR_BUILD"; then
+  ac_cv_prog_CC_FOR_BUILD="$CC_FOR_BUILD" # Let the user override the test.
+else
+as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
+for as_dir in $PATH
+do
+  IFS=$as_save_IFS
+  test -z "$as_dir" && as_dir=.
+    for ac_exec_ext in '' $ac_executable_extensions; do
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+    ac_cv_prog_CC_FOR_BUILD="${ac_tool_prefix}gcc"
+    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+    break 2
+  fi
+done
+  done
+IFS=$as_save_IFS
+
+fi
+fi
+CC_FOR_BUILD=$ac_cv_prog_CC_FOR_BUILD
+if test -n "$CC_FOR_BUILD"; then
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $CC_FOR_BUILD" >&5
+$as_echo "$CC_FOR_BUILD" >&6; }
+else
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
+$as_echo "no" >&6; }
+fi
+
+
+fi
+if test -z "$ac_cv_prog_CC_FOR_BUILD"; then
+  ac_ct_CC_FOR_BUILD=$CC_FOR_BUILD
+  # Extract the first word of "gcc", so it can be a program name with args.
+set dummy gcc; ac_word=$2
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+$as_echo_n "checking for $ac_word... " >&6; }
+if ${ac_cv_prog_ac_ct_CC_FOR_BUILD+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  if test -n "$ac_ct_CC_FOR_BUILD"; then
+  ac_cv_prog_ac_ct_CC_FOR_BUILD="$ac_ct_CC_FOR_BUILD" # Let the user override the test.
+else
+as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
+for as_dir in $PATH
+do
+  IFS=$as_save_IFS
+  test -z "$as_dir" && as_dir=.
+    for ac_exec_ext in '' $ac_executable_extensions; do
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+    ac_cv_prog_ac_ct_CC_FOR_BUILD="gcc"
+    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+    break 2
+  fi
+done
+  done
+IFS=$as_save_IFS
+
+fi
+fi
+ac_ct_CC_FOR_BUILD=$ac_cv_prog_ac_ct_CC_FOR_BUILD
+if test -n "$ac_ct_CC_FOR_BUILD"; then
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_ct_CC_FOR_BUILD" >&5
+$as_echo "$ac_ct_CC_FOR_BUILD" >&6; }
+else
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
+$as_echo "no" >&6; }
+fi
+
+  if test "x$ac_ct_CC_FOR_BUILD" = x; then
+    CC_FOR_BUILD=""
+  else
+    case $cross_compiling:$ac_tool_warned in
+yes:)
+{ $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: using cross tools not prefixed with build triplet" >&5
+$as_echo "$as_me: WARNING: using cross tools not prefixed with build triplet" >&2;}
+ac_tool_warned=yes ;;
+esac
+    CC_FOR_BUILD=$ac_ct_CC_FOR_BUILD
+  fi
+else
+  CC_FOR_BUILD="$ac_cv_prog_CC_FOR_BUILD"
+fi
+
+if test -z "$CC_FOR_BUILD"; then
+          if test -n "$ac_tool_prefix"; then
+    # Extract the first word of "${ac_tool_prefix}cc", so it can be a program name with args.
+set dummy ${ac_tool_prefix}cc; ac_word=$2
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+$as_echo_n "checking for $ac_word... " >&6; }
+if ${ac_cv_prog_CC_FOR_BUILD+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  if test -n "$CC_FOR_BUILD"; then
+  ac_cv_prog_CC_FOR_BUILD="$CC_FOR_BUILD" # Let the user override the test.
+else
+as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
+for as_dir in $PATH
+do
+  IFS=$as_save_IFS
+  test -z "$as_dir" && as_dir=.
+    for ac_exec_ext in '' $ac_executable_extensions; do
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+    ac_cv_prog_CC_FOR_BUILD="${ac_tool_prefix}cc"
+    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+    break 2
+  fi
+done
+  done
+IFS=$as_save_IFS
+
+fi
+fi
+CC_FOR_BUILD=$ac_cv_prog_CC_FOR_BUILD
+if test -n "$CC_FOR_BUILD"; then
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $CC_FOR_BUILD" >&5
+$as_echo "$CC_FOR_BUILD" >&6; }
+else
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
+$as_echo "no" >&6; }
+fi
+
+
+  fi
+fi
+if test -z "$CC_FOR_BUILD"; then
+  # Extract the first word of "cc", so it can be a program name with args.
+set dummy cc; ac_word=$2
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+$as_echo_n "checking for $ac_word... " >&6; }
+if ${ac_cv_prog_CC_FOR_BUILD+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  if test -n "$CC_FOR_BUILD"; then
+  ac_cv_prog_CC_FOR_BUILD="$CC_FOR_BUILD" # Let the user override the test.
+else
+  ac_prog_rejected=no
+as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
+for as_dir in $PATH
+do
+  IFS=$as_save_IFS
+  test -z "$as_dir" && as_dir=.
+    for ac_exec_ext in '' $ac_executable_extensions; do
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+    if test "$as_dir/$ac_word$ac_exec_ext" = "/usr/ucb/cc"; then
+       ac_prog_rejected=yes
+       continue
+     fi
+    ac_cv_prog_CC_FOR_BUILD="cc"
+    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+    break 2
+  fi
+done
+  done
+IFS=$as_save_IFS
+
+if test $ac_prog_rejected = yes; then
+  # We found a bogon in the path, so make sure we never use it.
+  set dummy $ac_cv_prog_CC_FOR_BUILD
+  shift
+  if test $# != 0; then
+    # We chose a different compiler from the bogus one.
+    # However, it has the same basename, so the bogon will be chosen
+    # first if we set CC_FOR_BUILD to just the basename; use the full file name.
+    shift
+    ac_cv_prog_CC_FOR_BUILD="$as_dir/$ac_word${1+' '}$@"
+  fi
+fi
+fi
+fi
+CC_FOR_BUILD=$ac_cv_prog_CC_FOR_BUILD
+if test -n "$CC_FOR_BUILD"; then
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $CC_FOR_BUILD" >&5
+$as_echo "$CC_FOR_BUILD" >&6; }
+else
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
+$as_echo "no" >&6; }
+fi
+
+
+fi
+if test -z "$CC_FOR_BUILD"; then
+  if test -n "$ac_tool_prefix"; then
+  for ac_prog in cl.exe
+  do
+    # Extract the first word of "$ac_tool_prefix$ac_prog", so it can be a program name with args.
+set dummy $ac_tool_prefix$ac_prog; ac_word=$2
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+$as_echo_n "checking for $ac_word... " >&6; }
+if ${ac_cv_prog_CC_FOR_BUILD+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  if test -n "$CC_FOR_BUILD"; then
+  ac_cv_prog_CC_FOR_BUILD="$CC_FOR_BUILD" # Let the user override the test.
+else
+as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
+for as_dir in $PATH
+do
+  IFS=$as_save_IFS
+  test -z "$as_dir" && as_dir=.
+    for ac_exec_ext in '' $ac_executable_extensions; do
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+    ac_cv_prog_CC_FOR_BUILD="$ac_tool_prefix$ac_prog"
+    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+    break 2
+  fi
+done
+  done
+IFS=$as_save_IFS
+
+fi
+fi
+CC_FOR_BUILD=$ac_cv_prog_CC_FOR_BUILD
+if test -n "$CC_FOR_BUILD"; then
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $CC_FOR_BUILD" >&5
+$as_echo "$CC_FOR_BUILD" >&6; }
+else
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
+$as_echo "no" >&6; }
+fi
+
+
+    test -n "$CC_FOR_BUILD" && break
+  done
+fi
+if test -z "$CC_FOR_BUILD"; then
+  ac_ct_CC_FOR_BUILD=$CC_FOR_BUILD
+  for ac_prog in cl.exe
+do
+  # Extract the first word of "$ac_prog", so it can be a program name with args.
+set dummy $ac_prog; ac_word=$2
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+$as_echo_n "checking for $ac_word... " >&6; }
+if ${ac_cv_prog_ac_ct_CC_FOR_BUILD+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  if test -n "$ac_ct_CC_FOR_BUILD"; then
+  ac_cv_prog_ac_ct_CC_FOR_BUILD="$ac_ct_CC_FOR_BUILD" # Let the user override the test.
+else
+as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
+for as_dir in $PATH
+do
+  IFS=$as_save_IFS
+  test -z "$as_dir" && as_dir=.
+    for ac_exec_ext in '' $ac_executable_extensions; do
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+    ac_cv_prog_ac_ct_CC_FOR_BUILD="$ac_prog"
+    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+    break 2
+  fi
+done
+  done
+IFS=$as_save_IFS
+
+fi
+fi
+ac_ct_CC_FOR_BUILD=$ac_cv_prog_ac_ct_CC_FOR_BUILD
+if test -n "$ac_ct_CC_FOR_BUILD"; then
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_ct_CC_FOR_BUILD" >&5
+$as_echo "$ac_ct_CC_FOR_BUILD" >&6; }
+else
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
+$as_echo "no" >&6; }
+fi
+
+
+  test -n "$ac_ct_CC_FOR_BUILD" && break
+done
+
+  if test "x$ac_ct_CC_FOR_BUILD" = x; then
+    CC_FOR_BUILD=""
+  else
+    case $cross_compiling:$ac_tool_warned in
+yes:)
+{ $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: using cross tools not prefixed with build triplet" >&5
+$as_echo "$as_me: WARNING: using cross tools not prefixed with build triplet" >&2;}
+ac_tool_warned=yes ;;
+esac
+    CC_FOR_BUILD=$ac_ct_CC_FOR_BUILD
+  fi
+fi
+
+fi
+
+
+test -z "$CC_FOR_BUILD" && { { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
+$as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
+as_fn_error $? "no acceptable C compiler found in \$PATH
+See \`config.log' for more details" "$LINENO" 5; }
+
+# Provide some information about the compiler.
+$as_echo "$as_me:${as_lineno-$LINENO}: checking for C compiler version" >&5
+set X $ac_compile
+ac_compiler=$2
+for ac_option in --version -v -V -qversion; do
+  { { ac_try="$ac_compiler $ac_option >&5"
+case "(($ac_try" in
+  *\"* | *\`* | *\\*) ac_try_echo=\$ac_try;;
+  *) ac_try_echo=$ac_try;;
+esac
+eval ac_try_echo="\"\$as_me:${as_lineno-$LINENO}: $ac_try_echo\""
+$as_echo "$ac_try_echo"; } >&5
+  (eval "$ac_compiler $ac_option >&5") 2>conftest.err
+  ac_status=$?
+  if test -s conftest.err; then
+    sed '10a\
+... rest of stderr output deleted ...
+         10q' conftest.err >conftest.er1
+    cat conftest.er1 >&5
+  fi
+  rm -f conftest.er1 conftest.err
+  $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
+  test $ac_status = 0; }
+done
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether we are using the GNU C compiler" >&5
+$as_echo_n "checking whether we are using the GNU C compiler... " >&6; }
+if ${ac_cv_c_compiler_gnu+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+#ifndef __GNUC__
+       choke me
+#endif
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_compile "$LINENO"; then :
+  ac_compiler_gnu=yes
+else
+  ac_compiler_gnu=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext conftest.$ac_ext
+ac_cv_c_compiler_gnu=$ac_compiler_gnu
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_c_compiler_gnu" >&5
+$as_echo "$ac_cv_c_compiler_gnu" >&6; }
+if test $ac_compiler_gnu = yes; then
+  GCC=yes
+else
+  GCC=
+fi
+ac_test_CFLAGS=${CFLAGS_FOR_BUILD+set}
+ac_save_CFLAGS=$CFLAGS_FOR_BUILD
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD accepts -g" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD accepts -g... " >&6; }
+if ${ac_cv_build_prog_cc_g+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  ac_save_c_werror_flag=$ac_c_werror_flag
+   ac_c_werror_flag=yes
+   ac_cv_build_prog_cc_g=no
+   CFLAGS_FOR_BUILD="-g"
+   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_compile "$LINENO"; then :
+  ac_cv_build_prog_cc_g=yes
+else
+  CFLAGS_FOR_BUILD=""
+      cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_compile "$LINENO"; then :
+
+else
+  ac_c_werror_flag=$ac_save_c_werror_flag
+	 CFLAGS_FOR_BUILD="-g"
+	 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_compile "$LINENO"; then :
+  ac_cv_build_prog_cc_g=yes
+fi
+rm -f core conftest.err conftest.$ac_build_objext conftest.$ac_ext
+fi
+rm -f core conftest.err conftest.$ac_build_objext conftest.$ac_ext
+fi
+rm -f core conftest.err conftest.$ac_build_objext conftest.$ac_ext
+   ac_c_werror_flag=$ac_save_c_werror_flag
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_build_prog_cc_g" >&5
+$as_echo "$ac_cv_build_prog_cc_g" >&6; }
+if test "$ac_test_CFLAGS" = set; then
+  CFLAGS_FOR_BUILD=$ac_save_CFLAGS
+elif test $ac_cv_build_prog_cc_g = yes; then
+  if test "$GCC" = yes; then
+    CFLAGS_FOR_BUILD="-g -O2"
+  else
+    CFLAGS_FOR_BUILD="-g"
+  fi
+else
+  if test "$GCC" = yes; then
+    CFLAGS_FOR_BUILD="-O2"
+  else
+    CFLAGS_FOR_BUILD=
+  fi
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $CC_FOR_BUILD option to accept ISO C89" >&5
+$as_echo_n "checking for $CC_FOR_BUILD option to accept ISO C89... " >&6; }
+if ${ac_cv_build_prog_cc_c89+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  ac_cv_build_prog_cc_c89=no
+ac_save_CC=$CC_FOR_BUILD
+cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+#include <stdarg.h>
+#include <stdio.h>
+struct stat;
+/* Most of the following tests are stolen from RCS 5.7's src/conf.sh.  */
+struct buf { int x; };
+FILE * (*rcsopen) (struct buf *, struct stat *, int);
+static char *e (p, i)
+     char **p;
+     int i;
+{
+  return p[i];
+}
+static char *f (char * (*g) (char **, int), char **p, ...)
+{
+  char *s;
+  va_list v;
+  va_start (v,p);
+  s = g (p, va_arg (v,int));
+  va_end (v);
+  return s;
+}
+
+/* OSF 4.0 Compaq cc is some sort of almost-ANSI by default.  It has
+   function prototypes and stuff, but not '\xHH' hex character constants.
+   These don't provoke an error unfortunately, instead are silently treated
+   as 'x'.  The following induces an error, until -std is added to get
+   proper ANSI mode.  Curiously '\x00'!='x' always comes out true, for an
+   array size at least.  It's necessary to write '\x00'==0 to get something
+   that's true only with -std.  */
+int osf4_cc_array ['\x00' == 0 ? 1 : -1];
+
+/* IBM C 6 for AIX is almost-ANSI by default, but it replaces macro parameters
+   inside strings and character constants.  */
+#define FOO(x) 'x'
+int xlc6_cc_array[FOO(a) == 'x' ? 1 : -1];
+
+int test (int i, double x);
+struct s1 {int (*f) (int a);};
+struct s2 {int (*f) (double a);};
+int pairnames (int, char **, FILE *(*)(struct buf *, struct stat *, int), int, int);
+int argc;
+char **argv;
+int
+main ()
+{
+return f (e, argv, 0) != argv[0]  ||  f (e, argv, 1) != argv[1];
+  ;
+  return 0;
+}
+_ACEOF
+for ac_arg in '' -qlanglvl=extc89 -qlanglvl=ansi -std \
+	-Ae "-Aa -D_HPUX_SOURCE" "-Xc -D__EXTENSIONS__"
+do
+  CC_FOR_BUILD="$ac_save_CC $ac_arg"
+  if ac_fn_c_try_compile "$LINENO"; then :
+  ac_cv_build_prog_cc_c89=$ac_arg
+fi
+rm -f core conftest.err conftest.$ac_build_objext
+  test "x$ac_cv_build_prog_cc_c89" != "xno" && break
+done
+rm -f conftest.$ac_ext
+CC_FOR_BUILD=$ac_save_CC
+
+fi
+# AC_CACHE_VAL
+case "x$ac_cv_build_prog_cc_c89" in
+  x)
+    { $as_echo "$as_me:${as_lineno-$LINENO}: result: none needed" >&5
+$as_echo "none needed" >&6; } ;;
+  xno)
+    { $as_echo "$as_me:${as_lineno-$LINENO}: result: unsupported" >&5
+$as_echo "unsupported" >&6; } ;;
+  *)
+    CC_FOR_BUILD="$CC_FOR_BUILD $ac_cv_build_prog_cc_c89"
+    { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_build_prog_cc_c89" >&5
+$as_echo "$ac_cv_build_prog_cc_c89" >&6; } ;;
+esac
+if test "x$ac_cv_build_prog_cc_c89" != xno; then :
+
+fi
+
+ac_ext=c
+ac_cpp='$CPP_FOR_BUILD $CPPFLAGS_FOR_BUILD'
+ac_compile='$CC_FOR_BUILD -c $CFLAGS_FOR_BUILD $CPPFLAGS_FOR_BUILD conftest.$ac_ext >&5'
+ac_link='$CC_FOR_BUILD -o conftest$ac_build_exeext $CFLAGS_FOR_BUILD $CPPFLAGS_FOR_BUILD $LDFLAGS_FOR_BUILD conftest.$ac_ext $LIBS >&5'
+ac_compiler_gnu=$ac_cv_c_compiler_gnu
+
+ac_ext=c
+ac_cpp='$CPP_FOR_BUILD $CPPFLAGS_FOR_BUILD'
+ac_compile='$CC_FOR_BUILD -c $CFLAGS_FOR_BUILD $CPPFLAGS_FOR_BUILD conftest.$ac_ext >&5'
+ac_link='$CC_FOR_BUILD -o conftest$ac_build_exeext $CFLAGS_FOR_BUILD $CPPFLAGS_FOR_BUILD $LDFLAGS_FOR_BUILD conftest.$ac_ext $LIBS >&5'
+ac_compiler_gnu=$ac_cv_c_compiler_gnu
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD understands -c and -o together" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD understands -c and -o together... " >&6; }
+if ${am_cv_build_prog_cc_c_o+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+  # Make sure it works both with $CC and with simple cc.
+  # Following AC_PROG_CC_C_O, we do the test twice because some
+  # compilers refuse to overwrite an existing .o file with -o,
+  # though they will create one.
+  am_cv_build_prog_cc_c_o=yes
+  for am_i in 1 2; do
+    if { echo "$as_me:$LINENO: $CC_FOR_BUILD -c conftest.$ac_ext -o conftest2.$ac_build_objext" >&5
+   ($CC_FOR_BUILD -c conftest.$ac_ext -o conftest2.$ac_build_objext) >&5 2>&5
+   ac_status=$?
+   echo "$as_me:$LINENO: \$? = $ac_status" >&5
+   (exit $ac_status); } \
+         && test -f conftest2.$ac_build_objext; then
+      : OK
+    else
+      am_cv_build_prog_cc_c_o=no
+      break
+    fi
+  done
+  rm -f core conftest*
+  unset am_i
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $am_cv_build_prog_cc_c_o" >&5
+$as_echo "$am_cv_build_prog_cc_c_o" >&6; }
+if test "$am_cv_build_prog_cc_c_o" != yes; then
+   # Losing compiler, so override with the script.
+   # FIXME: It is wrong to rewrite CC.
+   # But if we don't then we get into trouble of one sort or another.
+   # A longer-term fix would be to have automake use am__CC in this case,
+   # and then we could set am__CC="\$(top_srcdir)/compile \$(CC)"
+   CC_FOR_BUILD="$am_aux_dir/compile $CC_FOR_BUILD"
+fi
+ac_ext=c
+ac_cpp='$CPP_FOR_BUILD $CPPFLAGS_FOR_BUILD'
+ac_compile='$CC_FOR_BUILD -c $CFLAGS_FOR_BUILD $CPPFLAGS_FOR_BUILD conftest.$ac_ext >&5'
+ac_link='$CC_FOR_BUILD -o conftest$ac_build_exeext $CFLAGS_FOR_BUILD $CPPFLAGS_FOR_BUILD $LDFLAGS_FOR_BUILD conftest.$ac_ext $LIBS >&5'
+ac_compiler_gnu=$ac_cv_c_compiler_gnu
+
+
+depcc="$CC_FOR_BUILD"   am_compiler_list=
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking dependency style of $depcc" >&5
+$as_echo_n "checking dependency style of $depcc... " >&6; }
+if ${am_cv_build_CC_dependencies_compiler_type+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  if test -z "$AMDEP_TRUE" && test -f "$am_depcomp"; then
+  # We make a subdir and do the tests there.  Otherwise we can end up
+  # making bogus files that we don't know about and never remove.  For
+  # instance it was reported that on HP-UX the gcc test will end up
+  # making a dummy file named 'D' -- because '-MD' means "put the output
+  # in D".
+  rm -rf conftest.dir
+  mkdir conftest.dir
+  # Copy depcomp to subdir because otherwise we won't find it if we're
+  # using a relative directory.
+  cp "$am_depcomp" conftest.dir
+  cd conftest.dir
+  # We will build objects and dependencies in a subdirectory because
+  # it helps to detect inapplicable dependency modes.  For instance
+  # both Tru64's cc and ICC support -MD to output dependencies as a
+  # side effect of compilation, but ICC will put the dependencies in
+  # the current directory while Tru64 will put them in the object
+  # directory.
+  mkdir sub
+
+  am_cv_build_CC_dependencies_compiler_type=none
+  if test "$am_compiler_list" = ""; then
+     am_compiler_list=`sed -n 's/^#*\([a-zA-Z0-9]*\))$/\1/p' < ./depcomp`
+  fi
+  am__universal=false
+  case " $depcc " in #(
+     *\ -arch\ *\ -arch\ *) am__universal=true ;;
+     esac
+
+  for depmode in $am_compiler_list; do
+    # Setup a source with many dependencies, because some compilers
+    # like to wrap large dependency lists on column 80 (with \), and
+    # we should not choose a depcomp mode which is confused by this.
+    #
+    # We need to recreate these files for each test, as the compiler may
+    # overwrite some of them when testing with obscure command lines.
+    # This happens at least with the AIX C compiler.
+    : > sub/conftest.c
+    for i in 1 2 3 4 5 6; do
+      echo '#include "conftst'$i'.h"' >> sub/conftest.c
+      # Using ": > sub/conftst$i.h" creates only sub/conftst1.h with
+      # Solaris 10 /bin/sh.
+      echo '/* dummy */' > sub/conftst$i.h
+    done
+    echo "${am__include} ${am__quote}sub/conftest.Po${am__quote}" > confmf
+
+    # We check with '-c' and '-o' for the sake of the "dashmstdout"
+    # mode.  It turns out that the SunPro C++ compiler does not properly
+    # handle '-M -o', and we need to detect this.  Also, some Intel
+    # versions had trouble with output in subdirs.
+    am__obj=sub/conftest.${OBJEXT-o}
+    am__minus_obj="-o $am__obj"
+    case $depmode in
+    gcc)
+      # This depmode causes a compiler race in universal mode.
+      test "$am__universal" = false || continue
+      ;;
+    nosideeffect)
+      # After this tag, mechanisms are not by side-effect, so they'll
+      # only be used when explicitly requested.
+      if test "x$enable_dependency_tracking" = xyes; then
+	continue
+      else
+	break
+      fi
+      ;;
+    msvc7 | msvc7msys | msvisualcpp | msvcmsys)
+      # This compiler won't grok '-c -o', but also, the minuso test has
+      # not run yet.  These depmodes are late enough in the game, and
+      # so weak that their functioning should not be impacted.
+      am__obj=conftest.${OBJEXT-o}
+      am__minus_obj=
+      ;;
+    none) break ;;
+    esac
+    if depmode=$depmode \
+       source=sub/conftest.c object=$am__obj \
+       depfile=sub/conftest.Po tmpdepfile=sub/conftest.TPo \
+       $SHELL ./depcomp $depcc -c $am__minus_obj sub/conftest.c \
+         >/dev/null 2>conftest.err &&
+       grep sub/conftst1.h sub/conftest.Po > /dev/null 2>&1 &&
+       grep sub/conftst6.h sub/conftest.Po > /dev/null 2>&1 &&
+       grep $am__obj sub/conftest.Po > /dev/null 2>&1 &&
+       ${MAKE-make} -s -f confmf > /dev/null 2>&1; then
+      # icc doesn't choke on unknown options, it will just issue warnings
+      # or remarks (even with -Werror).  So we grep stderr for any message
+      # that says an option was ignored or not supported.
+      # When given -MP, icc 7.0 and 7.1 complain thusly:
+      #   icc: Command line warning: ignoring option '-M'; no argument required
+      # The diagnosis changed in icc 8.0:
+      #   icc: Command line remark: option '-MP' not supported
+      if (grep 'ignoring option' conftest.err ||
+          grep 'not supported' conftest.err) >/dev/null 2>&1; then :; else
+        am_cv_build_CC_dependencies_compiler_type=$depmode
+        break
+      fi
+    fi
+  done
+
+  cd ..
+  rm -rf conftest.dir
+else
+  am_cv_build_CC_dependencies_compiler_type=none
+fi
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $am_cv_build_CC_dependencies_compiler_type" >&5
+$as_echo "$am_cv_build_CC_dependencies_compiler_type" >&6; }
+CCDEPMODE=depmode=$am_cv_build_CC_dependencies_compiler_type
+
+ if
+  test "x$enable_dependency_tracking" != xno \
+  && test "$am_cv_build_CC_dependencies_compiler_type" = gcc3; then
+  am__fastdepCC_TRUE=
+  am__fastdepCC_FALSE='#'
+else
+  am__fastdepCC_TRUE='#'
+  am__fastdepCC_FALSE=
+fi
+
+
+ac_ext=c
+ac_cpp='$CPP_FOR_BUILD $CPPFLAGS_FOR_BUILD'
+ac_compile='$CC_FOR_BUILD -c $CFLAGS_FOR_BUILD $CPPFLAGS_FOR_BUILD conftest.$ac_ext >&5'
+ac_link='$CC_FOR_BUILD -o conftest$ac_build_exeext $CFLAGS_FOR_BUILD $CPPFLAGS_FOR_BUILD $LDFLAGS_FOR_BUILD conftest.$ac_ext $LIBS >&5'
+ac_compiler_gnu=$ac_cv_c_compiler_gnu
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking how to run the C preprocessor" >&5
+$as_echo_n "checking how to run the C preprocessor... " >&6; }
+# On Suns, sometimes $CPP names a directory.
+if test -n "$CPP_FOR_BUILD" && test -d "$CPP_FOR_BUILD"; then
+  CPP_FOR_BUILD=
+fi
+if test -z "$CPP_FOR_BUILD"; then
+  if ${ac_cv_build_prog_CPP+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+      # Double quotes because CPP needs to be expanded
+    for CPP_FOR_BUILD in "$CC_FOR_BUILD -E" "$CC_FOR_BUILD -E -traditional-cpp" "/lib/cpp"
+    do
+      ac_preproc_ok=false
+for ac_c_preproc_warn_flag in '' yes
+do
+  # Use a header file that comes with gcc, so configuring glibc
+  # with a fresh cross-compiler works.
+  # Prefer <limits.h> to <assert.h> if __STDC__ is defined, since
+  # <limits.h> exists even on freestanding compilers.
+  # On the NeXT, cc -E runs the code through the compiler's parser,
+  # not just through cpp. "Syntax error" is here to catch this case.
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+#ifdef __STDC__
+# include <limits.h>
+#else
+# include <assert.h>
+#endif
+		     Syntax error
+_ACEOF
+if ac_fn_c_try_cpp "$LINENO"; then :
+
+else
+  # Broken: fails on valid input.
+continue
+fi
+rm -f conftest.err conftest.i conftest.$ac_ext
+
+  # OK, works on sane cases.  Now check whether nonexistent headers
+  # can be detected and how.
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+#include <ac_nonexistent.h>
+_ACEOF
+if ac_fn_c_try_cpp "$LINENO"; then :
+  # Broken: success on invalid input.
+continue
+else
+  # Passes both tests.
+ac_preproc_ok=:
+break
+fi
+rm -f conftest.err conftest.i conftest.$ac_ext
+
+done
+# Because of `break', _AC_PREPROC_IFELSE's cleaning code was skipped.
+rm -f conftest.i conftest.err conftest.$ac_ext
+if $ac_preproc_ok; then :
+  break
+fi
+
+    done
+    ac_cv_build_prog_CPP=$CPP_FOR_BUILD
+
+fi
+  CPP_FOR_BUILD=$ac_cv_build_prog_CPP
+else
+  ac_cv_build_prog_CPP=$CPP_FOR_BUILD
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $CPP_FOR_BUILD" >&5
+$as_echo "$CPP_FOR_BUILD" >&6; }
+ac_preproc_ok=false
+for ac_c_preproc_warn_flag in '' yes
+do
+  # Use a header file that comes with gcc, so configuring glibc
+  # with a fresh cross-compiler works.
+  # Prefer <limits.h> to <assert.h> if __STDC__ is defined, since
+  # <limits.h> exists even on freestanding compilers.
+  # On the NeXT, cc -E runs the code through the compiler's parser,
+  # not just through cpp. "Syntax error" is here to catch this case.
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+#ifdef __STDC__
+# include <limits.h>
+#else
+# include <assert.h>
+#endif
+		     Syntax error
+_ACEOF
+if ac_fn_c_try_cpp "$LINENO"; then :
+
+else
+  # Broken: fails on valid input.
+continue
+fi
+rm -f conftest.err conftest.i conftest.$ac_ext
+
+  # OK, works on sane cases.  Now check whether nonexistent headers
+  # can be detected and how.
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+#include <ac_nonexistent.h>
+_ACEOF
+if ac_fn_c_try_cpp "$LINENO"; then :
+  # Broken: success on invalid input.
+continue
+else
+  # Passes both tests.
+ac_preproc_ok=:
+break
+fi
+rm -f conftest.err conftest.i conftest.$ac_ext
+
+done
+# Because of `break', _AC_PREPROC_IFELSE's cleaning code was skipped.
+rm -f conftest.i conftest.err conftest.$ac_ext
+if $ac_preproc_ok; then :
+
+else
+  { { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
+$as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
+as_fn_error $? "C preprocessor \"$CPP_FOR_BUILD\" fails sanity check
+See \`config.log' for more details" "$LINENO" 5; }
+fi
+
+ac_ext=c
+ac_cpp='$CPP_FOR_BUILD $CPPFLAGS_FOR_BUILD'
+ac_compile='$CC_FOR_BUILD -c $CFLAGS_FOR_BUILD $CPPFLAGS_FOR_BUILD conftest.$ac_ext >&5'
+ac_link='$CC_FOR_BUILD -o conftest$ac_build_exeext $CFLAGS_FOR_BUILD $CPPFLAGS_FOR_BUILD $LDFLAGS_FOR_BUILD conftest.$ac_ext $LIBS >&5'
+ac_compiler_gnu=$ac_cv_c_compiler_gnu
+
+
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD is fresh enough for -Werror" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD is fresh enough for -Werror... " >&6; }
+if ${st_cv_build_cc_enable_Werror+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+#if defined __GNUC__ && defined __GNUC_MINOR__
+# define GNUC_PREREQ(maj, min) ((__GNUC__ << 16) + __GNUC_MINOR__ >= ((maj) << 16) + (min))
+#else
+# define GNUC_PREREQ(maj, min) 0
+#endif
+
+#if defined __clang__ && defined __clang_major__ && defined __clang_minor__
+# define CLANG_PREREQ(maj, min) ((__clang_major__ << 16) + __clang_minor__ >= ((maj) << 16) + (min))
+#else
+# define CLANG_PREREQ(maj, min) 0
+#endif
+
+int
+main ()
+{
+int i[GNUC_PREREQ(4, 8) + CLANG_PREREQ(6, 0) > 0 ? 1 : - 1];
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_compile "$LINENO"; then :
+  st_cv_build_cc_enable_Werror=yes
+else
+  st_cv_build_cc_enable_Werror=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext conftest.$ac_ext
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $st_cv_build_cc_enable_Werror" >&5
+$as_echo "$st_cv_build_cc_enable_Werror" >&6; }
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether to try $CC_FOR_BUILD with -Werror by default" >&5
+$as_echo_n "checking whether to try $CC_FOR_BUILD with -Werror by default... " >&6; }
+if ${st_cv_build_enable_Werror+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  if test "$st_cv_build_cc_enable_Werror" != yes; then
+		  st_cv_build_enable_Werror='no, the compiler is too old'
+		elif test "$arch_enable_Werror" != yes; then
+		  st_cv_build_enable_Werror='no, architecture is not ready'
+		else
+		  st_cv_build_enable_Werror=yes
+		fi
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $st_cv_build_enable_Werror" >&5
+$as_echo "$st_cv_build_enable_Werror" >&6; }
+if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
+  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_build_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Wall" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Wall... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Wall+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Wall"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Wall=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Wall=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Wall" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Wall" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Wall" = xyes; then :
+  as_fn_append WARN_CFLAGS_FOR_BUILD " -Wall"
+fi
+
+
+if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
+  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_build_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Wempty-body" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Wempty-body... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Wempty_body+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Wempty-body"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Wempty_body=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Wempty_body=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Wempty_body" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Wempty_body" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Wempty_body" = xyes; then :
+  as_fn_append WARN_CFLAGS_FOR_BUILD " -Wempty-body"
+fi
+
+
+if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
+  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_build_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Wformat-security" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Wformat-security... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Wformat_security+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Wformat-security"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Wformat_security=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Wformat_security=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Wformat_security" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Wformat_security" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Wformat_security" = xyes; then :
+  as_fn_append WARN_CFLAGS_FOR_BUILD " -Wformat-security"
+fi
+
+
+if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
+  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_build_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Wignored-qualifiers" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Wignored-qualifiers... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Wignored_qualifiers+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Wignored-qualifiers"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Wignored_qualifiers=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Wignored_qualifiers=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Wignored_qualifiers" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Wignored_qualifiers" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Wignored_qualifiers" = xyes; then :
+  as_fn_append WARN_CFLAGS_FOR_BUILD " -Wignored-qualifiers"
+fi
+
+
+if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
+  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_build_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Wimplicit-fallthrough=5" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Wimplicit-fallthrough=5... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Wimplicit_fallthrough_5+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Wimplicit-fallthrough=5"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Wimplicit_fallthrough_5=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Wimplicit_fallthrough_5=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Wimplicit_fallthrough_5" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Wimplicit_fallthrough_5" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Wimplicit_fallthrough_5" = xyes; then :
+  as_fn_append WARN_CFLAGS_FOR_BUILD " -Wimplicit-fallthrough=5"
+fi
+
+
+if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
+  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_build_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Winit-self" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Winit-self... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Winit_self+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Winit-self"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Winit_self=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Winit_self=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Winit_self" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Winit_self" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Winit_self" = xyes; then :
+  as_fn_append WARN_CFLAGS_FOR_BUILD " -Winit-self"
+fi
+
+
+if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
+  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_build_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Winitializer-overrides" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Winitializer-overrides... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Winitializer_overrides+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Winitializer-overrides"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Winitializer_overrides=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Winitializer_overrides=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Winitializer_overrides" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Winitializer_overrides" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Winitializer_overrides" = xyes; then :
+  as_fn_append WARN_CFLAGS_FOR_BUILD " -Winitializer-overrides"
+fi
+
+
+if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
+  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_build_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Wlogical-op" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Wlogical-op... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Wlogical_op+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Wlogical-op"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Wlogical_op=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Wlogical_op=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Wlogical_op" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Wlogical_op" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Wlogical_op" = xyes; then :
+  as_fn_append WARN_CFLAGS_FOR_BUILD " -Wlogical-op"
+fi
+
+
+if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
+  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_build_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Wmissing-parameter-type" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Wmissing-parameter-type... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Wmissing_parameter_type+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Wmissing-parameter-type"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Wmissing_parameter_type=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Wmissing_parameter_type=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Wmissing_parameter_type" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Wmissing_parameter_type" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Wmissing_parameter_type" = xyes; then :
+  as_fn_append WARN_CFLAGS_FOR_BUILD " -Wmissing-parameter-type"
+fi
+
+
+if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
+  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_build_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Wnested-externs" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Wnested-externs... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Wnested_externs+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Wnested-externs"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Wnested_externs=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Wnested_externs=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Wnested_externs" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Wnested_externs" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Wnested_externs" = xyes; then :
+  as_fn_append WARN_CFLAGS_FOR_BUILD " -Wnested-externs"
+fi
+
+
+if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
+  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_build_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Wold-style-declaration" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Wold-style-declaration... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Wold_style_declaration+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Wold-style-declaration"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Wold_style_declaration=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Wold_style_declaration=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Wold_style_declaration" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Wold_style_declaration" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Wold_style_declaration" = xyes; then :
+  as_fn_append WARN_CFLAGS_FOR_BUILD " -Wold-style-declaration"
+fi
+
+
+if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
+  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_build_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Wold-style-definition" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Wold-style-definition... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Wold_style_definition+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Wold-style-definition"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Wold_style_definition=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Wold_style_definition=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Wold_style_definition" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Wold_style_definition" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Wold_style_definition" = xyes; then :
+  as_fn_append WARN_CFLAGS_FOR_BUILD " -Wold-style-definition"
+fi
+
+
+if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
+  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_build_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Woverride-init" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Woverride-init... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Woverride_init+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Woverride-init"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Woverride_init=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Woverride_init=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Woverride_init" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Woverride_init" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Woverride_init" = xyes; then :
+  as_fn_append WARN_CFLAGS_FOR_BUILD " -Woverride-init"
+fi
+
+
+if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
+  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_build_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Wsign-compare" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Wsign-compare... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Wsign_compare+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Wsign-compare"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Wsign_compare=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Wsign_compare=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Wsign_compare" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Wsign_compare" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Wsign_compare" = xyes; then :
+  as_fn_append WARN_CFLAGS_FOR_BUILD " -Wsign-compare"
+fi
+
+
+if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
+  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_build_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Wtype-limits" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Wtype-limits... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Wtype_limits+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Wtype-limits"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Wtype_limits=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Wtype_limits=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Wtype_limits" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Wtype_limits" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Wtype_limits" = xyes; then :
+  as_fn_append WARN_CFLAGS_FOR_BUILD " -Wtype-limits"
+fi
+
+
+if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
+  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_build_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Wwrite-strings" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Wwrite-strings... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Wwrite_strings+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Wwrite-strings"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Wwrite_strings=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Wwrite_strings=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Wwrite_strings" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Wwrite_strings" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Wwrite_strings" = xyes; then :
+  as_fn_append WARN_CFLAGS_FOR_BUILD " -Wwrite-strings"
+fi
+
+
+# Check whether --enable-gcc-Werror was given.
+if test "${enable_gcc_Werror+set}" = set; then :
+  enableval=$enable_gcc_Werror; case "$enable_gcc_Werror" in
+		yes|no|no,*) ;;
+		*) as_fn_error $? "bad value $enable_gcc_Werror for gcc-Werror option" "$LINENO" 5 ;;
+	       esac
+else
+  enable_gcc_Werror="$st_cv_build_enable_Werror"
+fi
+
+if test "$enable_gcc_Werror" = yes; then
+  if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
+  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
+else
+  gl_build_unknown_warnings_are_errors=
+fi
+
+
+fi
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror" >&5
+$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror... " >&6; }
+if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+
+  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
+  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror"
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_link "$LINENO"; then :
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror=yes
+else
+  gl_cv_warn_CFLAGS_FOR_BUILD__Werror=no
+fi
+rm -f core conftest.err conftest.$ac_build_objext \
+    conftest$ac_build_exeext conftest.$ac_ext
+  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror" >&5
+$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror" >&6; }
+if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror" = xyes; then :
+  as_fn_append WARN_CFLAGS_FOR_BUILD " -Werror"
+fi
+
+
+fi
+
+
+
+if test -n "${st_saved_cross_compiling+set}"; then :
+  cross_compiling="${st_saved_cross_compiling}"; unset st_saved_cross_compiling
+fi
+
+if test -n "${st_saved_ac_tool_prefix+set}"; then :
+  ac_tool_prefix="${st_saved_ac_tool_prefix}"; unset st_saved_ac_tool_prefix
+fi
+
+if test -n "${st_saved_ac_link+set}"; then :
+  ac_link="${st_saved_ac_link}"; unset st_saved_ac_link
+fi
+
+if test -n "${st_saved_ac_cv_c_decl_report+set}"; then :
+  ac_cv_c_decl_report="${st_saved_ac_cv_c_decl_report}"; unset st_saved_ac_cv_c_decl_report
+fi
+
+if test -n "${st_saved_ac_cv_c_compiler_gnu+set}"; then :
+  ac_cv_c_compiler_gnu="${st_saved_ac_cv_c_compiler_gnu}"; unset st_saved_ac_cv_c_compiler_gnu
+fi
+
+if test -n "${st_saved_ac_cpp+set}"; then :
+  ac_cpp="${st_saved_ac_cpp}"; unset st_saved_ac_cpp
+fi
+
+if test -n "${st_saved_ac_compiler_gnu+set}"; then :
+  ac_compiler_gnu="${st_saved_ac_compiler_gnu}"; unset st_saved_ac_compiler_gnu
+fi
+
+if test -n "${st_saved_ac_compile+set}"; then :
+  ac_compile="${st_saved_ac_compile}"; unset st_saved_ac_compile
+fi
+
+if test -n "${st_saved_ac_c_werror_flag+set}"; then :
+  ac_c_werror_flag="${st_saved_ac_c_werror_flag}"; unset st_saved_ac_c_werror_flag
+fi
+
+if test -n "${st_saved_ac_c_preproc_warn_flag+set}"; then :
+  ac_c_preproc_warn_flag="${st_saved_ac_c_preproc_warn_flag}"; unset st_saved_ac_c_preproc_warn_flag
+fi
+
+if test -n "${st_saved_ac_c_decl_warn_flag+set}"; then :
+  ac_c_decl_warn_flag="${st_saved_ac_c_decl_warn_flag}"; unset st_saved_ac_c_decl_warn_flag
+fi
+
+
+
+BUILD_EXEEXT=$ac_build_exeext
+BUILD_OBJEXT=$ac_build_objext
+
+if test -n "$ac_tool_prefix"; then
+  for ac_prog in ar lib "link -lib"
+  do
+    # Extract the first word of "$ac_tool_prefix$ac_prog", so it can be a program name with args.
+set dummy $ac_tool_prefix$ac_prog; ac_word=$2
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+$as_echo_n "checking for $ac_word... " >&6; }
+if ${ac_cv_prog_AR+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  if test -n "$AR"; then
+  ac_cv_prog_AR="$AR" # Let the user override the test.
+else
+as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
+for as_dir in $PATH
+do
+  IFS=$as_save_IFS
+  test -z "$as_dir" && as_dir=.
+    for ac_exec_ext in '' $ac_executable_extensions; do
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+    ac_cv_prog_AR="$ac_tool_prefix$ac_prog"
+    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+    break 2
+  fi
+done
+  done
+IFS=$as_save_IFS
+
+fi
+fi
+AR=$ac_cv_prog_AR
+if test -n "$AR"; then
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $AR" >&5
+$as_echo "$AR" >&6; }
+else
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
+$as_echo "no" >&6; }
+fi
+
+
+    test -n "$AR" && break
+  done
+fi
+if test -z "$AR"; then
+  ac_ct_AR=$AR
+  for ac_prog in ar lib "link -lib"
+do
+  # Extract the first word of "$ac_prog", so it can be a program name with args.
+set dummy $ac_prog; ac_word=$2
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
+$as_echo_n "checking for $ac_word... " >&6; }
+if ${ac_cv_prog_ac_ct_AR+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  if test -n "$ac_ct_AR"; then
+  ac_cv_prog_ac_ct_AR="$ac_ct_AR" # Let the user override the test.
+else
+as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
+for as_dir in $PATH
+do
+  IFS=$as_save_IFS
+  test -z "$as_dir" && as_dir=.
+    for ac_exec_ext in '' $ac_executable_extensions; do
+  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
+    ac_cv_prog_ac_ct_AR="$ac_prog"
+    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
+    break 2
+  fi
+done
+  done
+IFS=$as_save_IFS
+
+fi
+fi
+ac_ct_AR=$ac_cv_prog_ac_ct_AR
+if test -n "$ac_ct_AR"; then
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_ct_AR" >&5
+$as_echo "$ac_ct_AR" >&6; }
+else
+  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
+$as_echo "no" >&6; }
+fi
+
+
+  test -n "$ac_ct_AR" && break
+done
+
+  if test "x$ac_ct_AR" = x; then
+    AR="false"
+  else
+    case $cross_compiling:$ac_tool_warned in
+yes:)
+{ $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: using cross tools not prefixed with host triplet" >&5
+$as_echo "$as_me: WARNING: using cross tools not prefixed with host triplet" >&2;}
+ac_tool_warned=yes ;;
+esac
+    AR=$ac_ct_AR
+  fi
+fi
+
+: ${AR=ar}
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking the archiver ($AR) interface" >&5
+$as_echo_n "checking the archiver ($AR) interface... " >&6; }
+if ${am_cv_ar_interface+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  ac_ext=c
+ac_cpp='$CPP $CPPFLAGS'
+ac_compile='$CC -c $CFLAGS $CPPFLAGS conftest.$ac_ext >&5'
+ac_link='$CC -o conftest$ac_exeext $CFLAGS $CPPFLAGS $LDFLAGS conftest.$ac_ext $LIBS >&5'
+ac_compiler_gnu=$ac_cv_c_compiler_gnu
+
+   am_cv_ar_interface=ar
+   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+int some_variable = 0;
+_ACEOF
+if ac_fn_c_try_compile "$LINENO"; then :
+  am_ar_try='$AR cru libconftest.a conftest.$ac_objext >&5'
+      { { eval echo "\"\$as_me\":${as_lineno-$LINENO}: \"$am_ar_try\""; } >&5
+  (eval $am_ar_try) 2>&5
+  ac_status=$?
+  $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
+  test $ac_status = 0; }
+      if test "$ac_status" -eq 0; then
+        am_cv_ar_interface=ar
+      else
+        am_ar_try='$AR -NOLOGO -OUT:conftest.lib conftest.$ac_objext >&5'
+        { { eval echo "\"\$as_me\":${as_lineno-$LINENO}: \"$am_ar_try\""; } >&5
+  (eval $am_ar_try) 2>&5
+  ac_status=$?
+  $as_echo "$as_me:${as_lineno-$LINENO}: \$? = $ac_status" >&5
+  test $ac_status = 0; }
+        if test "$ac_status" -eq 0; then
+          am_cv_ar_interface=lib
+        else
+          am_cv_ar_interface=unknown
+        fi
+      fi
+      rm -f conftest.lib libconftest.a
+
+fi
+rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+   ac_ext=c
+ac_cpp='$CPP $CPPFLAGS'
+ac_compile='$CC -c $CFLAGS $CPPFLAGS conftest.$ac_ext >&5'
+ac_link='$CC -o conftest$ac_exeext $CFLAGS $CPPFLAGS $LDFLAGS conftest.$ac_ext $LIBS >&5'
+ac_compiler_gnu=$ac_cv_c_compiler_gnu
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $am_cv_ar_interface" >&5
+$as_echo "$am_cv_ar_interface" >&6; }
+
+case $am_cv_ar_interface in
+ar)
+  ;;
+lib)
+  # Microsoft lib, so override with the ar-lib wrapper script.
+  # FIXME: It is wrong to rewrite AR.
+  # But if we don't then we get into trouble of one sort or another.
+  # A longer-term fix would be to have automake use am__AR in this case,
+  # and then we could set am__AR="$am_aux_dir/ar-lib \$(AR)" or something
+  # similar.
+  AR="$am_aux_dir/ar-lib $AR"
+  ;;
+unknown)
+  as_fn_error $? "could not determine $AR interface" "$LINENO" 5
+  ;;
+esac
+
+
+
+  { $as_echo "$as_me:${as_lineno-$LINENO}: checking for typeof syntax and keyword spelling" >&5
+$as_echo_n "checking for typeof syntax and keyword spelling... " >&6; }
+if ${ac_cv_c_typeof+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  ac_cv_c_typeof=no
+     for ac_kw in typeof __typeof__ no; do
+       test $ac_kw = no && break
+       cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+
+int
+main ()
+{
+
+	   int value;
+	   typedef struct {
+		   char a [1
+			   + ! (($ac_kw (value))
+				(($ac_kw (value)) 0 < ($ac_kw (value)) -1
+				 ? ($ac_kw (value)) - 1
+				 : ~ (~ ($ac_kw (value)) 0
+				      << sizeof ($ac_kw (value)))))]; }
+	      ac__typeof_type_;
+	   return
+	     (! ((void) ((ac__typeof_type_ *) 0), 0));
+
+  ;
+  return 0;
+}
+_ACEOF
+if ac_fn_c_try_compile "$LINENO"; then :
+  ac_cv_c_typeof=$ac_kw
+fi
+rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+       test $ac_cv_c_typeof != no && break
+     done
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_c_typeof" >&5
+$as_echo "$ac_cv_c_typeof" >&6; }
+  if test $ac_cv_c_typeof != no; then
+
+$as_echo "#define HAVE_TYPEOF 1" >>confdefs.h
+
+    if test $ac_cv_c_typeof != typeof; then
+
+cat >>confdefs.h <<_ACEOF
+#define typeof $ac_cv_c_typeof
+_ACEOF
+
+    fi
+  fi
+
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for uid_t in sys/types.h" >&5
+$as_echo_n "checking for uid_t in sys/types.h... " >&6; }
+if ${ac_cv_type_uid_t+:} false; then :
+  $as_echo_n "(cached) " >&6
+else
+  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
+/* end confdefs.h.  */
+#include <sys/types.h>
+
+_ACEOF
+if (eval "$ac_cpp conftest.$ac_ext") 2>&5 |
+  $EGREP "uid_t" >/dev/null 2>&1; then :
+  ac_cv_type_uid_t=yes
+else
+  ac_cv_type_uid_t=no
+fi
+rm -f conftest*
+
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_type_uid_t" >&5
+$as_echo "$ac_cv_type_uid_t" >&6; }
+if test $ac_cv_type_uid_t = no; then
+
+$as_echo "#define uid_t int" >>confdefs.h
+
+
+$as_echo "#define gid_t int" >>confdefs.h
+
+fi
+
+
+for ac_func in accept4 be64toh fallocate fanotify_mark fcntl64 fopen64 fork fputs_unlocked fstatat ftruncate futimens iconv_open if_indextoname open64 open_memstream preadv process_vm_readv pwritev readahead signalfd stpcpy strerror strndup sync_file_range
+do :
+  as_ac_var=`$as_echo "ac_cv_func_$ac_func" | $as_tr_sh`
+ac_fn_c_check_func "$LINENO" "$ac_func" "$as_ac_var"
+if eval test \"x\$"$as_ac_var"\" = x"yes"; then :
+  cat >>confdefs.h <<_ACEOF
+#define `$as_echo "HAVE_$ac_func" | $as_tr_cpp` 1
+_ACEOF
+
+fi
+done
+
+
+ac_fn_c_check_type "$LINENO" "sig_atomic_t" "ac_cv_type_sig_atomic_t" "#include <signal.h>
+"
+if test "x$ac_cv_type_sig_atomic_t" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_SIG_ATOMIC_T 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_type "$LINENO" "struct sigcontext" "ac_cv_type_struct_sigcontext" "#include <signal.h>
+"
+if test "x$ac_cv_type_struct_sigcontext" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_SIGCONTEXT 1
+_ACEOF
+
+
+fi
+
+
+ac_fn_c_check_type "$LINENO" "struct mmsghdr" "ac_cv_type_struct_mmsghdr" "#include <sys/socket.h>
+"
+if test "x$ac_cv_type_struct_mmsghdr" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_MMSGHDR 1
+_ACEOF
+
+
+fi
+
+
+ac_fn_c_check_type "$LINENO" "__kernel_long_t" "ac_cv_type___kernel_long_t" "#include <asm/posix_types.h>
+"
+if test "x$ac_cv_type___kernel_long_t" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE___KERNEL_LONG_T 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_type "$LINENO" "__kernel_ulong_t" "ac_cv_type___kernel_ulong_t" "#include <asm/posix_types.h>
+"
+if test "x$ac_cv_type___kernel_ulong_t" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE___KERNEL_ULONG_T 1
+_ACEOF
+
+
+fi
+
+
+ac_fn_c_check_type "$LINENO" "struct __kernel_timespec" "ac_cv_type_struct___kernel_timespec" "#include <linux/time_types.h>
+"
+if test "x$ac_cv_type_struct___kernel_timespec" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT___KERNEL_TIMESPEC 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_type "$LINENO" "struct __kernel_sock_timeval" "ac_cv_type_struct___kernel_sock_timeval" "#include <linux/time_types.h>
+"
+if test "x$ac_cv_type_struct___kernel_sock_timeval" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT___KERNEL_SOCK_TIMEVAL 1
+_ACEOF
+
+
+fi
+
+
+ac_fn_c_check_type "$LINENO" "struct stat64" "ac_cv_type_struct_stat64" "#include <sys/types.h>
+#include <asm/stat.h>
+"
+if test "x$ac_cv_type_struct_stat64" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_STAT64 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_type "$LINENO" "struct __old_kernel_stat" "ac_cv_type_struct___old_kernel_stat" "#include <sys/types.h>
+#include <asm/stat.h>
+"
+if test "x$ac_cv_type_struct___old_kernel_stat" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT___OLD_KERNEL_STAT 1
+_ACEOF
+
+
+fi
+
+
+ac_fn_c_check_type "$LINENO" "struct user_desc" "ac_cv_type_struct_user_desc" "#include <asm/ldt.h>
+"
+if test "x$ac_cv_type_struct_user_desc" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_USER_DESC 1
+_ACEOF
+
+ac_fn_c_check_member "$LINENO" "struct user_desc" "lm" "ac_cv_member_struct_user_desc_lm" "#include <asm/ldt.h>
+"
+if test "x$ac_cv_member_struct_user_desc_lm" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_USER_DESC_LM 1
+_ACEOF
+
+
+fi
+
+fi
+
+
+ac_fn_c_check_member "$LINENO" "struct stat" "st_mtime_nsec" "ac_cv_member_struct_stat_st_mtime_nsec" "#include <sys/types.h>
+#include <asm/stat.h>
+"
+if test "x$ac_cv_member_struct_stat_st_mtime_nsec" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_STAT_ST_MTIME_NSEC 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct stat64" "st_mtime_nsec" "ac_cv_member_struct_stat64_st_mtime_nsec" "#include <sys/types.h>
+#include <asm/stat.h>
+"
+if test "x$ac_cv_member_struct_stat64_st_mtime_nsec" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_STAT64_ST_MTIME_NSEC 1
+_ACEOF
+
+
+fi
+
+
+ac_fn_c_check_type "$LINENO" "struct pt_all_user_regs" "ac_cv_type_struct_pt_all_user_regs" "#include <sys/ptrace.h>
+"
+if test "x$ac_cv_type_struct_pt_all_user_regs" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PT_ALL_USER_REGS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_type "$LINENO" "struct ia64_fpreg" "ac_cv_type_struct_ia64_fpreg" "#include <sys/ptrace.h>
+"
+if test "x$ac_cv_type_struct_ia64_fpreg" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_IA64_FPREG 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_type "$LINENO" "struct ptrace_peeksiginfo_args" "ac_cv_type_struct_ptrace_peeksiginfo_args" "#include <sys/ptrace.h>
+"
+if test "x$ac_cv_type_struct_ptrace_peeksiginfo_args" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PTRACE_PEEKSIGINFO_ARGS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_type "$LINENO" "struct __ptrace_syscall_info" "ac_cv_type_struct___ptrace_syscall_info" "#include <sys/ptrace.h>
+"
+if test "x$ac_cv_type_struct___ptrace_syscall_info" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT___PTRACE_SYSCALL_INFO 1
+_ACEOF
+
+
+fi
+
+
+ac_fn_c_check_type "$LINENO" "struct ptrace_syscall_info" "ac_cv_type_struct_ptrace_syscall_info" "#include <linux/ptrace.h>
+"
+if test "x$ac_cv_type_struct_ptrace_syscall_info" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PTRACE_SYSCALL_INFO 1
+_ACEOF
+
+
+fi
+
+
+# For kernels that do not have v3.10-rc1~201^2~11
+ac_fn_c_check_type "$LINENO" "s390_compat_regs" "ac_cv_type_s390_compat_regs" "#include <asm/ptrace.h>
+"
+if test "x$ac_cv_type_s390_compat_regs" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_S390_COMPAT_REGS 1
+_ACEOF
+
+
+fi
+
+
+ac_fn_c_check_type "$LINENO" "struct flock" "ac_cv_type_struct_flock" "#include <sys/types.h>
+#include <linux/fcntl.h>
+"
+if test "x$ac_cv_type_struct_flock" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_FLOCK 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_type "$LINENO" "struct flock64" "ac_cv_type_struct_flock64" "#include <sys/types.h>
+#include <linux/fcntl.h>
+"
+if test "x$ac_cv_type_struct_flock64" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_FLOCK64 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_type "$LINENO" "struct __kernel_flock" "ac_cv_type_struct___kernel_flock" "#include <sys/types.h>
+#include <linux/fcntl.h>
+"
+if test "x$ac_cv_type_struct___kernel_flock" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT___KERNEL_FLOCK 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_type "$LINENO" "struct __kernel_flock64" "ac_cv_type_struct___kernel_flock64" "#include <sys/types.h>
+#include <linux/fcntl.h>
+"
+if test "x$ac_cv_type_struct___kernel_flock64" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT___KERNEL_FLOCK64 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_type "$LINENO" "struct f_owner_ex" "ac_cv_type_struct_f_owner_ex" "#include <sys/types.h>
+#include <linux/fcntl.h>
+"
+if test "x$ac_cv_type_struct_f_owner_ex" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_F_OWNER_EX 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_type "$LINENO" "struct __kernel_f_owner_ex" "ac_cv_type_struct___kernel_f_owner_ex" "#include <sys/types.h>
+#include <linux/fcntl.h>
+"
+if test "x$ac_cv_type_struct___kernel_f_owner_ex" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT___KERNEL_F_OWNER_EX 1
+_ACEOF
+
+
+fi
+
+
+ac_fn_c_check_type "$LINENO" "struct kcmp_epoll_slot" "ac_cv_type_struct_kcmp_epoll_slot" "#include <linux/kcmp.h>
+"
+if test "x$ac_cv_type_struct_kcmp_epoll_slot" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_KCMP_EPOLL_SLOT 1
+_ACEOF
+
+
+fi
+
+
+ac_fn_c_check_type "$LINENO" "struct keyctl_kdf_params" "ac_cv_type_struct_keyctl_kdf_params" "#include <linux/keyctl.h>
+"
+if test "x$ac_cv_type_struct_keyctl_kdf_params" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_KEYCTL_KDF_PARAMS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_type "$LINENO" "struct keyctl_pkey_params" "ac_cv_type_struct_keyctl_pkey_params" "#include <linux/keyctl.h>
+"
+if test "x$ac_cv_type_struct_keyctl_pkey_params" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_KEYCTL_PKEY_PARAMS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_type "$LINENO" "struct keyctl_pkey_query" "ac_cv_type_struct_keyctl_pkey_query" "#include <linux/keyctl.h>
+"
+if test "x$ac_cv_type_struct_keyctl_pkey_query" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_KEYCTL_PKEY_QUERY 1
+_ACEOF
+
+
+fi
+
+
+ac_fn_c_check_member "$LINENO" "struct utsname" "domainname" "ac_cv_member_struct_utsname_domainname" "#include <sys/utsname.h>
+"
+if test "x$ac_cv_member_struct_utsname_domainname" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_UTSNAME_DOMAINNAME 1
+_ACEOF
+
+
+fi
+
+
+ac_fn_c_check_member "$LINENO" "siginfo_t" "si_syscall" "ac_cv_member_siginfo_t_si_syscall" "#include <signal.h>
+"
+if test "x$ac_cv_member_siginfo_t_si_syscall" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_SIGINFO_T_SI_SYSCALL 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "siginfo_t" "si_timerid" "ac_cv_member_siginfo_t_si_timerid" "#include <signal.h>
+"
+if test "x$ac_cv_member_siginfo_t_si_timerid" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_SIGINFO_T_SI_TIMERID 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "siginfo_t" "si_overrun" "ac_cv_member_siginfo_t_si_overrun" "#include <signal.h>
+"
+if test "x$ac_cv_member_siginfo_t_si_overrun" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_SIGINFO_T_SI_OVERRUN 1
+_ACEOF
+
+
+fi
+
+
+ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "precise_ip" "ac_cv_member_struct_perf_event_attr_precise_ip" "#include <linux/perf_event.h>
+"
+if test "x$ac_cv_member_struct_perf_event_attr_precise_ip" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PERF_EVENT_ATTR_PRECISE_IP 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "mmap_data" "ac_cv_member_struct_perf_event_attr_mmap_data" "#include <linux/perf_event.h>
+"
+if test "x$ac_cv_member_struct_perf_event_attr_mmap_data" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PERF_EVENT_ATTR_MMAP_DATA 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "sample_id_all" "ac_cv_member_struct_perf_event_attr_sample_id_all" "#include <linux/perf_event.h>
+"
+if test "x$ac_cv_member_struct_perf_event_attr_sample_id_all" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PERF_EVENT_ATTR_SAMPLE_ID_ALL 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "exclude_host" "ac_cv_member_struct_perf_event_attr_exclude_host" "#include <linux/perf_event.h>
+"
+if test "x$ac_cv_member_struct_perf_event_attr_exclude_host" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PERF_EVENT_ATTR_EXCLUDE_HOST 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "exclude_guest" "ac_cv_member_struct_perf_event_attr_exclude_guest" "#include <linux/perf_event.h>
+"
+if test "x$ac_cv_member_struct_perf_event_attr_exclude_guest" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PERF_EVENT_ATTR_EXCLUDE_GUEST 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "exclude_callchain_kernel" "ac_cv_member_struct_perf_event_attr_exclude_callchain_kernel" "#include <linux/perf_event.h>
+"
+if test "x$ac_cv_member_struct_perf_event_attr_exclude_callchain_kernel" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PERF_EVENT_ATTR_EXCLUDE_CALLCHAIN_KERNEL 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "exclude_callchain_user" "ac_cv_member_struct_perf_event_attr_exclude_callchain_user" "#include <linux/perf_event.h>
+"
+if test "x$ac_cv_member_struct_perf_event_attr_exclude_callchain_user" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PERF_EVENT_ATTR_EXCLUDE_CALLCHAIN_USER 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "mmap2" "ac_cv_member_struct_perf_event_attr_mmap2" "#include <linux/perf_event.h>
+"
+if test "x$ac_cv_member_struct_perf_event_attr_mmap2" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PERF_EVENT_ATTR_MMAP2 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "comm_exec" "ac_cv_member_struct_perf_event_attr_comm_exec" "#include <linux/perf_event.h>
+"
+if test "x$ac_cv_member_struct_perf_event_attr_comm_exec" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PERF_EVENT_ATTR_COMM_EXEC 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "use_clockid" "ac_cv_member_struct_perf_event_attr_use_clockid" "#include <linux/perf_event.h>
+"
+if test "x$ac_cv_member_struct_perf_event_attr_use_clockid" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PERF_EVENT_ATTR_USE_CLOCKID 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "context_switch" "ac_cv_member_struct_perf_event_attr_context_switch" "#include <linux/perf_event.h>
+"
+if test "x$ac_cv_member_struct_perf_event_attr_context_switch" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PERF_EVENT_ATTR_CONTEXT_SWITCH 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "write_backward" "ac_cv_member_struct_perf_event_attr_write_backward" "#include <linux/perf_event.h>
+"
+if test "x$ac_cv_member_struct_perf_event_attr_write_backward" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PERF_EVENT_ATTR_WRITE_BACKWARD 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "namespaces" "ac_cv_member_struct_perf_event_attr_namespaces" "#include <linux/perf_event.h>
+"
+if test "x$ac_cv_member_struct_perf_event_attr_namespaces" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PERF_EVENT_ATTR_NAMESPACES 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "bp_type" "ac_cv_member_struct_perf_event_attr_bp_type" "#include <linux/perf_event.h>
+"
+if test "x$ac_cv_member_struct_perf_event_attr_bp_type" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PERF_EVENT_ATTR_BP_TYPE 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "config1" "ac_cv_member_struct_perf_event_attr_config1" "#include <linux/perf_event.h>
+"
+if test "x$ac_cv_member_struct_perf_event_attr_config1" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PERF_EVENT_ATTR_CONFIG1 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "config2" "ac_cv_member_struct_perf_event_attr_config2" "#include <linux/perf_event.h>
+"
+if test "x$ac_cv_member_struct_perf_event_attr_config2" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PERF_EVENT_ATTR_CONFIG2 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "branch_sample_type" "ac_cv_member_struct_perf_event_attr_branch_sample_type" "#include <linux/perf_event.h>
+"
+if test "x$ac_cv_member_struct_perf_event_attr_branch_sample_type" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PERF_EVENT_ATTR_BRANCH_SAMPLE_TYPE 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "sample_regs_user" "ac_cv_member_struct_perf_event_attr_sample_regs_user" "#include <linux/perf_event.h>
+"
+if test "x$ac_cv_member_struct_perf_event_attr_sample_regs_user" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PERF_EVENT_ATTR_SAMPLE_REGS_USER 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "sample_stack_user" "ac_cv_member_struct_perf_event_attr_sample_stack_user" "#include <linux/perf_event.h>
+"
+if test "x$ac_cv_member_struct_perf_event_attr_sample_stack_user" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PERF_EVENT_ATTR_SAMPLE_STACK_USER 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "sample_regs_intr" "ac_cv_member_struct_perf_event_attr_sample_regs_intr" "#include <linux/perf_event.h>
+"
+if test "x$ac_cv_member_struct_perf_event_attr_sample_regs_intr" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PERF_EVENT_ATTR_SAMPLE_REGS_INTR 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "aux_watermark" "ac_cv_member_struct_perf_event_attr_aux_watermark" "#include <linux/perf_event.h>
+"
+if test "x$ac_cv_member_struct_perf_event_attr_aux_watermark" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PERF_EVENT_ATTR_AUX_WATERMARK 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "sample_max_stack" "ac_cv_member_struct_perf_event_attr_sample_max_stack" "#include <linux/perf_event.h>
+"
+if test "x$ac_cv_member_struct_perf_event_attr_sample_max_stack" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PERF_EVENT_ATTR_SAMPLE_MAX_STACK 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "aux_sample_size" "ac_cv_member_struct_perf_event_attr_aux_sample_size" "#include <linux/perf_event.h>
+"
+if test "x$ac_cv_member_struct_perf_event_attr_aux_sample_size" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PERF_EVENT_ATTR_AUX_SAMPLE_SIZE 1
+_ACEOF
+
+
+fi
+
+
+for ac_header in asm/cachectl.h asm/guarded_storage.h asm/sysmips.h elf.h gcov.h iconv.h mqueue.h netinet/sctp.h netipx/ipx.h paths.h scsi/sg.h sys/eventfd.h sys/fanotify.h sys/ipc.h sys/quota.h sys/signalfd.h sys/xattr.h ustat.h
+do :
+  as_ac_Header=`$as_echo "ac_cv_header_$ac_header" | $as_tr_sh`
+ac_fn_c_check_header_mongrel "$LINENO" "$ac_header" "$as_ac_Header" "$ac_includes_default"
+if eval test \"x\$"$as_ac_Header"\" = x"yes"; then :
+  cat >>confdefs.h <<_ACEOF
+#define `$as_echo "HAVE_$ac_header" | $as_tr_cpp` 1
+_ACEOF
+
+fi
+
+done
+
+
+for ac_header in linux/bsg.h linux/close_range.h linux/dm-ioctl.h linux/dqblk_xfs.h linux/falloc.h linux/fib_rules.h linux/fiemap.h linux/hiddev.h linux/ip_vs.h linux/ipc.h linux/kcmp.h linux/kvm.h linux/memfd.h linux/mmtimer.h linux/mount.h linux/mqueue.h linux/netfilter/ipset/ip_set.h linux/netfilter/nf_tables.h linux/netfilter/nf_tables_compat.h linux/netfilter/nfnetlink.h linux/netfilter/nfnetlink_acct.h linux/netfilter/nfnetlink_conntrack.h linux/netfilter/nfnetlink_cthelper.h linux/netfilter/nfnetlink_cttimeout.h linux/netfilter/nfnetlink_log.h linux/netfilter/nfnetlink_queue.h linux/nsfs.h linux/openat2.h linux/perf_event.h linux/quota.h linux/sched.h linux/seccomp.h linux/securebits.h linux/tee.h linux/userfaultfd.h linux/utsname.h
+do :
+  as_ac_Header=`$as_echo "ac_cv_header_$ac_header" | $as_tr_sh`
+ac_fn_c_check_header_compile "$LINENO" "$ac_header" "$as_ac_Header" "$ac_includes_default
+#include <linux/types.h>
+
+"
+if eval test \"x\$"$as_ac_Header"\" = x"yes"; then :
+  cat >>confdefs.h <<_ACEOF
+#define `$as_echo "HAVE_$ac_header" | $as_tr_cpp` 1
+_ACEOF
+
+fi
+
+done
+
+
+for ac_header in linux/if_addr.h linux/if_link.h linux/neighbour.h
+do :
+  as_ac_Header=`$as_echo "ac_cv_header_$ac_header" | $as_tr_sh`
+ac_fn_c_check_header_compile "$LINENO" "$ac_header" "$as_ac_Header" "$ac_includes_default
+#include <sys/socket.h>
+#include <linux/types.h>
+
+"
+if eval test \"x\$"$as_ac_Header"\" = x"yes"; then :
+  cat >>confdefs.h <<_ACEOF
+#define `$as_echo "HAVE_$ac_header" | $as_tr_cpp` 1
+_ACEOF
+
+fi
+
+done
+
+
+for ac_header in asm/sigcontext.h
+do :
+  ac_fn_c_check_header_compile "$LINENO" "asm/sigcontext.h" "ac_cv_header_asm_sigcontext_h" "#include <signal.h>
+"
+if test "x$ac_cv_header_asm_sigcontext_h" = xyes; then :
+  cat >>confdefs.h <<_ACEOF
+#define HAVE_ASM_SIGCONTEXT_H 1
+_ACEOF
+
+fi
+
+done
+
+
+for ac_header in netinet/tcp.h netinet/udp.h
+do :
+  as_ac_Header=`$as_echo "ac_cv_header_$ac_header" | $as_tr_sh`
+ac_fn_c_check_header_compile "$LINENO" "$ac_header" "$as_ac_Header" "#include <netinet/in.h>
+"
+if eval test \"x\$"$as_ac_Header"\" = x"yes"; then :
+  cat >>confdefs.h <<_ACEOF
+#define `$as_echo "HAVE_$ac_header" | $as_tr_cpp` 1
+_ACEOF
+
+fi
+
+done
+
+
+for ac_header in linux/netfilter/xt_osf.h
+do :
+  ac_fn_c_check_header_compile "$LINENO" "linux/netfilter/xt_osf.h" "ac_cv_header_linux_netfilter_xt_osf_h" "#include <linux/ip.h>
+#include <linux/tcp.h>
+"
+if test "x$ac_cv_header_linux_netfilter_xt_osf_h" = xyes; then :
+  cat >>confdefs.h <<_ACEOF
+#define HAVE_LINUX_NETFILTER_XT_OSF_H 1
+_ACEOF
+
+fi
+
+done
+
+
+for ac_header in linux/netfilter_arp/arp_tables.h linux/netfilter_bridge/ebtables.h linux/netfilter_ipv4/ip_tables.h linux/netfilter_ipv6/ip6_tables.h
+do :
+  as_ac_Header=`$as_echo "ac_cv_header_$ac_header" | $as_tr_sh`
+ac_fn_c_check_header_compile "$LINENO" "$ac_header" "$as_ac_Header" "#include <netinet/in.h>
+#include <net/if.h>
+"
+if eval test \"x\$"$as_ac_Header"\" = x"yes"; then :
+  cat >>confdefs.h <<_ACEOF
+#define `$as_echo "HAVE_$ac_header" | $as_tr_cpp` 1
+_ACEOF
+
+fi
+
+done
+
+
+for ac_header in linux/bpf.h
+do :
+  ac_fn_c_check_header_mongrel "$LINENO" "linux/bpf.h" "ac_cv_header_linux_bpf_h" "$ac_includes_default"
+if test "x$ac_cv_header_linux_bpf_h" = xyes; then :
+  cat >>confdefs.h <<_ACEOF
+#define HAVE_LINUX_BPF_H 1
+_ACEOF
+
+	ac_fn_c_check_type "$LINENO" "struct bpf_insn" "ac_cv_type_struct_bpf_insn" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_type_struct_bpf_insn" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_INSN 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_type "$LINENO" "struct bpf_map_info" "ac_cv_type_struct_bpf_map_info" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_type_struct_bpf_map_info" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_MAP_INFO 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_type "$LINENO" "struct bpf_prog_info" "ac_cv_type_struct_bpf_prog_info" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_type_struct_bpf_prog_info" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO 1
+_ACEOF
+
+
+fi
+
+		ac_fn_c_check_member "$LINENO" "struct bpf_map_info" "btf_id" "ac_cv_member_struct_bpf_map_info_btf_id" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_map_info_btf_id" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_MAP_INFO_BTF_ID 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_map_info" "btf_key_type_id" "ac_cv_member_struct_bpf_map_info_btf_key_type_id" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_map_info_btf_key_type_id" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_MAP_INFO_BTF_KEY_TYPE_ID 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_map_info" "btf_value_type_id" "ac_cv_member_struct_bpf_map_info_btf_value_type_id" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_map_info_btf_value_type_id" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_MAP_INFO_BTF_VALUE_TYPE_ID 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_map_info" "btf_vmlinux_value_type_id" "ac_cv_member_struct_bpf_map_info_btf_vmlinux_value_type_id" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_map_info_btf_vmlinux_value_type_id" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_MAP_INFO_BTF_VMLINUX_VALUE_TYPE_ID 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_map_info" "id" "ac_cv_member_struct_bpf_map_info_id" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_map_info_id" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_MAP_INFO_ID 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_map_info" "ifindex" "ac_cv_member_struct_bpf_map_info_ifindex" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_map_info_ifindex" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_MAP_INFO_IFINDEX 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_map_info" "key_size" "ac_cv_member_struct_bpf_map_info_key_size" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_map_info_key_size" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_MAP_INFO_KEY_SIZE 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_map_info" "map_flags" "ac_cv_member_struct_bpf_map_info_map_flags" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_map_info_map_flags" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_MAP_INFO_MAP_FLAGS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_map_info" "max_entries" "ac_cv_member_struct_bpf_map_info_max_entries" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_map_info_max_entries" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_MAP_INFO_MAX_ENTRIES 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_map_info" "name" "ac_cv_member_struct_bpf_map_info_name" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_map_info_name" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_MAP_INFO_NAME 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_map_info" "type" "ac_cv_member_struct_bpf_map_info_type" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_map_info_type" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_MAP_INFO_TYPE 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_map_info" "value_size" "ac_cv_member_struct_bpf_map_info_value_size" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_map_info_value_size" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_MAP_INFO_VALUE_SIZE 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "btf_id" "ac_cv_member_struct_bpf_prog_info_btf_id" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_btf_id" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_BTF_ID 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "created_by_uid" "ac_cv_member_struct_bpf_prog_info_created_by_uid" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_created_by_uid" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_CREATED_BY_UID 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "func_info" "ac_cv_member_struct_bpf_prog_info_func_info" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_func_info" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_FUNC_INFO 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "func_info_rec_size" "ac_cv_member_struct_bpf_prog_info_func_info_rec_size" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_func_info_rec_size" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_FUNC_INFO_REC_SIZE 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "id" "ac_cv_member_struct_bpf_prog_info_id" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_id" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_ID 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "ifindex" "ac_cv_member_struct_bpf_prog_info_ifindex" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_ifindex" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_IFINDEX 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "jited_func_lens" "ac_cv_member_struct_bpf_prog_info_jited_func_lens" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_jited_func_lens" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_JITED_FUNC_LENS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "jited_ksyms" "ac_cv_member_struct_bpf_prog_info_jited_ksyms" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_jited_ksyms" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_JITED_KSYMS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "jited_line_info" "ac_cv_member_struct_bpf_prog_info_jited_line_info" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_jited_line_info" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_JITED_LINE_INFO 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "jited_line_info_rec_size" "ac_cv_member_struct_bpf_prog_info_jited_line_info_rec_size" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_jited_line_info_rec_size" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_JITED_LINE_INFO_REC_SIZE 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "jited_prog_insns" "ac_cv_member_struct_bpf_prog_info_jited_prog_insns" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_jited_prog_insns" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_JITED_PROG_INSNS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "jited_prog_len" "ac_cv_member_struct_bpf_prog_info_jited_prog_len" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_jited_prog_len" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_JITED_PROG_LEN 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "line_info" "ac_cv_member_struct_bpf_prog_info_line_info" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_line_info" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_LINE_INFO 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "line_info_rec_size" "ac_cv_member_struct_bpf_prog_info_line_info_rec_size" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_line_info_rec_size" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_LINE_INFO_REC_SIZE 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "load_time" "ac_cv_member_struct_bpf_prog_info_load_time" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_load_time" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_LOAD_TIME 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "map_ids" "ac_cv_member_struct_bpf_prog_info_map_ids" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_map_ids" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_MAP_IDS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "name" "ac_cv_member_struct_bpf_prog_info_name" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_name" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_NAME 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "nr_func_info" "ac_cv_member_struct_bpf_prog_info_nr_func_info" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_nr_func_info" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_NR_FUNC_INFO 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "nr_jited_func_lens" "ac_cv_member_struct_bpf_prog_info_nr_jited_func_lens" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_nr_jited_func_lens" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_NR_JITED_FUNC_LENS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "nr_jited_ksyms" "ac_cv_member_struct_bpf_prog_info_nr_jited_ksyms" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_nr_jited_ksyms" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_NR_JITED_KSYMS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "nr_jited_line_info" "ac_cv_member_struct_bpf_prog_info_nr_jited_line_info" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_nr_jited_line_info" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_NR_JITED_LINE_INFO 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "nr_line_info" "ac_cv_member_struct_bpf_prog_info_nr_line_info" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_nr_line_info" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_NR_LINE_INFO 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "nr_map_ids" "ac_cv_member_struct_bpf_prog_info_nr_map_ids" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_nr_map_ids" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_NR_MAP_IDS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "nr_prog_tags" "ac_cv_member_struct_bpf_prog_info_nr_prog_tags" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_nr_prog_tags" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_NR_PROG_TAGS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "prog_tags" "ac_cv_member_struct_bpf_prog_info_prog_tags" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_prog_tags" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_PROG_TAGS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "run_cnt" "ac_cv_member_struct_bpf_prog_info_run_cnt" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_run_cnt" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_RUN_CNT 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "run_time_ns" "ac_cv_member_struct_bpf_prog_info_run_time_ns" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_run_time_ns" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_RUN_TIME_NS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "tag" "ac_cv_member_struct_bpf_prog_info_tag" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_tag" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_TAG 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "type" "ac_cv_member_struct_bpf_prog_info_type" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_type" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_TYPE 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "xlated_prog_insns" "ac_cv_member_struct_bpf_prog_info_xlated_prog_insns" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_xlated_prog_insns" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_XLATED_PROG_INSNS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "xlated_prog_len" "ac_cv_member_struct_bpf_prog_info_xlated_prog_len" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_struct_bpf_prog_info_xlated_prog_len" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BPF_PROG_INFO_XLATED_PROG_LEN 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "attach_bpf_fd" "ac_cv_member_union_bpf_attr_attach_bpf_fd" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_attach_bpf_fd" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_ATTACH_BPF_FD 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "attach_btf_id" "ac_cv_member_union_bpf_attr_attach_btf_id" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_attach_btf_id" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_ATTACH_BTF_ID 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "attach_flags" "ac_cv_member_union_bpf_attr_attach_flags" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_attach_flags" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_ATTACH_FLAGS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "attach_prog_fd" "ac_cv_member_union_bpf_attr_attach_prog_fd" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_attach_prog_fd" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_ATTACH_PROG_FD 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "attach_type" "ac_cv_member_union_bpf_attr_attach_type" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_attach_type" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_ATTACH_TYPE 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "batch.count" "ac_cv_member_union_bpf_attr_batch_count" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_batch_count" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_BATCH_COUNT 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "batch.elem_flags" "ac_cv_member_union_bpf_attr_batch_elem_flags" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_batch_elem_flags" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_BATCH_ELEM_FLAGS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "batch.flags" "ac_cv_member_union_bpf_attr_batch_flags" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_batch_flags" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_BATCH_FLAGS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "batch.in_batch" "ac_cv_member_union_bpf_attr_batch_in_batch" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_batch_in_batch" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_BATCH_IN_BATCH 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "batch.keys" "ac_cv_member_union_bpf_attr_batch_keys" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_batch_keys" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_BATCH_KEYS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "batch.map_fd" "ac_cv_member_union_bpf_attr_batch_map_fd" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_batch_map_fd" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_BATCH_MAP_FD 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "batch.out_batch" "ac_cv_member_union_bpf_attr_batch_out_batch" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_batch_out_batch" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_BATCH_OUT_BATCH 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "batch.values" "ac_cv_member_union_bpf_attr_batch_values" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_batch_values" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_BATCH_VALUES 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "bpf_fd" "ac_cv_member_union_bpf_attr_bpf_fd" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_bpf_fd" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_BPF_FD 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "btf" "ac_cv_member_union_bpf_attr_btf" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_btf" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_BTF 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "btf_fd" "ac_cv_member_union_bpf_attr_btf_fd" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_btf_fd" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_BTF_FD 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "btf_id" "ac_cv_member_union_bpf_attr_btf_id" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_btf_id" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_BTF_ID 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "btf_key_type_id" "ac_cv_member_union_bpf_attr_btf_key_type_id" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_btf_key_type_id" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_BTF_KEY_TYPE_ID 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "btf_log_buf" "ac_cv_member_union_bpf_attr_btf_log_buf" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_btf_log_buf" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_BTF_LOG_BUF 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "btf_log_level" "ac_cv_member_union_bpf_attr_btf_log_level" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_btf_log_level" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_BTF_LOG_LEVEL 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "btf_log_size" "ac_cv_member_union_bpf_attr_btf_log_size" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_btf_log_size" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_BTF_LOG_SIZE 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "btf_size" "ac_cv_member_union_bpf_attr_btf_size" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_btf_size" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_BTF_SIZE 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "btf_value_type_id" "ac_cv_member_union_bpf_attr_btf_value_type_id" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_btf_value_type_id" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_BTF_VALUE_TYPE_ID 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "btf_vmlinux_value_type_id" "ac_cv_member_union_bpf_attr_btf_vmlinux_value_type_id" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_btf_vmlinux_value_type_id" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_BTF_VMLINUX_VALUE_TYPE_ID 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "dummy" "ac_cv_member_union_bpf_attr_dummy" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_dummy" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_DUMMY 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "expected_attach_type" "ac_cv_member_union_bpf_attr_expected_attach_type" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_expected_attach_type" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_EXPECTED_ATTACH_TYPE 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "file_flags" "ac_cv_member_union_bpf_attr_file_flags" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_file_flags" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_FILE_FLAGS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "flags" "ac_cv_member_union_bpf_attr_flags" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_flags" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_FLAGS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "func_info" "ac_cv_member_union_bpf_attr_func_info" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_func_info" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_FUNC_INFO 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "func_info_cnt" "ac_cv_member_union_bpf_attr_func_info_cnt" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_func_info_cnt" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_FUNC_INFO_CNT 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "func_info_rec_size" "ac_cv_member_union_bpf_attr_func_info_rec_size" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_func_info_rec_size" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_FUNC_INFO_REC_SIZE 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "info.bpf_fd" "ac_cv_member_union_bpf_attr_info_bpf_fd" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_info_bpf_fd" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_INFO_BPF_FD 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "info.info" "ac_cv_member_union_bpf_attr_info_info" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_info_info" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_INFO_INFO 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "info.info_len" "ac_cv_member_union_bpf_attr_info_info_len" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_info_info_len" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_INFO_INFO_LEN 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "inner_map_fd" "ac_cv_member_union_bpf_attr_inner_map_fd" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_inner_map_fd" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_INNER_MAP_FD 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "insn_cnt" "ac_cv_member_union_bpf_attr_insn_cnt" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_insn_cnt" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_INSN_CNT 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "insns" "ac_cv_member_union_bpf_attr_insns" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_insns" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_INSNS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "kern_version" "ac_cv_member_union_bpf_attr_kern_version" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_kern_version" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_KERN_VERSION 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "key" "ac_cv_member_union_bpf_attr_key" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_key" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_KEY 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "key_size" "ac_cv_member_union_bpf_attr_key_size" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_key_size" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_KEY_SIZE 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "license" "ac_cv_member_union_bpf_attr_license" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_license" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_LICENSE 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "line_info" "ac_cv_member_union_bpf_attr_line_info" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_line_info" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_LINE_INFO 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "line_info_cnt" "ac_cv_member_union_bpf_attr_line_info_cnt" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_line_info_cnt" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_LINE_INFO_CNT 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "line_info_rec_size" "ac_cv_member_union_bpf_attr_line_info_rec_size" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_line_info_rec_size" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_LINE_INFO_REC_SIZE 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "link_create.attach_type" "ac_cv_member_union_bpf_attr_link_create_attach_type" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_link_create_attach_type" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_LINK_CREATE_ATTACH_TYPE 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "link_create.flags" "ac_cv_member_union_bpf_attr_link_create_flags" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_link_create_flags" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_LINK_CREATE_FLAGS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "link_create.prog_fd" "ac_cv_member_union_bpf_attr_link_create_prog_fd" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_link_create_prog_fd" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_LINK_CREATE_PROG_FD 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "link_create.target_fd" "ac_cv_member_union_bpf_attr_link_create_target_fd" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_link_create_target_fd" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_LINK_CREATE_TARGET_FD 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "link_update.flags" "ac_cv_member_union_bpf_attr_link_update_flags" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_link_update_flags" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_LINK_UPDATE_FLAGS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "link_update.link_fd" "ac_cv_member_union_bpf_attr_link_update_link_fd" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_link_update_link_fd" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_LINK_UPDATE_LINK_FD 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "link_update.new_prog_fd" "ac_cv_member_union_bpf_attr_link_update_new_prog_fd" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_link_update_new_prog_fd" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_LINK_UPDATE_NEW_PROG_FD 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "link_update.old_prog_fd" "ac_cv_member_union_bpf_attr_link_update_old_prog_fd" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_link_update_old_prog_fd" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_LINK_UPDATE_OLD_PROG_FD 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "log_buf" "ac_cv_member_union_bpf_attr_log_buf" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_log_buf" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_LOG_BUF 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "log_level" "ac_cv_member_union_bpf_attr_log_level" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_log_level" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_LOG_LEVEL 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "log_size" "ac_cv_member_union_bpf_attr_log_size" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_log_size" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_LOG_SIZE 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "map_fd" "ac_cv_member_union_bpf_attr_map_fd" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_map_fd" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_MAP_FD 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "map_flags" "ac_cv_member_union_bpf_attr_map_flags" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_map_flags" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_MAP_FLAGS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "map_id" "ac_cv_member_union_bpf_attr_map_id" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_map_id" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_MAP_ID 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "map_ifindex" "ac_cv_member_union_bpf_attr_map_ifindex" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_map_ifindex" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_MAP_IFINDEX 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "map_name" "ac_cv_member_union_bpf_attr_map_name" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_map_name" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_MAP_NAME 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "map_type" "ac_cv_member_union_bpf_attr_map_type" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_map_type" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_MAP_TYPE 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "max_entries" "ac_cv_member_union_bpf_attr_max_entries" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_max_entries" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_MAX_ENTRIES 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "next_id" "ac_cv_member_union_bpf_attr_next_id" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_next_id" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_NEXT_ID 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "next_key" "ac_cv_member_union_bpf_attr_next_key" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_next_key" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_NEXT_KEY 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "numa_node" "ac_cv_member_union_bpf_attr_numa_node" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_numa_node" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_NUMA_NODE 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "open_flags" "ac_cv_member_union_bpf_attr_open_flags" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_open_flags" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_OPEN_FLAGS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "pathname" "ac_cv_member_union_bpf_attr_pathname" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_pathname" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_PATHNAME 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "prog_btf_fd" "ac_cv_member_union_bpf_attr_prog_btf_fd" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_prog_btf_fd" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_PROG_BTF_FD 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "prog_flags" "ac_cv_member_union_bpf_attr_prog_flags" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_prog_flags" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_PROG_FLAGS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "prog_id" "ac_cv_member_union_bpf_attr_prog_id" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_prog_id" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_PROG_ID 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "prog_ifindex" "ac_cv_member_union_bpf_attr_prog_ifindex" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_prog_ifindex" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_PROG_IFINDEX 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "prog_name" "ac_cv_member_union_bpf_attr_prog_name" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_prog_name" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_PROG_NAME 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "prog_type" "ac_cv_member_union_bpf_attr_prog_type" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_prog_type" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_PROG_TYPE 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "query.attach_flags" "ac_cv_member_union_bpf_attr_query_attach_flags" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_query_attach_flags" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_QUERY_ATTACH_FLAGS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "query.attach_type" "ac_cv_member_union_bpf_attr_query_attach_type" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_query_attach_type" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_QUERY_ATTACH_TYPE 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "query.prog_cnt" "ac_cv_member_union_bpf_attr_query_prog_cnt" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_query_prog_cnt" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_QUERY_PROG_CNT 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "query.prog_ids" "ac_cv_member_union_bpf_attr_query_prog_ids" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_query_prog_ids" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_QUERY_PROG_IDS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "query.query_flags" "ac_cv_member_union_bpf_attr_query_query_flags" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_query_query_flags" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_QUERY_QUERY_FLAGS 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "query.target_fd" "ac_cv_member_union_bpf_attr_query_target_fd" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_query_target_fd" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_QUERY_TARGET_FD 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "raw_tracepoint.name" "ac_cv_member_union_bpf_attr_raw_tracepoint_name" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_raw_tracepoint_name" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_RAW_TRACEPOINT_NAME 1
+_ACEOF
+
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "raw_tracepoint.prog_fd" "ac_cv_member_union_bpf_attr_raw_tracepoint_prog_fd" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_raw_tracepoint_prog_fd" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_RAW_TRACEPOINT_PROG_FD 1
 _ACEOF
-if ac_fn_c_try_cpp "$LINENO"; then :
 
-else
-  # Broken: fails on valid input.
-continue
+
 fi
-rm -f conftest.err conftest.i conftest.$ac_ext
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "replace_bpf_fd" "ac_cv_member_union_bpf_attr_replace_bpf_fd" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_replace_bpf_fd" = xyes; then :
 
-  # OK, works on sane cases.  Now check whether nonexistent headers
-  # can be detected and how.
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-#include <ac_nonexistent.h>
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_REPLACE_BPF_FD 1
 _ACEOF
-if ac_fn_c_try_cpp "$LINENO"; then :
-  # Broken: success on invalid input.
-continue
-else
-  # Passes both tests.
-ac_preproc_ok=:
-break
-fi
-rm -f conftest.err conftest.i conftest.$ac_ext
 
-done
-# Because of `break', _AC_PREPROC_IFELSE's cleaning code was skipped.
-rm -f conftest.i conftest.err conftest.$ac_ext
-if $ac_preproc_ok; then :
 
-else
-  { { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
-$as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
-as_fn_error $? "C preprocessor \"$CPP_FOR_BUILD\" fails sanity check
-See \`config.log' for more details" "$LINENO" 5; }
 fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "start_id" "ac_cv_member_union_bpf_attr_start_id" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_start_id" = xyes; then :
 
-ac_ext=c
-ac_cpp='$CPP_FOR_BUILD $CPPFLAGS_FOR_BUILD'
-ac_compile='$CC_FOR_BUILD -c $CFLAGS_FOR_BUILD $CPPFLAGS_FOR_BUILD conftest.$ac_ext >&5'
-ac_link='$CC_FOR_BUILD -o conftest$ac_build_exeext $CFLAGS_FOR_BUILD $CPPFLAGS_FOR_BUILD $LDFLAGS_FOR_BUILD conftest.$ac_ext $LIBS >&5'
-ac_compiler_gnu=$ac_cv_c_compiler_gnu
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_START_ID 1
+_ACEOF
 
 
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "target_fd" "ac_cv_member_union_bpf_attr_target_fd" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_target_fd" = xyes; then :
 
-if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_TARGET_FD 1
+_ACEOF
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
 
-int
-main ()
-{
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "task_fd_query.buf" "ac_cv_member_union_bpf_attr_task_fd_query_buf" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_task_fd_query_buf" = xyes; then :
 
-  ;
-  return 0;
-}
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_BUF 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
-fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
-  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
-else
-  gl_build_unknown_warnings_are_errors=
-fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "task_fd_query.buf_len" "ac_cv_member_union_bpf_attr_task_fd_query_buf_len" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_task_fd_query_buf_len" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_BUF_LEN 1
+_ACEOF
 
 
 fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "task_fd_query.fd" "ac_cv_member_union_bpf_attr_task_fd_query_fd" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_task_fd_query_fd" = xyes; then :
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Wall" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Wall... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Wall+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_FD 1
+_ACEOF
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Wall"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
 
-int
-main ()
-{
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "task_fd_query.fd_type" "ac_cv_member_union_bpf_attr_task_fd_query_fd_type" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_task_fd_query_fd_type" = xyes; then :
 
-  ;
-  return 0;
-}
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_FD_TYPE 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Wall=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Wall=no
-fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Wall" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Wall" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Wall" = xyes; then :
-  as_fn_append WARN_CFLAGS_FOR_BUILD " -Wall"
-fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "task_fd_query.flags" "ac_cv_member_union_bpf_attr_task_fd_query_flags" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_task_fd_query_flags" = xyes; then :
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_FLAGS 1
+_ACEOF
 
-if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "task_fd_query.pid" "ac_cv_member_union_bpf_attr_task_fd_query_pid" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_task_fd_query_pid" = xyes; then :
 
-int
-main ()
-{
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_PID 1
+_ACEOF
 
-  ;
-  return 0;
-}
+
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "task_fd_query.probe_addr" "ac_cv_member_union_bpf_attr_task_fd_query_probe_addr" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_task_fd_query_probe_addr" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_PROBE_ADDR 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
+
+
 fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "task_fd_query.probe_offset" "ac_cv_member_union_bpf_attr_task_fd_query_probe_offset" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_task_fd_query_probe_offset" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_PROBE_OFFSET 1
+_ACEOF
+
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
-  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
-else
-  gl_build_unknown_warnings_are_errors=
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "task_fd_query.prog_id" "ac_cv_member_union_bpf_attr_task_fd_query_prog_id" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_task_fd_query_prog_id" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_PROG_ID 1
+_ACEOF
+
+
 fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "test.ctx_in" "ac_cv_member_union_bpf_attr_test_ctx_in" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_test_ctx_in" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_TEST_CTX_IN 1
+_ACEOF
 
 
 fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "test.ctx_out" "ac_cv_member_union_bpf_attr_test_ctx_out" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_test_ctx_out" = xyes; then :
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Wempty-body" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Wempty-body... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Wempty_body+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_TEST_CTX_OUT 1
+_ACEOF
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Wempty-body"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
 
-int
-main ()
-{
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "test.ctx_size_in" "ac_cv_member_union_bpf_attr_test_ctx_size_in" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_test_ctx_size_in" = xyes; then :
 
-  ;
-  return 0;
-}
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_TEST_CTX_SIZE_IN 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Wempty_body=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Wempty_body=no
+
+
 fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "test.ctx_size_out" "ac_cv_member_union_bpf_attr_test_ctx_size_out" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_test_ctx_size_out" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_TEST_CTX_SIZE_OUT 1
+_ACEOF
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Wempty_body" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Wempty_body" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Wempty_body" = xyes; then :
-  as_fn_append WARN_CFLAGS_FOR_BUILD " -Wempty-body"
-fi
 
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "test.data_in" "ac_cv_member_union_bpf_attr_test_data_in" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_test_data_in" = xyes; then :
 
-if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_TEST_DATA_IN 1
+_ACEOF
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
 
-int
-main ()
-{
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "test.data_out" "ac_cv_member_union_bpf_attr_test_data_out" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_test_data_out" = xyes; then :
 
-  ;
-  return 0;
-}
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_TEST_DATA_OUT 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
-fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
-  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
-else
-  gl_build_unknown_warnings_are_errors=
-fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "test.data_size_in" "ac_cv_member_union_bpf_attr_test_data_size_in" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_test_data_size_in" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_TEST_DATA_SIZE_IN 1
+_ACEOF
 
 
 fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "test.data_size_out" "ac_cv_member_union_bpf_attr_test_data_size_out" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_test_data_size_out" = xyes; then :
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Wformat-security" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Wformat-security... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Wformat_security+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_TEST_DATA_SIZE_OUT 1
+_ACEOF
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Wformat-security"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
 
-int
-main ()
-{
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "test.duration" "ac_cv_member_union_bpf_attr_test_duration" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_test_duration" = xyes; then :
 
-  ;
-  return 0;
-}
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_TEST_DURATION 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Wformat_security=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Wformat_security=no
-fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Wformat_security" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Wformat_security" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Wformat_security" = xyes; then :
-  as_fn_append WARN_CFLAGS_FOR_BUILD " -Wformat-security"
-fi
 
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "test.prog_fd" "ac_cv_member_union_bpf_attr_test_prog_fd" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_test_prog_fd" = xyes; then :
 
-if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_TEST_PROG_FD 1
+_ACEOF
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
 
-int
-main ()
-{
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "test.repeat" "ac_cv_member_union_bpf_attr_test_repeat" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_test_repeat" = xyes; then :
 
-  ;
-  return 0;
-}
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_TEST_REPEAT 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
-fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
-  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
-else
-  gl_build_unknown_warnings_are_errors=
-fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "test.retval" "ac_cv_member_union_bpf_attr_test_retval" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_test_retval" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_TEST_RETVAL 1
+_ACEOF
 
 
 fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "value" "ac_cv_member_union_bpf_attr_value" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_value" = xyes; then :
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Wignored-qualifiers" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Wignored-qualifiers... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Wignored_qualifiers+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_VALUE 1
+_ACEOF
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Wignored-qualifiers"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
 
-int
-main ()
-{
+fi
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "value_size" "ac_cv_member_union_bpf_attr_value_size" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_value_size" = xyes; then :
 
-  ;
-  return 0;
-}
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_VALUE_SIZE 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Wignored_qualifiers=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Wignored_qualifiers=no
+
+
 fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+ac_fn_c_check_member "$LINENO" "union bpf_attr" "dummy" "ac_cv_member_union_bpf_attr_dummy" "#include <linux/bpf.h>
+"
+if test "x$ac_cv_member_union_bpf_attr_dummy" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_UNION_BPF_ATTR_DUMMY 1
+_ACEOF
+
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Wignored_qualifiers" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Wignored_qualifiers" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Wignored_qualifiers" = xyes; then :
-  as_fn_append WARN_CFLAGS_FOR_BUILD " -Wignored-qualifiers"
+
+
+
 fi
 
+done
 
-if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+for ac_header in linux/io_uring.h
+do :
+  ac_fn_c_check_header_mongrel "$LINENO" "linux/io_uring.h" "ac_cv_header_linux_io_uring_h" "$ac_includes_default"
+if test "x$ac_cv_header_linux_io_uring_h" = xyes; then :
+  cat >>confdefs.h <<_ACEOF
+#define HAVE_LINUX_IO_URING_H 1
+_ACEOF
 
-int
-main ()
-{
+	ac_fn_c_check_member "$LINENO" "struct io_cqring_offsets" "flags" "ac_cv_member_struct_io_cqring_offsets_flags" "#include <linux/io_uring.h>
+"
+if test "x$ac_cv_member_struct_io_cqring_offsets_flags" = xyes; then :
 
-  ;
-  return 0;
-}
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_IO_CQRING_OFFSETS_FLAGS 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
-fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
-  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
-else
-  gl_build_unknown_warnings_are_errors=
+ac_fn_c_check_member "$LINENO" "struct io_uring_params" "features" "ac_cv_member_struct_io_uring_params_features" "#include <linux/io_uring.h>
+"
+if test "x$ac_cv_member_struct_io_uring_params_features" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_IO_URING_PARAMS_FEATURES 1
+_ACEOF
+
+
 fi
+ac_fn_c_check_member "$LINENO" "struct io_uring_params" "wq_fd" "ac_cv_member_struct_io_uring_params_wq_fd" "#include <linux/io_uring.h>
+"
+if test "x$ac_cv_member_struct_io_uring_params_wq_fd" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_IO_URING_PARAMS_WQ_FD 1
+_ACEOF
 
 
 fi
+ac_fn_c_check_member "$LINENO" "struct io_uring_params" "resv" "ac_cv_member_struct_io_uring_params_resv" "#include <linux/io_uring.h>
+"
+if test "x$ac_cv_member_struct_io_uring_params_resv" = xyes; then :
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Wimplicit-fallthrough=5" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Wimplicit-fallthrough=5... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Wimplicit_fallthrough_5+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Wimplicit-fallthrough=5"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_IO_URING_PARAMS_RESV 1
+_ACEOF
 
-int
-main ()
-{
 
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Wimplicit_fallthrough_5=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Wimplicit_fallthrough_5=no
 fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Wimplicit_fallthrough_5" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Wimplicit_fallthrough_5" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Wimplicit_fallthrough_5" = xyes; then :
-  as_fn_append WARN_CFLAGS_FOR_BUILD " -Wimplicit-fallthrough=5"
+
 fi
 
+done
 
-if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+for ac_header in bluetooth/bluetooth.h
+do :
+  ac_fn_c_check_header_mongrel "$LINENO" "bluetooth/bluetooth.h" "ac_cv_header_bluetooth_bluetooth_h" "$ac_includes_default"
+if test "x$ac_cv_header_bluetooth_bluetooth_h" = xyes; then :
+  cat >>confdefs.h <<_ACEOF
+#define HAVE_BLUETOOTH_BLUETOOTH_H 1
+_ACEOF
 
-int
-main ()
-{
+	ac_fn_c_check_member "$LINENO" "struct sockaddr_hci" "hci_channel" "ac_cv_member_struct_sockaddr_hci_hci_channel" "#include <bluetooth/bluetooth.h>
+			 #include <bluetooth/hci.h>
+"
+if test "x$ac_cv_member_struct_sockaddr_hci_hci_channel" = xyes; then :
 
-  ;
-  return 0;
-}
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_SOCKADDR_HCI_HCI_CHANNEL 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
-fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
-  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
-else
-  gl_build_unknown_warnings_are_errors=
+
+	ac_fn_c_check_member "$LINENO" "struct sockaddr_l2" "l2_bdaddr_type" "ac_cv_member_struct_sockaddr_l2_l2_bdaddr_type" "#include <bluetooth/bluetooth.h>
+			 #include <bluetooth/l2cap.h>
+"
+if test "x$ac_cv_member_struct_sockaddr_l2_l2_bdaddr_type" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_SOCKADDR_L2_L2_BDADDR_TYPE 1
+_ACEOF
+
+
 fi
 
 
 fi
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Winit-self" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Winit-self... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Winit_self+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+done
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Winit-self"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
 
-int
-main ()
-{
+ac_fn_c_check_member "$LINENO" "struct br_mdb_entry" "flags" "ac_cv_member_struct_br_mdb_entry_flags" "#include <netinet/in.h>
+#include <linux/if_bridge.h>
+"
+if test "x$ac_cv_member_struct_br_mdb_entry_flags" = xyes; then :
 
-  ;
-  return 0;
-}
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BR_MDB_ENTRY_FLAGS 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Winit_self=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Winit_self=no
-fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Winit_self" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Winit_self" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Winit_self" = xyes; then :
-  as_fn_append WARN_CFLAGS_FOR_BUILD " -Winit-self"
-fi
+ac_fn_c_check_member "$LINENO" "struct br_mdb_entry" "vid" "ac_cv_member_struct_br_mdb_entry_vid" "#include <netinet/in.h>
+#include <linux/if_bridge.h>
+"
+if test "x$ac_cv_member_struct_br_mdb_entry_vid" = xyes; then :
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BR_MDB_ENTRY_VID 1
+_ACEOF
 
-if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+fi
 
-int
-main ()
-{
 
-  ;
-  return 0;
-}
+ac_fn_c_check_type "$LINENO" "struct dcbmsg" "ac_cv_type_struct_dcbmsg" "#include <linux/dcbnl.h>
+"
+if test "x$ac_cv_type_struct_dcbmsg" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_DCBMSG 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
-fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
-  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
-else
-  gl_build_unknown_warnings_are_errors=
+
 fi
 
+ac_fn_c_check_type "$LINENO" "struct ifaddrlblmsg" "ac_cv_type_struct_ifaddrlblmsg" "#include <linux/if_addrlabel.h>
+"
+if test "x$ac_cv_type_struct_ifaddrlblmsg" = xyes; then :
 
-fi
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_IFADDRLBLMSG 1
+_ACEOF
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Winitializer-overrides" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Winitializer-overrides... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Winitializer_overrides+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Winitializer-overrides"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+fi
 
-int
-main ()
-{
+ac_fn_c_check_type "$LINENO" "struct netconfmsg" "ac_cv_type_struct_netconfmsg" "#include <linux/netconf.h>
+"
+if test "x$ac_cv_type_struct_netconfmsg" = xyes; then :
 
-  ;
-  return 0;
-}
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_NETCONFMSG 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Winitializer_overrides=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Winitializer_overrides=no
-fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Winitializer_overrides" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Winitializer_overrides" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Winitializer_overrides" = xyes; then :
-  as_fn_append WARN_CFLAGS_FOR_BUILD " -Winitializer-overrides"
+
 fi
 
 
-if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+ac_fn_c_check_type "$LINENO" "struct ifla_cacheinfo" "ac_cv_type_struct_ifla_cacheinfo" "#include <sys/socket.h>
+#include <linux/rtnetlink.h>
+"
+if test "x$ac_cv_type_struct_ifla_cacheinfo" = xyes; then :
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_IFLA_CACHEINFO 1
+_ACEOF
 
-int
-main ()
-{
 
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
 fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
-  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
-else
-  gl_build_unknown_warnings_are_errors=
-fi
+
+ac_fn_c_check_type "$LINENO" "struct gnet_stats_basic" "ac_cv_type_struct_gnet_stats_basic" "#include <linux/gen_stats.h>
+"
+if test "x$ac_cv_type_struct_gnet_stats_basic" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_GNET_STATS_BASIC 1
+_ACEOF
 
 
 fi
+ac_fn_c_check_type "$LINENO" "struct gnet_stats_queue" "ac_cv_type_struct_gnet_stats_queue" "#include <linux/gen_stats.h>
+"
+if test "x$ac_cv_type_struct_gnet_stats_queue" = xyes; then :
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Wlogical-op" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Wlogical-op... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Wlogical_op+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_GNET_STATS_QUEUE 1
+_ACEOF
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Wlogical-op"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
 
-int
-main ()
-{
+fi
+ac_fn_c_check_type "$LINENO" "struct gnet_stats_rate_est" "ac_cv_type_struct_gnet_stats_rate_est" "#include <linux/gen_stats.h>
+"
+if test "x$ac_cv_type_struct_gnet_stats_rate_est" = xyes; then :
 
-  ;
-  return 0;
-}
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_GNET_STATS_RATE_EST 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Wlogical_op=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Wlogical_op=no
-fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Wlogical_op" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Wlogical_op" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Wlogical_op" = xyes; then :
-  as_fn_append WARN_CFLAGS_FOR_BUILD " -Wlogical-op"
-fi
+ac_fn_c_check_type "$LINENO" "struct gnet_stats_rate_est64" "ac_cv_type_struct_gnet_stats_rate_est64" "#include <linux/gen_stats.h>
+"
+if test "x$ac_cv_type_struct_gnet_stats_rate_est64" = xyes; then :
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_GNET_STATS_RATE_EST64 1
+_ACEOF
 
-if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+fi
 
-int
-main ()
-{
 
-  ;
-  return 0;
-}
+ac_fn_c_check_type "$LINENO" "struct tc_sizespec" "ac_cv_type_struct_tc_sizespec" "#include <linux/types.h>
+#include <linux/pkt_sched.h>
+"
+if test "x$ac_cv_type_struct_tc_sizespec" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_TC_SIZESPEC 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
-fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
-  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
-else
-  gl_build_unknown_warnings_are_errors=
+
 fi
 
 
-fi
+ac_fn_c_check_type "$LINENO" "struct fib_rule_uid_range" "ac_cv_type_struct_fib_rule_uid_range" "#include <sys/socket.h>
+#include <linux/fib_rules.h>
+"
+if test "x$ac_cv_type_struct_fib_rule_uid_range" = xyes; then :
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Wmissing-parameter-type" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Wmissing-parameter-type... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Wmissing_parameter_type+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_FIB_RULE_UID_RANGE 1
+_ACEOF
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Wmissing-parameter-type"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
 
-int
-main ()
-{
+fi
+ac_fn_c_check_type "$LINENO" "struct fib_rule_port_range" "ac_cv_type_struct_fib_rule_port_range" "#include <sys/socket.h>
+#include <linux/fib_rules.h>
+"
+if test "x$ac_cv_type_struct_fib_rule_port_range" = xyes; then :
 
-  ;
-  return 0;
-}
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_FIB_RULE_PORT_RANGE 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Wmissing_parameter_type=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Wmissing_parameter_type=no
-fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Wmissing_parameter_type" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Wmissing_parameter_type" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Wmissing_parameter_type" = xyes; then :
-  as_fn_append WARN_CFLAGS_FOR_BUILD " -Wmissing-parameter-type"
+
 fi
 
 
-if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+ac_fn_c_check_type "$LINENO" "struct statfs" "ac_cv_type_struct_statfs" "#include <linux/types.h>
+#include <asm/statfs.h>
+"
+if test "x$ac_cv_type_struct_statfs" = xyes; then :
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_STATFS 1
+_ACEOF
 
-int
-main ()
-{
 
-  ;
-  return 0;
-}
+	ac_fn_c_check_member "$LINENO" "struct statfs" "f_frsize" "ac_cv_member_struct_statfs_f_frsize" "#include <linux/types.h>
+#include <asm/statfs.h>
+"
+if test "x$ac_cv_member_struct_statfs_f_frsize" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_STATFS_F_FRSIZE 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
-fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
-  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
-else
-  gl_build_unknown_warnings_are_errors=
-fi
+ac_fn_c_check_member "$LINENO" "struct statfs" "f_flags" "ac_cv_member_struct_statfs_f_flags" "#include <linux/types.h>
+#include <asm/statfs.h>
+"
+if test "x$ac_cv_member_struct_statfs_f_flags" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_STATFS_F_FLAGS 1
+_ACEOF
 
 
 fi
+ac_fn_c_check_member "$LINENO" "struct statfs" "f_fsid.val" "ac_cv_member_struct_statfs_f_fsid_val" "#include <linux/types.h>
+#include <asm/statfs.h>
+"
+if test "x$ac_cv_member_struct_statfs_f_fsid_val" = xyes; then :
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Wnested-externs" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Wnested-externs... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Wnested_externs+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_STATFS_F_FSID_VAL 1
+_ACEOF
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Wnested-externs"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
 
-int
-main ()
-{
+fi
+ac_fn_c_check_member "$LINENO" "struct statfs" "f_fsid.__val" "ac_cv_member_struct_statfs_f_fsid___val" "#include <linux/types.h>
+#include <asm/statfs.h>
+"
+if test "x$ac_cv_member_struct_statfs_f_fsid___val" = xyes; then :
 
-  ;
-  return 0;
-}
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_STATFS_F_FSID___VAL 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Wnested_externs=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Wnested_externs=no
-fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Wnested_externs" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Wnested_externs" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Wnested_externs" = xyes; then :
-  as_fn_append WARN_CFLAGS_FOR_BUILD " -Wnested-externs"
+
+
 fi
 
 
-if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+ac_fn_c_check_type "$LINENO" "struct statfs64" "ac_cv_type_struct_statfs64" "#include <linux/types.h>
+#include <asm/statfs.h>
+"
+if test "x$ac_cv_type_struct_statfs64" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_STATFS64 1
+_ACEOF
+
+
+	ac_fn_c_check_member "$LINENO" "struct statfs64" "f_frsize" "ac_cv_member_struct_statfs64_f_frsize" "#include <linux/types.h>
+#include <asm/statfs.h>
+"
+if test "x$ac_cv_member_struct_statfs64_f_frsize" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_STATFS64_F_FRSIZE 1
+_ACEOF
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
 
-int
-main ()
-{
+fi
+ac_fn_c_check_member "$LINENO" "struct statfs64" "f_flags" "ac_cv_member_struct_statfs64_f_flags" "#include <linux/types.h>
+#include <asm/statfs.h>
+"
+if test "x$ac_cv_member_struct_statfs64_f_flags" = xyes; then :
 
-  ;
-  return 0;
-}
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_STATFS64_F_FLAGS 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
-fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
-  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
-else
-  gl_build_unknown_warnings_are_errors=
+ac_fn_c_check_member "$LINENO" "struct statfs64" "f_fsid.val" "ac_cv_member_struct_statfs64_f_fsid_val" "#include <linux/types.h>
+#include <asm/statfs.h>
+"
+if test "x$ac_cv_member_struct_statfs64_f_fsid_val" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_STATFS64_F_FSID_VAL 1
+_ACEOF
+
+
 fi
+ac_fn_c_check_member "$LINENO" "struct statfs64" "f_fsid.__val" "ac_cv_member_struct_statfs64_f_fsid___val" "#include <linux/types.h>
+#include <asm/statfs.h>
+"
+if test "x$ac_cv_member_struct_statfs64_f_fsid___val" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_STATFS64_F_FSID___VAL 1
+_ACEOF
 
 
 fi
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Wold-style-declaration" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Wold-style-declaration... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Wold_style_declaration+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Wold-style-declaration"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+fi
 
-int
-main ()
-{
 
-  ;
-  return 0;
-}
+ac_fn_c_check_type "$LINENO" "struct statx" "ac_cv_type_struct_statx" "#include <linux/types.h>
+#include <linux/stat.h>
+"
+if test "x$ac_cv_type_struct_statx" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_STATX 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Wold_style_declaration=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Wold_style_declaration=no
-fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Wold_style_declaration" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Wold_style_declaration" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Wold_style_declaration" = xyes; then :
-  as_fn_append WARN_CFLAGS_FOR_BUILD " -Wold-style-declaration"
+
 fi
 
 
-if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+ac_fn_c_check_type "$LINENO" "struct blk_user_trace_setup" "ac_cv_type_struct_blk_user_trace_setup" "#include <linux/blktrace_api.h>
+"
+if test "x$ac_cv_type_struct_blk_user_trace_setup" = xyes; then :
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BLK_USER_TRACE_SETUP 1
+_ACEOF
 
-int
-main ()
-{
 
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
 fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
-  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
-else
-  gl_build_unknown_warnings_are_errors=
-fi
 
+ac_fn_c_check_type "$LINENO" "struct mtd_write_req" "ac_cv_type_struct_mtd_write_req" "#include <mtd/mtd-abi.h>
+"
+if test "x$ac_cv_type_struct_mtd_write_req" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_MTD_WRITE_REQ 1
+_ACEOF
 
-fi
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Wold-style-definition" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Wold-style-definition... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Wold_style_definition+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+fi
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Wold-style-definition"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
 
-int
-main ()
-{
+ac_fn_c_check_member "$LINENO" "struct ubi_attach_req" "max_beb_per1024" "ac_cv_member_struct_ubi_attach_req_max_beb_per1024" "#include <mtd/ubi-user.h>
+"
+if test "x$ac_cv_member_struct_ubi_attach_req_max_beb_per1024" = xyes; then :
 
-  ;
-  return 0;
-}
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_UBI_ATTACH_REQ_MAX_BEB_PER1024 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Wold_style_definition=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Wold_style_definition=no
-fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Wold_style_definition" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Wold_style_definition" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Wold_style_definition" = xyes; then :
-  as_fn_append WARN_CFLAGS_FOR_BUILD " -Wold-style-definition"
+
 fi
 
 
-if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+ac_fn_c_check_type "$LINENO" "struct ptp_sys_offset" "ac_cv_type_struct_ptp_sys_offset" "#include <linux/ptp_clock.h>
+"
+if test "x$ac_cv_type_struct_ptp_sys_offset" = xyes; then :
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_PTP_SYS_OFFSET 1
+_ACEOF
 
-int
-main ()
-{
 
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
 fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
-  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
-else
-  gl_build_unknown_warnings_are_errors=
-fi
+
+ac_fn_c_check_type "$LINENO" "struct kvm_cpuid2" "ac_cv_type_struct_kvm_cpuid2" "#include <linux/kvm.h>
+"
+if test "x$ac_cv_type_struct_kvm_cpuid2" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_KVM_CPUID2 1
+_ACEOF
 
 
 fi
+ac_fn_c_check_type "$LINENO" "struct kvm_regs" "ac_cv_type_struct_kvm_regs" "#include <linux/kvm.h>
+"
+if test "x$ac_cv_type_struct_kvm_regs" = xyes; then :
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Woverride-init" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Woverride-init... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Woverride_init+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_KVM_REGS 1
+_ACEOF
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Woverride-init"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
 
-int
-main ()
-{
+fi
+ac_fn_c_check_type "$LINENO" "struct kvm_sregs" "ac_cv_type_struct_kvm_sregs" "#include <linux/kvm.h>
+"
+if test "x$ac_cv_type_struct_kvm_sregs" = xyes; then :
 
-  ;
-  return 0;
-}
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_KVM_SREGS 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Woverride_init=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Woverride_init=no
+
+
 fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+ac_fn_c_check_type "$LINENO" "struct kvm_userspace_memory_region" "ac_cv_type_struct_kvm_userspace_memory_region" "#include <linux/kvm.h>
+"
+if test "x$ac_cv_type_struct_kvm_userspace_memory_region" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_KVM_USERSPACE_MEMORY_REGION 1
+_ACEOF
+
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Woverride_init" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Woverride_init" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Woverride_init" = xyes; then :
-  as_fn_append WARN_CFLAGS_FOR_BUILD " -Woverride-init"
 fi
 
 
-if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
+saved_CPPFLAGS="$CPPFLAGS"
+
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether <linux/signal.h> can be used along with <signal.h>" >&5
+$as_echo_n "checking whether <linux/signal.h> can be used along with <signal.h>... " >&6; }
+if ${st_cv_linux_signal+:} false; then :
   $as_echo_n "(cached) " >&6
 else
-
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
   cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 
-int
-main ()
-{
-
-  ;
-  return 0;
-}
+#include <signal.h>
+#include <linux/signal.h>
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
+if ac_fn_c_try_compile "$LINENO"; then :
+  st_cv_linux_signal=yes
 else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
+  st_cv_linux_signal=no
 fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
-
+rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
-  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
-else
-  gl_build_unknown_warnings_are_errors=
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $st_cv_linux_signal" >&5
+$as_echo "$st_cv_linux_signal" >&6; }
+if test "x$st_cv_linux_signal" = xno; then
+	mkdir -p linux/linux
+	cp $srcdir/linux/signal.h.in linux/linux/signal.h
+	CPPFLAGS="$CPPFLAGS -Ilinux"
 fi
 
+ac_fn_c_check_type "$LINENO" "struct __aio_sigset" "ac_cv_type_struct___aio_sigset" "#include <linux/aio_abi.h>
+"
+if test "x$ac_cv_type_struct___aio_sigset" = xyes; then :
 
-fi
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT___AIO_SIGSET 1
+_ACEOF
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Wsign-compare" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Wsign-compare... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Wsign_compare+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Wsign-compare"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+fi
 
-int
-main ()
-{
 
-  ;
-  return 0;
-}
+ac_fn_c_check_member "$LINENO" "struct iocb" "aio_flags" "ac_cv_member_struct_iocb_aio_flags" "#include <linux/aio_abi.h>
+"
+if test "x$ac_cv_member_struct_iocb_aio_flags" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_IOCB_AIO_FLAGS 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Wsign_compare=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Wsign_compare=no
-fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Wsign_compare" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Wsign_compare" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Wsign_compare" = xyes; then :
-  as_fn_append WARN_CFLAGS_FOR_BUILD " -Wsign-compare"
-fi
+ac_fn_c_check_member "$LINENO" "struct iocb" "aio_rw_flags" "ac_cv_member_struct_iocb_aio_rw_flags" "#include <linux/aio_abi.h>
+"
+if test "x$ac_cv_member_struct_iocb_aio_rw_flags" = xyes; then :
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_IOCB_AIO_RW_FLAGS 1
+_ACEOF
 
-if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+fi
 
-int
-main ()
-{
 
-  ;
-  return 0;
-}
+ac_fn_c_check_member "$LINENO" "struct clone_args" "cgroup" "ac_cv_member_struct_clone_args_cgroup" "#include <linux/sched.h>
+"
+if test "x$ac_cv_member_struct_clone_args_cgroup" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_CLONE_ARGS_CGROUP 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
-fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
-  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
-else
-  gl_build_unknown_warnings_are_errors=
+
 fi
 
 
-fi
+CPPFLAGS="$saved_CPPFLAGS"
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Wtype-limits" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Wtype-limits... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Wtype_limits+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+for ac_header in linux/btrfs.h
+do :
+  ac_fn_c_check_header_mongrel "$LINENO" "linux/btrfs.h" "ac_cv_header_linux_btrfs_h" "$ac_includes_default"
+if test "x$ac_cv_header_linux_btrfs_h" = xyes; then :
+  cat >>confdefs.h <<_ACEOF
+#define HAVE_LINUX_BTRFS_H 1
+_ACEOF
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Wtype-limits"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+	ac_fn_c_check_member "$LINENO" "struct btrfs_ioctl_feature_flags" "compat_flags" "ac_cv_member_struct_btrfs_ioctl_feature_flags_compat_flags" " #include <stdio.h>
+#include <linux/btrfs.h>
+"
+if test "x$ac_cv_member_struct_btrfs_ioctl_feature_flags_compat_flags" = xyes; then :
 
-int
-main ()
-{
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BTRFS_IOCTL_FEATURE_FLAGS_COMPAT_FLAGS 1
+_ACEOF
 
-  ;
-  return 0;
-}
+
+fi
+ac_fn_c_check_member "$LINENO" "struct btrfs_ioctl_fs_info_args" "nodesize" "ac_cv_member_struct_btrfs_ioctl_fs_info_args_nodesize" " #include <stdio.h>
+#include <linux/btrfs.h>
+"
+if test "x$ac_cv_member_struct_btrfs_ioctl_fs_info_args_nodesize" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BTRFS_IOCTL_FS_INFO_ARGS_NODESIZE 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Wtype_limits=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Wtype_limits=no
+
+
 fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+ac_fn_c_check_member "$LINENO" "struct btrfs_ioctl_defrag_range_args" "start" "ac_cv_member_struct_btrfs_ioctl_defrag_range_args_start" " #include <stdio.h>
+#include <linux/btrfs.h>
+"
+if test "x$ac_cv_member_struct_btrfs_ioctl_defrag_range_args_start" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BTRFS_IOCTL_DEFRAG_RANGE_ARGS_START 1
+_ACEOF
+
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Wtype_limits" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Wtype_limits" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Wtype_limits" = xyes; then :
-  as_fn_append WARN_CFLAGS_FOR_BUILD " -Wtype-limits"
+
 fi
 
+done
 
-if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
 
-int
-main ()
-{
 
-  ;
-  return 0;
-}
+for ac_header in linux/btrfs.h
+do :
+  ac_fn_c_check_header_compile "$LINENO" "linux/btrfs.h" "ac_cv_header_linux_btrfs_h" "$ac_includes_default
+#include <stdio.h>
+#include <stdint.h>
+"
+if test "x$ac_cv_header_linux_btrfs_h" = xyes; then :
+  cat >>confdefs.h <<_ACEOF
+#define HAVE_LINUX_BTRFS_H 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
-fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
+
+ac_fn_c_check_type "$LINENO" "struct btrfs_ioctl_logical_ino_args" "ac_cv_type_struct_btrfs_ioctl_logical_ino_args" "$ac_includes_default
+#include <stdio.h>
+#include <stdint.h>
+#include <linux/btrfs.h>
+"
+if test "x$ac_cv_type_struct_btrfs_ioctl_logical_ino_args" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BTRFS_IOCTL_LOGICAL_INO_ARGS 1
+_ACEOF
+
+ac_fn_c_check_member "$LINENO" "struct btrfs_ioctl_logical_ino_args" "inodes" "ac_cv_member_struct_btrfs_ioctl_logical_ino_args_inodes" "$ac_includes_default
+#include <stdio.h>
+#include <stdint.h>
+#include <linux/btrfs.h>
+"
+if test "x$ac_cv_member_struct_btrfs_ioctl_logical_ino_args_inodes" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BTRFS_IOCTL_LOGICAL_INO_ARGS_INODES 1
+_ACEOF
+
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
-  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
-else
-  gl_build_unknown_warnings_are_errors=
+
 fi
 
 
 fi
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Wwrite-strings" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Wwrite-strings... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Wwrite_strings+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+done
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Wwrite-strings"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
 
-int
-main ()
-{
+for ac_header in linux/cryptouser.h
+do :
+  ac_fn_c_check_header_compile "$LINENO" "linux/cryptouser.h" "ac_cv_header_linux_cryptouser_h" "$ac_includes_default
 
-  ;
-  return 0;
-}
+"
+if test "x$ac_cv_header_linux_cryptouser_h" = xyes; then :
+  cat >>confdefs.h <<_ACEOF
+#define HAVE_LINUX_CRYPTOUSER_H 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Wwrite_strings=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Wwrite_strings=no
-fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
-
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Wwrite_strings" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Wwrite_strings" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Wwrite_strings" = xyes; then :
-  as_fn_append WARN_CFLAGS_FOR_BUILD " -Wwrite-strings"
-fi
 
 
-# Check whether --enable-gcc-Werror was given.
-if test "${enable_gcc_Werror+set}" = set; then :
-  enableval=$enable_gcc_Werror; case $enableval in
-     yes) if test x${gl_build_unknown_warnings_are_errors+set} = x; then :
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror -Wunknown-warning-option... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
+ac_fn_c_check_type "$LINENO" "struct crypto_user_alg" "ac_cv_type_struct_crypto_user_alg" "$ac_includes_default
+#include <linux/cryptouser.h>
+"
+if test "x$ac_cv_type_struct_crypto_user_alg" = xyes; then :
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror -Wunknown-warning-option"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_CRYPTO_USER_ALG 1
+_ACEOF
 
-int
-main ()
-{
+ac_fn_c_check_member "$LINENO" "struct crypto_user_alg" "cru_flags" "ac_cv_member_struct_crypto_user_alg_cru_flags" "$ac_includes_default
+#include <linux/cryptouser.h>
+"
+if test "x$ac_cv_member_struct_crypto_user_alg_cru_flags" = xyes; then :
 
-  ;
-  return 0;
-}
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_CRYPTO_USER_ALG_CRU_FLAGS 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option=no
-fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror__Wunknown_warning_option" = xyes; then :
-  gl_build_unknown_warnings_are_errors='-Wunknown-warning-option -Werror'
-else
-  gl_build_unknown_warnings_are_errors=
-fi
 
+fi
 
 fi
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether $CC_FOR_BUILD handles -Werror" >&5
-$as_echo_n "checking whether $CC_FOR_BUILD handles -Werror... " >&6; }
-if ${gl_cv_warn_CFLAGS_FOR_BUILD__Werror+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
 
-  gl_save_compiler_FLAGS="$CFLAGS_FOR_BUILD"
-  as_fn_append CFLAGS_FOR_BUILD " $gl_build_unknown_warnings_are_errors -Werror"
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+ac_fn_c_check_type "$LINENO" "struct crypto_report_hash" "ac_cv_type_struct_crypto_report_hash" "$ac_includes_default
+#include <linux/cryptouser.h>
+"
+if test "x$ac_cv_type_struct_crypto_report_hash" = xyes; then :
 
-int
-main ()
-{
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_CRYPTO_REPORT_HASH 1
+_ACEOF
 
-  ;
-  return 0;
-}
+ac_fn_c_check_member "$LINENO" "struct crypto_report_hash" "digestsize" "ac_cv_member_struct_crypto_report_hash_digestsize" "$ac_includes_default
+#include <linux/cryptouser.h>
+"
+if test "x$ac_cv_member_struct_crypto_report_hash_digestsize" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_CRYPTO_REPORT_HASH_DIGESTSIZE 1
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror=yes
-else
-  gl_cv_warn_CFLAGS_FOR_BUILD__Werror=no
-fi
-rm -f core conftest.err conftest.$ac_build_objext \
-    conftest$ac_build_exeext conftest.$ac_ext
-  CFLAGS_FOR_BUILD="$gl_save_compiler_FLAGS"
+
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $gl_cv_warn_CFLAGS_FOR_BUILD__Werror" >&5
-$as_echo "$gl_cv_warn_CFLAGS_FOR_BUILD__Werror" >&6; }
-if test "x$gl_cv_warn_CFLAGS_FOR_BUILD__Werror" = xyes; then :
-  as_fn_append WARN_CFLAGS_FOR_BUILD " -Werror"
+
 fi
 
- ;;
-     no)  ;;
-     *)   as_fn_error $? "bad value $enableval for gcc-Werror option" "$LINENO" 5 ;;
-   esac
 
-fi
+ac_fn_c_check_type "$LINENO" "struct crypto_report_cipher" "ac_cv_type_struct_crypto_report_cipher" "$ac_includes_default
+#include <linux/cryptouser.h>
+"
+if test "x$ac_cv_type_struct_crypto_report_cipher" = xyes; then :
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_CRYPTO_REPORT_CIPHER 1
+_ACEOF
 
+ac_fn_c_check_member "$LINENO" "struct crypto_report_cipher" "max_keysize" "ac_cv_member_struct_crypto_report_cipher_max_keysize" "$ac_includes_default
+#include <linux/cryptouser.h>
+"
+if test "x$ac_cv_member_struct_crypto_report_cipher_max_keysize" = xyes; then :
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_CRYPTO_REPORT_CIPHER_MAX_KEYSIZE 1
+_ACEOF
 
-if test -n "${st_saved_cross_compiling+set}"; then :
-  cross_compiling="${st_saved_cross_compiling}"; unset st_saved_cross_compiling
-fi
 
-if test -n "${st_saved_ac_tool_prefix+set}"; then :
-  ac_tool_prefix="${st_saved_ac_tool_prefix}"; unset st_saved_ac_tool_prefix
 fi
 
-if test -n "${st_saved_ac_link+set}"; then :
-  ac_link="${st_saved_ac_link}"; unset st_saved_ac_link
 fi
 
-if test -n "${st_saved_ac_cv_c_decl_report+set}"; then :
-  ac_cv_c_decl_report="${st_saved_ac_cv_c_decl_report}"; unset st_saved_ac_cv_c_decl_report
-fi
 
-if test -n "${st_saved_ac_cv_c_compiler_gnu+set}"; then :
-  ac_cv_c_compiler_gnu="${st_saved_ac_cv_c_compiler_gnu}"; unset st_saved_ac_cv_c_compiler_gnu
-fi
+ac_fn_c_check_type "$LINENO" "struct crypto_report_blkcipher" "ac_cv_type_struct_crypto_report_blkcipher" "$ac_includes_default
+#include <linux/cryptouser.h>
+"
+if test "x$ac_cv_type_struct_crypto_report_blkcipher" = xyes; then :
 
-if test -n "${st_saved_ac_cpp+set}"; then :
-  ac_cpp="${st_saved_ac_cpp}"; unset st_saved_ac_cpp
-fi
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_CRYPTO_REPORT_BLKCIPHER 1
+_ACEOF
 
-if test -n "${st_saved_ac_compiler_gnu+set}"; then :
-  ac_compiler_gnu="${st_saved_ac_compiler_gnu}"; unset st_saved_ac_compiler_gnu
-fi
+ac_fn_c_check_member "$LINENO" "struct crypto_report_blkcipher" "ivsize" "ac_cv_member_struct_crypto_report_blkcipher_ivsize" "$ac_includes_default
+#include <linux/cryptouser.h>
+"
+if test "x$ac_cv_member_struct_crypto_report_blkcipher_ivsize" = xyes; then :
 
-if test -n "${st_saved_ac_compile+set}"; then :
-  ac_compile="${st_saved_ac_compile}"; unset st_saved_ac_compile
-fi
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_CRYPTO_REPORT_BLKCIPHER_IVSIZE 1
+_ACEOF
 
-if test -n "${st_saved_ac_c_werror_flag+set}"; then :
-  ac_c_werror_flag="${st_saved_ac_c_werror_flag}"; unset st_saved_ac_c_werror_flag
-fi
 
-if test -n "${st_saved_ac_c_preproc_warn_flag+set}"; then :
-  ac_c_preproc_warn_flag="${st_saved_ac_c_preproc_warn_flag}"; unset st_saved_ac_c_preproc_warn_flag
 fi
 
-if test -n "${st_saved_ac_c_decl_warn_flag+set}"; then :
-  ac_c_decl_warn_flag="${st_saved_ac_c_decl_warn_flag}"; unset st_saved_ac_c_decl_warn_flag
 fi
 
 
+ac_fn_c_check_type "$LINENO" "struct crypto_report_aead" "ac_cv_type_struct_crypto_report_aead" "$ac_includes_default
+#include <linux/cryptouser.h>
+"
+if test "x$ac_cv_type_struct_crypto_report_aead" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_CRYPTO_REPORT_AEAD 1
+_ACEOF
 
-BUILD_EXEEXT=$ac_build_exeext
-BUILD_OBJEXT=$ac_build_objext
+ac_fn_c_check_member "$LINENO" "struct crypto_report_aead" "ivsize" "ac_cv_member_struct_crypto_report_aead_ivsize" "$ac_includes_default
+#include <linux/cryptouser.h>
+"
+if test "x$ac_cv_member_struct_crypto_report_aead_ivsize" = xyes; then :
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_CRYPTO_REPORT_AEAD_IVSIZE 1
+_ACEOF
 
-if test -n "$ac_tool_prefix"; then
-  # Extract the first word of "${ac_tool_prefix}ranlib", so it can be a program name with args.
-set dummy ${ac_tool_prefix}ranlib; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_prog_RANLIB+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-  if test -n "$RANLIB"; then
-  ac_cv_prog_RANLIB="$RANLIB" # Let the user override the test.
-else
-as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
-for as_dir in $PATH
-do
-  IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
-    for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_prog_RANLIB="${ac_tool_prefix}ranlib"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
-    break 2
-  fi
-done
-  done
-IFS=$as_save_IFS
 
 fi
+
 fi
-RANLIB=$ac_cv_prog_RANLIB
-if test -n "$RANLIB"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $RANLIB" >&5
-$as_echo "$RANLIB" >&6; }
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
-fi
+
+
+ac_fn_c_check_type "$LINENO" "struct crypto_report_rng" "ac_cv_type_struct_crypto_report_rng" "$ac_includes_default
+#include <linux/cryptouser.h>
+"
+if test "x$ac_cv_type_struct_crypto_report_rng" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_CRYPTO_REPORT_RNG 1
+_ACEOF
+
+ac_fn_c_check_member "$LINENO" "struct crypto_report_rng" "seedsize" "ac_cv_member_struct_crypto_report_rng_seedsize" "$ac_includes_default
+#include <linux/cryptouser.h>
+"
+if test "x$ac_cv_member_struct_crypto_report_rng_seedsize" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_CRYPTO_REPORT_RNG_SEEDSIZE 1
+_ACEOF
 
 
 fi
-if test -z "$ac_cv_prog_RANLIB"; then
-  ac_ct_RANLIB=$RANLIB
-  # Extract the first word of "ranlib", so it can be a program name with args.
-set dummy ranlib; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_prog_ac_ct_RANLIB+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-  if test -n "$ac_ct_RANLIB"; then
-  ac_cv_prog_ac_ct_RANLIB="$ac_ct_RANLIB" # Let the user override the test.
-else
-as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
-for as_dir in $PATH
-do
-  IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
-    for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_prog_ac_ct_RANLIB="ranlib"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
-    break 2
-  fi
-done
-  done
-IFS=$as_save_IFS
 
 fi
-fi
-ac_ct_RANLIB=$ac_cv_prog_ac_ct_RANLIB
-if test -n "$ac_ct_RANLIB"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_ct_RANLIB" >&5
-$as_echo "$ac_ct_RANLIB" >&6; }
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
-fi
 
-  if test "x$ac_ct_RANLIB" = x; then
-    RANLIB=":"
-  else
-    case $cross_compiling:$ac_tool_warned in
-yes:)
-{ $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: using cross tools not prefixed with host triplet" >&5
-$as_echo "$as_me: WARNING: using cross tools not prefixed with host triplet" >&2;}
-ac_tool_warned=yes ;;
-esac
-    RANLIB=$ac_ct_RANLIB
-  fi
-else
-  RANLIB="$ac_cv_prog_RANLIB"
+
 fi
 
+done
 
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for grep that handles long lines and -e" >&5
-$as_echo_n "checking for grep that handles long lines and -e... " >&6; }
-if ${ac_cv_path_GREP+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-  if test -z "$GREP"; then
-  ac_path_GREP_found=false
-  # Loop through the user's path and test for each of PROGNAME-LIST
-  as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
-for as_dir in $PATH$PATH_SEPARATOR/usr/xpg4/bin
-do
-  IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
-    for ac_prog in grep ggrep; do
-    for ac_exec_ext in '' $ac_executable_extensions; do
-      ac_path_GREP="$as_dir/$ac_prog$ac_exec_ext"
-      as_fn_executable_p "$ac_path_GREP" || continue
-# Check for GNU ac_path_GREP and select it if it is found.
-  # Check for GNU $ac_path_GREP
-case `"$ac_path_GREP" --version 2>&1` in
-*GNU*)
-  ac_cv_path_GREP="$ac_path_GREP" ac_path_GREP_found=:;;
-*)
-  ac_count=0
-  $as_echo_n 0123456789 >"conftest.in"
-  while :
-  do
-    cat "conftest.in" "conftest.in" >"conftest.tmp"
-    mv "conftest.tmp" "conftest.in"
-    cp "conftest.in" "conftest.nl"
-    $as_echo 'GREP' >> "conftest.nl"
-    "$ac_path_GREP" -e 'GREP$' -e '-(cannot match)-' < "conftest.nl" >"conftest.out" 2>/dev/null || break
-    diff "conftest.out" "conftest.nl" >/dev/null 2>&1 || break
-    as_fn_arith $ac_count + 1 && ac_count=$as_val
-    if test $ac_count -gt ${ac_path_GREP_max-0}; then
-      # Best one so far, save it but keep looking for a better one
-      ac_cv_path_GREP="$ac_path_GREP"
-      ac_path_GREP_max=$ac_count
-    fi
-    # 10*(2^10) chars as input seems more than enough
-    test $ac_count -gt 10 && break
-  done
-  rm -f conftest.in conftest.tmp conftest.nl conftest.out;;
-esac
+for ac_header in linux/input.h
+do :
+  ac_fn_c_check_header_compile "$LINENO" "linux/input.h" "ac_cv_header_linux_input_h" "$ac_includes_default
 
-      $ac_path_GREP_found && break 3
-    done
-  done
-  done
-IFS=$as_save_IFS
-  if test -z "$ac_cv_path_GREP"; then
-    as_fn_error $? "no acceptable grep could be found in $PATH$PATH_SEPARATOR/usr/xpg4/bin" "$LINENO" 5
-  fi
-else
-  ac_cv_path_GREP=$GREP
-fi
+"
+if test "x$ac_cv_header_linux_input_h" = xyes; then :
+  cat >>confdefs.h <<_ACEOF
+#define HAVE_LINUX_INPUT_H 1
+_ACEOF
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_path_GREP" >&5
-$as_echo "$ac_cv_path_GREP" >&6; }
- GREP="$ac_cv_path_GREP"
 
+ac_fn_c_check_type "$LINENO" "struct input_absinfo" "ac_cv_type_struct_input_absinfo" "$ac_includes_default
+#include <linux/input.h>
+"
+if test "x$ac_cv_type_struct_input_absinfo" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_INPUT_ABSINFO 1
+_ACEOF
+
+ac_fn_c_check_member "$LINENO" "struct input_absinfo" "resolution" "ac_cv_member_struct_input_absinfo_resolution" "$ac_includes_default
+#include <linux/input.h>
+"
+if test "x$ac_cv_member_struct_input_absinfo_resolution" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_INPUT_ABSINFO_RESOLUTION 1
+_ACEOF
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for egrep" >&5
-$as_echo_n "checking for egrep... " >&6; }
-if ${ac_cv_path_EGREP+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-  if echo a | $GREP -E '(a|b)' >/dev/null 2>&1
-   then ac_cv_path_EGREP="$GREP -E"
-   else
-     if test -z "$EGREP"; then
-  ac_path_EGREP_found=false
-  # Loop through the user's path and test for each of PROGNAME-LIST
-  as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
-for as_dir in $PATH$PATH_SEPARATOR/usr/xpg4/bin
-do
-  IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
-    for ac_prog in egrep; do
-    for ac_exec_ext in '' $ac_executable_extensions; do
-      ac_path_EGREP="$as_dir/$ac_prog$ac_exec_ext"
-      as_fn_executable_p "$ac_path_EGREP" || continue
-# Check for GNU ac_path_EGREP and select it if it is found.
-  # Check for GNU $ac_path_EGREP
-case `"$ac_path_EGREP" --version 2>&1` in
-*GNU*)
-  ac_cv_path_EGREP="$ac_path_EGREP" ac_path_EGREP_found=:;;
-*)
-  ac_count=0
-  $as_echo_n 0123456789 >"conftest.in"
-  while :
-  do
-    cat "conftest.in" "conftest.in" >"conftest.tmp"
-    mv "conftest.tmp" "conftest.in"
-    cp "conftest.in" "conftest.nl"
-    $as_echo 'EGREP' >> "conftest.nl"
-    "$ac_path_EGREP" 'EGREP$' < "conftest.nl" >"conftest.out" 2>/dev/null || break
-    diff "conftest.out" "conftest.nl" >/dev/null 2>&1 || break
-    as_fn_arith $ac_count + 1 && ac_count=$as_val
-    if test $ac_count -gt ${ac_path_EGREP_max-0}; then
-      # Best one so far, save it but keep looking for a better one
-      ac_cv_path_EGREP="$ac_path_EGREP"
-      ac_path_EGREP_max=$ac_count
-    fi
-    # 10*(2^10) chars as input seems more than enough
-    test $ac_count -gt 10 && break
-  done
-  rm -f conftest.in conftest.tmp conftest.nl conftest.out;;
-esac
 
-      $ac_path_EGREP_found && break 3
-    done
-  done
-  done
-IFS=$as_save_IFS
-  if test -z "$ac_cv_path_EGREP"; then
-    as_fn_error $? "no acceptable egrep could be found in $PATH$PATH_SEPARATOR/usr/xpg4/bin" "$LINENO" 5
-  fi
-else
-  ac_cv_path_EGREP=$EGREP
 fi
 
-   fi
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_path_EGREP" >&5
-$as_echo "$ac_cv_path_EGREP" >&6; }
- EGREP="$ac_cv_path_EGREP"
 
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for ANSI C header files" >&5
-$as_echo_n "checking for ANSI C header files... " >&6; }
-if ${ac_cv_header_stdc+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-#include <stdlib.h>
-#include <stdarg.h>
-#include <string.h>
-#include <float.h>
+ac_fn_c_check_type "$LINENO" "struct input_keymap_entry" "ac_cv_type_struct_input_keymap_entry" "$ac_includes_default
+#include <linux/input.h>
+"
+if test "x$ac_cv_type_struct_input_keymap_entry" = xyes; then :
 
-int
-main ()
-{
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_INPUT_KEYMAP_ENTRY 1
+_ACEOF
 
-  ;
-  return 0;
-}
+ac_fn_c_check_member "$LINENO" "struct input_keymap_entry" "scancode" "ac_cv_member_struct_input_keymap_entry_scancode" "$ac_includes_default
+#include <linux/input.h>
+"
+if test "x$ac_cv_member_struct_input_keymap_entry_scancode" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_INPUT_KEYMAP_ENTRY_SCANCODE 1
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
-  ac_cv_header_stdc=yes
-else
-  ac_cv_header_stdc=no
+
+
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
 
-if test $ac_cv_header_stdc = yes; then
-  # SunOS 4.x string.h does not declare mem*, contrary to ANSI.
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-#include <string.h>
+fi
 
+
+ac_fn_c_check_type "$LINENO" "struct input_mask" "ac_cv_type_struct_input_mask" "$ac_includes_default
+#include <linux/input.h>
+"
+if test "x$ac_cv_type_struct_input_mask" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_INPUT_MASK 1
+_ACEOF
+
+ac_fn_c_check_member "$LINENO" "struct input_mask" "codes_ptr" "ac_cv_member_struct_input_mask_codes_ptr" "$ac_includes_default
+#include <linux/input.h>
+"
+if test "x$ac_cv_member_struct_input_mask_codes_ptr" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_INPUT_MASK_CODES_PTR 1
 _ACEOF
-if (eval "$ac_cpp conftest.$ac_ext") 2>&5 |
-  $EGREP "memchr" >/dev/null 2>&1; then :
 
-else
-  ac_cv_header_stdc=no
+
 fi
-rm -f conftest*
 
 fi
 
-if test $ac_cv_header_stdc = yes; then
-  # ISC 2.0.2 stdlib.h does not declare free, contrary to ANSI.
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-#include <stdlib.h>
 
+fi
+
+done
+
+
+for ac_header in linux/io_uring.h
+do :
+  ac_fn_c_check_header_compile "$LINENO" "linux/io_uring.h" "ac_cv_header_linux_io_uring_h" "$ac_includes_default
+
+"
+if test "x$ac_cv_header_linux_io_uring_h" = xyes; then :
+  cat >>confdefs.h <<_ACEOF
+#define HAVE_LINUX_IO_URING_H 1
 _ACEOF
-if (eval "$ac_cpp conftest.$ac_ext") 2>&5 |
-  $EGREP "free" >/dev/null 2>&1; then :
 
-else
-  ac_cv_header_stdc=no
-fi
-rm -f conftest*
 
-fi
+ac_fn_c_check_type "$LINENO" "struct io_sqring_offsets" "ac_cv_type_struct_io_sqring_offsets" "$ac_includes_default
+#include <linux/io_uring.h>
+"
+if test "x$ac_cv_type_struct_io_sqring_offsets" = xyes; then :
 
-if test $ac_cv_header_stdc = yes; then
-  # /bin/cc in Irix-4.0.5 gets non-ANSI ctype macros unless using -ansi.
-  if test "$cross_compiling" = yes; then :
-  :
-else
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-#include <ctype.h>
-#include <stdlib.h>
-#if ((' ' & 0x0FF) == 0x020)
-# define ISLOWER(c) ('a' <= (c) && (c) <= 'z')
-# define TOUPPER(c) (ISLOWER(c) ? 'A' + ((c) - 'a') : (c))
-#else
-# define ISLOWER(c) \
-		   (('a' <= (c) && (c) <= 'i') \
-		     || ('j' <= (c) && (c) <= 'r') \
-		     || ('s' <= (c) && (c) <= 'z'))
-# define TOUPPER(c) (ISLOWER(c) ? ((c) | 0x40) : (c))
-#endif
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_IO_SQRING_OFFSETS 1
+_ACEOF
 
-#define XOR(e, f) (((e) && !(f)) || (!(e) && (f)))
-int
-main ()
-{
-  int i;
-  for (i = 0; i < 256; i++)
-    if (XOR (islower (i), ISLOWER (i))
-	|| toupper (i) != TOUPPER (i))
-      return 2;
-  return 0;
-}
+ac_fn_c_check_member "$LINENO" "struct io_sqring_offsets" "resv2" "ac_cv_member_struct_io_sqring_offsets_resv2" "$ac_includes_default
+#include <linux/io_uring.h>
+"
+if test "x$ac_cv_member_struct_io_sqring_offsets_resv2" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_IO_SQRING_OFFSETS_RESV2 1
 _ACEOF
-if ac_fn_c_try_run "$LINENO"; then :
 
-else
-  ac_cv_header_stdc=no
-fi
-rm -f core *.core core.conftest.* gmon.out bb.out conftest$ac_exeext \
-  conftest.$ac_objext conftest.beam conftest.$ac_ext
-fi
 
 fi
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_header_stdc" >&5
-$as_echo "$ac_cv_header_stdc" >&6; }
-if test $ac_cv_header_stdc = yes; then
-
-$as_echo "#define STDC_HEADERS 1" >>confdefs.h
 
 fi
 
-# On IRIX 5.3, sys/types and inttypes.h are conflicting.
-for ac_header in sys/types.h sys/stat.h stdlib.h string.h memory.h strings.h \
-		  inttypes.h stdint.h unistd.h
-do :
-  as_ac_Header=`$as_echo "ac_cv_header_$ac_header" | $as_tr_sh`
-ac_fn_c_check_header_compile "$LINENO" "$ac_header" "$as_ac_Header" "$ac_includes_default
+
+ac_fn_c_check_type "$LINENO" "struct io_cqring_offsets" "ac_cv_type_struct_io_cqring_offsets" "$ac_includes_default
+#include <linux/io_uring.h>
 "
-if eval test \"x\$"$as_ac_Header"\" = x"yes"; then :
-  cat >>confdefs.h <<_ACEOF
-#define `$as_echo "HAVE_$ac_header" | $as_tr_cpp` 1
+if test "x$ac_cv_type_struct_io_cqring_offsets" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_IO_CQRING_OFFSETS 1
 _ACEOF
 
-fi
+ac_fn_c_check_member "$LINENO" "struct io_cqring_offsets" "cqes" "ac_cv_member_struct_io_cqring_offsets_cqes" "$ac_includes_default
+#include <linux/io_uring.h>
+"
+if test "x$ac_cv_member_struct_io_cqring_offsets_cqes" = xyes; then :
 
-done
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_IO_CQRING_OFFSETS_CQES 1
+_ACEOF
 
 
+fi
 
-  ac_fn_c_check_header_mongrel "$LINENO" "minix/config.h" "ac_cv_header_minix_config_h" "$ac_includes_default"
-if test "x$ac_cv_header_minix_config_h" = xyes; then :
-  MINIX=yes
-else
-  MINIX=
 fi
 
 
-  if test "$MINIX" = yes; then
+ac_fn_c_check_type "$LINENO" "struct io_uring_params" "ac_cv_type_struct_io_uring_params" "$ac_includes_default
+#include <linux/io_uring.h>
+"
+if test "x$ac_cv_type_struct_io_uring_params" = xyes; then :
 
-$as_echo "#define _POSIX_SOURCE 1" >>confdefs.h
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_IO_URING_PARAMS 1
+_ACEOF
+
+ac_fn_c_check_member "$LINENO" "struct io_uring_params" "cq_off" "ac_cv_member_struct_io_uring_params_cq_off" "$ac_includes_default
+#include <linux/io_uring.h>
+"
+if test "x$ac_cv_member_struct_io_uring_params_cq_off" = xyes; then :
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_IO_URING_PARAMS_CQ_OFF 1
+_ACEOF
 
-$as_echo "#define _POSIX_1_SOURCE 2" >>confdefs.h
 
+fi
 
-$as_echo "#define _MINIX 1" >>confdefs.h
+fi
 
-  fi
 
+ac_fn_c_check_type "$LINENO" "struct io_uring_files_update" "ac_cv_type_struct_io_uring_files_update" "$ac_includes_default
+#include <linux/io_uring.h>
+"
+if test "x$ac_cv_type_struct_io_uring_files_update" = xyes; then :
 
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether it is safe to define __EXTENSIONS__" >&5
-$as_echo_n "checking whether it is safe to define __EXTENSIONS__... " >&6; }
-if ${ac_cv_safe_to_define___extensions__+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_IO_URING_FILES_UPDATE 1
+_ACEOF
 
-#         define __EXTENSIONS__ 1
-          $ac_includes_default
-int
-main ()
-{
+ac_fn_c_check_member "$LINENO" "struct io_uring_files_update" "fds" "ac_cv_member_struct_io_uring_files_update_fds" "$ac_includes_default
+#include <linux/io_uring.h>
+"
+if test "x$ac_cv_member_struct_io_uring_files_update_fds" = xyes; then :
 
-  ;
-  return 0;
-}
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_IO_URING_FILES_UPDATE_FDS 1
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
-  ac_cv_safe_to_define___extensions__=yes
-else
-  ac_cv_safe_to_define___extensions__=no
+
+
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_safe_to_define___extensions__" >&5
-$as_echo "$ac_cv_safe_to_define___extensions__" >&6; }
-  test $ac_cv_safe_to_define___extensions__ = yes &&
-    $as_echo "#define __EXTENSIONS__ 1" >>confdefs.h
 
-  $as_echo "#define _ALL_SOURCE 1" >>confdefs.h
 
-  $as_echo "#define _GNU_SOURCE 1" >>confdefs.h
+ac_fn_c_check_type "$LINENO" "struct io_uring_probe_op" "ac_cv_type_struct_io_uring_probe_op" "$ac_includes_default
+#include <linux/io_uring.h>
+"
+if test "x$ac_cv_type_struct_io_uring_probe_op" = xyes; then :
 
-  $as_echo "#define _POSIX_PTHREAD_SEMANTICS 1" >>confdefs.h
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_IO_URING_PROBE_OP 1
+_ACEOF
 
-  $as_echo "#define _TANDEM_SOURCE 1" >>confdefs.h
+ac_fn_c_check_member "$LINENO" "struct io_uring_probe_op" "resv2" "ac_cv_member_struct_io_uring_probe_op_resv2" "$ac_includes_default
+#include <linux/io_uring.h>
+"
+if test "x$ac_cv_member_struct_io_uring_probe_op_resv2" = xyes; then :
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_IO_URING_PROBE_OP_RESV2 1
+_ACEOF
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for a sed that does not truncate output" >&5
-$as_echo_n "checking for a sed that does not truncate output... " >&6; }
-if ${ac_cv_path_SED+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-            ac_script=s/aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa/bbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb/
-     for ac_i in 1 2 3 4 5 6 7; do
-       ac_script="$ac_script$as_nl$ac_script"
-     done
-     echo "$ac_script" 2>/dev/null | sed 99q >conftest.sed
-     { ac_script=; unset ac_script;}
-     if test -z "$SED"; then
-  ac_path_SED_found=false
-  # Loop through the user's path and test for each of PROGNAME-LIST
-  as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
-for as_dir in $PATH
-do
-  IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
-    for ac_prog in sed gsed; do
-    for ac_exec_ext in '' $ac_executable_extensions; do
-      ac_path_SED="$as_dir/$ac_prog$ac_exec_ext"
-      as_fn_executable_p "$ac_path_SED" || continue
-# Check for GNU ac_path_SED and select it if it is found.
-  # Check for GNU $ac_path_SED
-case `"$ac_path_SED" --version 2>&1` in
-*GNU*)
-  ac_cv_path_SED="$ac_path_SED" ac_path_SED_found=:;;
-*)
-  ac_count=0
-  $as_echo_n 0123456789 >"conftest.in"
-  while :
-  do
-    cat "conftest.in" "conftest.in" >"conftest.tmp"
-    mv "conftest.tmp" "conftest.in"
-    cp "conftest.in" "conftest.nl"
-    $as_echo '' >> "conftest.nl"
-    "$ac_path_SED" -f conftest.sed < "conftest.nl" >"conftest.out" 2>/dev/null || break
-    diff "conftest.out" "conftest.nl" >/dev/null 2>&1 || break
-    as_fn_arith $ac_count + 1 && ac_count=$as_val
-    if test $ac_count -gt ${ac_path_SED_max-0}; then
-      # Best one so far, save it but keep looking for a better one
-      ac_cv_path_SED="$ac_path_SED"
-      ac_path_SED_max=$ac_count
-    fi
-    # 10*(2^10) chars as input seems more than enough
-    test $ac_count -gt 10 && break
-  done
-  rm -f conftest.in conftest.tmp conftest.nl conftest.out;;
-esac
 
-      $ac_path_SED_found && break 3
-    done
-  done
-  done
-IFS=$as_save_IFS
-  if test -z "$ac_cv_path_SED"; then
-    as_fn_error $? "no acceptable sed could be found in \$PATH" "$LINENO" 5
-  fi
-else
-  ac_cv_path_SED=$SED
 fi
 
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_path_SED" >&5
-$as_echo "$ac_cv_path_SED" >&6; }
- SED="$ac_cv_path_SED"
-  rm -f conftest.sed
+fi
+
+
+ac_fn_c_check_type "$LINENO" "struct io_uring_probe" "ac_cv_type_struct_io_uring_probe" "$ac_includes_default
+#include <linux/io_uring.h>
+"
+if test "x$ac_cv_type_struct_io_uring_probe" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_IO_URING_PROBE 1
+_ACEOF
 
+ac_fn_c_check_member "$LINENO" "struct io_uring_probe" "ops" "ac_cv_member_struct_io_uring_probe_ops" "$ac_includes_default
+#include <linux/io_uring.h>
+"
+if test "x$ac_cv_member_struct_io_uring_probe_ops" = xyes; then :
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_IO_URING_PROBE_OPS 1
+_ACEOF
 
 
-	# allow to override gcov location
+fi
 
-# Check whether --with-gcov was given.
-if test "${with_gcov+set}" = set; then :
-  withval=$with_gcov; _AX_CODE_COVERAGE_GCOV_PROG_WITH=$with_gcov
-else
-  _AX_CODE_COVERAGE_GCOV_PROG_WITH=gcov
 fi
 
 
-	{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether to build with code coverage support" >&5
-$as_echo_n "checking whether to build with code coverage support... " >&6; }
-	# Check whether --enable-code-coverage was given.
-if test "${enable_code_coverage+set}" = set; then :
-  enableval=$enable_code_coverage;
-else
-  enable_code_coverage=no
 fi
 
+done
 
-	 if test x$enable_code_coverage = xyes; then
-  CODE_COVERAGE_ENABLED_TRUE=
-  CODE_COVERAGE_ENABLED_FALSE='#'
-else
-  CODE_COVERAGE_ENABLED_TRUE='#'
-  CODE_COVERAGE_ENABLED_FALSE=
-fi
 
-	CODE_COVERAGE_ENABLED=$enable_code_coverage
+for ac_header in linux/loop.h
+do :
+  ac_fn_c_check_header_compile "$LINENO" "linux/loop.h" "ac_cv_header_linux_loop_h" "$ac_includes_default
+#include <linux/ioctl.h>
+"
+if test "x$ac_cv_header_linux_loop_h" = xyes; then :
+  cat >>confdefs.h <<_ACEOF
+#define HAVE_LINUX_LOOP_H 1
+_ACEOF
 
-	{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $enable_code_coverage" >&5
-$as_echo "$enable_code_coverage" >&6; }
 
-	if  test "$enable_code_coverage" = "yes" ; then :
+ac_fn_c_check_type "$LINENO" "struct loop_config" "ac_cv_type_struct_loop_config" "$ac_includes_default
+#include <linux/ioctl.h>
+#include <linux/loop.h>
+"
+if test "x$ac_cv_type_struct_loop_config" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_LOOP_CONFIG 1
+_ACEOF
+
+ac_fn_c_check_member "$LINENO" "struct loop_config" "__reserved" "ac_cv_member_struct_loop_config___reserved" "$ac_includes_default
+#include <linux/ioctl.h>
+#include <linux/loop.h>
+"
+if test "x$ac_cv_member_struct_loop_config___reserved" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_LOOP_CONFIG___RESERVED 1
+_ACEOF
 
-		# check for gcov
-		if test -n "$ac_tool_prefix"; then
-  # Extract the first word of "${ac_tool_prefix}$_AX_CODE_COVERAGE_GCOV_PROG_WITH", so it can be a program name with args.
-set dummy ${ac_tool_prefix}$_AX_CODE_COVERAGE_GCOV_PROG_WITH; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_prog_GCOV+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-  if test -n "$GCOV"; then
-  ac_cv_prog_GCOV="$GCOV" # Let the user override the test.
-else
-as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
-for as_dir in $PATH
-do
-  IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
-    for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_prog_GCOV="${ac_tool_prefix}$_AX_CODE_COVERAGE_GCOV_PROG_WITH"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
-    break 2
-  fi
-done
-  done
-IFS=$as_save_IFS
 
 fi
-fi
-GCOV=$ac_cv_prog_GCOV
-if test -n "$GCOV"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $GCOV" >&5
-$as_echo "$GCOV" >&6; }
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+
 fi
 
 
 fi
-if test -z "$ac_cv_prog_GCOV"; then
-  ac_ct_GCOV=$GCOV
-  # Extract the first word of "$_AX_CODE_COVERAGE_GCOV_PROG_WITH", so it can be a program name with args.
-set dummy $_AX_CODE_COVERAGE_GCOV_PROG_WITH; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_prog_ac_ct_GCOV+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-  if test -n "$ac_ct_GCOV"; then
-  ac_cv_prog_ac_ct_GCOV="$ac_ct_GCOV" # Let the user override the test.
-else
-as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
-for as_dir in $PATH
-do
-  IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
-    for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_prog_ac_ct_GCOV="$_AX_CODE_COVERAGE_GCOV_PROG_WITH"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
-    break 2
-  fi
+
 done
-  done
-IFS=$as_save_IFS
+
+
+for ac_header in linux/openat2.h
+do :
+  ac_fn_c_check_header_compile "$LINENO" "linux/openat2.h" "ac_cv_header_linux_openat2_h" "$ac_includes_default
+
+"
+if test "x$ac_cv_header_linux_openat2_h" = xyes; then :
+  cat >>confdefs.h <<_ACEOF
+#define HAVE_LINUX_OPENAT2_H 1
+_ACEOF
+
+
+ac_fn_c_check_type "$LINENO" "struct open_how" "ac_cv_type_struct_open_how" "$ac_includes_default
+#include <linux/openat2.h>
+"
+if test "x$ac_cv_type_struct_open_how" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_OPEN_HOW 1
+_ACEOF
+
+ac_fn_c_check_member "$LINENO" "struct open_how" "resolve" "ac_cv_member_struct_open_how_resolve" "$ac_includes_default
+#include <linux/openat2.h>
+"
+if test "x$ac_cv_member_struct_open_how_resolve" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_OPEN_HOW_RESOLVE 1
+_ACEOF
+
 
 fi
+
 fi
-ac_ct_GCOV=$ac_cv_prog_ac_ct_GCOV
-if test -n "$ac_ct_GCOV"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_ct_GCOV" >&5
-$as_echo "$ac_ct_GCOV" >&6; }
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+
+
 fi
 
-  if test "x$ac_ct_GCOV" = x; then
-    GCOV=":"
-  else
-    case $cross_compiling:$ac_tool_warned in
-yes:)
-{ $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: using cross tools not prefixed with host triplet" >&5
-$as_echo "$as_me: WARNING: using cross tools not prefixed with host triplet" >&2;}
-ac_tool_warned=yes ;;
-esac
-    GCOV=$ac_ct_GCOV
-  fi
-else
-  GCOV="$ac_cv_prog_GCOV"
+done
+
+
+for ac_header in linux/rtnetlink.h
+do :
+  ac_fn_c_check_header_compile "$LINENO" "linux/rtnetlink.h" "ac_cv_header_linux_rtnetlink_h" "$ac_includes_default
+#include \"$srcdir/netlink.h\"
+"
+if test "x$ac_cv_header_linux_rtnetlink_h" = xyes; then :
+  cat >>confdefs.h <<_ACEOF
+#define HAVE_LINUX_RTNETLINK_H 1
+_ACEOF
+
+
+ac_fn_c_check_type "$LINENO" "struct rtnl_link_stats" "ac_cv_type_struct_rtnl_link_stats" "$ac_includes_default
+#include \"$srcdir/netlink.h\"
+#include <linux/rtnetlink.h>
+"
+if test "x$ac_cv_type_struct_rtnl_link_stats" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_RTNL_LINK_STATS 1
+_ACEOF
+
+ac_fn_c_check_member "$LINENO" "struct rtnl_link_stats" "rx_nohandler" "ac_cv_member_struct_rtnl_link_stats_rx_nohandler" "$ac_includes_default
+#include \"$srcdir/netlink.h\"
+#include <linux/rtnetlink.h>
+"
+if test "x$ac_cv_member_struct_rtnl_link_stats_rx_nohandler" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_RTNL_LINK_STATS_RX_NOHANDLER 1
+_ACEOF
+
+
 fi
 
-		if test "X$GCOV" = "X:"; then :
-  as_fn_error $? "gcov is needed to do coverage" "$LINENO" 5
 fi
 
 
-				if  test "$GCC" = "no" ; then :
+ac_fn_c_check_type "$LINENO" "struct rtnl_link_stats64" "ac_cv_type_struct_rtnl_link_stats64" "$ac_includes_default
+#include \"$srcdir/netlink.h\"
+#include <linux/rtnetlink.h>
+"
+if test "x$ac_cv_type_struct_rtnl_link_stats64" = xyes; then :
 
-			as_fn_error $? "not compiling with gcc, which is required for gcov code coverage" "$LINENO" 5
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_RTNL_LINK_STATS64 1
+_ACEOF
 
-fi
+ac_fn_c_check_member "$LINENO" "struct rtnl_link_stats64" "rx_nohandler" "ac_cv_member_struct_rtnl_link_stats64_rx_nohandler" "$ac_includes_default
+#include \"$srcdir/netlink.h\"
+#include <linux/rtnetlink.h>
+"
+if test "x$ac_cv_member_struct_rtnl_link_stats64_rx_nohandler" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_RTNL_LINK_STATS64_RX_NOHANDLER 1
+_ACEOF
 
-		# Extract the first word of "lcov", so it can be a program name with args.
-set dummy lcov; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_prog_LCOV+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-  if test -n "$LCOV"; then
-  ac_cv_prog_LCOV="$LCOV" # Let the user override the test.
-else
-as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
-for as_dir in $PATH
-do
-  IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
-    for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_prog_LCOV="lcov"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
-    break 2
-  fi
-done
-  done
-IFS=$as_save_IFS
 
 fi
+
 fi
-LCOV=$ac_cv_prog_LCOV
-if test -n "$LCOV"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $LCOV" >&5
-$as_echo "$LCOV" >&6; }
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
-fi
 
 
-		# Extract the first word of "genhtml", so it can be a program name with args.
-set dummy genhtml; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_prog_GENHTML+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-  if test -n "$GENHTML"; then
-  ac_cv_prog_GENHTML="$GENHTML" # Let the user override the test.
-else
-as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
-for as_dir in $PATH
-do
-  IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
-    for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_prog_GENHTML="genhtml"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
-    break 2
-  fi
-done
-  done
-IFS=$as_save_IFS
+ac_fn_c_check_type "$LINENO" "struct ifla_bridge_id" "ac_cv_type_struct_ifla_bridge_id" "$ac_includes_default
+#include \"$srcdir/netlink.h\"
+#include <linux/rtnetlink.h>
+"
+if test "x$ac_cv_type_struct_ifla_bridge_id" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_IFLA_BRIDGE_ID 1
+_ACEOF
+
+ac_fn_c_check_member "$LINENO" "struct ifla_bridge_id" "addr" "ac_cv_member_struct_ifla_bridge_id_addr" "$ac_includes_default
+#include \"$srcdir/netlink.h\"
+#include <linux/rtnetlink.h>
+"
+if test "x$ac_cv_member_struct_ifla_bridge_id_addr" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_IFLA_BRIDGE_ID_ADDR 1
+_ACEOF
+
 
 fi
-fi
-GENHTML=$ac_cv_prog_GENHTML
-if test -n "$GENHTML"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $GENHTML" >&5
-$as_echo "$GENHTML" >&6; }
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
+
 fi
 
 
+ac_fn_c_check_type "$LINENO" "struct ifla_port_vsi" "ac_cv_type_struct_ifla_port_vsi" "$ac_includes_default
+#include \"$srcdir/netlink.h\"
+#include <linux/rtnetlink.h>
+"
+if test "x$ac_cv_type_struct_ifla_port_vsi" = xyes; then :
 
-		if  test -z "$LCOV" ; then :
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_IFLA_PORT_VSI 1
+_ACEOF
+
+ac_fn_c_check_member "$LINENO" "struct ifla_port_vsi" "pad" "ac_cv_member_struct_ifla_port_vsi_pad" "$ac_includes_default
+#include \"$srcdir/netlink.h\"
+#include <linux/rtnetlink.h>
+"
+if test "x$ac_cv_member_struct_ifla_port_vsi_pad" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_IFLA_PORT_VSI_PAD 1
+_ACEOF
 
-			as_fn_error $? "To enable code coverage reporting you must have lcov installed" "$LINENO" 5
 
 fi
 
-		if  test -z "$GENHTML" ; then :
+fi
 
-			as_fn_error $? "Could not find genhtml from the lcov package" "$LINENO" 5
 
 fi
 
-						CODE_COVERAGE_CPPFLAGS="-DENABLE_COVERAGE_GCOV -DNDEBUG"
-		CODE_COVERAGE_CFLAGS="-O0 -g -fprofile-arcs -ftest-coverage"
-		CODE_COVERAGE_CXXFLAGS="-O0 -g -fprofile-arcs -ftest-coverage"
-		CODE_COVERAGE_LIBS="-lgcov"
-		CODE_COVERAGE_LDFLAGS="$CODE_COVERAGE_LIBS"
+done
 
 
+for ac_header in linux/if_bridge.h
+do :
+  ac_fn_c_check_header_compile "$LINENO" "linux/if_bridge.h" "ac_cv_header_linux_if_bridge_h" "$ac_includes_default
+#include <netinet/in.h>
+"
+if test "x$ac_cv_header_linux_if_bridge_h" = xyes; then :
+  cat >>confdefs.h <<_ACEOF
+#define HAVE_LINUX_IF_BRIDGE_H 1
+_ACEOF
 
 
+ac_fn_c_check_type "$LINENO" "struct br_port_msg" "ac_cv_type_struct_br_port_msg" "$ac_includes_default
+#include <netinet/in.h>
+#include <linux/if_bridge.h>
+"
+if test "x$ac_cv_type_struct_br_port_msg" = xyes; then :
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BR_PORT_MSG 1
+_ACEOF
 
+ac_fn_c_check_member "$LINENO" "struct br_port_msg" "ifindex" "ac_cv_member_struct_br_port_msg_ifindex" "$ac_includes_default
+#include <netinet/in.h>
+#include <linux/if_bridge.h>
+"
+if test "x$ac_cv_member_struct_br_port_msg_ifindex" = xyes; then :
 
-		CODE_COVERAGE_RULES_CHECK='
-	-$(A''M_V_at)$(MAKE) $(AM_MAKEFLAGS) -k check
-	$(A''M_V_at)$(MAKE) $(AM_MAKEFLAGS) code-coverage-capture
-'
-		CODE_COVERAGE_RULES_CAPTURE='
-	$(code_coverage_v_lcov_cap)$(LCOV) $(code_coverage_quiet) $(addprefix --directory ,$(CODE_COVERAGE_DIRECTORY)) --capture --output-file "$(CODE_COVERAGE_OUTPUT_FILE).tmp" --test-name "$(call code_coverage_sanitize,$(PACKAGE_NAME)-$(PACKAGE_VERSION))" --no-checksum --compat-libtool $(CODE_COVERAGE_LCOV_SHOPTS) $(CODE_COVERAGE_LCOV_OPTIONS)
-	$(code_coverage_v_lcov_ign)$(LCOV) $(code_coverage_quiet) $(addprefix --directory ,$(CODE_COVERAGE_DIRECTORY)) --remove "$(CODE_COVERAGE_OUTPUT_FILE).tmp" "/tmp/*" $(CODE_COVERAGE_IGNORE_PATTERN) --output-file "$(CODE_COVERAGE_OUTPUT_FILE)" $(CODE_COVERAGE_LCOV_SHOPTS) $(CODE_COVERAGE_LCOV_RMOPTS)
-	-@rm -f $(CODE_COVERAGE_OUTPUT_FILE).tmp
-	$(code_coverage_v_genhtml)LANG=C $(GENHTML) $(code_coverage_quiet) $(addprefix --prefix ,$(CODE_COVERAGE_DIRECTORY)) --output-directory "$(CODE_COVERAGE_OUTPUT_DIRECTORY)" --title "$(PACKAGE_NAME)-$(PACKAGE_VERSION) Code Coverage" --legend --show-details "$(CODE_COVERAGE_OUTPUT_FILE)" $(CODE_COVERAGE_GENHTML_OPTIONS)
-	@echo "file://$(abs_builddir)/$(CODE_COVERAGE_OUTPUT_DIRECTORY)/index.html"
-'
-		CODE_COVERAGE_RULES_CLEAN='
-clean: code-coverage-clean
-distclean: code-coverage-clean
-code-coverage-clean:
-	-$(LCOV) --directory $(top_builddir) -z
-	-rm -rf $(CODE_COVERAGE_OUTPUT_FILE) $(CODE_COVERAGE_OUTPUT_FILE).tmp $(CODE_COVERAGE_OUTPUT_DIRECTORY)
-	-find . \( -name "*.gcda" -o -name "*.gcno" -o -name "*.gcov" \) -delete
-'
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BR_PORT_MSG_IFINDEX 1
+_ACEOF
 
-else
 
-		CODE_COVERAGE_RULES_CHECK='
-	@echo "Need to reconfigure with --enable-code-coverage"
-'
-		CODE_COVERAGE_RULES_CAPTURE="$CODE_COVERAGE_RULES_CHECK"
-		CODE_COVERAGE_RULES_CLEAN=''
+fi
 
 fi
 
-CODE_COVERAGE_RULES='
-# Code coverage
-#
-# Optional:
-#  - CODE_COVERAGE_DIRECTORY: Top-level directory for code coverage reporting.
-#    Multiple directories may be specified, separated by whitespace.
-#    (Default: $(top_builddir))
-#  - CODE_COVERAGE_OUTPUT_FILE: Filename and path for the .info file generated
-#    by lcov for code coverage. (Default:
-#    $(PACKAGE_NAME)-$(PACKAGE_VERSION)-coverage.info)
-#  - CODE_COVERAGE_OUTPUT_DIRECTORY: Directory for generated code coverage
-#    reports to be created. (Default:
-#    $(PACKAGE_NAME)-$(PACKAGE_VERSION)-coverage)
-#  - CODE_COVERAGE_BRANCH_COVERAGE: Set to 1 to enforce branch coverage,
-#    set to 0 to disable it and leave empty to stay with the default.
-#    (Default: empty)
-#  - CODE_COVERAGE_LCOV_SHOPTS_DEFAULT: Extra options shared between both lcov
-#    instances. (Default: based on $CODE_COVERAGE_BRANCH_COVERAGE)
-#  - CODE_COVERAGE_LCOV_SHOPTS: Extra options to shared between both lcov
-#    instances. (Default: $CODE_COVERAGE_LCOV_SHOPTS_DEFAULT)
-#  - CODE_COVERAGE_LCOV_OPTIONS_GCOVPATH: --gcov-tool pathtogcov
-#  - CODE_COVERAGE_LCOV_OPTIONS_DEFAULT: Extra options to pass to the
-#    collecting lcov instance. (Default: $CODE_COVERAGE_LCOV_OPTIONS_GCOVPATH)
-#  - CODE_COVERAGE_LCOV_OPTIONS: Extra options to pass to the collecting lcov
-#    instance. (Default: $CODE_COVERAGE_LCOV_OPTIONS_DEFAULT)
-#  - CODE_COVERAGE_LCOV_RMOPTS_DEFAULT: Extra options to pass to the filtering
-#    lcov instance. (Default: empty)
-#  - CODE_COVERAGE_LCOV_RMOPTS: Extra options to pass to the filtering lcov
-#    instance. (Default: $CODE_COVERAGE_LCOV_RMOPTS_DEFAULT)
-#  - CODE_COVERAGE_GENHTML_OPTIONS_DEFAULT: Extra options to pass to the
-#    genhtml instance. (Default: based on $CODE_COVERAGE_BRANCH_COVERAGE)
-#  - CODE_COVERAGE_GENHTML_OPTIONS: Extra options to pass to the genhtml
-#    instance. (Default: $CODE_COVERAGE_GENHTML_OPTIONS_DEFAULT)
-#  - CODE_COVERAGE_IGNORE_PATTERN: Extra glob pattern of files to ignore
-#
-# The generated report will be titled using the $(PACKAGE_NAME) and
-# $(PACKAGE_VERSION). In order to add the current git hash to the title,
-# use the git-version-gen script, available online.
 
-# Optional variables
-CODE_COVERAGE_DIRECTORY ?= $(top_builddir)
-CODE_COVERAGE_OUTPUT_FILE ?= $(PACKAGE_NAME)-$(PACKAGE_VERSION)-coverage.info
-CODE_COVERAGE_OUTPUT_DIRECTORY ?= $(PACKAGE_NAME)-$(PACKAGE_VERSION)-coverage
-CODE_COVERAGE_BRANCH_COVERAGE ?=
-CODE_COVERAGE_LCOV_SHOPTS_DEFAULT ?= $(if $(CODE_COVERAGE_BRANCH_COVERAGE),\
---rc lcov_branch_coverage=$(CODE_COVERAGE_BRANCH_COVERAGE))
-CODE_COVERAGE_LCOV_SHOPTS ?= $(CODE_COVERAGE_LCOV_SHOPTS_DEFAULT)
-CODE_COVERAGE_LCOV_OPTIONS_GCOVPATH ?= --gcov-tool "$(GCOV)"
-CODE_COVERAGE_LCOV_OPTIONS_DEFAULT ?= $(CODE_COVERAGE_LCOV_OPTIONS_GCOVPATH)
-CODE_COVERAGE_LCOV_OPTIONS ?= $(CODE_COVERAGE_LCOV_OPTIONS_DEFAULT)
-CODE_COVERAGE_LCOV_RMOPTS_DEFAULT ?=
-CODE_COVERAGE_LCOV_RMOPTS ?= $(CODE_COVERAGE_LCOV_RMOPTS_DEFAULT)
-CODE_COVERAGE_GENHTML_OPTIONS_DEFAULT ?=\
-$(if $(CODE_COVERAGE_BRANCH_COVERAGE),\
---rc genhtml_branch_coverage=$(CODE_COVERAGE_BRANCH_COVERAGE))
-CODE_COVERAGE_GENHTML_OPTIONS ?= $(CODE_COVERAGE_GENHTML_OPTIONS_DEFAULT)
-CODE_COVERAGE_IGNORE_PATTERN ?=
+ac_fn_c_check_type "$LINENO" "struct br_mdb_entry" "ac_cv_type_struct_br_mdb_entry" "$ac_includes_default
+#include <netinet/in.h>
+#include <linux/if_bridge.h>
+"
+if test "x$ac_cv_type_struct_br_mdb_entry" = xyes; then :
 
-code_coverage_v_lcov_cap = $(code_coverage_v_lcov_cap_$(V))
-code_coverage_v_lcov_cap_ = $(code_coverage_v_lcov_cap_$(AM_DEFAULT_VERBOSITY))
-code_coverage_v_lcov_cap_0 = @echo "  LCOV   --capture"\
- $(CODE_COVERAGE_OUTPUT_FILE);
-code_coverage_v_lcov_ign = $(code_coverage_v_lcov_ign_$(V))
-code_coverage_v_lcov_ign_ = $(code_coverage_v_lcov_ign_$(AM_DEFAULT_VERBOSITY))
-code_coverage_v_lcov_ign_0 = @echo "  LCOV   --remove /tmp/*"\
- $(CODE_COVERAGE_IGNORE_PATTERN);
-code_coverage_v_genhtml = $(code_coverage_v_genhtml_$(V))
-code_coverage_v_genhtml_ = $(code_coverage_v_genhtml_$(AM_DEFAULT_VERBOSITY))
-code_coverage_v_genhtml_0 = @echo "  GEN   " $(CODE_COVERAGE_OUTPUT_DIRECTORY);
-code_coverage_quiet = $(code_coverage_quiet_$(V))
-code_coverage_quiet_ = $(code_coverage_quiet_$(AM_DEFAULT_VERBOSITY))
-code_coverage_quiet_0 = --quiet
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BR_MDB_ENTRY 1
+_ACEOF
 
-# sanitizes the test-name: replaces with underscores: dashes and dots
-code_coverage_sanitize = $(subst -,_,$(subst .,_,$(1)))
+ac_fn_c_check_member "$LINENO" "struct br_mdb_entry" "addr" "ac_cv_member_struct_br_mdb_entry_addr" "$ac_includes_default
+#include <netinet/in.h>
+#include <linux/if_bridge.h>
+"
+if test "x$ac_cv_member_struct_br_mdb_entry_addr" = xyes; then :
 
-# Use recursive makes in order to ignore errors during check
-check-code-coverage:'"$CODE_COVERAGE_RULES_CHECK"'
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_BR_MDB_ENTRY_ADDR 1
+_ACEOF
 
-# Capture code coverage data
-code-coverage-capture: code-coverage-capture-hook'"$CODE_COVERAGE_RULES_CAPTURE"'
 
-# Hook rule executed before code-coverage-capture, overridable by the user
-code-coverage-capture-hook:
+fi
 
-'"$CODE_COVERAGE_RULES_CLEAN"'
+fi
 
-GITIGNOREFILES ?=
-GITIGNOREFILES += $(CODE_COVERAGE_OUTPUT_FILE) $(CODE_COVERAGE_OUTPUT_DIRECTORY)
 
-A''M_DISTCHECK_CONFIGURE_FLAGS ?=
-A''M_DISTCHECK_CONFIGURE_FLAGS += --disable-code-coverage
+fi
 
-.PHONY: check-code-coverage code-coverage-capture code-coverage-capture-hook code-coverage-clean
-'
+done
+
+
+for ac_header in linux/rtnetlink.h
+do :
+  ac_fn_c_check_header_compile "$LINENO" "linux/rtnetlink.h" "ac_cv_header_linux_rtnetlink_h" "$ac_includes_default
+#include \"$srcdir/netlink.h\"
+"
+if test "x$ac_cv_header_linux_rtnetlink_h" = xyes; then :
+  cat >>confdefs.h <<_ACEOF
+#define HAVE_LINUX_RTNETLINK_H 1
+_ACEOF
+
+
+ac_fn_c_check_type "$LINENO" "struct ndt_config" "ac_cv_type_struct_ndt_config" "$ac_includes_default
+#include \"$srcdir/netlink.h\"
+#include <linux/rtnetlink.h>
+"
+if test "x$ac_cv_type_struct_ndt_config" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_NDT_CONFIG 1
+_ACEOF
 
+ac_fn_c_check_member "$LINENO" "struct ndt_config" "ndtc_proxy_qlen" "ac_cv_member_struct_ndt_config_ndtc_proxy_qlen" "$ac_includes_default
+#include \"$srcdir/netlink.h\"
+#include <linux/rtnetlink.h>
+"
+if test "x$ac_cv_member_struct_ndt_config_ndtc_proxy_qlen" = xyes; then :
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_NDT_CONFIG_NDTC_PROXY_QLEN 1
+_ACEOF
 
 
+fi
 
+fi
 
-$as_echo "#define COPYRIGHT_YEAR \"2020\"" >>confdefs.h
 
-COPYRIGHT_YEAR=2020
+ac_fn_c_check_type "$LINENO" "struct ndt_stats" "ac_cv_type_struct_ndt_stats" "$ac_includes_default
+#include \"$srcdir/netlink.h\"
+#include <linux/rtnetlink.h>
+"
+if test "x$ac_cv_type_struct_ndt_stats" = xyes; then :
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_NDT_STATS 1
+_ACEOF
 
+ac_fn_c_check_member "$LINENO" "struct ndt_stats" "ndts_table_fulls" "ac_cv_member_struct_ndt_stats_ndts_table_fulls" "$ac_includes_default
+#include \"$srcdir/netlink.h\"
+#include <linux/rtnetlink.h>
+"
+if test "x$ac_cv_member_struct_ndt_stats_ndts_table_fulls" = xyes; then :
 
-$as_echo "#define MANPAGE_DATE \"2020-02-04\"" >>confdefs.h
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_NDT_STATS_NDTS_TABLE_FULLS 1
+_ACEOF
 
-MANPAGE_DATE=2020-02-04
 
+fi
 
- { $as_echo "$as_me:${as_lineno-$LINENO}: checking whether byte ordering is bigendian" >&5
-$as_echo_n "checking whether byte ordering is bigendian... " >&6; }
-if ${ac_cv_c_bigendian+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-  ac_cv_c_bigendian=unknown
-    # See if we're dealing with a universal compiler.
-    cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-#ifndef __APPLE_CC__
-	       not a universal capable compiler
-	     #endif
-	     typedef int dummy;
+fi
 
-_ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
 
-	# Check for potential -arch flags.  It is not universal unless
-	# there are at least two -arch flags with different values.
-	ac_arch=
-	ac_prev=
-	for ac_word in $CC $CFLAGS $CPPFLAGS $LDFLAGS; do
-	 if test -n "$ac_prev"; then
-	   case $ac_word in
-	     i?86 | x86_64 | ppc | ppc64)
-	       if test -z "$ac_arch" || test "$ac_arch" = "$ac_word"; then
-		 ac_arch=$ac_word
-	       else
-		 ac_cv_c_bigendian=universal
-		 break
-	       fi
-	       ;;
-	   esac
-	   ac_prev=
-	 elif test "x$ac_word" = "x-arch"; then
-	   ac_prev=arch
-	 fi
-       done
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
-    if test $ac_cv_c_bigendian = unknown; then
-      # See if sys/param.h defines the BYTE_ORDER macro.
-      cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-#include <sys/types.h>
-	     #include <sys/param.h>
 
-int
-main ()
-{
-#if ! (defined BYTE_ORDER && defined BIG_ENDIAN \
-		     && defined LITTLE_ENDIAN && BYTE_ORDER && BIG_ENDIAN \
-		     && LITTLE_ENDIAN)
-	      bogus endian macros
-	     #endif
+done
 
-  ;
-  return 0;
-}
+
+for ac_header in linux/rtnetlink.h
+do :
+  ac_fn_c_check_header_compile "$LINENO" "linux/rtnetlink.h" "ac_cv_header_linux_rtnetlink_h" "$ac_includes_default
+#include \"$srcdir/netlink.h\"
+"
+if test "x$ac_cv_header_linux_rtnetlink_h" = xyes; then :
+  cat >>confdefs.h <<_ACEOF
+#define HAVE_LINUX_RTNETLINK_H 1
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
-  # It does; now see whether it defined to BIG_ENDIAN or not.
-	 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-#include <sys/types.h>
-		#include <sys/param.h>
 
-int
-main ()
-{
-#if BYTE_ORDER != BIG_ENDIAN
-		 not big endian
-		#endif
 
-  ;
-  return 0;
-}
+ac_fn_c_check_type "$LINENO" "struct rta_mfc_stats" "ac_cv_type_struct_rta_mfc_stats" "$ac_includes_default
+#include \"$srcdir/netlink.h\"
+#include <linux/rtnetlink.h>
+"
+if test "x$ac_cv_type_struct_rta_mfc_stats" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_RTA_MFC_STATS 1
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
-  ac_cv_c_bigendian=yes
-else
-  ac_cv_c_bigendian=no
-fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
-fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
-    fi
-    if test $ac_cv_c_bigendian = unknown; then
-      # See if <limits.h> defines _LITTLE_ENDIAN or _BIG_ENDIAN (e.g., Solaris).
-      cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-#include <limits.h>
 
-int
-main ()
-{
-#if ! (defined _LITTLE_ENDIAN || defined _BIG_ENDIAN)
-	      bogus endian macros
-	     #endif
+ac_fn_c_check_member "$LINENO" "struct rta_mfc_stats" "mfcs_wrong_if" "ac_cv_member_struct_rta_mfc_stats_mfcs_wrong_if" "$ac_includes_default
+#include \"$srcdir/netlink.h\"
+#include <linux/rtnetlink.h>
+"
+if test "x$ac_cv_member_struct_rta_mfc_stats_mfcs_wrong_if" = xyes; then :
 
-  ;
-  return 0;
-}
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_RTA_MFC_STATS_MFCS_WRONG_IF 1
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
-  # It does; now see whether it defined to _BIG_ENDIAN or not.
-	 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-#include <limits.h>
 
-int
-main ()
-{
-#ifndef _BIG_ENDIAN
-		 not big endian
-		#endif
 
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
-  ac_cv_c_bigendian=yes
-else
-  ac_cv_c_bigendian=no
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
-fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
-    fi
-    if test $ac_cv_c_bigendian = unknown; then
-      # Compile a test program.
-      if test "$cross_compiling" = yes; then :
-  # Try to guess by grepping values from an object file.
-	 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-unsigned short int ascii_mm[] =
-		  { 0x4249, 0x4765, 0x6E44, 0x6961, 0x6E53, 0x7953, 0 };
-		unsigned short int ascii_ii[] =
-		  { 0x694C, 0x5454, 0x656C, 0x6E45, 0x6944, 0x6E61, 0 };
-		int use_ascii (int i) {
-		  return ascii_mm[i] + ascii_ii[i];
-		}
-		unsigned short int ebcdic_ii[] =
-		  { 0x89D3, 0xE3E3, 0x8593, 0x95C5, 0x89C4, 0x9581, 0 };
-		unsigned short int ebcdic_mm[] =
-		  { 0xC2C9, 0xC785, 0x95C4, 0x8981, 0x95E2, 0xA8E2, 0 };
-		int use_ebcdic (int i) {
-		  return ebcdic_mm[i] + ebcdic_ii[i];
-		}
-		extern int foo;
 
-int
-main ()
-{
-return use_ascii (foo) == use_ebcdic (foo);
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
-  if grep BIGenDianSyS conftest.$ac_objext >/dev/null; then
-	      ac_cv_c_bigendian=yes
-	    fi
-	    if grep LiTTleEnDian conftest.$ac_objext >/dev/null ; then
-	      if test "$ac_cv_c_bigendian" = unknown; then
-		ac_cv_c_bigendian=no
-	      else
-		# finding both strings is unlikely to happen, but who knows?
-		ac_cv_c_bigendian=unknown
-	      fi
-	    fi
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
-else
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-$ac_includes_default
-int
-main ()
-{
 
-	     /* Are we little or big endian?  From Harbison&Steele.  */
-	     union
-	     {
-	       long int l;
-	       char c[sizeof (long int)];
-	     } u;
-	     u.l = 1;
-	     return u.c[sizeof (long int) - 1] == 1;
 
-  ;
-  return 0;
-}
+ac_fn_c_check_type "$LINENO" "struct rtvia" "ac_cv_type_struct_rtvia" "$ac_includes_default
+#include \"$srcdir/netlink.h\"
+#include <linux/rtnetlink.h>
+"
+if test "x$ac_cv_type_struct_rtvia" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_RTVIA 1
 _ACEOF
-if ac_fn_c_try_run "$LINENO"; then :
-  ac_cv_c_bigendian=no
-else
-  ac_cv_c_bigendian=yes
-fi
-rm -f core *.core core.conftest.* gmon.out bb.out conftest$ac_exeext \
-  conftest.$ac_objext conftest.beam conftest.$ac_ext
-fi
 
-    fi
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_c_bigendian" >&5
-$as_echo "$ac_cv_c_bigendian" >&6; }
- case $ac_cv_c_bigendian in #(
-   yes)
-     $as_echo "#define WORDS_BIGENDIAN 1" >>confdefs.h
-;; #(
-   no)
-      ;; #(
-   universal)
+ac_fn_c_check_member "$LINENO" "struct rtvia" "rtvia_addr" "ac_cv_member_struct_rtvia_rtvia_addr" "$ac_includes_default
+#include \"$srcdir/netlink.h\"
+#include <linux/rtnetlink.h>
+"
+if test "x$ac_cv_member_struct_rtvia_rtvia_addr" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_RTVIA_RTVIA_ADDR 1
+_ACEOF
 
-$as_echo "#define AC_APPLE_UNIVERSAL_BUILD 1" >>confdefs.h
 
-     ;; #(
-   *)
-     as_fn_error $? "unknown endianness
- presetting ac_cv_c_bigendian=no (or yes) will help" "$LINENO" 5 ;;
- esac
+fi
 
+fi
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for supported architecture" >&5
-$as_echo_n "checking for supported architecture... " >&6; }
-arch_m32=
-arch_mx32=
-cc_flags_m32=-m32
-cc_flags_mx32=-mx32
-case "$host_cpu" in
-aarch64*)
-	arch=aarch64
-	arch_m32=arm
-	cc_flags_m32=
 
-$as_echo "#define AARCH64 1" >>confdefs.h
+fi
 
-	;;
-alpha*)
-	arch=alpha
+done
 
-$as_echo "#define ALPHA 1" >>confdefs.h
 
-	;;
-arc*)
-	arch=arc
+for ac_header in linux/tee.h
+do :
+  ac_fn_c_check_header_compile "$LINENO" "linux/tee.h" "ac_cv_header_linux_tee_h" "$ac_includes_default
+#include <linux/ioctl.h>
+"
+if test "x$ac_cv_header_linux_tee_h" = xyes; then :
+  cat >>confdefs.h <<_ACEOF
+#define HAVE_LINUX_TEE_H 1
+_ACEOF
 
-$as_echo "#define ARC 1" >>confdefs.h
 
-	;;
-arm*)
-	arch=arm
+ac_fn_c_check_type "$LINENO" "struct tee_ioctl_buf_data" "ac_cv_type_struct_tee_ioctl_buf_data" "$ac_includes_default
+#include <linux/ioctl.h>
+#include <linux/tee.h>
+"
+if test "x$ac_cv_type_struct_tee_ioctl_buf_data" = xyes; then :
 
-$as_echo "#define ARM 1" >>confdefs.h
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_TEE_IOCTL_BUF_DATA 1
+_ACEOF
 
-	;;
-avr32*)
-	arch=avr32
+ac_fn_c_check_member "$LINENO" "struct tee_ioctl_buf_data" "buf_len" "ac_cv_member_struct_tee_ioctl_buf_data_buf_len" "$ac_includes_default
+#include <linux/ioctl.h>
+#include <linux/tee.h>
+"
+if test "x$ac_cv_member_struct_tee_ioctl_buf_data_buf_len" = xyes; then :
 
-$as_echo "#define AVR32 1" >>confdefs.h
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_TEE_IOCTL_BUF_DATA_BUF_LEN 1
+_ACEOF
 
-	;;
-bfin)
-	arch=bfin
 
-$as_echo "#define BFIN 1" >>confdefs.h
+fi
 
-	;;
-csky*)
-	arch=csky
+fi
 
-$as_echo "#define CSKY 1" >>confdefs.h
 
-	;;
-hppa*|parisc*)
-	arch=hppa
+ac_fn_c_check_type "$LINENO" "struct tee_ioctl_cancel_arg" "ac_cv_type_struct_tee_ioctl_cancel_arg" "$ac_includes_default
+#include <linux/ioctl.h>
+#include <linux/tee.h>
+"
+if test "x$ac_cv_type_struct_tee_ioctl_cancel_arg" = xyes; then :
 
-$as_echo "#define HPPA 1" >>confdefs.h
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_TEE_IOCTL_CANCEL_ARG 1
+_ACEOF
 
-	;;
-i[3456]86|pentium)
-	arch=i386
+ac_fn_c_check_member "$LINENO" "struct tee_ioctl_cancel_arg" "session" "ac_cv_member_struct_tee_ioctl_cancel_arg_session" "$ac_includes_default
+#include <linux/ioctl.h>
+#include <linux/tee.h>
+"
+if test "x$ac_cv_member_struct_tee_ioctl_cancel_arg_session" = xyes; then :
 
-$as_echo "#define I386 1" >>confdefs.h
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_TEE_IOCTL_CANCEL_ARG_SESSION 1
+_ACEOF
 
-	;;
-ia64)
-	arch=ia64
 
-$as_echo "#define IA64 1" >>confdefs.h
+fi
 
-	;;
-m68k)
-	arch=m68k
+fi
 
-$as_echo "#define M68K 1" >>confdefs.h
 
-	;;
-metag*)
-	arch=metag
+ac_fn_c_check_type "$LINENO" "struct tee_ioctl_close_session_arg" "ac_cv_type_struct_tee_ioctl_close_session_arg" "$ac_includes_default
+#include <linux/ioctl.h>
+#include <linux/tee.h>
+"
+if test "x$ac_cv_type_struct_tee_ioctl_close_session_arg" = xyes; then :
 
-$as_echo "#define METAG 1" >>confdefs.h
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_TEE_IOCTL_CLOSE_SESSION_ARG 1
+_ACEOF
 
-	;;
-microblaze*)
-	arch=microblaze
+ac_fn_c_check_member "$LINENO" "struct tee_ioctl_close_session_arg" "session" "ac_cv_member_struct_tee_ioctl_close_session_arg_session" "$ac_includes_default
+#include <linux/ioctl.h>
+#include <linux/tee.h>
+"
+if test "x$ac_cv_member_struct_tee_ioctl_close_session_arg_session" = xyes; then :
 
-$as_echo "#define MICROBLAZE 1" >>confdefs.h
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_TEE_IOCTL_CLOSE_SESSION_ARG_SESSION 1
+_ACEOF
 
-	;;
-mips*)
-	arch=mips
 
-$as_echo "#define MIPS 1" >>confdefs.h
+fi
 
-	;;
-nios2*)
-	arch=nios2
+fi
 
-$as_echo "#define NIOS2 1" >>confdefs.h
 
-	;;
-or1k*)
-	arch=or1k
+ac_fn_c_check_type "$LINENO" "struct tee_ioctl_shm_alloc_data" "ac_cv_type_struct_tee_ioctl_shm_alloc_data" "$ac_includes_default
+#include <linux/ioctl.h>
+#include <linux/tee.h>
+"
+if test "x$ac_cv_type_struct_tee_ioctl_shm_alloc_data" = xyes; then :
 
-$as_echo "#define OR1K 1" >>confdefs.h
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_TEE_IOCTL_SHM_ALLOC_DATA 1
+_ACEOF
 
-	;;
-powerpc*)
+ac_fn_c_check_member "$LINENO" "struct tee_ioctl_shm_alloc_data" "id" "ac_cv_member_struct_tee_ioctl_shm_alloc_data_id" "$ac_includes_default
+#include <linux/ioctl.h>
+#include <linux/tee.h>
+"
+if test "x$ac_cv_member_struct_tee_ioctl_shm_alloc_data_id" = xyes; then :
 
-$as_echo "#define POWERPC 1" >>confdefs.h
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_TEE_IOCTL_SHM_ALLOC_DATA_ID 1
+_ACEOF
 
-	cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-#ifndef __LP64__
-# error 32 bit
-#endif
-int
-main ()
-{
 
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
-  arch=powerpc64
-else
-  arch=powerpc
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
-	if test "$arch" = "powerpc64"; then
-		# $ac_cv_c_bigendian is defined by AC_C_BIGENDIAN
-		case "$ac_cv_c_bigendian" in
-		no)
-			arch=powerpc64le
 
-$as_echo "#define POWERPC64LE 1" >>confdefs.h
+fi
 
-			;;
-		*)
-			arch_m32=powerpc
 
-$as_echo "#define POWERPC64 1" >>confdefs.h
+ac_fn_c_check_type "$LINENO" "struct tee_ioctl_shm_register_data" "ac_cv_type_struct_tee_ioctl_shm_register_data" "$ac_includes_default
+#include <linux/ioctl.h>
+#include <linux/tee.h>
+"
+if test "x$ac_cv_type_struct_tee_ioctl_shm_register_data" = xyes; then :
 
-			;;
-		esac
-	fi
-	;;
-riscv64*)
-	arch=riscv64
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_TEE_IOCTL_SHM_REGISTER_DATA 1
+_ACEOF
 
-$as_echo "#define RISCV64 1" >>confdefs.h
+ac_fn_c_check_member "$LINENO" "struct tee_ioctl_shm_register_data" "id" "ac_cv_member_struct_tee_ioctl_shm_register_data_id" "$ac_includes_default
+#include <linux/ioctl.h>
+#include <linux/tee.h>
+"
+if test "x$ac_cv_member_struct_tee_ioctl_shm_register_data_id" = xyes; then :
 
-	;;
-s390)
-	arch=s390
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_TEE_IOCTL_SHM_REGISTER_DATA_ID 1
+_ACEOF
 
-$as_echo "#define S390 1" >>confdefs.h
 
-	;;
-s390x)
-	arch=s390x
-	arch_m32=s390
-	cc_flags_m32=-m31
+fi
 
-$as_echo "#define S390X 1" >>confdefs.h
+fi
 
-	;;
-sh64*)
-	arch=sh64
 
-$as_echo "#define SH64 1" >>confdefs.h
+ac_fn_c_check_type "$LINENO" "struct tee_ioctl_version_data" "ac_cv_type_struct_tee_ioctl_version_data" "$ac_includes_default
+#include <linux/ioctl.h>
+#include <linux/tee.h>
+"
+if test "x$ac_cv_type_struct_tee_ioctl_version_data" = xyes; then :
 
-	;;
-sh*)
-	arch=sh
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_TEE_IOCTL_VERSION_DATA 1
+_ACEOF
 
-$as_echo "#define SH 1" >>confdefs.h
+ac_fn_c_check_member "$LINENO" "struct tee_ioctl_version_data" "gen_caps" "ac_cv_member_struct_tee_ioctl_version_data_gen_caps" "$ac_includes_default
+#include <linux/ioctl.h>
+#include <linux/tee.h>
+"
+if test "x$ac_cv_member_struct_tee_ioctl_version_data_gen_caps" = xyes; then :
 
-	;;
-sparc64*)
-	arch=sparc64
-	arch_m32=sparc
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_TEE_IOCTL_VERSION_DATA_GEN_CAPS 1
+_ACEOF
 
-$as_echo "#define SPARC64 1" >>confdefs.h
 
-	;;
-sparc*)
-	arch=sparc
+fi
 
-$as_echo "#define SPARC 1" >>confdefs.h
+fi
 
-	;;
-tile*)
-	arch=tile
 
-$as_echo "#define TILE 1" >>confdefs.h
+ac_fn_c_check_type "$LINENO" "struct tee_ioctl_param" "ac_cv_type_struct_tee_ioctl_param" "$ac_includes_default
+#include <linux/ioctl.h>
+#include <linux/tee.h>
+"
+if test "x$ac_cv_type_struct_tee_ioctl_param" = xyes; then :
 
-	;;
-x86?64*)
-	arch_m32=i386
-	cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-#ifndef __ILP32__
-# error not x32
-#endif
-int
-main ()
-{
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_TEE_IOCTL_PARAM 1
+_ACEOF
 
-  ;
-  return 0;
-}
+ac_fn_c_check_member "$LINENO" "struct tee_ioctl_param" "c" "ac_cv_member_struct_tee_ioctl_param_c" "$ac_includes_default
+#include <linux/ioctl.h>
+#include <linux/tee.h>
+"
+if test "x$ac_cv_member_struct_tee_ioctl_param_c" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_TEE_IOCTL_PARAM_C 1
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
-  arch=x32
-else
-  arch=x86_64
+
+
+fi
+
+fi
+
+
+ac_fn_c_check_type "$LINENO" "struct tee_ioctl_invoke_arg" "ac_cv_type_struct_tee_ioctl_invoke_arg" "$ac_includes_default
+#include <linux/ioctl.h>
+#include <linux/tee.h>
+"
+if test "x$ac_cv_type_struct_tee_ioctl_invoke_arg" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_TEE_IOCTL_INVOKE_ARG 1
+_ACEOF
+
+ac_fn_c_check_member "$LINENO" "struct tee_ioctl_invoke_arg" "params" "ac_cv_member_struct_tee_ioctl_invoke_arg_params" "$ac_includes_default
+#include <linux/ioctl.h>
+#include <linux/tee.h>
+"
+if test "x$ac_cv_member_struct_tee_ioctl_invoke_arg_params" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_TEE_IOCTL_INVOKE_ARG_PARAMS 1
+_ACEOF
+
+
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
-	if test "$arch" = "x86_64"; then
-		arch_mx32=x32
 
-$as_echo "#define X86_64 1" >>confdefs.h
+fi
 
-	else
 
-$as_echo "#define X32 1" >>confdefs.h
+ac_fn_c_check_type "$LINENO" "struct tee_iocl_supp_recv_arg" "ac_cv_type_struct_tee_iocl_supp_recv_arg" "$ac_includes_default
+#include <linux/ioctl.h>
+#include <linux/tee.h>
+"
+if test "x$ac_cv_type_struct_tee_iocl_supp_recv_arg" = xyes; then :
 
-	fi
-	;;
-xtensa*)
-	arch=xtensa
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_TEE_IOCL_SUPP_RECV_ARG 1
+_ACEOF
 
-$as_echo "#define XTENSA 1" >>confdefs.h
+ac_fn_c_check_member "$LINENO" "struct tee_iocl_supp_recv_arg" "params" "ac_cv_member_struct_tee_iocl_supp_recv_arg_params" "$ac_includes_default
+#include <linux/ioctl.h>
+#include <linux/tee.h>
+"
+if test "x$ac_cv_member_struct_tee_iocl_supp_recv_arg_params" = xyes; then :
 
-	;;
-*)
-	{ $as_echo "$as_me:${as_lineno-$LINENO}: result: NO!" >&5
-$as_echo "NO!" >&6; }
-	as_fn_error $? "architecture $host_cpu is not supported by strace" "$LINENO" 5
-	;;
-esac
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $arch" >&5
-$as_echo "$arch" >&6; }
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_TEE_IOCL_SUPP_RECV_ARG_PARAMS 1
+_ACEOF
 
-arch_native=$arch
 
-test -n "$arch_m32" ||
-	arch_m32=$arch
-test -n "$arch_mx32" ||
-	arch_mx32=$arch
+fi
 
+fi
 
 
+ac_fn_c_check_type "$LINENO" "struct tee_iocl_supp_send_arg" "ac_cv_type_struct_tee_iocl_supp_send_arg" "$ac_includes_default
+#include <linux/ioctl.h>
+#include <linux/tee.h>
+"
+if test "x$ac_cv_type_struct_tee_iocl_supp_send_arg" = xyes; then :
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_TEE_IOCL_SUPP_SEND_ARG 1
+_ACEOF
 
+ac_fn_c_check_member "$LINENO" "struct tee_iocl_supp_send_arg" "params" "ac_cv_member_struct_tee_iocl_supp_send_arg_params" "$ac_includes_default
+#include <linux/ioctl.h>
+#include <linux/tee.h>
+"
+if test "x$ac_cv_member_struct_tee_iocl_supp_send_arg_params" = xyes; then :
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_TEE_IOCL_SUPP_SEND_ARG_PARAMS 1
+_ACEOF
 
-MIPS_ABI=
-if test "$arch" = mips; then
-	{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for _MIPS_SIM" >&5
-$as_echo_n "checking for _MIPS_SIM... " >&6; }
-if ${st_cv__MIPS_SIM+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-  if ac_fn_c_compute_int "$LINENO" "_MIPS_SIM" "st_cv__MIPS_SIM"        ""; then :
 
-else
-  { { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
-$as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
-as_fn_error $? "_MIPS_SIM cannot be determined
-See \`config.log' for more details" "$LINENO" 5; }
 fi
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $st_cv__MIPS_SIM" >&5
-$as_echo "$st_cv__MIPS_SIM" >&6; }
 
-	# requires GCC >= 3.4
-	{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for MIPS ABI" >&5
-$as_echo_n "checking for MIPS ABI... " >&6; }
-if ${st_cv_mips_abi+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
 
-int
-main ()
-{
-int i[_MIPS_SIM == _ABIO32 ? 1 : - 1];
-  ;
-  return 0;
-}
-_ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
-  st_cv_mips_abi=o32
-else
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+ac_fn_c_check_type "$LINENO" "struct tee_ioctl_open_session_arg" "ac_cv_type_struct_tee_ioctl_open_session_arg" "$ac_includes_default
+#include <linux/ioctl.h>
+#include <linux/tee.h>
+"
+if test "x$ac_cv_type_struct_tee_ioctl_open_session_arg" = xyes; then :
 
-int
-main ()
-{
-int i[_MIPS_SIM == _ABIN32 ? 1 : - 1];
-  ;
-  return 0;
-}
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_TEE_IOCTL_OPEN_SESSION_ARG 1
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
-  st_cv_mips_abi=n32
-else
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
 
-int
-main ()
-{
-int i[_MIPS_SIM == _ABI64 ? 1 : - 1];
-  ;
-  return 0;
-}
+ac_fn_c_check_member "$LINENO" "struct tee_ioctl_open_session_arg" "params" "ac_cv_member_struct_tee_ioctl_open_session_arg_params" "$ac_includes_default
+#include <linux/ioctl.h>
+#include <linux/tee.h>
+"
+if test "x$ac_cv_member_struct_tee_ioctl_open_session_arg_params" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_TEE_IOCTL_OPEN_SESSION_ARG_PARAMS 1
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
-  st_cv_mips_abi=n64
-else
-  st_cv_mips_abi=unknown
+
+
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+
+
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
+
+done
+
+
+for ac_header in linux/videodev2.h
+do :
+  ac_fn_c_check_header_compile "$LINENO" "linux/videodev2.h" "ac_cv_header_linux_videodev2_h" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+"
+if test "x$ac_cv_header_linux_videodev2_h" = xyes; then :
+  cat >>confdefs.h <<_ACEOF
+#define HAVE_LINUX_VIDEODEV2_H 1
+_ACEOF
+
+
+ac_fn_c_check_type "$LINENO" "struct v4l2_capability" "ac_cv_type_struct_v4l2_capability" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+"
+if test "x$ac_cv_type_struct_v4l2_capability" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_V4L2_CAPABILITY 1
+_ACEOF
+
+ac_fn_c_check_member "$LINENO" "struct v4l2_capability" "reserved" "ac_cv_member_struct_v4l2_capability_reserved" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+"
+if test "x$ac_cv_member_struct_v4l2_capability_reserved" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_V4L2_CAPABILITY_RESERVED 1
+_ACEOF
+
+
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $st_cv_mips_abi" >&5
-$as_echo "$st_cv_mips_abi" >&6; }
 
-	case "$st_cv_mips_abi" in
-		o32)
-$as_echo "#define LINUX_MIPSO32 1" >>confdefs.h
-;;
-		n32)
-$as_echo "#define LINUX_MIPSN32 1" >>confdefs.h
-;;
-		n64)
-$as_echo "#define LINUX_MIPSN64 1" >>confdefs.h
-;;
-		*) as_fn_error $? "Unsupported _MIPS_SIM" "$LINENO" 5;;
-	esac
-	MIPS_ABI="$st_cv_mips_abi"
 fi
 
 
-# Check whether --enable-arm-oabi was given.
-if test "${enable_arm_oabi+set}" = set; then :
-  enableval=$enable_arm_oabi;
-else
-  enable_arm_oabi=no
-fi
+ac_fn_c_check_type "$LINENO" "struct v4l2_pix_format" "ac_cv_type_struct_v4l2_pix_format" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+"
+if test "x$ac_cv_type_struct_v4l2_pix_format" = xyes; then :
 
-case "$enable_arm_oabi" in
-	yes) enable_arm_oabi=1 ;;
-	no) enable_arm_oabi=0 ;;
-	*) as_fn_error $? "bad value $enable_arm_oabi for arm-oabi option" "$LINENO" 5 ;;
-esac
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_V4L2_PIX_FORMAT 1
+_ACEOF
+
+ac_fn_c_check_member "$LINENO" "struct v4l2_pix_format" "xfer_func" "ac_cv_member_struct_v4l2_pix_format_xfer_func" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+"
+if test "x$ac_cv_member_struct_v4l2_pix_format_xfer_func" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define ENABLE_ARM_OABI $enable_arm_oabi
+#define HAVE_STRUCT_V4L2_PIX_FORMAT_XFER_FUNC 1
 _ACEOF
 
 
+fi
 
-  { $as_echo "$as_me:${as_lineno-$LINENO}: checking for typeof syntax and keyword spelling" >&5
-$as_echo_n "checking for typeof syntax and keyword spelling... " >&6; }
-if ${ac_cv_c_typeof+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-  ac_cv_c_typeof=no
-     for ac_kw in typeof __typeof__ no; do
-       test $ac_kw = no && break
-       cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+fi
 
-int
-main ()
-{
 
-	   int value;
-	   typedef struct {
-		   char a [1
-			   + ! (($ac_kw (value))
-				(($ac_kw (value)) 0 < ($ac_kw (value)) -1
-				 ? ($ac_kw (value)) - 1
-				 : ~ (~ ($ac_kw (value)) 0
-				      << sizeof ($ac_kw (value)))))]; }
-	      ac__typeof_type_;
-	   return
-	     (! ((void) ((ac__typeof_type_ *) 0), 0));
+ac_fn_c_check_type "$LINENO" "struct v4l2_plane_pix_format" "ac_cv_type_struct_v4l2_plane_pix_format" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+"
+if test "x$ac_cv_type_struct_v4l2_plane_pix_format" = xyes; then :
 
-  ;
-  return 0;
-}
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_V4L2_PLANE_PIX_FORMAT 1
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
-  ac_cv_c_typeof=$ac_kw
+
+ac_fn_c_check_member "$LINENO" "struct v4l2_plane_pix_format" "reserved" "ac_cv_member_struct_v4l2_plane_pix_format_reserved" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+"
+if test "x$ac_cv_member_struct_v4l2_plane_pix_format_reserved" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_V4L2_PLANE_PIX_FORMAT_RESERVED 1
+_ACEOF
+
+
 fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
-       test $ac_cv_c_typeof != no && break
-     done
+
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_c_typeof" >&5
-$as_echo "$ac_cv_c_typeof" >&6; }
-  if test $ac_cv_c_typeof != no; then
 
-$as_echo "#define HAVE_TYPEOF 1" >>confdefs.h
 
-    if test $ac_cv_c_typeof != typeof; then
+ac_fn_c_check_type "$LINENO" "struct v4l2_clip" "ac_cv_type_struct_v4l2_clip" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+"
+if test "x$ac_cv_type_struct_v4l2_clip" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define typeof $ac_cv_c_typeof
+#define HAVE_STRUCT_V4L2_CLIP 1
 _ACEOF
 
-    fi
-  fi
+ac_fn_c_check_member "$LINENO" "struct v4l2_clip" "next" "ac_cv_member_struct_v4l2_clip_next" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+"
+if test "x$ac_cv_member_struct_v4l2_clip_next" = xyes; then :
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_V4L2_CLIP_NEXT 1
+_ACEOF
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for uid_t in sys/types.h" >&5
-$as_echo_n "checking for uid_t in sys/types.h... " >&6; }
-if ${ac_cv_type_uid_t+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
-#include <sys/types.h>
 
-_ACEOF
-if (eval "$ac_cpp conftest.$ac_ext") 2>&5 |
-  $EGREP "uid_t" >/dev/null 2>&1; then :
-  ac_cv_type_uid_t=yes
-else
-  ac_cv_type_uid_t=no
 fi
-rm -f conftest*
 
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_type_uid_t" >&5
-$as_echo "$ac_cv_type_uid_t" >&6; }
-if test $ac_cv_type_uid_t = no; then
-
-$as_echo "#define uid_t int" >>confdefs.h
 
 
-$as_echo "#define gid_t int" >>confdefs.h
+ac_fn_c_check_type "$LINENO" "struct v4l2_window" "ac_cv_type_struct_v4l2_window" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+"
+if test "x$ac_cv_type_struct_v4l2_window" = xyes; then :
 
-fi
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_V4L2_WINDOW 1
+_ACEOF
 
+ac_fn_c_check_member "$LINENO" "struct v4l2_window" "global_alpha" "ac_cv_member_struct_v4l2_window_global_alpha" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+"
+if test "x$ac_cv_member_struct_v4l2_window_global_alpha" = xyes; then :
 
-for ac_func in accept4 be64toh fallocate fanotify_mark fcntl64 fopen64 fork fputs_unlocked fstatat ftruncate futimens iconv_open if_indextoname open64 open_memstream prctl preadv process_vm_readv pwritev readahead signalfd stpcpy strerror strndup strsignal sync_file_range utimensat
-do :
-  as_ac_var=`$as_echo "ac_cv_func_$ac_func" | $as_tr_sh`
-ac_fn_c_check_func "$LINENO" "$ac_func" "$as_ac_var"
-if eval test \"x\$"$as_ac_var"\" = x"yes"; then :
-  cat >>confdefs.h <<_ACEOF
-#define `$as_echo "HAVE_$ac_func" | $as_tr_cpp` 1
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_V4L2_WINDOW_GLOBAL_ALPHA 1
 _ACEOF
 
+
+fi
+
 fi
-done
 
 
-ac_fn_c_check_type "$LINENO" "sig_atomic_t" "ac_cv_type_sig_atomic_t" "#include <signal.h>
+ac_fn_c_check_type "$LINENO" "struct v4l2_vbi_format" "ac_cv_type_struct_v4l2_vbi_format" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 "
-if test "x$ac_cv_type_sig_atomic_t" = xyes; then :
+if test "x$ac_cv_type_struct_v4l2_vbi_format" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_SIG_ATOMIC_T 1
+#define HAVE_STRUCT_V4L2_VBI_FORMAT 1
 _ACEOF
 
-
-fi
-ac_fn_c_check_type "$LINENO" "struct sigcontext" "ac_cv_type_struct_sigcontext" "#include <signal.h>
+ac_fn_c_check_member "$LINENO" "struct v4l2_vbi_format" "reserved" "ac_cv_member_struct_v4l2_vbi_format_reserved" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 "
-if test "x$ac_cv_type_struct_sigcontext" = xyes; then :
+if test "x$ac_cv_member_struct_v4l2_vbi_format_reserved" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_SIGCONTEXT 1
+#define HAVE_STRUCT_V4L2_VBI_FORMAT_RESERVED 1
 _ACEOF
 
 
 fi
 
+fi
+
 
-ac_fn_c_check_type "$LINENO" "struct mmsghdr" "ac_cv_type_struct_mmsghdr" "#include <sys/socket.h>
+ac_fn_c_check_type "$LINENO" "struct v4l2_sliced_vbi_format" "ac_cv_type_struct_v4l2_sliced_vbi_format" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 "
-if test "x$ac_cv_type_struct_mmsghdr" = xyes; then :
+if test "x$ac_cv_type_struct_v4l2_sliced_vbi_format" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_MMSGHDR 1
+#define HAVE_STRUCT_V4L2_SLICED_VBI_FORMAT 1
+_ACEOF
+
+ac_fn_c_check_member "$LINENO" "struct v4l2_sliced_vbi_format" "reserved" "ac_cv_member_struct_v4l2_sliced_vbi_format_reserved" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+"
+if test "x$ac_cv_member_struct_v4l2_sliced_vbi_format_reserved" = xyes; then :
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_STRUCT_V4L2_SLICED_VBI_FORMAT_RESERVED 1
 _ACEOF
 
 
 fi
 
+fi
+
 
-ac_fn_c_check_type "$LINENO" "__kernel_long_t" "ac_cv_type___kernel_long_t" "#include <asm/posix_types.h>
+ac_fn_c_check_type "$LINENO" "struct v4l2_sliced_vbi_cap" "ac_cv_type_struct_v4l2_sliced_vbi_cap" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 "
-if test "x$ac_cv_type___kernel_long_t" = xyes; then :
+if test "x$ac_cv_type_struct_v4l2_sliced_vbi_cap" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE___KERNEL_LONG_T 1
+#define HAVE_STRUCT_V4L2_SLICED_VBI_CAP 1
 _ACEOF
 
-
-fi
-ac_fn_c_check_type "$LINENO" "__kernel_ulong_t" "ac_cv_type___kernel_ulong_t" "#include <asm/posix_types.h>
+ac_fn_c_check_member "$LINENO" "struct v4l2_sliced_vbi_cap" "reserved" "ac_cv_member_struct_v4l2_sliced_vbi_cap_reserved" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 "
-if test "x$ac_cv_type___kernel_ulong_t" = xyes; then :
+if test "x$ac_cv_member_struct_v4l2_sliced_vbi_cap_reserved" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE___KERNEL_ULONG_T 1
+#define HAVE_STRUCT_V4L2_SLICED_VBI_CAP_RESERVED 1
 _ACEOF
 
 
 fi
 
+fi
+
 
-ac_fn_c_check_type "$LINENO" "struct __kernel_timespec" "ac_cv_type_struct___kernel_timespec" "#include <linux/time_types.h>
+ac_fn_c_check_type "$LINENO" "struct v4l2_format" "ac_cv_type_struct_v4l2_format" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 "
-if test "x$ac_cv_type_struct___kernel_timespec" = xyes; then :
+if test "x$ac_cv_type_struct_v4l2_format" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT___KERNEL_TIMESPEC 1
+#define HAVE_STRUCT_V4L2_FORMAT 1
 _ACEOF
 
-
-fi
-ac_fn_c_check_type "$LINENO" "struct __kernel_sock_timeval" "ac_cv_type_struct___kernel_sock_timeval" "#include <linux/time_types.h>
+ac_fn_c_check_member "$LINENO" "struct v4l2_format" "fmt" "ac_cv_member_struct_v4l2_format_fmt" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 "
-if test "x$ac_cv_type_struct___kernel_sock_timeval" = xyes; then :
+if test "x$ac_cv_member_struct_v4l2_format_fmt" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT___KERNEL_SOCK_TIMEVAL 1
+#define HAVE_STRUCT_V4L2_FORMAT_FMT 1
 _ACEOF
 
 
 fi
 
+fi
+
 
-ac_fn_c_check_type "$LINENO" "struct stat64" "ac_cv_type_struct_stat64" "#include <sys/types.h>
-#include <asm/stat.h>
+ac_fn_c_check_type "$LINENO" "struct v4l2_area" "ac_cv_type_struct_v4l2_area" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 "
-if test "x$ac_cv_type_struct_stat64" = xyes; then :
+if test "x$ac_cv_type_struct_v4l2_area" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_STAT64 1
+#define HAVE_STRUCT_V4L2_AREA 1
 _ACEOF
 
-
-fi
-ac_fn_c_check_type "$LINENO" "struct __old_kernel_stat" "ac_cv_type_struct___old_kernel_stat" "#include <sys/types.h>
-#include <asm/stat.h>
+ac_fn_c_check_member "$LINENO" "struct v4l2_area" "height" "ac_cv_member_struct_v4l2_area_height" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 "
-if test "x$ac_cv_type_struct___old_kernel_stat" = xyes; then :
+if test "x$ac_cv_member_struct_v4l2_area_height" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT___OLD_KERNEL_STAT 1
+#define HAVE_STRUCT_V4L2_AREA_HEIGHT 1
 _ACEOF
 
 
 fi
 
+fi
+
 
-ac_fn_c_check_type "$LINENO" "struct user_desc" "ac_cv_type_struct_user_desc" "#include <asm/ldt.h>
+ac_fn_c_check_type "$LINENO" "struct v4l2_ext_controls" "ac_cv_type_struct_v4l2_ext_controls" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 "
-if test "x$ac_cv_type_struct_user_desc" = xyes; then :
+if test "x$ac_cv_type_struct_v4l2_ext_controls" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_USER_DESC 1
+#define HAVE_STRUCT_V4L2_EXT_CONTROLS 1
 _ACEOF
 
-ac_fn_c_check_member "$LINENO" "struct user_desc" "lm" "ac_cv_member_struct_user_desc_lm" "#include <asm/ldt.h>
+ac_fn_c_check_member "$LINENO" "struct v4l2_ext_controls" "controls" "ac_cv_member_struct_v4l2_ext_controls_controls" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 "
-if test "x$ac_cv_member_struct_user_desc_lm" = xyes; then :
+if test "x$ac_cv_member_struct_v4l2_ext_controls_controls" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_USER_DESC_LM 1
+#define HAVE_STRUCT_V4L2_EXT_CONTROLS_CONTROLS 1
 _ACEOF
 
 
@@ -10139,5270 +14665,7057 @@ fi
 fi
 
 
-ac_fn_c_check_member "$LINENO" "struct stat" "st_mtime_nsec" "ac_cv_member_struct_stat_st_mtime_nsec" "#include <sys/types.h>
-#include <asm/stat.h>
+ac_fn_c_check_type "$LINENO" "struct v4l2_frmsize_discrete" "ac_cv_type_struct_v4l2_frmsize_discrete" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 "
-if test "x$ac_cv_member_struct_stat_st_mtime_nsec" = xyes; then :
+if test "x$ac_cv_type_struct_v4l2_frmsize_discrete" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_STAT_ST_MTIME_NSEC 1
+#define HAVE_STRUCT_V4L2_FRMSIZE_DISCRETE 1
 _ACEOF
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct stat64" "st_mtime_nsec" "ac_cv_member_struct_stat64_st_mtime_nsec" "#include <sys/types.h>
-#include <asm/stat.h>
+ac_fn_c_check_member "$LINENO" "struct v4l2_frmsize_discrete" "height" "ac_cv_member_struct_v4l2_frmsize_discrete_height" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 "
-if test "x$ac_cv_member_struct_stat64_st_mtime_nsec" = xyes; then :
+if test "x$ac_cv_member_struct_v4l2_frmsize_discrete_height" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_STAT64_ST_MTIME_NSEC 1
+#define HAVE_STRUCT_V4L2_FRMSIZE_DISCRETE_HEIGHT 1
 _ACEOF
 
 
 fi
 
+fi
+
 
-ac_fn_c_check_type "$LINENO" "struct pt_all_user_regs" "ac_cv_type_struct_pt_all_user_regs" "#include <sys/ptrace.h>
+ac_fn_c_check_type "$LINENO" "struct v4l2_frmsize_stepwise" "ac_cv_type_struct_v4l2_frmsize_stepwise" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 "
-if test "x$ac_cv_type_struct_pt_all_user_regs" = xyes; then :
+if test "x$ac_cv_type_struct_v4l2_frmsize_stepwise" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PT_ALL_USER_REGS 1
+#define HAVE_STRUCT_V4L2_FRMSIZE_STEPWISE 1
 _ACEOF
 
-
-fi
-ac_fn_c_check_type "$LINENO" "struct ia64_fpreg" "ac_cv_type_struct_ia64_fpreg" "#include <sys/ptrace.h>
+ac_fn_c_check_member "$LINENO" "struct v4l2_frmsize_stepwise" "step_height" "ac_cv_member_struct_v4l2_frmsize_stepwise_step_height" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 "
-if test "x$ac_cv_type_struct_ia64_fpreg" = xyes; then :
+if test "x$ac_cv_member_struct_v4l2_frmsize_stepwise_step_height" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_IA64_FPREG 1
+#define HAVE_STRUCT_V4L2_FRMSIZE_STEPWISE_STEP_HEIGHT 1
 _ACEOF
 
 
 fi
-ac_fn_c_check_type "$LINENO" "struct ptrace_peeksiginfo_args" "ac_cv_type_struct_ptrace_peeksiginfo_args" "#include <sys/ptrace.h>
+
+fi
+
+
+ac_fn_c_check_type "$LINENO" "struct v4l2_frmsizeenum" "ac_cv_type_struct_v4l2_frmsizeenum" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 "
-if test "x$ac_cv_type_struct_ptrace_peeksiginfo_args" = xyes; then :
+if test "x$ac_cv_type_struct_v4l2_frmsizeenum" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PTRACE_PEEKSIGINFO_ARGS 1
+#define HAVE_STRUCT_V4L2_FRMSIZEENUM 1
 _ACEOF
 
-
-fi
-ac_fn_c_check_type "$LINENO" "struct __ptrace_syscall_info" "ac_cv_type_struct___ptrace_syscall_info" "#include <sys/ptrace.h>
+ac_fn_c_check_member "$LINENO" "struct v4l2_frmsizeenum" "reserved" "ac_cv_member_struct_v4l2_frmsizeenum_reserved" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 "
-if test "x$ac_cv_type_struct___ptrace_syscall_info" = xyes; then :
+if test "x$ac_cv_member_struct_v4l2_frmsizeenum_reserved" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT___PTRACE_SYSCALL_INFO 1
+#define HAVE_STRUCT_V4L2_FRMSIZEENUM_RESERVED 1
 _ACEOF
 
 
 fi
 
+fi
+
 
-ac_fn_c_check_type "$LINENO" "struct ptrace_syscall_info" "ac_cv_type_struct_ptrace_syscall_info" "#include <linux/ptrace.h>
+ac_fn_c_check_type "$LINENO" "struct v4l2_frmival_stepwise" "ac_cv_type_struct_v4l2_frmival_stepwise" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 "
-if test "x$ac_cv_type_struct_ptrace_syscall_info" = xyes; then :
+if test "x$ac_cv_type_struct_v4l2_frmival_stepwise" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PTRACE_SYSCALL_INFO 1
+#define HAVE_STRUCT_V4L2_FRMIVAL_STEPWISE 1
 _ACEOF
 
-
-fi
-
-
-# For kernels that do not have v3.10-rc1~201^2~11
-ac_fn_c_check_type "$LINENO" "s390_compat_regs" "ac_cv_type_s390_compat_regs" "#include <asm/ptrace.h>
+ac_fn_c_check_member "$LINENO" "struct v4l2_frmival_stepwise" "step" "ac_cv_member_struct_v4l2_frmival_stepwise_step" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 "
-if test "x$ac_cv_type_s390_compat_regs" = xyes; then :
+if test "x$ac_cv_member_struct_v4l2_frmival_stepwise_step" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_S390_COMPAT_REGS 1
+#define HAVE_STRUCT_V4L2_FRMIVAL_STEPWISE_STEP 1
 _ACEOF
 
 
 fi
 
+fi
 
-ac_fn_c_check_type "$LINENO" "struct flock" "ac_cv_type_struct_flock" "#include <sys/types.h>
-#include <linux/fcntl.h>
+
+ac_fn_c_check_type "$LINENO" "struct v4l2_frmivalenum" "ac_cv_type_struct_v4l2_frmivalenum" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 "
-if test "x$ac_cv_type_struct_flock" = xyes; then :
+if test "x$ac_cv_type_struct_v4l2_frmivalenum" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_FLOCK 1
+#define HAVE_STRUCT_V4L2_FRMIVALENUM 1
 _ACEOF
 
-
-fi
-ac_fn_c_check_type "$LINENO" "struct flock64" "ac_cv_type_struct_flock64" "#include <sys/types.h>
-#include <linux/fcntl.h>
+ac_fn_c_check_member "$LINENO" "struct v4l2_frmivalenum" "reserved" "ac_cv_member_struct_v4l2_frmivalenum_reserved" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 "
-if test "x$ac_cv_type_struct_flock64" = xyes; then :
+if test "x$ac_cv_member_struct_v4l2_frmivalenum_reserved" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_FLOCK64 1
+#define HAVE_STRUCT_V4L2_FRMIVALENUM_RESERVED 1
 _ACEOF
 
 
 fi
-ac_fn_c_check_type "$LINENO" "struct __kernel_flock" "ac_cv_type_struct___kernel_flock" "#include <sys/types.h>
-#include <linux/fcntl.h>
-"
-if test "x$ac_cv_type_struct___kernel_flock" = xyes; then :
 
-cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT___KERNEL_FLOCK 1
-_ACEOF
+fi
 
 
-fi
-ac_fn_c_check_type "$LINENO" "struct __kernel_flock64" "ac_cv_type_struct___kernel_flock64" "#include <sys/types.h>
-#include <linux/fcntl.h>
+ac_fn_c_check_type "$LINENO" "struct v4l2_create_buffers" "ac_cv_type_struct_v4l2_create_buffers" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 "
-if test "x$ac_cv_type_struct___kernel_flock64" = xyes; then :
+if test "x$ac_cv_type_struct_v4l2_create_buffers" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT___KERNEL_FLOCK64 1
+#define HAVE_STRUCT_V4L2_CREATE_BUFFERS 1
 _ACEOF
 
-
-fi
-ac_fn_c_check_type "$LINENO" "struct f_owner_ex" "ac_cv_type_struct_f_owner_ex" "#include <sys/types.h>
-#include <linux/fcntl.h>
+ac_fn_c_check_member "$LINENO" "struct v4l2_create_buffers" "reserved" "ac_cv_member_struct_v4l2_create_buffers_reserved" "$ac_includes_default
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 "
-if test "x$ac_cv_type_struct_f_owner_ex" = xyes; then :
+if test "x$ac_cv_member_struct_v4l2_create_buffers_reserved" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_F_OWNER_EX 1
+#define HAVE_STRUCT_V4L2_CREATE_BUFFERS_RESERVED 1
 _ACEOF
 
 
 fi
-ac_fn_c_check_type "$LINENO" "struct __kernel_f_owner_ex" "ac_cv_type_struct___kernel_f_owner_ex" "#include <sys/types.h>
-#include <linux/fcntl.h>
-"
-if test "x$ac_cv_type_struct___kernel_f_owner_ex" = xyes; then :
 
-cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT___KERNEL_F_OWNER_EX 1
-_ACEOF
+fi
 
 
 fi
 
+done
+
+
+
+
+ac_fn_c_check_decl "$LINENO" "BTRFS_COMPRESS_NONE" "ac_cv_have_decl_BTRFS_COMPRESS_NONE" "
+#include <stdio.h>
+#include <linux/btrfs.h>
 
-ac_fn_c_check_type "$LINENO" "struct kcmp_epoll_slot" "ac_cv_type_struct_kcmp_epoll_slot" "#include <linux/kcmp.h>
 "
-if test "x$ac_cv_type_struct_kcmp_epoll_slot" = xyes; then :
+if test "x$ac_cv_have_decl_BTRFS_COMPRESS_NONE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_KCMP_EPOLL_SLOT 1
+#define HAVE_DECL_BTRFS_COMPRESS_NONE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "BTRFS_COMPRESS_ZLIB" "ac_cv_have_decl_BTRFS_COMPRESS_ZLIB" "
+#include <stdio.h>
+#include <linux/btrfs.h>
 
-
+"
+if test "x$ac_cv_have_decl_BTRFS_COMPRESS_ZLIB" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_BTRFS_COMPRESS_ZLIB $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "BTRFS_COMPRESS_LZO" "ac_cv_have_decl_BTRFS_COMPRESS_LZO" "
+#include <stdio.h>
+#include <linux/btrfs.h>
 
-ac_fn_c_check_type "$LINENO" "struct keyctl_kdf_params" "ac_cv_type_struct_keyctl_kdf_params" "#include <linux/keyctl.h>
 "
-if test "x$ac_cv_type_struct_keyctl_kdf_params" = xyes; then :
+if test "x$ac_cv_have_decl_BTRFS_COMPRESS_LZO" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_KEYCTL_KDF_PARAMS 1
+#define HAVE_DECL_BTRFS_COMPRESS_LZO $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "BTRFS_COMPRESS_ZSTD" "ac_cv_have_decl_BTRFS_COMPRESS_ZSTD" "
+#include <stdio.h>
+#include <linux/btrfs.h>
 
-
-fi
-ac_fn_c_check_type "$LINENO" "struct keyctl_pkey_params" "ac_cv_type_struct_keyctl_pkey_params" "#include <linux/keyctl.h>
 "
-if test "x$ac_cv_type_struct_keyctl_pkey_params" = xyes; then :
+if test "x$ac_cv_have_decl_BTRFS_COMPRESS_ZSTD" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_KEYCTL_PKEY_PARAMS 1
+#define HAVE_DECL_BTRFS_COMPRESS_ZSTD $ac_have_decl
 _ACEOF
 
 
-fi
-ac_fn_c_check_type "$LINENO" "struct keyctl_pkey_query" "ac_cv_type_struct_keyctl_pkey_query" "#include <linux/keyctl.h>
+ac_fn_c_check_decl "$LINENO" "CLOSE_RANGE_UNSHARE" "ac_cv_have_decl_CLOSE_RANGE_UNSHARE" "
+#include <linux/close_range.h>
+
 "
-if test "x$ac_cv_type_struct_keyctl_pkey_query" = xyes; then :
+if test "x$ac_cv_have_decl_CLOSE_RANGE_UNSHARE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_KEYCTL_PKEY_QUERY 1
+#define HAVE_DECL_CLOSE_RANGE_UNSHARE $ac_have_decl
 _ACEOF
 
 
+ac_fn_c_check_decl "$LINENO" "LO_FLAGS_READ_ONLY" "ac_cv_have_decl_LO_FLAGS_READ_ONLY" "
+#include <linux/loop.h>
+
+"
+if test "x$ac_cv_have_decl_LO_FLAGS_READ_ONLY" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_LO_FLAGS_READ_ONLY $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "LO_FLAGS_USE_AOPS" "ac_cv_have_decl_LO_FLAGS_USE_AOPS" "
+#include <linux/loop.h>
 
-ac_fn_c_check_member "$LINENO" "struct utsname" "domainname" "ac_cv_member_struct_utsname_domainname" "#include <sys/utsname.h>
 "
-if test "x$ac_cv_member_struct_utsname_domainname" = xyes; then :
+if test "x$ac_cv_have_decl_LO_FLAGS_USE_AOPS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_UTSNAME_DOMAINNAME 1
+#define HAVE_DECL_LO_FLAGS_USE_AOPS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "LO_FLAGS_AUTOCLEAR" "ac_cv_have_decl_LO_FLAGS_AUTOCLEAR" "
+#include <linux/loop.h>
 
-
+"
+if test "x$ac_cv_have_decl_LO_FLAGS_AUTOCLEAR" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_LO_FLAGS_AUTOCLEAR $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "LO_FLAGS_PARTSCAN" "ac_cv_have_decl_LO_FLAGS_PARTSCAN" "
+#include <linux/loop.h>
 
-ac_fn_c_check_member "$LINENO" "siginfo_t" "si_syscall" "ac_cv_member_siginfo_t_si_syscall" "#include <signal.h>
 "
-if test "x$ac_cv_member_siginfo_t_si_syscall" = xyes; then :
+if test "x$ac_cv_have_decl_LO_FLAGS_PARTSCAN" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_SIGINFO_T_SI_SYSCALL 1
+#define HAVE_DECL_LO_FLAGS_PARTSCAN $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "LO_FLAGS_DIRECT_IO" "ac_cv_have_decl_LO_FLAGS_DIRECT_IO" "
+#include <linux/loop.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "siginfo_t" "si_timerid" "ac_cv_member_siginfo_t_si_timerid" "#include <signal.h>
 "
-if test "x$ac_cv_member_siginfo_t_si_timerid" = xyes; then :
+if test "x$ac_cv_have_decl_LO_FLAGS_DIRECT_IO" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_SIGINFO_T_SI_TIMERID 1
+#define HAVE_DECL_LO_FLAGS_DIRECT_IO $ac_have_decl
 _ACEOF
 
 
-fi
-ac_fn_c_check_member "$LINENO" "siginfo_t" "si_overrun" "ac_cv_member_siginfo_t_si_overrun" "#include <signal.h>
+ac_fn_c_check_decl "$LINENO" "XDP_ATTACHED_NONE" "ac_cv_have_decl_XDP_ATTACHED_NONE" "
+#include <netinet/in.h>
+#include <linux/rtnetlink.h>
+
 "
-if test "x$ac_cv_member_siginfo_t_si_overrun" = xyes; then :
+if test "x$ac_cv_have_decl_XDP_ATTACHED_NONE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_SIGINFO_T_SI_OVERRUN 1
+#define HAVE_DECL_XDP_ATTACHED_NONE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "XDP_ATTACHED_DRV" "ac_cv_have_decl_XDP_ATTACHED_DRV" "
+#include <netinet/in.h>
+#include <linux/rtnetlink.h>
 
-
+"
+if test "x$ac_cv_have_decl_XDP_ATTACHED_DRV" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_XDP_ATTACHED_DRV $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "XDP_ATTACHED_SKB" "ac_cv_have_decl_XDP_ATTACHED_SKB" "
+#include <netinet/in.h>
+#include <linux/rtnetlink.h>
 
-ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "precise_ip" "ac_cv_member_struct_perf_event_attr_precise_ip" "#include <linux/perf_event.h>
 "
-if test "x$ac_cv_member_struct_perf_event_attr_precise_ip" = xyes; then :
+if test "x$ac_cv_have_decl_XDP_ATTACHED_SKB" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PERF_EVENT_ATTR_PRECISE_IP 1
+#define HAVE_DECL_XDP_ATTACHED_SKB $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "XDP_ATTACHED_HW" "ac_cv_have_decl_XDP_ATTACHED_HW" "
+#include <netinet/in.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "mmap_data" "ac_cv_member_struct_perf_event_attr_mmap_data" "#include <linux/perf_event.h>
 "
-if test "x$ac_cv_member_struct_perf_event_attr_mmap_data" = xyes; then :
+if test "x$ac_cv_have_decl_XDP_ATTACHED_HW" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PERF_EVENT_ATTR_MMAP_DATA 1
+#define HAVE_DECL_XDP_ATTACHED_HW $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "XDP_ATTACHED_MULTI" "ac_cv_have_decl_XDP_ATTACHED_MULTI" "
+#include <netinet/in.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "sample_id_all" "ac_cv_member_struct_perf_event_attr_sample_id_all" "#include <linux/perf_event.h>
 "
-if test "x$ac_cv_member_struct_perf_event_attr_sample_id_all" = xyes; then :
+if test "x$ac_cv_have_decl_XDP_ATTACHED_MULTI" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PERF_EVENT_ATTR_SAMPLE_ID_ALL 1
+#define HAVE_DECL_XDP_ATTACHED_MULTI $ac_have_decl
 _ACEOF
 
 
-fi
-ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "exclude_host" "ac_cv_member_struct_perf_event_attr_exclude_host" "#include <linux/perf_event.h>
+ac_fn_c_check_decl "$LINENO" "IFLA_XDP_UNSPEC" "ac_cv_have_decl_IFLA_XDP_UNSPEC" "
+#include <netinet/in.h>
+#include <linux/rtnetlink.h>
+
 "
-if test "x$ac_cv_member_struct_perf_event_attr_exclude_host" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_XDP_UNSPEC" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PERF_EVENT_ATTR_EXCLUDE_HOST 1
+#define HAVE_DECL_IFLA_XDP_UNSPEC $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_XDP_FD" "ac_cv_have_decl_IFLA_XDP_FD" "
+#include <netinet/in.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "exclude_guest" "ac_cv_member_struct_perf_event_attr_exclude_guest" "#include <linux/perf_event.h>
 "
-if test "x$ac_cv_member_struct_perf_event_attr_exclude_guest" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_XDP_FD" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PERF_EVENT_ATTR_EXCLUDE_GUEST 1
+#define HAVE_DECL_IFLA_XDP_FD $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_XDP_ATTACHED" "ac_cv_have_decl_IFLA_XDP_ATTACHED" "
+#include <netinet/in.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "exclude_callchain_kernel" "ac_cv_member_struct_perf_event_attr_exclude_callchain_kernel" "#include <linux/perf_event.h>
 "
-if test "x$ac_cv_member_struct_perf_event_attr_exclude_callchain_kernel" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_XDP_ATTACHED" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PERF_EVENT_ATTR_EXCLUDE_CALLCHAIN_KERNEL 1
+#define HAVE_DECL_IFLA_XDP_ATTACHED $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_XDP_FLAGS" "ac_cv_have_decl_IFLA_XDP_FLAGS" "
+#include <netinet/in.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "exclude_callchain_user" "ac_cv_member_struct_perf_event_attr_exclude_callchain_user" "#include <linux/perf_event.h>
 "
-if test "x$ac_cv_member_struct_perf_event_attr_exclude_callchain_user" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_XDP_FLAGS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PERF_EVENT_ATTR_EXCLUDE_CALLCHAIN_USER 1
+#define HAVE_DECL_IFLA_XDP_FLAGS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_XDP_PROG_ID" "ac_cv_have_decl_IFLA_XDP_PROG_ID" "
+#include <netinet/in.h>
+#include <linux/rtnetlink.h>
 
-
+"
+if test "x$ac_cv_have_decl_IFLA_XDP_PROG_ID" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
-ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "mmap2" "ac_cv_member_struct_perf_event_attr_mmap2" "#include <linux/perf_event.h>
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_IFLA_XDP_PROG_ID $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_XDP_DRV_PROG_ID" "ac_cv_have_decl_IFLA_XDP_DRV_PROG_ID" "
+#include <netinet/in.h>
+#include <linux/rtnetlink.h>
+
 "
-if test "x$ac_cv_member_struct_perf_event_attr_mmap2" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_XDP_DRV_PROG_ID" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PERF_EVENT_ATTR_MMAP2 1
+#define HAVE_DECL_IFLA_XDP_DRV_PROG_ID $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_XDP_SKB_PROG_ID" "ac_cv_have_decl_IFLA_XDP_SKB_PROG_ID" "
+#include <netinet/in.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "comm_exec" "ac_cv_member_struct_perf_event_attr_comm_exec" "#include <linux/perf_event.h>
 "
-if test "x$ac_cv_member_struct_perf_event_attr_comm_exec" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_XDP_SKB_PROG_ID" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PERF_EVENT_ATTR_COMM_EXEC 1
+#define HAVE_DECL_IFLA_XDP_SKB_PROG_ID $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_XDP_HW_PROG_ID" "ac_cv_have_decl_IFLA_XDP_HW_PROG_ID" "
+#include <netinet/in.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "use_clockid" "ac_cv_member_struct_perf_event_attr_use_clockid" "#include <linux/perf_event.h>
 "
-if test "x$ac_cv_member_struct_perf_event_attr_use_clockid" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_XDP_HW_PROG_ID" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PERF_EVENT_ATTR_USE_CLOCKID 1
+#define HAVE_DECL_IFLA_XDP_HW_PROG_ID $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_XDP_EXPECTED_FD" "ac_cv_have_decl_IFLA_XDP_EXPECTED_FD" "
+#include <netinet/in.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "context_switch" "ac_cv_member_struct_perf_event_attr_context_switch" "#include <linux/perf_event.h>
 "
-if test "x$ac_cv_member_struct_perf_event_attr_context_switch" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_XDP_EXPECTED_FD" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PERF_EVENT_ATTR_CONTEXT_SWITCH 1
+#define HAVE_DECL_IFLA_XDP_EXPECTED_FD $ac_have_decl
 _ACEOF
 
 
-fi
-ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "write_backward" "ac_cv_member_struct_perf_event_attr_write_backward" "#include <linux/perf_event.h>
+ac_fn_c_check_decl "$LINENO" "IFLA_UNSPEC" "ac_cv_have_decl_IFLA_UNSPEC" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
+
 "
-if test "x$ac_cv_member_struct_perf_event_attr_write_backward" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_UNSPEC" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PERF_EVENT_ATTR_WRITE_BACKWARD 1
+#define HAVE_DECL_IFLA_UNSPEC $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_ADDRESS" "ac_cv_have_decl_IFLA_ADDRESS" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "namespaces" "ac_cv_member_struct_perf_event_attr_namespaces" "#include <linux/perf_event.h>
 "
-if test "x$ac_cv_member_struct_perf_event_attr_namespaces" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_ADDRESS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PERF_EVENT_ATTR_NAMESPACES 1
+#define HAVE_DECL_IFLA_ADDRESS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_BROADCAST" "ac_cv_have_decl_IFLA_BROADCAST" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "bp_type" "ac_cv_member_struct_perf_event_attr_bp_type" "#include <linux/perf_event.h>
 "
-if test "x$ac_cv_member_struct_perf_event_attr_bp_type" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_BROADCAST" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PERF_EVENT_ATTR_BP_TYPE 1
+#define HAVE_DECL_IFLA_BROADCAST $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_IFNAME" "ac_cv_have_decl_IFLA_IFNAME" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "config1" "ac_cv_member_struct_perf_event_attr_config1" "#include <linux/perf_event.h>
 "
-if test "x$ac_cv_member_struct_perf_event_attr_config1" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_IFNAME" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PERF_EVENT_ATTR_CONFIG1 1
+#define HAVE_DECL_IFLA_IFNAME $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_MTU" "ac_cv_have_decl_IFLA_MTU" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "config2" "ac_cv_member_struct_perf_event_attr_config2" "#include <linux/perf_event.h>
 "
-if test "x$ac_cv_member_struct_perf_event_attr_config2" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_MTU" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PERF_EVENT_ATTR_CONFIG2 1
+#define HAVE_DECL_IFLA_MTU $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_LINK" "ac_cv_have_decl_IFLA_LINK" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "branch_sample_type" "ac_cv_member_struct_perf_event_attr_branch_sample_type" "#include <linux/perf_event.h>
 "
-if test "x$ac_cv_member_struct_perf_event_attr_branch_sample_type" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_LINK" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PERF_EVENT_ATTR_BRANCH_SAMPLE_TYPE 1
+#define HAVE_DECL_IFLA_LINK $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_QDISC" "ac_cv_have_decl_IFLA_QDISC" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "sample_regs_user" "ac_cv_member_struct_perf_event_attr_sample_regs_user" "#include <linux/perf_event.h>
 "
-if test "x$ac_cv_member_struct_perf_event_attr_sample_regs_user" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_QDISC" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PERF_EVENT_ATTR_SAMPLE_REGS_USER 1
+#define HAVE_DECL_IFLA_QDISC $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_STATS" "ac_cv_have_decl_IFLA_STATS" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "sample_stack_user" "ac_cv_member_struct_perf_event_attr_sample_stack_user" "#include <linux/perf_event.h>
 "
-if test "x$ac_cv_member_struct_perf_event_attr_sample_stack_user" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_STATS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PERF_EVENT_ATTR_SAMPLE_STACK_USER 1
+#define HAVE_DECL_IFLA_STATS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_COST" "ac_cv_have_decl_IFLA_COST" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "sample_regs_intr" "ac_cv_member_struct_perf_event_attr_sample_regs_intr" "#include <linux/perf_event.h>
 "
-if test "x$ac_cv_member_struct_perf_event_attr_sample_regs_intr" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_COST" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PERF_EVENT_ATTR_SAMPLE_REGS_INTR 1
+#define HAVE_DECL_IFLA_COST $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_PRIORITY" "ac_cv_have_decl_IFLA_PRIORITY" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "aux_watermark" "ac_cv_member_struct_perf_event_attr_aux_watermark" "#include <linux/perf_event.h>
 "
-if test "x$ac_cv_member_struct_perf_event_attr_aux_watermark" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_PRIORITY" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PERF_EVENT_ATTR_AUX_WATERMARK 1
+#define HAVE_DECL_IFLA_PRIORITY $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_MASTER" "ac_cv_have_decl_IFLA_MASTER" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "sample_max_stack" "ac_cv_member_struct_perf_event_attr_sample_max_stack" "#include <linux/perf_event.h>
 "
-if test "x$ac_cv_member_struct_perf_event_attr_sample_max_stack" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_MASTER" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PERF_EVENT_ATTR_SAMPLE_MAX_STACK 1
+#define HAVE_DECL_IFLA_MASTER $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_WIRELESS" "ac_cv_have_decl_IFLA_WIRELESS" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct perf_event_attr" "aux_sample_size" "ac_cv_member_struct_perf_event_attr_aux_sample_size" "#include <linux/perf_event.h>
 "
-if test "x$ac_cv_member_struct_perf_event_attr_aux_sample_size" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_WIRELESS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PERF_EVENT_ATTR_AUX_SAMPLE_SIZE 1
+#define HAVE_DECL_IFLA_WIRELESS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_PROTINFO" "ac_cv_have_decl_IFLA_PROTINFO" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
+"
+if test "x$ac_cv_have_decl_IFLA_PROTINFO" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
-
-for ac_header in asm/cachectl.h asm/guarded_storage.h asm/sysmips.h elf.h gcov.h iconv.h inttypes.h linux/bsg.h linux/dm-ioctl.h linux/dqblk_xfs.h linux/falloc.h linux/fib_rules.h linux/fiemap.h linux/hiddev.h linux/if_addr.h linux/if_link.h linux/ip_vs.h linux/ipc.h linux/kcmp.h linux/kvm.h linux/memfd.h linux/mmtimer.h linux/mount.h linux/neighbour.h linux/netfilter/ipset/ip_set.h linux/netfilter/nf_tables.h linux/netfilter/nf_tables_compat.h linux/netfilter/nfnetlink.h linux/netfilter/nfnetlink_acct.h linux/netfilter/nfnetlink_conntrack.h linux/netfilter/nfnetlink_cthelper.h linux/netfilter/nfnetlink_cttimeout.h linux/netfilter/nfnetlink_log.h linux/netfilter/nfnetlink_queue.h linux/nsfs.h linux/perf_event.h linux/quota.h linux/sched.h linux/seccomp.h linux/securebits.h linux/userfaultfd.h linux/utsname.h mqueue.h netinet/sctp.h netipx/ipx.h paths.h scsi/sg.h stropts.h sys/conf.h sys/eventfd.h sys/fanotify.h sys/ipc.h sys/quota.h sys/signalfd.h sys/xattr.h ustat.h
-do :
-  as_ac_Header=`$as_echo "ac_cv_header_$ac_header" | $as_tr_sh`
-ac_fn_c_check_header_mongrel "$LINENO" "$ac_header" "$as_ac_Header" "$ac_includes_default"
-if eval test \"x\$"$as_ac_Header"\" = x"yes"; then :
-  cat >>confdefs.h <<_ACEOF
-#define `$as_echo "HAVE_$ac_header" | $as_tr_cpp` 1
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_IFLA_PROTINFO $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_TXQLEN" "ac_cv_have_decl_IFLA_TXQLEN" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
+"
+if test "x$ac_cv_have_decl_IFLA_TXQLEN" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
-done
-
-
-for ac_header in asm/sigcontext.h
-do :
-  ac_fn_c_check_header_compile "$LINENO" "asm/sigcontext.h" "ac_cv_header_asm_sigcontext_h" "#include <signal.h>
-"
-if test "x$ac_cv_header_asm_sigcontext_h" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_ASM_SIGCONTEXT_H 1
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_IFLA_TXQLEN $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_MAP" "ac_cv_have_decl_IFLA_MAP" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
+"
+if test "x$ac_cv_have_decl_IFLA_MAP" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
-done
-
-
-for ac_header in netinet/tcp.h netinet/udp.h
-do :
-  as_ac_Header=`$as_echo "ac_cv_header_$ac_header" | $as_tr_sh`
-ac_fn_c_check_header_compile "$LINENO" "$ac_header" "$as_ac_Header" "#include <netinet/in.h>
-"
-if eval test \"x\$"$as_ac_Header"\" = x"yes"; then :
-  cat >>confdefs.h <<_ACEOF
-#define `$as_echo "HAVE_$ac_header" | $as_tr_cpp` 1
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_IFLA_MAP $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_WEIGHT" "ac_cv_have_decl_IFLA_WEIGHT" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
+"
+if test "x$ac_cv_have_decl_IFLA_WEIGHT" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
-done
-
-
-for ac_header in linux/mqueue.h
-do :
-  ac_fn_c_check_header_compile "$LINENO" "linux/mqueue.h" "ac_cv_header_linux_mqueue_h" "#include <linux/types.h>
-"
-if test "x$ac_cv_header_linux_mqueue_h" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_LINUX_MQUEUE_H 1
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_IFLA_WEIGHT $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_OPERSTATE" "ac_cv_have_decl_IFLA_OPERSTATE" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
+"
+if test "x$ac_cv_have_decl_IFLA_OPERSTATE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
-done
-
-
-for ac_header in linux/netfilter/xt_osf.h
-do :
-  ac_fn_c_check_header_compile "$LINENO" "linux/netfilter/xt_osf.h" "ac_cv_header_linux_netfilter_xt_osf_h" "#include <linux/ip.h>
-#include <linux/tcp.h>
-"
-if test "x$ac_cv_header_linux_netfilter_xt_osf_h" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_LINUX_NETFILTER_XT_OSF_H 1
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_IFLA_OPERSTATE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_LINKMODE" "ac_cv_have_decl_IFLA_LINKMODE" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
+"
+if test "x$ac_cv_have_decl_IFLA_LINKMODE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
-done
-
-
-for ac_header in linux/netfilter_arp/arp_tables.h linux/netfilter_bridge/ebtables.h linux/netfilter_ipv4/ip_tables.h linux/netfilter_ipv6/ip6_tables.h
-do :
-  as_ac_Header=`$as_echo "ac_cv_header_$ac_header" | $as_tr_sh`
-ac_fn_c_check_header_compile "$LINENO" "$ac_header" "$as_ac_Header" "#include <netinet/in.h>
-#include <net/if.h>
-"
-if eval test \"x\$"$as_ac_Header"\" = x"yes"; then :
-  cat >>confdefs.h <<_ACEOF
-#define `$as_echo "HAVE_$ac_header" | $as_tr_cpp` 1
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_IFLA_LINKMODE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_LINKINFO" "ac_cv_have_decl_IFLA_LINKINFO" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
+"
+if test "x$ac_cv_have_decl_IFLA_LINKINFO" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
-done
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_IFLA_LINKINFO $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_NET_NS_PID" "ac_cv_have_decl_IFLA_NET_NS_PID" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
+"
+if test "x$ac_cv_have_decl_IFLA_NET_NS_PID" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
-for ac_header in linux/bpf.h
-do :
-  ac_fn_c_check_header_mongrel "$LINENO" "linux/bpf.h" "ac_cv_header_linux_bpf_h" "$ac_includes_default"
-if test "x$ac_cv_header_linux_bpf_h" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_LINUX_BPF_H 1
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_IFLA_NET_NS_PID $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_IFALIAS" "ac_cv_have_decl_IFLA_IFALIAS" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-	ac_fn_c_check_type "$LINENO" "struct bpf_insn" "ac_cv_type_struct_bpf_insn" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_type_struct_bpf_insn" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_IFALIAS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_INSN 1
+#define HAVE_DECL_IFLA_IFALIAS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_NUM_VF" "ac_cv_have_decl_IFLA_NUM_VF" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_type "$LINENO" "struct bpf_map_info" "ac_cv_type_struct_bpf_map_info" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_type_struct_bpf_map_info" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_NUM_VF" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_MAP_INFO 1
+#define HAVE_DECL_IFLA_NUM_VF $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_VFINFO_LIST" "ac_cv_have_decl_IFLA_VFINFO_LIST" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_type "$LINENO" "struct bpf_prog_info" "ac_cv_type_struct_bpf_prog_info" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_type_struct_bpf_prog_info" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_VFINFO_LIST" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO 1
+#define HAVE_DECL_IFLA_VFINFO_LIST $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_STATS64" "ac_cv_have_decl_IFLA_STATS64" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
+"
+if test "x$ac_cv_have_decl_IFLA_STATS64" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
-		ac_fn_c_check_member "$LINENO" "struct bpf_map_info" "btf_id" "ac_cv_member_struct_bpf_map_info_btf_id" "#include <linux/bpf.h>
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_IFLA_STATS64 $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_VF_PORTS" "ac_cv_have_decl_IFLA_VF_PORTS" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
+
 "
-if test "x$ac_cv_member_struct_bpf_map_info_btf_id" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_VF_PORTS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_MAP_INFO_BTF_ID 1
+#define HAVE_DECL_IFLA_VF_PORTS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_PORT_SELF" "ac_cv_have_decl_IFLA_PORT_SELF" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_map_info" "btf_key_type_id" "ac_cv_member_struct_bpf_map_info_btf_key_type_id" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_map_info_btf_key_type_id" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_PORT_SELF" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_MAP_INFO_BTF_KEY_TYPE_ID 1
+#define HAVE_DECL_IFLA_PORT_SELF $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_AF_SPEC" "ac_cv_have_decl_IFLA_AF_SPEC" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_map_info" "btf_value_type_id" "ac_cv_member_struct_bpf_map_info_btf_value_type_id" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_map_info_btf_value_type_id" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_AF_SPEC" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_MAP_INFO_BTF_VALUE_TYPE_ID 1
+#define HAVE_DECL_IFLA_AF_SPEC $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_GROUP" "ac_cv_have_decl_IFLA_GROUP" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_map_info" "id" "ac_cv_member_struct_bpf_map_info_id" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_map_info_id" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_GROUP" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_MAP_INFO_ID 1
+#define HAVE_DECL_IFLA_GROUP $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_NET_NS_FD" "ac_cv_have_decl_IFLA_NET_NS_FD" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_map_info" "ifindex" "ac_cv_member_struct_bpf_map_info_ifindex" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_map_info_ifindex" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_NET_NS_FD" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_MAP_INFO_IFINDEX 1
+#define HAVE_DECL_IFLA_NET_NS_FD $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_EXT_MASK" "ac_cv_have_decl_IFLA_EXT_MASK" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_map_info" "key_size" "ac_cv_member_struct_bpf_map_info_key_size" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_map_info_key_size" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_EXT_MASK" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_MAP_INFO_KEY_SIZE 1
+#define HAVE_DECL_IFLA_EXT_MASK $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_PROMISCUITY" "ac_cv_have_decl_IFLA_PROMISCUITY" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_map_info" "map_flags" "ac_cv_member_struct_bpf_map_info_map_flags" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_map_info_map_flags" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_PROMISCUITY" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_MAP_INFO_MAP_FLAGS 1
+#define HAVE_DECL_IFLA_PROMISCUITY $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_NUM_TX_QUEUES" "ac_cv_have_decl_IFLA_NUM_TX_QUEUES" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_map_info" "max_entries" "ac_cv_member_struct_bpf_map_info_max_entries" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_map_info_max_entries" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_NUM_TX_QUEUES" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_MAP_INFO_MAX_ENTRIES 1
+#define HAVE_DECL_IFLA_NUM_TX_QUEUES $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_NUM_RX_QUEUES" "ac_cv_have_decl_IFLA_NUM_RX_QUEUES" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_map_info" "name" "ac_cv_member_struct_bpf_map_info_name" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_map_info_name" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_NUM_RX_QUEUES" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_MAP_INFO_NAME 1
+#define HAVE_DECL_IFLA_NUM_RX_QUEUES $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_CARRIER" "ac_cv_have_decl_IFLA_CARRIER" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_map_info" "type" "ac_cv_member_struct_bpf_map_info_type" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_map_info_type" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_CARRIER" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_MAP_INFO_TYPE 1
+#define HAVE_DECL_IFLA_CARRIER $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_PHYS_PORT_ID" "ac_cv_have_decl_IFLA_PHYS_PORT_ID" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_map_info" "value_size" "ac_cv_member_struct_bpf_map_info_value_size" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_map_info_value_size" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_PHYS_PORT_ID" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_MAP_INFO_VALUE_SIZE 1
+#define HAVE_DECL_IFLA_PHYS_PORT_ID $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_CARRIER_CHANGES" "ac_cv_have_decl_IFLA_CARRIER_CHANGES" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "btf_id" "ac_cv_member_struct_bpf_prog_info_btf_id" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_btf_id" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_CARRIER_CHANGES" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_BTF_ID 1
+#define HAVE_DECL_IFLA_CARRIER_CHANGES $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_PHYS_SWITCH_ID" "ac_cv_have_decl_IFLA_PHYS_SWITCH_ID" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "created_by_uid" "ac_cv_member_struct_bpf_prog_info_created_by_uid" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_created_by_uid" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_PHYS_SWITCH_ID" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_CREATED_BY_UID 1
+#define HAVE_DECL_IFLA_PHYS_SWITCH_ID $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_LINK_NETNSID" "ac_cv_have_decl_IFLA_LINK_NETNSID" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "func_info" "ac_cv_member_struct_bpf_prog_info_func_info" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_func_info" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_LINK_NETNSID" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_FUNC_INFO 1
+#define HAVE_DECL_IFLA_LINK_NETNSID $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_PHYS_PORT_NAME" "ac_cv_have_decl_IFLA_PHYS_PORT_NAME" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "func_info_rec_size" "ac_cv_member_struct_bpf_prog_info_func_info_rec_size" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_func_info_rec_size" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_PHYS_PORT_NAME" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_FUNC_INFO_REC_SIZE 1
+#define HAVE_DECL_IFLA_PHYS_PORT_NAME $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_PROTO_DOWN" "ac_cv_have_decl_IFLA_PROTO_DOWN" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "id" "ac_cv_member_struct_bpf_prog_info_id" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_id" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_PROTO_DOWN" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_ID 1
+#define HAVE_DECL_IFLA_PROTO_DOWN $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_GSO_MAX_SEGS" "ac_cv_have_decl_IFLA_GSO_MAX_SEGS" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "ifindex" "ac_cv_member_struct_bpf_prog_info_ifindex" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_ifindex" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_GSO_MAX_SEGS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_IFINDEX 1
+#define HAVE_DECL_IFLA_GSO_MAX_SEGS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_GSO_MAX_SIZE" "ac_cv_have_decl_IFLA_GSO_MAX_SIZE" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "jited_func_lens" "ac_cv_member_struct_bpf_prog_info_jited_func_lens" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_jited_func_lens" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_GSO_MAX_SIZE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_JITED_FUNC_LENS 1
+#define HAVE_DECL_IFLA_GSO_MAX_SIZE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_PAD" "ac_cv_have_decl_IFLA_PAD" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "jited_ksyms" "ac_cv_member_struct_bpf_prog_info_jited_ksyms" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_jited_ksyms" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_PAD" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_JITED_KSYMS 1
+#define HAVE_DECL_IFLA_PAD $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_XDP" "ac_cv_have_decl_IFLA_XDP" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "jited_line_info" "ac_cv_member_struct_bpf_prog_info_jited_line_info" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_jited_line_info" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_XDP" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_JITED_LINE_INFO 1
+#define HAVE_DECL_IFLA_XDP $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_EVENT" "ac_cv_have_decl_IFLA_EVENT" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "jited_line_info_rec_size" "ac_cv_member_struct_bpf_prog_info_jited_line_info_rec_size" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_jited_line_info_rec_size" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_EVENT" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_JITED_LINE_INFO_REC_SIZE 1
+#define HAVE_DECL_IFLA_EVENT $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_NEW_NETNSID" "ac_cv_have_decl_IFLA_NEW_NETNSID" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "jited_prog_insns" "ac_cv_member_struct_bpf_prog_info_jited_prog_insns" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_jited_prog_insns" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_NEW_NETNSID" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_JITED_PROG_INSNS 1
+#define HAVE_DECL_IFLA_NEW_NETNSID $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_IF_NETNSID" "ac_cv_have_decl_IFLA_IF_NETNSID" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "jited_prog_len" "ac_cv_member_struct_bpf_prog_info_jited_prog_len" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_jited_prog_len" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_IF_NETNSID" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_JITED_PROG_LEN 1
+#define HAVE_DECL_IFLA_IF_NETNSID $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_CARRIER_UP_COUNT" "ac_cv_have_decl_IFLA_CARRIER_UP_COUNT" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "line_info" "ac_cv_member_struct_bpf_prog_info_line_info" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_line_info" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_CARRIER_UP_COUNT" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_LINE_INFO 1
+#define HAVE_DECL_IFLA_CARRIER_UP_COUNT $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_CARRIER_DOWN_COUNT" "ac_cv_have_decl_IFLA_CARRIER_DOWN_COUNT" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "line_info_rec_size" "ac_cv_member_struct_bpf_prog_info_line_info_rec_size" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_line_info_rec_size" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_CARRIER_DOWN_COUNT" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_LINE_INFO_REC_SIZE 1
+#define HAVE_DECL_IFLA_CARRIER_DOWN_COUNT $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_NEW_IFINDEX" "ac_cv_have_decl_IFLA_NEW_IFINDEX" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "load_time" "ac_cv_member_struct_bpf_prog_info_load_time" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_load_time" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_NEW_IFINDEX" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_LOAD_TIME 1
+#define HAVE_DECL_IFLA_NEW_IFINDEX $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_MIN_MTU" "ac_cv_have_decl_IFLA_MIN_MTU" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "map_ids" "ac_cv_member_struct_bpf_prog_info_map_ids" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_map_ids" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_MIN_MTU" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_MAP_IDS 1
+#define HAVE_DECL_IFLA_MIN_MTU $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_MAX_MTU" "ac_cv_have_decl_IFLA_MAX_MTU" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "name" "ac_cv_member_struct_bpf_prog_info_name" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_name" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_MAX_MTU" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_NAME 1
+#define HAVE_DECL_IFLA_MAX_MTU $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_PROP_LIST" "ac_cv_have_decl_IFLA_PROP_LIST" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "nr_func_info" "ac_cv_member_struct_bpf_prog_info_nr_func_info" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_nr_func_info" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_PROP_LIST" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_NR_FUNC_INFO 1
+#define HAVE_DECL_IFLA_PROP_LIST $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_ALT_IFNAME" "ac_cv_have_decl_IFLA_ALT_IFNAME" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "nr_jited_func_lens" "ac_cv_member_struct_bpf_prog_info_nr_jited_func_lens" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_nr_jited_func_lens" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_ALT_IFNAME" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_NR_JITED_FUNC_LENS 1
+#define HAVE_DECL_IFLA_ALT_IFNAME $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_PERM_ADDRESS" "ac_cv_have_decl_IFLA_PERM_ADDRESS" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "nr_jited_ksyms" "ac_cv_member_struct_bpf_prog_info_nr_jited_ksyms" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_nr_jited_ksyms" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_PERM_ADDRESS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_NR_JITED_KSYMS 1
+#define HAVE_DECL_IFLA_PERM_ADDRESS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "IFLA_PROTO_DOWN_REASON" "ac_cv_have_decl_IFLA_PROTO_DOWN_REASON" "
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "nr_jited_line_info" "ac_cv_member_struct_bpf_prog_info_nr_jited_line_info" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_nr_jited_line_info" = xyes; then :
+if test "x$ac_cv_have_decl_IFLA_PROTO_DOWN_REASON" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_NR_JITED_LINE_INFO 1
+#define HAVE_DECL_IFLA_PROTO_DOWN_REASON $ac_have_decl
 _ACEOF
 
 
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "nr_line_info" "ac_cv_member_struct_bpf_prog_info_nr_line_info" "#include <linux/bpf.h>
+ac_fn_c_check_decl "$LINENO" "TCA_ACT_UNSPEC" "ac_cv_have_decl_TCA_ACT_UNSPEC" "
+#include <linux/pkt_cls.h>
+
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_nr_line_info" = xyes; then :
+if test "x$ac_cv_have_decl_TCA_ACT_UNSPEC" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_NR_LINE_INFO 1
+#define HAVE_DECL_TCA_ACT_UNSPEC $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "TCA_ACT_KIND" "ac_cv_have_decl_TCA_ACT_KIND" "
+#include <linux/pkt_cls.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "nr_map_ids" "ac_cv_member_struct_bpf_prog_info_nr_map_ids" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_nr_map_ids" = xyes; then :
+if test "x$ac_cv_have_decl_TCA_ACT_KIND" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_NR_MAP_IDS 1
+#define HAVE_DECL_TCA_ACT_KIND $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "TCA_ACT_OPTIONS" "ac_cv_have_decl_TCA_ACT_OPTIONS" "
+#include <linux/pkt_cls.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "nr_prog_tags" "ac_cv_member_struct_bpf_prog_info_nr_prog_tags" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_nr_prog_tags" = xyes; then :
+if test "x$ac_cv_have_decl_TCA_ACT_OPTIONS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_NR_PROG_TAGS 1
+#define HAVE_DECL_TCA_ACT_OPTIONS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "TCA_ACT_INDEX" "ac_cv_have_decl_TCA_ACT_INDEX" "
+#include <linux/pkt_cls.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "prog_tags" "ac_cv_member_struct_bpf_prog_info_prog_tags" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_prog_tags" = xyes; then :
+if test "x$ac_cv_have_decl_TCA_ACT_INDEX" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_PROG_TAGS 1
+#define HAVE_DECL_TCA_ACT_INDEX $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "TCA_ACT_STATS" "ac_cv_have_decl_TCA_ACT_STATS" "
+#include <linux/pkt_cls.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "run_cnt" "ac_cv_member_struct_bpf_prog_info_run_cnt" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_run_cnt" = xyes; then :
+if test "x$ac_cv_have_decl_TCA_ACT_STATS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_RUN_CNT 1
+#define HAVE_DECL_TCA_ACT_STATS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "TCA_ACT_PAD" "ac_cv_have_decl_TCA_ACT_PAD" "
+#include <linux/pkt_cls.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "run_time_ns" "ac_cv_member_struct_bpf_prog_info_run_time_ns" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_run_time_ns" = xyes; then :
+if test "x$ac_cv_have_decl_TCA_ACT_PAD" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_RUN_TIME_NS 1
+#define HAVE_DECL_TCA_ACT_PAD $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "TCA_ACT_COOKIE" "ac_cv_have_decl_TCA_ACT_COOKIE" "
+#include <linux/pkt_cls.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "tag" "ac_cv_member_struct_bpf_prog_info_tag" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_tag" = xyes; then :
+if test "x$ac_cv_have_decl_TCA_ACT_COOKIE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_TAG 1
+#define HAVE_DECL_TCA_ACT_COOKIE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "TCA_ACT_FLAGS" "ac_cv_have_decl_TCA_ACT_FLAGS" "
+#include <linux/pkt_cls.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "type" "ac_cv_member_struct_bpf_prog_info_type" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_type" = xyes; then :
+if test "x$ac_cv_have_decl_TCA_ACT_FLAGS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_TYPE 1
+#define HAVE_DECL_TCA_ACT_FLAGS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "TCA_ACT_HW_STATS" "ac_cv_have_decl_TCA_ACT_HW_STATS" "
+#include <linux/pkt_cls.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "xlated_prog_insns" "ac_cv_member_struct_bpf_prog_info_xlated_prog_insns" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_xlated_prog_insns" = xyes; then :
+if test "x$ac_cv_have_decl_TCA_ACT_HW_STATS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_XLATED_PROG_INSNS 1
+#define HAVE_DECL_TCA_ACT_HW_STATS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "TCA_ACT_USED_HW_STATS" "ac_cv_have_decl_TCA_ACT_USED_HW_STATS" "
+#include <linux/pkt_cls.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct bpf_prog_info" "xlated_prog_len" "ac_cv_member_struct_bpf_prog_info_xlated_prog_len" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_struct_bpf_prog_info_xlated_prog_len" = xyes; then :
+if test "x$ac_cv_have_decl_TCA_ACT_USED_HW_STATS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BPF_PROG_INFO_XLATED_PROG_LEN 1
+#define HAVE_DECL_TCA_ACT_USED_HW_STATS $ac_have_decl
 _ACEOF
 
 
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "attach_bpf_fd" "ac_cv_member_union_bpf_attr_attach_bpf_fd" "#include <linux/bpf.h>
+ac_fn_c_check_decl "$LINENO" "TCA_STAB_UNSPEC" "ac_cv_have_decl_TCA_STAB_UNSPEC" "
+#include <linux/types.h>
+#include <linux/pkt_sched.h>
+
 "
-if test "x$ac_cv_member_union_bpf_attr_attach_bpf_fd" = xyes; then :
+if test "x$ac_cv_have_decl_TCA_STAB_UNSPEC" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_ATTACH_BPF_FD 1
+#define HAVE_DECL_TCA_STAB_UNSPEC $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "TCA_STAB_BASE" "ac_cv_have_decl_TCA_STAB_BASE" "
+#include <linux/types.h>
+#include <linux/pkt_sched.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "attach_btf_id" "ac_cv_member_union_bpf_attr_attach_btf_id" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_attach_btf_id" = xyes; then :
+if test "x$ac_cv_have_decl_TCA_STAB_BASE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_ATTACH_BTF_ID 1
+#define HAVE_DECL_TCA_STAB_BASE $ac_have_decl
 _ACEOF
-
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "attach_flags" "ac_cv_member_union_bpf_attr_attach_flags" "#include <linux/bpf.h>
+ac_fn_c_check_decl "$LINENO" "TCA_STAB_DATA" "ac_cv_have_decl_TCA_STAB_DATA" "
+#include <linux/types.h>
+#include <linux/pkt_sched.h>
+
 "
-if test "x$ac_cv_member_union_bpf_attr_attach_flags" = xyes; then :
+if test "x$ac_cv_have_decl_TCA_STAB_DATA" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_ATTACH_FLAGS 1
+#define HAVE_DECL_TCA_STAB_DATA $ac_have_decl
 _ACEOF
 
 
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "attach_prog_fd" "ac_cv_member_union_bpf_attr_attach_prog_fd" "#include <linux/bpf.h>
+ac_fn_c_check_decl "$LINENO" "TCA_STATS_UNSPEC" "ac_cv_have_decl_TCA_STATS_UNSPEC" "
+#include <linux/gen_stats.h>
+
 "
-if test "x$ac_cv_member_union_bpf_attr_attach_prog_fd" = xyes; then :
+if test "x$ac_cv_have_decl_TCA_STATS_UNSPEC" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_ATTACH_PROG_FD 1
+#define HAVE_DECL_TCA_STATS_UNSPEC $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "TCA_STATS_BASIC" "ac_cv_have_decl_TCA_STATS_BASIC" "
+#include <linux/gen_stats.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "attach_type" "ac_cv_member_union_bpf_attr_attach_type" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_attach_type" = xyes; then :
+if test "x$ac_cv_have_decl_TCA_STATS_BASIC" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_ATTACH_TYPE 1
+#define HAVE_DECL_TCA_STATS_BASIC $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "TCA_STATS_RATE_EST" "ac_cv_have_decl_TCA_STATS_RATE_EST" "
+#include <linux/gen_stats.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "bpf_fd" "ac_cv_member_union_bpf_attr_bpf_fd" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_bpf_fd" = xyes; then :
+if test "x$ac_cv_have_decl_TCA_STATS_RATE_EST" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_BPF_FD 1
+#define HAVE_DECL_TCA_STATS_RATE_EST $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "TCA_STATS_QUEUE" "ac_cv_have_decl_TCA_STATS_QUEUE" "
+#include <linux/gen_stats.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "btf" "ac_cv_member_union_bpf_attr_btf" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_btf" = xyes; then :
+if test "x$ac_cv_have_decl_TCA_STATS_QUEUE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_BTF 1
+#define HAVE_DECL_TCA_STATS_QUEUE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "TCA_STATS_APP" "ac_cv_have_decl_TCA_STATS_APP" "
+#include <linux/gen_stats.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "btf_fd" "ac_cv_member_union_bpf_attr_btf_fd" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_btf_fd" = xyes; then :
+if test "x$ac_cv_have_decl_TCA_STATS_APP" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_BTF_FD 1
+#define HAVE_DECL_TCA_STATS_APP $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "TCA_STATS_RATE_EST64" "ac_cv_have_decl_TCA_STATS_RATE_EST64" "
+#include <linux/gen_stats.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "btf_id" "ac_cv_member_union_bpf_attr_btf_id" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_btf_id" = xyes; then :
+if test "x$ac_cv_have_decl_TCA_STATS_RATE_EST64" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_BTF_ID 1
+#define HAVE_DECL_TCA_STATS_RATE_EST64 $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "TCA_STATS_PAD" "ac_cv_have_decl_TCA_STATS_PAD" "
+#include <linux/gen_stats.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "btf_key_type_id" "ac_cv_member_union_bpf_attr_btf_key_type_id" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_btf_key_type_id" = xyes; then :
+if test "x$ac_cv_have_decl_TCA_STATS_PAD" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_BTF_KEY_TYPE_ID 1
+#define HAVE_DECL_TCA_STATS_PAD $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "TCA_STATS_BASIC_HW" "ac_cv_have_decl_TCA_STATS_BASIC_HW" "
+#include <linux/gen_stats.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "btf_log_buf" "ac_cv_member_union_bpf_attr_btf_log_buf" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_btf_log_buf" = xyes; then :
+if test "x$ac_cv_have_decl_TCA_STATS_BASIC_HW" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_BTF_LOG_BUF 1
+#define HAVE_DECL_TCA_STATS_BASIC_HW $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "TCA_STATS_PKT64" "ac_cv_have_decl_TCA_STATS_PKT64" "
+#include <linux/gen_stats.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "btf_log_level" "ac_cv_member_union_bpf_attr_btf_log_level" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_btf_log_level" = xyes; then :
+if test "x$ac_cv_have_decl_TCA_STATS_PKT64" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_BTF_LOG_LEVEL 1
+#define HAVE_DECL_TCA_STATS_PKT64 $ac_have_decl
 _ACEOF
 
 
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "btf_log_size" "ac_cv_member_union_bpf_attr_btf_log_size" "#include <linux/bpf.h>
+ac_fn_c_check_decl "$LINENO" "KERN_OSTYPE" "ac_cv_have_decl_KERN_OSTYPE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_member_union_bpf_attr_btf_log_size" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_OSTYPE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_BTF_LOG_SIZE 1
+#define HAVE_DECL_KERN_OSTYPE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_OSRELEASE" "ac_cv_have_decl_KERN_OSRELEASE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "btf_size" "ac_cv_member_union_bpf_attr_btf_size" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_btf_size" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_OSRELEASE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_BTF_SIZE 1
+#define HAVE_DECL_KERN_OSRELEASE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_OSREV" "ac_cv_have_decl_KERN_OSREV" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "btf_value_type_id" "ac_cv_member_union_bpf_attr_btf_value_type_id" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_btf_value_type_id" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_OSREV" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_BTF_VALUE_TYPE_ID 1
+#define HAVE_DECL_KERN_OSREV $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_VERSION" "ac_cv_have_decl_KERN_VERSION" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "dummy" "ac_cv_member_union_bpf_attr_dummy" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_dummy" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_VERSION" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_DUMMY 1
+#define HAVE_DECL_KERN_VERSION $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_SECUREMASK" "ac_cv_have_decl_KERN_SECUREMASK" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "expected_attach_type" "ac_cv_member_union_bpf_attr_expected_attach_type" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_expected_attach_type" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_SECUREMASK" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_EXPECTED_ATTACH_TYPE 1
+#define HAVE_DECL_KERN_SECUREMASK $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_PROF" "ac_cv_have_decl_KERN_PROF" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "file_flags" "ac_cv_member_union_bpf_attr_file_flags" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_file_flags" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_PROF" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_FILE_FLAGS 1
+#define HAVE_DECL_KERN_PROF $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_NODENAME" "ac_cv_have_decl_KERN_NODENAME" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "flags" "ac_cv_member_union_bpf_attr_flags" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_flags" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_NODENAME" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_FLAGS 1
+#define HAVE_DECL_KERN_NODENAME $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_DOMAINNAME" "ac_cv_have_decl_KERN_DOMAINNAME" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "func_info" "ac_cv_member_union_bpf_attr_func_info" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_func_info" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_DOMAINNAME" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_FUNC_INFO 1
+#define HAVE_DECL_KERN_DOMAINNAME $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_PANIC" "ac_cv_have_decl_KERN_PANIC" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "func_info_cnt" "ac_cv_member_union_bpf_attr_func_info_cnt" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_func_info_cnt" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_PANIC" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_FUNC_INFO_CNT 1
+#define HAVE_DECL_KERN_PANIC $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_REALROOTDEV" "ac_cv_have_decl_KERN_REALROOTDEV" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "func_info_rec_size" "ac_cv_member_union_bpf_attr_func_info_rec_size" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_func_info_rec_size" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_REALROOTDEV" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_FUNC_INFO_REC_SIZE 1
+#define HAVE_DECL_KERN_REALROOTDEV $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_SPARC_REBOOT" "ac_cv_have_decl_KERN_SPARC_REBOOT" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "info.bpf_fd" "ac_cv_member_union_bpf_attr_info_bpf_fd" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_info_bpf_fd" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_SPARC_REBOOT" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_INFO_BPF_FD 1
+#define HAVE_DECL_KERN_SPARC_REBOOT $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_CTLALTDEL" "ac_cv_have_decl_KERN_CTLALTDEL" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "info.info" "ac_cv_member_union_bpf_attr_info_info" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_info_info" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_CTLALTDEL" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_INFO_INFO 1
+#define HAVE_DECL_KERN_CTLALTDEL $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_PRINTK" "ac_cv_have_decl_KERN_PRINTK" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "info.info_len" "ac_cv_member_union_bpf_attr_info_info_len" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_info_info_len" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_PRINTK" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_INFO_INFO_LEN 1
+#define HAVE_DECL_KERN_PRINTK $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_NAMETRANS" "ac_cv_have_decl_KERN_NAMETRANS" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "inner_map_fd" "ac_cv_member_union_bpf_attr_inner_map_fd" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_inner_map_fd" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_NAMETRANS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_INNER_MAP_FD 1
+#define HAVE_DECL_KERN_NAMETRANS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_PPC_HTABRECLAIM" "ac_cv_have_decl_KERN_PPC_HTABRECLAIM" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "insn_cnt" "ac_cv_member_union_bpf_attr_insn_cnt" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_insn_cnt" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_PPC_HTABRECLAIM" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_INSN_CNT 1
+#define HAVE_DECL_KERN_PPC_HTABRECLAIM $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_PPC_ZEROPAGED" "ac_cv_have_decl_KERN_PPC_ZEROPAGED" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "insns" "ac_cv_member_union_bpf_attr_insns" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_insns" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_PPC_ZEROPAGED" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_INSNS 1
+#define HAVE_DECL_KERN_PPC_ZEROPAGED $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_PPC_POWERSAVE_NAP" "ac_cv_have_decl_KERN_PPC_POWERSAVE_NAP" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "kern_version" "ac_cv_member_union_bpf_attr_kern_version" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_kern_version" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_PPC_POWERSAVE_NAP" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_KERN_VERSION 1
+#define HAVE_DECL_KERN_PPC_POWERSAVE_NAP $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_MODPROBE" "ac_cv_have_decl_KERN_MODPROBE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "key" "ac_cv_member_union_bpf_attr_key" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_key" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_MODPROBE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_KEY 1
+#define HAVE_DECL_KERN_MODPROBE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_SG_BIG_BUFF" "ac_cv_have_decl_KERN_SG_BIG_BUFF" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "key_size" "ac_cv_member_union_bpf_attr_key_size" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_key_size" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_SG_BIG_BUFF" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_KEY_SIZE 1
+#define HAVE_DECL_KERN_SG_BIG_BUFF $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_ACCT" "ac_cv_have_decl_KERN_ACCT" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "license" "ac_cv_member_union_bpf_attr_license" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_license" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_ACCT" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_LICENSE 1
+#define HAVE_DECL_KERN_ACCT $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_PPC_L2CR" "ac_cv_have_decl_KERN_PPC_L2CR" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "line_info" "ac_cv_member_union_bpf_attr_line_info" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_line_info" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_PPC_L2CR" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_LINE_INFO 1
+#define HAVE_DECL_KERN_PPC_L2CR $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_RTSIGNR" "ac_cv_have_decl_KERN_RTSIGNR" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "line_info_cnt" "ac_cv_member_union_bpf_attr_line_info_cnt" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_line_info_cnt" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_RTSIGNR" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_LINE_INFO_CNT 1
+#define HAVE_DECL_KERN_RTSIGNR $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_RTSIGMAX" "ac_cv_have_decl_KERN_RTSIGMAX" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "line_info_rec_size" "ac_cv_member_union_bpf_attr_line_info_rec_size" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_line_info_rec_size" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_RTSIGMAX" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_LINE_INFO_REC_SIZE 1
+#define HAVE_DECL_KERN_RTSIGMAX $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_SHMMAX" "ac_cv_have_decl_KERN_SHMMAX" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "log_buf" "ac_cv_member_union_bpf_attr_log_buf" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_log_buf" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_SHMMAX" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_LOG_BUF 1
+#define HAVE_DECL_KERN_SHMMAX $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_MSGMAX" "ac_cv_have_decl_KERN_MSGMAX" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "log_level" "ac_cv_member_union_bpf_attr_log_level" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_log_level" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_MSGMAX" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_LOG_LEVEL 1
+#define HAVE_DECL_KERN_MSGMAX $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_MSGMNB" "ac_cv_have_decl_KERN_MSGMNB" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "log_size" "ac_cv_member_union_bpf_attr_log_size" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_log_size" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_MSGMNB" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_LOG_SIZE 1
+#define HAVE_DECL_KERN_MSGMNB $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_MSGPOOL" "ac_cv_have_decl_KERN_MSGPOOL" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "map_fd" "ac_cv_member_union_bpf_attr_map_fd" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_map_fd" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_MSGPOOL" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_MAP_FD 1
+#define HAVE_DECL_KERN_MSGPOOL $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_SYSRQ" "ac_cv_have_decl_KERN_SYSRQ" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "map_flags" "ac_cv_member_union_bpf_attr_map_flags" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_map_flags" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_SYSRQ" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_MAP_FLAGS 1
+#define HAVE_DECL_KERN_SYSRQ $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_MAX_THREADS" "ac_cv_have_decl_KERN_MAX_THREADS" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "map_id" "ac_cv_member_union_bpf_attr_map_id" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_map_id" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_MAX_THREADS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_MAP_ID 1
+#define HAVE_DECL_KERN_MAX_THREADS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_RANDOM" "ac_cv_have_decl_KERN_RANDOM" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "map_ifindex" "ac_cv_member_union_bpf_attr_map_ifindex" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_map_ifindex" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_RANDOM" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_MAP_IFINDEX 1
+#define HAVE_DECL_KERN_RANDOM $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_SHMALL" "ac_cv_have_decl_KERN_SHMALL" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "map_name" "ac_cv_member_union_bpf_attr_map_name" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_map_name" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_SHMALL" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_MAP_NAME 1
+#define HAVE_DECL_KERN_SHMALL $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_MSGMNI" "ac_cv_have_decl_KERN_MSGMNI" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "map_type" "ac_cv_member_union_bpf_attr_map_type" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_map_type" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_MSGMNI" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_MAP_TYPE 1
+#define HAVE_DECL_KERN_MSGMNI $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_SEM" "ac_cv_have_decl_KERN_SEM" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "max_entries" "ac_cv_member_union_bpf_attr_max_entries" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_max_entries" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_SEM" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_MAX_ENTRIES 1
+#define HAVE_DECL_KERN_SEM $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_SPARC_STOP_A" "ac_cv_have_decl_KERN_SPARC_STOP_A" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "next_id" "ac_cv_member_union_bpf_attr_next_id" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_next_id" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_SPARC_STOP_A" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_NEXT_ID 1
+#define HAVE_DECL_KERN_SPARC_STOP_A $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_SHMMNI" "ac_cv_have_decl_KERN_SHMMNI" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "next_key" "ac_cv_member_union_bpf_attr_next_key" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_next_key" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_SHMMNI" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_NEXT_KEY 1
+#define HAVE_DECL_KERN_SHMMNI $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_OVERFLOWUID" "ac_cv_have_decl_KERN_OVERFLOWUID" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "numa_node" "ac_cv_member_union_bpf_attr_numa_node" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_numa_node" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_OVERFLOWUID" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_NUMA_NODE 1
+#define HAVE_DECL_KERN_OVERFLOWUID $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_OVERFLOWGID" "ac_cv_have_decl_KERN_OVERFLOWGID" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "open_flags" "ac_cv_member_union_bpf_attr_open_flags" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_open_flags" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_OVERFLOWGID" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_OPEN_FLAGS 1
+#define HAVE_DECL_KERN_OVERFLOWGID $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_SHMPATH" "ac_cv_have_decl_KERN_SHMPATH" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "pathname" "ac_cv_member_union_bpf_attr_pathname" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_pathname" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_SHMPATH" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_PATHNAME 1
+#define HAVE_DECL_KERN_SHMPATH $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_HOTPLUG" "ac_cv_have_decl_KERN_HOTPLUG" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "prog_btf_fd" "ac_cv_member_union_bpf_attr_prog_btf_fd" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_prog_btf_fd" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_HOTPLUG" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_PROG_BTF_FD 1
+#define HAVE_DECL_KERN_HOTPLUG $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_IEEE_EMULATION_WARNINGS" "ac_cv_have_decl_KERN_IEEE_EMULATION_WARNINGS" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "prog_flags" "ac_cv_member_union_bpf_attr_prog_flags" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_prog_flags" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_IEEE_EMULATION_WARNINGS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_PROG_FLAGS 1
+#define HAVE_DECL_KERN_IEEE_EMULATION_WARNINGS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_S390_USER_DEBUG_LOGGING" "ac_cv_have_decl_KERN_S390_USER_DEBUG_LOGGING" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "prog_id" "ac_cv_member_union_bpf_attr_prog_id" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_prog_id" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_S390_USER_DEBUG_LOGGING" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_PROG_ID 1
+#define HAVE_DECL_KERN_S390_USER_DEBUG_LOGGING $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_CORE_USES_PID" "ac_cv_have_decl_KERN_CORE_USES_PID" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "prog_ifindex" "ac_cv_member_union_bpf_attr_prog_ifindex" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_prog_ifindex" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_CORE_USES_PID" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_PROG_IFINDEX 1
+#define HAVE_DECL_KERN_CORE_USES_PID $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_TAINTED" "ac_cv_have_decl_KERN_TAINTED" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "prog_name" "ac_cv_member_union_bpf_attr_prog_name" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_prog_name" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_TAINTED" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_PROG_NAME 1
+#define HAVE_DECL_KERN_TAINTED $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_CADPID" "ac_cv_have_decl_KERN_CADPID" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "prog_type" "ac_cv_member_union_bpf_attr_prog_type" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_prog_type" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_CADPID" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_PROG_TYPE 1
+#define HAVE_DECL_KERN_CADPID $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_PIDMAX" "ac_cv_have_decl_KERN_PIDMAX" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "query.attach_flags" "ac_cv_member_union_bpf_attr_query_attach_flags" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_query_attach_flags" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_PIDMAX" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_QUERY_ATTACH_FLAGS 1
+#define HAVE_DECL_KERN_PIDMAX $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_CORE_PATTERN" "ac_cv_have_decl_KERN_CORE_PATTERN" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "query.attach_type" "ac_cv_member_union_bpf_attr_query_attach_type" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_query_attach_type" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_CORE_PATTERN" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_QUERY_ATTACH_TYPE 1
+#define HAVE_DECL_KERN_CORE_PATTERN $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_PANIC_ON_OOPS" "ac_cv_have_decl_KERN_PANIC_ON_OOPS" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "query.prog_cnt" "ac_cv_member_union_bpf_attr_query_prog_cnt" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_query_prog_cnt" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_PANIC_ON_OOPS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_QUERY_PROG_CNT 1
+#define HAVE_DECL_KERN_PANIC_ON_OOPS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_HPPA_PWRSW" "ac_cv_have_decl_KERN_HPPA_PWRSW" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "query.prog_ids" "ac_cv_member_union_bpf_attr_query_prog_ids" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_query_prog_ids" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_HPPA_PWRSW" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_QUERY_PROG_IDS 1
+#define HAVE_DECL_KERN_HPPA_PWRSW $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_HPPA_UNALIGNED" "ac_cv_have_decl_KERN_HPPA_UNALIGNED" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "query.query_flags" "ac_cv_member_union_bpf_attr_query_query_flags" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_query_query_flags" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_HPPA_UNALIGNED" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_QUERY_QUERY_FLAGS 1
+#define HAVE_DECL_KERN_HPPA_UNALIGNED $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_PRINTK_RATELIMIT" "ac_cv_have_decl_KERN_PRINTK_RATELIMIT" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "query.target_fd" "ac_cv_member_union_bpf_attr_query_target_fd" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_query_target_fd" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_PRINTK_RATELIMIT" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_QUERY_TARGET_FD 1
+#define HAVE_DECL_KERN_PRINTK_RATELIMIT $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_PRINTK_RATELIMIT_BURST" "ac_cv_have_decl_KERN_PRINTK_RATELIMIT_BURST" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "raw_tracepoint.name" "ac_cv_member_union_bpf_attr_raw_tracepoint_name" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_raw_tracepoint_name" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_PRINTK_RATELIMIT_BURST" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_RAW_TRACEPOINT_NAME 1
+#define HAVE_DECL_KERN_PRINTK_RATELIMIT_BURST $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_PTY" "ac_cv_have_decl_KERN_PTY" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "raw_tracepoint.prog_fd" "ac_cv_member_union_bpf_attr_raw_tracepoint_prog_fd" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_raw_tracepoint_prog_fd" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_PTY" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_RAW_TRACEPOINT_PROG_FD 1
+#define HAVE_DECL_KERN_PTY $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_NGROUPS_MAX" "ac_cv_have_decl_KERN_NGROUPS_MAX" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "start_id" "ac_cv_member_union_bpf_attr_start_id" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_start_id" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_NGROUPS_MAX" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_START_ID 1
+#define HAVE_DECL_KERN_NGROUPS_MAX $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_SPARC_SCONS_PWROFF" "ac_cv_have_decl_KERN_SPARC_SCONS_PWROFF" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "target_fd" "ac_cv_member_union_bpf_attr_target_fd" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_target_fd" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_SPARC_SCONS_PWROFF" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_TARGET_FD 1
+#define HAVE_DECL_KERN_SPARC_SCONS_PWROFF $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_HZ_TIMER" "ac_cv_have_decl_KERN_HZ_TIMER" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "task_fd_query.buf" "ac_cv_member_union_bpf_attr_task_fd_query_buf" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_task_fd_query_buf" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_HZ_TIMER" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_BUF 1
+#define HAVE_DECL_KERN_HZ_TIMER $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_UNKNOWN_NMI_PANIC" "ac_cv_have_decl_KERN_UNKNOWN_NMI_PANIC" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "task_fd_query.buf_len" "ac_cv_member_union_bpf_attr_task_fd_query_buf_len" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_task_fd_query_buf_len" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_UNKNOWN_NMI_PANIC" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_BUF_LEN 1
+#define HAVE_DECL_KERN_UNKNOWN_NMI_PANIC $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_BOOTLOADER_TYPE" "ac_cv_have_decl_KERN_BOOTLOADER_TYPE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "task_fd_query.fd" "ac_cv_member_union_bpf_attr_task_fd_query_fd" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_task_fd_query_fd" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_BOOTLOADER_TYPE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_FD 1
+#define HAVE_DECL_KERN_BOOTLOADER_TYPE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_RANDOMIZE" "ac_cv_have_decl_KERN_RANDOMIZE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "task_fd_query.fd_type" "ac_cv_member_union_bpf_attr_task_fd_query_fd_type" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_task_fd_query_fd_type" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_RANDOMIZE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_FD_TYPE 1
+#define HAVE_DECL_KERN_RANDOMIZE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_SETUID_DUMPABLE" "ac_cv_have_decl_KERN_SETUID_DUMPABLE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "task_fd_query.flags" "ac_cv_member_union_bpf_attr_task_fd_query_flags" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_task_fd_query_flags" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_SETUID_DUMPABLE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_FLAGS 1
+#define HAVE_DECL_KERN_SETUID_DUMPABLE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_SPIN_RETRY" "ac_cv_have_decl_KERN_SPIN_RETRY" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
+"
+if test "x$ac_cv_have_decl_KERN_SPIN_RETRY" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "task_fd_query.pid" "ac_cv_member_union_bpf_attr_task_fd_query_pid" "#include <linux/bpf.h>
-"
-if test "x$ac_cv_member_union_bpf_attr_task_fd_query_pid" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_PID 1
+#define HAVE_DECL_KERN_SPIN_RETRY $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_ACPI_VIDEO_FLAGS" "ac_cv_have_decl_KERN_ACPI_VIDEO_FLAGS" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "task_fd_query.probe_addr" "ac_cv_member_union_bpf_attr_task_fd_query_probe_addr" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_task_fd_query_probe_addr" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_ACPI_VIDEO_FLAGS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_PROBE_ADDR 1
+#define HAVE_DECL_KERN_ACPI_VIDEO_FLAGS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_IA64_UNALIGNED" "ac_cv_have_decl_KERN_IA64_UNALIGNED" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "task_fd_query.probe_offset" "ac_cv_member_union_bpf_attr_task_fd_query_probe_offset" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_task_fd_query_probe_offset" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_IA64_UNALIGNED" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_PROBE_OFFSET 1
+#define HAVE_DECL_KERN_IA64_UNALIGNED $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_COMPAT_LOG" "ac_cv_have_decl_KERN_COMPAT_LOG" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "task_fd_query.prog_id" "ac_cv_member_union_bpf_attr_task_fd_query_prog_id" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_task_fd_query_prog_id" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_COMPAT_LOG" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_TASK_FD_QUERY_PROG_ID 1
+#define HAVE_DECL_KERN_COMPAT_LOG $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_MAX_LOCK_DEPTH" "ac_cv_have_decl_KERN_MAX_LOCK_DEPTH" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "test.ctx_in" "ac_cv_member_union_bpf_attr_test_ctx_in" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_test_ctx_in" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_MAX_LOCK_DEPTH" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_TEST_CTX_IN 1
+#define HAVE_DECL_KERN_MAX_LOCK_DEPTH $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_NMI_WATCHDOG" "ac_cv_have_decl_KERN_NMI_WATCHDOG" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "test.ctx_out" "ac_cv_member_union_bpf_attr_test_ctx_out" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_test_ctx_out" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_NMI_WATCHDOG" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_TEST_CTX_OUT 1
+#define HAVE_DECL_KERN_NMI_WATCHDOG $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_PANIC_ON_NMI" "ac_cv_have_decl_KERN_PANIC_ON_NMI" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "test.ctx_size_in" "ac_cv_member_union_bpf_attr_test_ctx_size_in" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_test_ctx_size_in" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_PANIC_ON_NMI" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_TEST_CTX_SIZE_IN 1
+#define HAVE_DECL_KERN_PANIC_ON_NMI $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_PANIC_ON_WARN" "ac_cv_have_decl_KERN_PANIC_ON_WARN" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "test.ctx_size_out" "ac_cv_member_union_bpf_attr_test_ctx_size_out" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_test_ctx_size_out" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_PANIC_ON_WARN" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_TEST_CTX_SIZE_OUT 1
+#define HAVE_DECL_KERN_PANIC_ON_WARN $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "KERN_PANIC_PRINT" "ac_cv_have_decl_KERN_PANIC_PRINT" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "test.data_in" "ac_cv_member_union_bpf_attr_test_data_in" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_test_data_in" = xyes; then :
+if test "x$ac_cv_have_decl_KERN_PANIC_PRINT" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_TEST_DATA_IN 1
+#define HAVE_DECL_KERN_PANIC_PRINT $ac_have_decl
 _ACEOF
 
 
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "test.data_out" "ac_cv_member_union_bpf_attr_test_data_out" "#include <linux/bpf.h>
+ac_fn_c_check_decl "$LINENO" "NET_CORE" "ac_cv_have_decl_NET_CORE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_member_union_bpf_attr_test_data_out" = xyes; then :
+if test "x$ac_cv_have_decl_NET_CORE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_TEST_DATA_OUT 1
+#define HAVE_DECL_NET_CORE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_ETHER" "ac_cv_have_decl_NET_ETHER" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "test.data_size_in" "ac_cv_member_union_bpf_attr_test_data_size_in" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_test_data_size_in" = xyes; then :
+if test "x$ac_cv_have_decl_NET_ETHER" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_TEST_DATA_SIZE_IN 1
+#define HAVE_DECL_NET_ETHER $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_802" "ac_cv_have_decl_NET_802" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "test.data_size_out" "ac_cv_member_union_bpf_attr_test_data_size_out" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_test_data_size_out" = xyes; then :
+if test "x$ac_cv_have_decl_NET_802" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_TEST_DATA_SIZE_OUT 1
+#define HAVE_DECL_NET_802 $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_UNIX" "ac_cv_have_decl_NET_UNIX" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "test.duration" "ac_cv_member_union_bpf_attr_test_duration" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_test_duration" = xyes; then :
+if test "x$ac_cv_have_decl_NET_UNIX" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_TEST_DURATION 1
+#define HAVE_DECL_NET_UNIX $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4" "ac_cv_have_decl_NET_IPV4" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "test.prog_fd" "ac_cv_member_union_bpf_attr_test_prog_fd" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_test_prog_fd" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_TEST_PROG_FD 1
+#define HAVE_DECL_NET_IPV4 $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPX" "ac_cv_have_decl_NET_IPX" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "test.repeat" "ac_cv_member_union_bpf_attr_test_repeat" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_test_repeat" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPX" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_TEST_REPEAT 1
+#define HAVE_DECL_NET_IPX $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_ATALK" "ac_cv_have_decl_NET_ATALK" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "test.retval" "ac_cv_member_union_bpf_attr_test_retval" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_test_retval" = xyes; then :
+if test "x$ac_cv_have_decl_NET_ATALK" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_TEST_RETVAL 1
+#define HAVE_DECL_NET_ATALK $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_NETROM" "ac_cv_have_decl_NET_NETROM" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "value" "ac_cv_member_union_bpf_attr_value" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_value" = xyes; then :
+if test "x$ac_cv_have_decl_NET_NETROM" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_VALUE 1
+#define HAVE_DECL_NET_NETROM $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_AX25" "ac_cv_have_decl_NET_AX25" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "value_size" "ac_cv_member_union_bpf_attr_value_size" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_value_size" = xyes; then :
+if test "x$ac_cv_have_decl_NET_AX25" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_VALUE_SIZE 1
+#define HAVE_DECL_NET_AX25 $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_BRIDGE" "ac_cv_have_decl_NET_BRIDGE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "union bpf_attr" "dummy" "ac_cv_member_union_bpf_attr_dummy" "#include <linux/bpf.h>
 "
-if test "x$ac_cv_member_union_bpf_attr_dummy" = xyes; then :
+if test "x$ac_cv_have_decl_NET_BRIDGE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_UNION_BPF_ATTR_DUMMY 1
+#define HAVE_DECL_NET_BRIDGE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_ROSE" "ac_cv_have_decl_NET_ROSE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
-
-
+"
+if test "x$ac_cv_have_decl_NET_ROSE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
-done
-
-
-for ac_header in linux/io_uring.h
-do :
-  ac_fn_c_check_header_mongrel "$LINENO" "linux/io_uring.h" "ac_cv_header_linux_io_uring_h" "$ac_includes_default"
-if test "x$ac_cv_header_linux_io_uring_h" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_LINUX_IO_URING_H 1
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_ROSE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV6" "ac_cv_have_decl_NET_IPV6" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-	ac_fn_c_check_member "$LINENO" "struct io_uring_params" "features" "ac_cv_member_struct_io_uring_params_features" "#include <linux/io_uring.h>
 "
-if test "x$ac_cv_member_struct_io_uring_params_features" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV6" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_IO_URING_PARAMS_FEATURES 1
+#define HAVE_DECL_NET_IPV6 $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_X25" "ac_cv_have_decl_NET_X25" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
+"
+if test "x$ac_cv_have_decl_NET_X25" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
-ac_fn_c_check_member "$LINENO" "struct io_uring_params" "wq_fd" "ac_cv_member_struct_io_uring_params_wq_fd" "#include <linux/io_uring.h>
-"
-if test "x$ac_cv_member_struct_io_uring_params_wq_fd" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_IO_URING_PARAMS_WQ_FD 1
+#define HAVE_DECL_NET_X25 $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TR" "ac_cv_have_decl_NET_TR" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct io_uring_params" "resv" "ac_cv_member_struct_io_uring_params_resv" "#include <linux/io_uring.h>
 "
-if test "x$ac_cv_member_struct_io_uring_params_resv" = xyes; then :
+if test "x$ac_cv_have_decl_NET_TR" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_IO_URING_PARAMS_RESV 1
+#define HAVE_DECL_NET_TR $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_DECNET" "ac_cv_have_decl_NET_DECNET" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
-
+"
+if test "x$ac_cv_have_decl_NET_DECNET" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
-done
-
-
-for ac_header in bluetooth/bluetooth.h
-do :
-  ac_fn_c_check_header_mongrel "$LINENO" "bluetooth/bluetooth.h" "ac_cv_header_bluetooth_bluetooth_h" "$ac_includes_default"
-if test "x$ac_cv_header_bluetooth_bluetooth_h" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_BLUETOOTH_BLUETOOTH_H 1
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_DECNET $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_ECONET" "ac_cv_have_decl_NET_ECONET" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-	ac_fn_c_check_member "$LINENO" "struct sockaddr_hci" "hci_channel" "ac_cv_member_struct_sockaddr_hci_hci_channel" "#include <bluetooth/bluetooth.h>
-			 #include <bluetooth/hci.h>
 "
-if test "x$ac_cv_member_struct_sockaddr_hci_hci_channel" = xyes; then :
+if test "x$ac_cv_have_decl_NET_ECONET" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_SOCKADDR_HCI_HCI_CHANNEL 1
+#define HAVE_DECL_NET_ECONET $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_SCTP" "ac_cv_have_decl_NET_SCTP" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
-	ac_fn_c_check_member "$LINENO" "struct sockaddr_l2" "l2_bdaddr_type" "ac_cv_member_struct_sockaddr_l2_l2_bdaddr_type" "#include <bluetooth/bluetooth.h>
-			 #include <bluetooth/l2cap.h>
 "
-if test "x$ac_cv_member_struct_sockaddr_l2_l2_bdaddr_type" = xyes; then :
+if test "x$ac_cv_have_decl_NET_SCTP" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_SOCKADDR_L2_L2_BDADDR_TYPE 1
+#define HAVE_DECL_NET_SCTP $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_LLC" "ac_cv_have_decl_NET_LLC" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
+"
+if test "x$ac_cv_have_decl_NET_LLC" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_LLC $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_NETFILTER" "ac_cv_have_decl_NET_NETFILTER" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
+"
+if test "x$ac_cv_have_decl_NET_NETFILTER" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
-done
-
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_NETFILTER $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_DCCP" "ac_cv_have_decl_NET_DCCP" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_member "$LINENO" "struct br_mdb_entry" "flags" "ac_cv_member_struct_br_mdb_entry_flags" "#include <linux/if_bridge.h>
 "
-if test "x$ac_cv_member_struct_br_mdb_entry_flags" = xyes; then :
+if test "x$ac_cv_have_decl_NET_DCCP" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BR_MDB_ENTRY_FLAGS 1
+#define HAVE_DECL_NET_DCCP $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IRDA" "ac_cv_have_decl_NET_IRDA" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct br_mdb_entry" "vid" "ac_cv_member_struct_br_mdb_entry_vid" "#include <linux/if_bridge.h>
 "
-if test "x$ac_cv_member_struct_br_mdb_entry_vid" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IRDA" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BR_MDB_ENTRY_VID 1
+#define HAVE_DECL_NET_IRDA $ac_have_decl
 _ACEOF
 
 
-fi
-
+ac_fn_c_check_decl "$LINENO" "NET_CORE_WMEM_MAX" "ac_cv_have_decl_NET_CORE_WMEM_MAX" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_type "$LINENO" "struct dcbmsg" "ac_cv_type_struct_dcbmsg" "#include <linux/dcbnl.h>
 "
-if test "x$ac_cv_type_struct_dcbmsg" = xyes; then :
+if test "x$ac_cv_have_decl_NET_CORE_WMEM_MAX" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_DCBMSG 1
+#define HAVE_DECL_NET_CORE_WMEM_MAX $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_CORE_RMEM_MAX" "ac_cv_have_decl_NET_CORE_RMEM_MAX" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
-ac_fn_c_check_type "$LINENO" "struct ifaddrlblmsg" "ac_cv_type_struct_ifaddrlblmsg" "#include <linux/if_addrlabel.h>
 "
-if test "x$ac_cv_type_struct_ifaddrlblmsg" = xyes; then :
+if test "x$ac_cv_have_decl_NET_CORE_RMEM_MAX" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_IFADDRLBLMSG 1
+#define HAVE_DECL_NET_CORE_RMEM_MAX $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_CORE_WMEM_DEFAULT" "ac_cv_have_decl_NET_CORE_WMEM_DEFAULT" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
-ac_fn_c_check_type "$LINENO" "struct netconfmsg" "ac_cv_type_struct_netconfmsg" "#include <linux/netconf.h>
 "
-if test "x$ac_cv_type_struct_netconfmsg" = xyes; then :
+if test "x$ac_cv_have_decl_NET_CORE_WMEM_DEFAULT" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_NETCONFMSG 1
+#define HAVE_DECL_NET_CORE_WMEM_DEFAULT $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_CORE_RMEM_DEFAULT" "ac_cv_have_decl_NET_CORE_RMEM_DEFAULT" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
+"
+if test "x$ac_cv_have_decl_NET_CORE_RMEM_DEFAULT" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_CORE_RMEM_DEFAULT $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_CORE_MAX_BACKLOG" "ac_cv_have_decl_NET_CORE_MAX_BACKLOG" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_type "$LINENO" "struct ifla_cacheinfo" "ac_cv_type_struct_ifla_cacheinfo" "#include <sys/socket.h>
-#include <linux/rtnetlink.h>
 "
-if test "x$ac_cv_type_struct_ifla_cacheinfo" = xyes; then :
+if test "x$ac_cv_have_decl_NET_CORE_MAX_BACKLOG" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_IFLA_CACHEINFO 1
+#define HAVE_DECL_NET_CORE_MAX_BACKLOG $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_CORE_FASTROUTE" "ac_cv_have_decl_NET_CORE_FASTROUTE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
+"
+if test "x$ac_cv_have_decl_NET_CORE_FASTROUTE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_CORE_FASTROUTE $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_CORE_MSG_COST" "ac_cv_have_decl_NET_CORE_MSG_COST" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_decl "$LINENO" "TCA_ACT_PAD" "ac_cv_have_decl_TCA_ACT_PAD" "#include <sys/socket.h>
-#include <linux/pkt_cls.h>
 "
-if test "x$ac_cv_have_decl_TCA_ACT_PAD" = xyes; then :
+if test "x$ac_cv_have_decl_NET_CORE_MSG_COST" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_TCA_ACT_PAD $ac_have_decl
+#define HAVE_DECL_NET_CORE_MSG_COST $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "TCA_ACT_COOKIE" "ac_cv_have_decl_TCA_ACT_COOKIE" "#include <sys/socket.h>
-#include <linux/pkt_cls.h>
+ac_fn_c_check_decl "$LINENO" "NET_CORE_MSG_BURST" "ac_cv_have_decl_NET_CORE_MSG_BURST" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_TCA_ACT_COOKIE" = xyes; then :
+if test "x$ac_cv_have_decl_NET_CORE_MSG_BURST" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_TCA_ACT_COOKIE $ac_have_decl
+#define HAVE_DECL_NET_CORE_MSG_BURST $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "TCA_ACT_FLAGS" "ac_cv_have_decl_TCA_ACT_FLAGS" "#include <sys/socket.h>
-#include <linux/pkt_cls.h>
+ac_fn_c_check_decl "$LINENO" "NET_CORE_OPTMEM_MAX" "ac_cv_have_decl_NET_CORE_OPTMEM_MAX" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_TCA_ACT_FLAGS" = xyes; then :
+if test "x$ac_cv_have_decl_NET_CORE_OPTMEM_MAX" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_TCA_ACT_FLAGS $ac_have_decl
+#define HAVE_DECL_NET_CORE_OPTMEM_MAX $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_CORE_HOT_LIST_LENGTH" "ac_cv_have_decl_NET_CORE_HOT_LIST_LENGTH" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_decl "$LINENO" "IFLA_PORT_SELF" "ac_cv_have_decl_IFLA_PORT_SELF" "#include <sys/socket.h>
-#include <linux/rtnetlink.h>
 "
-if test "x$ac_cv_have_decl_IFLA_PORT_SELF" = xyes; then :
+if test "x$ac_cv_have_decl_NET_CORE_HOT_LIST_LENGTH" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_IFLA_PORT_SELF $ac_have_decl
+#define HAVE_DECL_NET_CORE_HOT_LIST_LENGTH $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "IFLA_PROTINFO" "ac_cv_have_decl_IFLA_PROTINFO" "#include <sys/socket.h>
-#include <linux/rtnetlink.h>
+ac_fn_c_check_decl "$LINENO" "NET_CORE_DIVERT_VERSION" "ac_cv_have_decl_NET_CORE_DIVERT_VERSION" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_IFLA_PROTINFO" = xyes; then :
+if test "x$ac_cv_have_decl_NET_CORE_DIVERT_VERSION" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_IFLA_PROTINFO $ac_have_decl
+#define HAVE_DECL_NET_CORE_DIVERT_VERSION $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "IFLA_AF_SPEC" "ac_cv_have_decl_IFLA_AF_SPEC" "#include <sys/socket.h>
-#include <linux/rtnetlink.h>
+ac_fn_c_check_decl "$LINENO" "NET_CORE_NO_CONG_THRESH" "ac_cv_have_decl_NET_CORE_NO_CONG_THRESH" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_IFLA_AF_SPEC" = xyes; then :
+if test "x$ac_cv_have_decl_NET_CORE_NO_CONG_THRESH" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_IFLA_AF_SPEC $ac_have_decl
+#define HAVE_DECL_NET_CORE_NO_CONG_THRESH $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "IFLA_XDP" "ac_cv_have_decl_IFLA_XDP" "#include <sys/socket.h>
-#include <linux/rtnetlink.h>
+ac_fn_c_check_decl "$LINENO" "NET_CORE_NO_CONG" "ac_cv_have_decl_NET_CORE_NO_CONG" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_IFLA_XDP" = xyes; then :
+if test "x$ac_cv_have_decl_NET_CORE_NO_CONG" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_IFLA_XDP $ac_have_decl
+#define HAVE_DECL_NET_CORE_NO_CONG $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_CORE_LO_CONG" "ac_cv_have_decl_NET_CORE_LO_CONG" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-ac_fn_c_check_type "$LINENO" "struct gnet_stats_basic" "ac_cv_type_struct_gnet_stats_basic" "#include <linux/gen_stats.h>
 "
-if test "x$ac_cv_type_struct_gnet_stats_basic" = xyes; then :
+if test "x$ac_cv_have_decl_NET_CORE_LO_CONG" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_GNET_STATS_BASIC 1
+#define HAVE_DECL_NET_CORE_LO_CONG $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_CORE_MOD_CONG" "ac_cv_have_decl_NET_CORE_MOD_CONG" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_type "$LINENO" "struct gnet_stats_queue" "ac_cv_type_struct_gnet_stats_queue" "#include <linux/gen_stats.h>
 "
-if test "x$ac_cv_type_struct_gnet_stats_queue" = xyes; then :
+if test "x$ac_cv_have_decl_NET_CORE_MOD_CONG" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_GNET_STATS_QUEUE 1
+#define HAVE_DECL_NET_CORE_MOD_CONG $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_CORE_DEV_WEIGHT" "ac_cv_have_decl_NET_CORE_DEV_WEIGHT" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_type "$LINENO" "struct gnet_stats_rate_est" "ac_cv_type_struct_gnet_stats_rate_est" "#include <linux/gen_stats.h>
 "
-if test "x$ac_cv_type_struct_gnet_stats_rate_est" = xyes; then :
+if test "x$ac_cv_have_decl_NET_CORE_DEV_WEIGHT" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_GNET_STATS_RATE_EST 1
+#define HAVE_DECL_NET_CORE_DEV_WEIGHT $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_CORE_SOMAXCONN" "ac_cv_have_decl_NET_CORE_SOMAXCONN" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_type "$LINENO" "struct gnet_stats_rate_est64" "ac_cv_type_struct_gnet_stats_rate_est64" "#include <linux/gen_stats.h>
 "
-if test "x$ac_cv_type_struct_gnet_stats_rate_est64" = xyes; then :
+if test "x$ac_cv_have_decl_NET_CORE_SOMAXCONN" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_GNET_STATS_RATE_EST64 1
+#define HAVE_DECL_NET_CORE_SOMAXCONN $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_CORE_DESTROY_DELAY" "ac_cv_have_decl_NET_CORE_DESTROY_DELAY" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
-ac_fn_c_check_decl "$LINENO" "TCA_STATS_PKT64" "ac_cv_have_decl_TCA_STATS_PKT64" "#include <linux/gen_stats.h>
 "
-if test "x$ac_cv_have_decl_TCA_STATS_PKT64" = xyes; then :
+if test "x$ac_cv_have_decl_NET_CORE_DESTROY_DELAY" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_TCA_STATS_PKT64 $ac_have_decl
+#define HAVE_DECL_NET_CORE_DESTROY_DELAY $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_CORE_BUDGET" "ac_cv_have_decl_NET_CORE_BUDGET" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-ac_fn_c_check_type "$LINENO" "struct tc_sizespec" "ac_cv_type_struct_tc_sizespec" "#include <linux/types.h>
-#include <linux/pkt_sched.h>
 "
-if test "x$ac_cv_type_struct_tc_sizespec" = xyes; then :
+if test "x$ac_cv_have_decl_NET_CORE_BUDGET" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_TC_SIZESPEC 1
+#define HAVE_DECL_NET_CORE_BUDGET $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_CORE_AEVENT_ETIME" "ac_cv_have_decl_NET_CORE_AEVENT_ETIME" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
-ac_fn_c_check_decl "$LINENO" "TCA_STAB_DATA" "ac_cv_have_decl_TCA_STAB_DATA" "#include <linux/types.h>
-#include <linux/pkt_sched.h>
 "
-if test "x$ac_cv_have_decl_TCA_STAB_DATA" = xyes; then :
+if test "x$ac_cv_have_decl_NET_CORE_AEVENT_ETIME" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_TCA_STAB_DATA $ac_have_decl
+#define HAVE_DECL_NET_CORE_AEVENT_ETIME $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_CORE_AEVENT_RSEQTH" "ac_cv_have_decl_NET_CORE_AEVENT_RSEQTH" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-ac_fn_c_check_type "$LINENO" "struct fib_rule_uid_range" "ac_cv_type_struct_fib_rule_uid_range" "#include <linux/fib_rules.h>
 "
-if test "x$ac_cv_type_struct_fib_rule_uid_range" = xyes; then :
+if test "x$ac_cv_have_decl_NET_CORE_AEVENT_RSEQTH" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_FIB_RULE_UID_RANGE 1
+#define HAVE_DECL_NET_CORE_AEVENT_RSEQTH $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_CORE_WARNINGS" "ac_cv_have_decl_NET_CORE_WARNINGS" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_type "$LINENO" "struct fib_rule_port_range" "ac_cv_type_struct_fib_rule_port_range" "#include <linux/fib_rules.h>
 "
-if test "x$ac_cv_type_struct_fib_rule_port_range" = xyes; then :
+if test "x$ac_cv_have_decl_NET_CORE_WARNINGS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_FIB_RULE_PORT_RANGE 1
+#define HAVE_DECL_NET_CORE_WARNINGS $ac_have_decl
 _ACEOF
 
 
-fi
-
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_FORWARD" "ac_cv_have_decl_NET_IPV4_FORWARD" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_type "$LINENO" "struct statfs" "ac_cv_type_struct_statfs" "#include <linux/types.h>
-#include <asm/statfs.h>
 "
-if test "x$ac_cv_type_struct_statfs" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_FORWARD" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_STATFS 1
+#define HAVE_DECL_NET_IPV4_FORWARD $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_DYNADDR" "ac_cv_have_decl_NET_IPV4_DYNADDR" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-	ac_fn_c_check_member "$LINENO" "struct statfs" "f_frsize" "ac_cv_member_struct_statfs_f_frsize" "#include <linux/types.h>
-#include <asm/statfs.h>
 "
-if test "x$ac_cv_member_struct_statfs_f_frsize" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_DYNADDR" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_STATFS_F_FRSIZE 1
+#define HAVE_DECL_NET_IPV4_DYNADDR $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF" "ac_cv_have_decl_NET_IPV4_CONF" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct statfs" "f_flags" "ac_cv_member_struct_statfs_f_flags" "#include <linux/types.h>
-#include <asm/statfs.h>
 "
-if test "x$ac_cv_member_struct_statfs_f_flags" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_CONF" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_STATFS_F_FLAGS 1
+#define HAVE_DECL_NET_IPV4_CONF $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_NEIGH" "ac_cv_have_decl_NET_IPV4_NEIGH" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct statfs" "f_fsid.val" "ac_cv_member_struct_statfs_f_fsid_val" "#include <linux/types.h>
-#include <asm/statfs.h>
 "
-if test "x$ac_cv_member_struct_statfs_f_fsid_val" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_NEIGH" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_STATFS_F_FSID_VAL 1
+#define HAVE_DECL_NET_IPV4_NEIGH $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ROUTE" "ac_cv_have_decl_NET_IPV4_ROUTE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct statfs" "f_fsid.__val" "ac_cv_member_struct_statfs_f_fsid___val" "#include <linux/types.h>
-#include <asm/statfs.h>
 "
-if test "x$ac_cv_member_struct_statfs_f_fsid___val" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_ROUTE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_STATFS_F_FSID___VAL 1
+#define HAVE_DECL_NET_IPV4_ROUTE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_FIB_HASH" "ac_cv_have_decl_NET_IPV4_FIB_HASH" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
-
-fi
-
-
-ac_fn_c_check_type "$LINENO" "struct statfs64" "ac_cv_type_struct_statfs64" "#include <linux/types.h>
-#include <asm/statfs.h>
 "
-if test "x$ac_cv_type_struct_statfs64" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_FIB_HASH" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_STATFS64 1
+#define HAVE_DECL_NET_IPV4_FIB_HASH $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_NETFILTER" "ac_cv_have_decl_NET_IPV4_NETFILTER" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-	ac_fn_c_check_member "$LINENO" "struct statfs64" "f_frsize" "ac_cv_member_struct_statfs64_f_frsize" "#include <linux/types.h>
-#include <asm/statfs.h>
 "
-if test "x$ac_cv_member_struct_statfs64_f_frsize" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_NETFILTER" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_STATFS64_F_FRSIZE 1
+#define HAVE_DECL_NET_IPV4_NETFILTER $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_TCP_TIMESTAMPS" "ac_cv_have_decl_NET_IPV4_TCP_TIMESTAMPS" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct statfs64" "f_flags" "ac_cv_member_struct_statfs64_f_flags" "#include <linux/types.h>
-#include <asm/statfs.h>
 "
-if test "x$ac_cv_member_struct_statfs64_f_flags" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_TCP_TIMESTAMPS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_STATFS64_F_FLAGS 1
+#define HAVE_DECL_NET_IPV4_TCP_TIMESTAMPS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_TCP_WINDOW_SCALING" "ac_cv_have_decl_NET_IPV4_TCP_WINDOW_SCALING" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct statfs64" "f_fsid.val" "ac_cv_member_struct_statfs64_f_fsid_val" "#include <linux/types.h>
-#include <asm/statfs.h>
 "
-if test "x$ac_cv_member_struct_statfs64_f_fsid_val" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_TCP_WINDOW_SCALING" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_STATFS64_F_FSID_VAL 1
+#define HAVE_DECL_NET_IPV4_TCP_WINDOW_SCALING $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_TCP_SACK" "ac_cv_have_decl_NET_IPV4_TCP_SACK" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct statfs64" "f_fsid.__val" "ac_cv_member_struct_statfs64_f_fsid___val" "#include <linux/types.h>
-#include <asm/statfs.h>
 "
-if test "x$ac_cv_member_struct_statfs64_f_fsid___val" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_TCP_SACK" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_STATFS64_F_FSID___VAL 1
+#define HAVE_DECL_NET_IPV4_TCP_SACK $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_TCP_RETRANS_COLLAPSE" "ac_cv_have_decl_NET_IPV4_TCP_RETRANS_COLLAPSE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
-
-fi
-
-
-ac_fn_c_check_type "$LINENO" "struct statx" "ac_cv_type_struct_statx" "#include <linux/types.h>
-#include <linux/stat.h>
 "
-if test "x$ac_cv_type_struct_statx" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_TCP_RETRANS_COLLAPSE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_STATX 1
+#define HAVE_DECL_NET_IPV4_TCP_RETRANS_COLLAPSE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_DEFAULT_TTL" "ac_cv_have_decl_NET_IPV4_DEFAULT_TTL" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
-
-ac_fn_c_check_type "$LINENO" "struct blk_user_trace_setup" "ac_cv_type_struct_blk_user_trace_setup" "#include <linux/blktrace_api.h>
 "
-if test "x$ac_cv_type_struct_blk_user_trace_setup" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_DEFAULT_TTL" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BLK_USER_TRACE_SETUP 1
+#define HAVE_DECL_NET_IPV4_DEFAULT_TTL $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_AUTOCONFIG" "ac_cv_have_decl_NET_IPV4_AUTOCONFIG" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
-
-ac_fn_c_check_type "$LINENO" "struct mtd_write_req" "ac_cv_type_struct_mtd_write_req" "#include <mtd/mtd-abi.h>
 "
-if test "x$ac_cv_type_struct_mtd_write_req" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_AUTOCONFIG" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_MTD_WRITE_REQ 1
+#define HAVE_DECL_NET_IPV4_AUTOCONFIG $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_NO_PMTU_DISC" "ac_cv_have_decl_NET_IPV4_NO_PMTU_DISC" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
-
-ac_fn_c_check_member "$LINENO" "struct ubi_attach_req" "max_beb_per1024" "ac_cv_member_struct_ubi_attach_req_max_beb_per1024" "#include <mtd/ubi-user.h>
 "
-if test "x$ac_cv_member_struct_ubi_attach_req_max_beb_per1024" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_NO_PMTU_DISC" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_UBI_ATTACH_REQ_MAX_BEB_PER1024 1
+#define HAVE_DECL_NET_IPV4_NO_PMTU_DISC $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_TCP_SYN_RETRIES" "ac_cv_have_decl_NET_IPV4_TCP_SYN_RETRIES" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
+"
+if test "x$ac_cv_have_decl_NET_IPV4_TCP_SYN_RETRIES" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_IPV4_TCP_SYN_RETRIES $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_IPFRAG_HIGH_THRESH" "ac_cv_have_decl_NET_IPV4_IPFRAG_HIGH_THRESH" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_type "$LINENO" "struct ptp_sys_offset" "ac_cv_type_struct_ptp_sys_offset" "#include <linux/ptp_clock.h>
 "
-if test "x$ac_cv_type_struct_ptp_sys_offset" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_IPFRAG_HIGH_THRESH" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_PTP_SYS_OFFSET 1
+#define HAVE_DECL_NET_IPV4_IPFRAG_HIGH_THRESH $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_IPFRAG_LOW_THRESH" "ac_cv_have_decl_NET_IPV4_IPFRAG_LOW_THRESH" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
+"
+if test "x$ac_cv_have_decl_NET_IPV4_IPFRAG_LOW_THRESH" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_IPV4_IPFRAG_LOW_THRESH $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_IPFRAG_TIME" "ac_cv_have_decl_NET_IPV4_IPFRAG_TIME" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_type "$LINENO" "struct kvm_cpuid2" "ac_cv_type_struct_kvm_cpuid2" "#include <linux/kvm.h>
 "
-if test "x$ac_cv_type_struct_kvm_cpuid2" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_IPFRAG_TIME" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_KVM_CPUID2 1
+#define HAVE_DECL_NET_IPV4_IPFRAG_TIME $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_TCP_MAX_KA_PROBES" "ac_cv_have_decl_NET_IPV4_TCP_MAX_KA_PROBES" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_type "$LINENO" "struct kvm_regs" "ac_cv_type_struct_kvm_regs" "#include <linux/kvm.h>
 "
-if test "x$ac_cv_type_struct_kvm_regs" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_TCP_MAX_KA_PROBES" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_KVM_REGS 1
+#define HAVE_DECL_NET_IPV4_TCP_MAX_KA_PROBES $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_TCP_KEEPALIVE_TIME" "ac_cv_have_decl_NET_IPV4_TCP_KEEPALIVE_TIME" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_type "$LINENO" "struct kvm_sregs" "ac_cv_type_struct_kvm_sregs" "#include <linux/kvm.h>
 "
-if test "x$ac_cv_type_struct_kvm_sregs" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_TCP_KEEPALIVE_TIME" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_KVM_SREGS 1
+#define HAVE_DECL_NET_IPV4_TCP_KEEPALIVE_TIME $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_TCP_KEEPALIVE_PROBES" "ac_cv_have_decl_NET_IPV4_TCP_KEEPALIVE_PROBES" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_type "$LINENO" "struct kvm_userspace_memory_region" "ac_cv_type_struct_kvm_userspace_memory_region" "#include <linux/kvm.h>
 "
-if test "x$ac_cv_type_struct_kvm_userspace_memory_region" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_TCP_KEEPALIVE_PROBES" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_KVM_USERSPACE_MEMORY_REGION 1
+#define HAVE_DECL_NET_IPV4_TCP_KEEPALIVE_PROBES $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_TCP_RETRIES1" "ac_cv_have_decl_NET_IPV4_TCP_RETRIES1" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
+"
+if test "x$ac_cv_have_decl_NET_IPV4_TCP_RETRIES1" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_IPV4_TCP_RETRIES1 $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_TCP_RETRIES2" "ac_cv_have_decl_NET_IPV4_TCP_RETRIES2" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-saved_CPPFLAGS="$CPPFLAGS"
-
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking whether <linux/signal.h> can be used along with <signal.h>" >&5
-$as_echo_n "checking whether <linux/signal.h> can be used along with <signal.h>... " >&6; }
-if ${st_cv_linux_signal+:} false; then :
-  $as_echo_n "(cached) " >&6
+"
+if test "x$ac_cv_have_decl_NET_IPV4_TCP_RETRIES2" = xyes; then :
+  ac_have_decl=1
 else
-  cat confdefs.h - <<_ACEOF >conftest.$ac_ext
-/* end confdefs.h.  */
+  ac_have_decl=0
+fi
 
-#include <signal.h>
-#include <linux/signal.h>
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_IPV4_TCP_RETRIES2 $ac_have_decl
 _ACEOF
-if ac_fn_c_try_compile "$LINENO"; then :
-  st_cv_linux_signal=yes
-else
-  st_cv_linux_signal=no
-fi
-rm -f core conftest.err conftest.$ac_objext conftest.$ac_ext
-fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $st_cv_linux_signal" >&5
-$as_echo "$st_cv_linux_signal" >&6; }
-if test "x$st_cv_linux_signal" = xno; then
-	mkdir -p linux/linux
-	cp $srcdir/linux/signal.h.in linux/linux/signal.h
-	CPPFLAGS="$CPPFLAGS -Ilinux"
-fi
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_TCP_FIN_TIMEOUT" "ac_cv_have_decl_NET_IPV4_TCP_FIN_TIMEOUT" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_type "$LINENO" "struct __aio_sigset" "ac_cv_type_struct___aio_sigset" "#include <linux/aio_abi.h>
 "
-if test "x$ac_cv_type_struct___aio_sigset" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_TCP_FIN_TIMEOUT" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT___AIO_SIGSET 1
+#define HAVE_DECL_NET_IPV4_TCP_FIN_TIMEOUT $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_IP_MASQ_DEBUG" "ac_cv_have_decl_NET_IPV4_IP_MASQ_DEBUG" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
+"
+if test "x$ac_cv_have_decl_NET_IPV4_IP_MASQ_DEBUG" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_IPV4_IP_MASQ_DEBUG $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_SYNCOOKIES" "ac_cv_have_decl_NET_TCP_SYNCOOKIES" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_member "$LINENO" "struct iocb" "aio_flags" "ac_cv_member_struct_iocb_aio_flags" "#include <linux/aio_abi.h>
 "
-if test "x$ac_cv_member_struct_iocb_aio_flags" = xyes; then :
+if test "x$ac_cv_have_decl_NET_TCP_SYNCOOKIES" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_IOCB_AIO_FLAGS 1
+#define HAVE_DECL_NET_TCP_SYNCOOKIES $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_STDURG" "ac_cv_have_decl_NET_TCP_STDURG" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct iocb" "aio_rw_flags" "ac_cv_member_struct_iocb_aio_rw_flags" "#include <linux/aio_abi.h>
 "
-if test "x$ac_cv_member_struct_iocb_aio_rw_flags" = xyes; then :
+if test "x$ac_cv_have_decl_NET_TCP_STDURG" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_IOCB_AIO_RW_FLAGS 1
+#define HAVE_DECL_NET_TCP_STDURG $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_RFC1337" "ac_cv_have_decl_NET_TCP_RFC1337" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
+"
+if test "x$ac_cv_have_decl_NET_TCP_RFC1337" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_TCP_RFC1337 $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_SYN_TAILDROP" "ac_cv_have_decl_NET_TCP_SYN_TAILDROP" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_member "$LINENO" "struct clone_args" "set_tid_size" "ac_cv_member_struct_clone_args_set_tid_size" "#include <linux/sched.h>
 "
-if test "x$ac_cv_member_struct_clone_args_set_tid_size" = xyes; then :
+if test "x$ac_cv_have_decl_NET_TCP_SYN_TAILDROP" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_CLONE_ARGS_SET_TID_SIZE 1
+#define HAVE_DECL_NET_TCP_SYN_TAILDROP $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_MAX_SYN_BACKLOG" "ac_cv_have_decl_NET_TCP_MAX_SYN_BACKLOG" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
+"
+if test "x$ac_cv_have_decl_NET_TCP_MAX_SYN_BACKLOG" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
-
-CPPFLAGS="$saved_CPPFLAGS"
-
-for ac_header in linux/btrfs.h
-do :
-  ac_fn_c_check_header_mongrel "$LINENO" "linux/btrfs.h" "ac_cv_header_linux_btrfs_h" "$ac_includes_default"
-if test "x$ac_cv_header_linux_btrfs_h" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_LINUX_BTRFS_H 1
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_TCP_MAX_SYN_BACKLOG $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_LOCAL_PORT_RANGE" "ac_cv_have_decl_NET_IPV4_LOCAL_PORT_RANGE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-	ac_fn_c_check_member "$LINENO" "struct btrfs_ioctl_feature_flags" "compat_flags" "ac_cv_member_struct_btrfs_ioctl_feature_flags_compat_flags" " #include <stdio.h>
-#include <linux/btrfs.h>
 "
-if test "x$ac_cv_member_struct_btrfs_ioctl_feature_flags_compat_flags" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_LOCAL_PORT_RANGE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BTRFS_IOCTL_FEATURE_FLAGS_COMPAT_FLAGS 1
+#define HAVE_DECL_NET_IPV4_LOCAL_PORT_RANGE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ICMP_ECHO_IGNORE_ALL" "ac_cv_have_decl_NET_IPV4_ICMP_ECHO_IGNORE_ALL" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct btrfs_ioctl_fs_info_args" "nodesize" "ac_cv_member_struct_btrfs_ioctl_fs_info_args_nodesize" " #include <stdio.h>
-#include <linux/btrfs.h>
 "
-if test "x$ac_cv_member_struct_btrfs_ioctl_fs_info_args_nodesize" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_ICMP_ECHO_IGNORE_ALL" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BTRFS_IOCTL_FS_INFO_ARGS_NODESIZE 1
+#define HAVE_DECL_NET_IPV4_ICMP_ECHO_IGNORE_ALL $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ICMP_ECHO_IGNORE_BROADCASTS" "ac_cv_have_decl_NET_IPV4_ICMP_ECHO_IGNORE_BROADCASTS" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct btrfs_ioctl_defrag_range_args" "start" "ac_cv_member_struct_btrfs_ioctl_defrag_range_args_start" " #include <stdio.h>
-#include <linux/btrfs.h>
 "
-if test "x$ac_cv_member_struct_btrfs_ioctl_defrag_range_args_start" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_ICMP_ECHO_IGNORE_BROADCASTS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BTRFS_IOCTL_DEFRAG_RANGE_ARGS_START 1
+#define HAVE_DECL_NET_IPV4_ICMP_ECHO_IGNORE_BROADCASTS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ICMP_SOURCEQUENCH_RATE" "ac_cv_have_decl_NET_IPV4_ICMP_SOURCEQUENCH_RATE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct btrfs_ioctl_search_args_v2" "buf_size" "ac_cv_member_struct_btrfs_ioctl_search_args_v2_buf_size" " #include <stdio.h>
-#include <linux/btrfs.h>
 "
-if test "x$ac_cv_member_struct_btrfs_ioctl_search_args_v2_buf_size" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_ICMP_SOURCEQUENCH_RATE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BTRFS_IOCTL_SEARCH_ARGS_V2_BUF_SIZE 1
+#define HAVE_DECL_NET_IPV4_ICMP_SOURCEQUENCH_RATE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ICMP_DESTUNREACH_RATE" "ac_cv_have_decl_NET_IPV4_ICMP_DESTUNREACH_RATE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-ac_fn_c_check_member "$LINENO" "struct btrfs_ioctl_logical_ino_args" "flags" "ac_cv_member_struct_btrfs_ioctl_logical_ino_args_flags" " #include <stdio.h>
-#include <linux/btrfs.h>
 "
-if test "x$ac_cv_member_struct_btrfs_ioctl_logical_ino_args_flags" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_ICMP_DESTUNREACH_RATE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BTRFS_IOCTL_LOGICAL_INO_ARGS_FLAGS 1
+#define HAVE_DECL_NET_IPV4_ICMP_DESTUNREACH_RATE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ICMP_TIMEEXCEED_RATE" "ac_cv_have_decl_NET_IPV4_ICMP_TIMEEXCEED_RATE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
-	ac_fn_c_check_decl "$LINENO" "BTRFS_COMPRESS_NONE" "ac_cv_have_decl_BTRFS_COMPRESS_NONE" " #include <stdio.h>
-#include <linux/btrfs.h>
 "
-if test "x$ac_cv_have_decl_BTRFS_COMPRESS_NONE" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_ICMP_TIMEEXCEED_RATE" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_BTRFS_COMPRESS_NONE $ac_have_decl
+#define HAVE_DECL_NET_IPV4_ICMP_TIMEEXCEED_RATE $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "BTRFS_COMPRESS_ZLIB" "ac_cv_have_decl_BTRFS_COMPRESS_ZLIB" " #include <stdio.h>
-#include <linux/btrfs.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ICMP_PARAMPROB_RATE" "ac_cv_have_decl_NET_IPV4_ICMP_PARAMPROB_RATE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_BTRFS_COMPRESS_ZLIB" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_ICMP_PARAMPROB_RATE" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_BTRFS_COMPRESS_ZLIB $ac_have_decl
+#define HAVE_DECL_NET_IPV4_ICMP_PARAMPROB_RATE $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "BTRFS_COMPRESS_LZO" "ac_cv_have_decl_BTRFS_COMPRESS_LZO" " #include <stdio.h>
-#include <linux/btrfs.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ICMP_ECHOREPLY_RATE" "ac_cv_have_decl_NET_IPV4_ICMP_ECHOREPLY_RATE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_BTRFS_COMPRESS_LZO" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_ICMP_ECHOREPLY_RATE" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_BTRFS_COMPRESS_LZO $ac_have_decl
+#define HAVE_DECL_NET_IPV4_ICMP_ECHOREPLY_RATE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ICMP_IGNORE_BOGUS_ERROR_RESPONSES" "ac_cv_have_decl_NET_IPV4_ICMP_IGNORE_BOGUS_ERROR_RESPONSES" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
+"
+if test "x$ac_cv_have_decl_NET_IPV4_ICMP_IGNORE_BOGUS_ERROR_RESPONSES" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
-done
-
-
-
-
-for ac_header in linux/cryptouser.h
-do :
-  ac_fn_c_check_header_mongrel "$LINENO" "linux/cryptouser.h" "ac_cv_header_linux_cryptouser_h" "$ac_includes_default"
-if test "x$ac_cv_header_linux_cryptouser_h" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_LINUX_CRYPTOUSER_H 1
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_IPV4_ICMP_IGNORE_BOGUS_ERROR_RESPONSES $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_IGMP_MAX_MEMBERSHIPS" "ac_cv_have_decl_NET_IPV4_IGMP_MAX_MEMBERSHIPS" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-ac_fn_c_check_type "$LINENO" "struct crypto_user_alg" "ac_cv_type_struct_crypto_user_alg" "$ac_includes_default
-#include <linux/cryptouser.h>
 "
-if test "x$ac_cv_type_struct_crypto_user_alg" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_IGMP_MAX_MEMBERSHIPS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_CRYPTO_USER_ALG 1
+#define HAVE_DECL_NET_IPV4_IGMP_MAX_MEMBERSHIPS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_TW_RECYCLE" "ac_cv_have_decl_NET_TCP_TW_RECYCLE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_member "$LINENO" "struct crypto_user_alg" "cru_flags" "ac_cv_member_struct_crypto_user_alg_cru_flags" "$ac_includes_default
-#include <linux/cryptouser.h>
 "
-if test "x$ac_cv_member_struct_crypto_user_alg_cru_flags" = xyes; then :
+if test "x$ac_cv_have_decl_NET_TCP_TW_RECYCLE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_CRYPTO_USER_ALG_CRU_FLAGS 1
+#define HAVE_DECL_NET_TCP_TW_RECYCLE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ALWAYS_DEFRAG" "ac_cv_have_decl_NET_IPV4_ALWAYS_DEFRAG" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
+"
+if test "x$ac_cv_have_decl_NET_IPV4_ALWAYS_DEFRAG" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_IPV4_ALWAYS_DEFRAG $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_TCP_KEEPALIVE_INTVL" "ac_cv_have_decl_NET_IPV4_TCP_KEEPALIVE_INTVL" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_type "$LINENO" "struct crypto_report_hash" "ac_cv_type_struct_crypto_report_hash" "$ac_includes_default
-#include <linux/cryptouser.h>
 "
-if test "x$ac_cv_type_struct_crypto_report_hash" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_TCP_KEEPALIVE_INTVL" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_CRYPTO_REPORT_HASH 1
+#define HAVE_DECL_NET_IPV4_TCP_KEEPALIVE_INTVL $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_INET_PEER_THRESHOLD" "ac_cv_have_decl_NET_IPV4_INET_PEER_THRESHOLD" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_member "$LINENO" "struct crypto_report_hash" "digestsize" "ac_cv_member_struct_crypto_report_hash_digestsize" "$ac_includes_default
-#include <linux/cryptouser.h>
 "
-if test "x$ac_cv_member_struct_crypto_report_hash_digestsize" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_INET_PEER_THRESHOLD" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_CRYPTO_REPORT_HASH_DIGESTSIZE 1
+#define HAVE_DECL_NET_IPV4_INET_PEER_THRESHOLD $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_INET_PEER_MINTTL" "ac_cv_have_decl_NET_IPV4_INET_PEER_MINTTL" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
+"
+if test "x$ac_cv_have_decl_NET_IPV4_INET_PEER_MINTTL" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_IPV4_INET_PEER_MINTTL $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_INET_PEER_MAXTTL" "ac_cv_have_decl_NET_IPV4_INET_PEER_MAXTTL" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_type "$LINENO" "struct crypto_report_cipher" "ac_cv_type_struct_crypto_report_cipher" "$ac_includes_default
-#include <linux/cryptouser.h>
 "
-if test "x$ac_cv_type_struct_crypto_report_cipher" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_INET_PEER_MAXTTL" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_CRYPTO_REPORT_CIPHER 1
+#define HAVE_DECL_NET_IPV4_INET_PEER_MAXTTL $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_INET_PEER_GC_MINTIME" "ac_cv_have_decl_NET_IPV4_INET_PEER_GC_MINTIME" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_member "$LINENO" "struct crypto_report_cipher" "max_keysize" "ac_cv_member_struct_crypto_report_cipher_max_keysize" "$ac_includes_default
-#include <linux/cryptouser.h>
 "
-if test "x$ac_cv_member_struct_crypto_report_cipher_max_keysize" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_INET_PEER_GC_MINTIME" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_CRYPTO_REPORT_CIPHER_MAX_KEYSIZE 1
+#define HAVE_DECL_NET_IPV4_INET_PEER_GC_MINTIME $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_INET_PEER_GC_MAXTIME" "ac_cv_have_decl_NET_IPV4_INET_PEER_GC_MAXTIME" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
+"
+if test "x$ac_cv_have_decl_NET_IPV4_INET_PEER_GC_MAXTIME" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_IPV4_INET_PEER_GC_MAXTIME $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_ORPHAN_RETRIES" "ac_cv_have_decl_NET_TCP_ORPHAN_RETRIES" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_type "$LINENO" "struct crypto_report_blkcipher" "ac_cv_type_struct_crypto_report_blkcipher" "$ac_includes_default
-#include <linux/cryptouser.h>
 "
-if test "x$ac_cv_type_struct_crypto_report_blkcipher" = xyes; then :
+if test "x$ac_cv_have_decl_NET_TCP_ORPHAN_RETRIES" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_CRYPTO_REPORT_BLKCIPHER 1
+#define HAVE_DECL_NET_TCP_ORPHAN_RETRIES $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_ABORT_ON_OVERFLOW" "ac_cv_have_decl_NET_TCP_ABORT_ON_OVERFLOW" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_member "$LINENO" "struct crypto_report_blkcipher" "ivsize" "ac_cv_member_struct_crypto_report_blkcipher_ivsize" "$ac_includes_default
-#include <linux/cryptouser.h>
 "
-if test "x$ac_cv_member_struct_crypto_report_blkcipher_ivsize" = xyes; then :
+if test "x$ac_cv_have_decl_NET_TCP_ABORT_ON_OVERFLOW" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_CRYPTO_REPORT_BLKCIPHER_IVSIZE 1
+#define HAVE_DECL_NET_TCP_ABORT_ON_OVERFLOW $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_SYNACK_RETRIES" "ac_cv_have_decl_NET_TCP_SYNACK_RETRIES" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
+"
+if test "x$ac_cv_have_decl_NET_TCP_SYNACK_RETRIES" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_TCP_SYNACK_RETRIES $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_MAX_ORPHANS" "ac_cv_have_decl_NET_TCP_MAX_ORPHANS" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_type "$LINENO" "struct crypto_report_aead" "ac_cv_type_struct_crypto_report_aead" "$ac_includes_default
-#include <linux/cryptouser.h>
 "
-if test "x$ac_cv_type_struct_crypto_report_aead" = xyes; then :
+if test "x$ac_cv_have_decl_NET_TCP_MAX_ORPHANS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_CRYPTO_REPORT_AEAD 1
+#define HAVE_DECL_NET_TCP_MAX_ORPHANS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_MAX_TW_BUCKETS" "ac_cv_have_decl_NET_TCP_MAX_TW_BUCKETS" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_member "$LINENO" "struct crypto_report_aead" "ivsize" "ac_cv_member_struct_crypto_report_aead_ivsize" "$ac_includes_default
-#include <linux/cryptouser.h>
 "
-if test "x$ac_cv_member_struct_crypto_report_aead_ivsize" = xyes; then :
+if test "x$ac_cv_have_decl_NET_TCP_MAX_TW_BUCKETS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_CRYPTO_REPORT_AEAD_IVSIZE 1
+#define HAVE_DECL_NET_TCP_MAX_TW_BUCKETS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_FACK" "ac_cv_have_decl_NET_TCP_FACK" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
+"
+if test "x$ac_cv_have_decl_NET_TCP_FACK" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_TCP_FACK $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_REORDERING" "ac_cv_have_decl_NET_TCP_REORDERING" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_type "$LINENO" "struct crypto_report_rng" "ac_cv_type_struct_crypto_report_rng" "$ac_includes_default
-#include <linux/cryptouser.h>
 "
-if test "x$ac_cv_type_struct_crypto_report_rng" = xyes; then :
+if test "x$ac_cv_have_decl_NET_TCP_REORDERING" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_CRYPTO_REPORT_RNG 1
+#define HAVE_DECL_NET_TCP_REORDERING $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_ECN" "ac_cv_have_decl_NET_TCP_ECN" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_member "$LINENO" "struct crypto_report_rng" "seedsize" "ac_cv_member_struct_crypto_report_rng_seedsize" "$ac_includes_default
-#include <linux/cryptouser.h>
 "
-if test "x$ac_cv_member_struct_crypto_report_rng_seedsize" = xyes; then :
+if test "x$ac_cv_have_decl_NET_TCP_ECN" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_CRYPTO_REPORT_RNG_SEEDSIZE 1
+#define HAVE_DECL_NET_TCP_ECN $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_DSACK" "ac_cv_have_decl_NET_TCP_DSACK" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
+"
+if test "x$ac_cv_have_decl_NET_TCP_DSACK" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_TCP_DSACK $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_MEM" "ac_cv_have_decl_NET_TCP_MEM" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
+"
+if test "x$ac_cv_have_decl_NET_TCP_MEM" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
-done
-
-
-for ac_header in linux/input.h
-do :
-  ac_fn_c_check_header_mongrel "$LINENO" "linux/input.h" "ac_cv_header_linux_input_h" "$ac_includes_default"
-if test "x$ac_cv_header_linux_input_h" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_LINUX_INPUT_H 1
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_TCP_MEM $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_WMEM" "ac_cv_have_decl_NET_TCP_WMEM" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-ac_fn_c_check_type "$LINENO" "struct input_absinfo" "ac_cv_type_struct_input_absinfo" "$ac_includes_default
-#include <linux/input.h>
 "
-if test "x$ac_cv_type_struct_input_absinfo" = xyes; then :
+if test "x$ac_cv_have_decl_NET_TCP_WMEM" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_INPUT_ABSINFO 1
+#define HAVE_DECL_NET_TCP_WMEM $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_RMEM" "ac_cv_have_decl_NET_TCP_RMEM" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_member "$LINENO" "struct input_absinfo" "resolution" "ac_cv_member_struct_input_absinfo_resolution" "$ac_includes_default
-#include <linux/input.h>
 "
-if test "x$ac_cv_member_struct_input_absinfo_resolution" = xyes; then :
+if test "x$ac_cv_have_decl_NET_TCP_RMEM" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_INPUT_ABSINFO_RESOLUTION 1
+#define HAVE_DECL_NET_TCP_RMEM $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_APP_WIN" "ac_cv_have_decl_NET_TCP_APP_WIN" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
+"
+if test "x$ac_cv_have_decl_NET_TCP_APP_WIN" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_TCP_APP_WIN $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_ADV_WIN_SCALE" "ac_cv_have_decl_NET_TCP_ADV_WIN_SCALE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_type "$LINENO" "struct input_keymap_entry" "ac_cv_type_struct_input_keymap_entry" "$ac_includes_default
-#include <linux/input.h>
 "
-if test "x$ac_cv_type_struct_input_keymap_entry" = xyes; then :
+if test "x$ac_cv_have_decl_NET_TCP_ADV_WIN_SCALE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_INPUT_KEYMAP_ENTRY 1
+#define HAVE_DECL_NET_TCP_ADV_WIN_SCALE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_NONLOCAL_BIND" "ac_cv_have_decl_NET_IPV4_NONLOCAL_BIND" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_member "$LINENO" "struct input_keymap_entry" "scancode" "ac_cv_member_struct_input_keymap_entry_scancode" "$ac_includes_default
-#include <linux/input.h>
 "
-if test "x$ac_cv_member_struct_input_keymap_entry_scancode" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_NONLOCAL_BIND" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_INPUT_KEYMAP_ENTRY_SCANCODE 1
+#define HAVE_DECL_NET_IPV4_NONLOCAL_BIND $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ICMP_RATELIMIT" "ac_cv_have_decl_NET_IPV4_ICMP_RATELIMIT" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
+"
+if test "x$ac_cv_have_decl_NET_IPV4_ICMP_RATELIMIT" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_IPV4_ICMP_RATELIMIT $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ICMP_RATEMASK" "ac_cv_have_decl_NET_IPV4_ICMP_RATEMASK" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_type "$LINENO" "struct input_mask" "ac_cv_type_struct_input_mask" "$ac_includes_default
-#include <linux/input.h>
 "
-if test "x$ac_cv_type_struct_input_mask" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_ICMP_RATEMASK" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_INPUT_MASK 1
+#define HAVE_DECL_NET_IPV4_ICMP_RATEMASK $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_TW_REUSE" "ac_cv_have_decl_NET_TCP_TW_REUSE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_member "$LINENO" "struct input_mask" "codes_ptr" "ac_cv_member_struct_input_mask_codes_ptr" "$ac_includes_default
-#include <linux/input.h>
 "
-if test "x$ac_cv_member_struct_input_mask_codes_ptr" = xyes; then :
+if test "x$ac_cv_have_decl_NET_TCP_TW_REUSE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_INPUT_MASK_CODES_PTR 1
+#define HAVE_DECL_NET_TCP_TW_REUSE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_FRTO" "ac_cv_have_decl_NET_TCP_FRTO" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
-fi
-
-
+"
+if test "x$ac_cv_have_decl_NET_TCP_FRTO" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
-done
-
-
-for ac_header in linux/io_uring.h
-do :
-  ac_fn_c_check_header_mongrel "$LINENO" "linux/io_uring.h" "ac_cv_header_linux_io_uring_h" "$ac_includes_default"
-if test "x$ac_cv_header_linux_io_uring_h" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_LINUX_IO_URING_H 1
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_TCP_FRTO $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_LOW_LATENCY" "ac_cv_have_decl_NET_TCP_LOW_LATENCY" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-ac_fn_c_check_type "$LINENO" "struct io_sqring_offsets" "ac_cv_type_struct_io_sqring_offsets" "$ac_includes_default
-#include <linux/io_uring.h>
 "
-if test "x$ac_cv_type_struct_io_sqring_offsets" = xyes; then :
+if test "x$ac_cv_have_decl_NET_TCP_LOW_LATENCY" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_IO_SQRING_OFFSETS 1
+#define HAVE_DECL_NET_TCP_LOW_LATENCY $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_IPFRAG_SECRET_INTERVAL" "ac_cv_have_decl_NET_IPV4_IPFRAG_SECRET_INTERVAL" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_member "$LINENO" "struct io_sqring_offsets" "resv2" "ac_cv_member_struct_io_sqring_offsets_resv2" "$ac_includes_default
-#include <linux/io_uring.h>
 "
-if test "x$ac_cv_member_struct_io_sqring_offsets_resv2" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_IPFRAG_SECRET_INTERVAL" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_IO_SQRING_OFFSETS_RESV2 1
+#define HAVE_DECL_NET_IPV4_IPFRAG_SECRET_INTERVAL $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_IGMP_MAX_MSF" "ac_cv_have_decl_NET_IPV4_IGMP_MAX_MSF" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
+"
+if test "x$ac_cv_have_decl_NET_IPV4_IGMP_MAX_MSF" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_IPV4_IGMP_MAX_MSF $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_NO_METRICS_SAVE" "ac_cv_have_decl_NET_TCP_NO_METRICS_SAVE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_type "$LINENO" "struct io_cqring_offsets" "ac_cv_type_struct_io_cqring_offsets" "$ac_includes_default
-#include <linux/io_uring.h>
 "
-if test "x$ac_cv_type_struct_io_cqring_offsets" = xyes; then :
+if test "x$ac_cv_have_decl_NET_TCP_NO_METRICS_SAVE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_IO_CQRING_OFFSETS 1
+#define HAVE_DECL_NET_TCP_NO_METRICS_SAVE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_DEFAULT_WIN_SCALE" "ac_cv_have_decl_NET_TCP_DEFAULT_WIN_SCALE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_member "$LINENO" "struct io_cqring_offsets" "resv" "ac_cv_member_struct_io_cqring_offsets_resv" "$ac_includes_default
-#include <linux/io_uring.h>
 "
-if test "x$ac_cv_member_struct_io_cqring_offsets_resv" = xyes; then :
+if test "x$ac_cv_have_decl_NET_TCP_DEFAULT_WIN_SCALE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_IO_CQRING_OFFSETS_RESV 1
+#define HAVE_DECL_NET_TCP_DEFAULT_WIN_SCALE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_MODERATE_RCVBUF" "ac_cv_have_decl_NET_TCP_MODERATE_RCVBUF" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
+"
+if test "x$ac_cv_have_decl_NET_TCP_MODERATE_RCVBUF" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_TCP_MODERATE_RCVBUF $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_TSO_WIN_DIVISOR" "ac_cv_have_decl_NET_TCP_TSO_WIN_DIVISOR" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_type "$LINENO" "struct io_uring_params" "ac_cv_type_struct_io_uring_params" "$ac_includes_default
-#include <linux/io_uring.h>
 "
-if test "x$ac_cv_type_struct_io_uring_params" = xyes; then :
+if test "x$ac_cv_have_decl_NET_TCP_TSO_WIN_DIVISOR" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_IO_URING_PARAMS 1
+#define HAVE_DECL_NET_TCP_TSO_WIN_DIVISOR $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_BIC_BETA" "ac_cv_have_decl_NET_TCP_BIC_BETA" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_member "$LINENO" "struct io_uring_params" "cq_off" "ac_cv_member_struct_io_uring_params_cq_off" "$ac_includes_default
-#include <linux/io_uring.h>
 "
-if test "x$ac_cv_member_struct_io_uring_params_cq_off" = xyes; then :
+if test "x$ac_cv_have_decl_NET_TCP_BIC_BETA" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_IO_URING_PARAMS_CQ_OFF 1
+#define HAVE_DECL_NET_TCP_BIC_BETA $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ICMP_ERRORS_USE_INBOUND_IFADDR" "ac_cv_have_decl_NET_IPV4_ICMP_ERRORS_USE_INBOUND_IFADDR" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
+"
+if test "x$ac_cv_have_decl_NET_IPV4_ICMP_ERRORS_USE_INBOUND_IFADDR" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_IPV4_ICMP_ERRORS_USE_INBOUND_IFADDR $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_CONG_CONTROL" "ac_cv_have_decl_NET_TCP_CONG_CONTROL" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_type "$LINENO" "struct io_uring_files_update" "ac_cv_type_struct_io_uring_files_update" "$ac_includes_default
-#include <linux/io_uring.h>
 "
-if test "x$ac_cv_type_struct_io_uring_files_update" = xyes; then :
+if test "x$ac_cv_have_decl_NET_TCP_CONG_CONTROL" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_IO_URING_FILES_UPDATE 1
+#define HAVE_DECL_NET_TCP_CONG_CONTROL $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_ABC" "ac_cv_have_decl_NET_TCP_ABC" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_member "$LINENO" "struct io_uring_files_update" "fds" "ac_cv_member_struct_io_uring_files_update_fds" "$ac_includes_default
-#include <linux/io_uring.h>
 "
-if test "x$ac_cv_member_struct_io_uring_files_update_fds" = xyes; then :
+if test "x$ac_cv_have_decl_NET_TCP_ABC" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_IO_URING_FILES_UPDATE_FDS 1
+#define HAVE_DECL_NET_TCP_ABC $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_IPFRAG_MAX_DIST" "ac_cv_have_decl_NET_IPV4_IPFRAG_MAX_DIST" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
+"
+if test "x$ac_cv_have_decl_NET_IPV4_IPFRAG_MAX_DIST" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_IPV4_IPFRAG_MAX_DIST $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_MTU_PROBING" "ac_cv_have_decl_NET_TCP_MTU_PROBING" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
+"
+if test "x$ac_cv_have_decl_NET_TCP_MTU_PROBING" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
-done
-
-
-for ac_header in linux/rtnetlink.h
-do :
-  ac_fn_c_check_header_mongrel "$LINENO" "linux/rtnetlink.h" "ac_cv_header_linux_rtnetlink_h" "$ac_includes_default"
-if test "x$ac_cv_header_linux_rtnetlink_h" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_LINUX_RTNETLINK_H 1
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_TCP_MTU_PROBING $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_BASE_MSS" "ac_cv_have_decl_NET_TCP_BASE_MSS" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-ac_fn_c_check_type "$LINENO" "struct rtnl_link_stats" "ac_cv_type_struct_rtnl_link_stats" "$ac_includes_default
-#include \"$srcdir/netlink.h\"
-#include <linux/rtnetlink.h>
 "
-if test "x$ac_cv_type_struct_rtnl_link_stats" = xyes; then :
+if test "x$ac_cv_have_decl_NET_TCP_BASE_MSS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_RTNL_LINK_STATS 1
+#define HAVE_DECL_NET_TCP_BASE_MSS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_TCP_WORKAROUND_SIGNED_WINDOWS" "ac_cv_have_decl_NET_IPV4_TCP_WORKAROUND_SIGNED_WINDOWS" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_member "$LINENO" "struct rtnl_link_stats" "rx_nohandler" "ac_cv_member_struct_rtnl_link_stats_rx_nohandler" "$ac_includes_default
-#include \"$srcdir/netlink.h\"
-#include <linux/rtnetlink.h>
 "
-if test "x$ac_cv_member_struct_rtnl_link_stats_rx_nohandler" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_TCP_WORKAROUND_SIGNED_WINDOWS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_RTNL_LINK_STATS_RX_NOHANDLER 1
+#define HAVE_DECL_NET_IPV4_TCP_WORKAROUND_SIGNED_WINDOWS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_DMA_COPYBREAK" "ac_cv_have_decl_NET_TCP_DMA_COPYBREAK" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
+"
+if test "x$ac_cv_have_decl_NET_TCP_DMA_COPYBREAK" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_TCP_DMA_COPYBREAK $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_SLOW_START_AFTER_IDLE" "ac_cv_have_decl_NET_TCP_SLOW_START_AFTER_IDLE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_type "$LINENO" "struct rtnl_link_stats64" "ac_cv_type_struct_rtnl_link_stats64" "$ac_includes_default
-#include \"$srcdir/netlink.h\"
-#include <linux/rtnetlink.h>
 "
-if test "x$ac_cv_type_struct_rtnl_link_stats64" = xyes; then :
+if test "x$ac_cv_have_decl_NET_TCP_SLOW_START_AFTER_IDLE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_RTNL_LINK_STATS64 1
+#define HAVE_DECL_NET_TCP_SLOW_START_AFTER_IDLE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_CIPSOV4_CACHE_ENABLE" "ac_cv_have_decl_NET_CIPSOV4_CACHE_ENABLE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_member "$LINENO" "struct rtnl_link_stats64" "rx_nohandler" "ac_cv_member_struct_rtnl_link_stats64_rx_nohandler" "$ac_includes_default
-#include \"$srcdir/netlink.h\"
-#include <linux/rtnetlink.h>
 "
-if test "x$ac_cv_member_struct_rtnl_link_stats64_rx_nohandler" = xyes; then :
+if test "x$ac_cv_have_decl_NET_CIPSOV4_CACHE_ENABLE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_RTNL_LINK_STATS64_RX_NOHANDLER 1
+#define HAVE_DECL_NET_CIPSOV4_CACHE_ENABLE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_CIPSOV4_CACHE_BUCKET_SIZE" "ac_cv_have_decl_NET_CIPSOV4_CACHE_BUCKET_SIZE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
+"
+if test "x$ac_cv_have_decl_NET_CIPSOV4_CACHE_BUCKET_SIZE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_CIPSOV4_CACHE_BUCKET_SIZE $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_CIPSOV4_RBM_OPTFMT" "ac_cv_have_decl_NET_CIPSOV4_RBM_OPTFMT" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_type "$LINENO" "struct ifla_bridge_id" "ac_cv_type_struct_ifla_bridge_id" "$ac_includes_default
-#include \"$srcdir/netlink.h\"
-#include <linux/rtnetlink.h>
 "
-if test "x$ac_cv_type_struct_ifla_bridge_id" = xyes; then :
+if test "x$ac_cv_have_decl_NET_CIPSOV4_RBM_OPTFMT" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_IFLA_BRIDGE_ID 1
+#define HAVE_DECL_NET_CIPSOV4_RBM_OPTFMT $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_CIPSOV4_RBM_STRICTVALID" "ac_cv_have_decl_NET_CIPSOV4_RBM_STRICTVALID" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_member "$LINENO" "struct ifla_bridge_id" "addr" "ac_cv_member_struct_ifla_bridge_id_addr" "$ac_includes_default
-#include \"$srcdir/netlink.h\"
-#include <linux/rtnetlink.h>
 "
-if test "x$ac_cv_member_struct_ifla_bridge_id_addr" = xyes; then :
+if test "x$ac_cv_have_decl_NET_CIPSOV4_RBM_STRICTVALID" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_IFLA_BRIDGE_ID_ADDR 1
+#define HAVE_DECL_NET_CIPSOV4_RBM_STRICTVALID $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_AVAIL_CONG_CONTROL" "ac_cv_have_decl_NET_TCP_AVAIL_CONG_CONTROL" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
+"
+if test "x$ac_cv_have_decl_NET_TCP_AVAIL_CONG_CONTROL" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_TCP_AVAIL_CONG_CONTROL $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_ALLOWED_CONG_CONTROL" "ac_cv_have_decl_NET_TCP_ALLOWED_CONG_CONTROL" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
+
+"
+if test "x$ac_cv_have_decl_NET_TCP_ALLOWED_CONG_CONTROL" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_TCP_ALLOWED_CONG_CONTROL $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_MAX_SSTHRESH" "ac_cv_have_decl_NET_TCP_MAX_SSTHRESH" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_type "$LINENO" "struct ifla_port_vsi" "ac_cv_type_struct_ifla_port_vsi" "$ac_includes_default
-#include \"$srcdir/netlink.h\"
-#include <linux/rtnetlink.h>
 "
-if test "x$ac_cv_type_struct_ifla_port_vsi" = xyes; then :
+if test "x$ac_cv_have_decl_NET_TCP_MAX_SSTHRESH" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_IFLA_PORT_VSI 1
+#define HAVE_DECL_NET_TCP_MAX_SSTHRESH $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_TCP_FRTO_RESPONSE" "ac_cv_have_decl_NET_TCP_FRTO_RESPONSE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_member "$LINENO" "struct ifla_port_vsi" "pad" "ac_cv_member_struct_ifla_port_vsi_pad" "$ac_includes_default
-#include \"$srcdir/netlink.h\"
-#include <linux/rtnetlink.h>
 "
-if test "x$ac_cv_member_struct_ifla_port_vsi_pad" = xyes; then :
+if test "x$ac_cv_have_decl_NET_TCP_FRTO_RESPONSE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_IFLA_PORT_VSI_PAD 1
+#define HAVE_DECL_NET_TCP_FRTO_RESPONSE $ac_have_decl
 _ACEOF
 
 
-fi
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_FORWARDING" "ac_cv_have_decl_NET_IPV4_CONF_FORWARDING" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
+"
+if test "x$ac_cv_have_decl_NET_IPV4_CONF_FORWARDING" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_IPV4_CONF_FORWARDING $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_MC_FORWARDING" "ac_cv_have_decl_NET_IPV4_CONF_MC_FORWARDING" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
+"
+if test "x$ac_cv_have_decl_NET_IPV4_CONF_MC_FORWARDING" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
-done
-
-
-for ac_header in linux/if_bridge.h
-do :
-  ac_fn_c_check_header_mongrel "$LINENO" "linux/if_bridge.h" "ac_cv_header_linux_if_bridge_h" "$ac_includes_default"
-if test "x$ac_cv_header_linux_if_bridge_h" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_LINUX_IF_BRIDGE_H 1
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_IPV4_CONF_MC_FORWARDING $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_PROXY_ARP" "ac_cv_have_decl_NET_IPV4_CONF_PROXY_ARP" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-ac_fn_c_check_type "$LINENO" "struct br_port_msg" "ac_cv_type_struct_br_port_msg" "$ac_includes_default
-#include <netinet/in.h>
-#include <linux/if_bridge.h>
 "
-if test "x$ac_cv_type_struct_br_port_msg" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_CONF_PROXY_ARP" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BR_PORT_MSG 1
+#define HAVE_DECL_NET_IPV4_CONF_PROXY_ARP $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_ACCEPT_REDIRECTS" "ac_cv_have_decl_NET_IPV4_CONF_ACCEPT_REDIRECTS" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_member "$LINENO" "struct br_port_msg" "ifindex" "ac_cv_member_struct_br_port_msg_ifindex" "$ac_includes_default
-#include <netinet/in.h>
-#include <linux/if_bridge.h>
 "
-if test "x$ac_cv_member_struct_br_port_msg_ifindex" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_CONF_ACCEPT_REDIRECTS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BR_PORT_MSG_IFINDEX 1
+#define HAVE_DECL_NET_IPV4_CONF_ACCEPT_REDIRECTS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_SECURE_REDIRECTS" "ac_cv_have_decl_NET_IPV4_CONF_SECURE_REDIRECTS" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
+"
+if test "x$ac_cv_have_decl_NET_IPV4_CONF_SECURE_REDIRECTS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_IPV4_CONF_SECURE_REDIRECTS $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_SEND_REDIRECTS" "ac_cv_have_decl_NET_IPV4_CONF_SEND_REDIRECTS" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_type "$LINENO" "struct br_mdb_entry" "ac_cv_type_struct_br_mdb_entry" "$ac_includes_default
-#include <netinet/in.h>
-#include <linux/if_bridge.h>
 "
-if test "x$ac_cv_type_struct_br_mdb_entry" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_CONF_SEND_REDIRECTS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BR_MDB_ENTRY 1
+#define HAVE_DECL_NET_IPV4_CONF_SEND_REDIRECTS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_SHARED_MEDIA" "ac_cv_have_decl_NET_IPV4_CONF_SHARED_MEDIA" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_member "$LINENO" "struct br_mdb_entry" "addr" "ac_cv_member_struct_br_mdb_entry_addr" "$ac_includes_default
-#include <netinet/in.h>
-#include <linux/if_bridge.h>
 "
-if test "x$ac_cv_member_struct_br_mdb_entry_addr" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_CONF_SHARED_MEDIA" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_BR_MDB_ENTRY_ADDR 1
+#define HAVE_DECL_NET_IPV4_CONF_SHARED_MEDIA $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_RP_FILTER" "ac_cv_have_decl_NET_IPV4_CONF_RP_FILTER" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
+"
+if test "x$ac_cv_have_decl_NET_IPV4_CONF_RP_FILTER" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_IPV4_CONF_RP_FILTER $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_ACCEPT_SOURCE_ROUTE" "ac_cv_have_decl_NET_IPV4_CONF_ACCEPT_SOURCE_ROUTE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
+"
+if test "x$ac_cv_have_decl_NET_IPV4_CONF_ACCEPT_SOURCE_ROUTE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
-done
-
-
-for ac_header in linux/rtnetlink.h
-do :
-  ac_fn_c_check_header_mongrel "$LINENO" "linux/rtnetlink.h" "ac_cv_header_linux_rtnetlink_h" "$ac_includes_default"
-if test "x$ac_cv_header_linux_rtnetlink_h" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_LINUX_RTNETLINK_H 1
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_IPV4_CONF_ACCEPT_SOURCE_ROUTE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_BOOTP_RELAY" "ac_cv_have_decl_NET_IPV4_CONF_BOOTP_RELAY" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-ac_fn_c_check_type "$LINENO" "struct ndt_config" "ac_cv_type_struct_ndt_config" "$ac_includes_default
-#include \"$srcdir/netlink.h\"
-#include <linux/rtnetlink.h>
 "
-if test "x$ac_cv_type_struct_ndt_config" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_CONF_BOOTP_RELAY" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_NDT_CONFIG 1
+#define HAVE_DECL_NET_IPV4_CONF_BOOTP_RELAY $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_LOG_MARTIANS" "ac_cv_have_decl_NET_IPV4_CONF_LOG_MARTIANS" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_member "$LINENO" "struct ndt_config" "ndtc_proxy_qlen" "ac_cv_member_struct_ndt_config_ndtc_proxy_qlen" "$ac_includes_default
-#include \"$srcdir/netlink.h\"
-#include <linux/rtnetlink.h>
 "
-if test "x$ac_cv_member_struct_ndt_config_ndtc_proxy_qlen" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_CONF_LOG_MARTIANS" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_NDT_CONFIG_NDTC_PROXY_QLEN 1
+#define HAVE_DECL_NET_IPV4_CONF_LOG_MARTIANS $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_TAG" "ac_cv_have_decl_NET_IPV4_CONF_TAG" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
+"
+if test "x$ac_cv_have_decl_NET_IPV4_CONF_TAG" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_IPV4_CONF_TAG $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_ARPFILTER" "ac_cv_have_decl_NET_IPV4_CONF_ARPFILTER" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
+
+"
+if test "x$ac_cv_have_decl_NET_IPV4_CONF_ARPFILTER" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_IPV4_CONF_ARPFILTER $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_MEDIUM_ID" "ac_cv_have_decl_NET_IPV4_CONF_MEDIUM_ID" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_type "$LINENO" "struct ndt_stats" "ac_cv_type_struct_ndt_stats" "$ac_includes_default
-#include \"$srcdir/netlink.h\"
-#include <linux/rtnetlink.h>
 "
-if test "x$ac_cv_type_struct_ndt_stats" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_CONF_MEDIUM_ID" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_NDT_STATS 1
+#define HAVE_DECL_NET_IPV4_CONF_MEDIUM_ID $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_NOXFRM" "ac_cv_have_decl_NET_IPV4_CONF_NOXFRM" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_member "$LINENO" "struct ndt_stats" "ndts_table_fulls" "ac_cv_member_struct_ndt_stats_ndts_table_fulls" "$ac_includes_default
-#include \"$srcdir/netlink.h\"
-#include <linux/rtnetlink.h>
 "
-if test "x$ac_cv_member_struct_ndt_stats_ndts_table_fulls" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_CONF_NOXFRM" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_NDT_STATS_NDTS_TABLE_FULLS 1
+#define HAVE_DECL_NET_IPV4_CONF_NOXFRM $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_NOPOLICY" "ac_cv_have_decl_NET_IPV4_CONF_NOPOLICY" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
+"
+if test "x$ac_cv_have_decl_NET_IPV4_CONF_NOPOLICY" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_IPV4_CONF_NOPOLICY $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_FORCE_IGMP_VERSION" "ac_cv_have_decl_NET_IPV4_CONF_FORCE_IGMP_VERSION" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
+"
+if test "x$ac_cv_have_decl_NET_IPV4_CONF_FORCE_IGMP_VERSION" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
-done
-
-
-for ac_header in linux/rtnetlink.h
-do :
-  ac_fn_c_check_header_mongrel "$LINENO" "linux/rtnetlink.h" "ac_cv_header_linux_rtnetlink_h" "$ac_includes_default"
-if test "x$ac_cv_header_linux_rtnetlink_h" = xyes; then :
-  cat >>confdefs.h <<_ACEOF
-#define HAVE_LINUX_RTNETLINK_H 1
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_IPV4_CONF_FORCE_IGMP_VERSION $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_ARP_ANNOUNCE" "ac_cv_have_decl_NET_IPV4_CONF_ARP_ANNOUNCE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-ac_fn_c_check_type "$LINENO" "struct rta_mfc_stats" "ac_cv_type_struct_rta_mfc_stats" "$ac_includes_default
-#include \"$srcdir/netlink.h\"
-#include <linux/rtnetlink.h>
 "
-if test "x$ac_cv_type_struct_rta_mfc_stats" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_CONF_ARP_ANNOUNCE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_RTA_MFC_STATS 1
+#define HAVE_DECL_NET_IPV4_CONF_ARP_ANNOUNCE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_ARP_IGNORE" "ac_cv_have_decl_NET_IPV4_CONF_ARP_IGNORE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_member "$LINENO" "struct rta_mfc_stats" "mfcs_wrong_if" "ac_cv_member_struct_rta_mfc_stats_mfcs_wrong_if" "$ac_includes_default
-#include \"$srcdir/netlink.h\"
-#include <linux/rtnetlink.h>
 "
-if test "x$ac_cv_member_struct_rta_mfc_stats_mfcs_wrong_if" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_CONF_ARP_IGNORE" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_RTA_MFC_STATS_MFCS_WRONG_IF 1
+#define HAVE_DECL_NET_IPV4_CONF_ARP_IGNORE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_PROMOTE_SECONDARIES" "ac_cv_have_decl_NET_IPV4_CONF_PROMOTE_SECONDARIES" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-fi
-
+"
+if test "x$ac_cv_have_decl_NET_IPV4_CONF_PROMOTE_SECONDARIES" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_IPV4_CONF_PROMOTE_SECONDARIES $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_ARP_ACCEPT" "ac_cv_have_decl_NET_IPV4_CONF_ARP_ACCEPT" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_type "$LINENO" "struct rtvia" "ac_cv_type_struct_rtvia" "$ac_includes_default
-#include \"$srcdir/netlink.h\"
-#include <linux/rtnetlink.h>
 "
-if test "x$ac_cv_type_struct_rtvia" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_CONF_ARP_ACCEPT" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_RTVIA 1
+#define HAVE_DECL_NET_IPV4_CONF_ARP_ACCEPT $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_ARP_NOTIFY" "ac_cv_have_decl_NET_IPV4_CONF_ARP_NOTIFY" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_member "$LINENO" "struct rtvia" "rtvia_addr" "ac_cv_member_struct_rtvia_rtvia_addr" "$ac_includes_default
-#include \"$srcdir/netlink.h\"
-#include <linux/rtnetlink.h>
 "
-if test "x$ac_cv_member_struct_rtvia_rtvia_addr" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_CONF_ARP_NOTIFY" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_STRUCT_RTVIA_RTVIA_ADDR 1
+#define HAVE_DECL_NET_IPV4_CONF_ARP_NOTIFY $ac_have_decl
 _ACEOF
 
 
-fi
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ROUTE_FLUSH" "ac_cv_have_decl_NET_IPV4_ROUTE_FLUSH" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
+"
+if test "x$ac_cv_have_decl_NET_IPV4_ROUTE_FLUSH" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_IPV4_ROUTE_FLUSH $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ROUTE_MIN_DELAY" "ac_cv_have_decl_NET_IPV4_ROUTE_MIN_DELAY" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
+"
+if test "x$ac_cv_have_decl_NET_IPV4_ROUTE_MIN_DELAY" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
 fi
 
-done
-
-
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_IPV4_ROUTE_MIN_DELAY $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ROUTE_MAX_DELAY" "ac_cv_have_decl_NET_IPV4_ROUTE_MAX_DELAY" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_decl "$LINENO" "sys_errlist" "ac_cv_have_decl_sys_errlist" "$ac_includes_default"
-if test "x$ac_cv_have_decl_sys_errlist" = xyes; then :
+"
+if test "x$ac_cv_have_decl_NET_IPV4_ROUTE_MAX_DELAY" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_SYS_ERRLIST $ac_have_decl
+#define HAVE_DECL_NET_IPV4_ROUTE_MAX_DELAY $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ROUTE_GC_THRESH" "ac_cv_have_decl_NET_IPV4_ROUTE_GC_THRESH" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-ac_fn_c_check_decl "$LINENO" "PTRACE_PEEKUSER" "ac_cv_have_decl_PTRACE_PEEKUSER" "#include <sys/ptrace.h>
 "
-if test "x$ac_cv_have_decl_PTRACE_PEEKUSER" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_ROUTE_GC_THRESH" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_PTRACE_PEEKUSER $ac_have_decl
+#define HAVE_DECL_NET_IPV4_ROUTE_GC_THRESH $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "PTRACE_POKEUSER" "ac_cv_have_decl_PTRACE_POKEUSER" "#include <sys/ptrace.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ROUTE_MAX_SIZE" "ac_cv_have_decl_NET_IPV4_ROUTE_MAX_SIZE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_PTRACE_POKEUSER" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_ROUTE_MAX_SIZE" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_PTRACE_POKEUSER $ac_have_decl
+#define HAVE_DECL_NET_IPV4_ROUTE_MAX_SIZE $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ROUTE_GC_MIN_INTERVAL" "ac_cv_have_decl_NET_IPV4_ROUTE_GC_MIN_INTERVAL" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-ac_fn_c_check_decl "$LINENO" "P_PID" "ac_cv_have_decl_P_PID" "#include <sys/wait.h>
 "
-if test "x$ac_cv_have_decl_P_PID" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_ROUTE_GC_MIN_INTERVAL" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_P_PID $ac_have_decl
+#define HAVE_DECL_NET_IPV4_ROUTE_GC_MIN_INTERVAL $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "P_PPID" "ac_cv_have_decl_P_PPID" "#include <sys/wait.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ROUTE_GC_TIMEOUT" "ac_cv_have_decl_NET_IPV4_ROUTE_GC_TIMEOUT" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_P_PPID" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_ROUTE_GC_TIMEOUT" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_P_PPID $ac_have_decl
+#define HAVE_DECL_NET_IPV4_ROUTE_GC_TIMEOUT $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "P_PGID" "ac_cv_have_decl_P_PGID" "#include <sys/wait.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ROUTE_GC_INTERVAL" "ac_cv_have_decl_NET_IPV4_ROUTE_GC_INTERVAL" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_P_PGID" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_ROUTE_GC_INTERVAL" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_P_PGID $ac_have_decl
+#define HAVE_DECL_NET_IPV4_ROUTE_GC_INTERVAL $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "P_SID" "ac_cv_have_decl_P_SID" "#include <sys/wait.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ROUTE_REDIRECT_LOAD" "ac_cv_have_decl_NET_IPV4_ROUTE_REDIRECT_LOAD" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_P_SID" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_ROUTE_REDIRECT_LOAD" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_P_SID $ac_have_decl
+#define HAVE_DECL_NET_IPV4_ROUTE_REDIRECT_LOAD $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "P_CID" "ac_cv_have_decl_P_CID" "#include <sys/wait.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ROUTE_REDIRECT_NUMBER" "ac_cv_have_decl_NET_IPV4_ROUTE_REDIRECT_NUMBER" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_P_CID" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_ROUTE_REDIRECT_NUMBER" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_P_CID $ac_have_decl
+#define HAVE_DECL_NET_IPV4_ROUTE_REDIRECT_NUMBER $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "P_UID" "ac_cv_have_decl_P_UID" "#include <sys/wait.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ROUTE_REDIRECT_SILENCE" "ac_cv_have_decl_NET_IPV4_ROUTE_REDIRECT_SILENCE" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_P_UID" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_ROUTE_REDIRECT_SILENCE" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_P_UID $ac_have_decl
+#define HAVE_DECL_NET_IPV4_ROUTE_REDIRECT_SILENCE $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "P_GID" "ac_cv_have_decl_P_GID" "#include <sys/wait.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ROUTE_ERROR_COST" "ac_cv_have_decl_NET_IPV4_ROUTE_ERROR_COST" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_P_GID" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_ROUTE_ERROR_COST" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_P_GID $ac_have_decl
+#define HAVE_DECL_NET_IPV4_ROUTE_ERROR_COST $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "P_ALL" "ac_cv_have_decl_P_ALL" "#include <sys/wait.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ROUTE_ERROR_BURST" "ac_cv_have_decl_NET_IPV4_ROUTE_ERROR_BURST" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_P_ALL" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_ROUTE_ERROR_BURST" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_P_ALL $ac_have_decl
+#define HAVE_DECL_NET_IPV4_ROUTE_ERROR_BURST $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "P_LWPID" "ac_cv_have_decl_P_LWPID" "#include <sys/wait.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ROUTE_GC_ELASTICITY" "ac_cv_have_decl_NET_IPV4_ROUTE_GC_ELASTICITY" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_P_LWPID" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_ROUTE_GC_ELASTICITY" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_P_LWPID $ac_have_decl
+#define HAVE_DECL_NET_IPV4_ROUTE_GC_ELASTICITY $ac_have_decl
 _ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ROUTE_MTU_EXPIRES" "ac_cv_have_decl_NET_IPV4_ROUTE_MTU_EXPIRES" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
 
-
-ac_fn_c_check_decl "$LINENO" "LO_FLAGS_READ_ONLY" "ac_cv_have_decl_LO_FLAGS_READ_ONLY" "#include <linux/loop.h>
 "
-if test "x$ac_cv_have_decl_LO_FLAGS_READ_ONLY" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_ROUTE_MTU_EXPIRES" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_LO_FLAGS_READ_ONLY $ac_have_decl
+#define HAVE_DECL_NET_IPV4_ROUTE_MTU_EXPIRES $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "LO_FLAGS_USE_AOPS" "ac_cv_have_decl_LO_FLAGS_USE_AOPS" "#include <linux/loop.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ROUTE_MIN_PMTU" "ac_cv_have_decl_NET_IPV4_ROUTE_MIN_PMTU" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_LO_FLAGS_USE_AOPS" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_ROUTE_MIN_PMTU" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_LO_FLAGS_USE_AOPS $ac_have_decl
+#define HAVE_DECL_NET_IPV4_ROUTE_MIN_PMTU $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "LO_FLAGS_AUTOCLEAR" "ac_cv_have_decl_LO_FLAGS_AUTOCLEAR" "#include <linux/loop.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ROUTE_MIN_ADVMSS" "ac_cv_have_decl_NET_IPV4_ROUTE_MIN_ADVMSS" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_LO_FLAGS_AUTOCLEAR" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_ROUTE_MIN_ADVMSS" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_LO_FLAGS_AUTOCLEAR $ac_have_decl
+#define HAVE_DECL_NET_IPV4_ROUTE_MIN_ADVMSS $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "LO_FLAGS_PARTSCAN" "ac_cv_have_decl_LO_FLAGS_PARTSCAN" "#include <linux/loop.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ROUTE_SECRET_INTERVAL" "ac_cv_have_decl_NET_IPV4_ROUTE_SECRET_INTERVAL" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_LO_FLAGS_PARTSCAN" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_ROUTE_SECRET_INTERVAL" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_LO_FLAGS_PARTSCAN $ac_have_decl
+#define HAVE_DECL_NET_IPV4_ROUTE_SECRET_INTERVAL $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "LO_FLAGS_DIRECT_IO" "ac_cv_have_decl_LO_FLAGS_DIRECT_IO" "#include <linux/loop.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV4_ROUTE_GC_MIN_INTERVAL_MS" "ac_cv_have_decl_NET_IPV4_ROUTE_GC_MIN_INTERVAL_MS" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_LO_FLAGS_DIRECT_IO" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV4_ROUTE_GC_MIN_INTERVAL_MS" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_LO_FLAGS_DIRECT_IO $ac_have_decl
+#define HAVE_DECL_NET_IPV4_ROUTE_GC_MIN_INTERVAL_MS $ac_have_decl
 _ACEOF
 
 
-ac_fn_c_check_decl "$LINENO" "CTL_PROC" "ac_cv_have_decl_CTL_PROC" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV6_CONF" "ac_cv_have_decl_NET_IPV6_CONF" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_CTL_PROC" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV6_CONF" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_CTL_PROC $ac_have_decl
+#define HAVE_DECL_NET_IPV6_CONF $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "CTL_ARLAN" "ac_cv_have_decl_CTL_ARLAN" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV6_NEIGH" "ac_cv_have_decl_NET_IPV6_NEIGH" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_CTL_ARLAN" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV6_NEIGH" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_CTL_ARLAN $ac_have_decl
+#define HAVE_DECL_NET_IPV6_NEIGH $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "CTL_S390DBF" "ac_cv_have_decl_CTL_S390DBF" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV6_ROUTE" "ac_cv_have_decl_NET_IPV6_ROUTE" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_CTL_S390DBF" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV6_ROUTE" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_CTL_S390DBF $ac_have_decl
+#define HAVE_DECL_NET_IPV6_ROUTE $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "CTL_SUNRPC" "ac_cv_have_decl_CTL_SUNRPC" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV6_ICMP" "ac_cv_have_decl_NET_IPV6_ICMP" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_CTL_SUNRPC" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV6_ICMP" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_CTL_SUNRPC $ac_have_decl
+#define HAVE_DECL_NET_IPV6_ICMP $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "CTL_PM" "ac_cv_have_decl_CTL_PM" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV6_BINDV6ONLY" "ac_cv_have_decl_NET_IPV6_BINDV6ONLY" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_CTL_PM" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV6_BINDV6ONLY" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_CTL_PM $ac_have_decl
+#define HAVE_DECL_NET_IPV6_BINDV6ONLY $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "CTL_FRV" "ac_cv_have_decl_CTL_FRV" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV6_IP6FRAG_HIGH_THRESH" "ac_cv_have_decl_NET_IPV6_IP6FRAG_HIGH_THRESH" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_CTL_FRV" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV6_IP6FRAG_HIGH_THRESH" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_CTL_FRV $ac_have_decl
+#define HAVE_DECL_NET_IPV6_IP6FRAG_HIGH_THRESH $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "KERN_PRINTK_RATELIMIT" "ac_cv_have_decl_KERN_PRINTK_RATELIMIT" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV6_IP6FRAG_LOW_THRESH" "ac_cv_have_decl_NET_IPV6_IP6FRAG_LOW_THRESH" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_KERN_PRINTK_RATELIMIT" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV6_IP6FRAG_LOW_THRESH" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_KERN_PRINTK_RATELIMIT $ac_have_decl
+#define HAVE_DECL_NET_IPV6_IP6FRAG_LOW_THRESH $ac_have_decl
+_ACEOF
+ac_fn_c_check_decl "$LINENO" "NET_IPV6_IP6FRAG_TIME" "ac_cv_have_decl_NET_IPV6_IP6FRAG_TIME" "
+#include <sys/types.h>
+#include <linux/sysctl.h>
+
+"
+if test "x$ac_cv_have_decl_NET_IPV6_IP6FRAG_TIME" = xyes; then :
+  ac_have_decl=1
+else
+  ac_have_decl=0
+fi
+
+cat >>confdefs.h <<_ACEOF
+#define HAVE_DECL_NET_IPV6_IP6FRAG_TIME $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "KERN_PRINTK_RATELIMIT_BURST" "ac_cv_have_decl_KERN_PRINTK_RATELIMIT_BURST" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV6_IP6FRAG_SECRET_INTERVAL" "ac_cv_have_decl_NET_IPV6_IP6FRAG_SECRET_INTERVAL" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_KERN_PRINTK_RATELIMIT_BURST" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV6_IP6FRAG_SECRET_INTERVAL" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_KERN_PRINTK_RATELIMIT_BURST $ac_have_decl
+#define HAVE_DECL_NET_IPV6_IP6FRAG_SECRET_INTERVAL $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "KERN_PTY" "ac_cv_have_decl_KERN_PTY" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV6_MLD_MAX_MSF" "ac_cv_have_decl_NET_IPV6_MLD_MAX_MSF" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_KERN_PTY" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV6_MLD_MAX_MSF" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_KERN_PTY $ac_have_decl
+#define HAVE_DECL_NET_IPV6_MLD_MAX_MSF $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "KERN_NGROUPS_MAX" "ac_cv_have_decl_KERN_NGROUPS_MAX" "#include <sys/types.h>
+
+
+ac_fn_c_check_decl "$LINENO" "NET_IPV6_ROUTE_FLUSH" "ac_cv_have_decl_NET_IPV6_ROUTE_FLUSH" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_KERN_NGROUPS_MAX" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV6_ROUTE_FLUSH" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_KERN_NGROUPS_MAX $ac_have_decl
+#define HAVE_DECL_NET_IPV6_ROUTE_FLUSH $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "KERN_SPARC_SCONS_PWROFF" "ac_cv_have_decl_KERN_SPARC_SCONS_PWROFF" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV6_ROUTE_GC_THRESH" "ac_cv_have_decl_NET_IPV6_ROUTE_GC_THRESH" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_KERN_SPARC_SCONS_PWROFF" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV6_ROUTE_GC_THRESH" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_KERN_SPARC_SCONS_PWROFF $ac_have_decl
+#define HAVE_DECL_NET_IPV6_ROUTE_GC_THRESH $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "KERN_HZ_TIMER" "ac_cv_have_decl_KERN_HZ_TIMER" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV6_ROUTE_MAX_SIZE" "ac_cv_have_decl_NET_IPV6_ROUTE_MAX_SIZE" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_KERN_HZ_TIMER" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV6_ROUTE_MAX_SIZE" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_KERN_HZ_TIMER $ac_have_decl
+#define HAVE_DECL_NET_IPV6_ROUTE_MAX_SIZE $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "KERN_UNKNOWN_NMI_PANIC" "ac_cv_have_decl_KERN_UNKNOWN_NMI_PANIC" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV6_ROUTE_GC_MIN_INTERVAL" "ac_cv_have_decl_NET_IPV6_ROUTE_GC_MIN_INTERVAL" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_KERN_UNKNOWN_NMI_PANIC" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV6_ROUTE_GC_MIN_INTERVAL" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_KERN_UNKNOWN_NMI_PANIC $ac_have_decl
+#define HAVE_DECL_NET_IPV6_ROUTE_GC_MIN_INTERVAL $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "KERN_BOOTLOADER_TYPE" "ac_cv_have_decl_KERN_BOOTLOADER_TYPE" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV6_ROUTE_GC_TIMEOUT" "ac_cv_have_decl_NET_IPV6_ROUTE_GC_TIMEOUT" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_KERN_BOOTLOADER_TYPE" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV6_ROUTE_GC_TIMEOUT" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_KERN_BOOTLOADER_TYPE $ac_have_decl
+#define HAVE_DECL_NET_IPV6_ROUTE_GC_TIMEOUT $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "KERN_RANDOMIZE" "ac_cv_have_decl_KERN_RANDOMIZE" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV6_ROUTE_GC_INTERVAL" "ac_cv_have_decl_NET_IPV6_ROUTE_GC_INTERVAL" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_KERN_RANDOMIZE" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV6_ROUTE_GC_INTERVAL" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_KERN_RANDOMIZE $ac_have_decl
+#define HAVE_DECL_NET_IPV6_ROUTE_GC_INTERVAL $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "KERN_SETUID_DUMPABLE" "ac_cv_have_decl_KERN_SETUID_DUMPABLE" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV6_ROUTE_GC_ELASTICITY" "ac_cv_have_decl_NET_IPV6_ROUTE_GC_ELASTICITY" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_KERN_SETUID_DUMPABLE" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV6_ROUTE_GC_ELASTICITY" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_KERN_SETUID_DUMPABLE $ac_have_decl
+#define HAVE_DECL_NET_IPV6_ROUTE_GC_ELASTICITY $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "KERN_SPIN_RETRY" "ac_cv_have_decl_KERN_SPIN_RETRY" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV6_ROUTE_MTU_EXPIRES" "ac_cv_have_decl_NET_IPV6_ROUTE_MTU_EXPIRES" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_KERN_SPIN_RETRY" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV6_ROUTE_MTU_EXPIRES" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_KERN_SPIN_RETRY $ac_have_decl
+#define HAVE_DECL_NET_IPV6_ROUTE_MTU_EXPIRES $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "KERN_ACPI_VIDEO_FLAGS" "ac_cv_have_decl_KERN_ACPI_VIDEO_FLAGS" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV6_ROUTE_MIN_ADVMSS" "ac_cv_have_decl_NET_IPV6_ROUTE_MIN_ADVMSS" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_KERN_ACPI_VIDEO_FLAGS" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV6_ROUTE_MIN_ADVMSS" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_KERN_ACPI_VIDEO_FLAGS $ac_have_decl
+#define HAVE_DECL_NET_IPV6_ROUTE_MIN_ADVMSS $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "KERN_IA64_UNALIGNED" "ac_cv_have_decl_KERN_IA64_UNALIGNED" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "NET_IPV6_ROUTE_GC_MIN_INTERVAL_MS" "ac_cv_have_decl_NET_IPV6_ROUTE_GC_MIN_INTERVAL_MS" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_KERN_IA64_UNALIGNED" = xyes; then :
+if test "x$ac_cv_have_decl_NET_IPV6_ROUTE_GC_MIN_INTERVAL_MS" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_KERN_IA64_UNALIGNED $ac_have_decl
+#define HAVE_DECL_NET_IPV6_ROUTE_GC_MIN_INTERVAL_MS $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "KERN_COMPAT_LOG" "ac_cv_have_decl_KERN_COMPAT_LOG" "#include <sys/types.h>
+
+
+ac_fn_c_check_decl "$LINENO" "NET_UNIX_DESTROY_DELAY" "ac_cv_have_decl_NET_UNIX_DESTROY_DELAY" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_KERN_COMPAT_LOG" = xyes; then :
+if test "x$ac_cv_have_decl_NET_UNIX_DESTROY_DELAY" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_KERN_COMPAT_LOG $ac_have_decl
+#define HAVE_DECL_NET_UNIX_DESTROY_DELAY $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "KERN_MAX_LOCK_DEPTH" "ac_cv_have_decl_KERN_MAX_LOCK_DEPTH" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "NET_UNIX_DELETE_DELAY" "ac_cv_have_decl_NET_UNIX_DELETE_DELAY" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_KERN_MAX_LOCK_DEPTH" = xyes; then :
+if test "x$ac_cv_have_decl_NET_UNIX_DELETE_DELAY" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_KERN_MAX_LOCK_DEPTH $ac_have_decl
+#define HAVE_DECL_NET_UNIX_DELETE_DELAY $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "KERN_NMI_WATCHDOG" "ac_cv_have_decl_KERN_NMI_WATCHDOG" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "NET_UNIX_MAX_DGRAM_QLEN" "ac_cv_have_decl_NET_UNIX_MAX_DGRAM_QLEN" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_KERN_NMI_WATCHDOG" = xyes; then :
+if test "x$ac_cv_have_decl_NET_UNIX_MAX_DGRAM_QLEN" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_KERN_NMI_WATCHDOG $ac_have_decl
+#define HAVE_DECL_NET_UNIX_MAX_DGRAM_QLEN $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "KERN_PANIC_ON_NMI" "ac_cv_have_decl_KERN_PANIC_ON_NMI" "#include <sys/types.h>
+
+
+ac_fn_c_check_decl "$LINENO" "CTL_KERN" "ac_cv_have_decl_CTL_KERN" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_KERN_PANIC_ON_NMI" = xyes; then :
+if test "x$ac_cv_have_decl_CTL_KERN" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_KERN_PANIC_ON_NMI $ac_have_decl
+#define HAVE_DECL_CTL_KERN $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "KERN_PANIC_ON_WARN" "ac_cv_have_decl_KERN_PANIC_ON_WARN" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "CTL_VM" "ac_cv_have_decl_CTL_VM" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_KERN_PANIC_ON_WARN" = xyes; then :
+if test "x$ac_cv_have_decl_CTL_VM" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_KERN_PANIC_ON_WARN $ac_have_decl
+#define HAVE_DECL_CTL_VM $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "KERN_PANIC_PRINT" "ac_cv_have_decl_KERN_PANIC_PRINT" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "CTL_NET" "ac_cv_have_decl_CTL_NET" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_KERN_PANIC_PRINT" = xyes; then :
+if test "x$ac_cv_have_decl_CTL_NET" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_KERN_PANIC_PRINT $ac_have_decl
+#define HAVE_DECL_CTL_NET $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_LLC" "ac_cv_have_decl_NET_LLC" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "CTL_FS" "ac_cv_have_decl_CTL_FS" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_LLC" = xyes; then :
+if test "x$ac_cv_have_decl_CTL_FS" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_LLC $ac_have_decl
+#define HAVE_DECL_CTL_FS $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_NETFILTER" "ac_cv_have_decl_NET_NETFILTER" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "CTL_DEBUG" "ac_cv_have_decl_CTL_DEBUG" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_NETFILTER" = xyes; then :
+if test "x$ac_cv_have_decl_CTL_DEBUG" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_NETFILTER $ac_have_decl
+#define HAVE_DECL_CTL_DEBUG $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_DCCP" "ac_cv_have_decl_NET_DCCP" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "CTL_DEV" "ac_cv_have_decl_CTL_DEV" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_DCCP" = xyes; then :
+if test "x$ac_cv_have_decl_CTL_DEV" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_DCCP $ac_have_decl
+#define HAVE_DECL_CTL_DEV $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_IRDA" "ac_cv_have_decl_NET_IRDA" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "CTL_BUS" "ac_cv_have_decl_CTL_BUS" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_IRDA" = xyes; then :
+if test "x$ac_cv_have_decl_CTL_BUS" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_IRDA $ac_have_decl
+#define HAVE_DECL_CTL_BUS $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_CORE_DESTROY_DELAY" "ac_cv_have_decl_NET_CORE_DESTROY_DELAY" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "CTL_ABI" "ac_cv_have_decl_CTL_ABI" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_CORE_DESTROY_DELAY" = xyes; then :
+if test "x$ac_cv_have_decl_CTL_ABI" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_CORE_DESTROY_DELAY $ac_have_decl
+#define HAVE_DECL_CTL_ABI $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_CORE_BUDGET" "ac_cv_have_decl_NET_CORE_BUDGET" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "CTL_CPU" "ac_cv_have_decl_CTL_CPU" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_CORE_BUDGET" = xyes; then :
+if test "x$ac_cv_have_decl_CTL_CPU" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_CORE_BUDGET $ac_have_decl
+#define HAVE_DECL_CTL_CPU $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_CORE_AEVENT_ETIME" "ac_cv_have_decl_NET_CORE_AEVENT_ETIME" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "CTL_PROC" "ac_cv_have_decl_CTL_PROC" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_CORE_AEVENT_ETIME" = xyes; then :
+if test "x$ac_cv_have_decl_CTL_PROC" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_CORE_AEVENT_ETIME $ac_have_decl
+#define HAVE_DECL_CTL_PROC $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_CORE_AEVENT_RSEQTH" "ac_cv_have_decl_NET_CORE_AEVENT_RSEQTH" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "CTL_ARLAN" "ac_cv_have_decl_CTL_ARLAN" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_CORE_AEVENT_RSEQTH" = xyes; then :
+if test "x$ac_cv_have_decl_CTL_ARLAN" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_CORE_AEVENT_RSEQTH $ac_have_decl
+#define HAVE_DECL_CTL_ARLAN $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_CORE_WARNINGS" "ac_cv_have_decl_NET_CORE_WARNINGS" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "CTL_S390DBF" "ac_cv_have_decl_CTL_S390DBF" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_CORE_WARNINGS" = xyes; then :
+if test "x$ac_cv_have_decl_CTL_S390DBF" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_CORE_WARNINGS $ac_have_decl
+#define HAVE_DECL_CTL_S390DBF $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_IPV4_IGMP_MAX_MSF" "ac_cv_have_decl_NET_IPV4_IGMP_MAX_MSF" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "CTL_SUNRPC" "ac_cv_have_decl_CTL_SUNRPC" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_IPV4_IGMP_MAX_MSF" = xyes; then :
+if test "x$ac_cv_have_decl_CTL_SUNRPC" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_IPV4_IGMP_MAX_MSF $ac_have_decl
+#define HAVE_DECL_CTL_SUNRPC $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_TCP_NO_METRICS_SAVE" "ac_cv_have_decl_NET_TCP_NO_METRICS_SAVE" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "CTL_PM" "ac_cv_have_decl_CTL_PM" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_TCP_NO_METRICS_SAVE" = xyes; then :
+if test "x$ac_cv_have_decl_CTL_PM" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_TCP_NO_METRICS_SAVE $ac_have_decl
+#define HAVE_DECL_CTL_PM $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_TCP_DEFAULT_WIN_SCALE" "ac_cv_have_decl_NET_TCP_DEFAULT_WIN_SCALE" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "CTL_FRV" "ac_cv_have_decl_CTL_FRV" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_TCP_DEFAULT_WIN_SCALE" = xyes; then :
+if test "x$ac_cv_have_decl_CTL_FRV" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_TCP_DEFAULT_WIN_SCALE $ac_have_decl
+#define HAVE_DECL_CTL_FRV $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_TCP_MODERATE_RCVBUF" "ac_cv_have_decl_NET_TCP_MODERATE_RCVBUF" "#include <sys/types.h>
+
+
+ac_fn_c_check_decl "$LINENO" "VM_OVERCOMMIT_MEMORY" "ac_cv_have_decl_VM_OVERCOMMIT_MEMORY" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_TCP_MODERATE_RCVBUF" = xyes; then :
+if test "x$ac_cv_have_decl_VM_OVERCOMMIT_MEMORY" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_TCP_MODERATE_RCVBUF $ac_have_decl
+#define HAVE_DECL_VM_OVERCOMMIT_MEMORY $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_TCP_TSO_WIN_DIVISOR" "ac_cv_have_decl_NET_TCP_TSO_WIN_DIVISOR" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "VM_PAGE_CLUSTER" "ac_cv_have_decl_VM_PAGE_CLUSTER" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_TCP_TSO_WIN_DIVISOR" = xyes; then :
+if test "x$ac_cv_have_decl_VM_PAGE_CLUSTER" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_TCP_TSO_WIN_DIVISOR $ac_have_decl
+#define HAVE_DECL_VM_PAGE_CLUSTER $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_TCP_BIC_BETA" "ac_cv_have_decl_NET_TCP_BIC_BETA" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "VM_DIRTY_BACKGROUND" "ac_cv_have_decl_VM_DIRTY_BACKGROUND" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_TCP_BIC_BETA" = xyes; then :
+if test "x$ac_cv_have_decl_VM_DIRTY_BACKGROUND" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_TCP_BIC_BETA $ac_have_decl
+#define HAVE_DECL_VM_DIRTY_BACKGROUND $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_IPV4_ICMP_ERRORS_USE_INBOUND_IFADDR" "ac_cv_have_decl_NET_IPV4_ICMP_ERRORS_USE_INBOUND_IFADDR" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "VM_DIRTY_RATIO" "ac_cv_have_decl_VM_DIRTY_RATIO" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_IPV4_ICMP_ERRORS_USE_INBOUND_IFADDR" = xyes; then :
+if test "x$ac_cv_have_decl_VM_DIRTY_RATIO" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_IPV4_ICMP_ERRORS_USE_INBOUND_IFADDR $ac_have_decl
+#define HAVE_DECL_VM_DIRTY_RATIO $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_TCP_CONG_CONTROL" "ac_cv_have_decl_NET_TCP_CONG_CONTROL" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "VM_DIRTY_WB_CS" "ac_cv_have_decl_VM_DIRTY_WB_CS" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_TCP_CONG_CONTROL" = xyes; then :
+if test "x$ac_cv_have_decl_VM_DIRTY_WB_CS" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_TCP_CONG_CONTROL $ac_have_decl
+#define HAVE_DECL_VM_DIRTY_WB_CS $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_TCP_ABC" "ac_cv_have_decl_NET_TCP_ABC" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "VM_DIRTY_EXPIRE_CS" "ac_cv_have_decl_VM_DIRTY_EXPIRE_CS" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_TCP_ABC" = xyes; then :
+if test "x$ac_cv_have_decl_VM_DIRTY_EXPIRE_CS" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_TCP_ABC $ac_have_decl
+#define HAVE_DECL_VM_DIRTY_EXPIRE_CS $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_IPV4_IPFRAG_MAX_DIST" "ac_cv_have_decl_NET_IPV4_IPFRAG_MAX_DIST" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "VM_NR_PDFLUSH_THREADS" "ac_cv_have_decl_VM_NR_PDFLUSH_THREADS" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_IPV4_IPFRAG_MAX_DIST" = xyes; then :
+if test "x$ac_cv_have_decl_VM_NR_PDFLUSH_THREADS" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_IPV4_IPFRAG_MAX_DIST $ac_have_decl
+#define HAVE_DECL_VM_NR_PDFLUSH_THREADS $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_TCP_MTU_PROBING" "ac_cv_have_decl_NET_TCP_MTU_PROBING" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "VM_OVERCOMMIT_RATIO" "ac_cv_have_decl_VM_OVERCOMMIT_RATIO" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_TCP_MTU_PROBING" = xyes; then :
+if test "x$ac_cv_have_decl_VM_OVERCOMMIT_RATIO" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_TCP_MTU_PROBING $ac_have_decl
+#define HAVE_DECL_VM_OVERCOMMIT_RATIO $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_TCP_BASE_MSS" "ac_cv_have_decl_NET_TCP_BASE_MSS" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "VM_PAGEBUF" "ac_cv_have_decl_VM_PAGEBUF" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_TCP_BASE_MSS" = xyes; then :
+if test "x$ac_cv_have_decl_VM_PAGEBUF" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_TCP_BASE_MSS $ac_have_decl
+#define HAVE_DECL_VM_PAGEBUF $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_IPV4_TCP_WORKAROUND_SIGNED_WINDOWS" "ac_cv_have_decl_NET_IPV4_TCP_WORKAROUND_SIGNED_WINDOWS" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "VM_HUGETLB_PAGES" "ac_cv_have_decl_VM_HUGETLB_PAGES" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_IPV4_TCP_WORKAROUND_SIGNED_WINDOWS" = xyes; then :
+if test "x$ac_cv_have_decl_VM_HUGETLB_PAGES" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_IPV4_TCP_WORKAROUND_SIGNED_WINDOWS $ac_have_decl
+#define HAVE_DECL_VM_HUGETLB_PAGES $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_TCP_DMA_COPYBREAK" "ac_cv_have_decl_NET_TCP_DMA_COPYBREAK" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "VM_SWAPPINESS" "ac_cv_have_decl_VM_SWAPPINESS" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_TCP_DMA_COPYBREAK" = xyes; then :
+if test "x$ac_cv_have_decl_VM_SWAPPINESS" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_TCP_DMA_COPYBREAK $ac_have_decl
+#define HAVE_DECL_VM_SWAPPINESS $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_TCP_SLOW_START_AFTER_IDLE" "ac_cv_have_decl_NET_TCP_SLOW_START_AFTER_IDLE" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "VM_LOWMEM_RESERVE_RATIO" "ac_cv_have_decl_VM_LOWMEM_RESERVE_RATIO" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_TCP_SLOW_START_AFTER_IDLE" = xyes; then :
+if test "x$ac_cv_have_decl_VM_LOWMEM_RESERVE_RATIO" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_TCP_SLOW_START_AFTER_IDLE $ac_have_decl
+#define HAVE_DECL_VM_LOWMEM_RESERVE_RATIO $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_CIPSOV4_CACHE_ENABLE" "ac_cv_have_decl_NET_CIPSOV4_CACHE_ENABLE" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "VM_MIN_FREE_KBYTES" "ac_cv_have_decl_VM_MIN_FREE_KBYTES" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_CIPSOV4_CACHE_ENABLE" = xyes; then :
+if test "x$ac_cv_have_decl_VM_MIN_FREE_KBYTES" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_CIPSOV4_CACHE_ENABLE $ac_have_decl
+#define HAVE_DECL_VM_MIN_FREE_KBYTES $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_CIPSOV4_CACHE_BUCKET_SIZE" "ac_cv_have_decl_NET_CIPSOV4_CACHE_BUCKET_SIZE" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "VM_MAX_MAP_COUNT" "ac_cv_have_decl_VM_MAX_MAP_COUNT" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_CIPSOV4_CACHE_BUCKET_SIZE" = xyes; then :
+if test "x$ac_cv_have_decl_VM_MAX_MAP_COUNT" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_CIPSOV4_CACHE_BUCKET_SIZE $ac_have_decl
+#define HAVE_DECL_VM_MAX_MAP_COUNT $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_CIPSOV4_RBM_OPTFMT" "ac_cv_have_decl_NET_CIPSOV4_RBM_OPTFMT" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "VM_LAPTOP_MODE" "ac_cv_have_decl_VM_LAPTOP_MODE" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_CIPSOV4_RBM_OPTFMT" = xyes; then :
+if test "x$ac_cv_have_decl_VM_LAPTOP_MODE" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_CIPSOV4_RBM_OPTFMT $ac_have_decl
+#define HAVE_DECL_VM_LAPTOP_MODE $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_CIPSOV4_RBM_STRICTVALID" "ac_cv_have_decl_NET_CIPSOV4_RBM_STRICTVALID" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "VM_BLOCK_DUMP" "ac_cv_have_decl_VM_BLOCK_DUMP" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_CIPSOV4_RBM_STRICTVALID" = xyes; then :
+if test "x$ac_cv_have_decl_VM_BLOCK_DUMP" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_CIPSOV4_RBM_STRICTVALID $ac_have_decl
+#define HAVE_DECL_VM_BLOCK_DUMP $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_TCP_AVAIL_CONG_CONTROL" "ac_cv_have_decl_NET_TCP_AVAIL_CONG_CONTROL" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "VM_HUGETLB_GROUP" "ac_cv_have_decl_VM_HUGETLB_GROUP" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_TCP_AVAIL_CONG_CONTROL" = xyes; then :
+if test "x$ac_cv_have_decl_VM_HUGETLB_GROUP" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_TCP_AVAIL_CONG_CONTROL $ac_have_decl
+#define HAVE_DECL_VM_HUGETLB_GROUP $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_TCP_ALLOWED_CONG_CONTROL" "ac_cv_have_decl_NET_TCP_ALLOWED_CONG_CONTROL" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "VM_VFS_CACHE_PRESSURE" "ac_cv_have_decl_VM_VFS_CACHE_PRESSURE" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_TCP_ALLOWED_CONG_CONTROL" = xyes; then :
+if test "x$ac_cv_have_decl_VM_VFS_CACHE_PRESSURE" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_TCP_ALLOWED_CONG_CONTROL $ac_have_decl
+#define HAVE_DECL_VM_VFS_CACHE_PRESSURE $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_TCP_MAX_SSTHRESH" "ac_cv_have_decl_NET_TCP_MAX_SSTHRESH" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "VM_LEGACY_VA_LAYOUT" "ac_cv_have_decl_VM_LEGACY_VA_LAYOUT" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_TCP_MAX_SSTHRESH" = xyes; then :
+if test "x$ac_cv_have_decl_VM_LEGACY_VA_LAYOUT" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_TCP_MAX_SSTHRESH $ac_have_decl
+#define HAVE_DECL_VM_LEGACY_VA_LAYOUT $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_TCP_FRTO_RESPONSE" "ac_cv_have_decl_NET_TCP_FRTO_RESPONSE" "#include <sys/types.h>
+ac_fn_c_check_decl "$LINENO" "VM_SWAP_TOKEN_TIMEOUT" "ac_cv_have_decl_VM_SWAP_TOKEN_TIMEOUT" "
+#include <sys/types.h>
 #include <linux/sysctl.h>
+
 "
-if test "x$ac_cv_have_decl_NET_TCP_FRTO_RESPONSE" = xyes; then :
+if test "x$ac_cv_have_decl_VM_SWAP_TOKEN_TIMEOUT" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_TCP_FRTO_RESPONSE $ac_have_decl
+#define HAVE_DECL_VM_SWAP_TOKEN_TIMEOUT $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_IPV4_ROUTE_GC_MIN_INTERVAL_MS" "ac_cv_have_decl_NET_IPV4_ROUTE_GC_MIN_INTERVAL_MS" "#include <sys/types.h>
-#include <linux/sysctl.h>
+
+
+ac_fn_c_check_decl "$LINENO" "V4L2_BUF_TYPE_VIDEO_CAPTURE" "ac_cv_have_decl_V4L2_BUF_TYPE_VIDEO_CAPTURE" "
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_NET_IPV4_ROUTE_GC_MIN_INTERVAL_MS" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_BUF_TYPE_VIDEO_CAPTURE" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_IPV4_ROUTE_GC_MIN_INTERVAL_MS $ac_have_decl
+#define HAVE_DECL_V4L2_BUF_TYPE_VIDEO_CAPTURE $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_FORCE_IGMP_VERSION" "ac_cv_have_decl_NET_IPV4_CONF_FORCE_IGMP_VERSION" "#include <sys/types.h>
-#include <linux/sysctl.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_BUF_TYPE_VIDEO_OUTPUT" "ac_cv_have_decl_V4L2_BUF_TYPE_VIDEO_OUTPUT" "
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_NET_IPV4_CONF_FORCE_IGMP_VERSION" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_BUF_TYPE_VIDEO_OUTPUT" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_IPV4_CONF_FORCE_IGMP_VERSION $ac_have_decl
+#define HAVE_DECL_V4L2_BUF_TYPE_VIDEO_OUTPUT $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_ARP_ANNOUNCE" "ac_cv_have_decl_NET_IPV4_CONF_ARP_ANNOUNCE" "#include <sys/types.h>
-#include <linux/sysctl.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_BUF_TYPE_VIDEO_OVERLAY" "ac_cv_have_decl_V4L2_BUF_TYPE_VIDEO_OVERLAY" "
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_NET_IPV4_CONF_ARP_ANNOUNCE" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_BUF_TYPE_VIDEO_OVERLAY" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_IPV4_CONF_ARP_ANNOUNCE $ac_have_decl
+#define HAVE_DECL_V4L2_BUF_TYPE_VIDEO_OVERLAY $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_ARP_IGNORE" "ac_cv_have_decl_NET_IPV4_CONF_ARP_IGNORE" "#include <sys/types.h>
-#include <linux/sysctl.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_BUF_TYPE_VBI_CAPTURE" "ac_cv_have_decl_V4L2_BUF_TYPE_VBI_CAPTURE" "
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_NET_IPV4_CONF_ARP_IGNORE" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_BUF_TYPE_VBI_CAPTURE" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_IPV4_CONF_ARP_IGNORE $ac_have_decl
+#define HAVE_DECL_V4L2_BUF_TYPE_VBI_CAPTURE $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_PROMOTE_SECONDARIES" "ac_cv_have_decl_NET_IPV4_CONF_PROMOTE_SECONDARIES" "#include <sys/types.h>
-#include <linux/sysctl.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_BUF_TYPE_VBI_OUTPUT" "ac_cv_have_decl_V4L2_BUF_TYPE_VBI_OUTPUT" "
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_NET_IPV4_CONF_PROMOTE_SECONDARIES" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_BUF_TYPE_VBI_OUTPUT" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_IPV4_CONF_PROMOTE_SECONDARIES $ac_have_decl
+#define HAVE_DECL_V4L2_BUF_TYPE_VBI_OUTPUT $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_ARP_ACCEPT" "ac_cv_have_decl_NET_IPV4_CONF_ARP_ACCEPT" "#include <sys/types.h>
-#include <linux/sysctl.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_BUF_TYPE_SLICED_VBI_CAPTURE" "ac_cv_have_decl_V4L2_BUF_TYPE_SLICED_VBI_CAPTURE" "
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_NET_IPV4_CONF_ARP_ACCEPT" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_BUF_TYPE_SLICED_VBI_CAPTURE" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_IPV4_CONF_ARP_ACCEPT $ac_have_decl
+#define HAVE_DECL_V4L2_BUF_TYPE_SLICED_VBI_CAPTURE $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_IPV4_CONF_ARP_NOTIFY" "ac_cv_have_decl_NET_IPV4_CONF_ARP_NOTIFY" "#include <sys/types.h>
-#include <linux/sysctl.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_BUF_TYPE_SLICED_VBI_OUTPUT" "ac_cv_have_decl_V4L2_BUF_TYPE_SLICED_VBI_OUTPUT" "
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_NET_IPV4_CONF_ARP_NOTIFY" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_BUF_TYPE_SLICED_VBI_OUTPUT" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_IPV4_CONF_ARP_NOTIFY $ac_have_decl
+#define HAVE_DECL_V4L2_BUF_TYPE_SLICED_VBI_OUTPUT $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_IPV6_MLD_MAX_MSF" "ac_cv_have_decl_NET_IPV6_MLD_MAX_MSF" "#include <sys/types.h>
-#include <linux/sysctl.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY" "ac_cv_have_decl_V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY" "
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_NET_IPV6_MLD_MAX_MSF" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_IPV6_MLD_MAX_MSF $ac_have_decl
+#define HAVE_DECL_V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "NET_IPV6_ROUTE_GC_MIN_INTERVAL_MS" "ac_cv_have_decl_NET_IPV6_ROUTE_GC_MIN_INTERVAL_MS" "#include <sys/types.h>
-#include <linux/sysctl.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE" "ac_cv_have_decl_V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE" "
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_NET_IPV6_ROUTE_GC_MIN_INTERVAL_MS" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_NET_IPV6_ROUTE_GC_MIN_INTERVAL_MS $ac_have_decl
+#define HAVE_DECL_V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "VM_MAX_MAP_COUNT" "ac_cv_have_decl_VM_MAX_MAP_COUNT" "#include <sys/types.h>
-#include <linux/sysctl.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE" "ac_cv_have_decl_V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE" "
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_VM_MAX_MAP_COUNT" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_VM_MAX_MAP_COUNT $ac_have_decl
+#define HAVE_DECL_V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "VM_LAPTOP_MODE" "ac_cv_have_decl_VM_LAPTOP_MODE" "#include <sys/types.h>
-#include <linux/sysctl.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_BUF_TYPE_SDR_CAPTURE" "ac_cv_have_decl_V4L2_BUF_TYPE_SDR_CAPTURE" "
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_VM_LAPTOP_MODE" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_BUF_TYPE_SDR_CAPTURE" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_VM_LAPTOP_MODE $ac_have_decl
+#define HAVE_DECL_V4L2_BUF_TYPE_SDR_CAPTURE $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "VM_BLOCK_DUMP" "ac_cv_have_decl_VM_BLOCK_DUMP" "#include <sys/types.h>
-#include <linux/sysctl.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_BUF_TYPE_SDR_OUTPUT" "ac_cv_have_decl_V4L2_BUF_TYPE_SDR_OUTPUT" "
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_VM_BLOCK_DUMP" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_BUF_TYPE_SDR_OUTPUT" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_VM_BLOCK_DUMP $ac_have_decl
+#define HAVE_DECL_V4L2_BUF_TYPE_SDR_OUTPUT $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "VM_HUGETLB_GROUP" "ac_cv_have_decl_VM_HUGETLB_GROUP" "#include <sys/types.h>
-#include <linux/sysctl.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_BUF_TYPE_META_CAPTURE" "ac_cv_have_decl_V4L2_BUF_TYPE_META_CAPTURE" "
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_VM_HUGETLB_GROUP" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_BUF_TYPE_META_CAPTURE" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_VM_HUGETLB_GROUP $ac_have_decl
+#define HAVE_DECL_V4L2_BUF_TYPE_META_CAPTURE $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "VM_VFS_CACHE_PRESSURE" "ac_cv_have_decl_VM_VFS_CACHE_PRESSURE" "#include <sys/types.h>
-#include <linux/sysctl.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_BUF_TYPE_META_OUTPUT" "ac_cv_have_decl_V4L2_BUF_TYPE_META_OUTPUT" "
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_VM_VFS_CACHE_PRESSURE" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_BUF_TYPE_META_OUTPUT" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_VM_VFS_CACHE_PRESSURE $ac_have_decl
+#define HAVE_DECL_V4L2_BUF_TYPE_META_OUTPUT $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "VM_LEGACY_VA_LAYOUT" "ac_cv_have_decl_VM_LEGACY_VA_LAYOUT" "#include <sys/types.h>
-#include <linux/sysctl.h>
+
+
+ac_fn_c_check_decl "$LINENO" "V4L2_COLORSPACE_DEFAULT" "ac_cv_have_decl_V4L2_COLORSPACE_DEFAULT" "
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_VM_LEGACY_VA_LAYOUT" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_COLORSPACE_DEFAULT" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_VM_LEGACY_VA_LAYOUT $ac_have_decl
+#define HAVE_DECL_V4L2_COLORSPACE_DEFAULT $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "VM_SWAP_TOKEN_TIMEOUT" "ac_cv_have_decl_VM_SWAP_TOKEN_TIMEOUT" "#include <sys/types.h>
-#include <linux/sysctl.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_COLORSPACE_SMPTE170M" "ac_cv_have_decl_V4L2_COLORSPACE_SMPTE170M" "
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_VM_SWAP_TOKEN_TIMEOUT" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_COLORSPACE_SMPTE170M" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_VM_SWAP_TOKEN_TIMEOUT $ac_have_decl
+#define HAVE_DECL_V4L2_COLORSPACE_SMPTE170M $ac_have_decl
 _ACEOF
-
-
-ac_fn_c_check_decl "$LINENO" "V4L2_FIELD_ANY" "ac_cv_have_decl_V4L2_FIELD_ANY" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_COLORSPACE_SMPTE240M" "ac_cv_have_decl_V4L2_COLORSPACE_SMPTE240M" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_FIELD_ANY" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_COLORSPACE_SMPTE240M" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_FIELD_ANY $ac_have_decl
+#define HAVE_DECL_V4L2_COLORSPACE_SMPTE240M $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_FIELD_NONE" "ac_cv_have_decl_V4L2_FIELD_NONE" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_COLORSPACE_REC709" "ac_cv_have_decl_V4L2_COLORSPACE_REC709" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_FIELD_NONE" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_COLORSPACE_REC709" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_FIELD_NONE $ac_have_decl
+#define HAVE_DECL_V4L2_COLORSPACE_REC709 $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_FIELD_TOP" "ac_cv_have_decl_V4L2_FIELD_TOP" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_COLORSPACE_BT878" "ac_cv_have_decl_V4L2_COLORSPACE_BT878" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_FIELD_TOP" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_COLORSPACE_BT878" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_FIELD_TOP $ac_have_decl
+#define HAVE_DECL_V4L2_COLORSPACE_BT878 $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_FIELD_BOTTOM" "ac_cv_have_decl_V4L2_FIELD_BOTTOM" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_COLORSPACE_470_SYSTEM_M" "ac_cv_have_decl_V4L2_COLORSPACE_470_SYSTEM_M" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_FIELD_BOTTOM" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_COLORSPACE_470_SYSTEM_M" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_FIELD_BOTTOM $ac_have_decl
+#define HAVE_DECL_V4L2_COLORSPACE_470_SYSTEM_M $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_FIELD_INTERLACED" "ac_cv_have_decl_V4L2_FIELD_INTERLACED" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_COLORSPACE_470_SYSTEM_BG" "ac_cv_have_decl_V4L2_COLORSPACE_470_SYSTEM_BG" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_FIELD_INTERLACED" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_COLORSPACE_470_SYSTEM_BG" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_FIELD_INTERLACED $ac_have_decl
+#define HAVE_DECL_V4L2_COLORSPACE_470_SYSTEM_BG $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_FIELD_SEQ_TB" "ac_cv_have_decl_V4L2_FIELD_SEQ_TB" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_COLORSPACE_JPEG" "ac_cv_have_decl_V4L2_COLORSPACE_JPEG" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_FIELD_SEQ_TB" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_COLORSPACE_JPEG" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_FIELD_SEQ_TB $ac_have_decl
+#define HAVE_DECL_V4L2_COLORSPACE_JPEG $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_FIELD_SEQ_BT" "ac_cv_have_decl_V4L2_FIELD_SEQ_BT" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_COLORSPACE_SRGB" "ac_cv_have_decl_V4L2_COLORSPACE_SRGB" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_FIELD_SEQ_BT" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_COLORSPACE_SRGB" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_FIELD_SEQ_BT $ac_have_decl
+#define HAVE_DECL_V4L2_COLORSPACE_SRGB $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_FIELD_ALTERNATE" "ac_cv_have_decl_V4L2_FIELD_ALTERNATE" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_COLORSPACE_OPRGB" "ac_cv_have_decl_V4L2_COLORSPACE_OPRGB" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_FIELD_ALTERNATE" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_COLORSPACE_OPRGB" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_FIELD_ALTERNATE $ac_have_decl
+#define HAVE_DECL_V4L2_COLORSPACE_OPRGB $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_FIELD_INTERLACED_TB" "ac_cv_have_decl_V4L2_FIELD_INTERLACED_TB" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_COLORSPACE_BT2020" "ac_cv_have_decl_V4L2_COLORSPACE_BT2020" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_FIELD_INTERLACED_TB" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_COLORSPACE_BT2020" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_FIELD_INTERLACED_TB $ac_have_decl
+#define HAVE_DECL_V4L2_COLORSPACE_BT2020 $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_FIELD_INTERLACED_BT" "ac_cv_have_decl_V4L2_FIELD_INTERLACED_BT" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_COLORSPACE_RAW" "ac_cv_have_decl_V4L2_COLORSPACE_RAW" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_FIELD_INTERLACED_BT" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_COLORSPACE_RAW" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_FIELD_INTERLACED_BT $ac_have_decl
+#define HAVE_DECL_V4L2_COLORSPACE_RAW $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_BUF_TYPE_VIDEO_CAPTURE" "ac_cv_have_decl_V4L2_BUF_TYPE_VIDEO_CAPTURE" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_COLORSPACE_DCI_P3" "ac_cv_have_decl_V4L2_COLORSPACE_DCI_P3" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_BUF_TYPE_VIDEO_CAPTURE" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_COLORSPACE_DCI_P3" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_BUF_TYPE_VIDEO_CAPTURE $ac_have_decl
+#define HAVE_DECL_V4L2_COLORSPACE_DCI_P3 $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE" "ac_cv_have_decl_V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE" "#include <sys/time.h>
+
+
+ac_fn_c_check_decl "$LINENO" "V4L2_CTRL_TYPE_INTEGER" "ac_cv_have_decl_V4L2_CTRL_TYPE_INTEGER" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_CTRL_TYPE_INTEGER" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE $ac_have_decl
+#define HAVE_DECL_V4L2_CTRL_TYPE_INTEGER $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_BUF_TYPE_VIDEO_OUTPUT" "ac_cv_have_decl_V4L2_BUF_TYPE_VIDEO_OUTPUT" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_CTRL_TYPE_BOOLEAN" "ac_cv_have_decl_V4L2_CTRL_TYPE_BOOLEAN" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_BUF_TYPE_VIDEO_OUTPUT" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_CTRL_TYPE_BOOLEAN" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_BUF_TYPE_VIDEO_OUTPUT $ac_have_decl
+#define HAVE_DECL_V4L2_CTRL_TYPE_BOOLEAN $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE" "ac_cv_have_decl_V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_CTRL_TYPE_MENU" "ac_cv_have_decl_V4L2_CTRL_TYPE_MENU" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_CTRL_TYPE_MENU" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE $ac_have_decl
+#define HAVE_DECL_V4L2_CTRL_TYPE_MENU $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_BUF_TYPE_VIDEO_OVERLAY" "ac_cv_have_decl_V4L2_BUF_TYPE_VIDEO_OVERLAY" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_CTRL_TYPE_BUTTON" "ac_cv_have_decl_V4L2_CTRL_TYPE_BUTTON" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_BUF_TYPE_VIDEO_OVERLAY" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_CTRL_TYPE_BUTTON" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_BUF_TYPE_VIDEO_OVERLAY $ac_have_decl
+#define HAVE_DECL_V4L2_CTRL_TYPE_BUTTON $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_BUF_TYPE_VBI_CAPTURE" "ac_cv_have_decl_V4L2_BUF_TYPE_VBI_CAPTURE" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_CTRL_TYPE_INTEGER64" "ac_cv_have_decl_V4L2_CTRL_TYPE_INTEGER64" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_BUF_TYPE_VBI_CAPTURE" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_CTRL_TYPE_INTEGER64" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_BUF_TYPE_VBI_CAPTURE $ac_have_decl
+#define HAVE_DECL_V4L2_CTRL_TYPE_INTEGER64 $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_BUF_TYPE_VBI_OUTPUT" "ac_cv_have_decl_V4L2_BUF_TYPE_VBI_OUTPUT" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_CTRL_TYPE_CTRL_CLASS" "ac_cv_have_decl_V4L2_CTRL_TYPE_CTRL_CLASS" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_BUF_TYPE_VBI_OUTPUT" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_CTRL_TYPE_CTRL_CLASS" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_BUF_TYPE_VBI_OUTPUT $ac_have_decl
+#define HAVE_DECL_V4L2_CTRL_TYPE_CTRL_CLASS $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_BUF_TYPE_SLICED_VBI_CAPTURE" "ac_cv_have_decl_V4L2_BUF_TYPE_SLICED_VBI_CAPTURE" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_CTRL_TYPE_STRING" "ac_cv_have_decl_V4L2_CTRL_TYPE_STRING" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_BUF_TYPE_SLICED_VBI_CAPTURE" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_CTRL_TYPE_STRING" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_BUF_TYPE_SLICED_VBI_CAPTURE $ac_have_decl
+#define HAVE_DECL_V4L2_CTRL_TYPE_STRING $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_BUF_TYPE_SLICED_VBI_OUTPUT" "ac_cv_have_decl_V4L2_BUF_TYPE_SLICED_VBI_OUTPUT" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_CTRL_TYPE_BITMASK" "ac_cv_have_decl_V4L2_CTRL_TYPE_BITMASK" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_BUF_TYPE_SLICED_VBI_OUTPUT" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_CTRL_TYPE_BITMASK" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_BUF_TYPE_SLICED_VBI_OUTPUT $ac_have_decl
+#define HAVE_DECL_V4L2_CTRL_TYPE_BITMASK $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY" "ac_cv_have_decl_V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_CTRL_TYPE_INTEGER_MENU" "ac_cv_have_decl_V4L2_CTRL_TYPE_INTEGER_MENU" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_CTRL_TYPE_INTEGER_MENU" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY $ac_have_decl
+#define HAVE_DECL_V4L2_CTRL_TYPE_INTEGER_MENU $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_BUF_TYPE_SDR_CAPTURE" "ac_cv_have_decl_V4L2_BUF_TYPE_SDR_CAPTURE" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_CTRL_TYPE_U8" "ac_cv_have_decl_V4L2_CTRL_TYPE_U8" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_BUF_TYPE_SDR_CAPTURE" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_CTRL_TYPE_U8" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_BUF_TYPE_SDR_CAPTURE $ac_have_decl
+#define HAVE_DECL_V4L2_CTRL_TYPE_U8 $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_BUF_TYPE_SDR_OUTPUT" "ac_cv_have_decl_V4L2_BUF_TYPE_SDR_OUTPUT" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_CTRL_TYPE_U16" "ac_cv_have_decl_V4L2_CTRL_TYPE_U16" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_BUF_TYPE_SDR_OUTPUT" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_CTRL_TYPE_U16" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_BUF_TYPE_SDR_OUTPUT $ac_have_decl
+#define HAVE_DECL_V4L2_CTRL_TYPE_U16 $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_TUNER_RADIO" "ac_cv_have_decl_V4L2_TUNER_RADIO" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_CTRL_TYPE_U32" "ac_cv_have_decl_V4L2_CTRL_TYPE_U32" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_TUNER_RADIO" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_CTRL_TYPE_U32" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_TUNER_RADIO $ac_have_decl
+#define HAVE_DECL_V4L2_CTRL_TYPE_U32 $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_TUNER_ANALOG_TV" "ac_cv_have_decl_V4L2_TUNER_ANALOG_TV" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_CTRL_TYPE_AREA" "ac_cv_have_decl_V4L2_CTRL_TYPE_AREA" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_TUNER_ANALOG_TV" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_CTRL_TYPE_AREA" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_TUNER_ANALOG_TV $ac_have_decl
+#define HAVE_DECL_V4L2_CTRL_TYPE_AREA $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_TUNER_DIGITAL_TV" "ac_cv_have_decl_V4L2_TUNER_DIGITAL_TV" "#include <sys/time.h>
+
+
+ac_fn_c_check_decl "$LINENO" "V4L2_FIELD_ANY" "ac_cv_have_decl_V4L2_FIELD_ANY" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_TUNER_DIGITAL_TV" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_FIELD_ANY" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_TUNER_DIGITAL_TV $ac_have_decl
+#define HAVE_DECL_V4L2_FIELD_ANY $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_MEMORY_MMAP" "ac_cv_have_decl_V4L2_MEMORY_MMAP" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_FIELD_NONE" "ac_cv_have_decl_V4L2_FIELD_NONE" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_MEMORY_MMAP" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_FIELD_NONE" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_MEMORY_MMAP $ac_have_decl
+#define HAVE_DECL_V4L2_FIELD_NONE $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_MEMORY_USERPTR" "ac_cv_have_decl_V4L2_MEMORY_USERPTR" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_FIELD_TOP" "ac_cv_have_decl_V4L2_FIELD_TOP" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_MEMORY_USERPTR" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_FIELD_TOP" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_MEMORY_USERPTR $ac_have_decl
+#define HAVE_DECL_V4L2_FIELD_TOP $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_MEMORY_OVERLAY" "ac_cv_have_decl_V4L2_MEMORY_OVERLAY" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_FIELD_BOTTOM" "ac_cv_have_decl_V4L2_FIELD_BOTTOM" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_MEMORY_OVERLAY" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_FIELD_BOTTOM" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_MEMORY_OVERLAY $ac_have_decl
+#define HAVE_DECL_V4L2_FIELD_BOTTOM $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_MEMORY_DMABUF" "ac_cv_have_decl_V4L2_MEMORY_DMABUF" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_FIELD_INTERLACED" "ac_cv_have_decl_V4L2_FIELD_INTERLACED" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_MEMORY_DMABUF" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_FIELD_INTERLACED" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_MEMORY_DMABUF $ac_have_decl
+#define HAVE_DECL_V4L2_FIELD_INTERLACED $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_COLORSPACE_SMPTE170M" "ac_cv_have_decl_V4L2_COLORSPACE_SMPTE170M" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_FIELD_SEQ_TB" "ac_cv_have_decl_V4L2_FIELD_SEQ_TB" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_COLORSPACE_SMPTE170M" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_FIELD_SEQ_TB" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_COLORSPACE_SMPTE170M $ac_have_decl
+#define HAVE_DECL_V4L2_FIELD_SEQ_TB $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_COLORSPACE_SMPTE240M" "ac_cv_have_decl_V4L2_COLORSPACE_SMPTE240M" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_FIELD_SEQ_BT" "ac_cv_have_decl_V4L2_FIELD_SEQ_BT" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_COLORSPACE_SMPTE240M" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_FIELD_SEQ_BT" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_COLORSPACE_SMPTE240M $ac_have_decl
+#define HAVE_DECL_V4L2_FIELD_SEQ_BT $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_COLORSPACE_REC709" "ac_cv_have_decl_V4L2_COLORSPACE_REC709" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_FIELD_ALTERNATE" "ac_cv_have_decl_V4L2_FIELD_ALTERNATE" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_COLORSPACE_REC709" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_FIELD_ALTERNATE" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_COLORSPACE_REC709 $ac_have_decl
+#define HAVE_DECL_V4L2_FIELD_ALTERNATE $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_COLORSPACE_BT878" "ac_cv_have_decl_V4L2_COLORSPACE_BT878" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_FIELD_INTERLACED_TB" "ac_cv_have_decl_V4L2_FIELD_INTERLACED_TB" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_COLORSPACE_BT878" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_FIELD_INTERLACED_TB" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_COLORSPACE_BT878 $ac_have_decl
+#define HAVE_DECL_V4L2_FIELD_INTERLACED_TB $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_COLORSPACE_470_SYSTEM_M" "ac_cv_have_decl_V4L2_COLORSPACE_470_SYSTEM_M" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_FIELD_INTERLACED_BT" "ac_cv_have_decl_V4L2_FIELD_INTERLACED_BT" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_COLORSPACE_470_SYSTEM_M" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_FIELD_INTERLACED_BT" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_COLORSPACE_470_SYSTEM_M $ac_have_decl
+#define HAVE_DECL_V4L2_FIELD_INTERLACED_BT $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_COLORSPACE_470_SYSTEM_BG" "ac_cv_have_decl_V4L2_COLORSPACE_470_SYSTEM_BG" "#include <sys/time.h>
+
+
+ac_fn_c_check_decl "$LINENO" "V4L2_FRMSIZE_TYPE_DISCRETE" "ac_cv_have_decl_V4L2_FRMSIZE_TYPE_DISCRETE" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_COLORSPACE_470_SYSTEM_BG" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_FRMSIZE_TYPE_DISCRETE" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_COLORSPACE_470_SYSTEM_BG $ac_have_decl
+#define HAVE_DECL_V4L2_FRMSIZE_TYPE_DISCRETE $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_COLORSPACE_JPEG" "ac_cv_have_decl_V4L2_COLORSPACE_JPEG" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_FRMSIZE_TYPE_CONTINUOUS" "ac_cv_have_decl_V4L2_FRMSIZE_TYPE_CONTINUOUS" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_COLORSPACE_JPEG" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_FRMSIZE_TYPE_CONTINUOUS" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_COLORSPACE_JPEG $ac_have_decl
+#define HAVE_DECL_V4L2_FRMSIZE_TYPE_CONTINUOUS $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_COLORSPACE_SRGB" "ac_cv_have_decl_V4L2_COLORSPACE_SRGB" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_FRMSIZE_TYPE_STEPWISE" "ac_cv_have_decl_V4L2_FRMSIZE_TYPE_STEPWISE" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_COLORSPACE_SRGB" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_FRMSIZE_TYPE_STEPWISE" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_COLORSPACE_SRGB $ac_have_decl
+#define HAVE_DECL_V4L2_FRMSIZE_TYPE_STEPWISE $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_PRIORITY_UNSET" "ac_cv_have_decl_V4L2_PRIORITY_UNSET" "#include <sys/time.h>
+
+
+ac_fn_c_check_decl "$LINENO" "V4L2_MEMORY_MMAP" "ac_cv_have_decl_V4L2_MEMORY_MMAP" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_PRIORITY_UNSET" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_MEMORY_MMAP" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_PRIORITY_UNSET $ac_have_decl
+#define HAVE_DECL_V4L2_MEMORY_MMAP $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_PRIORITY_BACKGROUND" "ac_cv_have_decl_V4L2_PRIORITY_BACKGROUND" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_MEMORY_USERPTR" "ac_cv_have_decl_V4L2_MEMORY_USERPTR" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_PRIORITY_BACKGROUND" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_MEMORY_USERPTR" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_PRIORITY_BACKGROUND $ac_have_decl
+#define HAVE_DECL_V4L2_MEMORY_USERPTR $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_PRIORITY_INTERACTIVE" "ac_cv_have_decl_V4L2_PRIORITY_INTERACTIVE" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_MEMORY_OVERLAY" "ac_cv_have_decl_V4L2_MEMORY_OVERLAY" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_PRIORITY_INTERACTIVE" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_MEMORY_OVERLAY" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_PRIORITY_INTERACTIVE $ac_have_decl
+#define HAVE_DECL_V4L2_MEMORY_OVERLAY $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_PRIORITY_RECORD" "ac_cv_have_decl_V4L2_PRIORITY_RECORD" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_MEMORY_DMABUF" "ac_cv_have_decl_V4L2_MEMORY_DMABUF" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_PRIORITY_RECORD" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_MEMORY_DMABUF" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_PRIORITY_RECORD $ac_have_decl
+#define HAVE_DECL_V4L2_MEMORY_DMABUF $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_FRMSIZE_TYPE_DISCRETE" "ac_cv_have_decl_V4L2_FRMSIZE_TYPE_DISCRETE" "#include <sys/time.h>
+
+
+ac_fn_c_check_decl "$LINENO" "V4L2_TUNER_RADIO" "ac_cv_have_decl_V4L2_TUNER_RADIO" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_FRMSIZE_TYPE_DISCRETE" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_TUNER_RADIO" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_FRMSIZE_TYPE_DISCRETE $ac_have_decl
+#define HAVE_DECL_V4L2_TUNER_RADIO $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_FRMSIZE_TYPE_CONTINUOUS" "ac_cv_have_decl_V4L2_FRMSIZE_TYPE_CONTINUOUS" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_TUNER_ANALOG_TV" "ac_cv_have_decl_V4L2_TUNER_ANALOG_TV" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_FRMSIZE_TYPE_CONTINUOUS" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_TUNER_ANALOG_TV" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_FRMSIZE_TYPE_CONTINUOUS $ac_have_decl
+#define HAVE_DECL_V4L2_TUNER_ANALOG_TV $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_FRMSIZE_TYPE_STEPWISE" "ac_cv_have_decl_V4L2_FRMSIZE_TYPE_STEPWISE" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_TUNER_DIGITAL_TV" "ac_cv_have_decl_V4L2_TUNER_DIGITAL_TV" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_FRMSIZE_TYPE_STEPWISE" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_TUNER_DIGITAL_TV" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_FRMSIZE_TYPE_STEPWISE $ac_have_decl
+#define HAVE_DECL_V4L2_TUNER_DIGITAL_TV $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_FRMIVAL_TYPE_DISCRETE" "ac_cv_have_decl_V4L2_FRMIVAL_TYPE_DISCRETE" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_TUNER_SDR" "ac_cv_have_decl_V4L2_TUNER_SDR" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_FRMIVAL_TYPE_DISCRETE" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_TUNER_SDR" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_FRMIVAL_TYPE_DISCRETE $ac_have_decl
+#define HAVE_DECL_V4L2_TUNER_SDR $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_FRMIVAL_TYPE_CONTINUOUS" "ac_cv_have_decl_V4L2_FRMIVAL_TYPE_CONTINUOUS" "#include <sys/time.h>
+ac_fn_c_check_decl "$LINENO" "V4L2_TUNER_RF" "ac_cv_have_decl_V4L2_TUNER_RF" "
+#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_FRMIVAL_TYPE_CONTINUOUS" = xyes; then :
+if test "x$ac_cv_have_decl_V4L2_TUNER_RF" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_FRMIVAL_TYPE_CONTINUOUS $ac_have_decl
+#define HAVE_DECL_V4L2_TUNER_RF $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_FRMIVAL_TYPE_STEPWISE" "ac_cv_have_decl_V4L2_FRMIVAL_TYPE_STEPWISE" "#include <sys/time.h>
-#include <linux/ioctl.h>
-#include <linux/types.h>
-#include <linux/videodev2.h>
+
+
+ac_fn_c_check_decl "$LINENO" "P_ALL" "ac_cv_have_decl_P_ALL" "
+#include <sys/types.h>
+#include <sys/wait.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_FRMIVAL_TYPE_STEPWISE" = xyes; then :
+if test "x$ac_cv_have_decl_P_ALL" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_FRMIVAL_TYPE_STEPWISE $ac_have_decl
+#define HAVE_DECL_P_ALL $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_CTRL_TYPE_INTEGER" "ac_cv_have_decl_V4L2_CTRL_TYPE_INTEGER" "#include <sys/time.h>
-#include <linux/ioctl.h>
-#include <linux/types.h>
-#include <linux/videodev2.h>
+ac_fn_c_check_decl "$LINENO" "P_PID" "ac_cv_have_decl_P_PID" "
+#include <sys/types.h>
+#include <sys/wait.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_CTRL_TYPE_INTEGER" = xyes; then :
+if test "x$ac_cv_have_decl_P_PID" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_CTRL_TYPE_INTEGER $ac_have_decl
+#define HAVE_DECL_P_PID $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_CTRL_TYPE_BOOLEAN" "ac_cv_have_decl_V4L2_CTRL_TYPE_BOOLEAN" "#include <sys/time.h>
-#include <linux/ioctl.h>
-#include <linux/types.h>
-#include <linux/videodev2.h>
+ac_fn_c_check_decl "$LINENO" "P_PGID" "ac_cv_have_decl_P_PGID" "
+#include <sys/types.h>
+#include <sys/wait.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_CTRL_TYPE_BOOLEAN" = xyes; then :
+if test "x$ac_cv_have_decl_P_PGID" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_CTRL_TYPE_BOOLEAN $ac_have_decl
+#define HAVE_DECL_P_PGID $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_CTRL_TYPE_MENU" "ac_cv_have_decl_V4L2_CTRL_TYPE_MENU" "#include <sys/time.h>
-#include <linux/ioctl.h>
-#include <linux/types.h>
-#include <linux/videodev2.h>
+ac_fn_c_check_decl "$LINENO" "P_PIDFD" "ac_cv_have_decl_P_PIDFD" "
+#include <sys/types.h>
+#include <sys/wait.h>
+
 "
-if test "x$ac_cv_have_decl_V4L2_CTRL_TYPE_MENU" = xyes; then :
+if test "x$ac_cv_have_decl_P_PIDFD" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_CTRL_TYPE_MENU $ac_have_decl
+#define HAVE_DECL_P_PIDFD $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_CTRL_TYPE_BUTTON" "ac_cv_have_decl_V4L2_CTRL_TYPE_BUTTON" "#include <sys/time.h>
-#include <linux/ioctl.h>
-#include <linux/types.h>
-#include <linux/videodev2.h>
-"
-if test "x$ac_cv_have_decl_V4L2_CTRL_TYPE_BUTTON" = xyes; then :
+
+
+
+ac_fn_c_check_decl "$LINENO" "sys_errlist" "ac_cv_have_decl_sys_errlist" "$ac_includes_default"
+if test "x$ac_cv_have_decl_sys_errlist" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_CTRL_TYPE_BUTTON $ac_have_decl
+#define HAVE_DECL_SYS_ERRLIST $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_CTRL_TYPE_INTEGER64" "ac_cv_have_decl_V4L2_CTRL_TYPE_INTEGER64" "#include <sys/time.h>
-#include <linux/ioctl.h>
-#include <linux/types.h>
-#include <linux/videodev2.h>
+
+ac_fn_c_check_decl "$LINENO" "PTRACE_PEEKUSER" "ac_cv_have_decl_PTRACE_PEEKUSER" "#include <sys/ptrace.h>
 "
-if test "x$ac_cv_have_decl_V4L2_CTRL_TYPE_INTEGER64" = xyes; then :
+if test "x$ac_cv_have_decl_PTRACE_PEEKUSER" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_CTRL_TYPE_INTEGER64 $ac_have_decl
+#define HAVE_DECL_PTRACE_PEEKUSER $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_CTRL_TYPE_CTRL_CLASS" "ac_cv_have_decl_V4L2_CTRL_TYPE_CTRL_CLASS" "#include <sys/time.h>
-#include <linux/ioctl.h>
-#include <linux/types.h>
-#include <linux/videodev2.h>
+ac_fn_c_check_decl "$LINENO" "PTRACE_POKEUSER" "ac_cv_have_decl_PTRACE_POKEUSER" "#include <sys/ptrace.h>
 "
-if test "x$ac_cv_have_decl_V4L2_CTRL_TYPE_CTRL_CLASS" = xyes; then :
+if test "x$ac_cv_have_decl_PTRACE_POKEUSER" = xyes; then :
   ac_have_decl=1
 else
   ac_have_decl=0
 fi
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_CTRL_TYPE_CTRL_CLASS $ac_have_decl
+#define HAVE_DECL_PTRACE_POKEUSER $ac_have_decl
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_CTRL_TYPE_STRING" "ac_cv_have_decl_V4L2_CTRL_TYPE_STRING" "#include <sys/time.h>
+
+
+ac_fn_c_check_type "$LINENO" "struct v4l2_create_buffers" "ac_cv_type_struct_v4l2_create_buffers" "#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
 "
-if test "x$ac_cv_have_decl_V4L2_CTRL_TYPE_STRING" = xyes; then :
-  ac_have_decl=1
-else
-  ac_have_decl=0
-fi
+if test "x$ac_cv_type_struct_v4l2_create_buffers" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_CTRL_TYPE_STRING $ac_have_decl
+#define HAVE_STRUCT_V4L2_CREATE_BUFFERS 1
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_CTRL_TYPE_BITMASK" "ac_cv_have_decl_V4L2_CTRL_TYPE_BITMASK" "#include <sys/time.h>
+
+
+fi
+ac_fn_c_check_type "$LINENO" "struct v4l2_frmsizeenum" "ac_cv_type_struct_v4l2_frmsizeenum" "#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
 "
-if test "x$ac_cv_have_decl_V4L2_CTRL_TYPE_BITMASK" = xyes; then :
-  ac_have_decl=1
-else
-  ac_have_decl=0
-fi
+if test "x$ac_cv_type_struct_v4l2_frmsizeenum" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_CTRL_TYPE_BITMASK $ac_have_decl
+#define HAVE_STRUCT_V4L2_FRMSIZEENUM 1
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_CTRL_TYPE_INTEGER_MENU" "ac_cv_have_decl_V4L2_CTRL_TYPE_INTEGER_MENU" "#include <sys/time.h>
+
+
+fi
+ac_fn_c_check_type "$LINENO" "struct v4l2_frmivalenum" "ac_cv_type_struct_v4l2_frmivalenum" "#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
 "
-if test "x$ac_cv_have_decl_V4L2_CTRL_TYPE_INTEGER_MENU" = xyes; then :
-  ac_have_decl=1
-else
-  ac_have_decl=0
-fi
+if test "x$ac_cv_type_struct_v4l2_frmivalenum" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_CTRL_TYPE_INTEGER_MENU $ac_have_decl
+#define HAVE_STRUCT_V4L2_FRMIVALENUM 1
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_CTRL_TYPE_U8" "ac_cv_have_decl_V4L2_CTRL_TYPE_U8" "#include <sys/time.h>
+
+
+fi
+ac_fn_c_check_type "$LINENO" "struct v4l2_meta_format" "ac_cv_type_struct_v4l2_meta_format" "#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
 "
-if test "x$ac_cv_have_decl_V4L2_CTRL_TYPE_U8" = xyes; then :
-  ac_have_decl=1
-else
-  ac_have_decl=0
-fi
+if test "x$ac_cv_type_struct_v4l2_meta_format" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_CTRL_TYPE_U8 $ac_have_decl
+#define HAVE_STRUCT_V4L2_META_FORMAT 1
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_CTRL_TYPE_U16" "ac_cv_have_decl_V4L2_CTRL_TYPE_U16" "#include <sys/time.h>
+
+
+fi
+ac_fn_c_check_type "$LINENO" "struct v4l2_pix_format_mplane" "ac_cv_type_struct_v4l2_pix_format_mplane" "#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
 "
-if test "x$ac_cv_have_decl_V4L2_CTRL_TYPE_U16" = xyes; then :
-  ac_have_decl=1
-else
-  ac_have_decl=0
-fi
+if test "x$ac_cv_type_struct_v4l2_pix_format_mplane" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_CTRL_TYPE_U16 $ac_have_decl
+#define HAVE_STRUCT_V4L2_PIX_FORMAT_MPLANE 1
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_CTRL_TYPE_U32" "ac_cv_have_decl_V4L2_CTRL_TYPE_U32" "#include <sys/time.h>
+
+
+fi
+ac_fn_c_check_type "$LINENO" "struct v4l2_plane_pix_format" "ac_cv_type_struct_v4l2_plane_pix_format" "#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
 "
-if test "x$ac_cv_have_decl_V4L2_CTRL_TYPE_U32" = xyes; then :
-  ac_have_decl=1
-else
-  ac_have_decl=0
-fi
+if test "x$ac_cv_type_struct_v4l2_plane_pix_format" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_CTRL_TYPE_U32 $ac_have_decl
+#define HAVE_STRUCT_V4L2_PLANE_PIX_FORMAT 1
 _ACEOF
-ac_fn_c_check_decl "$LINENO" "V4L2_CTRL_TYPE_AREA" "ac_cv_have_decl_V4L2_CTRL_TYPE_AREA" "#include <sys/time.h>
+
+
+fi
+ac_fn_c_check_type "$LINENO" "struct v4l2_sdr_format" "ac_cv_type_struct_v4l2_sdr_format" "#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
 #include <linux/videodev2.h>
 "
-if test "x$ac_cv_have_decl_V4L2_CTRL_TYPE_AREA" = xyes; then :
-  ac_have_decl=1
-else
-  ac_have_decl=0
-fi
+if test "x$ac_cv_type_struct_v4l2_sdr_format" = xyes; then :
 
 cat >>confdefs.h <<_ACEOF
-#define HAVE_DECL_V4L2_CTRL_TYPE_AREA $ac_have_decl
+#define HAVE_STRUCT_V4L2_SDR_FORMAT 1
 _ACEOF
 
 
+fi
+
+
 ac_fn_c_check_member "$LINENO" "struct v4l2_capability" "device_caps" "ac_cv_member_struct_v4l2_capability_device_caps" "#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
@@ -15872,13 +22185,13 @@ $as_echo "#define HAVE__STATIC_ASSERT 1"
 		;;
 esac
 
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for dladdr in -ldl" >&5
-$as_echo_n "checking for dladdr in -ldl... " >&6; }
-if ${ac_cv_lib_dl_dladdr+:} false; then :
+saved_LIBS="$LIBS"
+{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for library containing dladdr" >&5
+$as_echo_n "checking for library containing dladdr... " >&6; }
+if ${ac_cv_search_dladdr+:} false; then :
   $as_echo_n "(cached) " >&6
 else
-  ac_check_lib_save_LIBS=$LIBS
-LIBS="-ldl  $LIBS"
+  ac_func_search_save_LIBS=$LIBS
 cat confdefs.h - <<_ACEOF >conftest.$ac_ext
 /* end confdefs.h.  */
 
@@ -15897,27 +22210,47 @@ return dladdr ();
   return 0;
 }
 _ACEOF
-if ac_fn_c_try_link "$LINENO"; then :
-  ac_cv_lib_dl_dladdr=yes
-else
-  ac_cv_lib_dl_dladdr=no
+for ac_lib in '' dl; do
+  if test -z "$ac_lib"; then
+    ac_res="none required"
+  else
+    ac_res=-l$ac_lib
+    LIBS="-l$ac_lib  $ac_func_search_save_LIBS"
+  fi
+  if ac_fn_c_try_link "$LINENO"; then :
+  ac_cv_search_dladdr=$ac_res
 fi
 rm -f core conftest.err conftest.$ac_objext \
-    conftest$ac_exeext conftest.$ac_ext
-LIBS=$ac_check_lib_save_LIBS
+    conftest$ac_exeext
+  if ${ac_cv_search_dladdr+:} false; then :
+  break
 fi
-{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_lib_dl_dladdr" >&5
-$as_echo "$ac_cv_lib_dl_dladdr" >&6; }
-if test "x$ac_cv_lib_dl_dladdr" = xyes; then :
-  dl_LIBS='-ldl'
+done
+if ${ac_cv_search_dladdr+:} false; then :
+
 else
-  dl_LIBS=
+  ac_cv_search_dladdr=no
+fi
+rm conftest.$ac_ext
+LIBS=$ac_func_search_save_LIBS
+fi
+{ $as_echo "$as_me:${as_lineno-$LINENO}: result: $ac_cv_search_dladdr" >&5
+$as_echo "$ac_cv_search_dladdr" >&6; }
+ac_res=$ac_cv_search_dladdr
+if test "$ac_res" != no; then :
+  test "$ac_res" = "none required" || LIBS="$ac_res $LIBS"
+
 fi
 
-if test "x$ac_cv_lib_dl_dladdr" = xyes; then
+LIBS="$saved_LIBS"
+dl_LIBS=""
+if test "$ac_cv_search_dladdr" != no; then
 
 $as_echo "#define HAVE_DLADDR 1" >>confdefs.h
 
+	case "$ac_cv_search_dladdr" in
+		-l*) dl_LIBS="$ac_cv_search_dladdr" ;;
+	esac
 fi
 
 
@@ -16121,47 +22454,6 @@ case "$ac_cv_search_mq_open" in
 esac
 
 
-# Extract the first word of "perl", so it can be a program name with args.
-set dummy perl; ac_word=$2
-{ $as_echo "$as_me:${as_lineno-$LINENO}: checking for $ac_word" >&5
-$as_echo_n "checking for $ac_word... " >&6; }
-if ${ac_cv_path_PERL+:} false; then :
-  $as_echo_n "(cached) " >&6
-else
-  case $PERL in
-  [\\/]* | ?:[\\/]*)
-  ac_cv_path_PERL="$PERL" # Let the user override the test with a path.
-  ;;
-  *)
-  as_save_IFS=$IFS; IFS=$PATH_SEPARATOR
-for as_dir in $PATH
-do
-  IFS=$as_save_IFS
-  test -z "$as_dir" && as_dir=.
-    for ac_exec_ext in '' $ac_executable_extensions; do
-  if as_fn_executable_p "$as_dir/$ac_word$ac_exec_ext"; then
-    ac_cv_path_PERL="$as_dir/$ac_word$ac_exec_ext"
-    $as_echo "$as_me:${as_lineno-$LINENO}: found $as_dir/$ac_word$ac_exec_ext" >&5
-    break 2
-  fi
-done
-  done
-IFS=$as_save_IFS
-
-  ;;
-esac
-fi
-PERL=$ac_cv_path_PERL
-if test -n "$PERL"; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: $PERL" >&5
-$as_echo "$PERL" >&6; }
-else
-  { $as_echo "$as_me:${as_lineno-$LINENO}: result: no" >&5
-$as_echo "no" >&6; }
-fi
-
-
-
 if test -n "$ac_tool_prefix"; then
   # Extract the first word of "${ac_tool_prefix}readelf", so it can be a program name with args.
 set dummy ${ac_tool_prefix}readelf; ac_word=$2
@@ -18738,15 +25030,15 @@ if test -z "${am__fastdepCC_TRUE}" && te
   as_fn_error $? "conditional \"am__fastdepCC\" was never defined.
 Usually this means the macro was only invoked conditionally." "$LINENO" 5
 fi
-if test -z "${am__fastdepCC_TRUE}" && test -z "${am__fastdepCC_FALSE}"; then
-  as_fn_error $? "conditional \"am__fastdepCC\" was never defined.
-Usually this means the macro was only invoked conditionally." "$LINENO" 5
-fi
 if test -z "${CODE_COVERAGE_ENABLED_TRUE}" && test -z "${CODE_COVERAGE_ENABLED_FALSE}"; then
   as_fn_error $? "conditional \"CODE_COVERAGE_ENABLED\" was never defined.
 Usually this means the macro was only invoked conditionally." "$LINENO" 5
 fi
 
+if test -z "${am__fastdepCC_TRUE}" && test -z "${am__fastdepCC_FALSE}"; then
+  as_fn_error $? "conditional \"am__fastdepCC\" was never defined.
+Usually this means the macro was only invoked conditionally." "$LINENO" 5
+fi
 if test -z "${ENABLE_STACKTRACE_TRUE}" && test -z "${ENABLE_STACKTRACE_FALSE}"; then
   as_fn_error $? "conditional \"ENABLE_STACKTRACE\" was never defined.
 Usually this means the macro was only invoked conditionally." "$LINENO" 5
@@ -19180,7 +25472,7 @@ cat >>$CONFIG_STATUS <<\_ACEOF || ac_wri
 # report actual input values of CONFIG_FILES etc. instead of their
 # values after options handling.
 ac_log="
-This file was extended by strace $as_me 5.5, which was
+This file was extended by strace $as_me 5.9, which was
 generated by GNU Autoconf 2.69.  Invocation command line was
 
   CONFIG_FILES    = $CONFIG_FILES
@@ -19247,7 +25539,7 @@ _ACEOF
 cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
 ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
 ac_cs_version="\\
-strace config.status 5.5
+strace config.status 5.9
 configured by $0, generated by GNU Autoconf 2.69,
   with options \\"\$ac_cs_config\\"
 
@@ -20059,7 +26351,9 @@ $as_echo X/"$am_mf" |
     { { $as_echo "$as_me:${as_lineno-$LINENO}: error: in \`$ac_pwd':" >&5
 $as_echo "$as_me: error: in \`$ac_pwd':" >&2;}
 as_fn_error $? "Something went wrong bootstrapping makefile fragments
-    for automatic dependency tracking.  Try re-running configure with the
+    for automatic dependency tracking.  If GNU make was not used, consider
+    re-running the configure script with MAKE=\"gmake\" (or whatever is
+    necessary).  You can also try re-running configure with the
     '--disable-dependency-tracking' option to at least be able to build
     the package (albeit without support for automatic dependency tracking).
 See \`config.log' for more details" "$LINENO" 5; }
diff -pruN 5.5-3/configure.ac 5.9-0ubuntu2/configure.ac
--- 5.5-3/configure.ac	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/configure.ac	2020-09-23 16:28:11.000000000 +0000
@@ -34,8 +34,6 @@ AC_SUBST(DEB_CHANGELOGTIME)
 AC_PROG_CC
 AC_PROG_CC_STDC
 AC_PROG_CPP
-st_WARN_CFLAGS
-AX_PROG_CC_FOR_BUILD
 AC_PROG_INSTALL
 AC_PROG_RANLIB
 
@@ -50,6 +48,9 @@ AC_SUBST([MANPAGE_DATE], [manpage_date])
 
 AC_C_BIGENDIAN
 
+dnl arch-specific default for --enable-gcc-Werror
+arch_enable_Werror=yes
+
 AC_MSG_CHECKING([for supported architecture])
 arch_m32=
 arch_mx32=
@@ -64,6 +65,7 @@ aarch64*)
 	;;
 alpha*)
 	arch=alpha
+	arch_enable_Werror=no
 	AC_DEFINE([ALPHA], 1, [Define for the Alpha architecture.])
 	;;
 arc*)
@@ -80,6 +82,7 @@ avr32*)
 	;;
 bfin)
 	arch=bfin
+	arch_enable_Werror=no
 	AC_DEFINE([BFIN], 1, [Define for the Blackfin architecture.])
 	;;
 csky*)
@@ -108,6 +111,7 @@ metag*)
 	;;
 microblaze*)
 	arch=microblaze
+	arch_enable_Werror=no
 	AC_DEFINE([MICROBLAZE], 1, [Define for the MicroBlaze architecture.])
 	;;
 mips*)
@@ -257,6 +261,10 @@ esac
 AC_DEFINE_UNQUOTED([ENABLE_ARM_OABI], [$enable_arm_oabi],
 		   [Define to 1 if you want OABI support on ARM EABI.])
 
+st_WARN_CFLAGS
+AX_PROG_CC_FOR_BUILD
+AM_PROG_AR
+
 AC_C_TYPEOF
 
 AC_TYPE_UID_T
@@ -277,7 +285,6 @@ AC_CHECK_FUNCS(m4_normalize([
 	if_indextoname
 	open64
 	open_memstream
-	prctl
 	preadv
 	process_vm_readv
 	pwritev
@@ -286,9 +293,7 @@ AC_CHECK_FUNCS(m4_normalize([
 	stpcpy
 	strerror
 	strndup
-	strsignal
 	sync_file_range
-	utimensat
 ]))
 
 AC_CHECK_TYPES([sig_atomic_t, struct sigcontext],,, [#include <signal.h>])
@@ -388,16 +393,29 @@ AC_CHECK_HEADERS(m4_normalize([
 	elf.h
 	gcov.h
 	iconv.h
-	inttypes.h
+	mqueue.h
+	netinet/sctp.h
+	netipx/ipx.h
+	paths.h
+	scsi/sg.h
+	sys/eventfd.h
+	sys/fanotify.h
+	sys/ipc.h
+	sys/quota.h
+	sys/signalfd.h
+	sys/xattr.h
+	ustat.h
+]))
+
+AC_CHECK_HEADERS(m4_normalize([
 	linux/bsg.h
+	linux/close_range.h
 	linux/dm-ioctl.h
 	linux/dqblk_xfs.h
 	linux/falloc.h
 	linux/fib_rules.h
 	linux/fiemap.h
 	linux/hiddev.h
-	linux/if_addr.h
-	linux/if_link.h
 	linux/ip_vs.h
 	linux/ipc.h
 	linux/kcmp.h
@@ -405,7 +423,7 @@ AC_CHECK_HEADERS(m4_normalize([
 	linux/memfd.h
 	linux/mmtimer.h
 	linux/mount.h
-	linux/neighbour.h
+	linux/mqueue.h
 	linux/netfilter/ipset/ip_set.h
 	linux/netfilter/nf_tables.h
 	linux/netfilter/nf_tables_compat.h
@@ -417,35 +435,32 @@ AC_CHECK_HEADERS(m4_normalize([
 	linux/netfilter/nfnetlink_log.h
 	linux/netfilter/nfnetlink_queue.h
 	linux/nsfs.h
+	linux/openat2.h
 	linux/perf_event.h
 	linux/quota.h
 	linux/sched.h
 	linux/seccomp.h
 	linux/securebits.h
+	linux/tee.h
 	linux/userfaultfd.h
 	linux/utsname.h
-	mqueue.h
-	netinet/sctp.h
-	netipx/ipx.h
-	paths.h
-	scsi/sg.h
-	stropts.h
-	sys/conf.h
-	sys/eventfd.h
-	sys/fanotify.h
-	sys/ipc.h
-	sys/quota.h
-	sys/signalfd.h
-	sys/xattr.h
-	ustat.h
-]))
+]),,, [AC_INCLUDES_DEFAULT
+#include <linux/types.h>
+])
+
+AC_CHECK_HEADERS(m4_normalize([
+	linux/if_addr.h
+	linux/if_link.h
+	linux/neighbour.h
+]),,, [AC_INCLUDES_DEFAULT
+#include <sys/socket.h>
+#include <linux/types.h>
+])
 
 AC_CHECK_HEADERS([asm/sigcontext.h],,, [#include <signal.h>])
 
 AC_CHECK_HEADERS([netinet/tcp.h netinet/udp.h],,, [#include <netinet/in.h>])
 
-AC_CHECK_HEADERS([linux/mqueue.h],,, [#include <linux/types.h>])
-
 AC_CHECK_HEADERS([linux/netfilter/xt_osf.h],,, [#include <linux/ip.h>
 #include <linux/tcp.h>])
 
@@ -468,6 +483,7 @@ AC_CHECK_HEADERS([linux/bpf.h], [
 
 AC_CHECK_HEADERS([linux/io_uring.h], [
 	AC_CHECK_MEMBERS(m4_normalize([
+		struct io_cqring_offsets.flags,
 		struct io_uring_params.features,
 		struct io_uring_params.wq_fd,
 		struct io_uring_params.resv
@@ -486,7 +502,8 @@ AC_CHECK_HEADERS([bluetooth/bluetooth.h]
 AC_CHECK_MEMBERS(m4_normalize([
 	struct br_mdb_entry.flags,
 	struct br_mdb_entry.vid
-]),,, [#include <linux/if_bridge.h>])
+]),,, [#include <netinet/in.h>
+#include <linux/if_bridge.h>])
 
 AC_CHECK_TYPES([struct dcbmsg],,, [#include <linux/dcbnl.h>])
 AC_CHECK_TYPES([struct ifaddrlblmsg],,, [#include <linux/if_addrlabel.h>])
@@ -497,39 +514,21 @@ AC_CHECK_TYPES(m4_normalize([
 ]),,, [#include <sys/socket.h>
 #include <linux/rtnetlink.h>])
 
-AC_CHECK_DECLS(m4_normalize([
-	TCA_ACT_PAD,
-	TCA_ACT_COOKIE,
-	TCA_ACT_FLAGS
-]),,, [#include <sys/socket.h>
-#include <linux/pkt_cls.h>])
-AC_CHECK_DECLS(m4_normalize([
-	IFLA_PORT_SELF,
-	IFLA_PROTINFO,
-	IFLA_AF_SPEC,
-	IFLA_XDP
-]),,, [#include <sys/socket.h>
-#include <linux/rtnetlink.h>])
-
 AC_CHECK_TYPES(m4_normalize([
 	struct gnet_stats_basic,
 	struct gnet_stats_queue,
 	struct gnet_stats_rate_est,
 	struct gnet_stats_rate_est64
 ]),,, [#include <linux/gen_stats.h>])
-AC_CHECK_DECLS(m4_normalize([
-	TCA_STATS_PKT64
-]),,, [#include <linux/gen_stats.h>])
 
 AC_CHECK_TYPES([struct tc_sizespec],,, [#include <linux/types.h>
 #include <linux/pkt_sched.h>])
-AC_CHECK_DECLS([TCA_STAB_DATA],,, [#include <linux/types.h>
-#include <linux/pkt_sched.h>])
 
 AC_CHECK_TYPES(m4_normalize([
 	struct fib_rule_uid_range,
 	struct fib_rule_port_range
-]),,, [#include <linux/fib_rules.h>])
+]),,, [#include <sys/socket.h>
+#include <linux/fib_rules.h>])
 
 AC_CHECK_TYPES([struct statfs], [
 	AC_CHECK_MEMBERS(m4_normalize([
@@ -595,7 +594,7 @@ AC_CHECK_MEMBERS(m4_normalize([
 		struct iocb.aio_rw_flags
 		]),,, [#include <linux/aio_abi.h>])
 
-AC_CHECK_MEMBERS([struct clone_args.set_tid_size],,, [#include <linux/sched.h>])
+AC_CHECK_MEMBERS([struct clone_args.cgroup],,, [#include <linux/sched.h>])
 
 CPPFLAGS="$saved_CPPFLAGS"
 
@@ -603,16 +602,12 @@ AC_CHECK_HEADERS([linux/btrfs.h], [
 	AC_CHECK_MEMBERS(m4_normalize([
 		struct btrfs_ioctl_feature_flags.compat_flags,
 		struct btrfs_ioctl_fs_info_args.nodesize,
-		struct btrfs_ioctl_defrag_range_args.start,
-		struct btrfs_ioctl_search_args_v2.buf_size,
-		struct btrfs_ioctl_logical_ino_args.flags
+		struct btrfs_ioctl_defrag_range_args.start
 		]),,, [ #include <stdio.h>
-#include <linux/btrfs.h>])
-	AC_CHECK_DECLS(m4_normalize([BTRFS_COMPRESS_NONE, BTRFS_COMPRESS_ZLIB,
-				BTRFS_COMPRESS_LZO]),,,[ #include <stdio.h>
 #include <linux/btrfs.h>])])
 
 st_CHECK_TYPES
+st_CHECK_ENUMS
 
 AC_CHECK_DECLS([sys_errlist])
 AC_CHECK_DECLS(m4_normalize([
@@ -620,165 +615,14 @@ AC_CHECK_DECLS(m4_normalize([
 	PTRACE_POKEUSER
 ]),,, [#include <sys/ptrace.h>])
 
-AC_CHECK_DECLS(m4_normalize([
-	P_PID,
-	P_PPID,
-	P_PGID,
-	P_SID,
-	P_CID,
-	P_UID,
-	P_GID,
-	P_ALL,
-	P_LWPID
-]),,, [#include <sys/wait.h>])
-
-AC_CHECK_DECLS(m4_normalize([
-	LO_FLAGS_READ_ONLY,
-	LO_FLAGS_USE_AOPS,
-	LO_FLAGS_AUTOCLEAR,
-	LO_FLAGS_PARTSCAN,
-	LO_FLAGS_DIRECT_IO
-]),,, [#include <linux/loop.h>])
-
-AC_CHECK_DECLS(m4_normalize([
-	CTL_PROC,
-	CTL_ARLAN,
-	CTL_S390DBF,
-	CTL_SUNRPC,
-	CTL_PM,
-	CTL_FRV,
-	KERN_PRINTK_RATELIMIT,
-	KERN_PRINTK_RATELIMIT_BURST,
-	KERN_PTY,
-	KERN_NGROUPS_MAX,
-	KERN_SPARC_SCONS_PWROFF,
-	KERN_HZ_TIMER,
-	KERN_UNKNOWN_NMI_PANIC,
-	KERN_BOOTLOADER_TYPE,
-	KERN_RANDOMIZE,
-	KERN_SETUID_DUMPABLE,
-	KERN_SPIN_RETRY,
-	KERN_ACPI_VIDEO_FLAGS,
-	KERN_IA64_UNALIGNED,
-	KERN_COMPAT_LOG,
-	KERN_MAX_LOCK_DEPTH,
-	KERN_NMI_WATCHDOG,
-	KERN_PANIC_ON_NMI,
-	KERN_PANIC_ON_WARN,
-	KERN_PANIC_PRINT,
-	NET_LLC,
-	NET_NETFILTER,
-	NET_DCCP,
-	NET_IRDA,
-	NET_CORE_DESTROY_DELAY,
-	NET_CORE_BUDGET,
-	NET_CORE_AEVENT_ETIME,
-	NET_CORE_AEVENT_RSEQTH,
-	NET_CORE_WARNINGS,
-	NET_IPV4_IGMP_MAX_MSF,
-	NET_TCP_NO_METRICS_SAVE,
-	NET_TCP_DEFAULT_WIN_SCALE,
-	NET_TCP_MODERATE_RCVBUF,
-	NET_TCP_TSO_WIN_DIVISOR,
-	NET_TCP_BIC_BETA,
-	NET_IPV4_ICMP_ERRORS_USE_INBOUND_IFADDR,
-	NET_TCP_CONG_CONTROL,
-	NET_TCP_ABC,
-	NET_IPV4_IPFRAG_MAX_DIST,
-	NET_TCP_MTU_PROBING,
-	NET_TCP_BASE_MSS,
-	NET_IPV4_TCP_WORKAROUND_SIGNED_WINDOWS,
-	NET_TCP_DMA_COPYBREAK,
-	NET_TCP_SLOW_START_AFTER_IDLE,
-	NET_CIPSOV4_CACHE_ENABLE,
-	NET_CIPSOV4_CACHE_BUCKET_SIZE,
-	NET_CIPSOV4_RBM_OPTFMT,
-	NET_CIPSOV4_RBM_STRICTVALID,
-	NET_TCP_AVAIL_CONG_CONTROL,
-	NET_TCP_ALLOWED_CONG_CONTROL,
-	NET_TCP_MAX_SSTHRESH,
-	NET_TCP_FRTO_RESPONSE,
-	NET_IPV4_ROUTE_GC_MIN_INTERVAL_MS,
-	NET_IPV4_CONF_FORCE_IGMP_VERSION,
-	NET_IPV4_CONF_ARP_ANNOUNCE,
-	NET_IPV4_CONF_ARP_IGNORE,
-	NET_IPV4_CONF_PROMOTE_SECONDARIES,
-	NET_IPV4_CONF_ARP_ACCEPT,
-	NET_IPV4_CONF_ARP_NOTIFY,
-	NET_IPV6_MLD_MAX_MSF,
-	NET_IPV6_ROUTE_GC_MIN_INTERVAL_MS,
-	VM_MAX_MAP_COUNT,
-	VM_LAPTOP_MODE,
-	VM_BLOCK_DUMP,
-	VM_HUGETLB_GROUP,
-	VM_VFS_CACHE_PRESSURE,
-	VM_LEGACY_VA_LAYOUT,
-	VM_SWAP_TOKEN_TIMEOUT
-]),,,
-[#include <sys/types.h>
-#include <linux/sysctl.h>])
-
-AC_CHECK_DECLS(m4_normalize([
-	V4L2_FIELD_ANY,
-	V4L2_FIELD_NONE,
-	V4L2_FIELD_TOP,
-	V4L2_FIELD_BOTTOM,
-	V4L2_FIELD_INTERLACED,
-	V4L2_FIELD_SEQ_TB,
-	V4L2_FIELD_SEQ_BT,
-	V4L2_FIELD_ALTERNATE,
-	V4L2_FIELD_INTERLACED_TB,
-	V4L2_FIELD_INTERLACED_BT,
-	V4L2_BUF_TYPE_VIDEO_CAPTURE,
-	V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE,
-	V4L2_BUF_TYPE_VIDEO_OUTPUT,
-	V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE,
-	V4L2_BUF_TYPE_VIDEO_OVERLAY,
-	V4L2_BUF_TYPE_VBI_CAPTURE,
-	V4L2_BUF_TYPE_VBI_OUTPUT,
-	V4L2_BUF_TYPE_SLICED_VBI_CAPTURE,
-	V4L2_BUF_TYPE_SLICED_VBI_OUTPUT,
-	V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY,
-	V4L2_BUF_TYPE_SDR_CAPTURE,
-	V4L2_BUF_TYPE_SDR_OUTPUT,
-	V4L2_TUNER_RADIO,
-	V4L2_TUNER_ANALOG_TV,
-	V4L2_TUNER_DIGITAL_TV,
-	V4L2_MEMORY_MMAP,
-	V4L2_MEMORY_USERPTR,
-	V4L2_MEMORY_OVERLAY,
-	V4L2_MEMORY_DMABUF,
-	V4L2_COLORSPACE_SMPTE170M,
-	V4L2_COLORSPACE_SMPTE240M,
-	V4L2_COLORSPACE_REC709,
-	V4L2_COLORSPACE_BT878,
-	V4L2_COLORSPACE_470_SYSTEM_M,
-	V4L2_COLORSPACE_470_SYSTEM_BG,
-	V4L2_COLORSPACE_JPEG,
-	V4L2_COLORSPACE_SRGB,
-	V4L2_PRIORITY_UNSET,
-	V4L2_PRIORITY_BACKGROUND,
-	V4L2_PRIORITY_INTERACTIVE,
-	V4L2_PRIORITY_RECORD,
-	V4L2_FRMSIZE_TYPE_DISCRETE,
-	V4L2_FRMSIZE_TYPE_CONTINUOUS,
-	V4L2_FRMSIZE_TYPE_STEPWISE,
-	V4L2_FRMIVAL_TYPE_DISCRETE,
-	V4L2_FRMIVAL_TYPE_CONTINUOUS,
-	V4L2_FRMIVAL_TYPE_STEPWISE,
-	V4L2_CTRL_TYPE_INTEGER,
-	V4L2_CTRL_TYPE_BOOLEAN,
-	V4L2_CTRL_TYPE_MENU,
-	V4L2_CTRL_TYPE_BUTTON,
-	V4L2_CTRL_TYPE_INTEGER64,
-	V4L2_CTRL_TYPE_CTRL_CLASS,
-	V4L2_CTRL_TYPE_STRING,
-	V4L2_CTRL_TYPE_BITMASK,
-	V4L2_CTRL_TYPE_INTEGER_MENU,
-	V4L2_CTRL_TYPE_U8,
-	V4L2_CTRL_TYPE_U16,
-	V4L2_CTRL_TYPE_U32,
-	V4L2_CTRL_TYPE_AREA
+AC_CHECK_TYPES(m4_normalize([
+	struct v4l2_create_buffers,
+	struct v4l2_frmsizeenum,
+	struct v4l2_frmivalenum,
+	struct v4l2_meta_format,
+	struct v4l2_pix_format_mplane,
+	struct v4l2_plane_pix_format,
+	struct v4l2_sdr_format
 ]),,, [#include <sys/time.h>
 #include <linux/ioctl.h>
 #include <linux/types.h>
@@ -875,9 +719,15 @@ case "x$st_cv_have_static_assert" in
 		;;
 esac
 
-AC_CHECK_LIB([dl], [dladdr], [dl_LIBS='-ldl'], [dl_LIBS=])
-if test "x$ac_cv_lib_dl_dladdr" = xyes; then
+saved_LIBS="$LIBS"
+AC_SEARCH_LIBS([dladdr], [dl])
+LIBS="$saved_LIBS"
+dl_LIBS=""
+if test "$ac_cv_search_dladdr" != no; then
 	AC_DEFINE([HAVE_DLADDR], [1], [Define to 1 if the system provides dladdr])
+	case "$ac_cv_search_dladdr" in
+		-l*) dl_LIBS="$ac_cv_search_dladdr" ;;
+	esac
 fi
 AC_SUBST(dl_LIBS)
 
@@ -910,8 +760,6 @@ case "$ac_cv_search_mq_open" in
 esac
 AC_SUBST(mq_LIBS)
 
-AC_PATH_PROG([PERL], [perl])
-
 AC_CHECK_TOOL([READELF], [readelf])
 
 st_STACKTRACE
diff -pruN 5.5-3/count.c 5.9-0ubuntu2/count.c
--- 5.5-3/count.c	2019-08-08 17:04:29.000000000 +0000
+++ 5.9-0ubuntu2/count.c	2020-04-03 22:58:26.000000000 +0000
@@ -8,7 +8,7 @@
  *                    <barrow_dj@mail.yahoo.com,djbarrow@de.ibm.com>
  * Copyright (c) 2004 Roland McGrath <roland@redhat.com>
  * Copyright (c) 2006 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2006-2018 The strace developers.
+ * Copyright (c) 2006-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -16,28 +16,101 @@
 
 #include "defs.h"
 
+#include <stdarg.h>
+
 /* Per-syscall stats structure */
 struct call_counts {
 	/* time may be total latency or system time */
 	struct timespec time;
-	unsigned int calls, errors;
+	struct timespec time_min;
+	struct timespec time_max;
+	struct timespec time_avg;
+	uint64_t calls, errors;
 };
 
 static struct call_counts *countv[SUPPORTED_PERSONALITIES];
 #define counts (countv[current_personality])
 
 static const struct timespec zero_ts;
+static const struct timespec max_ts = {
+	(time_t) (long long) (zero_extend_signed_to_ull((time_t) -1ULL) >> 1),
+	999999999 };
 
 static struct timespec overhead;
 
+
+enum count_summary_columns {
+	CSC_NONE,
+	CSC_TIME_100S,
+	CSC_TIME_TOTAL,
+	CSC_TIME_MIN,
+	CSC_TIME_MAX,
+	CSC_TIME_AVG,
+	CSC_CALLS,
+	CSC_ERRORS,
+	CSC_SC_NAME,
+
+	CSC_MAX,
+};
+
+static uint8_t columns[CSC_MAX] = {
+	CSC_TIME_100S,
+	CSC_TIME_TOTAL,
+	CSC_TIME_AVG,
+	CSC_CALLS,
+	CSC_ERRORS,
+	CSC_SC_NAME,
+};
+
+static const struct {
+	const char *name;
+	uint8_t     column;
+} column_aliases[] = {
+	{ "time",         CSC_TIME_100S  },
+	{ "time_percent", CSC_TIME_100S  },
+	{ "time-percent", CSC_TIME_100S  },
+	{ "time_total",   CSC_TIME_TOTAL },
+	{ "time-total",   CSC_TIME_TOTAL },
+	{ "total_time",   CSC_TIME_TOTAL },
+	{ "total-time",   CSC_TIME_TOTAL },
+	{ "min_time",     CSC_TIME_MIN   },
+	{ "min-time",     CSC_TIME_MIN   },
+	{ "shortest",     CSC_TIME_MIN   },
+	{ "time_min",     CSC_TIME_MIN   },
+	{ "time-min",     CSC_TIME_MIN   },
+	{ "longest" ,     CSC_TIME_MAX   },
+	{ "max_time",     CSC_TIME_MAX   },
+	{ "max-time",     CSC_TIME_MAX   },
+	{ "time_max",     CSC_TIME_MAX   },
+	{ "time-max",     CSC_TIME_MAX   },
+	{ "avg_time",     CSC_TIME_AVG   },
+	{ "avg-time",     CSC_TIME_AVG   },
+	{ "time_avg",     CSC_TIME_AVG   },
+	{ "time-avg",     CSC_TIME_AVG   },
+	{ "calls",        CSC_CALLS      },
+	{ "count",        CSC_CALLS      },
+	{ "error",        CSC_ERRORS     },
+	{ "errors",       CSC_ERRORS     },
+	{ "name",         CSC_SC_NAME    },
+	{ "syscall",      CSC_SC_NAME    },
+	{ "syscall_name", CSC_SC_NAME    },
+	{ "syscall-name", CSC_SC_NAME    },
+	{ "none",         CSC_NONE       },
+	{ "nothing",      CSC_NONE       },
+};
+
 void
 count_syscall(struct tcb *tcp, const struct timespec *syscall_exiting_ts)
 {
 	if (!scno_in_range(tcp->scno))
 		return;
 
-	if (!counts)
+	if (!counts) {
 		counts = xcalloc(nsyscalls, sizeof(*counts));
+
+		for (size_t i = 0; i < nsyscalls; i++)
+			counts[i].time_min = max_ts;
+	}
 	struct call_counts *cc = &counts[tcp->scno];
 
 	cc->calls++;
@@ -54,7 +127,12 @@ count_syscall(struct tcb *tcp, const str
 	}
 
 	ts_sub(&wts, &wts, &overhead);
-	ts_add(&cc->time, &cc->time, ts_max(&wts, &zero_ts));
+
+	const struct timespec *wts_nonneg = ts_max(&wts, &zero_ts);
+
+	ts_add(&cc->time, &cc->time, wts_nonneg);
+	cc->time_min = *ts_min(&cc->time_min, wts_nonneg);
+	cc->time_max = *ts_max(&cc->time_max, wts_nonneg);
 }
 
 static int
@@ -66,6 +144,27 @@ time_cmp(const void *a, const void *b)
 }
 
 static int
+min_time_cmp(const void *a, const void *b)
+{
+	return -ts_cmp(&counts[*((unsigned int *) a)].time_min,
+		       &counts[*((unsigned int *) b)].time_min);
+}
+
+static int
+max_time_cmp(const void *a, const void *b)
+{
+	return -ts_cmp(&counts[*((unsigned int *) a)].time_max,
+		       &counts[*((unsigned int *) b)].time_max);
+}
+
+static int
+avg_time_cmp(const void *a, const void *b)
+{
+	return -ts_cmp(&counts[*((unsigned int *) a)].time_avg,
+		       &counts[*((unsigned int *) b)].time_avg);
+}
+
+static int
 syscall_cmp(const void *a, const void *b)
 {
 	const unsigned int *a_int = a;
@@ -97,32 +196,26 @@ error_cmp(const void *a, const void *b)
 	return (m < n) ? 1 : (m > n) ? -1 : 0;
 }
 
-static int (*sortfun)(const void *, const void *);
+typedef int (*sort_func)(const void *, const void *);
+static sort_func sortfun;
 
 void
 set_sortby(const char *sortby)
 {
-	static const struct {
-		int (*fn)(const void *, const void *);
-		const char *name;
-	} sort_fns[] = {
-		{ time_cmp,	"time" },
-		{ time_cmp,	"time_total" },
-		{ time_cmp,	"total_time" },
-		{ count_cmp,	"calls" },
-		{ count_cmp,	"count" },
-		{ error_cmp,	"error" },
-		{ error_cmp,	"errors" },
-		{ syscall_cmp,	"name" },
-		{ syscall_cmp,	"syscall" },
-		{ syscall_cmp,	"syscall_name" },
-		{ NULL,		"none" },
-		{ NULL,		"nothing" },
+	static const sort_func sort_fns[CSC_MAX] = {
+		[CSC_TIME_100S]  = time_cmp,
+		[CSC_TIME_TOTAL] = time_cmp,
+		[CSC_TIME_MIN]   = min_time_cmp,
+		[CSC_TIME_MAX]   = max_time_cmp,
+		[CSC_TIME_AVG]   = avg_time_cmp,
+		[CSC_CALLS]      = count_cmp,
+		[CSC_ERRORS]     = error_cmp,
+		[CSC_SC_NAME]    = syscall_cmp,
 	};
 
-	for (size_t i = 0; i < ARRAY_SIZE(sort_fns); ++i) {
-		if (!strcmp(sort_fns[i].name, sortby)) {
-			sortfun = sort_fns[i].fn;
+	for (size_t i = 0; i < ARRAY_SIZE(column_aliases); ++i) {
+		if (!strcmp(column_aliases[i].name, sortby)) {
+			sortfun = sort_fns[column_aliases[i].column];
 			return;
 		}
 	}
@@ -130,71 +223,282 @@ set_sortby(const char *sortby)
 	error_msg_and_help("invalid sortby: '%s'", sortby);
 }
 
+void
+set_count_summary_columns(const char *s)
+{
+	uint8_t visible[CSC_MAX] = { 0 };
+	const char *prev = s;
+	size_t cur = 0;
+
+	memset(columns, 0, sizeof(columns));
+
+	for (;;) {
+		bool found = false;
+		const char *pos = strchr(prev, ',');
+		size_t len = pos ? (size_t) (pos - prev) : strlen(prev);
+
+		for (size_t i = 0; i < ARRAY_SIZE(column_aliases); i++) {
+			if (strncmp(column_aliases[i].name, prev, len) ||
+			    column_aliases[i].name[len])
+				continue;
+			if (column_aliases[i].column == CSC_NONE ||
+			    column_aliases[i].column >= CSC_MAX)
+				continue;
+
+			if (visible[column_aliases[i].column])
+				error_msg_and_help("call summary column "
+						   "has been provided more "
+						   "than once: '%s' (-U option "
+						   "residual: '%s')",
+						   column_aliases[i].name,
+						   prev);
+
+			columns[cur++] = column_aliases[i].column;
+			visible[column_aliases[i].column] = 1;
+			found = true;
+
+			break;
+		}
+
+		if (!found)
+			error_msg_and_help("unknown column name: '%.*s'",
+					   (int) MIN(len, INT_MAX), prev);
+
+		if (!pos)
+			break;
+
+		prev = pos + 1;
+	}
+
+	/*
+	 * Always enable syscall name column, as without it table is meaningless
+	 */
+	if (!visible[CSC_SC_NAME])
+		columns[cur++] = CSC_SC_NAME;
+}
+
 int
 set_overhead(const char *str)
 {
 	return parse_ts(str, &overhead);
 }
 
+static size_t ATTRIBUTE_FORMAT((printf, 1, 2))
+num_chars(const char *fmt, ...)
+{
+	va_list ap;
+
+	va_start(ap, fmt);
+	int ret = vsnprintf(NULL, 0, fmt, ap);
+	va_end(ap);
+
+	return (unsigned int) MAX(ret, 0);
+}
+
 static void
 call_summary_pers(FILE *outf)
 {
-	static const char dashes[]  = "----------------";
-	static const char header[]  = "%6.6s %11.11s %11.11s %9.9s %9.9s %s\n";
-	static const char data[]    = "%6.2f %11.6f %11lu %9u %9.u %s\n";
-	static const char summary[] = "%6.6s %11.6f %11.11s %9u %9.u %s\n";
-
-	unsigned int i;
-	unsigned int call_cum, error_cum;
-	struct timespec tv_cum, dtv;
-	double  float_tv_cum;
-	double  percent;
-	unsigned int *sorted_count;
-
-	fprintf(outf, header,
-		"% time", "seconds", "usecs/call",
-		"calls", "errors", "syscall");
-	fprintf(outf, header, dashes, dashes, dashes, dashes, dashes, dashes);
-
-	sorted_count = xcalloc(sizeof(sorted_count[0]), nsyscalls);
-	call_cum = error_cum = tv_cum.tv_sec = tv_cum.tv_nsec = 0;
-	for (i = 0; i < nsyscalls; i++) {
-		sorted_count[i] = i;
-		if (counts == NULL || counts[i].calls == 0)
+	unsigned int *indices;
+	size_t last_column = 0;
+
+	struct timespec tv_cum = zero_ts;
+	const struct timespec *tv_min = &max_ts;
+	const struct timespec *tv_min_max = &zero_ts;
+	const struct timespec *tv_max = &zero_ts;
+	const struct timespec *tv_avg_max = &zero_ts;
+	uint64_t call_cum = 0;
+	uint64_t error_cum = 0;
+
+	double float_tv_cum;
+	double percent;
+
+	size_t sc_name_max = 0;
+
+
+	/* sort, calculate statistics */
+	indices = xcalloc(sizeof(indices[0]), nsyscalls);
+	for (size_t i = 0; i < nsyscalls; ++i) {
+		indices[i] = i;
+		if (counts[i].calls == 0)
 			continue;
+
+		ts_add(&tv_cum, &tv_cum, &counts[i].time);
+		tv_min = ts_min(tv_min, &counts[i].time_min);
+		tv_min_max = ts_max(tv_min_max, &counts[i].time_min);
+		tv_max = ts_max(tv_max, &counts[i].time_max);
 		call_cum += counts[i].calls;
 		error_cum += counts[i].errors;
-		ts_add(&tv_cum, &tv_cum, &counts[i].time);
+
+		ts_div(&counts[i].time_avg, &counts[i].time, counts[i].calls);
+		tv_avg_max = ts_max(tv_avg_max, &counts[i].time_avg);
+
+		sc_name_max = MAX(sc_name_max, strlen(sysent[i].sys_name));
 	}
 	float_tv_cum = ts_float(&tv_cum);
-	if (counts) {
-		if (sortfun)
-			qsort((void *) sorted_count, nsyscalls,
-			      sizeof(sorted_count[0]), sortfun);
-		for (i = 0; i < nsyscalls; i++) {
-			double float_syscall_time;
-			unsigned int idx = sorted_count[i];
-			struct call_counts *cc = &counts[idx];
-			if (cc->calls == 0)
-				continue;
-			ts_div(&dtv, &cc->time, cc->calls);
-			float_syscall_time = ts_float(&cc->time);
-			percent = (100.0 * float_syscall_time);
-			if (percent != 0.0)
-				   percent /= float_tv_cum;
-			/* else: float_tv_cum can be 0.0 too and we get 0/0 = NAN */
-			fprintf(outf, data,
-				percent, float_syscall_time,
-				(long) (1000000 * dtv.tv_sec + dtv.tv_nsec / 1000),
-				cc->calls, cc->errors, sysent[idx].sys_name);
+
+	if (sortfun)
+		qsort((void *) indices, nsyscalls, sizeof(indices[0]), sortfun);
+
+	enum column_flags {
+		CF_L = 1 << 0, /* Left-aligned column */
+	};
+	static const struct {
+		const char *s;
+		size_t sz;
+		const char *fmt;
+		const char *last_fmt;
+		uint32_t flags;
+	} cdesc[] = {
+		[CSC_TIME_100S]  = { ARRSZ_PAIR("% time") - 1,   "%1$*2$.2f" },
+		[CSC_TIME_MIN]   = { ARRSZ_PAIR("shortest") - 1, "%1$*2$.6f" },
+		[CSC_TIME_MAX]   = { ARRSZ_PAIR("longest") - 1,  "%1$*2$.6f" },
+		/* Historical field sizes are preserved */
+		[CSC_TIME_TOTAL] = { "seconds",    11, "%1$*2$.6f" },
+		[CSC_TIME_AVG]   = { "usecs/call", 11, "%1$*2$" PRIu64 },
+		[CSC_CALLS]      = { "calls",       9, "%1$*2$" PRIu64 },
+		[CSC_ERRORS]     = { "errors",      9, "%1$*2$.0" PRIu64 },
+		[CSC_SC_NAME]    = { "syscall",    16, "%1$-*2$s", "%1$s", CF_L },
+	};
+
+	/* calculate column widths */
+#define W_(c_, v_) [c_] = MAX(cdesc[c_].sz, (v_))
+	unsigned int cwidths[CSC_MAX] = {
+		W_(CSC_TIME_100S,  sizeof("100.00") - 1),
+		W_(CSC_TIME_TOTAL, num_chars("%.6f", float_tv_cum)),
+		W_(CSC_TIME_MIN,   num_chars("%" PRId64 ".000000",
+					     (int64_t) tv_min_max->tv_sec)),
+		W_(CSC_TIME_MAX,   num_chars("%" PRId64 ".000000",
+					     (int64_t) tv_max->tv_sec)),
+		W_(CSC_TIME_AVG,   num_chars("%" PRId64 ,
+					     (uint64_t) (ts_float(tv_avg_max)
+							 * 1e6))),
+		W_(CSC_CALLS,      num_chars("%" PRIu64, call_cum)),
+		W_(CSC_ERRORS,     num_chars("%" PRIu64, error_cum)),
+		W_(CSC_SC_NAME,    sc_name_max + 1),
+	};
+#undef W_
+
+	/* find the last column */
+	for (size_t i = 0; i < ARRAY_SIZE(columns) && columns[i]; ++i)
+		last_column = i;
+
+	/* header */
+	for (size_t i = 0; i <= last_column; ++i) {
+		const char *fmt = cdesc[columns[i]].flags & CF_L
+				  ? (i == last_column ? "%1$s" : "%1$-*2$s")
+				  : "%1$*2$s";
+		if (i)
+			fputc(' ', outf);
+		fprintf(outf, fmt, cdesc[columns[i]].s, cwidths[columns[i]]);
+	}
+	fputc('\n', outf);
+
+	/* divider */
+	for (size_t i = 0; i <= last_column; ++i) {
+		if (i)
+			fputc(' ', outf);
+
+		for (size_t j = 0; j < cwidths[columns[i]]; ++j)
+			fputc('-', outf);
+	}
+	fputc('\n', outf);
+
+	/* cache column formats */
+#define FC_(c_) \
+	case (c_): \
+		column_fmts[i] = (i == last_column) && cdesc[c].last_fmt \
+				 ? cdesc[c].last_fmt : cdesc[c].fmt; \
+		break
+#define PC_(c_, val_) \
+	case (c_): \
+		fprintf(outf, column_fmts[i], (val_), cwidths[c]); \
+		break
+
+	const char *column_fmts[last_column + 1];
+	for (size_t i = 0; i <= last_column; ++i) {
+		const size_t c = columns[i];
+
+		switch (c) {
+		FC_(CSC_TIME_100S);
+		FC_(CSC_TIME_TOTAL);
+		FC_(CSC_TIME_MIN);
+		FC_(CSC_TIME_MAX);
+		FC_(CSC_TIME_AVG);
+		FC_(CSC_CALLS);
+		FC_(CSC_ERRORS);
+		FC_(CSC_SC_NAME);
+		}
+	}
+
+	/* data output */
+	for (size_t j = 0; j < nsyscalls; ++j) {
+		unsigned int idx = indices[j];
+		struct call_counts *cc = &counts[idx];
+		double float_syscall_time;
+
+		if (cc->calls == 0)
+			continue;
+
+		float_syscall_time = ts_float(&cc->time);
+		percent = (100.0 * float_syscall_time);
+		/* else: float_tv_cum can be 0.0 too and we get 0/0 = NAN */
+		if (percent != 0.0)
+			   percent /= float_tv_cum;
+
+		for (size_t i = 0; i <= last_column; ++i) {
+			const size_t c = columns[i];
+			if (i)
+				fputc(' ', outf);
+
+			switch (c) {
+			PC_(CSC_TIME_100S,  percent);
+			PC_(CSC_TIME_TOTAL, float_syscall_time);
+			PC_(CSC_TIME_MIN,   ts_float(&cc->time_min));
+			PC_(CSC_TIME_MAX,   ts_float(&cc->time_max));
+			PC_(CSC_TIME_AVG,
+			    (uint64_t) (ts_float(&cc->time_avg) * 1e6));
+			PC_(CSC_CALLS,      cc->calls);
+			PC_(CSC_ERRORS,     cc->errors);
+			PC_(CSC_SC_NAME,    sysent[idx].sys_name);
+			}
+		}
+
+		fputc('\n', outf);
+	}
+
+	free(indices);
+
+	/* footer */
+	for (size_t i = 0; i <= last_column; ++i) {
+		if (i)
+			fputc(' ', outf);
+
+		for (size_t j = 0; j < cwidths[columns[i]]; ++j)
+			fputc('-', outf);
+	}
+	fputc('\n', outf);
+
+	/* totals */
+	for (size_t i = 0; i <= last_column; ++i) {
+		const size_t c = columns[i];
+		if (i)
+			fputc(' ', outf);
+
+		switch (c) {
+		PC_(CSC_TIME_100S, 100.0);
+		PC_(CSC_TIME_TOTAL, float_tv_cum);
+		PC_(CSC_TIME_MIN, ts_float(tv_min));
+		PC_(CSC_TIME_MAX, ts_float(tv_max));
+		PC_(CSC_TIME_AVG, (uint64_t) (float_tv_cum / call_cum * 1e6));
+		PC_(CSC_CALLS, call_cum);
+		PC_(CSC_ERRORS, error_cum);
+		PC_(CSC_SC_NAME, "total");
 		}
 	}
-	free(sorted_count);
+	fputc('\n', outf);
 
-	fprintf(outf, header, dashes, dashes, dashes, dashes, dashes, dashes);
-	fprintf(outf, summary,
-		"100.00", float_tv_cum, "",
-		call_cum, error_cum, "total");
+#undef PC_
+#undef FC_
 }
 
 void
diff -pruN 5.5-3/CREDITS 5.9-0ubuntu2/CREDITS
--- 5.5-3/CREDITS	2020-02-06 16:24:03.000000000 +0000
+++ 5.9-0ubuntu2/CREDITS	2020-09-24 09:19:47.000000000 +0000
@@ -19,6 +19,7 @@ strace-devel@lists.strace.io mailing lis
 	Alexey Gladkov <gladkov.alexey@gmail.com>
 	Alexey Neyman <stilor@att.net>
 	Ali Polatel <alip@exherbo.org>
+	Alistair Francis <alistair.francis@wdc.com>
 	Anatoly Pugachev <matorola@gmail.com>
 	Anchit Jain <anchitjain1234@gmail.com>
 	Andi Kleen <ak@linux.intel.com>
@@ -49,6 +50,7 @@ strace-devel@lists.strace.io mailing lis
 	Chris Dearman <chris.dearman@imgtec.com>
 	Chris Lamb <lamby@debian.org>
 	Chris Metcalf <cmetcalf@tilera.com>
+	Chris Packham <chris.packham@alliedtelesis.co.nz>
 	Chris Zankel <chris@zankel.net>
 	Christian Neukirchen <chneukirchen@gmail.com>
 	Christian Svensson <blue@cmd.nu>
@@ -83,6 +85,7 @@ strace-devel@lists.strace.io mailing lis
 	Eugeniy Paltsev <Eugeniy.Paltsev@synopsys.com>
 	Ezequiel Garcia <ezequiel@vanguardiasur.com.ar>
 	Fabien Siron <fabien.siron@epita.fr>
+	Fabrice Fontaine <fontaine.fabrice@gmail.com>
 	Fanda Uchytil <strace.t8xuewpmde@h4x.cz>
 	Fei Jie <feij.fnst@cn.fujitsu.com>
 	Felix Janda <felix.janda@posteo.de>
@@ -116,6 +119,7 @@ strace-devel@lists.strace.io mailing lis
 	James Hogan <james.hogan@imgtec.com>
 	James Yang <james.yang@freescale.com>
 	Jan Kratochvil <jan.kratochvil@redhat.com>
+	Jann Horn <jannh@google.com>
 	Janosch Frank <frankja@linux.ibm.com>
 	JayRJoshi <jay.r.joshi100@gmail.com>
 	Jeff Law <law@redhat.com>
@@ -137,6 +141,7 @@ strace-devel@lists.strace.io mailing lis
 	Katerina Koukiou <k.koukiou@googlemail.com>
 	Keith Owens <kaos.ocs@gmail.com>
 	Keith Thompson <kst@alsys.com>
+	Kemeng Shi <shikemeng@huawei.com>
 	Khem Raj <raj.khem@gmail.com>
 	Kirill A. Shutemov <kirill@shutemov.name>
 	Kyle McMartin <kyle@mcmartin.ca>
@@ -149,6 +154,7 @@ strace-devel@lists.strace.io mailing lis
 	Lubomir Rintel <lkundrak@v3.sk>
 	Luca Clementi <luca.clementi@gmail.com>
 	Lupe Christoph <lupe@alanya.isar.muc.de>
+	Ma Jun <majun258@linux.alibaba.com>
 	Maarten ter Huurne <maarten@treewalker.org>
 	Mark Hills <mark.hills@framestore.com>
 	Mark Wielaard <mjw@redhat.com>
@@ -158,6 +164,7 @@ strace-devel@lists.strace.io mailing lis
 	Matt Day <mday@artisoft.com>
 	Matthias Pfaller <leo@dachau.marco.de>
 	Max Filippov <jcmvbkbc@gmail.com>
+	Maxim Akhmedov <max42@yandex-team.ru>
 	Maxim Shchetynin <maxim@de.ibm.com>
 	Maxin B. John <maxin.john@enea.com>
 	Md Haris Iqbal <haris.phnx@gmail.com>
@@ -170,6 +177,7 @@ strace-devel@lists.strace.io mailing lis
 	Michal Sekletar <msekleta@redhat.com>
 	Michal Simek <monstr@monstr.eu>
 	Mike Frysinger <vapier@gentoo.org>
+	Mike Gilbert <floppym@gentoo.org>
 	Mike Stroyan <mike.stroyan@hp.com>
 	Mikulas Patocka <mpatocka@redhat.com>
 	Miroslav Lichvar <mlichvar@redhat.com>
@@ -179,6 +187,7 @@ strace-devel@lists.strace.io mailing lis
 	Nate Eldredge <nate@cartsys.com>
 	Nate Sammons <nate@users.sourceforge.net>
 	Neil Campbell <lists@thebatcave.org.uk>
+	Niklas Cathor <niklas.cathor@gmx.de>
 	Nikolay Marchuk <marchuk.nikolay.a@gmail.com>
 	Orion Poplawski <orion@cora.nwra.com>
 	Paolo Bonzini <pbonzini@redhat.com>
@@ -212,6 +221,7 @@ strace-devel@lists.strace.io mailing lis
 	Roland McGrath <roland@redhat.com>
 	Rolf Eike Beer <eb@emlix.com>
 	Romain Naour <romain.naour@smile.fr>
+	Ruinland ChuanTzu Tsai <ruinland@andestech.com>
 	Sami Farin <safari@u.safari.iki.fi>
 	Sandhya Bankar <bankarsandhya512@gmail.com>
 	Scott Tsai <scottt958@yahoo.com.tw>
@@ -227,8 +237,10 @@ strace-devel@lists.strace.io mailing lis
 	Stanislav Brabec <sbrabec@suse.cz>
 	Stefan Sørensen <stefan.sorensen@spectralink.com>
 	Steve Bennett <steveb@workware.net.au>
+	Steve Langasek <steve.langasek@ubuntu.com>
 	Steve McIntyre <steve@einval.com>
 	Steven Honeyman <stevenhoneyman@gmail.com>
+	Sven Schnelle <svens@stackframe.org>
 	Szabolcs Nagy <nsz@port70.net>
 	Thanh Ma <tma@encore.com>
 	Thiemo Seufer <ths@networkno.de>
@@ -238,6 +250,7 @@ strace-devel@lists.strace.io mailing lis
 	Tim Yamin <plasmaroo@gentoo.org>
 	Timo Lindfors <timo.lindfors@iki.fi>
 	Tom Dyas <tdyas@eden.rutgers.edu>
+	Tom Stellard <tstellar@redhat.com>
 	Tommi Rantala <ext-tommi.1.rantala@nokia.com>
 	Topi Miettinen <Topi.Miettinen@nic.fi>
 	Tuan Hoang <tmhoang@linux.ibm.com>
@@ -259,4 +272,5 @@ strace-devel@lists.strace.io mailing lis
 	Zhang Le <robert.zhangle@gmail.com>
 	Zhibin Li <haoyouab@gmail.com>
 	Zubin Mithra <zubin.mithra@gmail.com>
+	Ákos Uzonyi <uzonyi.akos@gmail.com>
 	Марк Коренберг <socketpair@gmail.com>
diff -pruN 5.5-3/debian/changelog 5.9-0ubuntu2/debian/changelog
--- 5.5-3/debian/changelog	2020-04-07 14:17:29.000000000 +0000
+++ 5.9-0ubuntu2/debian/changelog	2020-10-26 14:50:39.000000000 +0000
@@ -1,3 +1,31 @@
+strace (5.9-0ubuntu2) hirsute; urgency=medium
+
+  * Really XFAIL failing m32 tests
+
+ -- Balint Reczey <rbalint@ubuntu.com>  Mon, 26 Oct 2020 15:50:39 +0100
+
+strace (5.9-0ubuntu1) hirsute; urgency=medium
+
+  * debian/gitlab-ci.yml: Add simple Salsa CI configuration
+  * New upstream version 5.9
+  * Refresh patches
+  * Fix s390_sthyi response decoding to fix FTBFS on s390x
+  * debian/rules: Skip tests on riscv64
+  * Update failing tests.
+    Drop XFAILs for riscv64 because tests are skipped there.
+
+ -- Balint Reczey <rbalint@ubuntu.com>  Mon, 19 Oct 2020 11:59:15 +0200
+
+strace (5.5-3ubuntu1) focal; urgency=medium
+
+  * Merge from Debian unstable.  Remaining changes:
+    - Apply ptrace-error-verbosity.patch
+    - also filter kexec_file_load out of the list of programs to run for other
+      tests.
+  * XFAIL multiple tests with CPU timeout to fix FTBFS on riscv64
+
+ -- Balint Reczey <rbalint@ubuntu.com>  Fri, 17 Apr 2020 00:23:25 +0200
+
 strace (5.5-3) unstable; urgency=medium
 
   * Take more upstream patches to fix mipsel test failures
@@ -20,6 +48,33 @@ strace (5.5-1) unstable; urgency=medium
 
  -- Steve McIntyre <93sam@debian.org>  Thu, 26 Mar 2020 10:30:07 +0100
 
+strace (4.26-0.2ubuntu3) eoan; urgency=medium
+
+  * also filter kexec_file_load out of the list of programs to run for other
+    tests.
+
+ -- Steve Langasek <steve.langasek@ubuntu.com>  Fri, 03 May 2019 05:19:49 +0000
+
+strace (4.26-0.2ubuntu2) eoan; urgency=medium
+
+  * debian/patches/kexec_file_load.patch: reintroduce now for arm64, which
+    has added the syscall only in Linux 5.0 and later, so has the same
+    problem as before with the split between kernel build headers and
+    runtime kernel.
+
+ -- Steve Langasek <steve.langasek@ubuntu.com>  Thu, 02 May 2019 17:55:57 -0700
+
+strace (4.26-0.2ubuntu1) eoan; urgency=low
+
+  * Merge from Debian unstable.  Remaining changes:
+    - Apply ptrace-error-verbosity.patch
+  * Drop kexec_file_load.patch; was already disabled in previous
+    versions, and causes no problems since we are consistently building/
+    testing devel against a much newer kernel than 4.11.
+  * Drop fix-glibc-ftbfs.patch, fixed differently upstream.
+
+ -- Steve Langasek <steve.langasek@ubuntu.com>  Thu, 02 May 2019 16:50:08 -0700
+
 strace (4.26-0.2) unstable; urgency=medium
 
   * Non-maintainer upload.
@@ -42,6 +97,26 @@ strace (4.26-0.1) unstable; urgency=medi
 
  -- Andreas Henriksson <andreas@fatal.se>  Sat, 12 Jan 2019 20:32:27 +0100
 
+strace (4.25-0ubuntu1) disco; urgency=medium
+
+  * New upstream version.
+
+ -- Matthias Klose <doko@ubuntu.com>  Sat, 24 Nov 2018 14:27:33 +0100
+
+strace (4.21-1ubuntu2) cosmic; urgency=medium
+
+  * Fix ftbfs with new glibc, statx is now defined.
+
+ -- Dimitri John Ledkov <xnox@ubuntu.com>  Thu, 04 Oct 2018 17:03:56 +0100
+
+strace (4.21-1ubuntu1) bionic; urgency=medium
+
+  * Merge with Debian; remaining changes:
+    - Apply ptrace-error-verbosity.patch
+    - kexec_file_load.patch: Skip kexec_file_load test on ppc* before 4.11.
+
+ -- Matthias Klose <doko@ubuntu.com>  Wed, 11 Apr 2018 16:18:47 +0200
+
 strace (4.21-1) unstable; urgency=medium
 
   * New upstream release(s)
@@ -74,6 +149,24 @@ strace (4.21-1) unstable; urgency=medium
 
  -- Steve McIntyre <93sam@debian.org>  Mon, 19 Feb 2018 14:59:09 +0000
 
+strace (4.19-1ubuntu2) bionic; urgency=medium
+
+  * debian/patches/tests-fix-llseek-test.patch: Cherry pick upstream commit
+    3d2a5884ce6311834ae16729e2b01ccf3625c6dd to fix llseek test on armhf
+
+ -- Julian Andres Klode <juliank@ubuntu.com>  Tue, 23 Jan 2018 12:53:51 +0100
+
+strace (4.19-1ubuntu1) bionic; urgency=low
+
+  * Merge from Debian unstable.  Remaining changes:
+    - Apply ptrace-error-verbosity.patch
+    - debian/patches/no-arm-unaligned-access: Don't allow unaligned access
+      on ARM in the tests.
+    - kexec_file_load.patch: Skip kexec_file_load test on ppc* before 4.11.
+    - debian/control: Use linux-any for architecture fields
+
+ -- Julian Andres Klode <juliank@ubuntu.com>  Fri, 12 Jan 2018 18:21:49 +0100
+
 strace (4.19-1) unstable; urgency=medium
 
   * New upstream release(s)
@@ -82,6 +175,26 @@ strace (4.19-1) unstable; urgency=medium
 
  -- Steve McIntyre <93sam@debian.org>  Wed, 01 Nov 2017 02:29:18 +0000
 
+strace (4.15-2ubuntu3) artful; urgency=medium
+
+  * kexec_file_load.patch: Skip kexec_file_load test on ppc* before 4.11.
+
+ -- Adam Conrad <adconrad@ubuntu.com>  Sat, 17 Jun 2017 11:12:39 -0600
+
+strace (4.15-2ubuntu2) artful; urgency=medium
+
+  * debian/patches/no-arm-unaligned-access: Don't allow unaligned access
+    on ARM in the tests.
+
+ -- Steve Langasek <steve.langasek@ubuntu.com>  Thu, 15 Jun 2017 21:57:41 -0700
+
+strace (4.15-2ubuntu1) zesty; urgency=low
+
+  * Merge from Debian unstable.  Remaining changes:
+    - Apply ptrace-error-verbosity.patch
+
+ -- Dimitri John Ledkov <xnox@ubuntu.com>  Thu, 19 Jan 2017 14:02:00 +0000
+
 strace (4.15-2) unstable; urgency=medium
 
   * Disable some tests on hppa too
@@ -128,6 +241,15 @@ strace (4.13-1) unstable; urgency=medium
 
  -- Dmitry V. Levin <ldv@altlinux.org>  Tue, 26 Jul 2016 16:17:18 +0000
 
+strace (4.12-3ubuntu1) yakkety; urgency=medium
+
+  * Merge from Debian unstalbe.  Remaining changes:
+    - Apply ptrace-error-verbosity.patch
+
+  * Drop lseek patch, no longer needed.
+
+ -- Dimitri John Ledkov <xnox@ubuntu.com>  Fri, 12 Aug 2016 11:08:03 +0100
+
 strace (4.12-3) unstable; urgency=medium
 
   * Fix up 32/64-bit test output in strace -S test to fix i386 build
@@ -154,6 +276,19 @@ strace (4.12-1) unstable; urgency=low
 
  -- Steve McIntyre <93sam@debian.org>  Fri, 03 Jun 2016 00:18:40 +0100
 
+strace (4.11-1ubuntu3) xenial; urgency=high
+
+  * Patch lseek test-suite to ignore libc generated lseek calls.
+
+ -- Dimitri John Ledkov <xnox@ubuntu.com>  Wed, 13 Jan 2016 14:51:01 +0000
+
+strace (4.11-1ubuntu2) xenial; urgency=high
+
+  * Merge from Debian unstable.  Remaining changes:
+    - Apply ptrace-error-verbosity.patch    
+
+ -- Dimitri John Ledkov <xnox@ubuntu.com>  Tue, 12 Jan 2016 16:03:48 +0000
+
 strace (4.11-1) unstable; urgency=low
 
   [ Dmitry V. Levin ]
@@ -167,6 +302,17 @@ strace (4.11-1) unstable; urgency=low
 
  -- Steve McIntyre <93sam@debian.org>  Fri, 08 Jan 2015 00:52:05 +0000
 
+strace (4.10-3ubuntu1) xenial; urgency=high
+
+  * Merge from Debian, remaining changes are:
+    - Apply ptrace-error-verbosity.patch
+    - Set architectures to linux-any
+  * New upstream release:
+    - Remaining patches dropped
+    - Autoreconf changes dropped
+
+ -- Dimitri John Ledkov <xnox@ubuntu.com>  Mon, 14 Dec 2015 13:46:13 +0000
+
 strace (4.10-3) unstable; urgency=medium
 
   * Really fix mips* builds - fix sys_syscall() handling.
@@ -1015,7 +1161,6 @@ strace (3.1-3) unstable; urgency=low
 
  -- Wichert Akkerman <wakkerma@wi.leidenuniv.nl>  Thu, 11 Jul 1996 20:19:11 +0200
 
-
 strace (3.1-2) unstable; urgency=low
 
   * Added some #ifdef's around IPX stuff to make it compilable on non-Linux
@@ -1038,3 +1183,4 @@ strace (3.1-1) unstable; urgency=low
   * added IPX support
 
  -- Wichert Akkerman <wakkerma@wi.leidenuniv.nl>  Thu, 1 Jun 1996 00:00:00 +0000
+
diff -pruN 5.5-3/debian/control 5.9-0ubuntu2/debian/control
--- 5.5-3/debian/control	2020-04-07 14:17:29.000000000 +0000
+++ 5.9-0ubuntu2/debian/control	2020-10-26 14:50:39.000000000 +0000
@@ -1,5 +1,6 @@
 Source: strace
-Maintainer: Steve McIntyre <93sam@debian.org>
+Maintainer: Ubuntu Developers <ubuntu-devel-discuss@lists.ubuntu.com>
+XSBC-Original-Maintainer: Steve McIntyre <93sam@debian.org>
 Section: utils
 Priority: optional
 Build-Depends: libc6-dev (>= 2.2.2) [!alpha !ia64], libc6.1-dev (>= 2.2.2) [alpha ia64], gcc-multilib [amd64 i386 powerpc ppc64 s390 sparc sparc64 x32], debhelper (>= 10.0.0), gawk, libunwind-dev [amd64], libiberty-dev [amd64], libbluetooth-dev
diff -pruN 5.5-3/debian/gitlab-ci.yml 5.9-0ubuntu2/debian/gitlab-ci.yml
--- 5.5-3/debian/gitlab-ci.yml	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/debian/gitlab-ci.yml	2020-10-26 14:50:39.000000000 +0000
@@ -0,0 +1,3 @@
+include:
+  - https://salsa.debian.org/salsa-ci-team/pipeline/raw/master/salsa-ci.yml
+  - https://salsa.debian.org/salsa-ci-team/pipeline/raw/master/pipeline-jobs.yml
diff -pruN 5.5-3/debian/patches/0005-XFAIL-tests-on-m-32-which-use-struct-shm_info-or-s.patch 5.9-0ubuntu2/debian/patches/0005-XFAIL-tests-on-m-32-which-use-struct-shm_info-or-s.patch
--- 5.5-3/debian/patches/0005-XFAIL-tests-on-m-32-which-use-struct-shm_info-or-s.patch	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/debian/patches/0005-XFAIL-tests-on-m-32-which-use-struct-shm_info-or-s.patch	2020-10-26 14:50:39.000000000 +0000
@@ -0,0 +1,181 @@
+From: Balint Reczey <balint.reczey@canonical.com>
+Date: Fri, 16 Oct 2020 18:25:23 +0200
+Subject: XFAIL tests on m32 which use struct shm_info or struct msginfo
+
+---
+ tests-m32/Makefile.am  | 9 ++++++++-
+ tests-m32/Makefile.in  | 9 ++++++++-
+ tests-mx32/Makefile.am | 9 ++++++++-
+ tests-mx32/Makefile.in | 9 ++++++++-
+ tests/Makefile.am      | 9 ++++++++-
+ tests/Makefile.in      | 9 ++++++++-
+ 6 files changed, 48 insertions(+), 6 deletions(-)
+
+diff --git a/tests-m32/Makefile.am b/tests-m32/Makefile.am
+index be704c0..4947ab8 100644
+--- a/tests-m32/Makefile.am
++++ b/tests-m32/Makefile.am
+@@ -324,6 +324,10 @@ else
+ STACKTRACE_TESTS =
+ endif
+ 
++# struct shm_info and struct msginfo differ on 32 and 64 bit architectures
++IPC_INFO_TESTS = ipc_msg.gen.test ipc_msg-Xabbrev.gen.test ipc_msg-Xraw.gen.test ipc_msg-Xverbose.gen.test
++SHM_INFO_TESTS = ipc_shm.gen.test ipc_shm-Xabbrev.gen.test ipc_shm-Xraw.gen.test ipc_shm-Xverbose.gen.test
++
+ DECODER_TESTS = \
+ 	bpf-success-long-y.test \
+ 	bpf-success-v.test \
+@@ -482,8 +486,11 @@ MISC_TESTS = \
+ 
+ TESTS = $(GEN_TESTS) $(DECODER_TESTS) $(MISC_TESTS) $(STACKTRACE_TESTS)
+ 
++# armhf builds run on arm64 kernel making those tests fail
++XFAIL_TESTS_arm = $(SHM_INFO_TESTS) $(IPC_INFO_TESTS)
++
+ XFAIL_TESTS_ =
+-XFAIL_TESTS_m32 = $(STACKTRACE_TESTS)
++XFAIL_TESTS_m32 = $(STACKTRACE_TESTS) $(SHM_INFO_TESTS) $(IPC_INFO_TESTS)
+ XFAIL_TESTS_mx32 = $(STACKTRACE_TESTS)
+ XFAIL_TESTS = $(XFAIL_TESTS_$(MPERS_NAME)) $(XFAIL_TESTS_$(ARCH))
+ 
+diff --git a/tests-m32/Makefile.in b/tests-m32/Makefile.in
+index defaf83..bed61c2 100644
+--- a/tests-m32/Makefile.in
++++ b/tests-m32/Makefile.in
+@@ -6609,6 +6609,10 @@ GEN_TESTS = _newselect.gen.test _newselect-P.gen.test accept.gen.test \
+ @ENABLE_STACKTRACE_FALSE@STACKTRACE_TESTS = 
+ @ENABLE_STACKTRACE_TRUE@STACKTRACE_TESTS = strace-k.test \
+ @ENABLE_STACKTRACE_TRUE@	strace-k-p.test $(am__append_1)
++
++# struct shm_info and struct msginfo differ on 32 and 64 bit architectures
++IPC_INFO_TESTS = ipc_msg.gen.test ipc_msg-Xabbrev.gen.test ipc_msg-Xraw.gen.test ipc_msg-Xverbose.gen.test
++SHM_INFO_TESTS = ipc_shm.gen.test ipc_shm-Xabbrev.gen.test ipc_shm-Xraw.gen.test ipc_shm-Xverbose.gen.test
+ DECODER_TESTS = \
+ 	bpf-success-long-y.test \
+ 	bpf-success-v.test \
+@@ -6765,8 +6769,11 @@ MISC_TESTS = \
+ 	umovestr_cached.test \
+ 	# end of MISC_TESTS
+ 
++# armhf builds run on arm64 kernel making those tests fail
++XFAIL_TESTS_arm = $(SHM_INFO_TESTS) $(IPC_INFO_TESTS)
++
+ XFAIL_TESTS_ = 
+-XFAIL_TESTS_m32 = $(STACKTRACE_TESTS)
++XFAIL_TESTS_m32 = $(STACKTRACE_TESTS) $(SHM_INFO_TESTS) $(IPC_INFO_TESTS)
+ XFAIL_TESTS_mx32 = $(STACKTRACE_TESTS)
+ XFAIL_TESTS = $(XFAIL_TESTS_$(MPERS_NAME)) $(XFAIL_TESTS_$(ARCH))
+ TEST_LOG_COMPILER = env
+diff --git a/tests-mx32/Makefile.am b/tests-mx32/Makefile.am
+index ec6fd73..c16bff9 100644
+--- a/tests-mx32/Makefile.am
++++ b/tests-mx32/Makefile.am
+@@ -324,6 +324,10 @@ else
+ STACKTRACE_TESTS =
+ endif
+ 
++# struct shm_info and struct msginfo differ on 32 and 64 bit architectures
++IPC_INFO_TESTS = ipc_msg.gen.test ipc_msg-Xabbrev.gen.test ipc_msg-Xraw.gen.test ipc_msg-Xverbose.gen.test
++SHM_INFO_TESTS = ipc_shm.gen.test ipc_shm-Xabbrev.gen.test ipc_shm-Xraw.gen.test ipc_shm-Xverbose.gen.test
++
+ DECODER_TESTS = \
+ 	bpf-success-long-y.test \
+ 	bpf-success-v.test \
+@@ -482,8 +486,11 @@ MISC_TESTS = \
+ 
+ TESTS = $(GEN_TESTS) $(DECODER_TESTS) $(MISC_TESTS) $(STACKTRACE_TESTS)
+ 
++# armhf builds run on arm64 kernel making those tests fail
++XFAIL_TESTS_arm = $(SHM_INFO_TESTS) $(IPC_INFO_TESTS)
++
+ XFAIL_TESTS_ =
+-XFAIL_TESTS_m32 = $(STACKTRACE_TESTS)
++XFAIL_TESTS_m32 = $(STACKTRACE_TESTS) $(SHM_INFO_TESTS) $(IPC_INFO_TESTS)
+ XFAIL_TESTS_mx32 = $(STACKTRACE_TESTS)
+ XFAIL_TESTS = $(XFAIL_TESTS_$(MPERS_NAME)) $(XFAIL_TESTS_$(ARCH))
+ 
+diff --git a/tests-mx32/Makefile.in b/tests-mx32/Makefile.in
+index db08967..b1e3e62 100644
+--- a/tests-mx32/Makefile.in
++++ b/tests-mx32/Makefile.in
+@@ -6609,6 +6609,10 @@ GEN_TESTS = _newselect.gen.test _newselect-P.gen.test accept.gen.test \
+ @ENABLE_STACKTRACE_FALSE@STACKTRACE_TESTS = 
+ @ENABLE_STACKTRACE_TRUE@STACKTRACE_TESTS = strace-k.test \
+ @ENABLE_STACKTRACE_TRUE@	strace-k-p.test $(am__append_1)
++
++# struct shm_info and struct msginfo differ on 32 and 64 bit architectures
++IPC_INFO_TESTS = ipc_msg.gen.test ipc_msg-Xabbrev.gen.test ipc_msg-Xraw.gen.test ipc_msg-Xverbose.gen.test
++SHM_INFO_TESTS = ipc_shm.gen.test ipc_shm-Xabbrev.gen.test ipc_shm-Xraw.gen.test ipc_shm-Xverbose.gen.test
+ DECODER_TESTS = \
+ 	bpf-success-long-y.test \
+ 	bpf-success-v.test \
+@@ -6765,8 +6769,11 @@ MISC_TESTS = \
+ 	umovestr_cached.test \
+ 	# end of MISC_TESTS
+ 
++# armhf builds run on arm64 kernel making those tests fail
++XFAIL_TESTS_arm = $(SHM_INFO_TESTS) $(IPC_INFO_TESTS)
++
+ XFAIL_TESTS_ = 
+-XFAIL_TESTS_m32 = $(STACKTRACE_TESTS)
++XFAIL_TESTS_m32 = $(STACKTRACE_TESTS) $(SHM_INFO_TESTS) $(IPC_INFO_TESTS)
+ XFAIL_TESTS_mx32 = $(STACKTRACE_TESTS)
+ XFAIL_TESTS = $(XFAIL_TESTS_$(MPERS_NAME)) $(XFAIL_TESTS_$(ARCH))
+ TEST_LOG_COMPILER = env
+diff --git a/tests/Makefile.am b/tests/Makefile.am
+index 17f4b42..75e8e5d 100644
+--- a/tests/Makefile.am
++++ b/tests/Makefile.am
+@@ -324,6 +324,10 @@ else
+ STACKTRACE_TESTS =
+ endif
+ 
++# struct shm_info and struct msginfo differ on 32 and 64 bit architectures
++IPC_INFO_TESTS = ipc_msg.gen.test ipc_msg-Xabbrev.gen.test ipc_msg-Xraw.gen.test ipc_msg-Xverbose.gen.test
++SHM_INFO_TESTS = ipc_shm.gen.test ipc_shm-Xabbrev.gen.test ipc_shm-Xraw.gen.test ipc_shm-Xverbose.gen.test
++
+ DECODER_TESTS = \
+ 	bpf-success-long-y.test \
+ 	bpf-success-v.test \
+@@ -482,8 +486,11 @@ MISC_TESTS = \
+ 
+ TESTS = $(GEN_TESTS) $(DECODER_TESTS) $(MISC_TESTS) $(STACKTRACE_TESTS)
+ 
++# armhf builds run on arm64 kernel making those tests fail
++XFAIL_TESTS_arm = $(SHM_INFO_TESTS) $(IPC_INFO_TESTS)
++
+ XFAIL_TESTS_ =
+-XFAIL_TESTS_m32 = $(STACKTRACE_TESTS)
++XFAIL_TESTS_m32 = $(STACKTRACE_TESTS) $(SHM_INFO_TESTS) $(IPC_INFO_TESTS)
+ XFAIL_TESTS_mx32 = $(STACKTRACE_TESTS)
+ XFAIL_TESTS = $(XFAIL_TESTS_$(MPERS_NAME)) $(XFAIL_TESTS_$(ARCH))
+ 
+diff --git a/tests/Makefile.in b/tests/Makefile.in
+index d97c8c3..8b12715 100644
+--- a/tests/Makefile.in
++++ b/tests/Makefile.in
+@@ -6609,6 +6609,10 @@ GEN_TESTS = _newselect.gen.test _newselect-P.gen.test accept.gen.test \
+ @ENABLE_STACKTRACE_FALSE@STACKTRACE_TESTS = 
+ @ENABLE_STACKTRACE_TRUE@STACKTRACE_TESTS = strace-k.test \
+ @ENABLE_STACKTRACE_TRUE@	strace-k-p.test $(am__append_1)
++
++# struct shm_info and struct msginfo differ on 32 and 64 bit architectures
++IPC_INFO_TESTS = ipc_msg.gen.test ipc_msg-Xabbrev.gen.test ipc_msg-Xraw.gen.test ipc_msg-Xverbose.gen.test
++SHM_INFO_TESTS = ipc_shm.gen.test ipc_shm-Xabbrev.gen.test ipc_shm-Xraw.gen.test ipc_shm-Xverbose.gen.test
+ DECODER_TESTS = \
+ 	bpf-success-long-y.test \
+ 	bpf-success-v.test \
+@@ -6765,8 +6769,11 @@ MISC_TESTS = \
+ 	umovestr_cached.test \
+ 	# end of MISC_TESTS
+ 
++# armhf builds run on arm64 kernel making those tests fail
++XFAIL_TESTS_arm = $(SHM_INFO_TESTS) $(IPC_INFO_TESTS)
++
+ XFAIL_TESTS_ = 
+-XFAIL_TESTS_m32 = $(STACKTRACE_TESTS)
++XFAIL_TESTS_m32 = $(STACKTRACE_TESTS) $(SHM_INFO_TESTS) $(IPC_INFO_TESTS)
+ XFAIL_TESTS_mx32 = $(STACKTRACE_TESTS)
+ XFAIL_TESTS = $(XFAIL_TESTS_$(MPERS_NAME)) $(XFAIL_TESTS_$(ARCH))
+ TEST_LOG_COMPILER = env
diff -pruN 5.5-3/debian/patches/0006-s390-Check-infmname-with-IS_ARRAY_ZERO-too.patch 5.9-0ubuntu2/debian/patches/0006-s390-Check-infmname-with-IS_ARRAY_ZERO-too.patch
--- 5.5-3/debian/patches/0006-s390-Check-infmname-with-IS_ARRAY_ZERO-too.patch	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/debian/patches/0006-s390-Check-infmname-with-IS_ARRAY_ZERO-too.patch	2020-10-26 14:50:39.000000000 +0000
@@ -0,0 +1,24 @@
+From: Balint Reczey <balint.reczey@canonical.com>
+Date: Thu, 15 Oct 2020 19:33:31 +0200
+Subject: s390: Check infmname with IS_ARRAY_ZERO, too
+
+Otherwise the s390_sthyi test fails showing the zero array.
+---
+ s390.c | 3 +--
+ 1 file changed, 1 insertion(+), 2 deletions(-)
+
+diff --git a/s390.c b/s390.c
+index 5864b54..157c3fe 100644
+--- a/s390.c
++++ b/s390.c
+@@ -557,9 +557,8 @@ print_sthyi_machine(struct tcb *tcp, struct sthyi_machine *hdr, uint16_t size,
+ 		PRINT_FIELD_U(", ", *hdr, infmdifl);
+ 
+ 	if (!abbrev(tcp)) {
+-		if (name_val || hdr->infmname)
++		if (name_val || !IS_ARRAY_ZERO(hdr->infmname))
+ 			PRINT_FIELD_EBCDIC(", ", *hdr, infmname);
+-
+ 		if (id_val || !IS_ARRAY_ZERO(hdr->infmtype))
+ 			PRINT_FIELD_EBCDIC(", ", *hdr, infmtype);
+ 		if (id_val || !IS_ARRAY_ZERO(hdr->infmmanu))
diff -pruN 5.5-3/debian/patches/01-fix_strace-DDD_test 5.9-0ubuntu2/debian/patches/01-fix_strace-DDD_test
--- 5.5-3/debian/patches/01-fix_strace-DDD_test	2020-04-07 14:17:29.000000000 +0000
+++ 5.9-0ubuntu2/debian/patches/01-fix_strace-DDD_test	1970-01-01 00:00:00.000000000 +0000
@@ -1,1185 +0,0 @@
-Fix problems with strace-DDD.test. Start with this commit from
-upstream:
-
-commit 00a29af7081ef4a7c4e5b538290b4a21fed5ef38
-Author: Dmitry V. Levin <ldv@altlinux.org>
-Date:   Sat Mar 28 16:57:34 2020 +0000
-
-    tests: fix strace-DDD.test for the case when strace has a process subreaper
-    
-    The test used to assume that the process reaper has pid 1, which is not
-    necessarily the case, e.g. there might be a process subreaper different
-    from pid 1.
-    
-    * tests/get_process_reaper.c: New file.
-    * tests/Makefile.am (check_PROGRAMS): Add get_process_reaper.
-    * tests/.gitignore: Likewise.
-    * tests/strace-DDD.test: Invoke get_process_reaper to find out
-    the process reaper id, use the latter in subsequent checks
-    instead of pid 1.
-    
-    References: https://bugs.debian.org/947396
-    Resolves: https://github.com/strace/strace/issues/129
-
-But then we have to expand the patch from tests/Makefile.am to
-tests{,-m32,-mx32}/Makefile.{am,in}. Messy, but that's the cost of
-making these changes after bootstrap/automake/autoconf.
-
-diff --git a/tests/Makefile.am b/tests/Makefile.am
-index f2a5bc6d8..8a5819de2 100644
---- a/tests/Makefile.am
-+++ b/tests/Makefile.am
-@@ -111,6 +111,7 @@ check_PROGRAMS = $(PURE_EXECUTABLES) \
- 	filter-unavailable \
- 	fork-f \
- 	fsync-y \
-+	get_process_reaper \
- 	getpid	\
- 	getppid	\
- 	gettid \
-diff --git a/tests/get_process_reaper.c b/tests/get_process_reaper.c
-new file mode 100644
-index 000000000..3c00c584b
---- /dev/null
-+++ b/tests/get_process_reaper.c
-@@ -0,0 +1,108 @@
-+/*
-+ * Print the process reaper id.
-+ *
-+ * Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
-+ * All rights reserved.
-+ *
-+ * SPDX-License-Identifier: GPL-2.0-or-later
-+ */
-+
-+#include "tests.h"
-+#include <stdio.h>
-+#include <unistd.h>
-+#include <sys/wait.h>
-+
-+/* PARENT - CHILD - GRANDCHILD */
-+
-+static int
-+grandchild(int read_fd, int write_fd)
-+{
-+	/* wait for notification from PARENT about CHILD completion */
-+	pid_t pid;
-+	if (read(read_fd, &pid, sizeof(pid)) != 0)
-+		perror_msg_and_fail("read");
-+
-+	/* write ppid to PARENT */
-+	pid = getppid();
-+	if (write(write_fd, &pid, sizeof(pid)) != sizeof(pid))
-+		perror_msg_and_fail("write");
-+
-+	_exit(0);
-+}
-+
-+static int
-+child(int read_fd, int write_fd)
-+{
-+	pid_t pid = fork();
-+	if (pid < 0)
-+		perror_msg_and_fail("fork");
-+
-+	if (!pid)
-+		return grandchild(read_fd, write_fd);
-+	else
-+		_exit(0);
-+}
-+
-+static int
-+parent(pid_t pid, int read_fd, int write_fd)
-+{
-+	/* wait for CHILD completion */
-+	int status;
-+	if (waitpid(pid, &status, 0) != pid)
-+		perror_msg_and_fail("waitpid");
-+	if (status != 0)
-+		error_msg_and_fail("status %x", status);
-+
-+	/* notify GRANDCHILD about CHILD completion */
-+	close(write_fd),
-+	      write_fd = -1;
-+
-+	/* read ppid of GRANDCHILD */
-+	if (read(read_fd, &pid, sizeof(pid)) != sizeof(pid))
-+		perror_msg_and_fail("read");
-+
-+	printf("%d\n", pid);
-+	return 0;
-+}
-+
-+int
-+main(void)
-+{
-+	int parent_grandchild_fds[2];
-+#define parent_read_fd		parent_grandchild_fds[0]
-+#define grandchild_write_fd	parent_grandchild_fds[1]
-+
-+	int grandchild_parent_fds[2];
-+#define	grandchild_read_fd	grandchild_parent_fds[0]
-+#define	parent_write_fd		grandchild_parent_fds[1]
-+
-+	if (pipe(parent_grandchild_fds) ||
-+	    pipe(grandchild_parent_fds))
-+		perror_msg_and_fail("pipe");
-+
-+	pid_t pid = fork();
-+	if (pid < 0)
-+		perror_msg_and_fail("fork");
-+
-+	if (!pid) {
-+		/* CHILD */
-+		close(parent_read_fd),
-+		      parent_read_fd = -1;
-+
-+		close(parent_write_fd),
-+		      parent_write_fd = -1;
-+
-+		return child(grandchild_read_fd,
-+			     grandchild_write_fd);
-+	} else {
-+		/* PARENT */
-+		close(grandchild_read_fd),
-+		      grandchild_read_fd = -1;
-+
-+		close(grandchild_write_fd),
-+		      grandchild_write_fd = -1;
-+
-+		return parent(pid, parent_read_fd,
-+				   parent_write_fd);
-+	}
-+}
-diff --git a/tests/strace-DDD.test b/tests/strace-DDD.test
-index e478ae5e8..671600bbe 100755
---- a/tests/strace-DDD.test
-+++ b/tests/strace-DDD.test
-@@ -19,10 +19,14 @@ stat_file=/proc/self/stat
- [ -f "$stat_file" ] ||
- 	framework_skip_ "$stat_file is not available"
- 
-+reapid="$(../get_process_reaper)" && [ "$reapid" -ge 1 ] ||
-+	fail_ 'get_process_reaper failed'
-+
- set -- -enone -esignal=none ../tracer_ppid_pgid_sid
- run_strace "$@" > "$OUT"
- read -r ppid pgid sid < "$OUT" &&
- [ "$ppid" -gt 1 ] &&
-+[ "$ppid" -ne "$reapid" ] &&
- [ "$pgid" -ge 0 ] &&
- [ "$sid" -ge 0 ] || {
- 	cat < "$OUT" > "$LOG"
-@@ -35,7 +39,7 @@ sid0="$sid"
- 
- run_strace -D "$@" > "$OUT"
- read -r ppid pgid sid < "$OUT" &&
--[ "$ppid" -eq 1 ] &&
-+[ "$ppid" -eq "$reapid" ] &&
- [ "$pgid" = "$pgid0" ] &&
- [ "$sid" = "$sid0" ] || {
- 	cat < "$OUT" > "$LOG"
-@@ -45,8 +49,9 @@ match_diff
- 
- run_strace -DD "$@" > "$OUT"
- read -r ppid pgid sid < "$OUT" &&
--[ "$ppid" -eq 1 ] &&
-+[ "$ppid" -eq "$reapid" ] &&
- [ "$pgid" -gt 1 ] &&
-+[ "$pgid" -ne "$reapid" ] &&
- [ "$pgid" != "$pgid0" ] &&
- [ "$pgid" != "$sid" ] &&
- [ "$sid" = "$sid0" ] || {
-@@ -57,8 +62,9 @@ match_diff
- 
- run_strace -DDD "$@" > "$OUT"
- read -r ppid pgid sid < "$OUT" &&
--[ "$ppid" -eq 1 ] &&
-+[ "$ppid" -eq "$reapid" ] &&
- [ "$pgid" -gt 1 ] &&
-+[ "$pgid" -ne "$reapid" ] &&
- [ "$pgid" != "$pgid0" ] &&
- [ "$sid" = "$pgid" ] &&
- [ "$sid" != "$sid0" ] || {
-diff --git a/tests/Makefile.in b/tests/Makefile.in
-index 309fe4443..783230ecc 100644
---- a/tests/Makefile.in
-+++ b/tests/Makefile.in
-@@ -118,9 +118,9 @@ check_PROGRAMS = $(am__EXEEXT_1) _newselect-P$(EXEEXT) answer$(EXEEXT) \
- 	count-f$(EXEEXT) delay$(EXEEXT) execve-v$(EXEEXT) \
- 	execveat-v$(EXEEXT) filter_seccomp-flag$(EXEEXT) \
- 	filter_seccomp-perf$(EXEEXT) filter-unavailable$(EXEEXT) \
--	fork-f$(EXEEXT) fsync-y$(EXEEXT) getpid$(EXEEXT) \
--	getppid$(EXEEXT) gettid$(EXEEXT) inject-nf$(EXEEXT) \
--	int_0x80$(EXEEXT) ioctl_dm-v$(EXEEXT) \
-+	fork-f$(EXEEXT) fsync-y$(EXEEXT) get_process_reaper$(EXEEXT) \
-+	getpid$(EXEEXT) getppid$(EXEEXT) gettid$(EXEEXT) \
-+	inject-nf$(EXEEXT) int_0x80$(EXEEXT) ioctl_dm-v$(EXEEXT) \
- 	ioctl_evdev-success$(EXEEXT) \
- 	ioctl_evdev-success-Xabbrev$(EXEEXT) \
- 	ioctl_evdev-success-Xraw$(EXEEXT) \
-@@ -944,6 +944,10 @@ get_mempolicy_SOURCES = get_mempolicy.c
- get_mempolicy_OBJECTS = get_mempolicy.$(OBJEXT)
- get_mempolicy_LDADD = $(LDADD)
- get_mempolicy_DEPENDENCIES = libtests.a
-+get_process_reaper_SOURCES = get_process_reaper.c
-+get_process_reaper_OBJECTS = get_process_reaper.$(OBJEXT)
-+get_process_reaper_LDADD = $(LDADD)
-+get_process_reaper_DEPENDENCIES = libtests.a
- getcpu_SOURCES = getcpu.c
- getcpu_OBJECTS = getcpu.$(OBJEXT)
- getcpu_LDADD = $(LDADD)
-@@ -3265,30 +3269,30 @@ am__depfiles_remade = ./$(DEPDIR)/_newselect-P.Po \
- 	./$(DEPDIR)/fsync.Po ./$(DEPDIR)/ftruncate.Po \
- 	./$(DEPDIR)/ftruncate64-ftruncate64.Po ./$(DEPDIR)/futex.Po \
- 	./$(DEPDIR)/futimesat.Po ./$(DEPDIR)/get_mempolicy.Po \
--	./$(DEPDIR)/getcpu.Po ./$(DEPDIR)/getcwd.Po \
--	./$(DEPDIR)/getdents.Po ./$(DEPDIR)/getdents64.Po \
--	./$(DEPDIR)/getegid.Po ./$(DEPDIR)/getegid32.Po \
--	./$(DEPDIR)/geteuid.Po ./$(DEPDIR)/geteuid32.Po \
--	./$(DEPDIR)/getgid.Po ./$(DEPDIR)/getgid32.Po \
--	./$(DEPDIR)/getgroups.Po ./$(DEPDIR)/getgroups32.Po \
--	./$(DEPDIR)/getpeername.Po ./$(DEPDIR)/getpgrp.Po \
--	./$(DEPDIR)/getpid.Po ./$(DEPDIR)/getppid.Po \
--	./$(DEPDIR)/getrandom.Po ./$(DEPDIR)/getresgid.Po \
--	./$(DEPDIR)/getresgid32.Po ./$(DEPDIR)/getresuid.Po \
--	./$(DEPDIR)/getresuid32.Po ./$(DEPDIR)/getrlimit.Po \
--	./$(DEPDIR)/getrusage.Po ./$(DEPDIR)/getsid.Po \
--	./$(DEPDIR)/getsockname.Po ./$(DEPDIR)/gettid.Po \
--	./$(DEPDIR)/getuid.Po ./$(DEPDIR)/getuid32.Po \
--	./$(DEPDIR)/getxxid.Po ./$(DEPDIR)/group_req.Po \
--	./$(DEPDIR)/inet-cmsg.Po ./$(DEPDIR)/init_module.Po \
--	./$(DEPDIR)/inject-nf.Po ./$(DEPDIR)/inotify.Po \
--	./$(DEPDIR)/inotify_init-y.Po ./$(DEPDIR)/inotify_init.Po \
--	./$(DEPDIR)/inotify_init1-y.Po ./$(DEPDIR)/inotify_init1.Po \
--	./$(DEPDIR)/int_0x80.Po ./$(DEPDIR)/io_uring_enter.Po \
--	./$(DEPDIR)/io_uring_register.Po ./$(DEPDIR)/io_uring_setup.Po \
--	./$(DEPDIR)/ioctl.Po ./$(DEPDIR)/ioctl_block.Po \
--	./$(DEPDIR)/ioctl_dm-v.Po ./$(DEPDIR)/ioctl_dm.Po \
--	./$(DEPDIR)/ioctl_evdev-Xabbrev.Po \
-+	./$(DEPDIR)/get_process_reaper.Po ./$(DEPDIR)/getcpu.Po \
-+	./$(DEPDIR)/getcwd.Po ./$(DEPDIR)/getdents.Po \
-+	./$(DEPDIR)/getdents64.Po ./$(DEPDIR)/getegid.Po \
-+	./$(DEPDIR)/getegid32.Po ./$(DEPDIR)/geteuid.Po \
-+	./$(DEPDIR)/geteuid32.Po ./$(DEPDIR)/getgid.Po \
-+	./$(DEPDIR)/getgid32.Po ./$(DEPDIR)/getgroups.Po \
-+	./$(DEPDIR)/getgroups32.Po ./$(DEPDIR)/getpeername.Po \
-+	./$(DEPDIR)/getpgrp.Po ./$(DEPDIR)/getpid.Po \
-+	./$(DEPDIR)/getppid.Po ./$(DEPDIR)/getrandom.Po \
-+	./$(DEPDIR)/getresgid.Po ./$(DEPDIR)/getresgid32.Po \
-+	./$(DEPDIR)/getresuid.Po ./$(DEPDIR)/getresuid32.Po \
-+	./$(DEPDIR)/getrlimit.Po ./$(DEPDIR)/getrusage.Po \
-+	./$(DEPDIR)/getsid.Po ./$(DEPDIR)/getsockname.Po \
-+	./$(DEPDIR)/gettid.Po ./$(DEPDIR)/getuid.Po \
-+	./$(DEPDIR)/getuid32.Po ./$(DEPDIR)/getxxid.Po \
-+	./$(DEPDIR)/group_req.Po ./$(DEPDIR)/inet-cmsg.Po \
-+	./$(DEPDIR)/init_module.Po ./$(DEPDIR)/inject-nf.Po \
-+	./$(DEPDIR)/inotify.Po ./$(DEPDIR)/inotify_init-y.Po \
-+	./$(DEPDIR)/inotify_init.Po ./$(DEPDIR)/inotify_init1-y.Po \
-+	./$(DEPDIR)/inotify_init1.Po ./$(DEPDIR)/int_0x80.Po \
-+	./$(DEPDIR)/io_uring_enter.Po ./$(DEPDIR)/io_uring_register.Po \
-+	./$(DEPDIR)/io_uring_setup.Po ./$(DEPDIR)/ioctl.Po \
-+	./$(DEPDIR)/ioctl_block.Po ./$(DEPDIR)/ioctl_dm-v.Po \
-+	./$(DEPDIR)/ioctl_dm.Po ./$(DEPDIR)/ioctl_evdev-Xabbrev.Po \
- 	./$(DEPDIR)/ioctl_evdev-Xraw.Po \
- 	./$(DEPDIR)/ioctl_evdev-Xverbose.Po \
- 	./$(DEPDIR)/ioctl_evdev-success-Xabbrev.Po \
-@@ -3689,23 +3693,24 @@ SOURCES = $(libtests_a_SOURCES) _newselect.c _newselect-P.c accept.c \
- 	fstat-Xverbose.c fstat64.c fstat64-Xabbrev.c fstat64-Xraw.c \
- 	fstat64-Xverbose.c fstatat64.c fstatfs.c fstatfs64.c fsync.c \
- 	fsync-y.c ftruncate.c ftruncate64.c futex.c futimesat.c \
--	get_mempolicy.c getcpu.c getcwd.c getdents.c getdents64.c \
--	getegid.c getegid32.c geteuid.c geteuid32.c getgid.c \
--	getgid32.c getgroups.c getgroups32.c getpeername.c getpgrp.c \
--	getpid.c getppid.c getrandom.c getresgid.c getresgid32.c \
--	getresuid.c getresuid32.c getrlimit.c getrusage.c getsid.c \
--	getsockname.c gettid.c getuid.c getuid32.c getxxid.c \
--	group_req.c inet-cmsg.c init_module.c inject-nf.c inotify.c \
--	inotify_init.c inotify_init-y.c inotify_init1.c \
--	inotify_init1-y.c int_0x80.c io_uring_enter.c \
--	io_uring_register.c io_uring_setup.c ioctl.c ioctl_block.c \
--	ioctl_dm.c ioctl_dm-v.c ioctl_evdev.c ioctl_evdev-Xabbrev.c \
--	ioctl_evdev-Xraw.c ioctl_evdev-Xverbose.c \
--	ioctl_evdev-success.c ioctl_evdev-success-Xabbrev.c \
--	ioctl_evdev-success-Xraw.c ioctl_evdev-success-Xverbose.c \
--	ioctl_evdev-success-v.c ioctl_evdev-success-v-Xabbrev.c \
--	ioctl_evdev-success-v-Xraw.c ioctl_evdev-success-v-Xverbose.c \
--	ioctl_evdev-v.c ioctl_evdev-v-Xabbrev.c ioctl_evdev-v-Xraw.c \
-+	get_mempolicy.c get_process_reaper.c getcpu.c getcwd.c \
-+	getdents.c getdents64.c getegid.c getegid32.c geteuid.c \
-+	geteuid32.c getgid.c getgid32.c getgroups.c getgroups32.c \
-+	getpeername.c getpgrp.c getpid.c getppid.c getrandom.c \
-+	getresgid.c getresgid32.c getresuid.c getresuid32.c \
-+	getrlimit.c getrusage.c getsid.c getsockname.c gettid.c \
-+	getuid.c getuid32.c getxxid.c group_req.c inet-cmsg.c \
-+	init_module.c inject-nf.c inotify.c inotify_init.c \
-+	inotify_init-y.c inotify_init1.c inotify_init1-y.c int_0x80.c \
-+	io_uring_enter.c io_uring_register.c io_uring_setup.c ioctl.c \
-+	ioctl_block.c ioctl_dm.c ioctl_dm-v.c ioctl_evdev.c \
-+	ioctl_evdev-Xabbrev.c ioctl_evdev-Xraw.c \
-+	ioctl_evdev-Xverbose.c ioctl_evdev-success.c \
-+	ioctl_evdev-success-Xabbrev.c ioctl_evdev-success-Xraw.c \
-+	ioctl_evdev-success-Xverbose.c ioctl_evdev-success-v.c \
-+	ioctl_evdev-success-v-Xabbrev.c ioctl_evdev-success-v-Xraw.c \
-+	ioctl_evdev-success-v-Xverbose.c ioctl_evdev-v.c \
-+	ioctl_evdev-v-Xabbrev.c ioctl_evdev-v-Xraw.c \
- 	ioctl_evdev-v-Xverbose.c ioctl_inotify.c ioctl_kvm_run.c \
- 	ioctl_kvm_run-v.c ioctl_kvm_run_auxstr_vcpu.c ioctl_loop.c \
- 	ioctl_loop-nv.c ioctl_loop-v.c ioctl_mtd.c ioctl_nbd.c \
-@@ -3876,23 +3881,24 @@ DIST_SOURCES = $(libtests_a_SOURCES) _newselect.c _newselect-P.c \
- 	fstat-Xverbose.c fstat64.c fstat64-Xabbrev.c fstat64-Xraw.c \
- 	fstat64-Xverbose.c fstatat64.c fstatfs.c fstatfs64.c fsync.c \
- 	fsync-y.c ftruncate.c ftruncate64.c futex.c futimesat.c \
--	get_mempolicy.c getcpu.c getcwd.c getdents.c getdents64.c \
--	getegid.c getegid32.c geteuid.c geteuid32.c getgid.c \
--	getgid32.c getgroups.c getgroups32.c getpeername.c getpgrp.c \
--	getpid.c getppid.c getrandom.c getresgid.c getresgid32.c \
--	getresuid.c getresuid32.c getrlimit.c getrusage.c getsid.c \
--	getsockname.c gettid.c getuid.c getuid32.c getxxid.c \
--	group_req.c inet-cmsg.c init_module.c inject-nf.c inotify.c \
--	inotify_init.c inotify_init-y.c inotify_init1.c \
--	inotify_init1-y.c int_0x80.c io_uring_enter.c \
--	io_uring_register.c io_uring_setup.c ioctl.c ioctl_block.c \
--	ioctl_dm.c ioctl_dm-v.c ioctl_evdev.c ioctl_evdev-Xabbrev.c \
--	ioctl_evdev-Xraw.c ioctl_evdev-Xverbose.c \
--	ioctl_evdev-success.c ioctl_evdev-success-Xabbrev.c \
--	ioctl_evdev-success-Xraw.c ioctl_evdev-success-Xverbose.c \
--	ioctl_evdev-success-v.c ioctl_evdev-success-v-Xabbrev.c \
--	ioctl_evdev-success-v-Xraw.c ioctl_evdev-success-v-Xverbose.c \
--	ioctl_evdev-v.c ioctl_evdev-v-Xabbrev.c ioctl_evdev-v-Xraw.c \
-+	get_mempolicy.c get_process_reaper.c getcpu.c getcwd.c \
-+	getdents.c getdents64.c getegid.c getegid32.c geteuid.c \
-+	geteuid32.c getgid.c getgid32.c getgroups.c getgroups32.c \
-+	getpeername.c getpgrp.c getpid.c getppid.c getrandom.c \
-+	getresgid.c getresgid32.c getresuid.c getresuid32.c \
-+	getrlimit.c getrusage.c getsid.c getsockname.c gettid.c \
-+	getuid.c getuid32.c getxxid.c group_req.c inet-cmsg.c \
-+	init_module.c inject-nf.c inotify.c inotify_init.c \
-+	inotify_init-y.c inotify_init1.c inotify_init1-y.c int_0x80.c \
-+	io_uring_enter.c io_uring_register.c io_uring_setup.c ioctl.c \
-+	ioctl_block.c ioctl_dm.c ioctl_dm-v.c ioctl_evdev.c \
-+	ioctl_evdev-Xabbrev.c ioctl_evdev-Xraw.c \
-+	ioctl_evdev-Xverbose.c ioctl_evdev-success.c \
-+	ioctl_evdev-success-Xabbrev.c ioctl_evdev-success-Xraw.c \
-+	ioctl_evdev-success-Xverbose.c ioctl_evdev-success-v.c \
-+	ioctl_evdev-success-v-Xabbrev.c ioctl_evdev-success-v-Xraw.c \
-+	ioctl_evdev-success-v-Xverbose.c ioctl_evdev-v.c \
-+	ioctl_evdev-v-Xabbrev.c ioctl_evdev-v-Xraw.c \
- 	ioctl_evdev-v-Xverbose.c ioctl_inotify.c ioctl_kvm_run.c \
- 	ioctl_kvm_run-v.c ioctl_kvm_run_auxstr_vcpu.c ioctl_loop.c \
- 	ioctl_loop-nv.c ioctl_loop-v.c ioctl_mtd.c ioctl_nbd.c \
-@@ -4421,6 +4427,7 @@ pdfdir = @pdfdir@
- prefix = @prefix@
- program_transform_name = @program_transform_name@
- psdir = @psdir@
-+runstatedir = @runstatedir@
- sbindir = @sbindir@
- sharedstatedir = @sharedstatedir@
- srcdir = @srcdir@
-@@ -6165,6 +6172,10 @@ get_mempolicy$(EXEEXT): $(get_mempolicy_OBJECTS) $(get_mempolicy_DEPENDENCIES) $
- 	@rm -f get_mempolicy$(EXEEXT)
- 	$(AM_V_CCLD)$(LINK) $(get_mempolicy_OBJECTS) $(get_mempolicy_LDADD) $(LIBS)
- 
-+get_process_reaper$(EXEEXT): $(get_process_reaper_OBJECTS) $(get_process_reaper_DEPENDENCIES) $(EXTRA_get_process_reaper_DEPENDENCIES) 
-+	@rm -f get_process_reaper$(EXEEXT)
-+	$(AM_V_CCLD)$(LINK) $(get_process_reaper_OBJECTS) $(get_process_reaper_LDADD) $(LIBS)
-+
- getcpu$(EXEEXT): $(getcpu_OBJECTS) $(getcpu_DEPENDENCIES) $(EXTRA_getcpu_DEPENDENCIES) 
- 	@rm -f getcpu$(EXEEXT)
- 	$(AM_V_CCLD)$(LINK) $(getcpu_OBJECTS) $(getcpu_LDADD) $(LIBS)
-@@ -8512,6 +8523,7 @@ distclean-compile:
- @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/futex.Po@am__quote@ # am--include-marker
- @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/futimesat.Po@am__quote@ # am--include-marker
- @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/get_mempolicy.Po@am__quote@ # am--include-marker
-+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/get_process_reaper.Po@am__quote@ # am--include-marker
- @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getcpu.Po@am__quote@ # am--include-marker
- @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getcwd.Po@am__quote@ # am--include-marker
- @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getdents.Po@am__quote@ # am--include-marker
-@@ -10222,6 +10234,7 @@ distclean: distclean-am
- 	-rm -f ./$(DEPDIR)/futex.Po
- 	-rm -f ./$(DEPDIR)/futimesat.Po
- 	-rm -f ./$(DEPDIR)/get_mempolicy.Po
-+	-rm -f ./$(DEPDIR)/get_process_reaper.Po
- 	-rm -f ./$(DEPDIR)/getcpu.Po
- 	-rm -f ./$(DEPDIR)/getcwd.Po
- 	-rm -f ./$(DEPDIR)/getdents.Po
-@@ -10981,6 +10994,7 @@ maintainer-clean: maintainer-clean-am
- 	-rm -f ./$(DEPDIR)/futex.Po
- 	-rm -f ./$(DEPDIR)/futimesat.Po
- 	-rm -f ./$(DEPDIR)/get_mempolicy.Po
-+	-rm -f ./$(DEPDIR)/get_process_reaper.Po
- 	-rm -f ./$(DEPDIR)/getcpu.Po
- 	-rm -f ./$(DEPDIR)/getcwd.Po
- 	-rm -f ./$(DEPDIR)/getdents.Po
-diff --git a/tests-m32/Makefile.am b/tests-m32/Makefile.am
-index f2a5bc6d8..8a5819de2 100644
---- a/tests-m32/Makefile.am
-+++ b/tests-m32/Makefile.am
-@@ -111,6 +111,7 @@ check_PROGRAMS = $(PURE_EXECUTABLES) \
- 	filter-unavailable \
- 	fork-f \
- 	fsync-y \
-+	get_process_reaper \
- 	getpid	\
- 	getppid	\
- 	gettid \
-diff --git a/tests-m32/get_process_reaper.c b/tests-m32/get_process_reaper.c
-new file mode 100644
-index 000000000..3c00c584b
---- /dev/null
-+++ b/tests-m32/get_process_reaper.c
-@@ -0,0 +1,108 @@
-+/*
-+ * Print the process reaper id.
-+ *
-+ * Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
-+ * All rights reserved.
-+ *
-+ * SPDX-License-Identifier: GPL-2.0-or-later
-+ */
-+
-+#include "tests.h"
-+#include <stdio.h>
-+#include <unistd.h>
-+#include <sys/wait.h>
-+
-+/* PARENT - CHILD - GRANDCHILD */
-+
-+static int
-+grandchild(int read_fd, int write_fd)
-+{
-+	/* wait for notification from PARENT about CHILD completion */
-+	pid_t pid;
-+	if (read(read_fd, &pid, sizeof(pid)) != 0)
-+		perror_msg_and_fail("read");
-+
-+	/* write ppid to PARENT */
-+	pid = getppid();
-+	if (write(write_fd, &pid, sizeof(pid)) != sizeof(pid))
-+		perror_msg_and_fail("write");
-+
-+	_exit(0);
-+}
-+
-+static int
-+child(int read_fd, int write_fd)
-+{
-+	pid_t pid = fork();
-+	if (pid < 0)
-+		perror_msg_and_fail("fork");
-+
-+	if (!pid)
-+		return grandchild(read_fd, write_fd);
-+	else
-+		_exit(0);
-+}
-+
-+static int
-+parent(pid_t pid, int read_fd, int write_fd)
-+{
-+	/* wait for CHILD completion */
-+	int status;
-+	if (waitpid(pid, &status, 0) != pid)
-+		perror_msg_and_fail("waitpid");
-+	if (status != 0)
-+		error_msg_and_fail("status %x", status);
-+
-+	/* notify GRANDCHILD about CHILD completion */
-+	close(write_fd),
-+	      write_fd = -1;
-+
-+	/* read ppid of GRANDCHILD */
-+	if (read(read_fd, &pid, sizeof(pid)) != sizeof(pid))
-+		perror_msg_and_fail("read");
-+
-+	printf("%d\n", pid);
-+	return 0;
-+}
-+
-+int
-+main(void)
-+{
-+	int parent_grandchild_fds[2];
-+#define parent_read_fd		parent_grandchild_fds[0]
-+#define grandchild_write_fd	parent_grandchild_fds[1]
-+
-+	int grandchild_parent_fds[2];
-+#define	grandchild_read_fd	grandchild_parent_fds[0]
-+#define	parent_write_fd		grandchild_parent_fds[1]
-+
-+	if (pipe(parent_grandchild_fds) ||
-+	    pipe(grandchild_parent_fds))
-+		perror_msg_and_fail("pipe");
-+
-+	pid_t pid = fork();
-+	if (pid < 0)
-+		perror_msg_and_fail("fork");
-+
-+	if (!pid) {
-+		/* CHILD */
-+		close(parent_read_fd),
-+		      parent_read_fd = -1;
-+
-+		close(parent_write_fd),
-+		      parent_write_fd = -1;
-+
-+		return child(grandchild_read_fd,
-+			     grandchild_write_fd);
-+	} else {
-+		/* PARENT */
-+		close(grandchild_read_fd),
-+		      grandchild_read_fd = -1;
-+
-+		close(grandchild_write_fd),
-+		      grandchild_write_fd = -1;
-+
-+		return parent(pid, parent_read_fd,
-+				   parent_write_fd);
-+	}
-+}
-diff --git a/tests-m32/strace-DDD.test b/tests-m32/strace-DDD.test
-index e478ae5e8..671600bbe 100755
---- a/tests-m32/strace-DDD.test
-+++ b/tests-m32/strace-DDD.test
-@@ -19,10 +19,14 @@ stat_file=/proc/self/stat
- [ -f "$stat_file" ] ||
- 	framework_skip_ "$stat_file is not available"
- 
-+reapid="$(../get_process_reaper)" && [ "$reapid" -ge 1 ] ||
-+	fail_ 'get_process_reaper failed'
-+
- set -- -enone -esignal=none ../tracer_ppid_pgid_sid
- run_strace "$@" > "$OUT"
- read -r ppid pgid sid < "$OUT" &&
- [ "$ppid" -gt 1 ] &&
-+[ "$ppid" -ne "$reapid" ] &&
- [ "$pgid" -ge 0 ] &&
- [ "$sid" -ge 0 ] || {
- 	cat < "$OUT" > "$LOG"
-@@ -35,7 +39,7 @@ sid0="$sid"
- 
- run_strace -D "$@" > "$OUT"
- read -r ppid pgid sid < "$OUT" &&
--[ "$ppid" -eq 1 ] &&
-+[ "$ppid" -eq "$reapid" ] &&
- [ "$pgid" = "$pgid0" ] &&
- [ "$sid" = "$sid0" ] || {
- 	cat < "$OUT" > "$LOG"
-@@ -45,8 +49,9 @@ match_diff
- 
- run_strace -DD "$@" > "$OUT"
- read -r ppid pgid sid < "$OUT" &&
--[ "$ppid" -eq 1 ] &&
-+[ "$ppid" -eq "$reapid" ] &&
- [ "$pgid" -gt 1 ] &&
-+[ "$pgid" -ne "$reapid" ] &&
- [ "$pgid" != "$pgid0" ] &&
- [ "$pgid" != "$sid" ] &&
- [ "$sid" = "$sid0" ] || {
-@@ -57,8 +62,9 @@ match_diff
- 
- run_strace -DDD "$@" > "$OUT"
- read -r ppid pgid sid < "$OUT" &&
--[ "$ppid" -eq 1 ] &&
-+[ "$ppid" -eq "$reapid" ] &&
- [ "$pgid" -gt 1 ] &&
-+[ "$pgid" -ne "$reapid" ] &&
- [ "$pgid" != "$pgid0" ] &&
- [ "$sid" = "$pgid" ] &&
- [ "$sid" != "$sid0" ] || {
-diff --git a/tests-m32/Makefile.in b/tests-m32/Makefile.in
-index 309fe4443..783230ecc 100644
---- a/tests-m32/Makefile.in
-+++ b/tests-m32/Makefile.in
-@@ -118,9 +118,9 @@ check_PROGRAMS = $(am__EXEEXT_1) _newselect-P$(EXEEXT) answer$(EXEEXT) \
- 	count-f$(EXEEXT) delay$(EXEEXT) execve-v$(EXEEXT) \
- 	execveat-v$(EXEEXT) filter_seccomp-flag$(EXEEXT) \
- 	filter_seccomp-perf$(EXEEXT) filter-unavailable$(EXEEXT) \
--	fork-f$(EXEEXT) fsync-y$(EXEEXT) getpid$(EXEEXT) \
--	getppid$(EXEEXT) gettid$(EXEEXT) inject-nf$(EXEEXT) \
--	int_0x80$(EXEEXT) ioctl_dm-v$(EXEEXT) \
-+	fork-f$(EXEEXT) fsync-y$(EXEEXT) get_process_reaper$(EXEEXT) \
-+	getpid$(EXEEXT) getppid$(EXEEXT) gettid$(EXEEXT) \
-+	inject-nf$(EXEEXT) int_0x80$(EXEEXT) ioctl_dm-v$(EXEEXT) \
- 	ioctl_evdev-success$(EXEEXT) \
- 	ioctl_evdev-success-Xabbrev$(EXEEXT) \
- 	ioctl_evdev-success-Xraw$(EXEEXT) \
-@@ -944,6 +944,10 @@ get_mempolicy_SOURCES = get_mempolicy.c
- get_mempolicy_OBJECTS = get_mempolicy.$(OBJEXT)
- get_mempolicy_LDADD = $(LDADD)
- get_mempolicy_DEPENDENCIES = libtests.a
-+get_process_reaper_SOURCES = get_process_reaper.c
-+get_process_reaper_OBJECTS = get_process_reaper.$(OBJEXT)
-+get_process_reaper_LDADD = $(LDADD)
-+get_process_reaper_DEPENDENCIES = libtests.a
- getcpu_SOURCES = getcpu.c
- getcpu_OBJECTS = getcpu.$(OBJEXT)
- getcpu_LDADD = $(LDADD)
-@@ -3265,30 +3269,30 @@ am__depfiles_remade = ./$(DEPDIR)/_newselect-P.Po \
- 	./$(DEPDIR)/fsync.Po ./$(DEPDIR)/ftruncate.Po \
- 	./$(DEPDIR)/ftruncate64-ftruncate64.Po ./$(DEPDIR)/futex.Po \
- 	./$(DEPDIR)/futimesat.Po ./$(DEPDIR)/get_mempolicy.Po \
--	./$(DEPDIR)/getcpu.Po ./$(DEPDIR)/getcwd.Po \
--	./$(DEPDIR)/getdents.Po ./$(DEPDIR)/getdents64.Po \
--	./$(DEPDIR)/getegid.Po ./$(DEPDIR)/getegid32.Po \
--	./$(DEPDIR)/geteuid.Po ./$(DEPDIR)/geteuid32.Po \
--	./$(DEPDIR)/getgid.Po ./$(DEPDIR)/getgid32.Po \
--	./$(DEPDIR)/getgroups.Po ./$(DEPDIR)/getgroups32.Po \
--	./$(DEPDIR)/getpeername.Po ./$(DEPDIR)/getpgrp.Po \
--	./$(DEPDIR)/getpid.Po ./$(DEPDIR)/getppid.Po \
--	./$(DEPDIR)/getrandom.Po ./$(DEPDIR)/getresgid.Po \
--	./$(DEPDIR)/getresgid32.Po ./$(DEPDIR)/getresuid.Po \
--	./$(DEPDIR)/getresuid32.Po ./$(DEPDIR)/getrlimit.Po \
--	./$(DEPDIR)/getrusage.Po ./$(DEPDIR)/getsid.Po \
--	./$(DEPDIR)/getsockname.Po ./$(DEPDIR)/gettid.Po \
--	./$(DEPDIR)/getuid.Po ./$(DEPDIR)/getuid32.Po \
--	./$(DEPDIR)/getxxid.Po ./$(DEPDIR)/group_req.Po \
--	./$(DEPDIR)/inet-cmsg.Po ./$(DEPDIR)/init_module.Po \
--	./$(DEPDIR)/inject-nf.Po ./$(DEPDIR)/inotify.Po \
--	./$(DEPDIR)/inotify_init-y.Po ./$(DEPDIR)/inotify_init.Po \
--	./$(DEPDIR)/inotify_init1-y.Po ./$(DEPDIR)/inotify_init1.Po \
--	./$(DEPDIR)/int_0x80.Po ./$(DEPDIR)/io_uring_enter.Po \
--	./$(DEPDIR)/io_uring_register.Po ./$(DEPDIR)/io_uring_setup.Po \
--	./$(DEPDIR)/ioctl.Po ./$(DEPDIR)/ioctl_block.Po \
--	./$(DEPDIR)/ioctl_dm-v.Po ./$(DEPDIR)/ioctl_dm.Po \
--	./$(DEPDIR)/ioctl_evdev-Xabbrev.Po \
-+	./$(DEPDIR)/get_process_reaper.Po ./$(DEPDIR)/getcpu.Po \
-+	./$(DEPDIR)/getcwd.Po ./$(DEPDIR)/getdents.Po \
-+	./$(DEPDIR)/getdents64.Po ./$(DEPDIR)/getegid.Po \
-+	./$(DEPDIR)/getegid32.Po ./$(DEPDIR)/geteuid.Po \
-+	./$(DEPDIR)/geteuid32.Po ./$(DEPDIR)/getgid.Po \
-+	./$(DEPDIR)/getgid32.Po ./$(DEPDIR)/getgroups.Po \
-+	./$(DEPDIR)/getgroups32.Po ./$(DEPDIR)/getpeername.Po \
-+	./$(DEPDIR)/getpgrp.Po ./$(DEPDIR)/getpid.Po \
-+	./$(DEPDIR)/getppid.Po ./$(DEPDIR)/getrandom.Po \
-+	./$(DEPDIR)/getresgid.Po ./$(DEPDIR)/getresgid32.Po \
-+	./$(DEPDIR)/getresuid.Po ./$(DEPDIR)/getresuid32.Po \
-+	./$(DEPDIR)/getrlimit.Po ./$(DEPDIR)/getrusage.Po \
-+	./$(DEPDIR)/getsid.Po ./$(DEPDIR)/getsockname.Po \
-+	./$(DEPDIR)/gettid.Po ./$(DEPDIR)/getuid.Po \
-+	./$(DEPDIR)/getuid32.Po ./$(DEPDIR)/getxxid.Po \
-+	./$(DEPDIR)/group_req.Po ./$(DEPDIR)/inet-cmsg.Po \
-+	./$(DEPDIR)/init_module.Po ./$(DEPDIR)/inject-nf.Po \
-+	./$(DEPDIR)/inotify.Po ./$(DEPDIR)/inotify_init-y.Po \
-+	./$(DEPDIR)/inotify_init.Po ./$(DEPDIR)/inotify_init1-y.Po \
-+	./$(DEPDIR)/inotify_init1.Po ./$(DEPDIR)/int_0x80.Po \
-+	./$(DEPDIR)/io_uring_enter.Po ./$(DEPDIR)/io_uring_register.Po \
-+	./$(DEPDIR)/io_uring_setup.Po ./$(DEPDIR)/ioctl.Po \
-+	./$(DEPDIR)/ioctl_block.Po ./$(DEPDIR)/ioctl_dm-v.Po \
-+	./$(DEPDIR)/ioctl_dm.Po ./$(DEPDIR)/ioctl_evdev-Xabbrev.Po \
- 	./$(DEPDIR)/ioctl_evdev-Xraw.Po \
- 	./$(DEPDIR)/ioctl_evdev-Xverbose.Po \
- 	./$(DEPDIR)/ioctl_evdev-success-Xabbrev.Po \
-@@ -3689,23 +3693,24 @@ SOURCES = $(libtests_a_SOURCES) _newselect.c _newselect-P.c accept.c \
- 	fstat-Xverbose.c fstat64.c fstat64-Xabbrev.c fstat64-Xraw.c \
- 	fstat64-Xverbose.c fstatat64.c fstatfs.c fstatfs64.c fsync.c \
- 	fsync-y.c ftruncate.c ftruncate64.c futex.c futimesat.c \
--	get_mempolicy.c getcpu.c getcwd.c getdents.c getdents64.c \
--	getegid.c getegid32.c geteuid.c geteuid32.c getgid.c \
--	getgid32.c getgroups.c getgroups32.c getpeername.c getpgrp.c \
--	getpid.c getppid.c getrandom.c getresgid.c getresgid32.c \
--	getresuid.c getresuid32.c getrlimit.c getrusage.c getsid.c \
--	getsockname.c gettid.c getuid.c getuid32.c getxxid.c \
--	group_req.c inet-cmsg.c init_module.c inject-nf.c inotify.c \
--	inotify_init.c inotify_init-y.c inotify_init1.c \
--	inotify_init1-y.c int_0x80.c io_uring_enter.c \
--	io_uring_register.c io_uring_setup.c ioctl.c ioctl_block.c \
--	ioctl_dm.c ioctl_dm-v.c ioctl_evdev.c ioctl_evdev-Xabbrev.c \
--	ioctl_evdev-Xraw.c ioctl_evdev-Xverbose.c \
--	ioctl_evdev-success.c ioctl_evdev-success-Xabbrev.c \
--	ioctl_evdev-success-Xraw.c ioctl_evdev-success-Xverbose.c \
--	ioctl_evdev-success-v.c ioctl_evdev-success-v-Xabbrev.c \
--	ioctl_evdev-success-v-Xraw.c ioctl_evdev-success-v-Xverbose.c \
--	ioctl_evdev-v.c ioctl_evdev-v-Xabbrev.c ioctl_evdev-v-Xraw.c \
-+	get_mempolicy.c get_process_reaper.c getcpu.c getcwd.c \
-+	getdents.c getdents64.c getegid.c getegid32.c geteuid.c \
-+	geteuid32.c getgid.c getgid32.c getgroups.c getgroups32.c \
-+	getpeername.c getpgrp.c getpid.c getppid.c getrandom.c \
-+	getresgid.c getresgid32.c getresuid.c getresuid32.c \
-+	getrlimit.c getrusage.c getsid.c getsockname.c gettid.c \
-+	getuid.c getuid32.c getxxid.c group_req.c inet-cmsg.c \
-+	init_module.c inject-nf.c inotify.c inotify_init.c \
-+	inotify_init-y.c inotify_init1.c inotify_init1-y.c int_0x80.c \
-+	io_uring_enter.c io_uring_register.c io_uring_setup.c ioctl.c \
-+	ioctl_block.c ioctl_dm.c ioctl_dm-v.c ioctl_evdev.c \
-+	ioctl_evdev-Xabbrev.c ioctl_evdev-Xraw.c \
-+	ioctl_evdev-Xverbose.c ioctl_evdev-success.c \
-+	ioctl_evdev-success-Xabbrev.c ioctl_evdev-success-Xraw.c \
-+	ioctl_evdev-success-Xverbose.c ioctl_evdev-success-v.c \
-+	ioctl_evdev-success-v-Xabbrev.c ioctl_evdev-success-v-Xraw.c \
-+	ioctl_evdev-success-v-Xverbose.c ioctl_evdev-v.c \
-+	ioctl_evdev-v-Xabbrev.c ioctl_evdev-v-Xraw.c \
- 	ioctl_evdev-v-Xverbose.c ioctl_inotify.c ioctl_kvm_run.c \
- 	ioctl_kvm_run-v.c ioctl_kvm_run_auxstr_vcpu.c ioctl_loop.c \
- 	ioctl_loop-nv.c ioctl_loop-v.c ioctl_mtd.c ioctl_nbd.c \
-@@ -3876,23 +3881,24 @@ DIST_SOURCES = $(libtests_a_SOURCES) _newselect.c _newselect-P.c \
- 	fstat-Xverbose.c fstat64.c fstat64-Xabbrev.c fstat64-Xraw.c \
- 	fstat64-Xverbose.c fstatat64.c fstatfs.c fstatfs64.c fsync.c \
- 	fsync-y.c ftruncate.c ftruncate64.c futex.c futimesat.c \
--	get_mempolicy.c getcpu.c getcwd.c getdents.c getdents64.c \
--	getegid.c getegid32.c geteuid.c geteuid32.c getgid.c \
--	getgid32.c getgroups.c getgroups32.c getpeername.c getpgrp.c \
--	getpid.c getppid.c getrandom.c getresgid.c getresgid32.c \
--	getresuid.c getresuid32.c getrlimit.c getrusage.c getsid.c \
--	getsockname.c gettid.c getuid.c getuid32.c getxxid.c \
--	group_req.c inet-cmsg.c init_module.c inject-nf.c inotify.c \
--	inotify_init.c inotify_init-y.c inotify_init1.c \
--	inotify_init1-y.c int_0x80.c io_uring_enter.c \
--	io_uring_register.c io_uring_setup.c ioctl.c ioctl_block.c \
--	ioctl_dm.c ioctl_dm-v.c ioctl_evdev.c ioctl_evdev-Xabbrev.c \
--	ioctl_evdev-Xraw.c ioctl_evdev-Xverbose.c \
--	ioctl_evdev-success.c ioctl_evdev-success-Xabbrev.c \
--	ioctl_evdev-success-Xraw.c ioctl_evdev-success-Xverbose.c \
--	ioctl_evdev-success-v.c ioctl_evdev-success-v-Xabbrev.c \
--	ioctl_evdev-success-v-Xraw.c ioctl_evdev-success-v-Xverbose.c \
--	ioctl_evdev-v.c ioctl_evdev-v-Xabbrev.c ioctl_evdev-v-Xraw.c \
-+	get_mempolicy.c get_process_reaper.c getcpu.c getcwd.c \
-+	getdents.c getdents64.c getegid.c getegid32.c geteuid.c \
-+	geteuid32.c getgid.c getgid32.c getgroups.c getgroups32.c \
-+	getpeername.c getpgrp.c getpid.c getppid.c getrandom.c \
-+	getresgid.c getresgid32.c getresuid.c getresuid32.c \
-+	getrlimit.c getrusage.c getsid.c getsockname.c gettid.c \
-+	getuid.c getuid32.c getxxid.c group_req.c inet-cmsg.c \
-+	init_module.c inject-nf.c inotify.c inotify_init.c \
-+	inotify_init-y.c inotify_init1.c inotify_init1-y.c int_0x80.c \
-+	io_uring_enter.c io_uring_register.c io_uring_setup.c ioctl.c \
-+	ioctl_block.c ioctl_dm.c ioctl_dm-v.c ioctl_evdev.c \
-+	ioctl_evdev-Xabbrev.c ioctl_evdev-Xraw.c \
-+	ioctl_evdev-Xverbose.c ioctl_evdev-success.c \
-+	ioctl_evdev-success-Xabbrev.c ioctl_evdev-success-Xraw.c \
-+	ioctl_evdev-success-Xverbose.c ioctl_evdev-success-v.c \
-+	ioctl_evdev-success-v-Xabbrev.c ioctl_evdev-success-v-Xraw.c \
-+	ioctl_evdev-success-v-Xverbose.c ioctl_evdev-v.c \
-+	ioctl_evdev-v-Xabbrev.c ioctl_evdev-v-Xraw.c \
- 	ioctl_evdev-v-Xverbose.c ioctl_inotify.c ioctl_kvm_run.c \
- 	ioctl_kvm_run-v.c ioctl_kvm_run_auxstr_vcpu.c ioctl_loop.c \
- 	ioctl_loop-nv.c ioctl_loop-v.c ioctl_mtd.c ioctl_nbd.c \
-@@ -4421,6 +4427,7 @@ pdfdir = @pdfdir@
- prefix = @prefix@
- program_transform_name = @program_transform_name@
- psdir = @psdir@
-+runstatedir = @runstatedir@
- sbindir = @sbindir@
- sharedstatedir = @sharedstatedir@
- srcdir = @srcdir@
-@@ -6165,6 +6172,10 @@ get_mempolicy$(EXEEXT): $(get_mempolicy_OBJECTS) $(get_mempolicy_DEPENDENCIES) $
- 	@rm -f get_mempolicy$(EXEEXT)
- 	$(AM_V_CCLD)$(LINK) $(get_mempolicy_OBJECTS) $(get_mempolicy_LDADD) $(LIBS)
- 
-+get_process_reaper$(EXEEXT): $(get_process_reaper_OBJECTS) $(get_process_reaper_DEPENDENCIES) $(EXTRA_get_process_reaper_DEPENDENCIES) 
-+	@rm -f get_process_reaper$(EXEEXT)
-+	$(AM_V_CCLD)$(LINK) $(get_process_reaper_OBJECTS) $(get_process_reaper_LDADD) $(LIBS)
-+
- getcpu$(EXEEXT): $(getcpu_OBJECTS) $(getcpu_DEPENDENCIES) $(EXTRA_getcpu_DEPENDENCIES) 
- 	@rm -f getcpu$(EXEEXT)
- 	$(AM_V_CCLD)$(LINK) $(getcpu_OBJECTS) $(getcpu_LDADD) $(LIBS)
-@@ -8512,6 +8523,7 @@ distclean-compile:
- @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/futex.Po@am__quote@ # am--include-marker
- @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/futimesat.Po@am__quote@ # am--include-marker
- @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/get_mempolicy.Po@am__quote@ # am--include-marker
-+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/get_process_reaper.Po@am__quote@ # am--include-marker
- @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getcpu.Po@am__quote@ # am--include-marker
- @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getcwd.Po@am__quote@ # am--include-marker
- @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getdents.Po@am__quote@ # am--include-marker
-@@ -10222,6 +10234,7 @@ distclean: distclean-am
- 	-rm -f ./$(DEPDIR)/futex.Po
- 	-rm -f ./$(DEPDIR)/futimesat.Po
- 	-rm -f ./$(DEPDIR)/get_mempolicy.Po
-+	-rm -f ./$(DEPDIR)/get_process_reaper.Po
- 	-rm -f ./$(DEPDIR)/getcpu.Po
- 	-rm -f ./$(DEPDIR)/getcwd.Po
- 	-rm -f ./$(DEPDIR)/getdents.Po
-@@ -10981,6 +10994,7 @@ maintainer-clean: maintainer-clean-am
- 	-rm -f ./$(DEPDIR)/futex.Po
- 	-rm -f ./$(DEPDIR)/futimesat.Po
- 	-rm -f ./$(DEPDIR)/get_mempolicy.Po
-+	-rm -f ./$(DEPDIR)/get_process_reaper.Po
- 	-rm -f ./$(DEPDIR)/getcpu.Po
- 	-rm -f ./$(DEPDIR)/getcwd.Po
- 	-rm -f ./$(DEPDIR)/getdents.Po
-diff --git a/tests-mx32/Makefile.am b/tests-mx32/Makefile.am
-index f2a5bc6d8..8a5819de2 100644
---- a/tests-mx32/Makefile.am
-+++ b/tests-mx32/Makefile.am
-@@ -111,6 +111,7 @@ check_PROGRAMS = $(PURE_EXECUTABLES) \
- 	filter-unavailable \
- 	fork-f \
- 	fsync-y \
-+	get_process_reaper \
- 	getpid	\
- 	getppid	\
- 	gettid \
-diff --git a/tests-mx32/get_process_reaper.c b/tests-mx32/get_process_reaper.c
-new file mode 100644
-index 000000000..3c00c584b
---- /dev/null
-+++ b/tests-mx32/get_process_reaper.c
-@@ -0,0 +1,108 @@
-+/*
-+ * Print the process reaper id.
-+ *
-+ * Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
-+ * All rights reserved.
-+ *
-+ * SPDX-License-Identifier: GPL-2.0-or-later
-+ */
-+
-+#include "tests.h"
-+#include <stdio.h>
-+#include <unistd.h>
-+#include <sys/wait.h>
-+
-+/* PARENT - CHILD - GRANDCHILD */
-+
-+static int
-+grandchild(int read_fd, int write_fd)
-+{
-+	/* wait for notification from PARENT about CHILD completion */
-+	pid_t pid;
-+	if (read(read_fd, &pid, sizeof(pid)) != 0)
-+		perror_msg_and_fail("read");
-+
-+	/* write ppid to PARENT */
-+	pid = getppid();
-+	if (write(write_fd, &pid, sizeof(pid)) != sizeof(pid))
-+		perror_msg_and_fail("write");
-+
-+	_exit(0);
-+}
-+
-+static int
-+child(int read_fd, int write_fd)
-+{
-+	pid_t pid = fork();
-+	if (pid < 0)
-+		perror_msg_and_fail("fork");
-+
-+	if (!pid)
-+		return grandchild(read_fd, write_fd);
-+	else
-+		_exit(0);
-+}
-+
-+static int
-+parent(pid_t pid, int read_fd, int write_fd)
-+{
-+	/* wait for CHILD completion */
-+	int status;
-+	if (waitpid(pid, &status, 0) != pid)
-+		perror_msg_and_fail("waitpid");
-+	if (status != 0)
-+		error_msg_and_fail("status %x", status);
-+
-+	/* notify GRANDCHILD about CHILD completion */
-+	close(write_fd),
-+	      write_fd = -1;
-+
-+	/* read ppid of GRANDCHILD */
-+	if (read(read_fd, &pid, sizeof(pid)) != sizeof(pid))
-+		perror_msg_and_fail("read");
-+
-+	printf("%d\n", pid);
-+	return 0;
-+}
-+
-+int
-+main(void)
-+{
-+	int parent_grandchild_fds[2];
-+#define parent_read_fd		parent_grandchild_fds[0]
-+#define grandchild_write_fd	parent_grandchild_fds[1]
-+
-+	int grandchild_parent_fds[2];
-+#define	grandchild_read_fd	grandchild_parent_fds[0]
-+#define	parent_write_fd		grandchild_parent_fds[1]
-+
-+	if (pipe(parent_grandchild_fds) ||
-+	    pipe(grandchild_parent_fds))
-+		perror_msg_and_fail("pipe");
-+
-+	pid_t pid = fork();
-+	if (pid < 0)
-+		perror_msg_and_fail("fork");
-+
-+	if (!pid) {
-+		/* CHILD */
-+		close(parent_read_fd),
-+		      parent_read_fd = -1;
-+
-+		close(parent_write_fd),
-+		      parent_write_fd = -1;
-+
-+		return child(grandchild_read_fd,
-+			     grandchild_write_fd);
-+	} else {
-+		/* PARENT */
-+		close(grandchild_read_fd),
-+		      grandchild_read_fd = -1;
-+
-+		close(grandchild_write_fd),
-+		      grandchild_write_fd = -1;
-+
-+		return parent(pid, parent_read_fd,
-+				   parent_write_fd);
-+	}
-+}
-diff --git a/tests-mx32/strace-DDD.test b/tests-mx32/strace-DDD.test
-index e478ae5e8..671600bbe 100755
---- a/tests-mx32/strace-DDD.test
-+++ b/tests-mx32/strace-DDD.test
-@@ -19,10 +19,14 @@ stat_file=/proc/self/stat
- [ -f "$stat_file" ] ||
- 	framework_skip_ "$stat_file is not available"
- 
-+reapid="$(../get_process_reaper)" && [ "$reapid" -ge 1 ] ||
-+	fail_ 'get_process_reaper failed'
-+
- set -- -enone -esignal=none ../tracer_ppid_pgid_sid
- run_strace "$@" > "$OUT"
- read -r ppid pgid sid < "$OUT" &&
- [ "$ppid" -gt 1 ] &&
-+[ "$ppid" -ne "$reapid" ] &&
- [ "$pgid" -ge 0 ] &&
- [ "$sid" -ge 0 ] || {
- 	cat < "$OUT" > "$LOG"
-@@ -35,7 +39,7 @@ sid0="$sid"
- 
- run_strace -D "$@" > "$OUT"
- read -r ppid pgid sid < "$OUT" &&
--[ "$ppid" -eq 1 ] &&
-+[ "$ppid" -eq "$reapid" ] &&
- [ "$pgid" = "$pgid0" ] &&
- [ "$sid" = "$sid0" ] || {
- 	cat < "$OUT" > "$LOG"
-@@ -45,8 +49,9 @@ match_diff
- 
- run_strace -DD "$@" > "$OUT"
- read -r ppid pgid sid < "$OUT" &&
--[ "$ppid" -eq 1 ] &&
-+[ "$ppid" -eq "$reapid" ] &&
- [ "$pgid" -gt 1 ] &&
-+[ "$pgid" -ne "$reapid" ] &&
- [ "$pgid" != "$pgid0" ] &&
- [ "$pgid" != "$sid" ] &&
- [ "$sid" = "$sid0" ] || {
-@@ -57,8 +62,9 @@ match_diff
- 
- run_strace -DDD "$@" > "$OUT"
- read -r ppid pgid sid < "$OUT" &&
--[ "$ppid" -eq 1 ] &&
-+[ "$ppid" -eq "$reapid" ] &&
- [ "$pgid" -gt 1 ] &&
-+[ "$pgid" -ne "$reapid" ] &&
- [ "$pgid" != "$pgid0" ] &&
- [ "$sid" = "$pgid" ] &&
- [ "$sid" != "$sid0" ] || {
-diff --git a/tests-mx32/Makefile.in b/tests-mx32/Makefile.in
-index 309fe4443..783230ecc 100644
---- a/tests-mx32/Makefile.in
-+++ b/tests-mx32/Makefile.in
-@@ -118,9 +118,9 @@ check_PROGRAMS = $(am__EXEEXT_1) _newselect-P$(EXEEXT) answer$(EXEEXT) \
- 	count-f$(EXEEXT) delay$(EXEEXT) execve-v$(EXEEXT) \
- 	execveat-v$(EXEEXT) filter_seccomp-flag$(EXEEXT) \
- 	filter_seccomp-perf$(EXEEXT) filter-unavailable$(EXEEXT) \
--	fork-f$(EXEEXT) fsync-y$(EXEEXT) getpid$(EXEEXT) \
--	getppid$(EXEEXT) gettid$(EXEEXT) inject-nf$(EXEEXT) \
--	int_0x80$(EXEEXT) ioctl_dm-v$(EXEEXT) \
-+	fork-f$(EXEEXT) fsync-y$(EXEEXT) get_process_reaper$(EXEEXT) \
-+	getpid$(EXEEXT) getppid$(EXEEXT) gettid$(EXEEXT) \
-+	inject-nf$(EXEEXT) int_0x80$(EXEEXT) ioctl_dm-v$(EXEEXT) \
- 	ioctl_evdev-success$(EXEEXT) \
- 	ioctl_evdev-success-Xabbrev$(EXEEXT) \
- 	ioctl_evdev-success-Xraw$(EXEEXT) \
-@@ -944,6 +944,10 @@ get_mempolicy_SOURCES = get_mempolicy.c
- get_mempolicy_OBJECTS = get_mempolicy.$(OBJEXT)
- get_mempolicy_LDADD = $(LDADD)
- get_mempolicy_DEPENDENCIES = libtests.a
-+get_process_reaper_SOURCES = get_process_reaper.c
-+get_process_reaper_OBJECTS = get_process_reaper.$(OBJEXT)
-+get_process_reaper_LDADD = $(LDADD)
-+get_process_reaper_DEPENDENCIES = libtests.a
- getcpu_SOURCES = getcpu.c
- getcpu_OBJECTS = getcpu.$(OBJEXT)
- getcpu_LDADD = $(LDADD)
-@@ -3265,30 +3269,30 @@ am__depfiles_remade = ./$(DEPDIR)/_newselect-P.Po \
- 	./$(DEPDIR)/fsync.Po ./$(DEPDIR)/ftruncate.Po \
- 	./$(DEPDIR)/ftruncate64-ftruncate64.Po ./$(DEPDIR)/futex.Po \
- 	./$(DEPDIR)/futimesat.Po ./$(DEPDIR)/get_mempolicy.Po \
--	./$(DEPDIR)/getcpu.Po ./$(DEPDIR)/getcwd.Po \
--	./$(DEPDIR)/getdents.Po ./$(DEPDIR)/getdents64.Po \
--	./$(DEPDIR)/getegid.Po ./$(DEPDIR)/getegid32.Po \
--	./$(DEPDIR)/geteuid.Po ./$(DEPDIR)/geteuid32.Po \
--	./$(DEPDIR)/getgid.Po ./$(DEPDIR)/getgid32.Po \
--	./$(DEPDIR)/getgroups.Po ./$(DEPDIR)/getgroups32.Po \
--	./$(DEPDIR)/getpeername.Po ./$(DEPDIR)/getpgrp.Po \
--	./$(DEPDIR)/getpid.Po ./$(DEPDIR)/getppid.Po \
--	./$(DEPDIR)/getrandom.Po ./$(DEPDIR)/getresgid.Po \
--	./$(DEPDIR)/getresgid32.Po ./$(DEPDIR)/getresuid.Po \
--	./$(DEPDIR)/getresuid32.Po ./$(DEPDIR)/getrlimit.Po \
--	./$(DEPDIR)/getrusage.Po ./$(DEPDIR)/getsid.Po \
--	./$(DEPDIR)/getsockname.Po ./$(DEPDIR)/gettid.Po \
--	./$(DEPDIR)/getuid.Po ./$(DEPDIR)/getuid32.Po \
--	./$(DEPDIR)/getxxid.Po ./$(DEPDIR)/group_req.Po \
--	./$(DEPDIR)/inet-cmsg.Po ./$(DEPDIR)/init_module.Po \
--	./$(DEPDIR)/inject-nf.Po ./$(DEPDIR)/inotify.Po \
--	./$(DEPDIR)/inotify_init-y.Po ./$(DEPDIR)/inotify_init.Po \
--	./$(DEPDIR)/inotify_init1-y.Po ./$(DEPDIR)/inotify_init1.Po \
--	./$(DEPDIR)/int_0x80.Po ./$(DEPDIR)/io_uring_enter.Po \
--	./$(DEPDIR)/io_uring_register.Po ./$(DEPDIR)/io_uring_setup.Po \
--	./$(DEPDIR)/ioctl.Po ./$(DEPDIR)/ioctl_block.Po \
--	./$(DEPDIR)/ioctl_dm-v.Po ./$(DEPDIR)/ioctl_dm.Po \
--	./$(DEPDIR)/ioctl_evdev-Xabbrev.Po \
-+	./$(DEPDIR)/get_process_reaper.Po ./$(DEPDIR)/getcpu.Po \
-+	./$(DEPDIR)/getcwd.Po ./$(DEPDIR)/getdents.Po \
-+	./$(DEPDIR)/getdents64.Po ./$(DEPDIR)/getegid.Po \
-+	./$(DEPDIR)/getegid32.Po ./$(DEPDIR)/geteuid.Po \
-+	./$(DEPDIR)/geteuid32.Po ./$(DEPDIR)/getgid.Po \
-+	./$(DEPDIR)/getgid32.Po ./$(DEPDIR)/getgroups.Po \
-+	./$(DEPDIR)/getgroups32.Po ./$(DEPDIR)/getpeername.Po \
-+	./$(DEPDIR)/getpgrp.Po ./$(DEPDIR)/getpid.Po \
-+	./$(DEPDIR)/getppid.Po ./$(DEPDIR)/getrandom.Po \
-+	./$(DEPDIR)/getresgid.Po ./$(DEPDIR)/getresgid32.Po \
-+	./$(DEPDIR)/getresuid.Po ./$(DEPDIR)/getresuid32.Po \
-+	./$(DEPDIR)/getrlimit.Po ./$(DEPDIR)/getrusage.Po \
-+	./$(DEPDIR)/getsid.Po ./$(DEPDIR)/getsockname.Po \
-+	./$(DEPDIR)/gettid.Po ./$(DEPDIR)/getuid.Po \
-+	./$(DEPDIR)/getuid32.Po ./$(DEPDIR)/getxxid.Po \
-+	./$(DEPDIR)/group_req.Po ./$(DEPDIR)/inet-cmsg.Po \
-+	./$(DEPDIR)/init_module.Po ./$(DEPDIR)/inject-nf.Po \
-+	./$(DEPDIR)/inotify.Po ./$(DEPDIR)/inotify_init-y.Po \
-+	./$(DEPDIR)/inotify_init.Po ./$(DEPDIR)/inotify_init1-y.Po \
-+	./$(DEPDIR)/inotify_init1.Po ./$(DEPDIR)/int_0x80.Po \
-+	./$(DEPDIR)/io_uring_enter.Po ./$(DEPDIR)/io_uring_register.Po \
-+	./$(DEPDIR)/io_uring_setup.Po ./$(DEPDIR)/ioctl.Po \
-+	./$(DEPDIR)/ioctl_block.Po ./$(DEPDIR)/ioctl_dm-v.Po \
-+	./$(DEPDIR)/ioctl_dm.Po ./$(DEPDIR)/ioctl_evdev-Xabbrev.Po \
- 	./$(DEPDIR)/ioctl_evdev-Xraw.Po \
- 	./$(DEPDIR)/ioctl_evdev-Xverbose.Po \
- 	./$(DEPDIR)/ioctl_evdev-success-Xabbrev.Po \
-@@ -3689,23 +3693,24 @@ SOURCES = $(libtests_a_SOURCES) _newselect.c _newselect-P.c accept.c \
- 	fstat-Xverbose.c fstat64.c fstat64-Xabbrev.c fstat64-Xraw.c \
- 	fstat64-Xverbose.c fstatat64.c fstatfs.c fstatfs64.c fsync.c \
- 	fsync-y.c ftruncate.c ftruncate64.c futex.c futimesat.c \
--	get_mempolicy.c getcpu.c getcwd.c getdents.c getdents64.c \
--	getegid.c getegid32.c geteuid.c geteuid32.c getgid.c \
--	getgid32.c getgroups.c getgroups32.c getpeername.c getpgrp.c \
--	getpid.c getppid.c getrandom.c getresgid.c getresgid32.c \
--	getresuid.c getresuid32.c getrlimit.c getrusage.c getsid.c \
--	getsockname.c gettid.c getuid.c getuid32.c getxxid.c \
--	group_req.c inet-cmsg.c init_module.c inject-nf.c inotify.c \
--	inotify_init.c inotify_init-y.c inotify_init1.c \
--	inotify_init1-y.c int_0x80.c io_uring_enter.c \
--	io_uring_register.c io_uring_setup.c ioctl.c ioctl_block.c \
--	ioctl_dm.c ioctl_dm-v.c ioctl_evdev.c ioctl_evdev-Xabbrev.c \
--	ioctl_evdev-Xraw.c ioctl_evdev-Xverbose.c \
--	ioctl_evdev-success.c ioctl_evdev-success-Xabbrev.c \
--	ioctl_evdev-success-Xraw.c ioctl_evdev-success-Xverbose.c \
--	ioctl_evdev-success-v.c ioctl_evdev-success-v-Xabbrev.c \
--	ioctl_evdev-success-v-Xraw.c ioctl_evdev-success-v-Xverbose.c \
--	ioctl_evdev-v.c ioctl_evdev-v-Xabbrev.c ioctl_evdev-v-Xraw.c \
-+	get_mempolicy.c get_process_reaper.c getcpu.c getcwd.c \
-+	getdents.c getdents64.c getegid.c getegid32.c geteuid.c \
-+	geteuid32.c getgid.c getgid32.c getgroups.c getgroups32.c \
-+	getpeername.c getpgrp.c getpid.c getppid.c getrandom.c \
-+	getresgid.c getresgid32.c getresuid.c getresuid32.c \
-+	getrlimit.c getrusage.c getsid.c getsockname.c gettid.c \
-+	getuid.c getuid32.c getxxid.c group_req.c inet-cmsg.c \
-+	init_module.c inject-nf.c inotify.c inotify_init.c \
-+	inotify_init-y.c inotify_init1.c inotify_init1-y.c int_0x80.c \
-+	io_uring_enter.c io_uring_register.c io_uring_setup.c ioctl.c \
-+	ioctl_block.c ioctl_dm.c ioctl_dm-v.c ioctl_evdev.c \
-+	ioctl_evdev-Xabbrev.c ioctl_evdev-Xraw.c \
-+	ioctl_evdev-Xverbose.c ioctl_evdev-success.c \
-+	ioctl_evdev-success-Xabbrev.c ioctl_evdev-success-Xraw.c \
-+	ioctl_evdev-success-Xverbose.c ioctl_evdev-success-v.c \
-+	ioctl_evdev-success-v-Xabbrev.c ioctl_evdev-success-v-Xraw.c \
-+	ioctl_evdev-success-v-Xverbose.c ioctl_evdev-v.c \
-+	ioctl_evdev-v-Xabbrev.c ioctl_evdev-v-Xraw.c \
- 	ioctl_evdev-v-Xverbose.c ioctl_inotify.c ioctl_kvm_run.c \
- 	ioctl_kvm_run-v.c ioctl_kvm_run_auxstr_vcpu.c ioctl_loop.c \
- 	ioctl_loop-nv.c ioctl_loop-v.c ioctl_mtd.c ioctl_nbd.c \
-@@ -3876,23 +3881,24 @@ DIST_SOURCES = $(libtests_a_SOURCES) _newselect.c _newselect-P.c \
- 	fstat-Xverbose.c fstat64.c fstat64-Xabbrev.c fstat64-Xraw.c \
- 	fstat64-Xverbose.c fstatat64.c fstatfs.c fstatfs64.c fsync.c \
- 	fsync-y.c ftruncate.c ftruncate64.c futex.c futimesat.c \
--	get_mempolicy.c getcpu.c getcwd.c getdents.c getdents64.c \
--	getegid.c getegid32.c geteuid.c geteuid32.c getgid.c \
--	getgid32.c getgroups.c getgroups32.c getpeername.c getpgrp.c \
--	getpid.c getppid.c getrandom.c getresgid.c getresgid32.c \
--	getresuid.c getresuid32.c getrlimit.c getrusage.c getsid.c \
--	getsockname.c gettid.c getuid.c getuid32.c getxxid.c \
--	group_req.c inet-cmsg.c init_module.c inject-nf.c inotify.c \
--	inotify_init.c inotify_init-y.c inotify_init1.c \
--	inotify_init1-y.c int_0x80.c io_uring_enter.c \
--	io_uring_register.c io_uring_setup.c ioctl.c ioctl_block.c \
--	ioctl_dm.c ioctl_dm-v.c ioctl_evdev.c ioctl_evdev-Xabbrev.c \
--	ioctl_evdev-Xraw.c ioctl_evdev-Xverbose.c \
--	ioctl_evdev-success.c ioctl_evdev-success-Xabbrev.c \
--	ioctl_evdev-success-Xraw.c ioctl_evdev-success-Xverbose.c \
--	ioctl_evdev-success-v.c ioctl_evdev-success-v-Xabbrev.c \
--	ioctl_evdev-success-v-Xraw.c ioctl_evdev-success-v-Xverbose.c \
--	ioctl_evdev-v.c ioctl_evdev-v-Xabbrev.c ioctl_evdev-v-Xraw.c \
-+	get_mempolicy.c get_process_reaper.c getcpu.c getcwd.c \
-+	getdents.c getdents64.c getegid.c getegid32.c geteuid.c \
-+	geteuid32.c getgid.c getgid32.c getgroups.c getgroups32.c \
-+	getpeername.c getpgrp.c getpid.c getppid.c getrandom.c \
-+	getresgid.c getresgid32.c getresuid.c getresuid32.c \
-+	getrlimit.c getrusage.c getsid.c getsockname.c gettid.c \
-+	getuid.c getuid32.c getxxid.c group_req.c inet-cmsg.c \
-+	init_module.c inject-nf.c inotify.c inotify_init.c \
-+	inotify_init-y.c inotify_init1.c inotify_init1-y.c int_0x80.c \
-+	io_uring_enter.c io_uring_register.c io_uring_setup.c ioctl.c \
-+	ioctl_block.c ioctl_dm.c ioctl_dm-v.c ioctl_evdev.c \
-+	ioctl_evdev-Xabbrev.c ioctl_evdev-Xraw.c \
-+	ioctl_evdev-Xverbose.c ioctl_evdev-success.c \
-+	ioctl_evdev-success-Xabbrev.c ioctl_evdev-success-Xraw.c \
-+	ioctl_evdev-success-Xverbose.c ioctl_evdev-success-v.c \
-+	ioctl_evdev-success-v-Xabbrev.c ioctl_evdev-success-v-Xraw.c \
-+	ioctl_evdev-success-v-Xverbose.c ioctl_evdev-v.c \
-+	ioctl_evdev-v-Xabbrev.c ioctl_evdev-v-Xraw.c \
- 	ioctl_evdev-v-Xverbose.c ioctl_inotify.c ioctl_kvm_run.c \
- 	ioctl_kvm_run-v.c ioctl_kvm_run_auxstr_vcpu.c ioctl_loop.c \
- 	ioctl_loop-nv.c ioctl_loop-v.c ioctl_mtd.c ioctl_nbd.c \
-@@ -4421,6 +4427,7 @@ pdfdir = @pdfdir@
- prefix = @prefix@
- program_transform_name = @program_transform_name@
- psdir = @psdir@
-+runstatedir = @runstatedir@
- sbindir = @sbindir@
- sharedstatedir = @sharedstatedir@
- srcdir = @srcdir@
-@@ -6165,6 +6172,10 @@ get_mempolicy$(EXEEXT): $(get_mempolicy_OBJECTS) $(get_mempolicy_DEPENDENCIES) $
- 	@rm -f get_mempolicy$(EXEEXT)
- 	$(AM_V_CCLD)$(LINK) $(get_mempolicy_OBJECTS) $(get_mempolicy_LDADD) $(LIBS)
- 
-+get_process_reaper$(EXEEXT): $(get_process_reaper_OBJECTS) $(get_process_reaper_DEPENDENCIES) $(EXTRA_get_process_reaper_DEPENDENCIES) 
-+	@rm -f get_process_reaper$(EXEEXT)
-+	$(AM_V_CCLD)$(LINK) $(get_process_reaper_OBJECTS) $(get_process_reaper_LDADD) $(LIBS)
-+
- getcpu$(EXEEXT): $(getcpu_OBJECTS) $(getcpu_DEPENDENCIES) $(EXTRA_getcpu_DEPENDENCIES) 
- 	@rm -f getcpu$(EXEEXT)
- 	$(AM_V_CCLD)$(LINK) $(getcpu_OBJECTS) $(getcpu_LDADD) $(LIBS)
-@@ -8512,6 +8523,7 @@ distclean-compile:
- @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/futex.Po@am__quote@ # am--include-marker
- @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/futimesat.Po@am__quote@ # am--include-marker
- @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/get_mempolicy.Po@am__quote@ # am--include-marker
-+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/get_process_reaper.Po@am__quote@ # am--include-marker
- @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getcpu.Po@am__quote@ # am--include-marker
- @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getcwd.Po@am__quote@ # am--include-marker
- @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getdents.Po@am__quote@ # am--include-marker
-@@ -10222,6 +10234,7 @@ distclean: distclean-am
- 	-rm -f ./$(DEPDIR)/futex.Po
- 	-rm -f ./$(DEPDIR)/futimesat.Po
- 	-rm -f ./$(DEPDIR)/get_mempolicy.Po
-+	-rm -f ./$(DEPDIR)/get_process_reaper.Po
- 	-rm -f ./$(DEPDIR)/getcpu.Po
- 	-rm -f ./$(DEPDIR)/getcwd.Po
- 	-rm -f ./$(DEPDIR)/getdents.Po
-@@ -10981,6 +10994,7 @@ maintainer-clean: maintainer-clean-am
- 	-rm -f ./$(DEPDIR)/futex.Po
- 	-rm -f ./$(DEPDIR)/futimesat.Po
- 	-rm -f ./$(DEPDIR)/get_mempolicy.Po
-+	-rm -f ./$(DEPDIR)/get_process_reaper.Po
- 	-rm -f ./$(DEPDIR)/getcpu.Po
- 	-rm -f ./$(DEPDIR)/getcwd.Po
- 	-rm -f ./$(DEPDIR)/getdents.Po
diff -pruN 5.5-3/debian/patches/03-disable_mips_umovestr_cached 5.9-0ubuntu2/debian/patches/03-disable_mips_umovestr_cached
--- 5.5-3/debian/patches/03-disable_mips_umovestr_cached	2020-04-07 14:17:29.000000000 +0000
+++ 5.9-0ubuntu2/debian/patches/03-disable_mips_umovestr_cached	1970-01-01 00:00:00.000000000 +0000
@@ -1,128 +0,0 @@
-Take upstream changes to disable this test on mips
-
---- a/tests/umovestr_cached.test	2020-04-07 17:02:24.956166544 +0100
-+++ b/tests/umovestr_cached.test	2020-04-07 17:02:15.860114447 +0100
-@@ -2,22 +2,30 @@
- #
- # Check effectiveness of umovestr memory caching.
- #
--# Copyright (c) 2017-2019 Dmitry V. Levin <ldv@altlinux.org>
-+# Copyright (c) 2017-2020 Dmitry V. Levin <ldv@altlinux.org>
- # All rights reserved.
- #
- # SPDX-License-Identifier: GPL-2.0-or-later
- 
- . "${srcdir=.}/init.sh"
- 
--run_strace_match_diff -e trace=writev
--
--if [ "$STRACE_ARCH" = ia64 ]; then
--	# ia64 invokes extra process_vm_readv syscalls to obtain syscall
--	# arguments, see linux/ia64/get_syscall_args.c for details.
--	skip_ "the test is not supported on $STRACE_ARCH yet"
--fi
--
- check_prog grep
-+$STRACE -d -enone / > /dev/null 2> "$LOG"
-+grep -x "[^:]*strace: PTRACE_GET_SYSCALL_INFO works" "$LOG" > /dev/null || {
-+	# PTRACE_GET_SYSCALL_INFO does not work
-+	case "$STRACE_ARCH:$MIPS_ABI" in
-+		ia64:|mips:o32)
-+		# ia64 invokes extra process_vm_readv syscalls to obtain syscall
-+		# arguments, see linux/ia64/get_syscall_args.c for details.
-+		# mips o32 obtains the first four syscalls arguments from registers
-+		# and invokes extra process_vm_readv syscalls to obtain remaining
-+		# syscall arguments, see linux/mips/get_syscall_args.c for details.
-+		skip_ "the test is not supported on $STRACE_ARCH yet"
-+		;;
-+	esac
-+}
-+
-+run_strace_match_diff -e trace=writev
- 
- run_strace -qq -esignal=none -eprocess_vm_readv -z \
- 	-o '|grep -c ^process_vm_readv > count' \
---- a/tests-m32/umovestr_cached.test	2020-04-07 17:02:24.956166544 +0100
-+++ b/tests-m32/umovestr_cached.test	2020-04-07 17:02:15.860114447 +0100
-@@ -2,22 +2,30 @@
- #
- # Check effectiveness of umovestr memory caching.
- #
--# Copyright (c) 2017-2019 Dmitry V. Levin <ldv@altlinux.org>
-+# Copyright (c) 2017-2020 Dmitry V. Levin <ldv@altlinux.org>
- # All rights reserved.
- #
- # SPDX-License-Identifier: GPL-2.0-or-later
- 
- . "${srcdir=.}/init.sh"
- 
--run_strace_match_diff -e trace=writev
--
--if [ "$STRACE_ARCH" = ia64 ]; then
--	# ia64 invokes extra process_vm_readv syscalls to obtain syscall
--	# arguments, see linux/ia64/get_syscall_args.c for details.
--	skip_ "the test is not supported on $STRACE_ARCH yet"
--fi
--
- check_prog grep
-+$STRACE -d -enone / > /dev/null 2> "$LOG"
-+grep -x "[^:]*strace: PTRACE_GET_SYSCALL_INFO works" "$LOG" > /dev/null || {
-+	# PTRACE_GET_SYSCALL_INFO does not work
-+	case "$STRACE_ARCH:$MIPS_ABI" in
-+		ia64:|mips:o32)
-+		# ia64 invokes extra process_vm_readv syscalls to obtain syscall
-+		# arguments, see linux/ia64/get_syscall_args.c for details.
-+		# mips o32 obtains the first four syscalls arguments from registers
-+		# and invokes extra process_vm_readv syscalls to obtain remaining
-+		# syscall arguments, see linux/mips/get_syscall_args.c for details.
-+		skip_ "the test is not supported on $STRACE_ARCH yet"
-+		;;
-+	esac
-+}
-+
-+run_strace_match_diff -e trace=writev
- 
- run_strace -qq -esignal=none -eprocess_vm_readv -z \
- 	-o '|grep -c ^process_vm_readv > count' \
---- a/tests-mx32/umovestr_cached.test	2020-04-07 17:02:24.956166544 +0100
-+++ b/tests-mx32/umovestr_cached.test	2020-04-07 17:02:15.860114447 +0100
-@@ -2,22 +2,30 @@
- #
- # Check effectiveness of umovestr memory caching.
- #
--# Copyright (c) 2017-2019 Dmitry V. Levin <ldv@altlinux.org>
-+# Copyright (c) 2017-2020 Dmitry V. Levin <ldv@altlinux.org>
- # All rights reserved.
- #
- # SPDX-License-Identifier: GPL-2.0-or-later
- 
- . "${srcdir=.}/init.sh"
- 
--run_strace_match_diff -e trace=writev
--
--if [ "$STRACE_ARCH" = ia64 ]; then
--	# ia64 invokes extra process_vm_readv syscalls to obtain syscall
--	# arguments, see linux/ia64/get_syscall_args.c for details.
--	skip_ "the test is not supported on $STRACE_ARCH yet"
--fi
--
- check_prog grep
-+$STRACE -d -enone / > /dev/null 2> "$LOG"
-+grep -x "[^:]*strace: PTRACE_GET_SYSCALL_INFO works" "$LOG" > /dev/null || {
-+	# PTRACE_GET_SYSCALL_INFO does not work
-+	case "$STRACE_ARCH:$MIPS_ABI" in
-+		ia64:|mips:o32)
-+		# ia64 invokes extra process_vm_readv syscalls to obtain syscall
-+		# arguments, see linux/ia64/get_syscall_args.c for details.
-+		# mips o32 obtains the first four syscalls arguments from registers
-+		# and invokes extra process_vm_readv syscalls to obtain remaining
-+		# syscall arguments, see linux/mips/get_syscall_args.c for details.
-+		skip_ "the test is not supported on $STRACE_ARCH yet"
-+		;;
-+	esac
-+}
-+
-+run_strace_match_diff -e trace=writev
- 
- run_strace -qq -esignal=none -eprocess_vm_readv -z \
- 	-o '|grep -c ^process_vm_readv > count' \
diff -pruN 5.5-3/debian/patches/04-fix_mips_getuid_tests 5.9-0ubuntu2/debian/patches/04-fix_mips_getuid_tests
--- 5.5-3/debian/patches/04-fix_mips_getuid_tests	2020-04-07 14:17:29.000000000 +0000
+++ 5.9-0ubuntu2/debian/patches/04-fix_mips_getuid_tests	1970-01-01 00:00:00.000000000 +0000
@@ -1,106 +0,0 @@
-commit 69fe885347080c72de428cf6bb6f727b3850e6f1
-Author: Dmitry V. Levin <ldv@altlinux.org>
-Date:   Tue Mar 31 22:57:10 2020 +0000
-
-    tests: fix get*id-creds tests on mips
-    
-    Apparently, mips executables may invoke prctl(PR_GET_FP_MODE) on their
-    own.  Since these calls are not filtered out by %creds, they have to be
-    dealt with before comparison.
-    
-    * tests/getuid.test [$STRACE_ARCH == mips]: Filter out
-    prctl(PR_GET_FP_MODE) from the log of %creds tests.
-
-diff --git a/tests/getuid.test b/tests/getuid.test
-index 50ed835c7..e8351a221 100755
---- a/tests/getuid.test
-+++ b/tests/getuid.test
-@@ -9,14 +9,25 @@
- 
- . "${srcdir=.}/init.sh"
- 
-+check_prog grep
- check_prog uniq
-+
- if [ "${NAME%-creds}" = "$NAME" ]; then
- 	syscall="$NAME"
- else
- 	NAME="${NAME%-creds}"
- 	syscall='%creds'
- fi
-+
- run_prog > /dev/null
- run_strace -qq -a9 -e"$syscall" $args > "$EXP"
--uniq < "$LOG" > "$OUT"
-+
-+case "$STRACE_ARCH:$syscall" in
-+	mips:%creds)
-+		grep -Fxv 'prctl(PR_GET_FP_MODE) = 0' < "$LOG" | uniq > "$OUT"
-+		;;
-+	*)	uniq < "$LOG" > "$OUT"
-+		;;
-+esac
-+
- match_diff "$OUT" "$EXP"
-diff --git a/tests-m32/getuid.test b/tests-m32/getuid.test
-index 50ed835c7..e8351a221 100755
---- a/tests-m32/getuid.test
-+++ b/tests-m32/getuid.test
-@@ -9,14 +9,25 @@
- 
- . "${srcdir=.}/init.sh"
- 
-+check_prog grep
- check_prog uniq
-+
- if [ "${NAME%-creds}" = "$NAME" ]; then
- 	syscall="$NAME"
- else
- 	NAME="${NAME%-creds}"
- 	syscall='%creds'
- fi
-+
- run_prog > /dev/null
- run_strace -qq -a9 -e"$syscall" $args > "$EXP"
--uniq < "$LOG" > "$OUT"
-+
-+case "$STRACE_ARCH:$syscall" in
-+	mips:%creds)
-+		grep -Fxv 'prctl(PR_GET_FP_MODE) = 0' < "$LOG" | uniq > "$OUT"
-+		;;
-+	*)	uniq < "$LOG" > "$OUT"
-+		;;
-+esac
-+
- match_diff "$OUT" "$EXP"
-diff --git a/tests-mx32/getuid.test b/tests-mx32/getuid.test
-index 50ed835c7..e8351a221 100755
---- a/tests-mx32/getuid.test
-+++ b/tests-mx32/getuid.test
-@@ -9,14 +9,25 @@
- 
- . "${srcdir=.}/init.sh"
- 
-+check_prog grep
- check_prog uniq
-+
- if [ "${NAME%-creds}" = "$NAME" ]; then
- 	syscall="$NAME"
- else
- 	NAME="${NAME%-creds}"
- 	syscall='%creds'
- fi
-+
- run_prog > /dev/null
- run_strace -qq -a9 -e"$syscall" $args > "$EXP"
--uniq < "$LOG" > "$OUT"
-+
-+case "$STRACE_ARCH:$syscall" in
-+	mips:%creds)
-+		grep -Fxv 'prctl(PR_GET_FP_MODE) = 0' < "$LOG" | uniq > "$OUT"
-+		;;
-+	*)	uniq < "$LOG" > "$OUT"
-+		;;
-+esac
-+
- match_diff "$OUT" "$EXP"
diff -pruN 5.5-3/debian/patches/kexec_file_load.patch 5.9-0ubuntu2/debian/patches/kexec_file_load.patch
--- 5.5-3/debian/patches/kexec_file_load.patch	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/debian/patches/kexec_file_load.patch	2020-10-26 14:50:39.000000000 +0000
@@ -0,0 +1,26 @@
+From: Adam Conrad <adconrad@ubuntu.com>
+Date: Thu, 16 Apr 2020 17:35:45 +0200
+Subject: Skip kexec_file_load test on arm64 before 5.0.
+
+Last-Update: 2019-05-02
+---
+ tests/kexec_file_load.gen.test | 8 ++++++++
+ 1 file changed, 8 insertions(+)
+
+diff --git a/tests/kexec_file_load.gen.test b/tests/kexec_file_load.gen.test
+index 1101349..682b076 100755
+--- a/tests/kexec_file_load.gen.test
++++ b/tests/kexec_file_load.gen.test
+@@ -1,4 +1,12 @@
+ #!/bin/sh -efu
+ # Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (kexec_file_load -s9 ); do not edit.
+ . "${srcdir=.}/init.sh"
++
++case $(uname -m) in
++  aarch64*)
++    # kexec_file_load was wired up after 4.18.x
++    require_min_kernel_version_or_skip 5.0
++    ;;
++esac
++
+ run_strace_match_diff -s9 
diff -pruN 5.5-3/debian/patches/no-arm-unaligned-access 5.9-0ubuntu2/debian/patches/no-arm-unaligned-access
--- 5.5-3/debian/patches/no-arm-unaligned-access	2020-04-07 14:17:29.000000000 +0000
+++ 5.9-0ubuntu2/debian/patches/no-arm-unaligned-access	1970-01-01 00:00:00.000000000 +0000
@@ -1,26 +0,0 @@
-From: Steve Langasek <steve.langasek@ubuntu.com>
-Date: Sun, 13 Jan 2019 10:26:19 +0100
-Subject: Don't allow unaligned access on ARM in the tests
-
-Last-Update: 2017-06-16
-
-The testsuite already handles alignment requirements on POWER and Sparc, add
-ARM to the list as well.  Not all ARM environments raise SIGBUS on unaligned
-access, but some (including the Ubuntu autobuilders) do.
----
- tests/perf_event_open.c | 2 +-
- 1 file changed, 1 insertion(+), 1 deletion(-)
-
-diff --git a/tests/perf_event_open.c b/tests/perf_event_open.c
-index ab8043f..c8859c9 100644
---- a/tests/perf_event_open.c
-+++ b/tests/perf_event_open.c
-@@ -489,7 +489,7 @@ end:
- }
- 
- /* These require aligned access, so no byte-grain checks possible */
--# if defined SPARC || defined SPARC64 || defined POWERPC || defined POWERPC64
-+# if defined SPARC || defined SPARC64 || defined POWERPC || defined POWERPC64 || defined ARM
- #  define ATTR_REC(sz) { tail_alloc((sz + 7) & ~7), sz }
- # else
- #  define ATTR_REC(sz) { tail_alloc(sz), sz }
diff -pruN 5.5-3/debian/patches/ptrace-error-verbosity.patch 5.9-0ubuntu2/debian/patches/ptrace-error-verbosity.patch
--- 5.5-3/debian/patches/ptrace-error-verbosity.patch	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/debian/patches/ptrace-error-verbosity.patch	2020-10-26 14:50:39.000000000 +0000
@@ -0,0 +1,29 @@
+From: Kees Cook <kees@ubuntu.com>
+Date: Thu, 16 Apr 2020 17:35:45 +0200
+Subject: try to make the PTRACE scope sysctl more discoverable via a
+
+verbose error message when failures happen.
+---
+ strace.c | 4 ++++
+ 1 file changed, 4 insertions(+)
+
+--- a/strace.c
++++ b/strace.c
+@@ -1187,6 +1187,8 @@
+ attach_tcb(struct tcb *const tcp)
+ {
+ 	if (ptrace_attach_or_seize(tcp->pid) < 0) {
++		if (errno == EPERM)
++			perror_msg("Could not attach to process. If your uid matches the uid of the target process, check the setting of /proc/sys/kernel/yama/ptrace_scope, or try again as the root user. For more details, see /etc/sysctl.d/10-ptrace.conf");
+ 		perror_msg("attach: ptrace(%s, %d)",
+ 			   ptrace_attach_cmd, tcp->pid);
+ 		droptcb(tcp);
+@@ -1216,6 +1218,8 @@
+ 
+ 			++ntid;
+ 			if (ptrace_attach_or_seize(tid) < 0) {
++				if (errno == EPERM)
++					perror_msg("Could not attach to process. If your uid matches the uid of the target process, check the setting of /proc/sys/kernel/yama/ptrace_scope, or try again as the root user. For more details, see /etc/sysctl.d/10-ptrace.conf");
+ 				++nerr;
+ 				debug_perror_msg("attach: ptrace(%s, %d)",
+ 						 ptrace_attach_cmd, tid);
diff -pruN 5.5-3/debian/patches/series 5.9-0ubuntu2/debian/patches/series
--- 5.5-3/debian/patches/series	2020-04-07 14:17:29.000000000 +0000
+++ 5.9-0ubuntu2/debian/patches/series	2020-10-26 14:50:39.000000000 +0000
@@ -1,6 +1,6 @@
-no-arm-unaligned-access
-01-fix_strace-DDD_test
 02-disable_delay_test
-03-disable_mips_umovestr_cached
-04-fix_mips_getuid_tests
 05-fixup_mips_creds_tests
+ptrace-error-verbosity.patch
+kexec_file_load.patch
+0006-s390-Check-infmname-with-IS_ARRAY_ZERO-too.patch
+0005-XFAIL-tests-on-m-32-which-use-struct-shm_info-or-s.patch
diff -pruN 5.5-3/debian/rules 5.9-0ubuntu2/debian/rules
--- 5.5-3/debian/rules	2020-04-07 14:17:29.000000000 +0000
+++ 5.9-0ubuntu2/debian/rules	2020-10-26 14:50:39.000000000 +0000
@@ -48,10 +48,18 @@ configure:
 
 %-stamp: %/Makefile
 	$(MAKE) -C $*
+
+# skip tests on riscv64, the dpkg fix is not perfect yet
+ifeq (,$(filter riscv64,$(DEB_HOST_ARCH)))
 ifeq (,$(findstring nocheck,$(DEB_BUILD_OPTIONS)))
+ifeq ($(DEB_HOST_ARCH),arm64)
+	# kexec_file_load only implemented on kernel >= 5.0
+	sed -i -e'/kexec_file_load/ s/^#*/#/' tests/pure_executables.list
+endif
 	$*/strace -V
 	$(MAKE) -C $* check VERBOSE=1
 endif
+endif
 	touch $@
 
 build/Makefile: configure
@@ -71,6 +79,7 @@ clean:
 	dh_testdir
 	dh_testroot
 	rm -rf build build-udeb build64 strace64.1 debian/strace64.substvars
+	sed -i -e'/kexec_file_load/ s/^#*//' tests/pure_executables.list
 	dh_clean
 
 binary: binary-indep binary-arch
diff -pruN 5.5-3/defs.h 5.9-0ubuntu2/defs.h
--- 5.5-3/defs.h	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/defs.h	2020-09-23 16:29:35.000000000 +0000
@@ -240,10 +240,13 @@ struct inject_data {
 
 struct inject_opts {
 	uint16_t first;
+	uint16_t last;
 	uint16_t step;
 	struct inject_data data;
 };
 
+# define INJECT_LAST_INF	((uint16_t) -1)
+
 # define MAX_ERRNO_VALUE			4095
 
 /* Trace Control Block */
@@ -256,6 +259,7 @@ struct tcb {
 # endif
 	unsigned long u_error;	/* Error code */
 	kernel_ulong_t scno;	/* System call number */
+	kernel_ulong_t true_scno;	/* Same, but without subcall decoding and shuffling */
 	kernel_ulong_t u_arg[MAX_ARGS];	/* System call arguments */
 	kernel_long_t u_rval;	/* Return value */
 	int sys_func_rval;	/* Syscall entry parser's return value */
@@ -277,6 +281,13 @@ struct tcb {
 	struct timespec etime;	/* Syscall entry time (CLOCK_MONOTONIC) */
 	struct timespec delay_expiration_time; /* When does the delay end */
 
+	/*
+	 * The ID of the PID namespace of this process
+	 * (inode number of /proc/<pid>/ns/pid)
+	 * (0: not initialized)
+	 */
+	unsigned int pid_ns;
+
 	struct mmap_cache_t *mmap_cache;
 
 	/*
@@ -410,7 +421,11 @@ extern const struct xlat whence_codes[];
 # define RVAL_HEX	001	/* hex format */
 # define RVAL_OCTAL	002	/* octal format */
 # define RVAL_FD		010	/* file descriptor */
-# define RVAL_MASK	013	/* mask for these values */
+# define RVAL_TID	011	/* task ID */
+# define RVAL_SID	012	/* session ID */
+# define RVAL_TGID	013	/* thread group ID */
+# define RVAL_PGID	014	/* process group ID */
+# define RVAL_MASK	017	/* mask for these values */
 
 # define RVAL_STR	020	/* Print `auxstr' field after return val */
 # define RVAL_NONE	040	/* Print nothing */
@@ -425,6 +440,16 @@ extern const struct xlat whence_codes[];
 
 # define indirect_ipccall(tcp) (tcp_sysent(tcp)->sys_flags & TRACE_INDIRECT_SUBCALL)
 
+enum pid_type {
+	PT_TID,
+	PT_TGID,
+	PT_PGID,
+	PT_SID,
+
+	PT_COUNT,
+	PT_NONE = -1
+};
+
 enum sock_proto {
 	SOCK_PROTO_UNKNOWN,
 	SOCK_PROTO_UNIX,
@@ -462,10 +487,11 @@ typedef enum {
 } cflag_t;
 extern cflag_t cflag;
 extern bool Tflag;
+extern int Tflag_scale;
+extern int Tflag_width;
 extern bool iflag;
 extern bool count_wallclock;
-extern unsigned int qflag;
-extern unsigned int show_fd_path;
+extern unsigned int pidns_translation;
 /* are we filtering traces based on paths? */
 extern struct path_set {
 	const char **paths_selected;
@@ -473,8 +499,16 @@ extern struct path_set {
 	size_t size;
 } global_path_set;
 # define tracing_paths (global_path_set.num_selected != 0)
+enum xflag_opts {
+	HEXSTR_NONE,
+	HEXSTR_NON_ASCII,
+	HEXSTR_ALL,
+
+	NUM_HEXSTR_OPTS
+};
 extern unsigned xflag;
-extern unsigned followfork;
+extern bool followfork;
+extern bool output_separately;
 # ifdef ENABLE_STACKTRACE
 /* if this is true do the stack trace for every system call */
 extern bool stack_trace_enabled;
@@ -487,15 +521,18 @@ extern unsigned os_release;
 # undef KERNEL_VERSION
 # define KERNEL_VERSION(a, b, c) (((a) << 16) + ((b) << 8) + (c))
 
-extern int read_int_from_file(struct tcb *, const char *, int *);
+extern int read_int_from_file(const char *, int *);
 
 extern void set_sortby(const char *);
 extern int set_overhead(const char *);
+extern void set_count_summary_columns(const char *columns);
 
 extern bool get_instruction_pointer(struct tcb *, kernel_ulong_t *);
 extern bool get_stack_pointer(struct tcb *, kernel_ulong_t *);
 extern void print_instruction_pointer(struct tcb *);
 
+extern void print_syscall_number(struct tcb *);
+
 extern void print_syscall_resume(struct tcb *tcp);
 
 extern int syscall_entering_decode(struct tcb *);
@@ -676,7 +713,14 @@ pathtrace_match(struct tcb *tcp)
 	return pathtrace_match_set(tcp, &global_path_set);
 }
 
-extern int getfdpath(struct tcb *, int, char *, unsigned);
+extern int getfdpath_pid(pid_t pid, int fd, char *buf, unsigned bufsize);
+
+static inline int
+getfdpath(struct tcb *tcp, int fd, char *buf, unsigned bufsize)
+{
+	return getfdpath_pid(tcp->pid, fd, buf, bufsize);
+}
+
 extern unsigned long getfdinode(struct tcb *, int);
 extern enum sock_proto getfdproto(struct tcb *, int);
 
@@ -708,11 +752,18 @@ str_strip_prefix_len(const char *str, co
 # define STR_STRIP_PREFIX(str, prefix)	\
 	str_strip_prefix_len((str), (prefix), sizeof(prefix) - 1)
 
+/** String is '\0'-terminated. */
 # define QUOTE_0_TERMINATED			0x01
+/** Do not emit leading and ending '"' characters. */
 # define QUOTE_OMIT_LEADING_TRAILING_QUOTES	0x02
+/** Do not print '\0' if it is the last character. */
 # define QUOTE_OMIT_TRAILING_0			0x08
-# define QUOTE_FORCE_HEX				0x10
-# define QUOTE_EMIT_COMMENT			0x20
+/** Print ellipsis if the last character is not '\0' */
+# define QUOTE_EXPECT_TRAILING_0		0x10
+/** Print string in hex (using '\xHH' notation). */
+# define QUOTE_FORCE_HEX			0x20
+/** Enclose the string in C comment syntax. */
+# define QUOTE_EMIT_COMMENT			0x40
 
 extern int string_quote(const char *, char *, unsigned int, unsigned int,
 			const char *escape_chars);
@@ -784,8 +835,18 @@ enum xlat_style_private_flags {
 	FLAG(PXF_DEFAULT_STR),
 };
 
-/** Print a value in accordance with xlat formatting settings. */
-extern void print_xlat_ex(uint64_t val, const char *str, enum xlat_style style);
+/**
+ * Print a value in accordance with xlat formatting settings.
+ *
+ * @param val   Value itself.
+ * @param str   String representation of the value.  Semantics may be affected
+ *              by style argument;
+ * @param style Combination of flags from enum xlat_style and PXF_* flags
+ *              from enum xlat_style_private_flags:
+ *               - PXF_DEFAULT_STR - interpret str argument as default
+ *                 (fallback) string and not as string representation of val.
+ */
+extern void print_xlat_ex(uint64_t val, const char *str, uint32_t style);
 # define print_xlat(val_) \
 	print_xlat_ex((val_), #val_, XLAT_STYLE_DEFAULT)
 # define print_xlat32(val_) \
@@ -832,7 +893,7 @@ extern void print_uuid(const unsigned ch
 
 extern void print_symbolic_mode_t(unsigned int);
 extern void print_numeric_umode_t(unsigned short);
-extern void print_numeric_long_umask(unsigned long);
+extern void print_numeric_ll_umode_t(unsigned long long);
 extern void print_dev_t(unsigned long long dev);
 extern void print_kernel_version(unsigned long version);
 extern void print_abnormal_hi(kernel_ulong_t);
@@ -939,7 +1000,7 @@ print_local_array_ex(struct tcb *tcp,
 }
 
 /** Shorthand for a shorthand for printing local arrays. */
-#define print_local_array(tcp_, start_addr_, print_func_)      \
+# define print_local_array(tcp_, start_addr_, print_func_)      \
 	print_local_array_ex((tcp_), (start_addr_), ARRAY_SIZE(start_addr_), \
 			     sizeof((start_addr_)[0]), (print_func_),        \
 			     NULL, 0, NULL, NULL)
@@ -947,6 +1008,29 @@ print_local_array_ex(struct tcb *tcp,
 extern kernel_ulong_t *
 fetch_indirect_syscall_args(struct tcb *, kernel_ulong_t addr, unsigned int n_args);
 
+extern void pidns_init(void);
+
+/**
+ * Returns the pid of the tracee as present in /proc of the tracer (can be
+ * different from tcp->pid if /proc and the tracer process are in different PID
+ * namespaces).
+ */
+extern int get_proc_pid(struct tcb *);
+
+/**
+ * Translates a pid from tracee's namespace to our namepace.
+ *
+ * @param tcp             The tcb of the tracee
+ *                        (NULL: from_id is in strace's namespace. Useful for
+ *                         getting the proc PID of from_id)
+ * @param from_id         The id to be translated
+ * @param type            The PID type of from_id
+ * @param proc_pid_ptr    If not NULL, writes the proc PID to this location
+ * @return                The translated id, or 0 if translation fails.
+ */
+extern int translate_pid(struct tcb *, int dest_id, enum pid_type type,
+		    int *proc_pid_ptr);
+
 extern void
 dumpiov_in_msghdr(struct tcb *, kernel_ulong_t addr, kernel_ulong_t data_size);
 
@@ -963,6 +1047,35 @@ extern int
 printstr_ex(struct tcb *, kernel_ulong_t addr, kernel_ulong_t len,
 	    unsigned int user_style);
 
+/**
+ * Print a region of tracee memory only in case non-zero bytes are present
+ * there.  It almost fits into printstr_ex, but it has some pretty specific
+ * behaviour peculiarities (like printing of ellipsis on error) to readily
+ * integrate it there.
+ *
+ * Since it is expected to be used for printing tail of a structure in tracee's
+ * memory, it accepts a combination of start_addr/start_offs/total_len and does
+ * the relevant calculations itself.
+ *
+ * @param prefix     A string printed in cases something is going to be printed.
+ * @param start_addr Address of the beginning of a structure (whose tail
+ *                   is supposedly to be printed) in tracee's memory.
+ * @param start_offs Offset from the beginning of the structure where the tail
+ *                   data starts.
+ * @param total_len  Total size of the tracee's memory region containing
+ *                   the structure and the tail data.
+ *                   Caller is responsible for imposing a sensible (usually
+ *                   mandated by the kernel interface, like get_pagesize())
+ *                   limit here.
+ * @param style      Passed to string_quote as "style" parameter.
+ * @return           Returns true is anything was printed, false otherwise.
+ */
+extern bool print_nonzero_bytes(struct tcb *const tcp, const char *prefix,
+				const kernel_ulong_t start_addr,
+				const unsigned int start_offs,
+				const unsigned int total_len,
+				const unsigned int style);
+
 extern int
 printpathn(struct tcb *, kernel_ulong_t addr, unsigned int n);
 
@@ -971,8 +1084,38 @@ printpath(struct tcb *, kernel_ulong_t a
 
 # define TIMESPEC_TEXT_BUFSIZE \
 		(sizeof(long long) * 3 * 2 + sizeof("{tv_sec=-, tv_nsec=}"))
-extern void printfd(struct tcb *, int);
-extern void print_sockaddr(const void *sa, int len);
+
+/**
+ * Returns the pid associated with pidfd of the process with ID pid_of_fd
+ */
+extern pid_t pidfd_get_pid(pid_t pid_of_fd, int fd);
+/**
+ * Print file descriptor fd owned by process with ID pid (from the PID NS
+ * of the tracer).
+ */
+extern void printfd_pid(struct tcb *tcp, pid_t pid, int fd);
+
+static inline void
+printfd(struct tcb *tcp, int fd)
+{
+	printfd_pid(tcp, tcp->pid, fd);
+}
+
+/**
+ * Print file descriptor fd owned by process with ID pid (from the PID NS
+ * of the tracee).
+ */
+extern void printfd_pid_tracee_ns(struct tcb *tcp, pid_t pid, int fd);
+
+/** Prints a PID specified in the tracee's PID namespace */
+extern void printpid(struct tcb *, int pid, enum pid_type type);
+
+/**
+ * Prints pid as a TGID if positive, and PGID if negative
+ * (like the first argument of kill).
+ */
+extern void printpid_tgid_pgid(struct tcb *, int pid);
+extern void print_sockaddr(struct tcb *, const void *sa, int len);
 extern bool
 print_inet_addr(int af, const void *addr, unsigned int len, const char *var_name);
 extern bool
@@ -1050,6 +1193,8 @@ extern void qualify_verbose(const char *
 extern void qualify_raw(const char *);
 extern void qualify_signals(const char *);
 extern void qualify_status(const char *);
+extern void qualify_quiet(const char *);
+extern void qualify_decode_fd(const char *);
 extern void qualify_read(const char *);
 extern void qualify_write(const char *);
 extern void qualify_fault(const char *);
@@ -1073,6 +1218,7 @@ DECL_IOCTL(nsfs);
 DECL_IOCTL(ptp);
 DECL_IOCTL(random);
 DECL_IOCTL(scsi);
+DECL_IOCTL(tee);
 DECL_IOCTL(term);
 DECL_IOCTL(ubi);
 DECL_IOCTL(uffdio);
@@ -1103,13 +1249,83 @@ extern void
 decode_netlink_kobject_uevent(struct tcb *, kernel_ulong_t addr,
 			      kernel_ulong_t len);
 
+enum find_xlat_flag_bits {
+	FXL_CASE_SENSITIVE_BIT,
+};
+
+enum find_xlat_flags {
+	/** Whether to use strcmp instead of strcasecmp for comparison */
+	FLAG(FXL_CASE_SENSITIVE),
+};
+
+/**
+ * Searches for a string-value pair in the provided array of pairs.
+ *
+ * @param items     Array of string-value pairs to search in.
+ * @param s         String to search for.
+ * @param num_items Item count in items array.
+ * @param flags     Bitwise-or'ed flags from enum find_xlat_flags.
+ * @return          Pointer to the first matching string-value pair inside items
+ *                  or NULL if nothing has been found.
+ */
+extern const struct xlat_data *find_xlat_val_ex(const struct xlat_data *items,
+						const char *s, size_t num_items,
+						unsigned int flags);
+# define find_xlat_val(items_, s_) \
+	find_xlat_val_ex((items_), (s_), ARRAY_SIZE(items_), 0)
+# define find_xlat_val_case(items_, s_) \
+	find_xlat_val_ex((items_), (s_), ARRAY_SIZE(items_), FXL_CASE_SENSITIVE)
+
+/**
+ * A find_xlat_val_ex wrapper for option arguments parsing.  Provides a value
+ * from strs array that matched the supplied arg string.  If arg is NULL,
+ * default_val is returned.  If nothing has matched, not_found value
+ * is returned.
+ *
+ * find_arg_val provides a wrapper for the common case of statically-defined
+ * strs arrays.
+ *
+ * @param arg         Argument string to parse
+ * @param strs        Array of string-value pairs to match arg against.
+ * @param strs_size   Element count in the strs array.
+ * @param default_val Value to return if arg is NULL.
+ * @param not_found   Value to return if arg hasn't found among strs.
+ * @return            default_val is arg is NULL, value part of the matched
+ *                    string-value pair, or not_found if nothing has matched.
+ */
+extern uint64_t find_arg_val_(const char *arg, const struct xlat_data *strs,
+			      size_t strs_size, uint64_t default_val,
+			      uint64_t not_found);
+/** A find_arg_val_ wrapper that supplies strs_size to it using ARRAY_SIZE. */
+# define find_arg_val(arg_, strs_, dflt_, not_found_) \
+	find_arg_val_((arg_), (strs_), ARRAY_SIZE(strs_), (dflt_), (not_found_))
+
+/**
+ * A find_arg_val wrapper for parsing time scale names.
+ *
+ * @param arg        String to parse
+ * @param empty_dflt Default scale for the empty arg.
+ * @param null_dflt  Default scale for the NULL arg.
+ * @param width      Width of the field required to print the second part
+ *                   with the specified precision.
+ * @return           Time scale (amount of nanoseconds) if found,
+ *                   empty_dflt if arg is empty, null_dflt if arg is NULL,
+ *                   -1 if arg doesn't match any known time scale.
+ */
+extern int str2timescale_ex(const char *arg, int empty_dflt, int null_dflt,
+			    int *width);
+/** str2timescale_ex wrapper for handling a separate argument. */
+# define str2timescale_optarg(arg_, w_) str2timescale_ex((arg_), -1, 1000, (w_))
+/** str2timescale_ex wrapper for handling a suffix in existing argument. */
+# define str2timescale_sfx(arg_, w_) str2timescale_ex((arg_), 1000, -1, (w_))
+
 extern int ts_nz(const struct timespec *);
 extern int ts_cmp(const struct timespec *, const struct timespec *);
 extern double ts_float(const struct timespec *);
 extern void ts_add(struct timespec *, const struct timespec *, const struct timespec *);
 extern void ts_sub(struct timespec *, const struct timespec *, const struct timespec *);
-extern void ts_mul(struct timespec *, const struct timespec *, int);
-extern void ts_div(struct timespec *, const struct timespec *, int);
+extern void ts_mul(struct timespec *, const struct timespec *, uint64_t);
+extern void ts_div(struct timespec *, const struct timespec *, uint64_t);
 extern const struct timespec *ts_min(const struct timespec *, const struct timespec *);
 extern const struct timespec *ts_max(const struct timespec *, const struct timespec *);
 extern int parse_ts(const char *s, struct timespec *t);
@@ -1194,11 +1410,13 @@ tprint_iov(struct tcb *tcp, kernel_ulong
 	tprint_iov_upto(tcp, len, addr, decode_iov, -1);
 }
 
-# if HAVE_ARCH_TIME32_SYSCALLS
+# if HAVE_ARCH_TIME32_SYSCALLS || HAVE_ARCH_TIMESPEC32
 extern bool print_timespec32_data_size(const void *arg, size_t size);
 extern bool print_timespec32_array_data_size(const void *arg,
 					     unsigned int nmemb,
 					     size_t size);
+# endif /* HAVE_ARCH_TIME32_SYSCALLS || HAVE_ARCH_TIMESPEC32 */
+# if HAVE_ARCH_TIME32_SYSCALLS
 extern int print_timespec32(struct tcb *, kernel_ulong_t);
 extern const char *sprint_timespec32(struct tcb *, kernel_ulong_t);
 extern int print_timespec32_utime_pair(struct tcb *, kernel_ulong_t);
@@ -1347,6 +1565,9 @@ DECL_PRINTNUM_ADDR(int64);
 extern bool
 printnum_fd(struct tcb *, kernel_ulong_t addr);
 
+extern bool
+printnum_pid(struct tcb *const tcp, const kernel_ulong_t addr, enum pid_type type);
+
 static inline bool
 printnum_slong(struct tcb *tcp, kernel_ulong_t addr)
 {
@@ -1537,4 +1758,64 @@ scno_is_valid(kernel_ulong_t scno)
 
 # define SYS_FUNC(syscall_name) int SYS_FUNC_NAME(sys_ ## syscall_name)(struct tcb *tcp)
 
+# define ILOG2_ITER_(val_, ret_, bit_)					\
+	do {								\
+		typeof(ret_) shift_ =					\
+			((val_) > ((((typeof(val_)) 1)			\
+				   << (1 << (bit_))) - 1)) << (bit_);	\
+		(val_) >>= shift_;					\
+		(ret_) |= shift_;					\
+	} while (0)
+
+/**
+ * Calculate floor(log2(val)), with the exception of val == 0, for which 0
+ * is returned as well.
+ *
+ * @param val 64-bit value to calculate integer base-2 logarithm for.
+ * @return    (unsigned int) floor(log2(val)) if val > 0, 0 if val == 0.
+ */
+static inline unsigned int
+ilog2_64(uint64_t val)
+{
+	unsigned int ret = 0;
+
+	ILOG2_ITER_(val, ret, 5);
+	ILOG2_ITER_(val, ret, 4);
+	ILOG2_ITER_(val, ret, 3);
+	ILOG2_ITER_(val, ret, 2);
+	ILOG2_ITER_(val, ret, 1);
+	ILOG2_ITER_(val, ret, 0);
+
+	return ret;
+}
+
+/**
+ * Calculate floor(log2(val)), with the exception of val == 0, for which 0
+ * is returned as well.
+ *
+ * @param val 32-bit value to calculate integer base-2 logarithm for.
+ * @return    (unsigned int) floor(log2(val)) if val > 0, 0 if val == 0.
+ */
+static inline unsigned int
+ilog2_32(uint32_t val)
+{
+	unsigned int ret = 0;
+
+	ILOG2_ITER_(val, ret, 4);
+	ILOG2_ITER_(val, ret, 3);
+	ILOG2_ITER_(val, ret, 2);
+	ILOG2_ITER_(val, ret, 1);
+	ILOG2_ITER_(val, ret, 0);
+
+	return ret;
+}
+
+# if SIZEOF_KERNEL_LONG_T > 4
+#  define ilog2_klong ilog2_64
+# else
+#  define ilog2_klong ilog2_32
+# endif
+
+# undef ILOG2_ITER_
+
 #endif /* !STRACE_DEFS_H */
diff -pruN 5.5-3/depcomp 5.9-0ubuntu2/depcomp
--- 5.5-3/depcomp	2020-02-06 16:23:37.000000000 +0000
+++ 5.9-0ubuntu2/depcomp	2020-09-24 09:19:02.000000000 +0000
@@ -3,7 +3,7 @@
 
 scriptversion=2018-03-07.03; # UTC
 
-# Copyright (C) 1999-2018 Free Software Foundation, Inc.
+# Copyright (C) 1999-2020 Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
diff -pruN 5.5-3/desc.c 5.9-0ubuntu2/desc.c
--- 5.5-3/desc.c	2019-05-22 11:05:13.000000000 +0000
+++ 5.9-0ubuntu2/desc.c	2020-06-01 14:15:16.000000000 +0000
@@ -3,7 +3,7 @@
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995, 1996 Rick Sladkey <jrs@world.std.com>
  * Copyright (c) 1996-1999 Wichert Akkerman <wichert@cistron.nl>
- * Copyright (c) 1999-2019 The strace developers.
+ * Copyright (c) 1999-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -19,37 +19,6 @@ SYS_FUNC(close)
 	return RVAL_DECODED;
 }
 
-SYS_FUNC(dup)
-{
-	printfd(tcp, tcp->u_arg[0]);
-
-	return RVAL_DECODED | RVAL_FD;
-}
-
-static int
-do_dup2(struct tcb *tcp, int flags_arg)
-{
-	printfd(tcp, tcp->u_arg[0]);
-	tprints(", ");
-	printfd(tcp, tcp->u_arg[1]);
-	if (flags_arg >= 0) {
-		tprints(", ");
-		printflags(open_mode_flags, tcp->u_arg[flags_arg], "O_???");
-	}
-
-	return RVAL_DECODED | RVAL_FD;
-}
-
-SYS_FUNC(dup2)
-{
-	return do_dup2(tcp, -1);
-}
-
-SYS_FUNC(dup3)
-{
-	return do_dup2(tcp, 2);
-}
-
 static int
 decode_select(struct tcb *const tcp, const kernel_ulong_t *const args,
 	      const print_obj_by_addr_fn print_tv_ts,
diff -pruN 5.5-3/dirent64.c 5.9-0ubuntu2/dirent64.c
--- 5.5-3/dirent64.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/dirent64.c	2020-04-12 00:32:29.000000000 +0000
@@ -1,106 +1,63 @@
 /*
- * Copyright (c) 1991, 1992 Paul Kranenburg <pk@cs.few.eur.nl>
- * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
- * Copyright (c) 1993, 1994, 1995, 1996 Rick Sladkey <jrs@world.std.com>
- * Copyright (c) 1996-1999 Wichert Akkerman <wichert@cistron.nl>
- * Copyright (c) 2005-2015 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#include "defs.h"
-#include <dirent.h>
-
-#include "xlat/dirent_types.h"
+#include "xgetdents.h"
+#include "kernel_dirent.h"
+#include "print_fields.h"
 
 #define D_NAME_LEN_MAX 256
 
-SYS_FUNC(getdents64)
+static void
+print_dentry_head(const kernel_dirent64_t *const dent)
 {
-	/* the minimum size of a valid dirent64 structure */
-	const unsigned int d_name_offset = offsetof(struct dirent64, d_name);
+	PRINT_FIELD_U("{", *dent, d_ino);
+	PRINT_FIELD_U(", ", *dent, d_off);
+	PRINT_FIELD_U(", ", *dent, d_reclen);
+}
 
-	unsigned int i, len, dents = 0;
-	char *buf;
+static unsigned int
+decode_dentry_head(struct tcb *const tcp, const void *const arg)
+{
+	const kernel_dirent64_t *const dent = arg;
 
-	if (entering(tcp)) {
-		printfd(tcp, tcp->u_arg[0]);
-		return 0;
-	}
+	if (!abbrev(tcp))
+		print_dentry_head(dent);
 
-	const unsigned int count = tcp->u_arg[2];
+	return dent->d_reclen;
+}
 
-	if (syserror(tcp) || !verbose(tcp)) {
-		tprints(", ");
-		printaddr(tcp->u_arg[1]);
-		tprintf(", %u", count);
-		return 0;
-	}
+static int
+decode_dentry_tail(struct tcb *const tcp, kernel_ulong_t addr,
+		   const void *const arg, unsigned int d_name_len)
+{
+	const kernel_dirent64_t *const dent = arg;
+	int rc = 0;
 
-	/* Beware of insanely large or too small values in tcp->u_rval */
-	if (tcp->u_rval > 1024*1024)
-		len = 1024*1024;
-	else if (tcp->u_rval < (int) d_name_offset)
-		len = 0;
-	else
-		len = tcp->u_rval;
-
-	if (len) {
-		buf = malloc(len);
-		if (!buf || umoven(tcp, tcp->u_arg[1], len, buf) < 0) {
-			tprints(", ");
-			printaddr(tcp->u_arg[1]);
-			tprintf(", %u", count);
-			free(buf);
-			return 0;
-		}
-	} else {
-		buf = NULL;
-	}
+	/* !abbrev(tcp) */
 
-	tprints(",");
-	if (!abbrev(tcp))
-		tprints(" [");
-	for (i = 0; len && i <= len - d_name_offset; ) {
-		struct dirent64 *d = (struct dirent64 *) &buf[i];
-		if (!abbrev(tcp)) {
-			int d_name_len;
-			if (d->d_reclen >= d_name_offset
-			    && i + d->d_reclen <= len) {
-				d_name_len = d->d_reclen - d_name_offset;
-			} else {
-				d_name_len = len - i - d_name_offset;
-			}
-			if (d_name_len > D_NAME_LEN_MAX)
-				d_name_len = D_NAME_LEN_MAX;
-
-			tprintf("%s{d_ino=%" PRIu64 ", d_off=%" PRId64
-				", d_reclen=%u, d_type=",
-				i ? ", " : "",
-				d->d_ino,
-				d->d_off,
-				d->d_reclen);
-			printxval(dirent_types, d->d_type, "DT_???");
-
-			tprints(", d_name=");
-			print_quoted_cstring(d->d_name, d_name_len);
-
-			tprints("}");
-		}
-		if (d->d_reclen < d_name_offset) {
-			tprints_comment("d_reclen < offsetof(struct dirent64, d_name)");
-			break;
-		}
-		i += d->d_reclen;
-		dents++;
+	PRINT_FIELD_XVAL(", ", *dent, d_type, dirent_types, "DT_???");
+
+	if (d_name_len) {
+		if (d_name_len > D_NAME_LEN_MAX)
+			d_name_len = D_NAME_LEN_MAX;
+		tprints(", d_name=");
+		rc = printpathn(tcp, addr, d_name_len - 1);
 	}
-	if (!abbrev(tcp))
-		tprints("]");
-	else
-		tprintf_comment("%u entries", dents);
-	tprintf(", %u", count);
-	free(buf);
-	return 0;
+	tprints("}");
+
+	return rc;
+}
+
+SYS_FUNC(getdents64)
+{
+	/* The minimum size of a valid directory entry.  */
+	static const unsigned int header_size =
+		offsetof(kernel_dirent64_t, d_name);
+
+	return xgetdents(tcp, header_size,
+			 decode_dentry_head, decode_dentry_tail);
 }
diff -pruN 5.5-3/dirent.c 5.9-0ubuntu2/dirent.c
--- 5.5-3/dirent.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/dirent.c	2020-06-01 14:15:16.000000000 +0000
@@ -4,34 +4,95 @@
  * Copyright (c) 1993, 1994, 1995, 1996 Rick Sladkey <jrs@world.std.com>
  * Copyright (c) 1996-1999 Wichert Akkerman <wichert@cistron.nl>
  * Copyright (c) 2005-2015 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2014-2018 The strace developers.
+ * Copyright (c) 2014-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #include "defs.h"
+#include "kernel_dirent.h"
 
-#include DEF_MPERS_TYPE(kernel_dirent)
+#include DEF_MPERS_TYPE(kernel_dirent_t)
 
 #include MPERS_DEFS
 
+#include "xgetdents.h"
+#include "print_fields.h"
+
 #define D_NAME_LEN_MAX 256
 
+/* The minimum size of a valid directory entry.  */
+static const unsigned int header_size =
+	offsetof(kernel_dirent_t, d_name);
+
+static void
+print_dentry_head(const kernel_dirent_t *const dent)
+{
+	PRINT_FIELD_U("{", *dent, d_ino);
+	PRINT_FIELD_U(", ", *dent, d_off);
+	PRINT_FIELD_U(", ", *dent, d_reclen);
+}
+
+static unsigned int
+decode_dentry_head(struct tcb *const tcp, const void *const arg)
+{
+	const kernel_dirent_t *const dent = arg;
+
+	if (!abbrev(tcp))
+		print_dentry_head(dent);
+
+	return dent->d_reclen;
+}
+
+static int
+decode_dentry_tail(struct tcb *const tcp, kernel_ulong_t addr,
+		   const void *const arg, const unsigned int d_name_type_len)
+{
+	int rc = 0;
+
+	/* !abbrev(tcp) */
+
+	if (d_name_type_len) {
+		unsigned int d_name_len = d_name_type_len - 1;
+		if (d_name_len) {
+			if (d_name_len > D_NAME_LEN_MAX)
+				d_name_len = D_NAME_LEN_MAX;
+			tprints(", d_name=");
+			rc = printpathn(tcp, addr, d_name_len - 1);
+		}
+		tprints(", d_type=");
+		const kernel_ulong_t d_type_addr =
+			addr + (d_name_type_len - 1);
+		unsigned char d_type;
+		if (umove_or_printaddr(tcp, d_type_addr, &d_type))
+			rc = -1;
+		else
+			printxval(dirent_types, d_type, "DT_???");
+	}
+	tprints("}");
+
+	return rc;
+}
+
+SYS_FUNC(getdents)
+{
+	return xgetdents(tcp, header_size,
+			 decode_dentry_head, decode_dentry_tail);
+}
+
 static void
 print_old_dirent(struct tcb *const tcp, const kernel_ulong_t addr)
 {
-	kernel_dirent d;
+	kernel_dirent_t dent;
 
-	if (umove_or_printaddr(tcp, addr, &d))
+	if (umove_or_printaddr(tcp, addr, &dent))
 		return;
 
-	tprintf("{d_ino=%llu, d_off=%llu, d_reclen=%u, d_name=",
-		zero_extend_signed_to_ull(d.d_ino),
-		zero_extend_signed_to_ull(d.d_off), d.d_reclen);
-	if (d.d_reclen > D_NAME_LEN_MAX)
-		d.d_reclen = D_NAME_LEN_MAX;
-	printpathn(tcp, addr + offsetof(kernel_dirent, d_name), d.d_reclen);
+	print_dentry_head(&dent);
+	tprints(", d_name=");
+	printpathn(tcp, addr + header_size,
+		   MIN(dent.d_reclen, D_NAME_LEN_MAX));
 	tprints("}");
 }
 
@@ -45,94 +106,10 @@ SYS_FUNC(readdir)
 			printaddr(tcp->u_arg[1]);
 		else
 			print_old_dirent(tcp, tcp->u_arg[1]);
+		const unsigned int count = tcp->u_arg[2];
 		/* Not much point in printing this out, it is always 1. */
-		if (tcp->u_arg[2] != 1)
-			tprintf(", %" PRI_klu, tcp->u_arg[2]);
-	}
-	return 0;
-}
-
-SYS_FUNC(getdents)
-{
-	unsigned int i, len, dents = 0;
-	unsigned char *buf;
-
-	if (entering(tcp)) {
-		printfd(tcp, tcp->u_arg[0]);
-		return 0;
-	}
-
-	const unsigned int count = tcp->u_arg[2];
-
-	if (syserror(tcp) || !verbose(tcp)) {
-		tprints(", ");
-		printaddr(tcp->u_arg[1]);
-		tprintf(", %u", count);
-		return 0;
-	}
-
-	/* Beware of insanely large or too small values in tcp->u_rval */
-	if (tcp->u_rval > 1024*1024)
-		len = 1024*1024;
-	else if (tcp->u_rval < (int) sizeof(kernel_dirent))
-		len = 0;
-	else
-		len = tcp->u_rval;
-
-	if (len) {
-		buf = malloc(len);
-		if (!buf || umoven(tcp, tcp->u_arg[1], len, buf) < 0) {
-			tprints(", ");
-			printaddr(tcp->u_arg[1]);
+		if (count != 1)
 			tprintf(", %u", count);
-			free(buf);
-			return 0;
-		}
-	} else {
-		buf = NULL;
 	}
-
-	tprints(",");
-	if (!abbrev(tcp))
-		tprints(" [");
-	for (i = 0; len && i <= len - sizeof(kernel_dirent); ) {
-		kernel_dirent *d = (kernel_dirent *) &buf[i];
-
-		if (!abbrev(tcp)) {
-			int oob = d->d_reclen < sizeof(kernel_dirent) ||
-				  i + d->d_reclen - 1 >= len;
-			int d_name_len = oob ? len - i : d->d_reclen;
-			d_name_len -= offsetof(kernel_dirent, d_name) + 1;
-			if (d_name_len > D_NAME_LEN_MAX)
-				d_name_len = D_NAME_LEN_MAX;
-
-			tprintf("%s{d_ino=%llu, d_off=%llu, d_reclen=%u"
-				", d_name=", i ? ", " : "",
-				zero_extend_signed_to_ull(d->d_ino),
-				zero_extend_signed_to_ull(d->d_off),
-				d->d_reclen);
-
-			print_quoted_cstring(d->d_name, d_name_len);
-
-			tprints(", d_type=");
-			if (oob)
-				tprints("?");
-			else
-				printxval(dirent_types, buf[i + d->d_reclen - 1], "DT_???");
-			tprints("}");
-		}
-		dents++;
-		if (d->d_reclen < sizeof(kernel_dirent)) {
-			tprints_comment("d_reclen < sizeof(struct dirent)");
-			break;
-		}
-		i += d->d_reclen;
-	}
-	if (!abbrev(tcp))
-		tprints("]");
-	else
-		tprintf_comment("%u entries", dents);
-	tprintf(", %u", count);
-	free(buf);
 	return 0;
 }
diff -pruN 5.5-3/dirent_types.c 5.9-0ubuntu2/dirent_types.c
--- 5.5-3/dirent_types.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/dirent_types.c	2020-04-12 00:32:29.000000000 +0000
@@ -0,0 +1,11 @@
+/*
+ * Copyright (c) 2005-2015 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2015-2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
+#include "defs.h"
+#include <dirent.h>
+#include "xlat/dirent_types.h"
diff -pruN 5.5-3/dup.c 5.9-0ubuntu2/dup.c
--- 5.5-3/dup.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/dup.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,42 @@
+/*
+ * Copyright (c) 1999-2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
+#include "defs.h"
+
+static int
+dup_123(struct tcb *const tcp, const int newfd_arg, const int flags_arg)
+{
+	printfd(tcp, tcp->u_arg[0]);
+
+	if (newfd_arg > 0) {
+		tprints(", ");
+		printfd(tcp, tcp->u_arg[newfd_arg]);
+
+		if (flags_arg > 0) {
+			tprints(", ");
+			printflags(open_mode_flags, tcp->u_arg[flags_arg],
+				   "O_???");
+		}
+	}
+
+	return RVAL_DECODED | RVAL_FD;
+}
+
+SYS_FUNC(dup)
+{
+	return dup_123(tcp, -1, -1);
+}
+
+SYS_FUNC(dup2)
+{
+	return dup_123(tcp, 1, -1);
+}
+
+SYS_FUNC(dup3)
+{
+	return dup_123(tcp, 1, 2);
+}
diff -pruN 5.5-3/evdev.c 5.9-0ubuntu2/evdev.c
--- 5.5-3/evdev.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/evdev.c	2020-07-12 08:00:00.000000000 +0000
@@ -14,6 +14,7 @@
 
 #ifdef HAVE_LINUX_INPUT_H
 
+# include "print_fields.h"
 # include <linux/ioctl.h>
 # include "types/evdev.h"
 
@@ -75,27 +76,21 @@ abs_ioctl(struct tcb *const tcp, const u
 	if (umoven_or_printaddr(tcp, arg, read_sz, &absinfo))
 		return RVAL_IOCTL_DECODED;
 
-	tprintf("{value=%u"
-		", minimum=%u, ",
-		absinfo.value,
-		absinfo.minimum);
+	PRINT_FIELD_U("{", absinfo, value);
+	PRINT_FIELD_U(", ", absinfo, minimum);
 
 	if (!abbrev(tcp)) {
-		tprintf("maximum=%u"
-			", fuzz=%u"
-			", flat=%u",
-			absinfo.maximum,
-			absinfo.fuzz,
-			absinfo.flat);
-		if (sz >= res_sz) {
-			tprintf(", resolution=%u%s",
-				absinfo.resolution,
-				sz > res_sz ? ", ..." : "");
-		} else if (sz > orig_sz) {
-			tprints(", ...");
+		PRINT_FIELD_U(", ", absinfo, maximum);
+		PRINT_FIELD_U(", ", absinfo, fuzz);
+		PRINT_FIELD_U(", ", absinfo, flat);
+		if (sz > orig_sz) {
+			if (sz >= res_sz)
+				PRINT_FIELD_U(", ", absinfo, resolution);
+			if (sz != res_sz)
+				tprints(", ...");
 		}
 	} else {
-		tprints("...");
+		tprints(", ...");
 	}
 
 	tprints("}");
@@ -129,25 +124,15 @@ keycode_V2_ioctl(struct tcb *const tcp,
 	if (umove_or_printaddr(tcp, arg, &ike))
 		return RVAL_IOCTL_DECODED;
 
-	tprintf("{flags=%" PRIu8
-		", len=%" PRIu8 ", ",
-		ike.flags,
-		ike.len);
+	PRINT_FIELD_U("{", ike, flags);
+	PRINT_FIELD_U(", ", ike, len);
 
 	if (!abbrev(tcp)) {
-		unsigned int i;
-
-		tprintf("index=%" PRIu16 ", keycode=", ike.index);
-		printxval(evdev_keycode, ike.keycode, "KEY_???");
-		tprints(", scancode=[");
-		for (i = 0; i < ARRAY_SIZE(ike.scancode); i++) {
-			if (i > 0)
-				tprints(", ");
-			tprintf("%" PRIx8, ike.scancode[i]);
-		}
-		tprints("]");
+		PRINT_FIELD_U(", ", ike, index);
+		PRINT_FIELD_XVAL(", ", ike, keycode, evdev_keycode, "KEY_???");
+		PRINT_FIELD_X_ARRAY(", ", ike, scancode);
 	} else {
-		tprints("...");
+		tprints(", ...");
 	}
 
 	tprints("}");
@@ -162,15 +147,13 @@ getid_ioctl(struct tcb *const tcp, const
 
 	struct input_id id;
 
-	if (!umove_or_printaddr(tcp, arg, &id))
-		tprintf("{ID_BUS=%" PRIu16
-			", ID_VENDOR=%" PRIu16
-			", ID_PRODUCT=%" PRIu16
-			", ID_VERSION=%" PRIu16 "}",
-			id.bustype,
-			id.vendor,
-			id.product,
-			id.version);
+	if (!umove_or_printaddr(tcp, arg, &id)) {
+		PRINT_FIELD_U("{", id, bustype);
+		PRINT_FIELD_U(", ", id, vendor);
+		PRINT_FIELD_U(", ", id, product);
+		PRINT_FIELD_U(", ", id, version);
+		tprints("}");
+	}
 
 	return RVAL_IOCTL_DECODED;
 }
diff -pruN 5.5-3/evdev_mpers.c 5.9-0ubuntu2/evdev_mpers.c
--- 5.5-3/evdev_mpers.c	2019-11-28 19:30:05.000000000 +0000
+++ 5.9-0ubuntu2/evdev_mpers.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2015 Etienne Gemsa <etienne.gemsa@lse.epita.fr>
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -24,19 +24,18 @@ typedef struct ff_effect struct_ff_effec
 
 #ifdef HAVE_LINUX_INPUT_H
 
+# include "print_fields.h"
+
 static void
 decode_envelope(void *const data)
 {
 	const struct ff_envelope *const envelope = data;
 
-	tprintf(", envelope={attack_length=%" PRIu16
-		", attack_level=%" PRIu16
-		", fade_length=%" PRIu16
-		", fade_level=%#x}",
-		envelope->attack_length,
-		envelope->attack_level,
-		envelope->fade_length,
-		envelope->fade_level);
+	PRINT_FIELD_U(", envelope={", *envelope, attack_length);
+	PRINT_FIELD_U(", ", *envelope, attack_level);
+	PRINT_FIELD_U(", ", *envelope, fade_length);
+	PRINT_FIELD_X(", ", *envelope, fade_level);
+	tprints("}");
 }
 
 static int
@@ -51,62 +50,48 @@ ff_effect_ioctl(struct tcb *const tcp, c
 
 	tprints("{type=");
 	print_evdev_ff_type(ffe.type);
-	tprintf(", id=%" PRIu16
-		", direction=%" PRIu16 ", ",
-		ffe.id,
-		ffe.direction);
+	PRINT_FIELD_D(", ", ffe, id);
+	PRINT_FIELD_U(", ", ffe, direction);
 
 	if (abbrev(tcp)) {
-		tprints("...}");
+		tprints(", ...}");
 		return RVAL_IOCTL_DECODED;
 	}
 
-	tprintf("trigger={button=%" PRIu16
-		", interval=%" PRIu16 "}"
-		", replay={length=%" PRIu16
-		", delay=%" PRIu16 "}",
-		ffe.trigger.button,
-		ffe.trigger.interval,
-		ffe.replay.length,
-		ffe.replay.delay);
+	PRINT_FIELD_U(", trigger={", ffe.trigger, button);
+	PRINT_FIELD_U(", ", ffe.trigger, interval);
+	PRINT_FIELD_U("}, replay={", ffe.replay, length);
+	PRINT_FIELD_U(", ", ffe.replay, delay);
+	tprints("}");
 
 	switch (ffe.type) {
 	case FF_CONSTANT:
-		tprintf(", constant={level=%" PRId16,
-			ffe.u.constant.level);
+		PRINT_FIELD_D(", constant={", ffe.u.constant, level);
 		decode_envelope(&ffe.u.constant.envelope);
 		tprints("}");
 		break;
 	case FF_RAMP:
-		tprintf(", ramp={start_level=%" PRId16
-			", end_level=%" PRId16,
-			ffe.u.ramp.start_level,
-			ffe.u.ramp.end_level);
+		PRINT_FIELD_D(", ramp={", ffe.u.ramp, start_level);
+		PRINT_FIELD_D(", ", ffe.u.ramp, end_level);
 		decode_envelope(&ffe.u.ramp.envelope);
 		tprints("}");
 		break;
 	case FF_PERIODIC:
-		tprintf(", periodic={waveform=%" PRIu16
-			", period=%" PRIu16
-			", magnitude=%" PRId16
-			", offset=%" PRId16
-			", phase=%" PRIu16,
-			ffe.u.periodic.waveform,
-			ffe.u.periodic.period,
-			ffe.u.periodic.magnitude,
-			ffe.u.periodic.offset,
-			ffe.u.periodic.phase);
+		PRINT_FIELD_U(", periodic={", ffe.u.periodic, waveform);
+		PRINT_FIELD_U(", ", ffe.u.periodic, period);
+		PRINT_FIELD_D(", ", ffe.u.periodic, magnitude);
+		PRINT_FIELD_D(", ", ffe.u.periodic, offset);
+		PRINT_FIELD_U(", ", ffe.u.periodic, phase);
 		decode_envelope(&ffe.u.periodic.envelope);
-		tprintf(", custom_len=%u, custom_data=",
-			ffe.u.periodic.custom_len);
+		PRINT_FIELD_U(", ", ffe.u.periodic, custom_len);
+		tprints(", custom_data=");
 		printaddr(ptr_to_kulong(ffe.u.periodic.custom_data));
 		tprints("}");
 		break;
 	case FF_RUMBLE:
-		tprintf(", rumble={strong_magnitude=%" PRIu16
-			", weak_magnitude=%" PRIu16 "}",
-			ffe.u.rumble.strong_magnitude,
-			ffe.u.rumble.weak_magnitude);
+		PRINT_FIELD_U(", rumble={", ffe.u.rumble, strong_magnitude);
+		PRINT_FIELD_U(", ", ffe.u.rumble, weak_magnitude);
+		tprints("}");
 		break;
 	default:
 		break;
diff -pruN 5.5-3/fcntl.c 5.9-0ubuntu2/fcntl.c
--- 5.5-3/fcntl.c	2018-12-17 19:19:23.000000000 +0000
+++ 5.9-0ubuntu2/fcntl.c	2020-08-25 14:29:30.000000000 +0000
@@ -3,7 +3,7 @@
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995, 1996 Rick Sladkey <jrs@world.std.com>
  * Copyright (c) 1996-1999 Wichert Akkerman <wichert@cistron.nl>
- * Copyright (c) 1999-2018 The strace developers.
+ * Copyright (c) 1999-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -11,6 +11,7 @@
 
 #include "defs.h"
 #include "flock.h"
+#include "print_fields.h"
 
 #include "xlat/f_owner_types.h"
 #include "xlat/f_seals.h"
@@ -20,16 +21,14 @@
 #include "xlat/notifyflags.h"
 
 static void
-print_struct_flock64(const struct_kernel_flock64 *fl, const int getlk)
+print_struct_flock64(struct tcb *const tcp, const struct_kernel_flock64 *fl, const int getlk)
 {
-	tprints("{l_type=");
-	printxval(lockfcmds, (unsigned short) fl->l_type, "F_???");
-	tprints(", l_whence=");
-	printxval(whence_codes, (unsigned short) fl->l_whence, "SEEK_???");
-	tprintf(", l_start=%" PRId64 ", l_len=%" PRId64,
-		(int64_t) fl->l_start, (int64_t) fl->l_len);
+	PRINT_FIELD_XVAL("{", *fl, l_type, lockfcmds, "F_???");
+	PRINT_FIELD_XVAL(", ", *fl, l_whence, whence_codes, "SEEK_???");
+	PRINT_FIELD_D(", ", *fl, l_start);
+	PRINT_FIELD_D(", ", *fl, l_len);
 	if (getlk)
-		tprintf(", l_pid=%lu", (unsigned long) fl->l_pid);
+		PRINT_FIELD_TGID(", ", *fl, l_pid, tcp);
 	tprints("}");
 }
 
@@ -39,7 +38,7 @@ printflock64(struct tcb *const tcp, cons
 	struct_kernel_flock64 fl;
 
 	if (fetch_struct_flock64(tcp, addr, &fl))
-		print_struct_flock64(&fl, getlk);
+		print_struct_flock64(tcp, &fl, getlk);
 }
 
 static void
@@ -48,7 +47,7 @@ printflock(struct tcb *const tcp, const
 	struct_kernel_flock64 fl;
 
 	if (fetch_struct_flock(tcp, addr, &fl))
-		print_struct_flock64(&fl, getlk);
+		print_struct_flock64(tcp, &fl, getlk);
 }
 
 static void
@@ -59,9 +58,24 @@ print_f_owner_ex(struct tcb *const tcp,
 	if (umove_or_printaddr(tcp, addr, &owner))
 		return;
 
-	tprints("{type=");
-	printxval(f_owner_types, owner.type, "F_OWNER_???");
-	tprintf(", pid=%d}", owner.pid);
+	PRINT_FIELD_XVAL("{", owner, type, f_owner_types, "F_OWNER_???");
+
+	enum pid_type pid_type = PT_NONE;
+	switch (owner.type)
+	{
+	case F_OWNER_TID:
+		pid_type = PT_TID;
+		break;
+	case F_OWNER_PID:
+		pid_type = PT_TGID;
+		break;
+	case F_OWNER_PGRP:
+		pid_type = PT_PGID;
+		break;
+	}
+	tprints(", pid=");
+	printpid(tcp, owner.pid, pid_type);
+	tprints("}");
 }
 
 static int
@@ -75,6 +89,9 @@ print_fcntl(struct tcb *tcp)
 		printflags(fdflags, tcp->u_arg[2], "FD_???");
 		break;
 	case F_SETOWN:
+		tprints(", ");
+		printpid_tgid_pgid(tcp, tcp->u_arg[2]);
+		break;
 	case F_SETPIPE_SZ:
 		tprintf(", %" PRI_kld, tcp->u_arg[2]);
 		break;
@@ -117,6 +134,8 @@ print_fcntl(struct tcb *tcp)
 		printsignal(tcp->u_arg[2]);
 		break;
 	case F_GETOWN:
+		return RVAL_DECODED |
+		       ((int) tcp->u_rval < 0 ? RVAL_PGID : RVAL_TGID);
 	case F_GETPIPE_SZ:
 		break;
 	case F_GETFD:
diff -pruN 5.5-3/file_ioctl.c 5.9-0ubuntu2/file_ioctl.c
--- 5.5-3/file_ioctl.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/file_ioctl.c	2020-07-12 08:00:00.000000000 +0000
@@ -1,16 +1,18 @@
 /*
  * Copyright (c) 2016 Jeff Mahoney <jeffm@suse.com>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #include "defs.h"
+#include "print_fields.h"
 #include <linux/ioctl.h>
 #include <linux/fs.h>
 
 #ifdef HAVE_LINUX_FIEMAP_H
+# include <linux/types.h>
 # include <linux/fiemap.h>
 # include "xlat/fiemap_flags.h"
 # include "xlat/fiemap_extent_flags.h"
@@ -72,14 +74,13 @@ print_file_dedupe_range_info(struct tcb
 	}
 
 	if (entering(tcp)) {
-		tprints("{dest_fd=");
-		printfd(tcp, info->dest_fd);
-		tprintf(", dest_offset=%" PRIu64 "}",
-			(uint64_t) info->dest_offset);
+		PRINT_FIELD_FD("{", *info, dest_fd, tcp);
+		PRINT_FIELD_U(", ", *info, dest_offset);
 	} else {
-		tprintf("{bytes_deduped=%" PRIu64 ", status=%d}",
-			(uint64_t) info->bytes_deduped, info->status);
+		PRINT_FIELD_U("{", *info, bytes_deduped);
+		PRINT_FIELD_D(", ", *info, status);
 	}
+	tprints("}");
 
 	return true;
 }
@@ -90,13 +91,11 @@ print_fiemap_extent(struct tcb *tcp, voi
 {
 	const struct fiemap_extent *fe = elem_buf;
 
-	tprintf("{fe_logical=%" PRI__u64
-		", fe_physical=%" PRI__u64
-		", fe_length=%" PRI__u64 ", ",
-		fe->fe_logical, fe->fe_physical, fe->fe_length);
-
-	printflags64(fiemap_extent_flags, fe->fe_flags,
-		     "FIEMAP_EXTENT_???");
+	PRINT_FIELD_U("{", *fe, fe_logical);
+	PRINT_FIELD_U(", ", *fe, fe_physical);
+	PRINT_FIELD_U(", ", *fe, fe_length);
+	PRINT_FIELD_FLAGS(", ", *fe, fe_flags, fiemap_extent_flags,
+			  "FIEMAP_EXTENT_???");
 	tprints("}");
 
 	return true;
@@ -119,14 +118,11 @@ file_ioctl(struct tcb *const tcp, const
 		if (umove_or_printaddr(tcp, arg, &args))
 			break;
 
-		tprints("{src_fd=");
-		printfd(tcp, args.src_fd);
-		tprintf(", src_offset=%" PRIu64
-			", src_length=%" PRIu64
-			", dest_offset=%" PRIu64 "}",
-			(uint64_t) args.src_offset,
-			(uint64_t) args.src_length,
-			(uint64_t) args.dest_offset);
+		PRINT_FIELD_FD("{", args, src_fd, tcp);
+		PRINT_FIELD_U(", ", args, src_offset);
+		PRINT_FIELD_U(", ", args, src_length);
+		PRINT_FIELD_U(", ", args, dest_offset);
+		tprints("}");
 		break;
 	}
 
@@ -149,12 +145,10 @@ file_ioctl(struct tcb *const tcp, const
 
 		tprints("{");
 		if (entering(tcp)) {
-			tprintf("src_offset=%" PRIu64
-				", src_length=%" PRIu64
-				", dest_count=%hu, ",
-				(uint64_t) args.src_offset,
-				(uint64_t) args.src_length,
-				(uint16_t) args.dest_count);
+			PRINT_FIELD_U("", args, src_offset);
+			PRINT_FIELD_U(", ", args, src_length);
+			PRINT_FIELD_U(", ", args, dest_count);
+			tprints(", ");
 		}
 
 		tprints("info=");
@@ -190,21 +184,18 @@ file_ioctl(struct tcb *const tcp, const
 			break;
 
 		if (entering(tcp)) {
-			tprintf("{fm_start=%" PRI__u64 ", "
-				"fm_length=%" PRI__u64 ", "
-				"fm_flags=",
-				args.fm_start, args.fm_length);
-			printflags64(fiemap_flags, args.fm_flags,
-				     "FIEMAP_FLAG_???");
-			tprintf(", fm_extent_count=%u}", args.fm_extent_count);
+			PRINT_FIELD_U("{", args, fm_start);
+			PRINT_FIELD_U(", ", args, fm_length);
+			PRINT_FIELD_FLAGS(", ", args, fm_flags, fiemap_flags,
+					  "FIEMAP_FLAG_???");
+			PRINT_FIELD_U(", ", args, fm_extent_count);
+			tprints("}");
 			return 0;
 		}
 
-		tprints("{fm_flags=");
-		printflags64(fiemap_flags, args.fm_flags,
-			     "FIEMAP_FLAG_???");
-		tprintf(", fm_mapped_extents=%u",
-			args.fm_mapped_extents);
+		PRINT_FIELD_FLAGS("{", args, fm_flags, fiemap_flags,
+				  "FIEMAP_FLAG_???");
+		PRINT_FIELD_U(", ", args, fm_mapped_extents);
 		if (abbrev(tcp)) {
 			tprints(", ...");
 		} else {
diff -pruN 5.5-3/filter_qualify.c 5.9-0ubuntu2/filter_qualify.c
--- 5.5-3/filter_qualify.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/filter_qualify.c	2020-04-23 07:18:14.000000000 +0000
@@ -18,8 +18,13 @@ struct number_set *read_set;
 struct number_set *write_set;
 struct number_set *signal_set;
 struct number_set *status_set;
+struct number_set *quiet_set;
+struct number_set *decode_fd_set;
 struct number_set *trace_set;
 
+bool quiet_set_updated = false;
+bool decode_fd_set_updated = false;
+
 static struct number_set *abbrev_set;
 static struct number_set *inject_set;
 static struct number_set *raw_set;
@@ -59,24 +64,47 @@ sigstr_to_uint(const char *s)
 	return -1;
 }
 
-static const char *statuses[NUMBER_OF_STATUSES] = {
-	[STATUS_SUCCESSFUL]  = "successful",
-	[STATUS_FAILED]      = "failed",
-	[STATUS_UNFINISHED]  = "unfinished",
-	[STATUS_UNAVAILABLE] = "unavailable",
-	[STATUS_DETACHED]    = "detached",
-};
-
 static int
 statusstr_to_uint(const char *str)
 {
-	unsigned int i;
+	static const struct xlat_data statuses[] = {
+		{ STATUS_SUCCESSFUL,  "successful" },
+		{ STATUS_FAILED,      "failed" },
+		{ STATUS_UNFINISHED,  "unfinished" },
+		{ STATUS_UNAVAILABLE, "unavailable" },
+		{ STATUS_DETACHED,    "detached" },
+	};
 
-	for (i = 0; i < NUMBER_OF_STATUSES; ++i)
-		if (strcasecmp(str, statuses[i]) == 0)
-			return i;
+	return (int) find_arg_val(str, statuses, -1ULL, -1ULL);
+}
 
-	return -1;
+static int
+quietstr_to_uint(const char *str)
+{
+	static const struct xlat_data quiet_strs[] = {
+		{ QUIET_ATTACH,        "attach" },
+		{ QUIET_EXIT,          "exit" },
+		{ QUIET_EXIT,          "exits" },
+		{ QUIET_PATH_RESOLVE,  "path-resolution" },
+		{ QUIET_PERSONALITY,   "personality" },
+		{ QUIET_THREAD_EXECVE, "superseded" },
+		{ QUIET_THREAD_EXECVE, "thread-execve" },
+	};
+
+	return (int) find_arg_val(str, quiet_strs, -1ULL, -1ULL);
+}
+
+static int
+decode_fd_str_to_uint(const char *str)
+{
+	static const struct xlat_data decode_fd_strs[] = {
+		{ DECODE_FD_PATH,      "path" },
+		{ DECODE_FD_SOCKET,    "socket" },
+		{ DECODE_FD_DEV,       "dev" },
+		{ DECODE_FD_PIDFD,     "pidfd" },
+	};
+
+	return (int) find_arg_val(str, decode_fd_strs, -1ULL, -1ULL);
 }
 
 static int
@@ -121,33 +149,67 @@ parse_inject_token(const char *const tok
 
 	if ((val = STR_STRIP_PREFIX(token, "when=")) != token) {
 		/*
-		 *	== 1+1
-		 * F	== F+0
-		 * F+	== F+1
-		 * F+S
+		 *        == 1..INF+1
+		 * F      == F..INF+0
+		 * F+     == F..INF+1
+		 * F+S    == F..INF+S
+		 * F..L   == F..L+1
+		 * F..L+S
 		 */
 		char *end;
-		intval = string_to_uint_ex(val, &end, 0xffff, "+");
+		intval = string_to_uint_ex(val, &end, 0xffff, "+.");
 		if (intval < 1)
 			return false;
 
 		fopts->first = intval;
 
-		if (*end) {
+		if (end[0] == '.') {
+			if (end[1] != '.')
+				return false;
+			/*
+			 * F..L
+			 * F..L+S
+			 */
+			val = end + 2;
+			intval = string_to_uint_ex(val, &end, 0xffff, "+");
+			if (intval < fopts->first || intval == INJECT_LAST_INF)
+				return false;
+			fopts->last = intval;
+		} else {
+			/*
+			 * F   == F..INF+0
+			 * F+  == F..INF+1
+			 * F+S == F..INF+S
+			 */
+			fopts->last = INJECT_LAST_INF;
+		}
+
+		if (end[0] != '\0') {
 			val = end + 1;
-			if (*val) {
-				/* F+S */
+			if (val[0] != '\0') {
+				/*
+				 * F+S    == F..INF+S
+				 * F..L+S
+				 */
 				intval = string_to_uint_upto(val, 0xffff);
 				if (intval < 1)
 					return false;
 				fopts->step = intval;
 			} else {
-				/* F+ == F+1 */
+				/*
+				 * F+    == F..INF+1
+				 * F..L+ == F..L+1
+				 */
 				fopts->step = 1;
 			}
 		} else {
-			/* F == F+0 */
-			fopts->step = 0;
+			if (fopts->last == INJECT_LAST_INF) {
+				/* F == F..INF+0 */
+				fopts->step = 0;
+			} else {
+				/* F..L == F..L+1 */
+				fopts->step = 1;
+			}
 		}
 	} else if ((val = STR_STRIP_PREFIX(token, "syscall=")) != token) {
 		if (fopts->data.flags & INJECT_F_SYSCALL)
@@ -307,6 +369,27 @@ qualify_status(const char *const str)
 }
 
 void
+qualify_quiet(const char *const str)
+{
+	if (!quiet_set)
+		quiet_set = alloc_number_set_array(1);
+	else
+		quiet_set_updated = true;
+	qualify_tokens(str, quiet_set, quietstr_to_uint, "quiet");
+}
+
+void
+qualify_decode_fd(const char *const str)
+{
+	if (!decode_fd_set)
+		decode_fd_set = alloc_number_set_array(1);
+	else
+		decode_fd_set_updated = true;
+	qualify_tokens(str, decode_fd_set, decode_fd_str_to_uint,
+		       "decode-fds");
+}
+
+void
 qualify_trace(const char *const str)
 {
 	if (!trace_set)
@@ -345,6 +428,7 @@ qualify_inject_common(const char *const
 {
 	struct inject_opts opts = {
 		.first = 1,
+		.last = INJECT_LAST_INF,
 		.step = 1,
 		.data = {
 			.delay_idx = -1
@@ -454,6 +538,10 @@ static const struct qual_options {
 	{ "signals",	qualify_signals	},
 	{ "status",	qualify_status	},
 	{ "s",		qualify_signals	},
+	{ "quiet",	qualify_quiet	},
+	{ "silent",	qualify_quiet	},
+	{ "silence",	qualify_quiet	},
+	{ "q",		qualify_quiet	},
 	{ "read",	qualify_read	},
 	{ "reads",	qualify_read	},
 	{ "r",		qualify_read	},
@@ -463,6 +551,8 @@ static const struct qual_options {
 	{ "fault",	qualify_fault	},
 	{ "inject",	qualify_inject	},
 	{ "kvm",	qualify_kvm	},
+	{ "decode-fd",	qualify_decode_fd },
+	{ "decode-fds",	qualify_decode_fd },
 };
 
 void
diff -pruN 5.5-3/filter_seccomp.c 5.9-0ubuntu2/filter_seccomp.c
--- 5.5-3/filter_seccomp.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/filter_seccomp.c	2020-04-15 13:39:57.000000000 +0000
@@ -27,30 +27,47 @@ bool seccomp_before_sysentry;
 
 # include <linux/seccomp.h>
 
+#else
+
+# define XLAT_MACROS_ONLY
+#  include "xlat/prctl_options.h"
+#  include "xlat/seccomp_mode.h"
+#  include "xlat/seccomp_ret_action.h"
+# undef XLAT_MACROS_ONLY
+
+struct seccomp_data {
+	int nr;
+	uint32_t arch;
+	uint64_t instruction_pointer;
+	uint64_t args[6];
+};
+
+#endif /* !HAVE_LINUX_SECCOMP_H */
+
 /* PERSONALITY*_AUDIT_ARCH definitions depend on AUDIT_ARCH_* constants.  */
-# ifdef PERSONALITY0_AUDIT_ARCH
-#  include <linux/audit.h>
-#  define XLAT_MACROS_ONLY
-#   include "xlat/elf_em.h"
-#   include "xlat/audit_arch.h"
-#  undef XLAT_MACROS_ONLY
-# endif
+#ifdef PERSONALITY0_AUDIT_ARCH
+# include <linux/audit.h>
+# define XLAT_MACROS_ONLY
+#  include "xlat/elf_em.h"
+#  include "xlat/audit_arch.h"
+# undef XLAT_MACROS_ONLY
+#endif
 
-# ifndef BPF_MAXINSNS
-#  define BPF_MAXINSNS 4096
-# endif
+#ifndef BPF_MAXINSNS
+# define BPF_MAXINSNS 4096
+#endif
 
-# define JMP_PLACEHOLDER_NEXT  ((unsigned char) -1)
-# define JMP_PLACEHOLDER_TRACE ((unsigned char) -2)
-# define JMP_PLACEHOLDER_ALLOW ((unsigned char) -3)
+#define JMP_PLACEHOLDER_NEXT  ((unsigned char) -1)
+#define JMP_PLACEHOLDER_TRACE ((unsigned char) -2)
+#define JMP_PLACEHOLDER_ALLOW ((unsigned char) -3)
 
-# define SET_BPF(filter, code, jt, jf, k) \
+#define SET_BPF(filter, code, jt, jf, k) \
 	(*(filter) = (struct sock_filter) { code, jt, jf, k })
 
-# define SET_BPF_STMT(filter, code, k) \
+#define SET_BPF_STMT(filter, code, k) \
 	SET_BPF(filter, code, 0, 0, k)
 
-# define SET_BPF_JUMP(filter, code, k, jt, jf) \
+#define SET_BPF_JUMP(filter, code, k, jt, jf) \
 	SET_BPF(filter, BPF_JMP | code, jt, jf, k)
 
 struct audit_arch_t {
@@ -59,13 +76,13 @@ struct audit_arch_t {
 };
 
 static const struct audit_arch_t audit_arch_vec[SUPPORTED_PERSONALITIES] = {
-# if SUPPORTED_PERSONALITIES > 1
+#if SUPPORTED_PERSONALITIES > 1
 	PERSONALITY0_AUDIT_ARCH,
 	PERSONALITY1_AUDIT_ARCH,
-#  if SUPPORTED_PERSONALITIES > 2
+# if SUPPORTED_PERSONALITIES > 2
 	PERSONALITY2_AUDIT_ARCH,
-#  endif
 # endif
+#endif
 };
 
 typedef unsigned short (*filter_generator_t)(struct sock_filter *,
@@ -90,7 +107,7 @@ static struct sock_fprog bpf_prog = {
 	.filter = NULL,
 };
 
-# ifdef HAVE_FORK
+#ifdef HAVE_FORK
 
 static void ATTRIBUTE_NORETURN
 check_seccomp_order_do_child(void)
@@ -250,7 +267,7 @@ check_seccomp_order_tracer(int pid)
 
 	return pid;
 }
-# endif /* HAVE_FORK */
+#endif /* HAVE_FORK */
 
 static void
 check_seccomp_order(void)
@@ -258,7 +275,7 @@ check_seccomp_order(void)
 	seccomp_filtering = false;
 
 	/* NOMMU provides no forks necessary for the test.  */
-# ifdef HAVE_FORK
+#ifdef HAVE_FORK
 	int pid = fork();
 	if (pid < 0) {
 		perror_func_msg("fork");
@@ -278,7 +295,7 @@ check_seccomp_order(void)
 			break;
 		}
 	}
-# endif /* HAVE_FORK */
+#endif /* HAVE_FORK */
 }
 
 static bool
@@ -351,10 +368,10 @@ linear_filter_generator(struct sock_filt
 	 */
 	unsigned short pos = 0;
 
-# if SUPPORTED_PERSONALITIES > 1
+#if SUPPORTED_PERSONALITIES > 1
 	SET_BPF_STMT(&filter[pos++], BPF_LD | BPF_W | BPF_ABS,
 		     offsetof(struct seccomp_data, arch));
-# endif
+#endif
 
 	/*
 	 * Personalities are iterated in reverse-order in the BPF program so
@@ -369,15 +386,15 @@ linear_filter_generator(struct sock_filt
 		unsigned int lower = UINT_MAX;
 		unsigned short start = pos, end;
 
-# if SUPPORTED_PERSONALITIES > 1
+#if SUPPORTED_PERSONALITIES > 1
 		/* if (arch != audit_arch_vec[p].arch) goto next; */
 		SET_BPF_JUMP(&filter[pos++], BPF_JEQ | BPF_K,
 			     audit_arch_vec[p].arch, 0, JMP_PLACEHOLDER_NEXT);
-# endif
+#endif
 		SET_BPF_STMT(&filter[pos++], BPF_LD | BPF_W | BPF_ABS,
 			     offsetof(struct seccomp_data, nr));
 
-# if SUPPORTED_PERSONALITIES > 1
+#if SUPPORTED_PERSONALITIES > 1
 		if (audit_arch_vec[p].flag) {
 			/* if (nr < audit_arch_vec[p].flag) goto next; */
 			SET_BPF_JUMP(&filter[pos++], BPF_JGE | BPF_K,
@@ -387,7 +404,7 @@ linear_filter_generator(struct sock_filt
 			SET_BPF_JUMP(&filter[pos++], BPF_JA,
 				     JMP_PLACEHOLDER_NEXT, 0, 0);
 		}
-# endif
+#endif
 
 		for (unsigned int i = 0; i < nsyscall_vec[p]; ++i) {
 			if (traced_by_seccomp(i, p)) {
@@ -450,10 +467,10 @@ linear_filter_generator(struct sock_filt
 		}
 	}
 
-# if SUPPORTED_PERSONALITIES > 1
+#if SUPPORTED_PERSONALITIES > 1
 	/* Jumps conditioned on .arch default to this RET_TRACE. */
 	SET_BPF_STMT(&filter[pos++], BPF_RET | BPF_K, SECCOMP_RET_TRACE);
-# endif
+#endif
 
 	return pos;
 }
@@ -491,10 +508,10 @@ binary_match_filter_generator(struct soc
 {
 	unsigned short pos = 0;
 
-# if SUPPORTED_PERSONALITIES > 1
+#if SUPPORTED_PERSONALITIES > 1
 	SET_BPF_STMT(&filter[pos++], BPF_LD | BPF_W | BPF_ABS,
 		     offsetof(struct seccomp_data, arch));
-# endif
+#endif
 
 	/* Personalities are iterated in reverse-order in the BPF program so that
 	 * the x86 case is naturally handled.  In x86, the first and third
@@ -509,14 +526,14 @@ binary_match_filter_generator(struct soc
 		unsigned int bitarray = 0;
 		unsigned int i;
 
-# if SUPPORTED_PERSONALITIES > 1
+#if SUPPORTED_PERSONALITIES > 1
 		SET_BPF_JUMP(&filter[pos++], BPF_JMP | BPF_JEQ | BPF_K,
 			     audit_arch_vec[p].arch, 0, JMP_PLACEHOLDER_NEXT);
-# endif
+#endif
 		SET_BPF_STMT(&filter[pos++], BPF_LD | BPF_W | BPF_ABS,
 			     offsetof(struct seccomp_data, nr));
 
-# if SUPPORTED_PERSONALITIES > 1
+#if SUPPORTED_PERSONALITIES > 1
 		if (audit_arch_vec[p].flag) {
 			SET_BPF_JUMP(&filter[pos++], BPF_JMP | BPF_JGE | BPF_K,
 				     audit_arch_vec[p].flag, 2, 0);
@@ -529,7 +546,7 @@ binary_match_filter_generator(struct soc
 			SET_BPF_STMT(&filter[pos++], BPF_ALU | BPF_AND | BPF_K,
 				     ~audit_arch_vec[p].flag);
 		}
-# endif
+#endif
 
 		/* X = 1 << nr % 32 = 1 << nr & 0x1F; */
 		SET_BPF_STMT(&filter[pos++], BPF_ALU | BPF_AND | BPF_K, 0x1F);
@@ -588,9 +605,9 @@ binary_match_filter_generator(struct soc
 		}
 	}
 
-# if SUPPORTED_PERSONALITIES > 1
+#if SUPPORTED_PERSONALITIES > 1
 	SET_BPF_STMT(&filter[pos++], BPF_RET | BPF_K, SECCOMP_RET_TRACE);
-# endif
+#endif
 
 	return pos;
 }
@@ -725,29 +742,6 @@ seccomp_filter_restart_operator(const st
 	return PTRACE_CONT;
 }
 
-#else /* !HAVE_LINUX_SECCOMP_H */
-
-# warning <linux/seccomp.h> is not available, seccomp filtering is not supported
-
-static void
-check_seccomp_filter_properties(void)
-{
-	seccomp_filtering = false;
-}
-
-void
-init_seccomp_filter(void)
-{
-}
-
-int
-seccomp_filter_restart_operator(const struct tcb *tcp)
-{
-	return PTRACE_SYSCALL;
-}
-
-#endif
-
 void
 check_seccomp_filter(void)
 {
diff -pruN 5.5-3/filter_seccomp.h 5.9-0ubuntu2/filter_seccomp.h
--- 5.5-3/filter_seccomp.h	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/filter_seccomp.h	2020-06-01 14:15:16.000000000 +0000
@@ -1,6 +1,7 @@
 /*
  * Copyright (c) 2018 Chen Jingpiao <chenjingpiao@gmail.com>
  * Copyright (c) 2019 Paul Chaignon <paul.chaignon@gmail.com>
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
diff -pruN 5.5-3/gcc_compat.h 5.9-0ubuntu2/gcc_compat.h
--- 5.5-3/gcc_compat.h	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/gcc_compat.h	2020-09-12 08:00:00.000000000 +0000
@@ -23,6 +23,21 @@
 #  define CLANG_PREREQ(maj, min)	0
 # endif
 
+# ifdef __GLIBC__
+#  ifdef __GLIBC_MINOR__
+#   define GLIBC_PREREQ_GE(maj, min)	\
+	((__GLIBC__ << 16) + __GLIBC_MINOR__ >= ((maj) << 16) + (min))
+#   define GLIBC_PREREQ_LT(maj, min)	\
+	((__GLIBC__ << 16) + __GLIBC_MINOR__ < ((maj) << 16) + (min))
+#  else /* !__GLIBC_MINOR__ */
+#   define GLIBC_PREREQ_GE(maj, min)	0
+#   define GLIBC_PREREQ_LT(maj, min)	1
+#  endif
+# else /* !__GLIBC__ */
+#  define GLIBC_PREREQ_GE(maj, min)	0
+#  define GLIBC_PREREQ_LT(maj, min)	0
+# endif
+
 # if !(GNUC_PREREQ(2, 0) || CLANG_PREREQ(1, 0))
 #  define __attribute__(x)	/* empty */
 # endif
diff -pruN 5.5-3/getpid.c 5.9-0ubuntu2/getpid.c
--- 5.5-3/getpid.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/getpid.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,46 @@
+/*
+ * Copyright (c) 2020 Ákos Uzonyi <uzonyi.akos@gmail.com>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
+#include "defs.h"
+
+SYS_FUNC(getpid)
+{
+	return RVAL_DECODED | RVAL_TGID;
+}
+
+SYS_FUNC(gettid)
+{
+	return RVAL_DECODED | RVAL_TID;
+}
+
+SYS_FUNC(getpgrp)
+{
+	return RVAL_DECODED | RVAL_PGID;
+}
+
+SYS_FUNC(getpgid)
+{
+	printpid(tcp, tcp->u_arg[0], PT_TGID);
+
+	return RVAL_DECODED | RVAL_PGID;
+}
+
+SYS_FUNC(getsid)
+{
+	printpid(tcp, tcp->u_arg[0], PT_TGID);
+
+	return RVAL_DECODED | RVAL_SID;
+}
+
+SYS_FUNC(setpgid)
+{
+	printpid(tcp, tcp->u_arg[0], PT_TGID);
+	tprints(", ");
+	printpid(tcp, tcp->u_arg[1], PT_PGID);
+
+	return RVAL_DECODED;
+}
diff -pruN 5.5-3/get_robust_list.c 5.9-0ubuntu2/get_robust_list.c
--- 5.5-3/get_robust_list.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/get_robust_list.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,5 +1,6 @@
 /*
  * Copyright (c) 2012-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2014-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -10,7 +11,8 @@
 SYS_FUNC(get_robust_list)
 {
 	if (entering(tcp)) {
-		tprintf("%d, ", (int) tcp->u_arg[0]);
+		printpid(tcp, tcp->u_arg[0], PT_TID);
+		tprints(", ");
 	} else {
 		printnum_ptr(tcp, tcp->u_arg[1]);
 		tprints(", ");
diff -pruN 5.5-3/hdio.c 5.9-0ubuntu2/hdio.c
--- 5.5-3/hdio.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/hdio.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2009, 2010 Jeff Mahoney <jeffm@suse.com>
  * Copyright (c) 2011-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -17,26 +17,83 @@ typedef struct hd_geometry struct_hd_geo
 
 #include MPERS_DEFS
 
+#include "print_fields.h"
+
+#include "xlat/hdio_drive_cmds.h"
+
+static int
+print_hdio_getgeo(struct tcb *const tcp, const kernel_ulong_t arg)
+{
+	if (entering(tcp)) {
+		tprints(", ");
+
+		return 0;
+	}
+
+	/* exiting */
+	struct_hd_geometry geo;
+
+	if (umove_or_printaddr(tcp, arg, &geo))
+		return RVAL_IOCTL_DECODED;
+
+	PRINT_FIELD_U("{", geo, heads);
+	PRINT_FIELD_U(", ", geo, sectors);
+	PRINT_FIELD_U(", ", geo, cylinders);
+	PRINT_FIELD_U(", ", geo, start);
+	tprints("}");
+
+	return RVAL_IOCTL_DECODED;
+}
+
+static int
+print_hdio_drive_cmd(struct tcb *const tcp, const kernel_ulong_t arg)
+{
+	enum { SECTOR_SIZE = 512 };
+
+	struct hd_drive_cmd_hdr c;
+
+	if (entering(tcp)) {
+		tprints(", ");
+
+		if (umove_or_printaddr(tcp, arg, &c))
+			return RVAL_IOCTL_DECODED;
+
+		PRINT_FIELD_XVAL("{", c, command, hdio_drive_cmds,
+				 "ATA_CMD_???");
+		PRINT_FIELD_U(", ", c, sector_number);
+		PRINT_FIELD_U(", ", c, feature);
+		PRINT_FIELD_U(", ", c, sector_count);
+		tprints("}");
+
+		return 0;
+	}
+
+	/* exiting */
+	if ((syserror(tcp) && tcp->u_error != EIO) || umove(tcp, arg, &c))
+		return RVAL_IOCTL_DECODED;
+
+	tprintf(" => {/* status */ %#x, /* error */ %u, /* nsector */ %u",
+		c.command, c.sector_number, c.feature);
+
+	if (c.sector_count) {
+		tprints(", ");
+		printstr_ex(tcp, arg + 4, c.sector_count * SECTOR_SIZE,
+			    QUOTE_FORCE_HEX);
+	}
+
+	tprints("}");
+
+	return RVAL_IOCTL_DECODED;
+}
+
 MPERS_PRINTER_DECL(int, hdio_ioctl, struct tcb *const tcp,
 		   const unsigned int code, const kernel_ulong_t arg)
 {
 	switch (code) {
 	case HDIO_GETGEO:
-		if (entering(tcp))
-			return 0;
-		else {
-			struct_hd_geometry geo;
-
-			tprints(", ");
-			if (!umove_or_printaddr(tcp, arg, &geo))
-				tprintf("{heads=%u, sectors=%u, "
-					"cylinders=%hu, start=%lu}",
-					(unsigned) geo.heads,
-					(unsigned) geo.sectors,
-					geo.cylinders,
-					(unsigned long) geo.start);
-		}
-		break;
+		return print_hdio_getgeo(tcp, arg);
+	case HDIO_DRIVE_CMD:
+		return print_hdio_drive_cmd(tcp, arg);
 	default:
 		return RVAL_DECODED;
 	}
diff -pruN 5.5-3/INSTALL 5.9-0ubuntu2/INSTALL
--- 5.5-3/INSTALL	2020-02-06 16:23:29.000000000 +0000
+++ 5.9-0ubuntu2/INSTALL	2020-09-24 09:18:52.000000000 +0000
@@ -125,7 +125,7 @@ make install
 
 6.1. Distribution tarball
 
-./make-dist
+maint/make-dist
 
 Requires git
 
diff -pruN 5.5-3/install-sh 5.9-0ubuntu2/install-sh
--- 5.5-3/install-sh	2020-02-06 16:23:34.000000000 +0000
+++ 5.9-0ubuntu2/install-sh	2020-09-24 09:18:59.000000000 +0000
@@ -1,7 +1,7 @@
 #!/bin/sh
 # install - install a program, script, or datafile
 
-scriptversion=2018-03-11.20; # UTC
+scriptversion=2020-07-26.22; # UTC
 
 # This originates from X11R5 (mit/util/scripts/install.sh), which was
 # later released in X11R6 (xc/config/util/install.sh) with the
@@ -69,6 +69,10 @@ posix_mkdir=
 # Desired mode of installed file.
 mode=0755
 
+# Create dirs (including intermediate dirs) using mode 755.
+# This is like GNU 'install' as of coreutils 8.32 (2020).
+mkdir_umask=22
+
 chgrpcmd=
 chmodcmd=$chmodprog
 chowncmd=
@@ -301,22 +305,6 @@ do
   if test $dstdir_status != 0; then
     case $posix_mkdir in
       '')
-        # Create intermediate dirs using mode 755 as modified by the umask.
-        # This is like FreeBSD 'install' as of 1997-10-28.
-        umask=`umask`
-        case $stripcmd.$umask in
-          # Optimize common cases.
-          *[2367][2367]) mkdir_umask=$umask;;
-          .*0[02][02] | .[02][02] | .[02]) mkdir_umask=22;;
-
-          *[0-7])
-            mkdir_umask=`expr $umask + 22 \
-              - $umask % 100 % 40 + $umask % 20 \
-              - $umask % 10 % 4 + $umask % 2
-            `;;
-          *) mkdir_umask=$umask,go-w;;
-        esac
-
         # With -d, create the new directory with the user-specified mode.
         # Otherwise, rely on $mkdir_umask.
         if test -n "$dir_arg"; then
@@ -326,52 +314,49 @@ do
         fi
 
         posix_mkdir=false
-        case $umask in
-          *[123567][0-7][0-7])
-            # POSIX mkdir -p sets u+wx bits regardless of umask, which
-            # is incompatible with FreeBSD 'install' when (umask & 300) != 0.
-            ;;
-          *)
-            # Note that $RANDOM variable is not portable (e.g. dash);  Use it
-            # here however when possible just to lower collision chance.
-            tmpdir=${TMPDIR-/tmp}/ins$RANDOM-$$
-
-            trap 'ret=$?; rmdir "$tmpdir/a/b" "$tmpdir/a" "$tmpdir" 2>/dev/null; exit $ret' 0
-
-            # Because "mkdir -p" follows existing symlinks and we likely work
-            # directly in world-writeable /tmp, make sure that the '$tmpdir'
-            # directory is successfully created first before we actually test
-            # 'mkdir -p' feature.
-            if (umask $mkdir_umask &&
-                $mkdirprog $mkdir_mode "$tmpdir" &&
-                exec $mkdirprog $mkdir_mode -p -- "$tmpdir/a/b") >/dev/null 2>&1
-            then
-              if test -z "$dir_arg" || {
-                   # Check for POSIX incompatibilities with -m.
-                   # HP-UX 11.23 and IRIX 6.5 mkdir -m -p sets group- or
-                   # other-writable bit of parent directory when it shouldn't.
-                   # FreeBSD 6.1 mkdir -m -p sets mode of existing directory.
-                   test_tmpdir="$tmpdir/a"
-                   ls_ld_tmpdir=`ls -ld "$test_tmpdir"`
-                   case $ls_ld_tmpdir in
-                     d????-?r-*) different_mode=700;;
-                     d????-?--*) different_mode=755;;
-                     *) false;;
-                   esac &&
-                   $mkdirprog -m$different_mode -p -- "$test_tmpdir" && {
-                     ls_ld_tmpdir_1=`ls -ld "$test_tmpdir"`
-                     test "$ls_ld_tmpdir" = "$ls_ld_tmpdir_1"
-                   }
-                 }
-              then posix_mkdir=:
-              fi
-              rmdir "$tmpdir/a/b" "$tmpdir/a" "$tmpdir"
-            else
-              # Remove any dirs left behind by ancient mkdir implementations.
-              rmdir ./$mkdir_mode ./-p ./-- "$tmpdir" 2>/dev/null
-            fi
-            trap '' 0;;
-        esac;;
+	# The $RANDOM variable is not portable (e.g., dash).  Use it
+	# here however when possible just to lower collision chance.
+	tmpdir=${TMPDIR-/tmp}/ins$RANDOM-$$
+
+	trap '
+	  ret=$?
+	  rmdir "$tmpdir/a/b" "$tmpdir/a" "$tmpdir" 2>/dev/null
+	  exit $ret
+	' 0
+
+	# Because "mkdir -p" follows existing symlinks and we likely work
+	# directly in world-writeable /tmp, make sure that the '$tmpdir'
+	# directory is successfully created first before we actually test
+	# 'mkdir -p'.
+	if (umask $mkdir_umask &&
+	    $mkdirprog $mkdir_mode "$tmpdir" &&
+	    exec $mkdirprog $mkdir_mode -p -- "$tmpdir/a/b") >/dev/null 2>&1
+	then
+	  if test -z "$dir_arg" || {
+	       # Check for POSIX incompatibilities with -m.
+	       # HP-UX 11.23 and IRIX 6.5 mkdir -m -p sets group- or
+	       # other-writable bit of parent directory when it shouldn't.
+	       # FreeBSD 6.1 mkdir -m -p sets mode of existing directory.
+	       test_tmpdir="$tmpdir/a"
+	       ls_ld_tmpdir=`ls -ld "$test_tmpdir"`
+	       case $ls_ld_tmpdir in
+		 d????-?r-*) different_mode=700;;
+		 d????-?--*) different_mode=755;;
+		 *) false;;
+	       esac &&
+	       $mkdirprog -m$different_mode -p -- "$test_tmpdir" && {
+		 ls_ld_tmpdir_1=`ls -ld "$test_tmpdir"`
+		 test "$ls_ld_tmpdir" = "$ls_ld_tmpdir_1"
+	       }
+	     }
+	  then posix_mkdir=:
+	  fi
+	  rmdir "$tmpdir/a/b" "$tmpdir/a" "$tmpdir"
+	else
+	  # Remove any dirs left behind by ancient mkdir implementations.
+	  rmdir ./$mkdir_mode ./-p ./-- "$tmpdir" 2>/dev/null
+	fi
+	trap '' 0;;
     esac
 
     if
@@ -382,7 +367,7 @@ do
     then :
     else
 
-      # The umask is ridiculous, or mkdir does not conform to POSIX,
+      # mkdir does not conform to POSIX,
       # or it failed possibly due to a race condition.  Create the
       # directory the slow way, step by step, checking for races as we go.
 
@@ -411,7 +396,7 @@ do
           prefixes=
         else
           if $posix_mkdir; then
-            (umask=$mkdir_umask &&
+            (umask $mkdir_umask &&
              $doit_exec $mkdirprog $mkdir_mode -p -- "$dstdir") && break
             # Don't fail if two instances are running concurrently.
             test -d "$prefix" || exit 1
@@ -451,7 +436,18 @@ do
     trap 'ret=$?; rm -f "$dsttmp" "$rmtmp" && exit $ret' 0
 
     # Copy the file name to the temp name.
-    (umask $cp_umask && $doit_exec $cpprog "$src" "$dsttmp") &&
+    (umask $cp_umask &&
+     { test -z "$stripcmd" || {
+	 # Create $dsttmp read-write so that cp doesn't create it read-only,
+	 # which would cause strip to fail.
+	 if test -z "$doit"; then
+	   : >"$dsttmp" # No need to fork-exec 'touch'.
+	 else
+	   $doit touch "$dsttmp"
+	 fi
+       }
+     } &&
+     $doit_exec $cpprog "$src" "$dsttmp") &&
 
     # and set any options; do chmod last to preserve setuid bits.
     #
diff -pruN 5.5-3/io.c 5.9-0ubuntu2/io.c
--- 5.5-3/io.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/io.c	2020-04-03 22:58:26.000000000 +0000
@@ -3,7 +3,7 @@
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995, 1996 Rick Sladkey <jrs@world.std.com>
  * Copyright (c) 1996-1999 Wichert Akkerman <wichert@cistron.nl>
- * Copyright (c) 1999-2019 The strace developers.
+ * Copyright (c) 1999-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
diff -pruN 5.5-3/ioctl.c 5.9-0ubuntu2/ioctl.c
--- 5.5-3/ioctl.c	2019-10-04 13:16:33.000000000 +0000
+++ 5.9-0ubuntu2/ioctl.c	2020-09-23 12:56:26.000000000 +0000
@@ -3,7 +3,7 @@
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995, 1996 Rick Sladkey <jrs@world.std.com>
  * Copyright (c) 1996-2001 Wichert Akkerman <wichert@cistron.nl>
- * Copyright (c) 1999-2019 The strace developers.
+ * Copyright (c) 1999-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -13,6 +13,29 @@
 #include <linux/ioctl.h>
 #include "xlat/ioctl_dirs.h"
 
+#if defined(SPARC) || defined(SPARC64)
+/*
+ * While Alpha, MIPS, PA-RISC, and POWER simply define _IOC_SIZEBITS to 13
+ * and utilise 3 bits for _IOC_DIRBITS, SPARC tries to provide 14 bits
+ * for the size field ("as on i386") by (ab)using the lowest direction bit.
+ * Unfortunately, while doing so, they decide to define _IOC_SIZE to 0
+ * when the direction doesn't have _IOC_READ/_IOC_WRITE bits set, which
+ * breaks the invariant
+ *
+ *     _IOC_SIZE(_IOC(dir, type, nr, size)) == size
+ *
+ * for _IOC_DIR(val) that doesn't include _IOC_READ or _IOC_WRITE, which
+ * is unacceptable for strace's use case.
+ * So, let's redefine _IOC_SIZE in a way that is more suitable for us.
+ */
+# undef _IOC_SIZE
+# define _IOC_SIZE(nr)						\
+	((_IOC_DIR(nr) & (_IOC_WRITE | _IOC_READ))		\
+		? (((nr) >> _IOC_SIZESHIFT) & _IOC_XSIZEMASK)	\
+		: (((nr) >> _IOC_SIZESHIFT) & _IOC_SIZEMASK))	\
+	/* end of _IOC_SIZE definition */
+#endif
+
 static int
 compare(const void *a, const void *b)
 {
@@ -85,7 +108,7 @@ evdev_decode_number(const unsigned int c
 	if (nr >= 0x20 && nr <= 0x20 + 0x1f) {
 		tprints("EVIOCGBIT(");
 		if (nr == 0x20)
-			tprintf("0");
+			tprints("0");
 		else
 			printxval_ex(evdev_ev, nr - 0x20,
 				     abbrev ? "EV_???" : NULL,
@@ -102,35 +125,35 @@ evdev_decode_number(const unsigned int c
 	}
 
 	switch (nr) {
-		case 0x06:
-			tprintf("EVIOCGNAME(%u)", _IOC_SIZE(code));
-			return 1;
-		case 0x07:
-			tprintf("EVIOCGPHYS(%u)", _IOC_SIZE(code));
-			return 1;
-		case 0x08:
-			tprintf("EVIOCGUNIQ(%u)", _IOC_SIZE(code));
-			return 1;
-		case 0x09:
-			tprintf("EVIOCGPROP(%u)", _IOC_SIZE(code));
-			return 1;
-		case 0x0a:
-			tprintf("EVIOCGMTSLOTS(%u)", _IOC_SIZE(code));
-			return 1;
-		case 0x18:
-			tprintf("EVIOCGKEY(%u)", _IOC_SIZE(code));
-			return 1;
-		case 0x19:
-			tprintf("EVIOCGLED(%u)", _IOC_SIZE(code));
-			return 1;
-		case 0x1a:
-			tprintf("EVIOCGSND(%u)", _IOC_SIZE(code));
-			return 1;
-		case 0x1b:
-			tprintf("EVIOCGSW(%u)", _IOC_SIZE(code));
-			return 1;
-		default:
-			return 0;
+	case 0x06:
+		tprintf("EVIOCGNAME(%u)", _IOC_SIZE(code));
+		return 1;
+	case 0x07:
+		tprintf("EVIOCGPHYS(%u)", _IOC_SIZE(code));
+		return 1;
+	case 0x08:
+		tprintf("EVIOCGUNIQ(%u)", _IOC_SIZE(code));
+		return 1;
+	case 0x09:
+		tprintf("EVIOCGPROP(%u)", _IOC_SIZE(code));
+		return 1;
+	case 0x0a:
+		tprintf("EVIOCGMTSLOTS(%u)", _IOC_SIZE(code));
+		return 1;
+	case 0x18:
+		tprintf("EVIOCGKEY(%u)", _IOC_SIZE(code));
+		return 1;
+	case 0x19:
+		tprintf("EVIOCGLED(%u)", _IOC_SIZE(code));
+		return 1;
+	case 0x1a:
+		tprintf("EVIOCGSND(%u)", _IOC_SIZE(code));
+		return 1;
+	case 0x1b:
+		tprintf("EVIOCGSW(%u)", _IOC_SIZE(code));
+		return 1;
+	default:
+		return 0;
 	}
 }
 
@@ -139,31 +162,34 @@ hiddev_decode_number(const unsigned int
 {
 	if (_IOC_DIR(code) == _IOC_READ) {
 		switch (_IOC_NR(code)) {
-			case 0x04:
-				tprintf("HIDIOCGRAWNAME(%u)", _IOC_SIZE(code));
-				return 1;
-			case 0x05:
-				tprintf("HIDIOCGRAWPHYS(%u)", _IOC_SIZE(code));
-				return 1;
-			case 0x06:
-				tprintf("HIDIOCSFEATURE(%u)", _IOC_SIZE(code));
-				return 1;
-			case 0x12:
-				tprintf("HIDIOCGPHYS(%u)", _IOC_SIZE(code));
-				return 1;
-			default:
-				return 0;
+		case 0x04:
+			tprintf("HIDIOCGRAWNAME(%u)", _IOC_SIZE(code));
+			return 1;
+		case 0x05:
+			tprintf("HIDIOCGRAWPHYS(%u)", _IOC_SIZE(code));
+			return 1;
+		case 0x06:
+			tprintf("HIDIOCSFEATURE(%u)", _IOC_SIZE(code));
+			return 1;
+		case 0x08:
+			tprintf("HIDIOCGRAWUNIQ(%u)", _IOC_SIZE(code));
+			return 1;
+		case 0x12:
+			tprintf("HIDIOCGPHYS(%u)", _IOC_SIZE(code));
+			return 1;
+		default:
+			return 0;
 		}
 	} else if (_IOC_DIR(code) == (_IOC_READ | _IOC_WRITE)) {
 		switch (_IOC_NR(code)) {
-			case 0x06:
-				tprintf("HIDIOCSFEATURE(%u)", _IOC_SIZE(code));
-				return 1;
-			case 0x07:
-				tprintf("HIDIOCGFEATURE(%u)", _IOC_SIZE(code));
-				return 1;
-			default:
-				return 0;
+		case 0x06:
+			tprintf("HIDIOCSFEATURE(%u)", _IOC_SIZE(code));
+			return 1;
+		case 0x07:
+			tprintf("HIDIOCGFEATURE(%u)", _IOC_SIZE(code));
+			return 1;
+		default:
+			return 0;
 		}
 	}
 
@@ -176,39 +202,39 @@ ioctl_decode_command_number(struct tcb *
 	const unsigned int code = tcp->u_arg[1];
 
 	switch (_IOC_TYPE(code)) {
-		case 'E':
-			return evdev_decode_number(code);
-		case 'H':
-			return hiddev_decode_number(code);
-		case 'M':
-			if (_IOC_DIR(code) == _IOC_WRITE) {
-				tprintf("MIXER_WRITE(%u)", _IOC_NR(code));
-				return 1;
-			} else if (_IOC_DIR(code) == _IOC_READ) {
-				tprintf("MIXER_READ(%u)", _IOC_NR(code));
-				return 1;
-			}
-			return 0;
-		case 'U':
-			if (_IOC_DIR(code) == _IOC_READ && _IOC_NR(code) == 0x2c) {
-				tprintf("UI_GET_SYSNAME(%u)", _IOC_SIZE(code));
-				return 1;
-			}
-			return 0;
-		case 'j':
-			if (_IOC_DIR(code) == _IOC_READ && _IOC_NR(code) == 0x13) {
-				tprintf("JSIOCGNAME(%u)", _IOC_SIZE(code));
-				return 1;
-			}
-			return 0;
-		case 'k':
-			if (_IOC_DIR(code) == _IOC_WRITE && _IOC_NR(code) == 0) {
-				tprintf("SPI_IOC_MESSAGE(%u)", _IOC_SIZE(code));
-				return 1;
-			}
-			return 0;
-		default:
-			return 0;
+	case 'E':
+		return evdev_decode_number(code);
+	case 'H':
+		return hiddev_decode_number(code);
+	case 'M':
+		if (_IOC_DIR(code) == _IOC_WRITE) {
+			tprintf("MIXER_WRITE(%u)", _IOC_NR(code));
+			return 1;
+		} else if (_IOC_DIR(code) == _IOC_READ) {
+			tprintf("MIXER_READ(%u)", _IOC_NR(code));
+			return 1;
+		}
+		return 0;
+	case 'U':
+		if (_IOC_DIR(code) == _IOC_READ && _IOC_NR(code) == 0x2c) {
+			tprintf("UI_GET_SYSNAME(%u)", _IOC_SIZE(code));
+			return 1;
+		}
+		return 0;
+	case 'j':
+		if (_IOC_DIR(code) == _IOC_READ && _IOC_NR(code) == 0x13) {
+			tprintf("JSIOCGNAME(%u)", _IOC_SIZE(code));
+			return 1;
+		}
+		return 0;
+	case 'k':
+		if (_IOC_DIR(code) == _IOC_WRITE && _IOC_NR(code) == 0) {
+			tprintf("SPI_IOC_MESSAGE(%u)", _IOC_SIZE(code));
+			return 1;
+		}
+		return 0;
+	default:
+		return 0;
 	}
 }
 
@@ -310,6 +336,8 @@ ioctl_decode(struct tcb *tcp)
 	case 0x94:
 		return btrfs_ioctl(tcp, code, arg);
 #endif
+	case 0xa4:
+		return tee_ioctl(tcp, code, arg);
 #ifdef HAVE_LINUX_USERFAULTFD_H
 	case 0xaa:
 		return uffdio_ioctl(tcp, code, arg);
diff -pruN 5.5-3/ioprio.c 5.9-0ubuntu2/ioprio.c
--- 5.5-3/ioprio.c	2019-07-16 11:41:18.000000000 +0000
+++ 5.9-0ubuntu2/ioprio.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2014-2019 The strace developers.
+ * Copyright (c) 2014-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -49,13 +49,30 @@ print_ioprio(unsigned int ioprio)
 		? tprints_comment : tprints)(str);
 }
 
+static void
+ioprio_print_who(struct tcb *tcp, int which, int who)
+{
+	switch (which)
+	{
+	case IOPRIO_WHO_PROCESS:
+		printpid(tcp, who, PT_TGID);
+		break;
+	case IOPRIO_WHO_PGRP:
+		printpid(tcp, who, PT_PGID);
+		break;
+	default:
+		tprintf("%d", who);
+		break;
+	}
+}
+
 SYS_FUNC(ioprio_get)
 {
 	if (entering(tcp)) {
 		/* int which */
 		printxval(ioprio_who, tcp->u_arg[0], "IOPRIO_WHO_???");
-		/* int who */
-		tprintf(", %d", (int) tcp->u_arg[1]);
+		tprints(", ");
+		ioprio_print_who(tcp, tcp->u_arg[0], tcp->u_arg[1]);
 		return 0;
 	} else {
 		if (syserror(tcp))
@@ -72,8 +89,9 @@ SYS_FUNC(ioprio_set)
 {
 	/* int which */
 	printxval(ioprio_who, tcp->u_arg[0], "IOPRIO_WHO_???");
-	/* int who */
-	tprintf(", %d, ", (int) tcp->u_arg[1]);
+	tprints(", ");
+	ioprio_print_who(tcp, tcp->u_arg[0], tcp->u_arg[1]);
+	tprints(", ");
 	/* int ioprio */
 	if (xlat_verbose(xlat_verbosity) != XLAT_STYLE_ABBREV)
 		tprintf("%d", (int) tcp->u_arg[2]);
diff -pruN 5.5-3/io_uring.c 5.9-0ubuntu2/io_uring.c
--- 5.5-3/io_uring.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/io_uring.c	2020-06-16 08:00:00.000000000 +0000
@@ -11,26 +11,14 @@
 
 #include "types/io_uring.h"
 
+#include "xlat/uring_op_flags.h"
+#include "xlat/uring_ops.h"
 #include "xlat/uring_setup_features.h"
 #include "xlat/uring_setup_flags.h"
 #include "xlat/uring_enter_flags.h"
 #include "xlat/uring_register_opcodes.h"
+#include "xlat/uring_cqring_flags.h"
 
-#ifdef HAVE_STRUCT_IO_CQRING_OFFSETS
-# ifdef HAVE_STRUCT_IO_CQRING_OFFSETS_RESV
-static_assert(offsetof(struct_io_cqring_offsets, resv)
-             >= offsetof(struct io_cqring_offsets, resv),
-             "struct io_cqring_offsets.resv offset mismatch"
-             ", please update the decoder");
-static_assert(sizeof_field(struct_io_cqring_offsets, resv)
-             <= sizeof_field(struct io_cqring_offsets, resv),
-             "struct io_cqring_offsets.resv size mismatch"
-             ", please update the decoder");
-# else /* !HAVE_STRUCT_IO_CQRING_OFFSETS_RESV */
-static_assert(0, "struct io_cqring_offsets.resv is missing"
-		 ", please update the decoder");
-# endif
-#endif /* HAVE_STRUCT_IO_CQRING_OFFSETS */
 #ifdef HAVE_STRUCT_IO_URING_PARAMS
 # ifdef HAVE_STRUCT_IO_URING_PARAMS_RESV
 static_assert(offsetof(struct_io_uring_params, resv)
@@ -71,42 +59,45 @@ SYS_FUNC(io_uring_setup)
 					  print_xint32_array_member);
 		}
 		return 0;
+	}
+
+	/* exiting */
+	if (syserror(tcp)) {
+		/* The remaining part of params is irrelevant.  */
+	} else if (umove(tcp, params_addr, &params)) {
+		tprints(", ???");
 	} else {
-		if (syserror(tcp)) {
-			/* The remaining part of params is irrelevant.  */
-		} else if (umove(tcp, params_addr, &params)) {
-			tprints(", ???");
-		} else {
-			PRINT_FIELD_U(", ", params, sq_entries);
-			PRINT_FIELD_U(", ", params, cq_entries);
-			PRINT_FIELD_FLAGS(", ", params, features,
-					  uring_setup_features,
-					  "IORING_FEAT_???");
-			PRINT_FIELD_U(", sq_off={", params.sq_off, head);
-			PRINT_FIELD_U(", ", params.sq_off, tail);
-			PRINT_FIELD_U(", ", params.sq_off, ring_mask);
-			PRINT_FIELD_U(", ", params.sq_off, ring_entries);
-			PRINT_FIELD_U(", ", params.sq_off, flags);
-			PRINT_FIELD_U(", ", params.sq_off, dropped);
-			PRINT_FIELD_U(", ", params.sq_off, array);
-			if (params.sq_off.resv1)
-				PRINT_FIELD_X(", ", params.sq_off, resv1);
-			if (params.sq_off.resv2)
-				PRINT_FIELD_X(", ", params.sq_off, resv2);
-			PRINT_FIELD_U("}, cq_off={", params.cq_off, head);
-			PRINT_FIELD_U(", ", params.cq_off, tail);
-			PRINT_FIELD_U(", ", params.cq_off, ring_mask);
-			PRINT_FIELD_U(", ", params.cq_off, ring_entries);
-			PRINT_FIELD_U(", ", params.cq_off, overflow);
-			PRINT_FIELD_U(", ", params.cq_off, cqes);
-			if (!IS_ARRAY_ZERO(params.cq_off.resv)) {
-				PRINT_FIELD_ARRAY(", ", params.cq_off, resv, tcp,
-						  print_xint64_array_member);
-			}
-			tprints("}");
-		}
+		PRINT_FIELD_U(", ", params, sq_entries);
+		PRINT_FIELD_U(", ", params, cq_entries);
+		PRINT_FIELD_FLAGS(", ", params, features,
+				  uring_setup_features,
+				  "IORING_FEAT_???");
+		PRINT_FIELD_U(", sq_off={", params.sq_off, head);
+		PRINT_FIELD_U(", ", params.sq_off, tail);
+		PRINT_FIELD_U(", ", params.sq_off, ring_mask);
+		PRINT_FIELD_U(", ", params.sq_off, ring_entries);
+		PRINT_FIELD_U(", ", params.sq_off, flags);
+		PRINT_FIELD_U(", ", params.sq_off, dropped);
+		PRINT_FIELD_U(", ", params.sq_off, array);
+		if (params.sq_off.resv1)
+			PRINT_FIELD_X(", ", params.sq_off, resv1);
+		if (params.sq_off.resv2)
+			PRINT_FIELD_X(", ", params.sq_off, resv2);
+		PRINT_FIELD_U("}, cq_off={", params.cq_off, head);
+		PRINT_FIELD_U(", ", params.cq_off, tail);
+		PRINT_FIELD_U(", ", params.cq_off, ring_mask);
+		PRINT_FIELD_U(", ", params.cq_off, ring_entries);
+		PRINT_FIELD_U(", ", params.cq_off, overflow);
+		PRINT_FIELD_U(", ", params.cq_off, cqes);
+		PRINT_FIELD_FLAGS(", ", params.cq_off, flags,
+				  uring_cqring_flags, "IORING_CQ_???");
+		if (params.cq_off.resv1)
+			PRINT_FIELD_X(", ", params.cq_off, resv1);
+		if (params.cq_off.resv2)
+			PRINT_FIELD_X(", ", params.cq_off, resv2);
 		tprints("}");
 	}
+	tprints("}");
 
 	return RVAL_DECODED | RVAL_FD;
 }
@@ -158,35 +149,114 @@ print_io_uring_files_update(struct tcb *
 	tprints("}");
 }
 
+static bool
+print_io_uring_probe_op(struct tcb *tcp, void *elem_buf, size_t elem_size,
+			void *data)
+{
+	struct_io_uring_probe_op *op = (struct_io_uring_probe_op *) elem_buf;
+
+	PRINT_FIELD_XVAL_U("{", *op, op, uring_ops, "IORING_OP_???");
+	if (op->resv)
+		PRINT_FIELD_X(", ", *op, resv);
+	PRINT_FIELD_FLAGS(", ", *op, flags, uring_op_flags, "IO_URING_OP_???");
+	if (op->resv2)
+		PRINT_FIELD_X(", ", *op, resv2);
+	tprints("}");
+
+	return true;
+}
+
+static int
+print_io_uring_probe(struct tcb *tcp, const kernel_ulong_t addr,
+		     const unsigned int nargs)
+{
+	struct_io_uring_probe *probe;
+	unsigned long printed = exiting(tcp) ? get_tcb_priv_ulong(tcp) : false;
+
+	if (exiting(tcp) && syserror(tcp)) {
+		if (!printed)
+			printaddr(addr);
+		return RVAL_DECODED;
+	}
+	if (nargs > 256) {
+		printaddr(addr);
+		return RVAL_DECODED;
+	}
+	if (printed)
+		tprints(" => ");
+
+	/* Maximum size is 8 * 256 + 16, a bit over 4k */
+	size_t probe_sz = sizeof(probe->ops[0]) * nargs + sizeof(*probe);
+	probe = alloca(probe_sz);
+
+	/*
+	 * So far, the operation doesn't use any data from the arg provided,
+	 * but it checks that it is filled with zeroes.
+	 */
+	if (umoven_or_printaddr(tcp, addr, probe_sz, probe))
+		return RVAL_DECODED;
+	if (entering(tcp) && is_filled((const char *) probe, 0, probe_sz))
+		return 0;
+	set_tcb_priv_ulong(tcp, true);
+
+	PRINT_FIELD_XVAL_U("{", *probe, last_op, uring_ops, "IORING_OP_???");
+	PRINT_FIELD_U(", ", *probe, ops_len);
+	if (probe->resv)
+		PRINT_FIELD_X(", ", *probe, resv);
+	if (!IS_ARRAY_ZERO(probe->resv2)) {
+		PRINT_FIELD_ARRAY(", ", *probe, resv2, tcp,
+				  print_xint32_array_member);
+	}
+	tprints(", ops=");
+	print_local_array_ex(tcp, probe->ops,
+			     entering(tcp) ? nargs : probe->ops_len,
+			     sizeof(probe->ops[0]), print_io_uring_probe_op,
+			     NULL, 0, NULL, NULL);
+	tprints("}");
+
+	return 0;
+}
+
 SYS_FUNC(io_uring_register)
 {
 	const int fd = tcp->u_arg[0];
 	const unsigned int opcode = tcp->u_arg[1];
 	const kernel_ulong_t arg = tcp->u_arg[2];
 	const unsigned int nargs = tcp->u_arg[3];
+	int rc = RVAL_DECODED;
 	int buf;
 
-	printfd(tcp, fd);
-	tprints(", ");
-	printxval(uring_register_opcodes, opcode, "IORING_REGISTER_???");
-	tprints(", ");
+	if (entering(tcp)) {
+		printfd(tcp, fd);
+		tprints(", ");
+		printxval(uring_register_opcodes, opcode,
+			  "IORING_REGISTER_???");
+		tprints(", ");
+	}
+
 	switch (opcode) {
 	case IORING_REGISTER_BUFFERS:
 		tprint_iov(tcp, nargs, arg, IOV_DECODE_ADDR);
 		break;
 	case IORING_REGISTER_FILES:
 	case IORING_REGISTER_EVENTFD:
+	case IORING_REGISTER_EVENTFD_ASYNC:
 		print_array(tcp, arg, nargs, &buf, sizeof(buf),
 			    tfetch_mem, print_fd_array_member, NULL);
 		break;
 	case IORING_REGISTER_FILES_UPDATE:
 		print_io_uring_files_update(tcp, arg, nargs);
 		break;
+	case IORING_REGISTER_PROBE:
+		rc = print_io_uring_probe(tcp, arg, nargs);
+		break;
 	default:
 		printaddr(arg);
 		break;
 	}
-	tprintf(", %u", nargs);
 
-	return RVAL_DECODED;
+	if (rc || exiting(tcp))
+		tprintf(", %u", nargs);
+
+	return rc;
 }
diff -pruN 5.5-3/ipc_defs.h 5.9-0ubuntu2/ipc_defs.h
--- 5.5-3/ipc_defs.h	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/ipc_defs.h	2020-09-19 08:00:00.000000000 +0000
@@ -37,7 +37,9 @@
 #  define SEM_H_PROVIDER "linux/sem.h"
 #  define SHM_H_PROVIDER "linux/shm.h"
 #  define NAME_OF_STRUCT_MSQID_DS msqid64_ds
+#  define NAME_OF_STRUCT_SEMID_DS semid64_ds
 #  define NAME_OF_STRUCT_SHMID_DS shmid64_ds
+#  define NAME_OF_STRUCT_SHMINFO shminfo64
 #  define NAME_OF_STRUCT_IPC_PERM_KEY key
 # elif defined HAVE_SYS_IPC_H
 #  include <sys/ipc.h>
@@ -45,7 +47,9 @@
 #  define SEM_H_PROVIDER "sys/sem.h"
 #  define SHM_H_PROVIDER "sys/shm.h"
 #  define NAME_OF_STRUCT_MSQID_DS msqid_ds
+#  define NAME_OF_STRUCT_SEMID_DS semid_ds
 #  define NAME_OF_STRUCT_SHMID_DS shmid_ds
+#  define NAME_OF_STRUCT_SHMINFO shminfo
 #  define NAME_OF_STRUCT_IPC_PERM_KEY __key
 # else
 #  error Neither <sys/ipc.h> nor <linux/ipc.h> is available
diff -pruN 5.5-3/ipc_msgctl.c 5.9-0ubuntu2/ipc_msgctl.c
--- 5.5-3/ipc_msgctl.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/ipc_msgctl.c	2020-09-19 08:00:00.000000000 +0000
@@ -22,62 +22,106 @@ typedef struct NAME_OF_STRUCT_MSQID_DS m
 
 #include MPERS_DEFS
 
+#include "print_fields.h"
 #include "xlat/msgctl_flags.h"
 
+#define key NAME_OF_STRUCT_IPC_PERM_KEY
+
 static void
-print_msqid_ds(struct tcb *const tcp, const kernel_ulong_t addr, int cmd)
+print_msqid_ds(struct tcb *const tcp, const kernel_ulong_t addr,
+	       const unsigned int cmd)
 {
-	/* TODO: We don't properly decode old compat ipc calls. */
-	if (cmd & IPC_64)
-		cmd &= ~IPC_64;
 	msqid_ds_t msqid_ds;
-	switch (cmd) {
-	case IPC_SET:
-	case IPC_STAT:
-		if (umove_or_printaddr(tcp, addr, &msqid_ds))
-			return;
-
-		tprints("{msg_perm={");
-		printuid("uid=", msqid_ds.msg_perm.uid);
-		printuid(", gid=", msqid_ds.msg_perm.gid);
-		tprints(", mode=");
-		print_numeric_umode_t(msqid_ds.msg_perm.mode);
 
-		if (cmd != IPC_STAT) {
-			tprints("}, ...}");
-			break;
-		}
+	if (umove_or_printaddr(tcp, addr, &msqid_ds))
+		return;
 
-		tprintf(", key=%u",
-			(unsigned) msqid_ds.msg_perm.NAME_OF_STRUCT_IPC_PERM_KEY);
-		printuid(", cuid=", msqid_ds.msg_perm.cuid);
-		printuid(", cgid=", msqid_ds.msg_perm.cgid);
-		tprints("}");
-		tprintf(", msg_stime=%u", (unsigned) msqid_ds.msg_stime);
-		tprintf(", msg_rtime=%u", (unsigned) msqid_ds.msg_rtime);
-		tprintf(", msg_ctime=%u", (unsigned) msqid_ds.msg_ctime);
-		tprintf(", msg_qnum=%u", (unsigned) msqid_ds.msg_qnum);
-		tprintf(", msg_qbytes=%u", (unsigned) msqid_ds.msg_qbytes);
-		tprintf(", msg_lspid=%u", (unsigned) msqid_ds.msg_lspid);
-		tprintf(", msg_lrpid=%u", (unsigned) msqid_ds.msg_lrpid);
-		tprints("}");
-		break;
-
-	default:
-		printaddr(addr);
-		break;
+	PRINT_FIELD_UID("{msg_perm={", msqid_ds.msg_perm, uid);
+	PRINT_FIELD_UID(", ", msqid_ds.msg_perm, gid);
+	PRINT_FIELD_NUMERIC_UMODE_T(", ", msqid_ds.msg_perm, mode);
+	if (cmd != IPC_SET) {
+		PRINT_FIELD_U(", ", msqid_ds.msg_perm, key);
+		PRINT_FIELD_UID(", ", msqid_ds.msg_perm, cuid);
+		PRINT_FIELD_UID(", ", msqid_ds.msg_perm, cgid);
+	}
+	tprints("}");
+	if (cmd != IPC_SET) {
+		PRINT_FIELD_U(", ", msqid_ds, msg_stime);
+		PRINT_FIELD_U(", ", msqid_ds, msg_rtime);
+		PRINT_FIELD_U(", ", msqid_ds, msg_ctime);
+		PRINT_FIELD_U(", ", msqid_ds, msg_qnum);
 	}
+	PRINT_FIELD_U(", ", msqid_ds, msg_qbytes);
+	if (cmd != IPC_SET) {
+		PRINT_FIELD_D(", ", msqid_ds, msg_lspid);
+		PRINT_FIELD_D(", ", msqid_ds, msg_lrpid);
+	}
+	tprints("}");
+}
+
+static void
+print_msginfo(struct tcb *const tcp, const kernel_ulong_t addr,
+	      const unsigned int cmd)
+{
+	struct msginfo info;
+
+	if (umove_or_printaddr(tcp, addr, &info))
+		return;
+
+	PRINT_FIELD_D("{", info, msgpool);
+	PRINT_FIELD_D(", ", info, msgmap);
+	PRINT_FIELD_D(", ", info, msgmax);
+	PRINT_FIELD_D(", ", info, msgmnb);
+	PRINT_FIELD_D(", ", info, msgmni);
+	PRINT_FIELD_D(", ", info, msgssz);
+	PRINT_FIELD_D(", ", info, msgtql);
+	PRINT_FIELD_U(", ", info, msgseg);
+	tprints("}");
 }
 
 SYS_FUNC(msgctl)
 {
+	const kernel_ulong_t addr = tcp->u_arg[indirect_ipccall(tcp) ? 3 : 2];
+	unsigned int cmd = tcp->u_arg[1];
+
+	/* TODO: We don't properly decode old compat ipc calls. */
+	if (cmd & IPC_64)
+		cmd &= ~IPC_64;
+
 	if (entering(tcp)) {
 		tprintf("%d, ", (int) tcp->u_arg[0]);
 		PRINTCTL(msgctl_flags, tcp->u_arg[1], "MSG_???");
 		tprints(", ");
+		switch (cmd) {
+		case IPC_SET:
+			print_msqid_ds(tcp, addr, cmd);
+			return RVAL_DECODED;
+
+		case IPC_STAT:
+		case MSG_STAT:
+		case MSG_STAT_ANY:
+		case IPC_INFO:
+		case MSG_INFO:
+			/* decode on exiting */
+			break;
+
+		default:
+			printaddr(addr);
+			return RVAL_DECODED;
+		}
 	} else {
-		const kernel_ulong_t addr = tcp->u_arg[indirect_ipccall(tcp) ? 3 : 2];
-		print_msqid_ds(tcp, addr, tcp->u_arg[1]);
+		switch (cmd) {
+		case IPC_STAT:
+		case MSG_STAT:
+		case MSG_STAT_ANY:
+			print_msqid_ds(tcp, addr, cmd);
+			break;
+
+		case IPC_INFO:
+		case MSG_INFO:
+			print_msginfo(tcp, addr, cmd);
+			break;
+		}
 	}
 	return 0;
 }
diff -pruN 5.5-3/ipc_sem.c 5.9-0ubuntu2/ipc_sem.c
--- 5.5-3/ipc_sem.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/ipc_sem.c	2020-09-19 08:00:00.000000000 +0000
@@ -16,7 +16,6 @@
 
 #include SEM_H_PROVIDER
 
-#include "xlat/semctl_flags.h"
 #include "xlat/semop_flags.h"
 
 static bool
@@ -93,20 +92,3 @@ SYS_FUNC(semget)
 	print_numeric_umode_t(tcp->u_arg[2] & 0777);
 	return RVAL_DECODED;
 }
-
-SYS_FUNC(semctl)
-{
-	tprintf("%d, %d, ", (int) tcp->u_arg[0], (int) tcp->u_arg[1]);
-	PRINTCTL(semctl_flags, tcp->u_arg[2], "SEM_???");
-	tprints(", ");
-	if (indirect_ipccall(tcp)
-#ifdef SPARC64
-	    && current_personality != 0
-#endif
-	   ) {
-		printnum_ptr(tcp, tcp->u_arg[3]);
-	} else {
-		printaddr(tcp->u_arg[3]);
-	}
-	return RVAL_DECODED;
-}
diff -pruN 5.5-3/ipc_semctl.c 5.9-0ubuntu2/ipc_semctl.c
--- 5.5-3/ipc_semctl.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/ipc_semctl.c	2020-09-19 08:00:00.000000000 +0000
@@ -0,0 +1,160 @@
+/*
+ * Copyright (c) 1993 Ulrich Pegelow <pegelow@moorea.uni-muenster.de>
+ * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
+ * Copyright (c) 1993, 1994, 1995, 1996 Rick Sladkey <jrs@world.std.com>
+ * Copyright (c) 1996-1999 Wichert Akkerman <wichert@cistron.nl>
+ * Copyright (c) 2003-2006 Roland McGrath <roland@redhat.com>
+ * Copyright (c) 2006-2015 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2015-2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
+#include "defs.h"
+
+#include DEF_MPERS_TYPE(semid_ds_t)
+#include DEF_MPERS_TYPE(semun_ptr_t)
+
+#include "ipc_defs.h"
+
+#include SEM_H_PROVIDER
+
+typedef struct NAME_OF_STRUCT_SEMID_DS semid_ds_t;
+typedef kernel_ulong_t semun_ptr_t;
+
+#include MPERS_DEFS
+
+#include "print_fields.h"
+#include "xlat/semctl_flags.h"
+
+#define key NAME_OF_STRUCT_IPC_PERM_KEY
+
+static void
+print_semid_ds(struct tcb *const tcp, const kernel_ulong_t addr,
+	       const unsigned int cmd, const bool indirect_addr)
+{
+	semid_ds_t ds;
+
+	if (!tfetch_mem(tcp, addr, sizeof(ds), &ds)) {
+		if (indirect_addr)
+			tprints("[");
+		printaddr(addr);
+		if (indirect_addr)
+			tprints("]");
+		return;
+	}
+
+	PRINT_FIELD_UID("{sem_perm={", ds.sem_perm, uid);
+	PRINT_FIELD_UID(", ", ds.sem_perm, gid);
+	PRINT_FIELD_NUMERIC_UMODE_T(", ", ds.sem_perm, mode);
+	if (cmd != IPC_SET) {
+		PRINT_FIELD_U(", ", ds.sem_perm, key);
+		PRINT_FIELD_UID(", ", ds.sem_perm, cuid);
+		PRINT_FIELD_UID(", ", ds.sem_perm, cgid);
+	}
+	tprints("}");
+	if (cmd != IPC_SET) {
+		PRINT_FIELD_U(", ", ds, sem_otime);
+		PRINT_FIELD_U(", ", ds, sem_ctime);
+		PRINT_FIELD_U(", ", ds, sem_nsems);
+	}
+	tprints("}");
+}
+
+static void
+print_seminfo(struct tcb *const tcp, const kernel_ulong_t addr,
+	      const unsigned int cmd, const bool indirect_addr)
+{
+	struct seminfo info;
+
+	if (umove_or_printaddr(tcp, addr, &info))
+		return;
+	if (!tfetch_mem(tcp, addr, sizeof(info), &info)) {
+		if (indirect_addr)
+			tprints("[");
+		printaddr(addr);
+		if (indirect_addr)
+			tprints("]");
+		return;
+	}
+
+	PRINT_FIELD_D("{", info, semmap);
+	PRINT_FIELD_D(", ", info, semmni);
+	PRINT_FIELD_D(", ", info, semmns);
+	PRINT_FIELD_D(", ", info, semmnu);
+	PRINT_FIELD_D(", ", info, semmsl);
+	PRINT_FIELD_D(", ", info, semopm);
+	PRINT_FIELD_D(", ", info, semume);
+	PRINT_FIELD_D(", ", info, semusz);
+	PRINT_FIELD_D(", ", info, semvmx);
+	PRINT_FIELD_D(", ", info, semaem);
+	tprints("}");
+}
+
+SYS_FUNC(semctl)
+{
+	kernel_ulong_t addr;
+	unsigned int cmd = tcp->u_arg[2];
+	const bool indirect_addr = indirect_ipccall(tcp)
+#ifdef SPARC64
+		    && current_personality != 0
+#endif
+		    ;
+
+	/* TODO: We don't properly decode old compat ipc calls. */
+	if (cmd & IPC_64)
+		cmd &= ~IPC_64;
+
+	if (entering(tcp)) {
+		tprintf("%d, %d, ", (int) tcp->u_arg[0], (int) tcp->u_arg[1]);
+		PRINTCTL(semctl_flags, tcp->u_arg[2], "SEM_???");
+		tprints(", ");
+
+		if (indirect_addr) {
+			semun_ptr_t ptr;
+			if (umove_or_printaddr(tcp, tcp->u_arg[3], &ptr))
+				return RVAL_DECODED;
+			addr = ptr;
+		} else {
+			addr = tcp->u_arg[3];
+		}
+		switch (cmd) {
+		case IPC_SET:
+			print_semid_ds(tcp, addr, cmd, indirect_addr);
+			return RVAL_DECODED;
+
+		case IPC_STAT:
+		case SEM_STAT:
+		case SEM_STAT_ANY:
+		case IPC_INFO:
+		case SEM_INFO:
+			/* decode on exiting */
+			set_tcb_priv_ulong(tcp, addr);
+			break;
+
+		default:
+			if (indirect_addr)
+				tprints("[");
+			printaddr(addr);
+			if (indirect_addr)
+				tprints("]");
+			return RVAL_DECODED;
+		}
+	} else {
+		addr = get_tcb_priv_ulong(tcp);
+		switch (cmd) {
+		case IPC_STAT:
+		case SEM_STAT:
+		case SEM_STAT_ANY:
+			print_semid_ds(tcp, addr, cmd, indirect_addr);
+			break;
+
+		case IPC_INFO:
+		case SEM_INFO:
+			print_seminfo(tcp, addr, cmd, indirect_addr);
+			break;
+		}
+	}
+	return 0;
+}
diff -pruN 5.5-3/ipc_shmctl.c 5.9-0ubuntu2/ipc_shmctl.c
--- 5.5-3/ipc_shmctl.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/ipc_shmctl.c	2020-09-19 08:00:00.000000000 +0000
@@ -14,70 +14,135 @@
 #include "defs.h"
 
 #include DEF_MPERS_TYPE(shmid_ds_t)
+#include DEF_MPERS_TYPE(struct_shm_info_t)
+#include DEF_MPERS_TYPE(struct_shm_ipc_info_t)
 
 #include "ipc_defs.h"
 
 #include SHM_H_PROVIDER
 typedef struct NAME_OF_STRUCT_SHMID_DS shmid_ds_t;
+typedef struct shm_info struct_shm_info_t;
+typedef struct NAME_OF_STRUCT_SHMINFO struct_shm_ipc_info_t;
 
 #include MPERS_DEFS
 
+#include "print_fields.h"
 #include "xlat/shmctl_flags.h"
 
+#define key NAME_OF_STRUCT_IPC_PERM_KEY
+
 static void
-print_shmid_ds(struct tcb *const tcp, const kernel_ulong_t addr, int cmd)
+print_shmid_ds(struct tcb *const tcp, const kernel_ulong_t addr,
+	       const unsigned int cmd)
 {
-	/* TODO: We don't properly decode old compat ipc calls. */
-	if (cmd & IPC_64)
-		cmd &= ~IPC_64;
 	shmid_ds_t shmid_ds;
-	switch (cmd) {
-	case IPC_SET:
-	case IPC_STAT:
-		if (umove_or_printaddr(tcp, addr, &shmid_ds))
-			return;
-
-		tprints("{shm_perm={");
-		printuid("uid=", shmid_ds.shm_perm.uid);
-		printuid(", gid=", shmid_ds.shm_perm.gid);
-		tprints(", mode=");
-		print_numeric_umode_t(shmid_ds.shm_perm.mode);
 
-		if (cmd != IPC_STAT) {
-			tprints("}, ...}");
-			break;
-		}
+	if (umove_or_printaddr(tcp, addr, &shmid_ds))
+		return;
 
-		tprintf(", key=%u",
-			(unsigned) shmid_ds.shm_perm.NAME_OF_STRUCT_IPC_PERM_KEY);
-		printuid(", cuid=", shmid_ds.shm_perm.cuid);
-		printuid(", cgid=", shmid_ds.shm_perm.cgid);
-		tprints("}");
-		tprintf(", shm_segsz=%u", (unsigned) shmid_ds.shm_segsz);
-		tprintf(", shm_cpid=%u", (unsigned) shmid_ds.shm_cpid);
-		tprintf(", shm_lpid=%u", (unsigned) shmid_ds.shm_lpid);
-		tprintf(", shm_nattch=%u", (unsigned) shmid_ds.shm_nattch);
-		tprintf(", shm_atime=%u", (unsigned) shmid_ds.shm_atime);
-		tprintf(", shm_dtime=%u", (unsigned) shmid_ds.shm_dtime);
-		tprintf(", shm_ctime=%u", (unsigned) shmid_ds.shm_ctime);
-		tprints("}");
-		break;
-
-	default:
-		printaddr(addr);
-		break;
+	PRINT_FIELD_UID("{shm_perm={", shmid_ds.shm_perm, uid);
+	PRINT_FIELD_UID(", ", shmid_ds.shm_perm, gid);
+	PRINT_FIELD_NUMERIC_UMODE_T(", ", shmid_ds.shm_perm, mode);
+
+	if (cmd != IPC_SET) {
+		PRINT_FIELD_U(", ", shmid_ds.shm_perm, key);
+		PRINT_FIELD_UID(", ", shmid_ds.shm_perm, cuid);
+		PRINT_FIELD_UID(", ", shmid_ds.shm_perm, cgid);
+	}
+	tprints("}");
+	if (cmd != IPC_SET) {
+		PRINT_FIELD_U(", ", shmid_ds, shm_segsz);
+		PRINT_FIELD_TGID(", ", shmid_ds, shm_cpid, tcp);
+		PRINT_FIELD_TGID(", ", shmid_ds, shm_lpid, tcp);
+		PRINT_FIELD_U(", ", shmid_ds, shm_nattch);
+		PRINT_FIELD_U(", ", shmid_ds, shm_atime);
+		PRINT_FIELD_U(", ", shmid_ds, shm_dtime);
+		PRINT_FIELD_U(", ", shmid_ds, shm_ctime);
 	}
+	tprints("}");
+}
+
+static void
+print_ipc_info(struct tcb *const tcp, const kernel_ulong_t addr,
+	       const unsigned int cmd)
+{
+	struct_shm_ipc_info_t info;
+
+	if (umove_or_printaddr(tcp, addr, &info))
+		return;
+
+	PRINT_FIELD_U("{", info, shmmax);
+	PRINT_FIELD_U(", ", info, shmmin);
+	PRINT_FIELD_U(", ", info, shmmni);
+	PRINT_FIELD_U(", ", info, shmseg);
+	PRINT_FIELD_U(", ", info, shmall);
+	tprints("}");
+}
+
+static void
+print_shm_info(struct tcb *const tcp, const kernel_ulong_t addr,
+	       const unsigned int cmd)
+{
+	struct_shm_info_t info;
+
+	if (umove_or_printaddr(tcp, addr, &info))
+		return;
+
+	PRINT_FIELD_D("{", info, used_ids);
+	PRINT_FIELD_U(", ", info, shm_tot);
+	PRINT_FIELD_U(", ", info, shm_rss);
+	PRINT_FIELD_U(", ", info, shm_swp);
+	PRINT_FIELD_U(", ", info, swap_attempts);
+	PRINT_FIELD_U(", ", info, swap_successes);
+	tprints("}");
 }
 
 SYS_FUNC(shmctl)
 {
+	const kernel_ulong_t addr = tcp->u_arg[indirect_ipccall(tcp) ? 3 : 2];
+	unsigned int cmd = tcp->u_arg[1];
+
+	/* TODO: We don't properly decode old compat ipc calls. */
+	if (cmd & IPC_64)
+		cmd &= ~IPC_64;
+
 	if (entering(tcp)) {
 		tprintf("%d, ", (int) tcp->u_arg[0]);
 		PRINTCTL(shmctl_flags, tcp->u_arg[1], "SHM_???");
 		tprints(", ");
+		switch (cmd) {
+		case IPC_SET:
+			print_shmid_ds(tcp, addr, cmd);
+			return RVAL_DECODED;
+
+		case IPC_STAT:
+		case SHM_STAT:
+		case SHM_STAT_ANY:
+		case IPC_INFO:
+		case SHM_INFO:
+			/* decode on exiting */
+			break;
+
+		default:
+			printaddr(addr);
+			return RVAL_DECODED;
+		}
 	} else {
-		const kernel_ulong_t addr = tcp->u_arg[indirect_ipccall(tcp) ? 3 : 2];
-		print_shmid_ds(tcp, addr, tcp->u_arg[1]);
+		switch (cmd) {
+		case IPC_STAT:
+		case SHM_STAT:
+		case SHM_STAT_ANY:
+			print_shmid_ds(tcp, addr, cmd);
+			break;
+
+		case IPC_INFO:
+			print_ipc_info(tcp, addr, cmd);
+			break;
+
+		case SHM_INFO:
+			print_shm_info(tcp, addr, cmd);
+			break;
+		}
 	}
 	return 0;
 }
diff -pruN 5.5-3/kcmp.c 5.9-0ubuntu2/kcmp.c
--- 5.5-3/kcmp.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/kcmp.c	2020-08-25 14:29:30.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -16,20 +16,10 @@ struct strace_kcmp_epoll_slot {
 	uint32_t toff;
 };
 
-static void
-printpidfd(struct tcb *tcp, pid_t pid, int fd)
-{
-	/*
-	 * XXX We want to use printfd here, but we should figure out which
-	 *     process in strace's PID NS is referred to first.
-	 */
-	tprintf("%d", fd);
-}
-
 #define PRINT_FIELD_PIDFD(prefix_, where_, field_, tcp_, pid_)		\
 	do {								\
 		STRACE_PRINTF("%s%s=", (prefix_), #field_);		\
-		printpidfd((tcp_), (pid_), (where_).field_);		\
+		printfd_pid_tracee_ns((tcp_), (pid_), (where_).field_);		\
 	} while (0)
 
 SYS_FUNC(kcmp)
@@ -40,15 +30,18 @@ SYS_FUNC(kcmp)
 	kernel_ulong_t idx1 = tcp->u_arg[3];
 	kernel_ulong_t idx2 = tcp->u_arg[4];
 
-	tprintf("%d, %d, ", pid1, pid2);
+	printpid(tcp, pid1, PT_TGID);
+	tprints(", ");
+	printpid(tcp, pid2, PT_TGID);
+	tprints(", ");
 	printxval(kcmp_types, type, "KCMP_???");
 
 	switch (type) {
 		case KCMP_FILE:
 			tprints(", ");
-			printpidfd(tcp, pid1, idx1);
+			printfd_pid_tracee_ns(tcp, pid1, idx1);
 			tprints(", ");
-			printpidfd(tcp, pid1, idx2);
+			printfd_pid_tracee_ns(tcp, pid2, idx2);
 
 			break;
 
@@ -56,7 +49,7 @@ SYS_FUNC(kcmp)
 			struct strace_kcmp_epoll_slot slot;
 
 			tprints(", ");
-			printpidfd(tcp, pid1, idx1);
+			printfd_pid_tracee_ns(tcp, pid1, idx1);
 			tprints(", ");
 
 			if (umove_or_printaddr(tcp, idx2, &slot))
diff -pruN 5.5-3/kernel_dirent.h 5.9-0ubuntu2/kernel_dirent.h
--- 5.5-3/kernel_dirent.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/kernel_dirent.h	2020-06-01 14:15:16.000000000 +0000
@@ -0,0 +1,29 @@
+/*
+ * Copyright (c) 2015 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2015-2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
+#ifndef STRACE_KERNEL_DIRENT_H
+# define STRACE_KERNEL_DIRENT_H
+
+# include "kernel_types.h"
+
+typedef struct {
+	kernel_ulong_t	d_ino;
+	kernel_ulong_t	d_off;
+	unsigned short	d_reclen;
+	char		d_name[1];
+} kernel_dirent_t;
+
+typedef struct {
+	uint64_t	d_ino;
+	uint64_t	d_off;
+	unsigned short	d_reclen;
+	unsigned char	d_type;
+	char		d_name[1];
+} kernel_dirent64_t;
+
+#endif /* !STRACE_KERNEL_DIRENT_H */
diff -pruN 5.5-3/kernel_rusage.h 5.9-0ubuntu2/kernel_rusage.h
--- 5.5-3/kernel_rusage.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/kernel_rusage.h	2020-04-19 01:22:29.000000000 +0000
@@ -0,0 +1,32 @@
+/*
+ * Copyright (c) 1999-2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
+#ifndef STRACE_KERNEL_RUSAGE_H
+# define STRACE_KERNEL_RUSAGE_H
+
+# include "kernel_timeval.h"
+
+typedef struct {
+	kernel_old_timeval_t	ru_utime;
+	kernel_old_timeval_t	ru_stime;
+	kernel_long_t		ru_maxrss;
+	kernel_long_t		ru_ixrss;
+	kernel_long_t		ru_idrss;
+	kernel_long_t		ru_isrss;
+	kernel_long_t		ru_minflt;
+	kernel_long_t		ru_majflt;
+	kernel_long_t		ru_nswap;
+	kernel_long_t		ru_inblock;
+	kernel_long_t		ru_oublock;
+	kernel_long_t		ru_msgsnd;
+	kernel_long_t		ru_msgrcv;
+	kernel_long_t		ru_nsignals;
+	kernel_long_t		ru_nvcsw;
+	kernel_long_t		ru_nivcsw;
+} kernel_rusage_t;
+
+#endif /* !STRACE_KERNEL_RUSAGE_H */
diff -pruN 5.5-3/kernel_timespec.h 5.9-0ubuntu2/kernel_timespec.h
--- 5.5-3/kernel_timespec.h	2019-05-05 22:28:34.000000000 +0000
+++ 5.9-0ubuntu2/kernel_timespec.h	2020-06-01 14:15:16.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2019-2020 Dmitry V. Levin <ldv@altlinux.org>
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -13,13 +13,13 @@ typedef struct {
 	long long tv_nsec;
 } kernel_timespec64_t;
 
-# if HAVE_ARCH_TIME32_SYSCALLS
+# if HAVE_ARCH_TIME32_SYSCALLS || HAVE_ARCH_TIMESPEC32
 
 typedef struct {
 	int tv_sec;
 	int tv_nsec;
 } kernel_timespec32_t;
 
-# endif /* HAVE_ARCH_TIME32_SYSCALLS */
+# endif /* HAVE_ARCH_TIME32_SYSCALLS || HAVE_ARCH_TIMESPEC32 */
 
 #endif /* !STRACE_KERNEL_TIMESPEC_H */
diff -pruN 5.5-3/kernel_timeval.h 5.9-0ubuntu2/kernel_timeval.h
--- 5.5-3/kernel_timeval.h	2019-05-16 22:46:26.000000000 +0000
+++ 5.9-0ubuntu2/kernel_timeval.h	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2019-2020 Dmitry V. Levin <ldv@altlinux.org>
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -8,9 +8,20 @@
 #ifndef STRACE_KERNEL_TIMEVAL_H
 # define STRACE_KERNEL_TIMEVAL_H
 
+# include "kernel_types.h"
+
 typedef struct {
 	long long tv_sec;
 	long long tv_usec;
 } kernel_timeval64_t;
 
+typedef struct {
+	kernel_long_t tv_sec;
+# if defined __sparc__ && defined __arch64__
+	int tv_usec;
+# else
+	kernel_long_t tv_usec;
+# endif
+} kernel_old_timeval_t;
+
 #endif /* !STRACE_KERNEL_TIMEVAL_H */
diff -pruN 5.5-3/kernel_types.h 5.9-0ubuntu2/kernel_types.h
--- 5.5-3/kernel_types.h	2018-12-30 15:35:21.000000000 +0000
+++ 5.9-0ubuntu2/kernel_types.h	2020-06-01 14:15:16.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -28,13 +28,6 @@ typedef unsigned long kernel_ulong_t;
 
 # endif
 
-typedef struct {
-	kernel_ulong_t	d_ino;
-	kernel_ulong_t	d_off;
-	unsigned short	d_reclen;
-	char		d_name[1];
-} kernel_dirent;
-
 # if SIZEOF_KERNEL_LONG_T > SIZEOF_LONG
 #  define PRI_kl "ll"
 # else
diff -pruN 5.5-3/kernel_v4l2_types.h 5.9-0ubuntu2/kernel_v4l2_types.h
--- 5.5-3/kernel_v4l2_types.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/kernel_v4l2_types.h	2020-05-28 08:00:00.000000000 +0000
@@ -0,0 +1,61 @@
+/*
+ * Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
+#ifndef STRACE_KERNEL_V4L2_BUFFER_H
+# define STRACE_KERNEL_V4L2_BUFFER_H
+
+# include "types/v4l2.h"
+# include "kernel_timeval.h"
+# include "kernel_timespec.h"
+
+# if defined __sparc__ && defined __arch64__
+typedef struct {
+	long long tv_sec;
+	int tv_usec;
+	int pad;
+} kernel_v4l2_timeval_t;
+# else
+typedef kernel_timeval64_t kernel_v4l2_timeval_t;
+# endif
+
+typedef struct {
+	uint32_t			index;
+	uint32_t			type;
+	uint32_t			bytesused;
+	uint32_t			flags;
+	uint32_t			field;
+	kernel_v4l2_timeval_t		timestamp;
+	struct v4l2_timecode		timecode;
+	uint32_t			sequence;
+	uint32_t			memory;
+	union {
+		uint32_t		offset;
+		unsigned long		userptr;
+		struct v4l2_plane	*planes;
+		int32_t			fd;
+	} m;
+	uint32_t			length;
+	uint32_t			reserved2;
+	union {
+		int32_t			request_fd;
+		uint32_t		reserved;
+	};
+} kernel_v4l2_buffer_t;
+
+typedef struct {
+	uint32_t				type;
+	union {
+		uint64_t			data[8];
+	} u;
+	uint32_t				pending;
+	uint32_t				sequence;
+	kernel_timespec64_t			timestamp;
+	uint32_t				id;
+	uint32_t				reserved[8];
+} kernel_v4l2_event_t;
+
+#endif /* !STRACE_KERNEL_V4L2_BUFFER_H */
diff -pruN 5.5-3/largefile_wrappers.h 5.9-0ubuntu2/largefile_wrappers.h
--- 5.5-3/largefile_wrappers.h	2019-12-15 16:29:06.000000000 +0000
+++ 5.9-0ubuntu2/largefile_wrappers.h	2020-09-23 16:29:35.000000000 +0000
@@ -2,7 +2,7 @@
  * Wrappers for handling discrepancies in LF64-themed syscalls availability and
  * necessity between various architectures and kernel versions.
  *
- * Copyright (c) 2012-2019 The strace developers.
+ * Copyright (c) 2012-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -29,6 +29,7 @@
 #  else
 #   define fcntl_fd fcntl
 #  endif
+#  define fstat_fd fstat64
 #  define strace_stat_t struct stat64
 #  define stat_file stat64
 #  define struct_dirent struct dirent64
@@ -39,6 +40,7 @@
 #  define open_file open
 #  define fopen_stream fopen
 #  define fcntl_fd fcntl
+#  define fstat_fd fstat
 #  define strace_stat_t struct stat
 #  define stat_file stat
 #  define struct_dirent struct dirent
diff -pruN 5.5-3/linux/32/ioctls_inc_align16.h 5.9-0ubuntu2/linux/32/ioctls_inc_align16.h
--- 5.5-3/linux/32/ioctls_inc_align16.h	2020-01-27 13:21:44.000000000 +0000
+++ 5.9-0ubuntu2/linux/32/ioctls_inc_align16.h	2020-09-23 16:29:35.000000000 +0000
@@ -155,6 +155,7 @@
 { "drm/drm.h", "DRM_IOCTL_MODE_GETCRTC", _IOC_READ|_IOC_WRITE, 0x64a1, 0x68 },
 { "drm/drm.h", "DRM_IOCTL_MODE_GETENCODER", _IOC_READ|_IOC_WRITE, 0x64a6, 0x14 },
 { "drm/drm.h", "DRM_IOCTL_MODE_GETFB", _IOC_READ|_IOC_WRITE, 0x64ad, 0x1c },
+{ "drm/drm.h", "DRM_IOCTL_MODE_GETFB2", _IOC_READ|_IOC_WRITE, 0x64ce, 0x64 },
 { "drm/drm.h", "DRM_IOCTL_MODE_GETGAMMA", _IOC_READ|_IOC_WRITE, 0x64a4, 0x20 },
 { "drm/drm.h", "DRM_IOCTL_MODE_GETPLANE", _IOC_READ|_IOC_WRITE, 0x64b6, 0x20 },
 { "drm/drm.h", "DRM_IOCTL_MODE_GETPLANERESOURCES", _IOC_READ|_IOC_WRITE, 0x64b5, 0x0c },
@@ -268,6 +269,7 @@
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_MADVISE", _IOC_READ|_IOC_WRITE, 0x6466, 0x0c },
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_MMAP", _IOC_READ|_IOC_WRITE, 0x645e, 0x28 },
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_MMAP_GTT", _IOC_READ|_IOC_WRITE, 0x6464, 0x10 },
+{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_MMAP_OFFSET", _IOC_READ|_IOC_WRITE, 0x6464, 0x20 },
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_PIN", _IOC_READ|_IOC_WRITE, 0x6455, 0x18 },
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_PREAD", _IOC_WRITE, 0x645c, 0x20 },
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_PWRITE", _IOC_WRITE, 0x645d, 0x20 },
@@ -330,7 +332,7 @@
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_INFO", _IOC_READ|_IOC_WRITE, 0x6443, 0x18 },
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_MADVISE", _IOC_READ|_IOC_WRITE, 0x6448, 0x0c },
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_NEW", _IOC_READ|_IOC_WRITE, 0x6442, 0x10 },
-{ "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_SUBMIT", _IOC_READ|_IOC_WRITE, 0x6446, 0x28 },
+{ "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_SUBMIT", _IOC_READ|_IOC_WRITE, 0x6446, 0x48 },
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_GET_PARAM", _IOC_READ|_IOC_WRITE, 0x6440, 0x10 },
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_SUBMITQUEUE_CLOSE", _IOC_WRITE, 0x644b, 0x04 },
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_SUBMITQUEUE_NEW", _IOC_READ|_IOC_WRITE, 0x644a, 0x0c },
@@ -695,6 +697,7 @@
 { "linux/btrfs.h", "BTRFS_IOC_SNAP_CREATE", _IOC_WRITE, 0x9401, 0x1000 },
 { "linux/btrfs.h", "BTRFS_IOC_SNAP_CREATE_V2", _IOC_WRITE, 0x9417, 0x1000 },
 { "linux/btrfs.h", "BTRFS_IOC_SNAP_DESTROY", _IOC_WRITE, 0x940f, 0x1000 },
+{ "linux/btrfs.h", "BTRFS_IOC_SNAP_DESTROY_V2", _IOC_WRITE, 0x943f, 0x1000 },
 { "linux/btrfs.h", "BTRFS_IOC_SPACE_INFO", _IOC_READ|_IOC_WRITE, 0x9414, 0x10 },
 { "linux/btrfs.h", "BTRFS_IOC_START_SYNC", _IOC_READ, 0x9418, 0x08 },
 { "linux/btrfs.h", "BTRFS_IOC_SUBVOL_CREATE", _IOC_WRITE, 0x940e, 0x1000 },
@@ -830,7 +833,9 @@
 { "linux/dm-ioctl.h", "DM_TARGET_MSG", _IOC_READ|_IOC_WRITE, 0xfd0e, 0x138 },
 { "linux/dm-ioctl.h", "DM_VERSION", _IOC_READ|_IOC_WRITE, 0xfd00, 0x138 },
 { "linux/dma-buf.h", "DMA_BUF_IOCTL_SYNC", _IOC_WRITE, 0x6200, 0x08 },
-{ "linux/dma-buf.h", "DMA_BUF_SET_NAME", _IOC_WRITE, 0x6201, 0x04 },
+{ "linux/dma-buf.h", "DMA_BUF_SET_NAME_A", _IOC_WRITE, 0x6201, 0x04 },
+{ "linux/dma-buf.h", "DMA_BUF_SET_NAME_B", _IOC_WRITE, 0x6201, 0x08 },
+{ "linux/dma-heap.h", "DMA_HEAP_IOCTL_ALLOC", _IOC_READ|_IOC_WRITE, 0x4800, 0x18 },
 { "linux/dn.h", "OSIOCGNETADDR", _IOC_READ, 0x89e1, 0x04 },
 { "linux/dn.h", "OSIOCSNETADDR", _IOC_WRITE, 0x89e0, 0x04 },
 { "linux/dn.h", "SIOCGNETADDR", _IOC_READ, 0x89e1, 0x04 },
@@ -987,15 +992,21 @@
 { "linux/firewire-cdev.h", "FW_CDEV_IOC_START_ISO", _IOC_WRITE, 0x230a, 0x10 },
 { "linux/firewire-cdev.h", "FW_CDEV_IOC_STOP_ISO", _IOC_WRITE, 0x230b, 0x04 },
 { "linux/fpga-dfl.h", "DFL_FPGA_CHECK_EXTENSION", _IOC_NONE, 0xb601, 0x00 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_FME_ERR_GET_IRQ_NUM", _IOC_READ, 0xb683, 0x04 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_FME_ERR_SET_IRQ", _IOC_WRITE, 0xb684, 0x08 },
 { "linux/fpga-dfl.h", "DFL_FPGA_FME_PORT_ASSIGN", _IOC_WRITE, 0xb682, 0x04 },
 { "linux/fpga-dfl.h", "DFL_FPGA_FME_PORT_PR", _IOC_NONE, 0xb680, 0x00 },
 { "linux/fpga-dfl.h", "DFL_FPGA_FME_PORT_RELEASE", _IOC_WRITE, 0xb681, 0x04 },
 { "linux/fpga-dfl.h", "DFL_FPGA_GET_API_VERSION", _IOC_NONE, 0xb600, 0x00 },
 { "linux/fpga-dfl.h", "DFL_FPGA_PORT_DMA_MAP", _IOC_NONE, 0xb643, 0x00 },
 { "linux/fpga-dfl.h", "DFL_FPGA_PORT_DMA_UNMAP", _IOC_NONE, 0xb644, 0x00 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_ERR_GET_IRQ_NUM", _IOC_READ, 0xb645, 0x04 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_ERR_SET_IRQ", _IOC_WRITE, 0xb646, 0x08 },
 { "linux/fpga-dfl.h", "DFL_FPGA_PORT_GET_INFO", _IOC_NONE, 0xb641, 0x00 },
 { "linux/fpga-dfl.h", "DFL_FPGA_PORT_GET_REGION_INFO", _IOC_NONE, 0xb642, 0x00 },
 { "linux/fpga-dfl.h", "DFL_FPGA_PORT_RESET", _IOC_NONE, 0xb640, 0x00 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_UINT_GET_IRQ_NUM", _IOC_READ, 0xb647, 0x04 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_UINT_SET_IRQ", _IOC_WRITE, 0xb648, 0x08 },
 { "linux/fs.h", "BLKALIGNOFF", _IOC_NONE, 0x127a, 0x00 },
 { "linux/fs.h", "BLKBSZGET", _IOC_READ, 0x1270, 0x04 },
 { "linux/fs.h", "BLKBSZSET", _IOC_WRITE, 0x1271, 0x04 },
@@ -1047,6 +1058,7 @@
 { "linux/fs.h", "FS_IOC_SETVERSION", _IOC_WRITE, 0x7602, 0x04 },
 { "linux/fscrypt.h", "FS_IOC_ADD_ENCRYPTION_KEY", _IOC_READ|_IOC_WRITE, 0x6617, 0x50 },
 { "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_KEY_STATUS", _IOC_READ|_IOC_WRITE, 0x661a, 0x80 },
+{ "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_NONCE", _IOC_READ, 0x661b, 0x10 },
 { "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_POLICY", _IOC_WRITE, 0x6615, 0x0c },
 { "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_POLICY_EX", _IOC_READ|_IOC_WRITE, 0x6616, 0x09 },
 { "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_PWSALT", _IOC_WRITE, 0x6614, 0x10 },
@@ -1092,10 +1104,6 @@
 { "linux/genwqe/genwqe_card.h", "GENWQE_WRITE_REG16", _IOC_WRITE, 0xa523, 0x10 },
 { "linux/genwqe/genwqe_card.h", "GENWQE_WRITE_REG32", _IOC_WRITE, 0xa521, 0x10 },
 { "linux/genwqe/genwqe_card.h", "GENWQE_WRITE_REG64", _IOC_WRITE, 0xa51f, 0x10 },
-{ "linux/gigaset_dev.h", "GIGASET_BRKCHARS", _IOC_WRITE, 0x4702, 0x06 },
-{ "linux/gigaset_dev.h", "GIGASET_CONFIG", _IOC_READ|_IOC_WRITE, 0x4701, 0x04 },
-{ "linux/gigaset_dev.h", "GIGASET_REDIR", _IOC_READ|_IOC_WRITE, 0x4700, 0x04 },
-{ "linux/gigaset_dev.h", "GIGASET_VERSION", _IOC_READ|_IOC_WRITE, 0x4703, 0x10 },
 { "linux/gpio.h", "GPIOHANDLE_GET_LINE_VALUES_IOCTL", _IOC_READ|_IOC_WRITE, 0xb408, 0x40 },
 { "linux/gpio.h", "GPIOHANDLE_SET_CONFIG_IOCTL", _IOC_READ|_IOC_WRITE, 0xb40a, 0x54 },
 { "linux/gpio.h", "GPIOHANDLE_SET_LINE_VALUES_IOCTL", _IOC_READ|_IOC_WRITE, 0xb409, 0x40 },
@@ -1103,6 +1111,8 @@
 { "linux/gpio.h", "GPIO_GET_LINEEVENT_IOCTL", _IOC_READ|_IOC_WRITE, 0xb404, 0x30 },
 { "linux/gpio.h", "GPIO_GET_LINEHANDLE_IOCTL", _IOC_READ|_IOC_WRITE, 0xb403, 0x16c },
 { "linux/gpio.h", "GPIO_GET_LINEINFO_IOCTL", _IOC_READ|_IOC_WRITE, 0xb402, 0x48 },
+{ "linux/gpio.h", "GPIO_GET_LINEINFO_UNWATCH_IOCTL", _IOC_READ|_IOC_WRITE, 0xb40c, 0x04 },
+{ "linux/gpio.h", "GPIO_GET_LINEINFO_WATCH_IOCTL", _IOC_READ|_IOC_WRITE, 0xb40b, 0x48 },
 { "linux/gsmmux.h", "GSMIOC_DISABLE_NET", _IOC_NONE, 0x4703, 0x00 },
 { "linux/gsmmux.h", "GSMIOC_ENABLE_NET", _IOC_WRITE, 0x4702, 0x34 },
 { "linux/gsmmux.h", "GSMIOC_GETCONF", _IOC_READ, 0x4700, 0x4c },
@@ -1346,6 +1356,7 @@
 { "linux/kd.h", "PIO_UNISCRNMAP", 0, 0x4B6A, 0 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_ACQUIRE_VM", _IOC_WRITE, 0x4b15, 0x08 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_ALLOC_MEMORY_OF_GPU", _IOC_READ|_IOC_WRITE, 0x4b16, 0x28 },
+{ "linux/kfd_ioctl.h", "AMDKFD_IOC_ALLOC_QUEUE_GWS", _IOC_READ|_IOC_WRITE, 0x4b1e, 0x10 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_CREATE_EVENT", _IOC_READ|_IOC_WRITE, 0x4b08, 0x20 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_CREATE_QUEUE", _IOC_READ|_IOC_WRITE, 0x4b02, 0x58 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_DBG_ADDRESS_WATCH", _IOC_WRITE, 0x4b0f, 0x10 },
@@ -1370,6 +1381,7 @@
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_SET_MEMORY_POLICY", _IOC_WRITE, 0x4b04, 0x20 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_SET_SCRATCH_BACKING_VA", _IOC_READ|_IOC_WRITE, 0x4b11, 0x10 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_SET_TRAP_HANDLER", _IOC_WRITE, 0x4b13, 0x18 },
+{ "linux/kfd_ioctl.h", "AMDKFD_IOC_SMI_EVENTS", _IOC_READ|_IOC_WRITE, 0x4b1f, 0x08 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_UNMAP_MEMORY_FROM_GPU", _IOC_READ|_IOC_WRITE, 0x4b19, 0x18 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_UPDATE_QUEUE", _IOC_WRITE, 0x4b07, 0x18 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_WAIT_EVENTS", _IOC_READ|_IOC_WRITE, 0x4b0c, 0x18 },
@@ -1403,6 +1415,7 @@
 { "linux/lirc.h", "LIRC_SET_WIDEBAND_RECEIVER", _IOC_WRITE, 0x6923, 0x04 },
 { "linux/loop.h", "LOOP_CHANGE_FD", 0, 0x4C06, 0 },
 { "linux/loop.h", "LOOP_CLR_FD", 0, 0x4C01, 0 },
+{ "linux/loop.h", "LOOP_CONFIGURE", 0, 0x4C0A, 0 },
 { "linux/loop.h", "LOOP_CTL_ADD", 0, 0x4C80, 0 },
 { "linux/loop.h", "LOOP_CTL_GET_FREE", 0, 0x4C82, 0 },
 { "linux/loop.h", "LOOP_CTL_REMOVE", 0, 0x4C81, 0 },
@@ -1547,6 +1560,7 @@
 { "linux/omapfb.h", "OMAPFB_WAITFORGO", _IOC_NONE, 0x4f3c, 0x00 },
 { "linux/omapfb.h", "OMAPFB_WAITFORVSYNC", _IOC_NONE, 0x4f39, 0x00 },
 { "linux/pcitest.h", "PCITEST_BAR", _IOC_NONE, 0x5001, 0x00 },
+{ "linux/pcitest.h", "PCITEST_CLEAR_IRQ", _IOC_NONE, 0x5010, 0x00 },
 { "linux/pcitest.h", "PCITEST_COPY", _IOC_WRITE, 0x5006, 0x04 },
 { "linux/pcitest.h", "PCITEST_GET_IRQTYPE", _IOC_NONE, 0x5009, 0x00 },
 { "linux/pcitest.h", "PCITEST_LEGACY_IRQ", _IOC_NONE, 0x5002, 0x00 },
@@ -1707,6 +1721,8 @@
 { "linux/raw.h", "RAW_GETBIND", _IOC_NONE, 0xac01, 0x00 },
 { "linux/raw.h", "RAW_SETBIND", _IOC_NONE, 0xac00, 0x00 },
 { "linux/reiserfs_fs.h", "REISERFS_IOC_UNPACK", _IOC_WRITE, 0xcd01, 0x04 },
+{ "linux/remoteproc_cdev.h", "RPROC_GET_SHUTDOWN_ON_RELEASE", _IOC_READ, 0xb702, 0x04 },
+{ "linux/remoteproc_cdev.h", "RPROC_SET_SHUTDOWN_ON_RELEASE", _IOC_WRITE, 0xb701, 0x04 },
 { "linux/rfkill.h", "RFKILL_IOCTL_NOINPUT", _IOC_NONE, 0x5201, 0x00 },
 { "linux/rio_cm_cdev.h", "RIO_CM_CHAN_ACCEPT", _IOC_READ|_IOC_WRITE, 0x6307, 0x08 },
 { "linux/rio_cm_cdev.h", "RIO_CM_CHAN_BIND", _IOC_WRITE, 0x6305, 0x08 },
@@ -1784,7 +1800,8 @@
 { "linux/scif_ioctl.h", "SCIF_VREADFROM", _IOC_READ|_IOC_WRITE, 0x730c, 0x24 },
 { "linux/scif_ioctl.h", "SCIF_VWRITETO", _IOC_READ|_IOC_WRITE, 0x730d, 0x24 },
 { "linux/scif_ioctl.h", "SCIF_WRITETO", _IOC_READ|_IOC_WRITE, 0x730b, 0x24 },
-{ "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_ID_VALID", _IOC_READ, 0x2102, 0x08 },
+{ "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_ADDFD", _IOC_WRITE, 0x2103, 0x18 },
+{ "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_ID_VALID", _IOC_WRITE, 0x2102, 0x08 },
 { "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_RECV", _IOC_READ|_IOC_WRITE, 0x2100, 0x50 },
 { "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_SEND", _IOC_READ|_IOC_WRITE, 0x2101, 0x18 },
 { "linux/sed-opal.h", "IOC_OPAL_ACTIVATE_LSP", _IOC_WRITE, 0x70df, 0x118 },
@@ -2100,6 +2117,22 @@
 { "linux/usb/iowarrior.h", "IOW_GETINFO", _IOC_READ, 0xc003, 0x26 },
 { "linux/usb/iowarrior.h", "IOW_READ", _IOC_WRITE, 0xc002, 0x04 },
 { "linux/usb/iowarrior.h", "IOW_WRITE", _IOC_WRITE, 0xc001, 0x04 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_CONFIGURE", _IOC_NONE, 0x5509, 0x00 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP0_READ", _IOC_READ|_IOC_WRITE, 0x5504, 0x08 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP0_STALL", _IOC_NONE, 0x550c, 0x00 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP0_WRITE", _IOC_WRITE, 0x5503, 0x08 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EPS_INFO", _IOC_READ, 0x550b, 0x384 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_CLEAR_HALT", _IOC_WRITE, 0x550e, 0x04 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_DISABLE", _IOC_WRITE, 0x5506, 0x04 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_ENABLE", _IOC_WRITE, 0x5505, 0x09 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_READ", _IOC_READ|_IOC_WRITE, 0x5508, 0x08 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_SET_HALT", _IOC_WRITE, 0x550d, 0x04 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_SET_WEDGE", _IOC_WRITE, 0x550f, 0x04 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_WRITE", _IOC_WRITE, 0x5507, 0x08 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EVENT_FETCH", _IOC_READ, 0x5502, 0x08 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_INIT", _IOC_WRITE, 0x5500, 0x101 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_RUN", _IOC_NONE, 0x5501, 0x00 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_VBUS_DRAW", _IOC_WRITE, 0x550a, 0x04 },
 { "linux/usb/tmc.h", "USBTMC488_IOCTL_GET_CAPS", _IOC_READ, 0x5b11, 0x01 },
 { "linux/usb/tmc.h", "USBTMC488_IOCTL_GOTO_LOCAL", _IOC_NONE, 0x5b14, 0x00 },
 { "linux/usb/tmc.h", "USBTMC488_IOCTL_LOCAL_LOCKOUT", _IOC_NONE, 0x5b15, 0x00 },
@@ -2169,6 +2202,7 @@
 { "linux/userfaultfd.h", "UFFDIO_REGISTER", _IOC_READ|_IOC_WRITE, 0xaa00, 0x20 },
 { "linux/userfaultfd.h", "UFFDIO_UNREGISTER", _IOC_READ, 0xaa01, 0x10 },
 { "linux/userfaultfd.h", "UFFDIO_WAKE", _IOC_READ, 0xaa02, 0x10 },
+{ "linux/userfaultfd.h", "UFFDIO_WRITEPROTECT", _IOC_READ|_IOC_WRITE, 0xaa06, 0x18 },
 { "linux/userfaultfd.h", "UFFDIO_ZEROPAGE", _IOC_READ|_IOC_WRITE, 0xaa04, 0x20 },
 { "linux/uvcvideo.h", "UVCIOC_CTRL_MAP", _IOC_READ|_IOC_WRITE, 0x7520, 0x58 },
 { "linux/uvcvideo.h", "UVCIOC_CTRL_QUERY", _IOC_READ|_IOC_WRITE, 0x7521, 0x0a },
@@ -2179,10 +2213,12 @@
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_G_FMT", _IOC_READ|_IOC_WRITE, 0x5604, 0x58 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_G_FRAME_INTERVAL", _IOC_READ|_IOC_WRITE, 0x5615, 0x30 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_G_SELECTION", _IOC_READ|_IOC_WRITE, 0x563d, 0x40 },
+{ "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_QUERYCAP", _IOC_READ, 0x5600, 0x40 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_S_CROP", _IOC_READ|_IOC_WRITE, 0x563c, 0x38 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_S_FMT", _IOC_READ|_IOC_WRITE, 0x5605, 0x58 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_S_FRAME_INTERVAL", _IOC_READ|_IOC_WRITE, 0x5616, 0x30 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_S_SELECTION", _IOC_READ|_IOC_WRITE, 0x563e, 0x40 },
+{ "linux/vboxguest.h", "VBG_IOCTL_ACQUIRE_GUEST_CAPABILITIES", _IOC_READ|_IOC_WRITE, 0x560d, 0x24 },
 { "linux/vboxguest.h", "VBG_IOCTL_CHANGE_FILTER_MASK", _IOC_READ|_IOC_WRITE, 0x560c, 0x20 },
 { "linux/vboxguest.h", "VBG_IOCTL_CHANGE_GUEST_CAPABILITIES", _IOC_READ|_IOC_WRITE, 0x560e, 0x20 },
 { "linux/vboxguest.h", "VBG_IOCTL_CHECK_BALLOON", _IOC_READ|_IOC_WRITE, 0x5611, 0x20 },
@@ -2190,10 +2226,11 @@
 { "linux/vboxguest.h", "VBG_IOCTL_HGCM_CONNECT", _IOC_READ|_IOC_WRITE, 0x5604, 0x9c },
 { "linux/vboxguest.h", "VBG_IOCTL_HGCM_DISCONNECT", _IOC_READ|_IOC_WRITE, 0x5605, 0x1c },
 { "linux/vboxguest.h", "VBG_IOCTL_INTERRUPT_ALL_WAIT_FOR_EVENTS", _IOC_READ|_IOC_WRITE, 0x560b, 0x18 },
-{ "linux/vboxguest.h", "VBG_IOCTL_VMMDEV_REQUEST_BIG", _IOC_READ|_IOC_WRITE, 0x5603, 0x00 },
+{ "linux/vboxguest.h", "VBG_IOCTL_VMMDEV_REQUEST_BIG", _IOC_NONE, 0x5603, 0x00 },
 { "linux/vboxguest.h", "VBG_IOCTL_WAIT_FOR_EVENTS", _IOC_READ|_IOC_WRITE, 0x560a, 0x20 },
 { "linux/vboxguest.h", "VBG_IOCTL_WRITE_CORE_DUMP", _IOC_READ|_IOC_WRITE, 0x5613, 0x1c },
 { "linux/vfio.h", "VFIO_CHECK_EXTENSION", _IOC_NONE, 0x3b65, 0x00 },
+{ "linux/vfio.h", "VFIO_DEVICE_FEATURE", _IOC_NONE, 0x3b75, 0x00 },
 { "linux/vfio.h", "VFIO_DEVICE_GET_GFX_DMABUF", _IOC_NONE, 0x3b73, 0x00 },
 { "linux/vfio.h", "VFIO_DEVICE_GET_INFO", _IOC_NONE, 0x3b6b, 0x00 },
 { "linux/vfio.h", "VFIO_DEVICE_GET_IRQ_INFO", _IOC_NONE, 0x3b6d, 0x00 },
@@ -2210,6 +2247,7 @@
 { "linux/vfio.h", "VFIO_GROUP_GET_STATUS", _IOC_NONE, 0x3b67, 0x00 },
 { "linux/vfio.h", "VFIO_GROUP_SET_CONTAINER", _IOC_NONE, 0x3b68, 0x00 },
 { "linux/vfio.h", "VFIO_GROUP_UNSET_CONTAINER", _IOC_NONE, 0x3b69, 0x00 },
+{ "linux/vfio.h", "VFIO_IOMMU_DIRTY_PAGES", _IOC_NONE, 0x3b75, 0x00 },
 { "linux/vfio.h", "VFIO_IOMMU_DISABLE", _IOC_NONE, 0x3b74, 0x00 },
 { "linux/vfio.h", "VFIO_IOMMU_ENABLE", _IOC_NONE, 0x3b73, 0x00 },
 { "linux/vfio.h", "VFIO_IOMMU_GET_INFO", _IOC_NONE, 0x3b70, 0x00 },
@@ -2247,6 +2285,14 @@
 { "linux/vhost.h", "VHOST_SET_VRING_ERR", _IOC_WRITE, 0xaf22, 0x08 },
 { "linux/vhost.h", "VHOST_SET_VRING_KICK", _IOC_WRITE, 0xaf20, 0x08 },
 { "linux/vhost.h", "VHOST_SET_VRING_NUM", _IOC_WRITE, 0xaf10, 0x08 },
+{ "linux/vhost.h", "VHOST_VDPA_GET_CONFIG", _IOC_READ, 0xaf73, 0x08 },
+{ "linux/vhost.h", "VHOST_VDPA_GET_DEVICE_ID", _IOC_READ, 0xaf70, 0x04 },
+{ "linux/vhost.h", "VHOST_VDPA_GET_STATUS", _IOC_READ, 0xaf71, 0x01 },
+{ "linux/vhost.h", "VHOST_VDPA_GET_VRING_NUM", _IOC_READ, 0xaf76, 0x02 },
+{ "linux/vhost.h", "VHOST_VDPA_SET_CONFIG", _IOC_WRITE, 0xaf74, 0x08 },
+{ "linux/vhost.h", "VHOST_VDPA_SET_CONFIG_CALL", _IOC_WRITE, 0xaf77, 0x04 },
+{ "linux/vhost.h", "VHOST_VDPA_SET_STATUS", _IOC_WRITE, 0xaf72, 0x01 },
+{ "linux/vhost.h", "VHOST_VDPA_SET_VRING_ENABLE", _IOC_WRITE, 0xaf75, 0x08 },
 { "linux/vhost.h", "VHOST_VSOCK_SET_GUEST_CID", _IOC_WRITE, 0xaf60, 0x08 },
 { "linux/vhost.h", "VHOST_VSOCK_SET_RUNNING", _IOC_WRITE, 0xaf61, 0x04 },
 { "linux/videodev2.h", "VIDIOC_CREATE_BUFS", _IOC_READ|_IOC_WRITE, 0x565c, 0xf8 },
@@ -2255,8 +2301,8 @@
 { "linux/videodev2.h", "VIDIOC_DBG_G_REGISTER", _IOC_READ|_IOC_WRITE, 0x5650, 0x38 },
 { "linux/videodev2.h", "VIDIOC_DBG_S_REGISTER", _IOC_WRITE, 0x564f, 0x38 },
 { "linux/videodev2.h", "VIDIOC_DECODER_CMD", _IOC_READ|_IOC_WRITE, 0x5660, 0x48 },
-{ "linux/videodev2.h", "VIDIOC_DQBUF", _IOC_READ|_IOC_WRITE, 0x5611, 0x44 },
-{ "linux/videodev2.h", "VIDIOC_DQEVENT", _IOC_READ, 0x5659, 0x78 },
+{ "linux/videodev2.h", "VIDIOC_DQBUF", _IOC_READ|_IOC_WRITE, 0x5611, 0x4c },
+{ "linux/videodev2.h", "VIDIOC_DQEVENT", _IOC_READ, 0x5659, 0x80 },
 { "linux/videodev2.h", "VIDIOC_DV_TIMINGS_CAP", _IOC_READ|_IOC_WRITE, 0x5664, 0x90 },
 { "linux/videodev2.h", "VIDIOC_ENCODER_CMD", _IOC_READ|_IOC_WRITE, 0x564d, 0x28 },
 { "linux/videodev2.h", "VIDIOC_ENUMAUDIO", _IOC_READ|_IOC_WRITE, 0x5641, 0x34 },
@@ -2293,9 +2339,9 @@
 { "linux/videodev2.h", "VIDIOC_G_TUNER", _IOC_READ|_IOC_WRITE, 0x561d, 0x54 },
 { "linux/videodev2.h", "VIDIOC_LOG_STATUS", _IOC_NONE, 0x5646, 0x00 },
 { "linux/videodev2.h", "VIDIOC_OVERLAY", _IOC_WRITE, 0x560e, 0x04 },
-{ "linux/videodev2.h", "VIDIOC_PREPARE_BUF", _IOC_READ|_IOC_WRITE, 0x565d, 0x44 },
-{ "linux/videodev2.h", "VIDIOC_QBUF", _IOC_READ|_IOC_WRITE, 0x560f, 0x44 },
-{ "linux/videodev2.h", "VIDIOC_QUERYBUF", _IOC_READ|_IOC_WRITE, 0x5609, 0x44 },
+{ "linux/videodev2.h", "VIDIOC_PREPARE_BUF", _IOC_READ|_IOC_WRITE, 0x565d, 0x4c },
+{ "linux/videodev2.h", "VIDIOC_QBUF", _IOC_READ|_IOC_WRITE, 0x560f, 0x4c },
+{ "linux/videodev2.h", "VIDIOC_QUERYBUF", _IOC_READ|_IOC_WRITE, 0x5609, 0x4c },
 { "linux/videodev2.h", "VIDIOC_QUERYCAP", _IOC_READ, 0x5600, 0x68 },
 { "linux/videodev2.h", "VIDIOC_QUERYCTRL", _IOC_READ|_IOC_WRITE, 0x5624, 0x44 },
 { "linux/videodev2.h", "VIDIOC_QUERYMENU", _IOC_READ|_IOC_WRITE, 0x5625, 0x2c },
@@ -2369,6 +2415,8 @@
 { "linux/vt.h", "VT_WAITACTIVE", 0, 0x5607, 0 },
 { "linux/vt.h", "VT_WAITEVENT", 0, 0x560E, 0 },
 { "linux/vtpm_proxy.h", "VTPM_PROXY_IOC_NEW_DEV", _IOC_READ|_IOC_WRITE, 0xa100, 0x14 },
+{ "linux/watch_queue.h", "IOC_WATCH_QUEUE_SET_FILTER", _IOC_NONE, 0x5761, 0x00 },
+{ "linux/watch_queue.h", "IOC_WATCH_QUEUE_SET_SIZE", _IOC_NONE, 0x5760, 0x00 },
 { "linux/watchdog.h", "WDIOC_GETBOOTSTATUS", _IOC_READ, 0x5702, 0x04 },
 { "linux/watchdog.h", "WDIOC_GETPRETIMEOUT", _IOC_READ, 0x5709, 0x04 },
 { "linux/watchdog.h", "WDIOC_GETSTATUS", _IOC_READ, 0x5701, 0x04 },
@@ -2444,7 +2492,12 @@
 { "media/i2c/saa6588.h", "SAA6588_CMD_READ", _IOC_READ, 0x5203, 0x04 },
 { "media/v4l2-common.h", "TUNER_SET_CONFIG", _IOC_WRITE, 0x645c, 0x08 },
 { "media/v4l2-common.h", "VIDIOC_INT_RESET", _IOC_WRITE, 0x6466, 0x04 },
-{ "media/v4l2-subdev.h", "V4L2_DEVICE_NOTIFY_EVENT", _IOC_WRITE, 0x7602, 0x78 },
+{ "media/v4l2-ioctl.h", "VIDIOC_DQBUF_TIME32", _IOC_READ|_IOC_WRITE, 0x5611, 0x44 },
+{ "media/v4l2-ioctl.h", "VIDIOC_DQEVENT_TIME32", _IOC_READ, 0x5659, 0x78 },
+{ "media/v4l2-ioctl.h", "VIDIOC_PREPARE_BUF_TIME32", _IOC_READ|_IOC_WRITE, 0x565d, 0x44 },
+{ "media/v4l2-ioctl.h", "VIDIOC_QBUF_TIME32", _IOC_READ|_IOC_WRITE, 0x560f, 0x44 },
+{ "media/v4l2-ioctl.h", "VIDIOC_QUERYBUF_TIME32", _IOC_READ|_IOC_WRITE, 0x5609, 0x44 },
+{ "media/v4l2-subdev.h", "V4L2_DEVICE_NOTIFY_EVENT", _IOC_WRITE, 0x7602, 0x80 },
 { "media/v4l2-subdev.h", "V4L2_SUBDEV_IR_RX_NOTIFY", _IOC_WRITE, 0x7600, 0x04 },
 { "media/v4l2-subdev.h", "V4L2_SUBDEV_IR_TX_NOTIFY", _IOC_WRITE, 0x7601, 0x04 },
 { "misc/cxl.h", "CXL_IOCTL_DOWNLOAD_IMAGE", _IOC_WRITE, 0xca0a, 0x40 },
@@ -2472,6 +2525,9 @@
 { "misc/ocxl.h", "OCXL_IOCTL_IRQ_ALLOC", _IOC_READ, 0xca11, 0x08 },
 { "misc/ocxl.h", "OCXL_IOCTL_IRQ_FREE", _IOC_WRITE, 0xca12, 0x08 },
 { "misc/ocxl.h", "OCXL_IOCTL_IRQ_SET_FD", _IOC_WRITE, 0xca13, 0x10 },
+{ "misc/uacce/hisi_qm.h", "UACCE_CMD_QM_SET_QP_CTX", _IOC_READ|_IOC_WRITE, 0x480a, 0x04 },
+{ "misc/uacce/uacce.h", "UACCE_CMD_PUT_Q", _IOC_NONE, 0x5701, 0x00 },
+{ "misc/uacce/uacce.h", "UACCE_CMD_START_Q", _IOC_NONE, 0x5700, 0x00 },
 { "misc/xilinx_sdfec.h", "XSDFEC_ADD_LDPC_CODE_PARAMS", _IOC_WRITE, 0x6605, 0x4a },
 { "misc/xilinx_sdfec.h", "XSDFEC_CLEAR_STATS", _IOC_NONE, 0x660b, 0x00 },
 { "misc/xilinx_sdfec.h", "XSDFEC_GET_CONFIG", _IOC_READ, 0x6606, 0x1c },
@@ -2724,7 +2780,8 @@
 { "sound/asound.h", "SNDRV_TIMER_IOCTL_START", _IOC_NONE, 0x54a0, 0x00 },
 { "sound/asound.h", "SNDRV_TIMER_IOCTL_STATUS", _IOC_READ, 0x5414, 0x58 },
 { "sound/asound.h", "SNDRV_TIMER_IOCTL_STOP", _IOC_NONE, 0x54a1, 0x00 },
-{ "sound/asound.h", "SNDRV_TIMER_IOCTL_TREAD", _IOC_WRITE, 0x5402, 0x04 },
+{ "sound/asound.h", "SNDRV_TIMER_IOCTL_TREAD64", _IOC_WRITE, 0x54a4, 0x04 },
+{ "sound/asound.h", "SNDRV_TIMER_IOCTL_TREAD_OLD", _IOC_WRITE, 0x5402, 0x04 },
 { "sound/asound_fm.h", "SNDRV_DM_FM_IOCTL_CLEAR_PATCHES", _IOC_NONE, 0x4840, 0x00 },
 { "sound/asound_fm.h", "SNDRV_DM_FM_IOCTL_INFO", _IOC_READ, 0x4820, 0x02 },
 { "sound/asound_fm.h", "SNDRV_DM_FM_IOCTL_PLAY_NOTE", _IOC_WRITE, 0x4822, 0x08 },
@@ -2782,6 +2839,10 @@
 { "sound/hdspm.h", "SNDRV_HDSPM_IOCTL_GET_PEAK_RMS", _IOC_READ, 0x4842, 0x906 },
 { "sound/hdspm.h", "SNDRV_HDSPM_IOCTL_GET_STATUS", _IOC_READ, 0x4847, 0x1a },
 { "sound/hdspm.h", "SNDRV_HDSPM_IOCTL_GET_VERSION", _IOC_READ, 0x4848, 0x20 },
+{ "sound/pcm.h", "SNDRV_PCM_IOCTL_STATUS32", _IOC_READ, 0x4120, 0x6c },
+{ "sound/pcm.h", "SNDRV_PCM_IOCTL_STATUS64", _IOC_READ, 0x4120, 0x80 },
+{ "sound/pcm.h", "SNDRV_PCM_IOCTL_STATUS_EXT32", _IOC_READ|_IOC_WRITE, 0x4124, 0x6c },
+{ "sound/pcm.h", "SNDRV_PCM_IOCTL_STATUS_EXT64", _IOC_READ|_IOC_WRITE, 0x4124, 0x80 },
 { "sound/sb16_csp.h", "SNDRV_SB_CSP_IOCTL_INFO", _IOC_READ, 0x4810, 0x26 },
 { "sound/sb16_csp.h", "SNDRV_SB_CSP_IOCTL_LOAD_CODE", _IOC_WRITE, 0x4811, 0x3012 },
 { "sound/sb16_csp.h", "SNDRV_SB_CSP_IOCTL_PAUSE", _IOC_NONE, 0x4815, 0x00 },
@@ -2808,15 +2869,6 @@
 { "staging/android/ashmem.h", "ASHMEM_UNPIN", _IOC_WRITE, 0x7708, 0x08 },
 { "staging/android/ion.h", "ION_IOC_ALLOC", _IOC_READ|_IOC_WRITE, 0x4900, 0x18 },
 { "staging/android/ion.h", "ION_IOC_HEAP_QUERY", _IOC_READ|_IOC_WRITE, 0x4908, 0x18 },
-{ "staging/android/vsoc_shm.h", "VSOC_COND_WAIT", _IOC_READ|_IOC_WRITE, 0xf507, 0x20 },
-{ "staging/android/vsoc_shm.h", "VSOC_COND_WAKE", _IOC_NONE, 0xf508, 0x00 },
-{ "staging/android/vsoc_shm.h", "VSOC_CREATE_FD_SCOPED_PERMISSION", _IOC_WRITE, 0xf500, 0x10 },
-{ "staging/android/vsoc_shm.h", "VSOC_DESCRIBE_REGION", _IOC_READ, 0xf504, 0x3c },
-{ "staging/android/vsoc_shm.h", "VSOC_GET_FD_SCOPED_PERMISSION", _IOC_READ, 0xf501, 0x10 },
-{ "staging/android/vsoc_shm.h", "VSOC_MAYBE_SEND_INTERRUPT_TO_HOST", _IOC_NONE, 0xf502, 0x00 },
-{ "staging/android/vsoc_shm.h", "VSOC_SELF_INTERRUPT", _IOC_NONE, 0xf505, 0x00 },
-{ "staging/android/vsoc_shm.h", "VSOC_SEND_INTERRUPT_TO_HOST", _IOC_NONE, 0xf506, 0x00 },
-{ "staging/android/vsoc_shm.h", "VSOC_WAIT_FOR_INCOMING_INTERRUPT", _IOC_NONE, 0xf503, 0x00 },
 { "video/da8xx-fb.h", "FBIGET_BRIGHTNESS", _IOC_READ, 0x4603, 0x04 },
 { "video/da8xx-fb.h", "FBIGET_COLOR", _IOC_READ, 0x4605, 0x04 },
 { "video/da8xx-fb.h", "FBIOGET_CONTRAST", _IOC_READ, 0x4601, 0x04 },
diff -pruN 5.5-3/linux/32/ioctls_inc_align32.h 5.9-0ubuntu2/linux/32/ioctls_inc_align32.h
--- 5.5-3/linux/32/ioctls_inc_align32.h	2020-01-27 13:21:44.000000000 +0000
+++ 5.9-0ubuntu2/linux/32/ioctls_inc_align32.h	2020-09-23 16:29:35.000000000 +0000
@@ -155,6 +155,7 @@
 { "drm/drm.h", "DRM_IOCTL_MODE_GETCRTC", _IOC_READ|_IOC_WRITE, 0x64a1, 0x68 },
 { "drm/drm.h", "DRM_IOCTL_MODE_GETENCODER", _IOC_READ|_IOC_WRITE, 0x64a6, 0x14 },
 { "drm/drm.h", "DRM_IOCTL_MODE_GETFB", _IOC_READ|_IOC_WRITE, 0x64ad, 0x1c },
+{ "drm/drm.h", "DRM_IOCTL_MODE_GETFB2", _IOC_READ|_IOC_WRITE, 0x64ce, 0x64 },
 { "drm/drm.h", "DRM_IOCTL_MODE_GETGAMMA", _IOC_READ|_IOC_WRITE, 0x64a4, 0x20 },
 { "drm/drm.h", "DRM_IOCTL_MODE_GETPLANE", _IOC_READ|_IOC_WRITE, 0x64b6, 0x20 },
 { "drm/drm.h", "DRM_IOCTL_MODE_GETPLANERESOURCES", _IOC_READ|_IOC_WRITE, 0x64b5, 0x0c },
@@ -268,6 +269,7 @@
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_MADVISE", _IOC_READ|_IOC_WRITE, 0x6466, 0x0c },
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_MMAP", _IOC_READ|_IOC_WRITE, 0x645e, 0x28 },
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_MMAP_GTT", _IOC_READ|_IOC_WRITE, 0x6464, 0x10 },
+{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_MMAP_OFFSET", _IOC_READ|_IOC_WRITE, 0x6464, 0x20 },
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_PIN", _IOC_READ|_IOC_WRITE, 0x6455, 0x18 },
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_PREAD", _IOC_WRITE, 0x645c, 0x20 },
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_PWRITE", _IOC_WRITE, 0x645d, 0x20 },
@@ -330,7 +332,7 @@
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_INFO", _IOC_READ|_IOC_WRITE, 0x6443, 0x18 },
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_MADVISE", _IOC_READ|_IOC_WRITE, 0x6448, 0x0c },
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_NEW", _IOC_READ|_IOC_WRITE, 0x6442, 0x10 },
-{ "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_SUBMIT", _IOC_READ|_IOC_WRITE, 0x6446, 0x28 },
+{ "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_SUBMIT", _IOC_READ|_IOC_WRITE, 0x6446, 0x48 },
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_GET_PARAM", _IOC_READ|_IOC_WRITE, 0x6440, 0x10 },
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_SUBMITQUEUE_CLOSE", _IOC_WRITE, 0x644b, 0x04 },
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_SUBMITQUEUE_NEW", _IOC_READ|_IOC_WRITE, 0x644a, 0x0c },
@@ -695,6 +697,7 @@
 { "linux/btrfs.h", "BTRFS_IOC_SNAP_CREATE", _IOC_WRITE, 0x9401, 0x1000 },
 { "linux/btrfs.h", "BTRFS_IOC_SNAP_CREATE_V2", _IOC_WRITE, 0x9417, 0x1000 },
 { "linux/btrfs.h", "BTRFS_IOC_SNAP_DESTROY", _IOC_WRITE, 0x940f, 0x1000 },
+{ "linux/btrfs.h", "BTRFS_IOC_SNAP_DESTROY_V2", _IOC_WRITE, 0x943f, 0x1000 },
 { "linux/btrfs.h", "BTRFS_IOC_SPACE_INFO", _IOC_READ|_IOC_WRITE, 0x9414, 0x10 },
 { "linux/btrfs.h", "BTRFS_IOC_START_SYNC", _IOC_READ, 0x9418, 0x08 },
 { "linux/btrfs.h", "BTRFS_IOC_SUBVOL_CREATE", _IOC_WRITE, 0x940e, 0x1000 },
@@ -830,7 +833,9 @@
 { "linux/dm-ioctl.h", "DM_TARGET_MSG", _IOC_READ|_IOC_WRITE, 0xfd0e, 0x138 },
 { "linux/dm-ioctl.h", "DM_VERSION", _IOC_READ|_IOC_WRITE, 0xfd00, 0x138 },
 { "linux/dma-buf.h", "DMA_BUF_IOCTL_SYNC", _IOC_WRITE, 0x6200, 0x08 },
-{ "linux/dma-buf.h", "DMA_BUF_SET_NAME", _IOC_WRITE, 0x6201, 0x04 },
+{ "linux/dma-buf.h", "DMA_BUF_SET_NAME_A", _IOC_WRITE, 0x6201, 0x04 },
+{ "linux/dma-buf.h", "DMA_BUF_SET_NAME_B", _IOC_WRITE, 0x6201, 0x08 },
+{ "linux/dma-heap.h", "DMA_HEAP_IOCTL_ALLOC", _IOC_READ|_IOC_WRITE, 0x4800, 0x18 },
 { "linux/dn.h", "OSIOCGNETADDR", _IOC_READ, 0x89e1, 0x04 },
 { "linux/dn.h", "OSIOCSNETADDR", _IOC_WRITE, 0x89e0, 0x04 },
 { "linux/dn.h", "SIOCGNETADDR", _IOC_READ, 0x89e1, 0x04 },
@@ -987,15 +992,21 @@
 { "linux/firewire-cdev.h", "FW_CDEV_IOC_START_ISO", _IOC_WRITE, 0x230a, 0x10 },
 { "linux/firewire-cdev.h", "FW_CDEV_IOC_STOP_ISO", _IOC_WRITE, 0x230b, 0x04 },
 { "linux/fpga-dfl.h", "DFL_FPGA_CHECK_EXTENSION", _IOC_NONE, 0xb601, 0x00 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_FME_ERR_GET_IRQ_NUM", _IOC_READ, 0xb683, 0x04 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_FME_ERR_SET_IRQ", _IOC_WRITE, 0xb684, 0x08 },
 { "linux/fpga-dfl.h", "DFL_FPGA_FME_PORT_ASSIGN", _IOC_WRITE, 0xb682, 0x04 },
 { "linux/fpga-dfl.h", "DFL_FPGA_FME_PORT_PR", _IOC_NONE, 0xb680, 0x00 },
 { "linux/fpga-dfl.h", "DFL_FPGA_FME_PORT_RELEASE", _IOC_WRITE, 0xb681, 0x04 },
 { "linux/fpga-dfl.h", "DFL_FPGA_GET_API_VERSION", _IOC_NONE, 0xb600, 0x00 },
 { "linux/fpga-dfl.h", "DFL_FPGA_PORT_DMA_MAP", _IOC_NONE, 0xb643, 0x00 },
 { "linux/fpga-dfl.h", "DFL_FPGA_PORT_DMA_UNMAP", _IOC_NONE, 0xb644, 0x00 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_ERR_GET_IRQ_NUM", _IOC_READ, 0xb645, 0x04 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_ERR_SET_IRQ", _IOC_WRITE, 0xb646, 0x08 },
 { "linux/fpga-dfl.h", "DFL_FPGA_PORT_GET_INFO", _IOC_NONE, 0xb641, 0x00 },
 { "linux/fpga-dfl.h", "DFL_FPGA_PORT_GET_REGION_INFO", _IOC_NONE, 0xb642, 0x00 },
 { "linux/fpga-dfl.h", "DFL_FPGA_PORT_RESET", _IOC_NONE, 0xb640, 0x00 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_UINT_GET_IRQ_NUM", _IOC_READ, 0xb647, 0x04 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_UINT_SET_IRQ", _IOC_WRITE, 0xb648, 0x08 },
 { "linux/fs.h", "BLKALIGNOFF", _IOC_NONE, 0x127a, 0x00 },
 { "linux/fs.h", "BLKBSZGET", _IOC_READ, 0x1270, 0x04 },
 { "linux/fs.h", "BLKBSZSET", _IOC_WRITE, 0x1271, 0x04 },
@@ -1047,6 +1058,7 @@
 { "linux/fs.h", "FS_IOC_SETVERSION", _IOC_WRITE, 0x7602, 0x04 },
 { "linux/fscrypt.h", "FS_IOC_ADD_ENCRYPTION_KEY", _IOC_READ|_IOC_WRITE, 0x6617, 0x50 },
 { "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_KEY_STATUS", _IOC_READ|_IOC_WRITE, 0x661a, 0x80 },
+{ "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_NONCE", _IOC_READ, 0x661b, 0x10 },
 { "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_POLICY", _IOC_WRITE, 0x6615, 0x0c },
 { "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_POLICY_EX", _IOC_READ|_IOC_WRITE, 0x6616, 0x09 },
 { "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_PWSALT", _IOC_WRITE, 0x6614, 0x10 },
@@ -1092,10 +1104,6 @@
 { "linux/genwqe/genwqe_card.h", "GENWQE_WRITE_REG16", _IOC_WRITE, 0xa523, 0x10 },
 { "linux/genwqe/genwqe_card.h", "GENWQE_WRITE_REG32", _IOC_WRITE, 0xa521, 0x10 },
 { "linux/genwqe/genwqe_card.h", "GENWQE_WRITE_REG64", _IOC_WRITE, 0xa51f, 0x10 },
-{ "linux/gigaset_dev.h", "GIGASET_BRKCHARS", _IOC_WRITE, 0x4702, 0x06 },
-{ "linux/gigaset_dev.h", "GIGASET_CONFIG", _IOC_READ|_IOC_WRITE, 0x4701, 0x04 },
-{ "linux/gigaset_dev.h", "GIGASET_REDIR", _IOC_READ|_IOC_WRITE, 0x4700, 0x04 },
-{ "linux/gigaset_dev.h", "GIGASET_VERSION", _IOC_READ|_IOC_WRITE, 0x4703, 0x10 },
 { "linux/gpio.h", "GPIOHANDLE_GET_LINE_VALUES_IOCTL", _IOC_READ|_IOC_WRITE, 0xb408, 0x40 },
 { "linux/gpio.h", "GPIOHANDLE_SET_CONFIG_IOCTL", _IOC_READ|_IOC_WRITE, 0xb40a, 0x54 },
 { "linux/gpio.h", "GPIOHANDLE_SET_LINE_VALUES_IOCTL", _IOC_READ|_IOC_WRITE, 0xb409, 0x40 },
@@ -1103,6 +1111,8 @@
 { "linux/gpio.h", "GPIO_GET_LINEEVENT_IOCTL", _IOC_READ|_IOC_WRITE, 0xb404, 0x30 },
 { "linux/gpio.h", "GPIO_GET_LINEHANDLE_IOCTL", _IOC_READ|_IOC_WRITE, 0xb403, 0x16c },
 { "linux/gpio.h", "GPIO_GET_LINEINFO_IOCTL", _IOC_READ|_IOC_WRITE, 0xb402, 0x48 },
+{ "linux/gpio.h", "GPIO_GET_LINEINFO_UNWATCH_IOCTL", _IOC_READ|_IOC_WRITE, 0xb40c, 0x04 },
+{ "linux/gpio.h", "GPIO_GET_LINEINFO_WATCH_IOCTL", _IOC_READ|_IOC_WRITE, 0xb40b, 0x48 },
 { "linux/gsmmux.h", "GSMIOC_DISABLE_NET", _IOC_NONE, 0x4703, 0x00 },
 { "linux/gsmmux.h", "GSMIOC_ENABLE_NET", _IOC_WRITE, 0x4702, 0x34 },
 { "linux/gsmmux.h", "GSMIOC_GETCONF", _IOC_READ, 0x4700, 0x4c },
@@ -1346,6 +1356,7 @@
 { "linux/kd.h", "PIO_UNISCRNMAP", 0, 0x4B6A, 0 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_ACQUIRE_VM", _IOC_WRITE, 0x4b15, 0x08 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_ALLOC_MEMORY_OF_GPU", _IOC_READ|_IOC_WRITE, 0x4b16, 0x28 },
+{ "linux/kfd_ioctl.h", "AMDKFD_IOC_ALLOC_QUEUE_GWS", _IOC_READ|_IOC_WRITE, 0x4b1e, 0x10 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_CREATE_EVENT", _IOC_READ|_IOC_WRITE, 0x4b08, 0x20 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_CREATE_QUEUE", _IOC_READ|_IOC_WRITE, 0x4b02, 0x58 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_DBG_ADDRESS_WATCH", _IOC_WRITE, 0x4b0f, 0x10 },
@@ -1370,6 +1381,7 @@
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_SET_MEMORY_POLICY", _IOC_WRITE, 0x4b04, 0x20 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_SET_SCRATCH_BACKING_VA", _IOC_READ|_IOC_WRITE, 0x4b11, 0x10 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_SET_TRAP_HANDLER", _IOC_WRITE, 0x4b13, 0x18 },
+{ "linux/kfd_ioctl.h", "AMDKFD_IOC_SMI_EVENTS", _IOC_READ|_IOC_WRITE, 0x4b1f, 0x08 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_UNMAP_MEMORY_FROM_GPU", _IOC_READ|_IOC_WRITE, 0x4b19, 0x18 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_UPDATE_QUEUE", _IOC_WRITE, 0x4b07, 0x18 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_WAIT_EVENTS", _IOC_READ|_IOC_WRITE, 0x4b0c, 0x18 },
@@ -1403,6 +1415,7 @@
 { "linux/lirc.h", "LIRC_SET_WIDEBAND_RECEIVER", _IOC_WRITE, 0x6923, 0x04 },
 { "linux/loop.h", "LOOP_CHANGE_FD", 0, 0x4C06, 0 },
 { "linux/loop.h", "LOOP_CLR_FD", 0, 0x4C01, 0 },
+{ "linux/loop.h", "LOOP_CONFIGURE", 0, 0x4C0A, 0 },
 { "linux/loop.h", "LOOP_CTL_ADD", 0, 0x4C80, 0 },
 { "linux/loop.h", "LOOP_CTL_GET_FREE", 0, 0x4C82, 0 },
 { "linux/loop.h", "LOOP_CTL_REMOVE", 0, 0x4C81, 0 },
@@ -1547,6 +1560,7 @@
 { "linux/omapfb.h", "OMAPFB_WAITFORGO", _IOC_NONE, 0x4f3c, 0x00 },
 { "linux/omapfb.h", "OMAPFB_WAITFORVSYNC", _IOC_NONE, 0x4f39, 0x00 },
 { "linux/pcitest.h", "PCITEST_BAR", _IOC_NONE, 0x5001, 0x00 },
+{ "linux/pcitest.h", "PCITEST_CLEAR_IRQ", _IOC_NONE, 0x5010, 0x00 },
 { "linux/pcitest.h", "PCITEST_COPY", _IOC_WRITE, 0x5006, 0x04 },
 { "linux/pcitest.h", "PCITEST_GET_IRQTYPE", _IOC_NONE, 0x5009, 0x00 },
 { "linux/pcitest.h", "PCITEST_LEGACY_IRQ", _IOC_NONE, 0x5002, 0x00 },
@@ -1707,6 +1721,8 @@
 { "linux/raw.h", "RAW_GETBIND", _IOC_NONE, 0xac01, 0x00 },
 { "linux/raw.h", "RAW_SETBIND", _IOC_NONE, 0xac00, 0x00 },
 { "linux/reiserfs_fs.h", "REISERFS_IOC_UNPACK", _IOC_WRITE, 0xcd01, 0x04 },
+{ "linux/remoteproc_cdev.h", "RPROC_GET_SHUTDOWN_ON_RELEASE", _IOC_READ, 0xb702, 0x04 },
+{ "linux/remoteproc_cdev.h", "RPROC_SET_SHUTDOWN_ON_RELEASE", _IOC_WRITE, 0xb701, 0x04 },
 { "linux/rfkill.h", "RFKILL_IOCTL_NOINPUT", _IOC_NONE, 0x5201, 0x00 },
 { "linux/rio_cm_cdev.h", "RIO_CM_CHAN_ACCEPT", _IOC_READ|_IOC_WRITE, 0x6307, 0x08 },
 { "linux/rio_cm_cdev.h", "RIO_CM_CHAN_BIND", _IOC_WRITE, 0x6305, 0x08 },
@@ -1784,7 +1800,8 @@
 { "linux/scif_ioctl.h", "SCIF_VREADFROM", _IOC_READ|_IOC_WRITE, 0x730c, 0x24 },
 { "linux/scif_ioctl.h", "SCIF_VWRITETO", _IOC_READ|_IOC_WRITE, 0x730d, 0x24 },
 { "linux/scif_ioctl.h", "SCIF_WRITETO", _IOC_READ|_IOC_WRITE, 0x730b, 0x24 },
-{ "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_ID_VALID", _IOC_READ, 0x2102, 0x08 },
+{ "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_ADDFD", _IOC_WRITE, 0x2103, 0x18 },
+{ "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_ID_VALID", _IOC_WRITE, 0x2102, 0x08 },
 { "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_RECV", _IOC_READ|_IOC_WRITE, 0x2100, 0x50 },
 { "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_SEND", _IOC_READ|_IOC_WRITE, 0x2101, 0x18 },
 { "linux/sed-opal.h", "IOC_OPAL_ACTIVATE_LSP", _IOC_WRITE, 0x70df, 0x118 },
@@ -2100,6 +2117,22 @@
 { "linux/usb/iowarrior.h", "IOW_GETINFO", _IOC_READ, 0xc003, 0x28 },
 { "linux/usb/iowarrior.h", "IOW_READ", _IOC_WRITE, 0xc002, 0x04 },
 { "linux/usb/iowarrior.h", "IOW_WRITE", _IOC_WRITE, 0xc001, 0x04 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_CONFIGURE", _IOC_NONE, 0x5509, 0x00 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP0_READ", _IOC_READ|_IOC_WRITE, 0x5504, 0x08 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP0_STALL", _IOC_NONE, 0x550c, 0x00 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP0_WRITE", _IOC_WRITE, 0x5503, 0x08 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EPS_INFO", _IOC_READ, 0x550b, 0x3c0 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_CLEAR_HALT", _IOC_WRITE, 0x550e, 0x04 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_DISABLE", _IOC_WRITE, 0x5506, 0x04 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_ENABLE", _IOC_WRITE, 0x5505, 0x09 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_READ", _IOC_READ|_IOC_WRITE, 0x5508, 0x08 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_SET_HALT", _IOC_WRITE, 0x550d, 0x04 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_SET_WEDGE", _IOC_WRITE, 0x550f, 0x04 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_WRITE", _IOC_WRITE, 0x5507, 0x08 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EVENT_FETCH", _IOC_READ, 0x5502, 0x08 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_INIT", _IOC_WRITE, 0x5500, 0x101 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_RUN", _IOC_NONE, 0x5501, 0x00 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_VBUS_DRAW", _IOC_WRITE, 0x550a, 0x04 },
 { "linux/usb/tmc.h", "USBTMC488_IOCTL_GET_CAPS", _IOC_READ, 0x5b11, 0x01 },
 { "linux/usb/tmc.h", "USBTMC488_IOCTL_GOTO_LOCAL", _IOC_NONE, 0x5b14, 0x00 },
 { "linux/usb/tmc.h", "USBTMC488_IOCTL_LOCAL_LOCKOUT", _IOC_NONE, 0x5b15, 0x00 },
@@ -2169,6 +2202,7 @@
 { "linux/userfaultfd.h", "UFFDIO_REGISTER", _IOC_READ|_IOC_WRITE, 0xaa00, 0x20 },
 { "linux/userfaultfd.h", "UFFDIO_UNREGISTER", _IOC_READ, 0xaa01, 0x10 },
 { "linux/userfaultfd.h", "UFFDIO_WAKE", _IOC_READ, 0xaa02, 0x10 },
+{ "linux/userfaultfd.h", "UFFDIO_WRITEPROTECT", _IOC_READ|_IOC_WRITE, 0xaa06, 0x18 },
 { "linux/userfaultfd.h", "UFFDIO_ZEROPAGE", _IOC_READ|_IOC_WRITE, 0xaa04, 0x20 },
 { "linux/uvcvideo.h", "UVCIOC_CTRL_MAP", _IOC_READ|_IOC_WRITE, 0x7520, 0x58 },
 { "linux/uvcvideo.h", "UVCIOC_CTRL_QUERY", _IOC_READ|_IOC_WRITE, 0x7521, 0x0c },
@@ -2179,10 +2213,12 @@
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_G_FMT", _IOC_READ|_IOC_WRITE, 0x5604, 0x58 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_G_FRAME_INTERVAL", _IOC_READ|_IOC_WRITE, 0x5615, 0x30 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_G_SELECTION", _IOC_READ|_IOC_WRITE, 0x563d, 0x40 },
+{ "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_QUERYCAP", _IOC_READ, 0x5600, 0x40 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_S_CROP", _IOC_READ|_IOC_WRITE, 0x563c, 0x38 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_S_FMT", _IOC_READ|_IOC_WRITE, 0x5605, 0x58 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_S_FRAME_INTERVAL", _IOC_READ|_IOC_WRITE, 0x5616, 0x30 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_S_SELECTION", _IOC_READ|_IOC_WRITE, 0x563e, 0x40 },
+{ "linux/vboxguest.h", "VBG_IOCTL_ACQUIRE_GUEST_CAPABILITIES", _IOC_READ|_IOC_WRITE, 0x560d, 0x24 },
 { "linux/vboxguest.h", "VBG_IOCTL_CHANGE_FILTER_MASK", _IOC_READ|_IOC_WRITE, 0x560c, 0x20 },
 { "linux/vboxguest.h", "VBG_IOCTL_CHANGE_GUEST_CAPABILITIES", _IOC_READ|_IOC_WRITE, 0x560e, 0x20 },
 { "linux/vboxguest.h", "VBG_IOCTL_CHECK_BALLOON", _IOC_READ|_IOC_WRITE, 0x5611, 0x20 },
@@ -2190,10 +2226,11 @@
 { "linux/vboxguest.h", "VBG_IOCTL_HGCM_CONNECT", _IOC_READ|_IOC_WRITE, 0x5604, 0x9c },
 { "linux/vboxguest.h", "VBG_IOCTL_HGCM_DISCONNECT", _IOC_READ|_IOC_WRITE, 0x5605, 0x1c },
 { "linux/vboxguest.h", "VBG_IOCTL_INTERRUPT_ALL_WAIT_FOR_EVENTS", _IOC_READ|_IOC_WRITE, 0x560b, 0x18 },
-{ "linux/vboxguest.h", "VBG_IOCTL_VMMDEV_REQUEST_BIG", _IOC_READ|_IOC_WRITE, 0x5603, 0x00 },
+{ "linux/vboxguest.h", "VBG_IOCTL_VMMDEV_REQUEST_BIG", _IOC_NONE, 0x5603, 0x00 },
 { "linux/vboxguest.h", "VBG_IOCTL_WAIT_FOR_EVENTS", _IOC_READ|_IOC_WRITE, 0x560a, 0x20 },
 { "linux/vboxguest.h", "VBG_IOCTL_WRITE_CORE_DUMP", _IOC_READ|_IOC_WRITE, 0x5613, 0x1c },
 { "linux/vfio.h", "VFIO_CHECK_EXTENSION", _IOC_NONE, 0x3b65, 0x00 },
+{ "linux/vfio.h", "VFIO_DEVICE_FEATURE", _IOC_NONE, 0x3b75, 0x00 },
 { "linux/vfio.h", "VFIO_DEVICE_GET_GFX_DMABUF", _IOC_NONE, 0x3b73, 0x00 },
 { "linux/vfio.h", "VFIO_DEVICE_GET_INFO", _IOC_NONE, 0x3b6b, 0x00 },
 { "linux/vfio.h", "VFIO_DEVICE_GET_IRQ_INFO", _IOC_NONE, 0x3b6d, 0x00 },
@@ -2210,6 +2247,7 @@
 { "linux/vfio.h", "VFIO_GROUP_GET_STATUS", _IOC_NONE, 0x3b67, 0x00 },
 { "linux/vfio.h", "VFIO_GROUP_SET_CONTAINER", _IOC_NONE, 0x3b68, 0x00 },
 { "linux/vfio.h", "VFIO_GROUP_UNSET_CONTAINER", _IOC_NONE, 0x3b69, 0x00 },
+{ "linux/vfio.h", "VFIO_IOMMU_DIRTY_PAGES", _IOC_NONE, 0x3b75, 0x00 },
 { "linux/vfio.h", "VFIO_IOMMU_DISABLE", _IOC_NONE, 0x3b74, 0x00 },
 { "linux/vfio.h", "VFIO_IOMMU_ENABLE", _IOC_NONE, 0x3b73, 0x00 },
 { "linux/vfio.h", "VFIO_IOMMU_GET_INFO", _IOC_NONE, 0x3b70, 0x00 },
@@ -2247,6 +2285,14 @@
 { "linux/vhost.h", "VHOST_SET_VRING_ERR", _IOC_WRITE, 0xaf22, 0x08 },
 { "linux/vhost.h", "VHOST_SET_VRING_KICK", _IOC_WRITE, 0xaf20, 0x08 },
 { "linux/vhost.h", "VHOST_SET_VRING_NUM", _IOC_WRITE, 0xaf10, 0x08 },
+{ "linux/vhost.h", "VHOST_VDPA_GET_CONFIG", _IOC_READ, 0xaf73, 0x08 },
+{ "linux/vhost.h", "VHOST_VDPA_GET_DEVICE_ID", _IOC_READ, 0xaf70, 0x04 },
+{ "linux/vhost.h", "VHOST_VDPA_GET_STATUS", _IOC_READ, 0xaf71, 0x01 },
+{ "linux/vhost.h", "VHOST_VDPA_GET_VRING_NUM", _IOC_READ, 0xaf76, 0x02 },
+{ "linux/vhost.h", "VHOST_VDPA_SET_CONFIG", _IOC_WRITE, 0xaf74, 0x08 },
+{ "linux/vhost.h", "VHOST_VDPA_SET_CONFIG_CALL", _IOC_WRITE, 0xaf77, 0x04 },
+{ "linux/vhost.h", "VHOST_VDPA_SET_STATUS", _IOC_WRITE, 0xaf72, 0x01 },
+{ "linux/vhost.h", "VHOST_VDPA_SET_VRING_ENABLE", _IOC_WRITE, 0xaf75, 0x08 },
 { "linux/vhost.h", "VHOST_VSOCK_SET_GUEST_CID", _IOC_WRITE, 0xaf60, 0x08 },
 { "linux/vhost.h", "VHOST_VSOCK_SET_RUNNING", _IOC_WRITE, 0xaf61, 0x04 },
 { "linux/videodev2.h", "VIDIOC_CREATE_BUFS", _IOC_READ|_IOC_WRITE, 0x565c, 0xf8 },
@@ -2255,8 +2301,8 @@
 { "linux/videodev2.h", "VIDIOC_DBG_G_REGISTER", _IOC_READ|_IOC_WRITE, 0x5650, 0x38 },
 { "linux/videodev2.h", "VIDIOC_DBG_S_REGISTER", _IOC_WRITE, 0x564f, 0x38 },
 { "linux/videodev2.h", "VIDIOC_DECODER_CMD", _IOC_READ|_IOC_WRITE, 0x5660, 0x48 },
-{ "linux/videodev2.h", "VIDIOC_DQBUF", _IOC_READ|_IOC_WRITE, 0x5611, 0x44 },
-{ "linux/videodev2.h", "VIDIOC_DQEVENT", _IOC_READ, 0x5659, 0x78 },
+{ "linux/videodev2.h", "VIDIOC_DQBUF", _IOC_READ|_IOC_WRITE, 0x5611, 0x4c },
+{ "linux/videodev2.h", "VIDIOC_DQEVENT", _IOC_READ, 0x5659, 0x80 },
 { "linux/videodev2.h", "VIDIOC_DV_TIMINGS_CAP", _IOC_READ|_IOC_WRITE, 0x5664, 0x90 },
 { "linux/videodev2.h", "VIDIOC_ENCODER_CMD", _IOC_READ|_IOC_WRITE, 0x564d, 0x28 },
 { "linux/videodev2.h", "VIDIOC_ENUMAUDIO", _IOC_READ|_IOC_WRITE, 0x5641, 0x34 },
@@ -2293,9 +2339,9 @@
 { "linux/videodev2.h", "VIDIOC_G_TUNER", _IOC_READ|_IOC_WRITE, 0x561d, 0x54 },
 { "linux/videodev2.h", "VIDIOC_LOG_STATUS", _IOC_NONE, 0x5646, 0x00 },
 { "linux/videodev2.h", "VIDIOC_OVERLAY", _IOC_WRITE, 0x560e, 0x04 },
-{ "linux/videodev2.h", "VIDIOC_PREPARE_BUF", _IOC_READ|_IOC_WRITE, 0x565d, 0x44 },
-{ "linux/videodev2.h", "VIDIOC_QBUF", _IOC_READ|_IOC_WRITE, 0x560f, 0x44 },
-{ "linux/videodev2.h", "VIDIOC_QUERYBUF", _IOC_READ|_IOC_WRITE, 0x5609, 0x44 },
+{ "linux/videodev2.h", "VIDIOC_PREPARE_BUF", _IOC_READ|_IOC_WRITE, 0x565d, 0x4c },
+{ "linux/videodev2.h", "VIDIOC_QBUF", _IOC_READ|_IOC_WRITE, 0x560f, 0x4c },
+{ "linux/videodev2.h", "VIDIOC_QUERYBUF", _IOC_READ|_IOC_WRITE, 0x5609, 0x4c },
 { "linux/videodev2.h", "VIDIOC_QUERYCAP", _IOC_READ, 0x5600, 0x68 },
 { "linux/videodev2.h", "VIDIOC_QUERYCTRL", _IOC_READ|_IOC_WRITE, 0x5624, 0x44 },
 { "linux/videodev2.h", "VIDIOC_QUERYMENU", _IOC_READ|_IOC_WRITE, 0x5625, 0x2c },
@@ -2369,6 +2415,8 @@
 { "linux/vt.h", "VT_WAITACTIVE", 0, 0x5607, 0 },
 { "linux/vt.h", "VT_WAITEVENT", 0, 0x560E, 0 },
 { "linux/vtpm_proxy.h", "VTPM_PROXY_IOC_NEW_DEV", _IOC_READ|_IOC_WRITE, 0xa100, 0x14 },
+{ "linux/watch_queue.h", "IOC_WATCH_QUEUE_SET_FILTER", _IOC_NONE, 0x5761, 0x00 },
+{ "linux/watch_queue.h", "IOC_WATCH_QUEUE_SET_SIZE", _IOC_NONE, 0x5760, 0x00 },
 { "linux/watchdog.h", "WDIOC_GETBOOTSTATUS", _IOC_READ, 0x5702, 0x04 },
 { "linux/watchdog.h", "WDIOC_GETPRETIMEOUT", _IOC_READ, 0x5709, 0x04 },
 { "linux/watchdog.h", "WDIOC_GETSTATUS", _IOC_READ, 0x5701, 0x04 },
@@ -2444,7 +2492,12 @@
 { "media/i2c/saa6588.h", "SAA6588_CMD_READ", _IOC_READ, 0x5203, 0x04 },
 { "media/v4l2-common.h", "TUNER_SET_CONFIG", _IOC_WRITE, 0x645c, 0x08 },
 { "media/v4l2-common.h", "VIDIOC_INT_RESET", _IOC_WRITE, 0x6466, 0x04 },
-{ "media/v4l2-subdev.h", "V4L2_DEVICE_NOTIFY_EVENT", _IOC_WRITE, 0x7602, 0x78 },
+{ "media/v4l2-ioctl.h", "VIDIOC_DQBUF_TIME32", _IOC_READ|_IOC_WRITE, 0x5611, 0x44 },
+{ "media/v4l2-ioctl.h", "VIDIOC_DQEVENT_TIME32", _IOC_READ, 0x5659, 0x78 },
+{ "media/v4l2-ioctl.h", "VIDIOC_PREPARE_BUF_TIME32", _IOC_READ|_IOC_WRITE, 0x565d, 0x44 },
+{ "media/v4l2-ioctl.h", "VIDIOC_QBUF_TIME32", _IOC_READ|_IOC_WRITE, 0x560f, 0x44 },
+{ "media/v4l2-ioctl.h", "VIDIOC_QUERYBUF_TIME32", _IOC_READ|_IOC_WRITE, 0x5609, 0x44 },
+{ "media/v4l2-subdev.h", "V4L2_DEVICE_NOTIFY_EVENT", _IOC_WRITE, 0x7602, 0x80 },
 { "media/v4l2-subdev.h", "V4L2_SUBDEV_IR_RX_NOTIFY", _IOC_WRITE, 0x7600, 0x04 },
 { "media/v4l2-subdev.h", "V4L2_SUBDEV_IR_TX_NOTIFY", _IOC_WRITE, 0x7601, 0x04 },
 { "misc/cxl.h", "CXL_IOCTL_DOWNLOAD_IMAGE", _IOC_WRITE, 0xca0a, 0x40 },
@@ -2472,6 +2525,9 @@
 { "misc/ocxl.h", "OCXL_IOCTL_IRQ_ALLOC", _IOC_READ, 0xca11, 0x08 },
 { "misc/ocxl.h", "OCXL_IOCTL_IRQ_FREE", _IOC_WRITE, 0xca12, 0x08 },
 { "misc/ocxl.h", "OCXL_IOCTL_IRQ_SET_FD", _IOC_WRITE, 0xca13, 0x10 },
+{ "misc/uacce/hisi_qm.h", "UACCE_CMD_QM_SET_QP_CTX", _IOC_READ|_IOC_WRITE, 0x480a, 0x04 },
+{ "misc/uacce/uacce.h", "UACCE_CMD_PUT_Q", _IOC_NONE, 0x5701, 0x00 },
+{ "misc/uacce/uacce.h", "UACCE_CMD_START_Q", _IOC_NONE, 0x5700, 0x00 },
 { "misc/xilinx_sdfec.h", "XSDFEC_ADD_LDPC_CODE_PARAMS", _IOC_WRITE, 0x6605, 0x4c },
 { "misc/xilinx_sdfec.h", "XSDFEC_CLEAR_STATS", _IOC_NONE, 0x660b, 0x00 },
 { "misc/xilinx_sdfec.h", "XSDFEC_GET_CONFIG", _IOC_READ, 0x6606, 0x1c },
@@ -2724,7 +2780,8 @@
 { "sound/asound.h", "SNDRV_TIMER_IOCTL_START", _IOC_NONE, 0x54a0, 0x00 },
 { "sound/asound.h", "SNDRV_TIMER_IOCTL_STATUS", _IOC_READ, 0x5414, 0x58 },
 { "sound/asound.h", "SNDRV_TIMER_IOCTL_STOP", _IOC_NONE, 0x54a1, 0x00 },
-{ "sound/asound.h", "SNDRV_TIMER_IOCTL_TREAD", _IOC_WRITE, 0x5402, 0x04 },
+{ "sound/asound.h", "SNDRV_TIMER_IOCTL_TREAD64", _IOC_WRITE, 0x54a4, 0x04 },
+{ "sound/asound.h", "SNDRV_TIMER_IOCTL_TREAD_OLD", _IOC_WRITE, 0x5402, 0x04 },
 { "sound/asound_fm.h", "SNDRV_DM_FM_IOCTL_CLEAR_PATCHES", _IOC_NONE, 0x4840, 0x00 },
 { "sound/asound_fm.h", "SNDRV_DM_FM_IOCTL_INFO", _IOC_READ, 0x4820, 0x02 },
 { "sound/asound_fm.h", "SNDRV_DM_FM_IOCTL_PLAY_NOTE", _IOC_WRITE, 0x4822, 0x0c },
@@ -2782,6 +2839,10 @@
 { "sound/hdspm.h", "SNDRV_HDSPM_IOCTL_GET_PEAK_RMS", _IOC_READ, 0x4842, 0x908 },
 { "sound/hdspm.h", "SNDRV_HDSPM_IOCTL_GET_STATUS", _IOC_READ, 0x4847, 0x1c },
 { "sound/hdspm.h", "SNDRV_HDSPM_IOCTL_GET_VERSION", _IOC_READ, 0x4848, 0x24 },
+{ "sound/pcm.h", "SNDRV_PCM_IOCTL_STATUS32", _IOC_READ, 0x4120, 0x6c },
+{ "sound/pcm.h", "SNDRV_PCM_IOCTL_STATUS64", _IOC_READ, 0x4120, 0x80 },
+{ "sound/pcm.h", "SNDRV_PCM_IOCTL_STATUS_EXT32", _IOC_READ|_IOC_WRITE, 0x4124, 0x6c },
+{ "sound/pcm.h", "SNDRV_PCM_IOCTL_STATUS_EXT64", _IOC_READ|_IOC_WRITE, 0x4124, 0x80 },
 { "sound/sb16_csp.h", "SNDRV_SB_CSP_IOCTL_INFO", _IOC_READ, 0x4810, 0x28 },
 { "sound/sb16_csp.h", "SNDRV_SB_CSP_IOCTL_LOAD_CODE", _IOC_WRITE, 0x4811, 0x3012 },
 { "sound/sb16_csp.h", "SNDRV_SB_CSP_IOCTL_PAUSE", _IOC_NONE, 0x4815, 0x00 },
@@ -2808,15 +2869,6 @@
 { "staging/android/ashmem.h", "ASHMEM_UNPIN", _IOC_WRITE, 0x7708, 0x08 },
 { "staging/android/ion.h", "ION_IOC_ALLOC", _IOC_READ|_IOC_WRITE, 0x4900, 0x18 },
 { "staging/android/ion.h", "ION_IOC_HEAP_QUERY", _IOC_READ|_IOC_WRITE, 0x4908, 0x18 },
-{ "staging/android/vsoc_shm.h", "VSOC_COND_WAIT", _IOC_READ|_IOC_WRITE, 0xf507, 0x20 },
-{ "staging/android/vsoc_shm.h", "VSOC_COND_WAKE", _IOC_NONE, 0xf508, 0x00 },
-{ "staging/android/vsoc_shm.h", "VSOC_CREATE_FD_SCOPED_PERMISSION", _IOC_WRITE, 0xf500, 0x10 },
-{ "staging/android/vsoc_shm.h", "VSOC_DESCRIBE_REGION", _IOC_READ, 0xf504, 0x3c },
-{ "staging/android/vsoc_shm.h", "VSOC_GET_FD_SCOPED_PERMISSION", _IOC_READ, 0xf501, 0x10 },
-{ "staging/android/vsoc_shm.h", "VSOC_MAYBE_SEND_INTERRUPT_TO_HOST", _IOC_NONE, 0xf502, 0x00 },
-{ "staging/android/vsoc_shm.h", "VSOC_SELF_INTERRUPT", _IOC_NONE, 0xf505, 0x00 },
-{ "staging/android/vsoc_shm.h", "VSOC_SEND_INTERRUPT_TO_HOST", _IOC_NONE, 0xf506, 0x00 },
-{ "staging/android/vsoc_shm.h", "VSOC_WAIT_FOR_INCOMING_INTERRUPT", _IOC_NONE, 0xf503, 0x00 },
 { "video/da8xx-fb.h", "FBIGET_BRIGHTNESS", _IOC_READ, 0x4603, 0x04 },
 { "video/da8xx-fb.h", "FBIGET_COLOR", _IOC_READ, 0x4605, 0x04 },
 { "video/da8xx-fb.h", "FBIOGET_CONTRAST", _IOC_READ, 0x4601, 0x04 },
diff -pruN 5.5-3/linux/32/ioctls_inc_align64.h 5.9-0ubuntu2/linux/32/ioctls_inc_align64.h
--- 5.5-3/linux/32/ioctls_inc_align64.h	2020-01-27 13:21:44.000000000 +0000
+++ 5.9-0ubuntu2/linux/32/ioctls_inc_align64.h	2020-09-23 16:29:35.000000000 +0000
@@ -155,6 +155,7 @@
 { "drm/drm.h", "DRM_IOCTL_MODE_GETCRTC", _IOC_READ|_IOC_WRITE, 0x64a1, 0x68 },
 { "drm/drm.h", "DRM_IOCTL_MODE_GETENCODER", _IOC_READ|_IOC_WRITE, 0x64a6, 0x14 },
 { "drm/drm.h", "DRM_IOCTL_MODE_GETFB", _IOC_READ|_IOC_WRITE, 0x64ad, 0x1c },
+{ "drm/drm.h", "DRM_IOCTL_MODE_GETFB2", _IOC_READ|_IOC_WRITE, 0x64ce, 0x68 },
 { "drm/drm.h", "DRM_IOCTL_MODE_GETGAMMA", _IOC_READ|_IOC_WRITE, 0x64a4, 0x20 },
 { "drm/drm.h", "DRM_IOCTL_MODE_GETPLANE", _IOC_READ|_IOC_WRITE, 0x64b6, 0x20 },
 { "drm/drm.h", "DRM_IOCTL_MODE_GETPLANERESOURCES", _IOC_READ|_IOC_WRITE, 0x64b5, 0x10 },
@@ -268,6 +269,7 @@
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_MADVISE", _IOC_READ|_IOC_WRITE, 0x6466, 0x0c },
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_MMAP", _IOC_READ|_IOC_WRITE, 0x645e, 0x28 },
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_MMAP_GTT", _IOC_READ|_IOC_WRITE, 0x6464, 0x10 },
+{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_MMAP_OFFSET", _IOC_READ|_IOC_WRITE, 0x6464, 0x20 },
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_PIN", _IOC_READ|_IOC_WRITE, 0x6455, 0x18 },
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_PREAD", _IOC_WRITE, 0x645c, 0x20 },
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_PWRITE", _IOC_WRITE, 0x645d, 0x20 },
@@ -330,7 +332,7 @@
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_INFO", _IOC_READ|_IOC_WRITE, 0x6443, 0x18 },
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_MADVISE", _IOC_READ|_IOC_WRITE, 0x6448, 0x0c },
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_NEW", _IOC_READ|_IOC_WRITE, 0x6442, 0x10 },
-{ "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_SUBMIT", _IOC_READ|_IOC_WRITE, 0x6446, 0x28 },
+{ "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_SUBMIT", _IOC_READ|_IOC_WRITE, 0x6446, 0x48 },
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_GET_PARAM", _IOC_READ|_IOC_WRITE, 0x6440, 0x10 },
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_SUBMITQUEUE_CLOSE", _IOC_WRITE, 0x644b, 0x04 },
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_SUBMITQUEUE_NEW", _IOC_READ|_IOC_WRITE, 0x644a, 0x0c },
@@ -695,6 +697,7 @@
 { "linux/btrfs.h", "BTRFS_IOC_SNAP_CREATE", _IOC_WRITE, 0x9401, 0x1000 },
 { "linux/btrfs.h", "BTRFS_IOC_SNAP_CREATE_V2", _IOC_WRITE, 0x9417, 0x1000 },
 { "linux/btrfs.h", "BTRFS_IOC_SNAP_DESTROY", _IOC_WRITE, 0x940f, 0x1000 },
+{ "linux/btrfs.h", "BTRFS_IOC_SNAP_DESTROY_V2", _IOC_WRITE, 0x943f, 0x1000 },
 { "linux/btrfs.h", "BTRFS_IOC_SPACE_INFO", _IOC_READ|_IOC_WRITE, 0x9414, 0x10 },
 { "linux/btrfs.h", "BTRFS_IOC_START_SYNC", _IOC_READ, 0x9418, 0x08 },
 { "linux/btrfs.h", "BTRFS_IOC_SUBVOL_CREATE", _IOC_WRITE, 0x940e, 0x1000 },
@@ -830,7 +833,9 @@
 { "linux/dm-ioctl.h", "DM_TARGET_MSG", _IOC_READ|_IOC_WRITE, 0xfd0e, 0x138 },
 { "linux/dm-ioctl.h", "DM_VERSION", _IOC_READ|_IOC_WRITE, 0xfd00, 0x138 },
 { "linux/dma-buf.h", "DMA_BUF_IOCTL_SYNC", _IOC_WRITE, 0x6200, 0x08 },
-{ "linux/dma-buf.h", "DMA_BUF_SET_NAME", _IOC_WRITE, 0x6201, 0x04 },
+{ "linux/dma-buf.h", "DMA_BUF_SET_NAME_A", _IOC_WRITE, 0x6201, 0x04 },
+{ "linux/dma-buf.h", "DMA_BUF_SET_NAME_B", _IOC_WRITE, 0x6201, 0x08 },
+{ "linux/dma-heap.h", "DMA_HEAP_IOCTL_ALLOC", _IOC_READ|_IOC_WRITE, 0x4800, 0x18 },
 { "linux/dn.h", "OSIOCGNETADDR", _IOC_READ, 0x89e1, 0x04 },
 { "linux/dn.h", "OSIOCSNETADDR", _IOC_WRITE, 0x89e0, 0x04 },
 { "linux/dn.h", "SIOCGNETADDR", _IOC_READ, 0x89e1, 0x04 },
@@ -987,15 +992,21 @@
 { "linux/firewire-cdev.h", "FW_CDEV_IOC_START_ISO", _IOC_WRITE, 0x230a, 0x10 },
 { "linux/firewire-cdev.h", "FW_CDEV_IOC_STOP_ISO", _IOC_WRITE, 0x230b, 0x04 },
 { "linux/fpga-dfl.h", "DFL_FPGA_CHECK_EXTENSION", _IOC_NONE, 0xb601, 0x00 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_FME_ERR_GET_IRQ_NUM", _IOC_READ, 0xb683, 0x04 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_FME_ERR_SET_IRQ", _IOC_WRITE, 0xb684, 0x08 },
 { "linux/fpga-dfl.h", "DFL_FPGA_FME_PORT_ASSIGN", _IOC_WRITE, 0xb682, 0x04 },
 { "linux/fpga-dfl.h", "DFL_FPGA_FME_PORT_PR", _IOC_NONE, 0xb680, 0x00 },
 { "linux/fpga-dfl.h", "DFL_FPGA_FME_PORT_RELEASE", _IOC_WRITE, 0xb681, 0x04 },
 { "linux/fpga-dfl.h", "DFL_FPGA_GET_API_VERSION", _IOC_NONE, 0xb600, 0x00 },
 { "linux/fpga-dfl.h", "DFL_FPGA_PORT_DMA_MAP", _IOC_NONE, 0xb643, 0x00 },
 { "linux/fpga-dfl.h", "DFL_FPGA_PORT_DMA_UNMAP", _IOC_NONE, 0xb644, 0x00 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_ERR_GET_IRQ_NUM", _IOC_READ, 0xb645, 0x04 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_ERR_SET_IRQ", _IOC_WRITE, 0xb646, 0x08 },
 { "linux/fpga-dfl.h", "DFL_FPGA_PORT_GET_INFO", _IOC_NONE, 0xb641, 0x00 },
 { "linux/fpga-dfl.h", "DFL_FPGA_PORT_GET_REGION_INFO", _IOC_NONE, 0xb642, 0x00 },
 { "linux/fpga-dfl.h", "DFL_FPGA_PORT_RESET", _IOC_NONE, 0xb640, 0x00 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_UINT_GET_IRQ_NUM", _IOC_READ, 0xb647, 0x04 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_UINT_SET_IRQ", _IOC_WRITE, 0xb648, 0x08 },
 { "linux/fs.h", "BLKALIGNOFF", _IOC_NONE, 0x127a, 0x00 },
 { "linux/fs.h", "BLKBSZGET", _IOC_READ, 0x1270, 0x04 },
 { "linux/fs.h", "BLKBSZSET", _IOC_WRITE, 0x1271, 0x04 },
@@ -1047,6 +1058,7 @@
 { "linux/fs.h", "FS_IOC_SETVERSION", _IOC_WRITE, 0x7602, 0x04 },
 { "linux/fscrypt.h", "FS_IOC_ADD_ENCRYPTION_KEY", _IOC_READ|_IOC_WRITE, 0x6617, 0x50 },
 { "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_KEY_STATUS", _IOC_READ|_IOC_WRITE, 0x661a, 0x80 },
+{ "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_NONCE", _IOC_READ, 0x661b, 0x10 },
 { "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_POLICY", _IOC_WRITE, 0x6615, 0x0c },
 { "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_POLICY_EX", _IOC_READ|_IOC_WRITE, 0x6616, 0x09 },
 { "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_PWSALT", _IOC_WRITE, 0x6614, 0x10 },
@@ -1092,10 +1104,6 @@
 { "linux/genwqe/genwqe_card.h", "GENWQE_WRITE_REG16", _IOC_WRITE, 0xa523, 0x10 },
 { "linux/genwqe/genwqe_card.h", "GENWQE_WRITE_REG32", _IOC_WRITE, 0xa521, 0x10 },
 { "linux/genwqe/genwqe_card.h", "GENWQE_WRITE_REG64", _IOC_WRITE, 0xa51f, 0x10 },
-{ "linux/gigaset_dev.h", "GIGASET_BRKCHARS", _IOC_WRITE, 0x4702, 0x06 },
-{ "linux/gigaset_dev.h", "GIGASET_CONFIG", _IOC_READ|_IOC_WRITE, 0x4701, 0x04 },
-{ "linux/gigaset_dev.h", "GIGASET_REDIR", _IOC_READ|_IOC_WRITE, 0x4700, 0x04 },
-{ "linux/gigaset_dev.h", "GIGASET_VERSION", _IOC_READ|_IOC_WRITE, 0x4703, 0x10 },
 { "linux/gpio.h", "GPIOHANDLE_GET_LINE_VALUES_IOCTL", _IOC_READ|_IOC_WRITE, 0xb408, 0x40 },
 { "linux/gpio.h", "GPIOHANDLE_SET_CONFIG_IOCTL", _IOC_READ|_IOC_WRITE, 0xb40a, 0x54 },
 { "linux/gpio.h", "GPIOHANDLE_SET_LINE_VALUES_IOCTL", _IOC_READ|_IOC_WRITE, 0xb409, 0x40 },
@@ -1103,6 +1111,8 @@
 { "linux/gpio.h", "GPIO_GET_LINEEVENT_IOCTL", _IOC_READ|_IOC_WRITE, 0xb404, 0x30 },
 { "linux/gpio.h", "GPIO_GET_LINEHANDLE_IOCTL", _IOC_READ|_IOC_WRITE, 0xb403, 0x16c },
 { "linux/gpio.h", "GPIO_GET_LINEINFO_IOCTL", _IOC_READ|_IOC_WRITE, 0xb402, 0x48 },
+{ "linux/gpio.h", "GPIO_GET_LINEINFO_UNWATCH_IOCTL", _IOC_READ|_IOC_WRITE, 0xb40c, 0x04 },
+{ "linux/gpio.h", "GPIO_GET_LINEINFO_WATCH_IOCTL", _IOC_READ|_IOC_WRITE, 0xb40b, 0x48 },
 { "linux/gsmmux.h", "GSMIOC_DISABLE_NET", _IOC_NONE, 0x4703, 0x00 },
 { "linux/gsmmux.h", "GSMIOC_ENABLE_NET", _IOC_WRITE, 0x4702, 0x34 },
 { "linux/gsmmux.h", "GSMIOC_GETCONF", _IOC_READ, 0x4700, 0x4c },
@@ -1346,6 +1356,7 @@
 { "linux/kd.h", "PIO_UNISCRNMAP", 0, 0x4B6A, 0 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_ACQUIRE_VM", _IOC_WRITE, 0x4b15, 0x08 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_ALLOC_MEMORY_OF_GPU", _IOC_READ|_IOC_WRITE, 0x4b16, 0x28 },
+{ "linux/kfd_ioctl.h", "AMDKFD_IOC_ALLOC_QUEUE_GWS", _IOC_READ|_IOC_WRITE, 0x4b1e, 0x10 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_CREATE_EVENT", _IOC_READ|_IOC_WRITE, 0x4b08, 0x20 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_CREATE_QUEUE", _IOC_READ|_IOC_WRITE, 0x4b02, 0x58 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_DBG_ADDRESS_WATCH", _IOC_WRITE, 0x4b0f, 0x10 },
@@ -1370,6 +1381,7 @@
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_SET_MEMORY_POLICY", _IOC_WRITE, 0x4b04, 0x20 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_SET_SCRATCH_BACKING_VA", _IOC_READ|_IOC_WRITE, 0x4b11, 0x10 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_SET_TRAP_HANDLER", _IOC_WRITE, 0x4b13, 0x18 },
+{ "linux/kfd_ioctl.h", "AMDKFD_IOC_SMI_EVENTS", _IOC_READ|_IOC_WRITE, 0x4b1f, 0x08 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_UNMAP_MEMORY_FROM_GPU", _IOC_READ|_IOC_WRITE, 0x4b19, 0x18 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_UPDATE_QUEUE", _IOC_WRITE, 0x4b07, 0x18 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_WAIT_EVENTS", _IOC_READ|_IOC_WRITE, 0x4b0c, 0x18 },
@@ -1403,6 +1415,7 @@
 { "linux/lirc.h", "LIRC_SET_WIDEBAND_RECEIVER", _IOC_WRITE, 0x6923, 0x04 },
 { "linux/loop.h", "LOOP_CHANGE_FD", 0, 0x4C06, 0 },
 { "linux/loop.h", "LOOP_CLR_FD", 0, 0x4C01, 0 },
+{ "linux/loop.h", "LOOP_CONFIGURE", 0, 0x4C0A, 0 },
 { "linux/loop.h", "LOOP_CTL_ADD", 0, 0x4C80, 0 },
 { "linux/loop.h", "LOOP_CTL_GET_FREE", 0, 0x4C82, 0 },
 { "linux/loop.h", "LOOP_CTL_REMOVE", 0, 0x4C81, 0 },
@@ -1547,6 +1560,7 @@
 { "linux/omapfb.h", "OMAPFB_WAITFORGO", _IOC_NONE, 0x4f3c, 0x00 },
 { "linux/omapfb.h", "OMAPFB_WAITFORVSYNC", _IOC_NONE, 0x4f39, 0x00 },
 { "linux/pcitest.h", "PCITEST_BAR", _IOC_NONE, 0x5001, 0x00 },
+{ "linux/pcitest.h", "PCITEST_CLEAR_IRQ", _IOC_NONE, 0x5010, 0x00 },
 { "linux/pcitest.h", "PCITEST_COPY", _IOC_WRITE, 0x5006, 0x04 },
 { "linux/pcitest.h", "PCITEST_GET_IRQTYPE", _IOC_NONE, 0x5009, 0x00 },
 { "linux/pcitest.h", "PCITEST_LEGACY_IRQ", _IOC_NONE, 0x5002, 0x00 },
@@ -1707,6 +1721,8 @@
 { "linux/raw.h", "RAW_GETBIND", _IOC_NONE, 0xac01, 0x00 },
 { "linux/raw.h", "RAW_SETBIND", _IOC_NONE, 0xac00, 0x00 },
 { "linux/reiserfs_fs.h", "REISERFS_IOC_UNPACK", _IOC_WRITE, 0xcd01, 0x04 },
+{ "linux/remoteproc_cdev.h", "RPROC_GET_SHUTDOWN_ON_RELEASE", _IOC_READ, 0xb702, 0x04 },
+{ "linux/remoteproc_cdev.h", "RPROC_SET_SHUTDOWN_ON_RELEASE", _IOC_WRITE, 0xb701, 0x04 },
 { "linux/rfkill.h", "RFKILL_IOCTL_NOINPUT", _IOC_NONE, 0x5201, 0x00 },
 { "linux/rio_cm_cdev.h", "RIO_CM_CHAN_ACCEPT", _IOC_READ|_IOC_WRITE, 0x6307, 0x08 },
 { "linux/rio_cm_cdev.h", "RIO_CM_CHAN_BIND", _IOC_WRITE, 0x6305, 0x08 },
@@ -1784,7 +1800,8 @@
 { "linux/scif_ioctl.h", "SCIF_VREADFROM", _IOC_READ|_IOC_WRITE, 0x730c, 0x28 },
 { "linux/scif_ioctl.h", "SCIF_VWRITETO", _IOC_READ|_IOC_WRITE, 0x730d, 0x28 },
 { "linux/scif_ioctl.h", "SCIF_WRITETO", _IOC_READ|_IOC_WRITE, 0x730b, 0x28 },
-{ "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_ID_VALID", _IOC_READ, 0x2102, 0x08 },
+{ "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_ADDFD", _IOC_WRITE, 0x2103, 0x18 },
+{ "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_ID_VALID", _IOC_WRITE, 0x2102, 0x08 },
 { "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_RECV", _IOC_READ|_IOC_WRITE, 0x2100, 0x50 },
 { "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_SEND", _IOC_READ|_IOC_WRITE, 0x2101, 0x18 },
 { "linux/sed-opal.h", "IOC_OPAL_ACTIVATE_LSP", _IOC_WRITE, 0x70df, 0x118 },
@@ -2100,6 +2117,22 @@
 { "linux/usb/iowarrior.h", "IOW_GETINFO", _IOC_READ, 0xc003, 0x28 },
 { "linux/usb/iowarrior.h", "IOW_READ", _IOC_WRITE, 0xc002, 0x04 },
 { "linux/usb/iowarrior.h", "IOW_WRITE", _IOC_WRITE, 0xc001, 0x04 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_CONFIGURE", _IOC_NONE, 0x5509, 0x00 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP0_READ", _IOC_READ|_IOC_WRITE, 0x5504, 0x08 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP0_STALL", _IOC_NONE, 0x550c, 0x00 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP0_WRITE", _IOC_WRITE, 0x5503, 0x08 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EPS_INFO", _IOC_READ, 0x550b, 0x3c0 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_CLEAR_HALT", _IOC_WRITE, 0x550e, 0x04 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_DISABLE", _IOC_WRITE, 0x5506, 0x04 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_ENABLE", _IOC_WRITE, 0x5505, 0x09 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_READ", _IOC_READ|_IOC_WRITE, 0x5508, 0x08 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_SET_HALT", _IOC_WRITE, 0x550d, 0x04 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_SET_WEDGE", _IOC_WRITE, 0x550f, 0x04 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_WRITE", _IOC_WRITE, 0x5507, 0x08 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EVENT_FETCH", _IOC_READ, 0x5502, 0x08 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_INIT", _IOC_WRITE, 0x5500, 0x101 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_RUN", _IOC_NONE, 0x5501, 0x00 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_VBUS_DRAW", _IOC_WRITE, 0x550a, 0x04 },
 { "linux/usb/tmc.h", "USBTMC488_IOCTL_GET_CAPS", _IOC_READ, 0x5b11, 0x01 },
 { "linux/usb/tmc.h", "USBTMC488_IOCTL_GOTO_LOCAL", _IOC_NONE, 0x5b14, 0x00 },
 { "linux/usb/tmc.h", "USBTMC488_IOCTL_LOCAL_LOCKOUT", _IOC_NONE, 0x5b15, 0x00 },
@@ -2169,6 +2202,7 @@
 { "linux/userfaultfd.h", "UFFDIO_REGISTER", _IOC_READ|_IOC_WRITE, 0xaa00, 0x20 },
 { "linux/userfaultfd.h", "UFFDIO_UNREGISTER", _IOC_READ, 0xaa01, 0x10 },
 { "linux/userfaultfd.h", "UFFDIO_WAKE", _IOC_READ, 0xaa02, 0x10 },
+{ "linux/userfaultfd.h", "UFFDIO_WRITEPROTECT", _IOC_READ|_IOC_WRITE, 0xaa06, 0x18 },
 { "linux/userfaultfd.h", "UFFDIO_ZEROPAGE", _IOC_READ|_IOC_WRITE, 0xaa04, 0x20 },
 { "linux/uvcvideo.h", "UVCIOC_CTRL_MAP", _IOC_READ|_IOC_WRITE, 0x7520, 0x58 },
 { "linux/uvcvideo.h", "UVCIOC_CTRL_QUERY", _IOC_READ|_IOC_WRITE, 0x7521, 0x0c },
@@ -2179,10 +2213,12 @@
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_G_FMT", _IOC_READ|_IOC_WRITE, 0x5604, 0x58 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_G_FRAME_INTERVAL", _IOC_READ|_IOC_WRITE, 0x5615, 0x30 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_G_SELECTION", _IOC_READ|_IOC_WRITE, 0x563d, 0x40 },
+{ "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_QUERYCAP", _IOC_READ, 0x5600, 0x40 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_S_CROP", _IOC_READ|_IOC_WRITE, 0x563c, 0x38 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_S_FMT", _IOC_READ|_IOC_WRITE, 0x5605, 0x58 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_S_FRAME_INTERVAL", _IOC_READ|_IOC_WRITE, 0x5616, 0x30 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_S_SELECTION", _IOC_READ|_IOC_WRITE, 0x563e, 0x40 },
+{ "linux/vboxguest.h", "VBG_IOCTL_ACQUIRE_GUEST_CAPABILITIES", _IOC_READ|_IOC_WRITE, 0x560d, 0x24 },
 { "linux/vboxguest.h", "VBG_IOCTL_CHANGE_FILTER_MASK", _IOC_READ|_IOC_WRITE, 0x560c, 0x20 },
 { "linux/vboxguest.h", "VBG_IOCTL_CHANGE_GUEST_CAPABILITIES", _IOC_READ|_IOC_WRITE, 0x560e, 0x20 },
 { "linux/vboxguest.h", "VBG_IOCTL_CHECK_BALLOON", _IOC_READ|_IOC_WRITE, 0x5611, 0x20 },
@@ -2190,10 +2226,11 @@
 { "linux/vboxguest.h", "VBG_IOCTL_HGCM_CONNECT", _IOC_READ|_IOC_WRITE, 0x5604, 0x9c },
 { "linux/vboxguest.h", "VBG_IOCTL_HGCM_DISCONNECT", _IOC_READ|_IOC_WRITE, 0x5605, 0x1c },
 { "linux/vboxguest.h", "VBG_IOCTL_INTERRUPT_ALL_WAIT_FOR_EVENTS", _IOC_READ|_IOC_WRITE, 0x560b, 0x18 },
-{ "linux/vboxguest.h", "VBG_IOCTL_VMMDEV_REQUEST_BIG", _IOC_READ|_IOC_WRITE, 0x5603, 0x00 },
+{ "linux/vboxguest.h", "VBG_IOCTL_VMMDEV_REQUEST_BIG", _IOC_NONE, 0x5603, 0x00 },
 { "linux/vboxguest.h", "VBG_IOCTL_WAIT_FOR_EVENTS", _IOC_READ|_IOC_WRITE, 0x560a, 0x20 },
 { "linux/vboxguest.h", "VBG_IOCTL_WRITE_CORE_DUMP", _IOC_READ|_IOC_WRITE, 0x5613, 0x1c },
 { "linux/vfio.h", "VFIO_CHECK_EXTENSION", _IOC_NONE, 0x3b65, 0x00 },
+{ "linux/vfio.h", "VFIO_DEVICE_FEATURE", _IOC_NONE, 0x3b75, 0x00 },
 { "linux/vfio.h", "VFIO_DEVICE_GET_GFX_DMABUF", _IOC_NONE, 0x3b73, 0x00 },
 { "linux/vfio.h", "VFIO_DEVICE_GET_INFO", _IOC_NONE, 0x3b6b, 0x00 },
 { "linux/vfio.h", "VFIO_DEVICE_GET_IRQ_INFO", _IOC_NONE, 0x3b6d, 0x00 },
@@ -2210,6 +2247,7 @@
 { "linux/vfio.h", "VFIO_GROUP_GET_STATUS", _IOC_NONE, 0x3b67, 0x00 },
 { "linux/vfio.h", "VFIO_GROUP_SET_CONTAINER", _IOC_NONE, 0x3b68, 0x00 },
 { "linux/vfio.h", "VFIO_GROUP_UNSET_CONTAINER", _IOC_NONE, 0x3b69, 0x00 },
+{ "linux/vfio.h", "VFIO_IOMMU_DIRTY_PAGES", _IOC_NONE, 0x3b75, 0x00 },
 { "linux/vfio.h", "VFIO_IOMMU_DISABLE", _IOC_NONE, 0x3b74, 0x00 },
 { "linux/vfio.h", "VFIO_IOMMU_ENABLE", _IOC_NONE, 0x3b73, 0x00 },
 { "linux/vfio.h", "VFIO_IOMMU_GET_INFO", _IOC_NONE, 0x3b70, 0x00 },
@@ -2247,6 +2285,14 @@
 { "linux/vhost.h", "VHOST_SET_VRING_ERR", _IOC_WRITE, 0xaf22, 0x08 },
 { "linux/vhost.h", "VHOST_SET_VRING_KICK", _IOC_WRITE, 0xaf20, 0x08 },
 { "linux/vhost.h", "VHOST_SET_VRING_NUM", _IOC_WRITE, 0xaf10, 0x08 },
+{ "linux/vhost.h", "VHOST_VDPA_GET_CONFIG", _IOC_READ, 0xaf73, 0x08 },
+{ "linux/vhost.h", "VHOST_VDPA_GET_DEVICE_ID", _IOC_READ, 0xaf70, 0x04 },
+{ "linux/vhost.h", "VHOST_VDPA_GET_STATUS", _IOC_READ, 0xaf71, 0x01 },
+{ "linux/vhost.h", "VHOST_VDPA_GET_VRING_NUM", _IOC_READ, 0xaf76, 0x02 },
+{ "linux/vhost.h", "VHOST_VDPA_SET_CONFIG", _IOC_WRITE, 0xaf74, 0x08 },
+{ "linux/vhost.h", "VHOST_VDPA_SET_CONFIG_CALL", _IOC_WRITE, 0xaf77, 0x04 },
+{ "linux/vhost.h", "VHOST_VDPA_SET_STATUS", _IOC_WRITE, 0xaf72, 0x01 },
+{ "linux/vhost.h", "VHOST_VDPA_SET_VRING_ENABLE", _IOC_WRITE, 0xaf75, 0x08 },
 { "linux/vhost.h", "VHOST_VSOCK_SET_GUEST_CID", _IOC_WRITE, 0xaf60, 0x08 },
 { "linux/vhost.h", "VHOST_VSOCK_SET_RUNNING", _IOC_WRITE, 0xaf61, 0x04 },
 { "linux/videodev2.h", "VIDIOC_CREATE_BUFS", _IOC_READ|_IOC_WRITE, 0x565c, 0xf8 },
@@ -2255,8 +2301,8 @@
 { "linux/videodev2.h", "VIDIOC_DBG_G_REGISTER", _IOC_READ|_IOC_WRITE, 0x5650, 0x38 },
 { "linux/videodev2.h", "VIDIOC_DBG_S_REGISTER", _IOC_WRITE, 0x564f, 0x38 },
 { "linux/videodev2.h", "VIDIOC_DECODER_CMD", _IOC_READ|_IOC_WRITE, 0x5660, 0x48 },
-{ "linux/videodev2.h", "VIDIOC_DQBUF", _IOC_READ|_IOC_WRITE, 0x5611, 0x44 },
-{ "linux/videodev2.h", "VIDIOC_DQEVENT", _IOC_READ, 0x5659, 0x80 },
+{ "linux/videodev2.h", "VIDIOC_DQBUF", _IOC_READ|_IOC_WRITE, 0x5611, 0x50 },
+{ "linux/videodev2.h", "VIDIOC_DQEVENT", _IOC_READ, 0x5659, 0x88 },
 { "linux/videodev2.h", "VIDIOC_DV_TIMINGS_CAP", _IOC_READ|_IOC_WRITE, 0x5664, 0x90 },
 { "linux/videodev2.h", "VIDIOC_ENCODER_CMD", _IOC_READ|_IOC_WRITE, 0x564d, 0x28 },
 { "linux/videodev2.h", "VIDIOC_ENUMAUDIO", _IOC_READ|_IOC_WRITE, 0x5641, 0x34 },
@@ -2293,9 +2339,9 @@
 { "linux/videodev2.h", "VIDIOC_G_TUNER", _IOC_READ|_IOC_WRITE, 0x561d, 0x54 },
 { "linux/videodev2.h", "VIDIOC_LOG_STATUS", _IOC_NONE, 0x5646, 0x00 },
 { "linux/videodev2.h", "VIDIOC_OVERLAY", _IOC_WRITE, 0x560e, 0x04 },
-{ "linux/videodev2.h", "VIDIOC_PREPARE_BUF", _IOC_READ|_IOC_WRITE, 0x565d, 0x44 },
-{ "linux/videodev2.h", "VIDIOC_QBUF", _IOC_READ|_IOC_WRITE, 0x560f, 0x44 },
-{ "linux/videodev2.h", "VIDIOC_QUERYBUF", _IOC_READ|_IOC_WRITE, 0x5609, 0x44 },
+{ "linux/videodev2.h", "VIDIOC_PREPARE_BUF", _IOC_READ|_IOC_WRITE, 0x565d, 0x50 },
+{ "linux/videodev2.h", "VIDIOC_QBUF", _IOC_READ|_IOC_WRITE, 0x560f, 0x50 },
+{ "linux/videodev2.h", "VIDIOC_QUERYBUF", _IOC_READ|_IOC_WRITE, 0x5609, 0x50 },
 { "linux/videodev2.h", "VIDIOC_QUERYCAP", _IOC_READ, 0x5600, 0x68 },
 { "linux/videodev2.h", "VIDIOC_QUERYCTRL", _IOC_READ|_IOC_WRITE, 0x5624, 0x44 },
 { "linux/videodev2.h", "VIDIOC_QUERYMENU", _IOC_READ|_IOC_WRITE, 0x5625, 0x2c },
@@ -2369,6 +2415,8 @@
 { "linux/vt.h", "VT_WAITACTIVE", 0, 0x5607, 0 },
 { "linux/vt.h", "VT_WAITEVENT", 0, 0x560E, 0 },
 { "linux/vtpm_proxy.h", "VTPM_PROXY_IOC_NEW_DEV", _IOC_READ|_IOC_WRITE, 0xa100, 0x14 },
+{ "linux/watch_queue.h", "IOC_WATCH_QUEUE_SET_FILTER", _IOC_NONE, 0x5761, 0x00 },
+{ "linux/watch_queue.h", "IOC_WATCH_QUEUE_SET_SIZE", _IOC_NONE, 0x5760, 0x00 },
 { "linux/watchdog.h", "WDIOC_GETBOOTSTATUS", _IOC_READ, 0x5702, 0x04 },
 { "linux/watchdog.h", "WDIOC_GETPRETIMEOUT", _IOC_READ, 0x5709, 0x04 },
 { "linux/watchdog.h", "WDIOC_GETSTATUS", _IOC_READ, 0x5701, 0x04 },
@@ -2444,7 +2492,12 @@
 { "media/i2c/saa6588.h", "SAA6588_CMD_READ", _IOC_READ, 0x5203, 0x04 },
 { "media/v4l2-common.h", "TUNER_SET_CONFIG", _IOC_WRITE, 0x645c, 0x08 },
 { "media/v4l2-common.h", "VIDIOC_INT_RESET", _IOC_WRITE, 0x6466, 0x04 },
-{ "media/v4l2-subdev.h", "V4L2_DEVICE_NOTIFY_EVENT", _IOC_WRITE, 0x7602, 0x80 },
+{ "media/v4l2-ioctl.h", "VIDIOC_DQBUF_TIME32", _IOC_READ|_IOC_WRITE, 0x5611, 0x44 },
+{ "media/v4l2-ioctl.h", "VIDIOC_DQEVENT_TIME32", _IOC_READ, 0x5659, 0x80 },
+{ "media/v4l2-ioctl.h", "VIDIOC_PREPARE_BUF_TIME32", _IOC_READ|_IOC_WRITE, 0x565d, 0x44 },
+{ "media/v4l2-ioctl.h", "VIDIOC_QBUF_TIME32", _IOC_READ|_IOC_WRITE, 0x560f, 0x44 },
+{ "media/v4l2-ioctl.h", "VIDIOC_QUERYBUF_TIME32", _IOC_READ|_IOC_WRITE, 0x5609, 0x44 },
+{ "media/v4l2-subdev.h", "V4L2_DEVICE_NOTIFY_EVENT", _IOC_WRITE, 0x7602, 0x88 },
 { "media/v4l2-subdev.h", "V4L2_SUBDEV_IR_RX_NOTIFY", _IOC_WRITE, 0x7600, 0x04 },
 { "media/v4l2-subdev.h", "V4L2_SUBDEV_IR_TX_NOTIFY", _IOC_WRITE, 0x7601, 0x04 },
 { "misc/cxl.h", "CXL_IOCTL_DOWNLOAD_IMAGE", _IOC_WRITE, 0xca0a, 0x40 },
@@ -2472,6 +2525,9 @@
 { "misc/ocxl.h", "OCXL_IOCTL_IRQ_ALLOC", _IOC_READ, 0xca11, 0x08 },
 { "misc/ocxl.h", "OCXL_IOCTL_IRQ_FREE", _IOC_WRITE, 0xca12, 0x08 },
 { "misc/ocxl.h", "OCXL_IOCTL_IRQ_SET_FD", _IOC_WRITE, 0xca13, 0x10 },
+{ "misc/uacce/hisi_qm.h", "UACCE_CMD_QM_SET_QP_CTX", _IOC_READ|_IOC_WRITE, 0x480a, 0x04 },
+{ "misc/uacce/uacce.h", "UACCE_CMD_PUT_Q", _IOC_NONE, 0x5701, 0x00 },
+{ "misc/uacce/uacce.h", "UACCE_CMD_START_Q", _IOC_NONE, 0x5700, 0x00 },
 { "misc/xilinx_sdfec.h", "XSDFEC_ADD_LDPC_CODE_PARAMS", _IOC_WRITE, 0x6605, 0x4c },
 { "misc/xilinx_sdfec.h", "XSDFEC_CLEAR_STATS", _IOC_NONE, 0x660b, 0x00 },
 { "misc/xilinx_sdfec.h", "XSDFEC_GET_CONFIG", _IOC_READ, 0x6606, 0x1c },
@@ -2724,7 +2780,8 @@
 { "sound/asound.h", "SNDRV_TIMER_IOCTL_START", _IOC_NONE, 0x54a0, 0x00 },
 { "sound/asound.h", "SNDRV_TIMER_IOCTL_STATUS", _IOC_READ, 0x5414, 0x58 },
 { "sound/asound.h", "SNDRV_TIMER_IOCTL_STOP", _IOC_NONE, 0x54a1, 0x00 },
-{ "sound/asound.h", "SNDRV_TIMER_IOCTL_TREAD", _IOC_WRITE, 0x5402, 0x04 },
+{ "sound/asound.h", "SNDRV_TIMER_IOCTL_TREAD64", _IOC_WRITE, 0x54a4, 0x04 },
+{ "sound/asound.h", "SNDRV_TIMER_IOCTL_TREAD_OLD", _IOC_WRITE, 0x5402, 0x04 },
 { "sound/asound_fm.h", "SNDRV_DM_FM_IOCTL_CLEAR_PATCHES", _IOC_NONE, 0x4840, 0x00 },
 { "sound/asound_fm.h", "SNDRV_DM_FM_IOCTL_INFO", _IOC_READ, 0x4820, 0x02 },
 { "sound/asound_fm.h", "SNDRV_DM_FM_IOCTL_PLAY_NOTE", _IOC_WRITE, 0x4822, 0x0c },
@@ -2782,6 +2839,10 @@
 { "sound/hdspm.h", "SNDRV_HDSPM_IOCTL_GET_PEAK_RMS", _IOC_READ, 0x4842, 0x908 },
 { "sound/hdspm.h", "SNDRV_HDSPM_IOCTL_GET_STATUS", _IOC_READ, 0x4847, 0x20 },
 { "sound/hdspm.h", "SNDRV_HDSPM_IOCTL_GET_VERSION", _IOC_READ, 0x4848, 0x24 },
+{ "sound/pcm.h", "SNDRV_PCM_IOCTL_STATUS32", _IOC_READ, 0x4120, 0x6c },
+{ "sound/pcm.h", "SNDRV_PCM_IOCTL_STATUS64", _IOC_READ, 0x4120, 0x80 },
+{ "sound/pcm.h", "SNDRV_PCM_IOCTL_STATUS_EXT32", _IOC_READ|_IOC_WRITE, 0x4124, 0x6c },
+{ "sound/pcm.h", "SNDRV_PCM_IOCTL_STATUS_EXT64", _IOC_READ|_IOC_WRITE, 0x4124, 0x80 },
 { "sound/sb16_csp.h", "SNDRV_SB_CSP_IOCTL_INFO", _IOC_READ, 0x4810, 0x28 },
 { "sound/sb16_csp.h", "SNDRV_SB_CSP_IOCTL_LOAD_CODE", _IOC_WRITE, 0x4811, 0x3012 },
 { "sound/sb16_csp.h", "SNDRV_SB_CSP_IOCTL_PAUSE", _IOC_NONE, 0x4815, 0x00 },
@@ -2808,15 +2869,6 @@
 { "staging/android/ashmem.h", "ASHMEM_UNPIN", _IOC_WRITE, 0x7708, 0x08 },
 { "staging/android/ion.h", "ION_IOC_ALLOC", _IOC_READ|_IOC_WRITE, 0x4900, 0x18 },
 { "staging/android/ion.h", "ION_IOC_HEAP_QUERY", _IOC_READ|_IOC_WRITE, 0x4908, 0x18 },
-{ "staging/android/vsoc_shm.h", "VSOC_COND_WAIT", _IOC_READ|_IOC_WRITE, 0xf507, 0x20 },
-{ "staging/android/vsoc_shm.h", "VSOC_COND_WAKE", _IOC_NONE, 0xf508, 0x00 },
-{ "staging/android/vsoc_shm.h", "VSOC_CREATE_FD_SCOPED_PERMISSION", _IOC_WRITE, 0xf500, 0x10 },
-{ "staging/android/vsoc_shm.h", "VSOC_DESCRIBE_REGION", _IOC_READ, 0xf504, 0x3c },
-{ "staging/android/vsoc_shm.h", "VSOC_GET_FD_SCOPED_PERMISSION", _IOC_READ, 0xf501, 0x10 },
-{ "staging/android/vsoc_shm.h", "VSOC_MAYBE_SEND_INTERRUPT_TO_HOST", _IOC_NONE, 0xf502, 0x00 },
-{ "staging/android/vsoc_shm.h", "VSOC_SELF_INTERRUPT", _IOC_NONE, 0xf505, 0x00 },
-{ "staging/android/vsoc_shm.h", "VSOC_SEND_INTERRUPT_TO_HOST", _IOC_NONE, 0xf506, 0x00 },
-{ "staging/android/vsoc_shm.h", "VSOC_WAIT_FOR_INCOMING_INTERRUPT", _IOC_NONE, 0xf503, 0x00 },
 { "video/da8xx-fb.h", "FBIGET_BRIGHTNESS", _IOC_READ, 0x4603, 0x04 },
 { "video/da8xx-fb.h", "FBIGET_COLOR", _IOC_READ, 0x4605, 0x04 },
 { "video/da8xx-fb.h", "FBIOGET_CONTRAST", _IOC_READ, 0x4601, 0x04 },
diff -pruN 5.5-3/linux/32/syscallent.h 5.9-0ubuntu2/linux/32/syscallent.h
--- 5.5-3/linux/32/syscallent.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/linux/32/syscallent.h	2020-08-01 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -12,7 +12,7 @@
 [  1] = { 1,	TM,		SEN(io_destroy),		"io_destroy"		},
 [  2] = { 3,	0,		SEN(io_submit),			"io_submit"		},
 [  3] = { 3,	0,		SEN(io_cancel),			"io_cancel"		},
-[  4] = { 5,	0,		SEN(io_getevents_time32),	"io_getevents"		},
+/* [  4] io_getevents */
 [  5] = { 5,	TF,		SEN(setxattr),			"setxattr"		},
 [  6] = { 5,	TF,		SEN(setxattr),			"lsetxattr"		},
 [  7] = { 5,	TD,		SEN(fsetxattr),			"fsetxattr"		},
@@ -80,8 +80,8 @@
 [ 69] = { 5,	TD,		SEN(preadv),			"preadv"		},
 [ 70] = { 5,	TD,		SEN(pwritev),			"pwritev"		},
 [ 71] = { 4,	TD|TN,		SEN(sendfile64),		"sendfile64"		},
-[ 72] = { 6,	TD,		SEN(pselect6_time32),		"pselect6"		},
-[ 73] = { 5,	TD,		SEN(ppoll_time32),		"ppoll"			},
+/* [ 72] pselect6 */
+/* [ 73] ppoll */
 [ 74] = { 4,	TD|TS,		SEN(signalfd4),			"signalfd4"		},
 [ 75] = { 4,	TD,		SEN(vmsplice),			"vmsplice"		},
 [ 76] = { 6,	TD,		SEN(splice),			"splice"		},
@@ -98,9 +98,9 @@
 [ 84] = { 6,	TD,		SEN(sync_file_range),		"sync_file_range"	},
 #endif
 [ 85] = { 2,	TD,		SEN(timerfd_create),		"timerfd_create"	},
-[ 86] = { 4,	TD,		SEN(timerfd_settime32),		"timerfd_settime"	},
-[ 87] = { 2,	TD,		SEN(timerfd_gettime32),		"timerfd_gettime"	},
-[ 88] = { 4,	TD|TF,		SEN(utimensat_time32),		"utimensat"		},
+/* [ 86] timerfd_settime */
+/* [ 87] timerfd_gettime */
+/* [ 88] utimensat */
 [ 89] = { 1,	TF,		SEN(acct),			"acct"			},
 [ 90] = { 2,	TC,		SEN(capget),			"capget"		},
 [ 91] = { 2,	TC,		SEN(capset),			"capset"		},
@@ -109,25 +109,25 @@
 [ 94] = { 1,	TP|SE,		SEN(exit),			"exit_group"		},
 [ 95] = { 5,	TP,		SEN(waitid),			"waitid"		},
 [ 96] = { 1,	0,		SEN(set_tid_address),		"set_tid_address"	},
-[ 97] = { 1,	TP,		SEN(unshare),			"unshare"		},
-[ 98] = { 6,	0,		SEN(futex_time32),		"futex"			},
+[ 97] = { 1,	0,		SEN(unshare),			"unshare"		},
+/* [ 98] futex */
 [ 99] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [100] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
-[101] = { 2,	0,		SEN(nanosleep_time32),		"nanosleep"		},
+/* [101] nanosleep */
 [102] = { 2,	0,		SEN(getitimer),			"getitimer"		},
 [103] = { 3,	0,		SEN(setitimer),			"setitimer"		},
 [104] = { 4,	0,		SEN(kexec_load),		"kexec_load"		},
 [105] = { 3,	0,		SEN(init_module),		"init_module"		},
 [106] = { 2,	0,		SEN(delete_module),		"delete_module"		},
 [107] = { 3,	0,		SEN(timer_create),		"timer_create"		},
-[108] = { 2,	0,		SEN(timer_gettime32),		"timer_gettime"		},
+/* [108] timer_gettime */
 [109] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
-[110] = { 4,	0,		SEN(timer_settime32),		"timer_settime"		},
+/* [110] timer_settime */
 [111] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[112] = { 2,	0,		SEN(clock_settime32),		"clock_settime"		},
-[113] = { 2,	0,		SEN(clock_gettime32),		"clock_gettime"		},
-[114] = { 2,	0,		SEN(clock_getres_time32),	"clock_getres"		},
-[115] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
+/* [112] clock_settime */
+/* [113] clock_gettime */
+/* [114] clock_getres */
+/* [115] clock_nanosleep */
 [116] = { 3,	0,		SEN(syslog),			"syslog"		},
 [117] = { 4,	0,		SEN(ptrace),			"ptrace"		},
 [118] = { 2,	0,		SEN(sched_setparam),		"sched_setparam"	},
@@ -139,18 +139,18 @@
 [124] = { 0,	0,		SEN(sched_yield),		"sched_yield"		},
 [125] = { 1,	0,		SEN(sched_get_priority_max),	"sched_get_priority_max"},
 [126] = { 1,	0,		SEN(sched_get_priority_min),	"sched_get_priority_min"},
-[127] = { 2,	0,		SEN(sched_rr_get_interval_time32),"sched_rr_get_interval"},
+/* [127] sched_rr_get_interval */
 [128] = { 0,	0,		SEN(restart_syscall),		"restart_syscall"	},
-[129] = { 2,	TS,		SEN(kill),			"kill"			},
-[130] = { 2,	TS,		SEN(kill),			"tkill"			},
-[131] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[129] = { 2,	TS|TP,		SEN(kill),			"kill"			},
+[130] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
+[131] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [132] = { 2,	TS,		SEN(sigaltstack),		"sigaltstack"		},
 [133] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [134] = { 4,	TS,		SEN(rt_sigaction),		"rt_sigaction"		},
 [135] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [136] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
-[137] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
-[138] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+/* [137] rt_sigtimedwait */
+[138] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [139] = { 0,	TS,		SEN(rt_sigreturn),		"rt_sigreturn"		},
 [140] = { 3,	0,		SEN(setpriority),		"setpriority"		},
 [141] = { 2,	0,		SEN(getpriority),		"getpriority"		},
@@ -181,9 +181,9 @@
 [166] = { 1,	NF,		SEN(umask),			"umask"			},
 [167] = { 5,	TC,		SEN(prctl),			"prctl"			},
 [168] = { 3,	0,		SEN(getcpu),			"getcpu"		},
-[169] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
-[170] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
-[171] = { 1,	0,		SEN(adjtimex32),		"adjtimex"		},
+/* [169] gettimeofday */
+/* [170] settimeofday */
+/* [171] adjtimex */
 [172] = { 0,	PU|NF,		SEN(getpid),			"getpid"		},
 [173] = { 0,	PU|NF,		SEN(getppid),			"getppid"		},
 [174] = { 0,	TC|PU|NF,	SEN(getuid),			"getuid"		},
@@ -194,8 +194,8 @@
 [179] = { 1,	0,		SEN(sysinfo),			"sysinfo"		},
 [180] = { 4,	TD,		SEN(mq_open),			"mq_open"		},
 [181] = { 1,	0,		SEN(mq_unlink),			"mq_unlink"		},
-[182] = { 5,	TD,		SEN(mq_timedsend_time32),	"mq_timedsend"		},
-[183] = { 5,	TD,		SEN(mq_timedreceive_time32),	"mq_timedreceive"	},
+/* [182] mq_timedsend */
+/* [183] mq_timedreceive */
 [184] = { 2,	TD,		SEN(mq_notify),			"mq_notify"		},
 [185] = { 3,	TD,		SEN(mq_getsetattr),		"mq_getsetattr"		},
 [186] = { 2,	TI,		SEN(msgget),			"msgget"		},
@@ -204,7 +204,7 @@
 [189] = { 4,	TI,		SEN(msgsnd),			"msgsnd"		},
 [190] = { 3,	TI,		SEN(semget),			"semget"		},
 [191] = { 4,	TI,		SEN(semctl),			"semctl"		},
-[192] = { 4,	TI,		SEN(semtimedop_time32),		"semtimedop"		},
+/* [192] semtimedop */
 [193] = { 3,	TI,		SEN(semop),			"semop"			},
 [194] = { 3,	TI,		SEN(shmget),			"shmget"		},
 [195] = { 3,	TI,		SEN(shmctl),			"shmctl"		},
@@ -255,15 +255,15 @@
 [240] = { 4,	TP|TS,		SEN(rt_tgsigqueueinfo),		"rt_tgsigqueueinfo"	},
 [241] = { 5,	TD,		SEN(perf_event_open),		"perf_event_open"	},
 [242] = { 4,	TN,		SEN(accept4),			"accept4"		},
-[243] = { 5,	TN,		SEN(recvmmsg_time32),		"recvmmsg"		},
+/* [243] recvmmsg */
 /* [244 ... 259] are arch specific */
-[260] = { 4,	TP,		SEN(wait4),			"wait4"			},
+/* [260] wait4 */
 [261] = { 4,	0,		SEN(prlimit64),			"prlimit64"		},
 [262] = { 2,	TD,		SEN(fanotify_init),		"fanotify_init"		},
 [263] = { 6,	TD|TF,		SEN(fanotify_mark),		"fanotify_mark"		},
 [264] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [265] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[266] = { 2,	0,		SEN(clock_adjtime32),		"clock_adjtime"		},
+/* [266] clock_adjtime */
 [267] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [268] = { 2,	TD,		SEN(setns),			"setns"			},
 [269] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
@@ -288,10 +288,13 @@
 [288] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [289] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
 [290] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
-[291] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
-[292] = { 6,	0,		SEN(io_pgetevents_time32),	"io_pgetevents"		},
+[291] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
+/* [292] io_pgetevents */
 [293] = { 4,	0,		SEN(rseq),			"rseq"			},
 [294] = { 5,	TD,		SEN(kexec_file_load),		"kexec_file_load"	},
+#if HAVE_ARCH_TIME32_SYSCALLS
+# include "32/syscallent-time32.h"
+#endif
 /* [295 ... 402] - reserved to sync up with other architectures */
 #include "syscallent-common-32.h"
 #include "syscallent-common.h"
diff -pruN 5.5-3/linux/32/syscallent-time32.h 5.9-0ubuntu2/linux/32/syscallent-time32.h
--- 5.5-3/linux/32/syscallent-time32.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/linux/32/syscallent-time32.h	2020-04-17 20:43:15.000000000 +0000
@@ -0,0 +1,33 @@
+/*
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
+[  4] = { 5,	0,		SEN(io_getevents_time32),	"io_getevents"		},
+[ 72] = { 6,	TD,		SEN(pselect6_time32),		"pselect6"		},
+[ 73] = { 5,	TD,		SEN(ppoll_time32),		"ppoll"			},
+[ 86] = { 4,	TD,		SEN(timerfd_settime32),		"timerfd_settime"	},
+[ 87] = { 2,	TD,		SEN(timerfd_gettime32),		"timerfd_gettime"	},
+[ 88] = { 4,	TD|TF,		SEN(utimensat_time32),		"utimensat"		},
+[ 98] = { 6,	0,		SEN(futex_time32),		"futex"			},
+[101] = { 2,	0,		SEN(nanosleep_time32),		"nanosleep"		},
+[108] = { 2,	0,		SEN(timer_gettime32),		"timer_gettime"		},
+[110] = { 4,	0,		SEN(timer_settime32),		"timer_settime"		},
+[112] = { 2,	TCL,		SEN(clock_settime32),		"clock_settime"		},
+[113] = { 2,	TCL,		SEN(clock_gettime32),		"clock_gettime"		},
+[114] = { 2,	TCL,		SEN(clock_getres_time32),	"clock_getres"		},
+[115] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
+[127] = { 2,	0,		SEN(sched_rr_get_interval_time32),"sched_rr_get_interval"},
+[137] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
+[169] = { 2,	TCL,		SEN(gettimeofday),		"gettimeofday"		},
+[170] = { 2,	TCL,		SEN(settimeofday),		"settimeofday"		},
+[171] = { 1,	TCL,		SEN(adjtimex32),		"adjtimex"		},
+[182] = { 5,	TD,		SEN(mq_timedsend_time32),	"mq_timedsend"		},
+[183] = { 5,	TD,		SEN(mq_timedreceive_time32),	"mq_timedreceive"	},
+[192] = { 4,	TI,		SEN(semtimedop_time32),		"semtimedop"		},
+[243] = { 5,	TN,		SEN(recvmmsg_time32),		"recvmmsg"		},
+[260] = { 4,	TP,		SEN(wait4),			"wait4"			},
+[266] = { 2,	TCL,		SEN(clock_adjtime32),		"clock_adjtime"		},
+[292] = { 6,	0,		SEN(io_pgetevents_time32),	"io_pgetevents"		},
diff -pruN 5.5-3/linux/64/ioctls_inc.h 5.9-0ubuntu2/linux/64/ioctls_inc.h
--- 5.5-3/linux/64/ioctls_inc.h	2020-01-27 13:21:44.000000000 +0000
+++ 5.9-0ubuntu2/linux/64/ioctls_inc.h	2020-09-23 16:29:35.000000000 +0000
@@ -155,6 +155,7 @@
 { "drm/drm.h", "DRM_IOCTL_MODE_GETCRTC", _IOC_READ|_IOC_WRITE, 0x64a1, 0x68 },
 { "drm/drm.h", "DRM_IOCTL_MODE_GETENCODER", _IOC_READ|_IOC_WRITE, 0x64a6, 0x14 },
 { "drm/drm.h", "DRM_IOCTL_MODE_GETFB", _IOC_READ|_IOC_WRITE, 0x64ad, 0x1c },
+{ "drm/drm.h", "DRM_IOCTL_MODE_GETFB2", _IOC_READ|_IOC_WRITE, 0x64ce, 0x68 },
 { "drm/drm.h", "DRM_IOCTL_MODE_GETGAMMA", _IOC_READ|_IOC_WRITE, 0x64a4, 0x20 },
 { "drm/drm.h", "DRM_IOCTL_MODE_GETPLANE", _IOC_READ|_IOC_WRITE, 0x64b6, 0x20 },
 { "drm/drm.h", "DRM_IOCTL_MODE_GETPLANERESOURCES", _IOC_READ|_IOC_WRITE, 0x64b5, 0x10 },
@@ -268,6 +269,7 @@
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_MADVISE", _IOC_READ|_IOC_WRITE, 0x6466, 0x0c },
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_MMAP", _IOC_READ|_IOC_WRITE, 0x645e, 0x28 },
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_MMAP_GTT", _IOC_READ|_IOC_WRITE, 0x6464, 0x10 },
+{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_MMAP_OFFSET", _IOC_READ|_IOC_WRITE, 0x6464, 0x20 },
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_PIN", _IOC_READ|_IOC_WRITE, 0x6455, 0x18 },
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_PREAD", _IOC_WRITE, 0x645c, 0x20 },
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_PWRITE", _IOC_WRITE, 0x645d, 0x20 },
@@ -330,7 +332,7 @@
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_INFO", _IOC_READ|_IOC_WRITE, 0x6443, 0x18 },
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_MADVISE", _IOC_READ|_IOC_WRITE, 0x6448, 0x0c },
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_NEW", _IOC_READ|_IOC_WRITE, 0x6442, 0x10 },
-{ "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_SUBMIT", _IOC_READ|_IOC_WRITE, 0x6446, 0x28 },
+{ "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_SUBMIT", _IOC_READ|_IOC_WRITE, 0x6446, 0x48 },
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_GET_PARAM", _IOC_READ|_IOC_WRITE, 0x6440, 0x10 },
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_SUBMITQUEUE_CLOSE", _IOC_WRITE, 0x644b, 0x04 },
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_SUBMITQUEUE_NEW", _IOC_READ|_IOC_WRITE, 0x644a, 0x0c },
@@ -695,6 +697,7 @@
 { "linux/btrfs.h", "BTRFS_IOC_SNAP_CREATE", _IOC_WRITE, 0x9401, 0x1000 },
 { "linux/btrfs.h", "BTRFS_IOC_SNAP_CREATE_V2", _IOC_WRITE, 0x9417, 0x1000 },
 { "linux/btrfs.h", "BTRFS_IOC_SNAP_DESTROY", _IOC_WRITE, 0x940f, 0x1000 },
+{ "linux/btrfs.h", "BTRFS_IOC_SNAP_DESTROY_V2", _IOC_WRITE, 0x943f, 0x1000 },
 { "linux/btrfs.h", "BTRFS_IOC_SPACE_INFO", _IOC_READ|_IOC_WRITE, 0x9414, 0x10 },
 { "linux/btrfs.h", "BTRFS_IOC_START_SYNC", _IOC_READ, 0x9418, 0x08 },
 { "linux/btrfs.h", "BTRFS_IOC_SUBVOL_CREATE", _IOC_WRITE, 0x940e, 0x1000 },
@@ -830,7 +833,9 @@
 { "linux/dm-ioctl.h", "DM_TARGET_MSG", _IOC_READ|_IOC_WRITE, 0xfd0e, 0x138 },
 { "linux/dm-ioctl.h", "DM_VERSION", _IOC_READ|_IOC_WRITE, 0xfd00, 0x138 },
 { "linux/dma-buf.h", "DMA_BUF_IOCTL_SYNC", _IOC_WRITE, 0x6200, 0x08 },
-{ "linux/dma-buf.h", "DMA_BUF_SET_NAME", _IOC_WRITE, 0x6201, 0x08 },
+{ "linux/dma-buf.h", "DMA_BUF_SET_NAME_A", _IOC_WRITE, 0x6201, 0x04 },
+{ "linux/dma-buf.h", "DMA_BUF_SET_NAME_B", _IOC_WRITE, 0x6201, 0x08 },
+{ "linux/dma-heap.h", "DMA_HEAP_IOCTL_ALLOC", _IOC_READ|_IOC_WRITE, 0x4800, 0x18 },
 { "linux/dn.h", "OSIOCGNETADDR", _IOC_READ, 0x89e1, 0x04 },
 { "linux/dn.h", "OSIOCSNETADDR", _IOC_WRITE, 0x89e0, 0x04 },
 { "linux/dn.h", "SIOCGNETADDR", _IOC_READ, 0x89e1, 0x04 },
@@ -987,15 +992,21 @@
 { "linux/firewire-cdev.h", "FW_CDEV_IOC_START_ISO", _IOC_WRITE, 0x230a, 0x10 },
 { "linux/firewire-cdev.h", "FW_CDEV_IOC_STOP_ISO", _IOC_WRITE, 0x230b, 0x04 },
 { "linux/fpga-dfl.h", "DFL_FPGA_CHECK_EXTENSION", _IOC_NONE, 0xb601, 0x00 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_FME_ERR_GET_IRQ_NUM", _IOC_READ, 0xb683, 0x04 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_FME_ERR_SET_IRQ", _IOC_WRITE, 0xb684, 0x08 },
 { "linux/fpga-dfl.h", "DFL_FPGA_FME_PORT_ASSIGN", _IOC_WRITE, 0xb682, 0x04 },
 { "linux/fpga-dfl.h", "DFL_FPGA_FME_PORT_PR", _IOC_NONE, 0xb680, 0x00 },
 { "linux/fpga-dfl.h", "DFL_FPGA_FME_PORT_RELEASE", _IOC_WRITE, 0xb681, 0x04 },
 { "linux/fpga-dfl.h", "DFL_FPGA_GET_API_VERSION", _IOC_NONE, 0xb600, 0x00 },
 { "linux/fpga-dfl.h", "DFL_FPGA_PORT_DMA_MAP", _IOC_NONE, 0xb643, 0x00 },
 { "linux/fpga-dfl.h", "DFL_FPGA_PORT_DMA_UNMAP", _IOC_NONE, 0xb644, 0x00 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_ERR_GET_IRQ_NUM", _IOC_READ, 0xb645, 0x04 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_ERR_SET_IRQ", _IOC_WRITE, 0xb646, 0x08 },
 { "linux/fpga-dfl.h", "DFL_FPGA_PORT_GET_INFO", _IOC_NONE, 0xb641, 0x00 },
 { "linux/fpga-dfl.h", "DFL_FPGA_PORT_GET_REGION_INFO", _IOC_NONE, 0xb642, 0x00 },
 { "linux/fpga-dfl.h", "DFL_FPGA_PORT_RESET", _IOC_NONE, 0xb640, 0x00 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_UINT_GET_IRQ_NUM", _IOC_READ, 0xb647, 0x04 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_UINT_SET_IRQ", _IOC_WRITE, 0xb648, 0x08 },
 { "linux/fs.h", "BLKALIGNOFF", _IOC_NONE, 0x127a, 0x00 },
 { "linux/fs.h", "BLKBSZGET", _IOC_READ, 0x1270, 0x08 },
 { "linux/fs.h", "BLKBSZSET", _IOC_WRITE, 0x1271, 0x08 },
@@ -1047,6 +1058,7 @@
 { "linux/fs.h", "FS_IOC_SETVERSION", _IOC_WRITE, 0x7602, 0x08 },
 { "linux/fscrypt.h", "FS_IOC_ADD_ENCRYPTION_KEY", _IOC_READ|_IOC_WRITE, 0x6617, 0x50 },
 { "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_KEY_STATUS", _IOC_READ|_IOC_WRITE, 0x661a, 0x80 },
+{ "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_NONCE", _IOC_READ, 0x661b, 0x10 },
 { "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_POLICY", _IOC_WRITE, 0x6615, 0x0c },
 { "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_POLICY_EX", _IOC_READ|_IOC_WRITE, 0x6616, 0x09 },
 { "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_PWSALT", _IOC_WRITE, 0x6614, 0x10 },
@@ -1092,10 +1104,6 @@
 { "linux/genwqe/genwqe_card.h", "GENWQE_WRITE_REG16", _IOC_WRITE, 0xa523, 0x10 },
 { "linux/genwqe/genwqe_card.h", "GENWQE_WRITE_REG32", _IOC_WRITE, 0xa521, 0x10 },
 { "linux/genwqe/genwqe_card.h", "GENWQE_WRITE_REG64", _IOC_WRITE, 0xa51f, 0x10 },
-{ "linux/gigaset_dev.h", "GIGASET_BRKCHARS", _IOC_WRITE, 0x4702, 0x06 },
-{ "linux/gigaset_dev.h", "GIGASET_CONFIG", _IOC_READ|_IOC_WRITE, 0x4701, 0x04 },
-{ "linux/gigaset_dev.h", "GIGASET_REDIR", _IOC_READ|_IOC_WRITE, 0x4700, 0x04 },
-{ "linux/gigaset_dev.h", "GIGASET_VERSION", _IOC_READ|_IOC_WRITE, 0x4703, 0x10 },
 { "linux/gpio.h", "GPIOHANDLE_GET_LINE_VALUES_IOCTL", _IOC_READ|_IOC_WRITE, 0xb408, 0x40 },
 { "linux/gpio.h", "GPIOHANDLE_SET_CONFIG_IOCTL", _IOC_READ|_IOC_WRITE, 0xb40a, 0x54 },
 { "linux/gpio.h", "GPIOHANDLE_SET_LINE_VALUES_IOCTL", _IOC_READ|_IOC_WRITE, 0xb409, 0x40 },
@@ -1103,6 +1111,8 @@
 { "linux/gpio.h", "GPIO_GET_LINEEVENT_IOCTL", _IOC_READ|_IOC_WRITE, 0xb404, 0x30 },
 { "linux/gpio.h", "GPIO_GET_LINEHANDLE_IOCTL", _IOC_READ|_IOC_WRITE, 0xb403, 0x16c },
 { "linux/gpio.h", "GPIO_GET_LINEINFO_IOCTL", _IOC_READ|_IOC_WRITE, 0xb402, 0x48 },
+{ "linux/gpio.h", "GPIO_GET_LINEINFO_UNWATCH_IOCTL", _IOC_READ|_IOC_WRITE, 0xb40c, 0x04 },
+{ "linux/gpio.h", "GPIO_GET_LINEINFO_WATCH_IOCTL", _IOC_READ|_IOC_WRITE, 0xb40b, 0x48 },
 { "linux/gsmmux.h", "GSMIOC_DISABLE_NET", _IOC_NONE, 0x4703, 0x00 },
 { "linux/gsmmux.h", "GSMIOC_ENABLE_NET", _IOC_WRITE, 0x4702, 0x34 },
 { "linux/gsmmux.h", "GSMIOC_GETCONF", _IOC_READ, 0x4700, 0x4c },
@@ -1346,6 +1356,7 @@
 { "linux/kd.h", "PIO_UNISCRNMAP", 0, 0x4B6A, 0 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_ACQUIRE_VM", _IOC_WRITE, 0x4b15, 0x08 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_ALLOC_MEMORY_OF_GPU", _IOC_READ|_IOC_WRITE, 0x4b16, 0x28 },
+{ "linux/kfd_ioctl.h", "AMDKFD_IOC_ALLOC_QUEUE_GWS", _IOC_READ|_IOC_WRITE, 0x4b1e, 0x10 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_CREATE_EVENT", _IOC_READ|_IOC_WRITE, 0x4b08, 0x20 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_CREATE_QUEUE", _IOC_READ|_IOC_WRITE, 0x4b02, 0x58 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_DBG_ADDRESS_WATCH", _IOC_WRITE, 0x4b0f, 0x10 },
@@ -1370,6 +1381,7 @@
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_SET_MEMORY_POLICY", _IOC_WRITE, 0x4b04, 0x20 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_SET_SCRATCH_BACKING_VA", _IOC_READ|_IOC_WRITE, 0x4b11, 0x10 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_SET_TRAP_HANDLER", _IOC_WRITE, 0x4b13, 0x18 },
+{ "linux/kfd_ioctl.h", "AMDKFD_IOC_SMI_EVENTS", _IOC_READ|_IOC_WRITE, 0x4b1f, 0x08 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_UNMAP_MEMORY_FROM_GPU", _IOC_READ|_IOC_WRITE, 0x4b19, 0x18 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_UPDATE_QUEUE", _IOC_WRITE, 0x4b07, 0x18 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_WAIT_EVENTS", _IOC_READ|_IOC_WRITE, 0x4b0c, 0x18 },
@@ -1403,6 +1415,7 @@
 { "linux/lirc.h", "LIRC_SET_WIDEBAND_RECEIVER", _IOC_WRITE, 0x6923, 0x04 },
 { "linux/loop.h", "LOOP_CHANGE_FD", 0, 0x4C06, 0 },
 { "linux/loop.h", "LOOP_CLR_FD", 0, 0x4C01, 0 },
+{ "linux/loop.h", "LOOP_CONFIGURE", 0, 0x4C0A, 0 },
 { "linux/loop.h", "LOOP_CTL_ADD", 0, 0x4C80, 0 },
 { "linux/loop.h", "LOOP_CTL_GET_FREE", 0, 0x4C82, 0 },
 { "linux/loop.h", "LOOP_CTL_REMOVE", 0, 0x4C81, 0 },
@@ -1547,6 +1560,7 @@
 { "linux/omapfb.h", "OMAPFB_WAITFORGO", _IOC_NONE, 0x4f3c, 0x00 },
 { "linux/omapfb.h", "OMAPFB_WAITFORVSYNC", _IOC_NONE, 0x4f39, 0x00 },
 { "linux/pcitest.h", "PCITEST_BAR", _IOC_NONE, 0x5001, 0x00 },
+{ "linux/pcitest.h", "PCITEST_CLEAR_IRQ", _IOC_NONE, 0x5010, 0x00 },
 { "linux/pcitest.h", "PCITEST_COPY", _IOC_WRITE, 0x5006, 0x08 },
 { "linux/pcitest.h", "PCITEST_GET_IRQTYPE", _IOC_NONE, 0x5009, 0x00 },
 { "linux/pcitest.h", "PCITEST_LEGACY_IRQ", _IOC_NONE, 0x5002, 0x00 },
@@ -1707,6 +1721,8 @@
 { "linux/raw.h", "RAW_GETBIND", _IOC_NONE, 0xac01, 0x00 },
 { "linux/raw.h", "RAW_SETBIND", _IOC_NONE, 0xac00, 0x00 },
 { "linux/reiserfs_fs.h", "REISERFS_IOC_UNPACK", _IOC_WRITE, 0xcd01, 0x08 },
+{ "linux/remoteproc_cdev.h", "RPROC_GET_SHUTDOWN_ON_RELEASE", _IOC_READ, 0xb702, 0x04 },
+{ "linux/remoteproc_cdev.h", "RPROC_SET_SHUTDOWN_ON_RELEASE", _IOC_WRITE, 0xb701, 0x04 },
 { "linux/rfkill.h", "RFKILL_IOCTL_NOINPUT", _IOC_NONE, 0x5201, 0x00 },
 { "linux/rio_cm_cdev.h", "RIO_CM_CHAN_ACCEPT", _IOC_READ|_IOC_WRITE, 0x6307, 0x08 },
 { "linux/rio_cm_cdev.h", "RIO_CM_CHAN_BIND", _IOC_WRITE, 0x6305, 0x08 },
@@ -1784,7 +1800,8 @@
 { "linux/scif_ioctl.h", "SCIF_VREADFROM", _IOC_READ|_IOC_WRITE, 0x730c, 0x28 },
 { "linux/scif_ioctl.h", "SCIF_VWRITETO", _IOC_READ|_IOC_WRITE, 0x730d, 0x28 },
 { "linux/scif_ioctl.h", "SCIF_WRITETO", _IOC_READ|_IOC_WRITE, 0x730b, 0x28 },
-{ "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_ID_VALID", _IOC_READ, 0x2102, 0x08 },
+{ "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_ADDFD", _IOC_WRITE, 0x2103, 0x18 },
+{ "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_ID_VALID", _IOC_WRITE, 0x2102, 0x08 },
 { "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_RECV", _IOC_READ|_IOC_WRITE, 0x2100, 0x50 },
 { "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_SEND", _IOC_READ|_IOC_WRITE, 0x2101, 0x18 },
 { "linux/sed-opal.h", "IOC_OPAL_ACTIVATE_LSP", _IOC_WRITE, 0x70df, 0x118 },
@@ -2100,6 +2117,22 @@
 { "linux/usb/iowarrior.h", "IOW_GETINFO", _IOC_READ, 0xc003, 0x28 },
 { "linux/usb/iowarrior.h", "IOW_READ", _IOC_WRITE, 0xc002, 0x08 },
 { "linux/usb/iowarrior.h", "IOW_WRITE", _IOC_WRITE, 0xc001, 0x08 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_CONFIGURE", _IOC_NONE, 0x5509, 0x00 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP0_READ", _IOC_READ|_IOC_WRITE, 0x5504, 0x08 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP0_STALL", _IOC_NONE, 0x550c, 0x00 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP0_WRITE", _IOC_WRITE, 0x5503, 0x08 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EPS_INFO", _IOC_READ, 0x550b, 0x3c0 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_CLEAR_HALT", _IOC_WRITE, 0x550e, 0x04 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_DISABLE", _IOC_WRITE, 0x5506, 0x04 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_ENABLE", _IOC_WRITE, 0x5505, 0x09 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_READ", _IOC_READ|_IOC_WRITE, 0x5508, 0x08 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_SET_HALT", _IOC_WRITE, 0x550d, 0x04 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_SET_WEDGE", _IOC_WRITE, 0x550f, 0x04 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_WRITE", _IOC_WRITE, 0x5507, 0x08 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EVENT_FETCH", _IOC_READ, 0x5502, 0x08 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_INIT", _IOC_WRITE, 0x5500, 0x101 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_RUN", _IOC_NONE, 0x5501, 0x00 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_VBUS_DRAW", _IOC_WRITE, 0x550a, 0x04 },
 { "linux/usb/tmc.h", "USBTMC488_IOCTL_GET_CAPS", _IOC_READ, 0x5b11, 0x01 },
 { "linux/usb/tmc.h", "USBTMC488_IOCTL_GOTO_LOCAL", _IOC_NONE, 0x5b14, 0x00 },
 { "linux/usb/tmc.h", "USBTMC488_IOCTL_LOCAL_LOCKOUT", _IOC_NONE, 0x5b15, 0x00 },
@@ -2169,6 +2202,7 @@
 { "linux/userfaultfd.h", "UFFDIO_REGISTER", _IOC_READ|_IOC_WRITE, 0xaa00, 0x20 },
 { "linux/userfaultfd.h", "UFFDIO_UNREGISTER", _IOC_READ, 0xaa01, 0x10 },
 { "linux/userfaultfd.h", "UFFDIO_WAKE", _IOC_READ, 0xaa02, 0x10 },
+{ "linux/userfaultfd.h", "UFFDIO_WRITEPROTECT", _IOC_READ|_IOC_WRITE, 0xaa06, 0x18 },
 { "linux/userfaultfd.h", "UFFDIO_ZEROPAGE", _IOC_READ|_IOC_WRITE, 0xaa04, 0x20 },
 { "linux/uvcvideo.h", "UVCIOC_CTRL_MAP", _IOC_READ|_IOC_WRITE, 0x7520, 0x60 },
 { "linux/uvcvideo.h", "UVCIOC_CTRL_QUERY", _IOC_READ|_IOC_WRITE, 0x7521, 0x10 },
@@ -2179,10 +2213,12 @@
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_G_FMT", _IOC_READ|_IOC_WRITE, 0x5604, 0x58 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_G_FRAME_INTERVAL", _IOC_READ|_IOC_WRITE, 0x5615, 0x30 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_G_SELECTION", _IOC_READ|_IOC_WRITE, 0x563d, 0x40 },
+{ "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_QUERYCAP", _IOC_READ, 0x5600, 0x40 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_S_CROP", _IOC_READ|_IOC_WRITE, 0x563c, 0x38 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_S_FMT", _IOC_READ|_IOC_WRITE, 0x5605, 0x58 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_S_FRAME_INTERVAL", _IOC_READ|_IOC_WRITE, 0x5616, 0x30 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_S_SELECTION", _IOC_READ|_IOC_WRITE, 0x563e, 0x40 },
+{ "linux/vboxguest.h", "VBG_IOCTL_ACQUIRE_GUEST_CAPABILITIES", _IOC_READ|_IOC_WRITE, 0x560d, 0x24 },
 { "linux/vboxguest.h", "VBG_IOCTL_CHANGE_FILTER_MASK", _IOC_READ|_IOC_WRITE, 0x560c, 0x20 },
 { "linux/vboxguest.h", "VBG_IOCTL_CHANGE_GUEST_CAPABILITIES", _IOC_READ|_IOC_WRITE, 0x560e, 0x20 },
 { "linux/vboxguest.h", "VBG_IOCTL_CHECK_BALLOON", _IOC_READ|_IOC_WRITE, 0x5611, 0x20 },
@@ -2190,10 +2226,11 @@
 { "linux/vboxguest.h", "VBG_IOCTL_HGCM_CONNECT", _IOC_READ|_IOC_WRITE, 0x5604, 0x9c },
 { "linux/vboxguest.h", "VBG_IOCTL_HGCM_DISCONNECT", _IOC_READ|_IOC_WRITE, 0x5605, 0x1c },
 { "linux/vboxguest.h", "VBG_IOCTL_INTERRUPT_ALL_WAIT_FOR_EVENTS", _IOC_READ|_IOC_WRITE, 0x560b, 0x18 },
-{ "linux/vboxguest.h", "VBG_IOCTL_VMMDEV_REQUEST_BIG", _IOC_READ|_IOC_WRITE, 0x5603, 0x00 },
+{ "linux/vboxguest.h", "VBG_IOCTL_VMMDEV_REQUEST_BIG", _IOC_NONE, 0x5603, 0x00 },
 { "linux/vboxguest.h", "VBG_IOCTL_WAIT_FOR_EVENTS", _IOC_READ|_IOC_WRITE, 0x560a, 0x20 },
 { "linux/vboxguest.h", "VBG_IOCTL_WRITE_CORE_DUMP", _IOC_READ|_IOC_WRITE, 0x5613, 0x1c },
 { "linux/vfio.h", "VFIO_CHECK_EXTENSION", _IOC_NONE, 0x3b65, 0x00 },
+{ "linux/vfio.h", "VFIO_DEVICE_FEATURE", _IOC_NONE, 0x3b75, 0x00 },
 { "linux/vfio.h", "VFIO_DEVICE_GET_GFX_DMABUF", _IOC_NONE, 0x3b73, 0x00 },
 { "linux/vfio.h", "VFIO_DEVICE_GET_INFO", _IOC_NONE, 0x3b6b, 0x00 },
 { "linux/vfio.h", "VFIO_DEVICE_GET_IRQ_INFO", _IOC_NONE, 0x3b6d, 0x00 },
@@ -2210,6 +2247,7 @@
 { "linux/vfio.h", "VFIO_GROUP_GET_STATUS", _IOC_NONE, 0x3b67, 0x00 },
 { "linux/vfio.h", "VFIO_GROUP_SET_CONTAINER", _IOC_NONE, 0x3b68, 0x00 },
 { "linux/vfio.h", "VFIO_GROUP_UNSET_CONTAINER", _IOC_NONE, 0x3b69, 0x00 },
+{ "linux/vfio.h", "VFIO_IOMMU_DIRTY_PAGES", _IOC_NONE, 0x3b75, 0x00 },
 { "linux/vfio.h", "VFIO_IOMMU_DISABLE", _IOC_NONE, 0x3b74, 0x00 },
 { "linux/vfio.h", "VFIO_IOMMU_ENABLE", _IOC_NONE, 0x3b73, 0x00 },
 { "linux/vfio.h", "VFIO_IOMMU_GET_INFO", _IOC_NONE, 0x3b70, 0x00 },
@@ -2247,6 +2285,14 @@
 { "linux/vhost.h", "VHOST_SET_VRING_ERR", _IOC_WRITE, 0xaf22, 0x08 },
 { "linux/vhost.h", "VHOST_SET_VRING_KICK", _IOC_WRITE, 0xaf20, 0x08 },
 { "linux/vhost.h", "VHOST_SET_VRING_NUM", _IOC_WRITE, 0xaf10, 0x08 },
+{ "linux/vhost.h", "VHOST_VDPA_GET_CONFIG", _IOC_READ, 0xaf73, 0x08 },
+{ "linux/vhost.h", "VHOST_VDPA_GET_DEVICE_ID", _IOC_READ, 0xaf70, 0x04 },
+{ "linux/vhost.h", "VHOST_VDPA_GET_STATUS", _IOC_READ, 0xaf71, 0x01 },
+{ "linux/vhost.h", "VHOST_VDPA_GET_VRING_NUM", _IOC_READ, 0xaf76, 0x02 },
+{ "linux/vhost.h", "VHOST_VDPA_SET_CONFIG", _IOC_WRITE, 0xaf74, 0x08 },
+{ "linux/vhost.h", "VHOST_VDPA_SET_CONFIG_CALL", _IOC_WRITE, 0xaf77, 0x04 },
+{ "linux/vhost.h", "VHOST_VDPA_SET_STATUS", _IOC_WRITE, 0xaf72, 0x01 },
+{ "linux/vhost.h", "VHOST_VDPA_SET_VRING_ENABLE", _IOC_WRITE, 0xaf75, 0x08 },
 { "linux/vhost.h", "VHOST_VSOCK_SET_GUEST_CID", _IOC_WRITE, 0xaf60, 0x08 },
 { "linux/vhost.h", "VHOST_VSOCK_SET_RUNNING", _IOC_WRITE, 0xaf61, 0x04 },
 { "linux/videodev2.h", "VIDIOC_CREATE_BUFS", _IOC_READ|_IOC_WRITE, 0x565c, 0x100 },
@@ -2369,6 +2415,8 @@
 { "linux/vt.h", "VT_WAITACTIVE", 0, 0x5607, 0 },
 { "linux/vt.h", "VT_WAITEVENT", 0, 0x560E, 0 },
 { "linux/vtpm_proxy.h", "VTPM_PROXY_IOC_NEW_DEV", _IOC_READ|_IOC_WRITE, 0xa100, 0x14 },
+{ "linux/watch_queue.h", "IOC_WATCH_QUEUE_SET_FILTER", _IOC_NONE, 0x5761, 0x00 },
+{ "linux/watch_queue.h", "IOC_WATCH_QUEUE_SET_SIZE", _IOC_NONE, 0x5760, 0x00 },
 { "linux/watchdog.h", "WDIOC_GETBOOTSTATUS", _IOC_READ, 0x5702, 0x04 },
 { "linux/watchdog.h", "WDIOC_GETPRETIMEOUT", _IOC_READ, 0x5709, 0x04 },
 { "linux/watchdog.h", "WDIOC_GETSTATUS", _IOC_READ, 0x5701, 0x04 },
@@ -2444,6 +2492,11 @@
 { "media/i2c/saa6588.h", "SAA6588_CMD_READ", _IOC_READ, 0x5203, 0x04 },
 { "media/v4l2-common.h", "TUNER_SET_CONFIG", _IOC_WRITE, 0x645c, 0x10 },
 { "media/v4l2-common.h", "VIDIOC_INT_RESET", _IOC_WRITE, 0x6466, 0x04 },
+{ "media/v4l2-ioctl.h", "VIDIOC_DQBUF_TIME32", _IOC_READ|_IOC_WRITE, 0x5611, 0x50 },
+{ "media/v4l2-ioctl.h", "VIDIOC_DQEVENT_TIME32", _IOC_READ, 0x5659, 0x80 },
+{ "media/v4l2-ioctl.h", "VIDIOC_PREPARE_BUF_TIME32", _IOC_READ|_IOC_WRITE, 0x565d, 0x50 },
+{ "media/v4l2-ioctl.h", "VIDIOC_QBUF_TIME32", _IOC_READ|_IOC_WRITE, 0x560f, 0x50 },
+{ "media/v4l2-ioctl.h", "VIDIOC_QUERYBUF_TIME32", _IOC_READ|_IOC_WRITE, 0x5609, 0x50 },
 { "media/v4l2-subdev.h", "V4L2_DEVICE_NOTIFY_EVENT", _IOC_WRITE, 0x7602, 0x88 },
 { "media/v4l2-subdev.h", "V4L2_SUBDEV_IR_RX_NOTIFY", _IOC_WRITE, 0x7600, 0x04 },
 { "media/v4l2-subdev.h", "V4L2_SUBDEV_IR_TX_NOTIFY", _IOC_WRITE, 0x7601, 0x04 },
@@ -2472,6 +2525,9 @@
 { "misc/ocxl.h", "OCXL_IOCTL_IRQ_ALLOC", _IOC_READ, 0xca11, 0x08 },
 { "misc/ocxl.h", "OCXL_IOCTL_IRQ_FREE", _IOC_WRITE, 0xca12, 0x08 },
 { "misc/ocxl.h", "OCXL_IOCTL_IRQ_SET_FD", _IOC_WRITE, 0xca13, 0x10 },
+{ "misc/uacce/hisi_qm.h", "UACCE_CMD_QM_SET_QP_CTX", _IOC_READ|_IOC_WRITE, 0x480a, 0x04 },
+{ "misc/uacce/uacce.h", "UACCE_CMD_PUT_Q", _IOC_NONE, 0x5701, 0x00 },
+{ "misc/uacce/uacce.h", "UACCE_CMD_START_Q", _IOC_NONE, 0x5700, 0x00 },
 { "misc/xilinx_sdfec.h", "XSDFEC_ADD_LDPC_CODE_PARAMS", _IOC_WRITE, 0x6605, 0x60 },
 { "misc/xilinx_sdfec.h", "XSDFEC_CLEAR_STATS", _IOC_NONE, 0x660b, 0x00 },
 { "misc/xilinx_sdfec.h", "XSDFEC_GET_CONFIG", _IOC_READ, 0x6606, 0x1c },
@@ -2724,7 +2780,8 @@
 { "sound/asound.h", "SNDRV_TIMER_IOCTL_START", _IOC_NONE, 0x54a0, 0x00 },
 { "sound/asound.h", "SNDRV_TIMER_IOCTL_STATUS", _IOC_READ, 0x5414, 0x60 },
 { "sound/asound.h", "SNDRV_TIMER_IOCTL_STOP", _IOC_NONE, 0x54a1, 0x00 },
-{ "sound/asound.h", "SNDRV_TIMER_IOCTL_TREAD", _IOC_WRITE, 0x5402, 0x04 },
+{ "sound/asound.h", "SNDRV_TIMER_IOCTL_TREAD64", _IOC_WRITE, 0x54a4, 0x04 },
+{ "sound/asound.h", "SNDRV_TIMER_IOCTL_TREAD_OLD", _IOC_WRITE, 0x5402, 0x04 },
 { "sound/asound_fm.h", "SNDRV_DM_FM_IOCTL_CLEAR_PATCHES", _IOC_NONE, 0x4840, 0x00 },
 { "sound/asound_fm.h", "SNDRV_DM_FM_IOCTL_INFO", _IOC_READ, 0x4820, 0x02 },
 { "sound/asound_fm.h", "SNDRV_DM_FM_IOCTL_PLAY_NOTE", _IOC_WRITE, 0x4822, 0x0c },
@@ -2782,6 +2839,10 @@
 { "sound/hdspm.h", "SNDRV_HDSPM_IOCTL_GET_PEAK_RMS", _IOC_READ, 0x4842, 0x908 },
 { "sound/hdspm.h", "SNDRV_HDSPM_IOCTL_GET_STATUS", _IOC_READ, 0x4847, 0x20 },
 { "sound/hdspm.h", "SNDRV_HDSPM_IOCTL_GET_VERSION", _IOC_READ, 0x4848, 0x24 },
+{ "sound/pcm.h", "SNDRV_PCM_IOCTL_STATUS32", _IOC_READ, 0x4120, 0x6c },
+{ "sound/pcm.h", "SNDRV_PCM_IOCTL_STATUS64", _IOC_READ, 0x4120, 0x98 },
+{ "sound/pcm.h", "SNDRV_PCM_IOCTL_STATUS_EXT32", _IOC_READ|_IOC_WRITE, 0x4124, 0x6c },
+{ "sound/pcm.h", "SNDRV_PCM_IOCTL_STATUS_EXT64", _IOC_READ|_IOC_WRITE, 0x4124, 0x98 },
 { "sound/sb16_csp.h", "SNDRV_SB_CSP_IOCTL_INFO", _IOC_READ, 0x4810, 0x28 },
 { "sound/sb16_csp.h", "SNDRV_SB_CSP_IOCTL_LOAD_CODE", _IOC_WRITE, 0x4811, 0x3012 },
 { "sound/sb16_csp.h", "SNDRV_SB_CSP_IOCTL_PAUSE", _IOC_NONE, 0x4815, 0x00 },
@@ -2808,15 +2869,6 @@
 { "staging/android/ashmem.h", "ASHMEM_UNPIN", _IOC_WRITE, 0x7708, 0x08 },
 { "staging/android/ion.h", "ION_IOC_ALLOC", _IOC_READ|_IOC_WRITE, 0x4900, 0x18 },
 { "staging/android/ion.h", "ION_IOC_HEAP_QUERY", _IOC_READ|_IOC_WRITE, 0x4908, 0x18 },
-{ "staging/android/vsoc_shm.h", "VSOC_COND_WAIT", _IOC_READ|_IOC_WRITE, 0xf507, 0x20 },
-{ "staging/android/vsoc_shm.h", "VSOC_COND_WAKE", _IOC_NONE, 0xf508, 0x00 },
-{ "staging/android/vsoc_shm.h", "VSOC_CREATE_FD_SCOPED_PERMISSION", _IOC_WRITE, 0xf500, 0x10 },
-{ "staging/android/vsoc_shm.h", "VSOC_DESCRIBE_REGION", _IOC_READ, 0xf504, 0x3c },
-{ "staging/android/vsoc_shm.h", "VSOC_GET_FD_SCOPED_PERMISSION", _IOC_READ, 0xf501, 0x10 },
-{ "staging/android/vsoc_shm.h", "VSOC_MAYBE_SEND_INTERRUPT_TO_HOST", _IOC_NONE, 0xf502, 0x00 },
-{ "staging/android/vsoc_shm.h", "VSOC_SELF_INTERRUPT", _IOC_NONE, 0xf505, 0x00 },
-{ "staging/android/vsoc_shm.h", "VSOC_SEND_INTERRUPT_TO_HOST", _IOC_NONE, 0xf506, 0x00 },
-{ "staging/android/vsoc_shm.h", "VSOC_WAIT_FOR_INCOMING_INTERRUPT", _IOC_NONE, 0xf503, 0x00 },
 { "video/da8xx-fb.h", "FBIGET_BRIGHTNESS", _IOC_READ, 0x4603, 0x04 },
 { "video/da8xx-fb.h", "FBIGET_COLOR", _IOC_READ, 0x4605, 0x04 },
 { "video/da8xx-fb.h", "FBIOGET_CONTRAST", _IOC_READ, 0x4601, 0x04 },
diff -pruN 5.5-3/linux/64/syscallent.h 5.9-0ubuntu2/linux/64/syscallent.h
--- 5.5-3/linux/64/syscallent.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/linux/64/syscallent.h	2020-08-01 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -102,7 +102,7 @@
 [ 94] = { 1,	TP|SE,		SEN(exit),			"exit_group"		},
 [ 95] = { 5,	TP,		SEN(waitid),			"waitid"		},
 [ 96] = { 1,	0,		SEN(set_tid_address),		"set_tid_address"	},
-[ 97] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[ 97] = { 1,	0,		SEN(unshare),			"unshare"		},
 [ 98] = { 6,	0,		SEN(futex_time64),		"futex"			},
 [ 99] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [100] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
@@ -117,9 +117,9 @@
 [109] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [110] = { 4,	0,		SEN(timer_settime64),		"timer_settime"		},
 [111] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[112] = { 2,	0,		SEN(clock_settime64),		"clock_settime"		},
-[113] = { 2,	0,		SEN(clock_gettime64),		"clock_gettime"		},
-[114] = { 2,	0,		SEN(clock_getres_time64),	"clock_getres"		},
+[112] = { 2,	TCL,		SEN(clock_settime64),		"clock_settime"		},
+[113] = { 2,	TCL,		SEN(clock_gettime64),		"clock_gettime"		},
+[114] = { 2,	TCL,		SEN(clock_getres_time64),	"clock_getres"		},
 [115] = { 4,	0,		SEN(clock_nanosleep_time64),	"clock_nanosleep"	},
 [116] = { 3,	0,		SEN(syslog),			"syslog"		},
 [117] = { 4,	0,		SEN(ptrace),			"ptrace"		},
@@ -134,16 +134,16 @@
 [126] = { 1,	0,		SEN(sched_get_priority_min),	"sched_get_priority_min"},
 [127] = { 2,	0,		SEN(sched_rr_get_interval_time64),"sched_rr_get_interval"},
 [128] = { 0,	0,		SEN(restart_syscall),		"restart_syscall"	},
-[129] = { 2,	TS,		SEN(kill),			"kill"			},
-[130] = { 2,	TS,		SEN(kill),			"tkill"			},
-[131] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[129] = { 2,	TS|TP,		SEN(kill),			"kill"			},
+[130] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
+[131] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [132] = { 2,	TS,		SEN(sigaltstack),		"sigaltstack"		},
 [133] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [134] = { 4,	TS,		SEN(rt_sigaction),		"rt_sigaction"		},
 [135] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [136] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [137] = { 4,	TS,		SEN(rt_sigtimedwait_time64),	"rt_sigtimedwait"	},
-[138] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[138] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [139] = { 0,	TS,		SEN(rt_sigreturn),		"rt_sigreturn"		},
 [140] = { 3,	0,		SEN(setpriority),		"setpriority"		},
 [141] = { 2,	0,		SEN(getpriority),		"getpriority"		},
@@ -174,9 +174,9 @@
 [166] = { 1,	NF,		SEN(umask),			"umask"			},
 [167] = { 5,	TC,		SEN(prctl),			"prctl"			},
 [168] = { 3,	0,		SEN(getcpu),			"getcpu"		},
-[169] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
-[170] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
-[171] = { 1,	0,		SEN(adjtimex64),		"adjtimex"		},
+[169] = { 2,	TCL,		SEN(gettimeofday),		"gettimeofday"		},
+[170] = { 2,	TCL,		SEN(settimeofday),		"settimeofday"		},
+[171] = { 1,	TCL,		SEN(adjtimex64),		"adjtimex"		},
 [172] = { 0,	PU|NF,		SEN(getpid),			"getpid"		},
 [173] = { 0,	PU|NF,		SEN(getppid),			"getppid"		},
 [174] = { 0,	TC|PU|NF,	SEN(getuid),			"getuid"		},
@@ -256,7 +256,7 @@
 [263] = { 5,	TD|TF,		SEN(fanotify_mark),		"fanotify_mark"		},
 [264] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [265] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[266] = { 2,	0,		SEN(clock_adjtime64),		"clock_adjtime"		},
+[266] = { 2,	TCL,		SEN(clock_adjtime64),		"clock_adjtime"		},
 [267] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [268] = { 2,	TD,		SEN(setns),			"setns"			},
 [269] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
@@ -281,7 +281,7 @@
 [288] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [289] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
 [290] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
-[291] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[291] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [292] = { 6,	0,		SEN(io_pgetevents_time64),	"io_pgetevents"		},
 [293] = { 4,	0,		SEN(rseq),			"rseq"			},
 [294] = { 5,	TD,		SEN(kexec_file_load),		"kexec_file_load"	},
diff -pruN 5.5-3/linux/alpha/syscallent.h 5.9-0ubuntu2/linux/alpha/syscallent.h
--- 5.5-3/linux/alpha/syscallent.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/linux/alpha/syscallent.h	2020-08-01 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995 Rick Sladkey <jrs@world.std.com>
- * Copyright (c) 1995-2019 The strace developers.
+ * Copyright (c) 1995-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -44,7 +44,7 @@
 [ 34] = { 5,	0,		SEN(printargs),			"osf_chflags"		}, /* not implemented */
 [ 35] = { 5,	0,		SEN(printargs),			"osf_fchflags"		}, /* not implemented */
 [ 36] = { 0,	0,		SEN(sync),			"sync"			},
-[ 37] = { 2,	TS,		SEN(kill),			"kill"			},
+[ 37] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [ 38] = { 5,	TF|TST|TSTA,	SEN(printargs),			"osf_old_stat"		}, /* not implemented */
 [ 39] = { 2,	0,		SEN(setpgid),			"setpgid"		},
 [ 40] = { 5,	TF|TLST|TSTA,	SEN(printargs),			"osf_old_lstat"		}, /* not implemented */
@@ -123,13 +123,13 @@
 [113] = { 3,	TN,		SEN(recvmsg),			"recvmsg"		},
 [114] = { 3,	TN,		SEN(sendmsg),			"sendmsg"		},
 [115] = { 5,	0,		SEN(printargs),			"osf_old_vtrace"	}, /* not implemented */
-[116] = { 2,	0,		SEN(osf_gettimeofday),		"osf_gettimeofday"	},
+[116] = { 2,	TCL,		SEN(osf_gettimeofday),		"osf_gettimeofday"	},
 [117] = { 2,	0,		SEN(osf_getrusage),		"osf_getrusage"		},
 [118] = { 5,	TN,		SEN(getsockopt),		"getsockopt"		},
 [119] = { },
 [120] = { 3,	TD,		SEN(readv),			"readv"			},
 [121] = { 3,	TD,		SEN(writev),			"writev"		},
-[122] = { 2,	0,		SEN(osf_settimeofday),		"osf_settimeofday"	},
+[122] = { 2,	TCL,		SEN(osf_settimeofday),		"osf_settimeofday"	},
 [123] = { 3,	TD,		SEN(fchown),			"fchown"		},
 [124] = { 2,	TD,		SEN(fchmod),			"fchmod"		},
 [125] = { 6,	TN,		SEN(recvfrom),			"recvfrom"		},
@@ -147,13 +147,13 @@
 [137] = { 1,	TF,		SEN(rmdir),			"rmdir"			},
 [138] = { 2,	TF,		SEN(osf_utimes),		"osf_utimes"		},
 [139] = { 5,	0,		SEN(printargs),			"osf_old_sigreturn"	}, /* not implemented */
-[140] = { 5,	0,		SEN(printargs),			"osf_adjtime"		}, /* not implemented */
+[140] = { 5,	TCL,		SEN(printargs),			"osf_adjtime"		}, /* not implemented */
 [141] = { 3,	TN,		SEN(getpeername),		"getpeername"		},
 [142] = { 5,	0,		SEN(printargs),			"osf_gethostid"		}, /* not implemented */
 [143] = { 5,	0,		SEN(printargs),			"osf_sethostid"		}, /* not implemented */
 [144] = { 2,	0,		SEN(getrlimit),			"getrlimit"		},
 [145] = { 2,	0,		SEN(setrlimit),			"setrlimit"		},
-[146] = { 5,	0,		SEN(printargs),			"osf_old_killpg"	}, /* not implemented */
+[146] = { 5,	TP,		SEN(printargs),			"osf_old_killpg"	}, /* not implemented */
 [147] = { 0,	0,		SEN(setsid),			"setsid"		},
 [148] = { 4,	TF,		SEN(quotactl),			"quotactl"		},
 [149] = { 5,	0,		SEN(printargs),			"osf_oldquota"		}, /* not implemented */
@@ -204,7 +204,7 @@
 [217] = { 3,	TM,		SEN(msync),			"msync"			},
 [218] = { 5,	0,		SEN(printargs),			"osf_signal"		}, /* not implemented */
 [219] = { 5,	0,		SEN(printargs),			"osf_utc_gettime"	}, /* not implemented */
-[220] = { 5,	0,		SEN(printargs),			"osf_utc_adjtime"	}, /* not implemented */
+[220] = { 5,	TCL,		SEN(printargs),			"osf_utc_adjtime"	}, /* not implemented */
 [221] = { },
 [222] = { 5,	0,		SEN(printargs),			"osf_security"		}, /* not implemented */
 [223] = { 5,	0,		SEN(printargs),			"osf_kloadcall"		}, /* not implemented */
@@ -226,7 +226,7 @@
 [242] = { 5,	0,		SEN(printargs),			"osf_uadmin"		}, /* not implemented */
 [243] = { 5,	0,		SEN(printargs),			"osf_fuser"		}, /* not implemented */
 [244] = { 2,	0,		SEN(printargs),			"osf_proplist_syscall"	},
-[245] = { 5,	0,		SEN(printargs),			"osf_ntp_adjtime"	}, /* not implemented */
+[245] = { 5,	TCL,		SEN(printargs),			"osf_ntp_adjtime"	}, /* not implemented */
 [246] = { 5,	0,		SEN(printargs),			"osf_ntp_gettime"	}, /* not implemented */
 [247] = { 5,	0,		SEN(printargs),			"osf_pathconf"		}, /* not implemented */
 [248] = { 5,	0,		SEN(printargs),			"osf_fpathconf"		}, /* not implemented */
@@ -247,7 +247,7 @@
 [300] = { 2,	0,		SEN(bdflush),			"bdflush"		},
 [301] = { 1,	0,		SEN(printargs),			"sethae"		},
 [302] = { 5,	TF,		SEN(mount),			"mount"			},
-[303] = { 1,	0,		SEN(adjtimex32),		"old_adjtimex"		},
+[303] = { 1,	TCL,		SEN(adjtimex32),		"old_adjtimex"		},
 [304] = { 1,	TF,		SEN(swapoff),			"swapoff"		},
 [305] = { 3,	TD,		SEN(getdents),			"getdents"		},
 [306] = { 2,	0,		SEN(create_module),		"create_module"		}, /* not implemented */
@@ -300,17 +300,17 @@
 [353] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [354] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [355] = { 4,	TS,		SEN(rt_sigtimedwait_time64),	"rt_sigtimedwait"	},
-[356] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[356] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [357] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [358] = { 5,	TD,		SEN(select),			"select"		},
-[359] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
-[360] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
+[359] = { 2,	TCL,		SEN(gettimeofday),		"gettimeofday"		},
+[360] = { 2,	TCL,		SEN(settimeofday),		"settimeofday"		},
 [361] = { 2,	0,		SEN(getitimer),			"getitimer"		},
 [362] = { 3,	0,		SEN(setitimer),			"setitimer"		},
 [363] = { 2,	TF,		SEN(utimes),			"utimes"		},
 [364] = { 2,	0,		SEN(getrusage),			"getrusage"		},
 [365] = { 4,	TP,		SEN(wait4),			"wait4"			},
-[366] = { 1,	0,		SEN(adjtimex64),		"adjtimex"		},
+[366] = { 1,	TCL,		SEN(adjtimex64),		"adjtimex"		},
 [367] = { 2,	TF,		SEN(getcwd),			"getcwd"		},
 [368] = { 2,	TC,		SEN(capget),			"capget"		},
 [369] = { 2,	TC,		SEN(capset),			"capset"		},
@@ -325,7 +325,7 @@
 [378] = { 0,	PU|NF,		SEN(gettid),			"gettid"		},
 [379] = { 3,	TD,		SEN(readahead),			"readahead"		},
 [380] = { },
-[381] = { 2,	TS,		SEN(kill),			"tkill"			},
+[381] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [382] = { 5,	TF,		SEN(setxattr),			"setxattr"		},
 [383] = { 5,	TF,		SEN(setxattr),			"lsetxattr"		},
 [384] = { 5,	TD,		SEN(fsetxattr),			"fsetxattr"		},
@@ -362,12 +362,12 @@
 [416] = { 2,	0,		SEN(timer_gettime64),		"timer_gettime"		},
 [417] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [418] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[419] = { 2,	0,		SEN(clock_settime64),		"clock_settime"		},
-[420] = { 2,	0,		SEN(clock_gettime64),		"clock_gettime"		},
-[421] = { 2,	0,		SEN(clock_getres_time64),	"clock_getres"		},
+[419] = { 2,	TCL,		SEN(clock_settime64),		"clock_settime"		},
+[420] = { 2,	TCL,		SEN(clock_gettime64),		"clock_gettime"		},
+[421] = { 2,	TCL,		SEN(clock_getres_time64),	"clock_getres"		},
 [422] = { 4,	0,		SEN(clock_nanosleep_time64),	"clock_nanosleep"	},
 [423] = { 4,	TI,		SEN(semtimedop_time64),		"semtimedop"		},
-[424] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[424] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [425] = { 2,	TF|TST|TSTA,	SEN(stat64),			"stat64"		},
 [426] = { 2,	TF|TLST|TSTA,	SEN(lstat64),			"lstat64"		},
 [427] = { 2,	TD|TFST|TSTA,	SEN(fstat64),			"fstat64"		},
@@ -408,7 +408,7 @@
 [462] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [463] = { 6,	TD,		SEN(pselect6_time64),		"pselect6"		},
 [464] = { 5,	TD,		SEN(ppoll_time64),		"ppoll"			},
-[465] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[465] = { 1,	0,		SEN(unshare),			"unshare"		},
 [466] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [467] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
 [468] = { 6,	TD,		SEN(splice),			"splice"		},
@@ -442,7 +442,7 @@
 [496] = { 4,	0,		SEN(prlimit64),			"prlimit64"		},
 [497] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [498] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[499] = { 2,	0,		SEN(clock_adjtime64),		"clock_adjtime"		},
+[499] = { 2,	TCL,		SEN(clock_adjtime64),		"clock_adjtime"		},
 [500] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [501] = { 2,	TD,		SEN(setns),			"setns"			},
 [502] = { 4,	TN,		SEN(accept4),			"accept4"		},
@@ -465,7 +465,7 @@
 [519] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
 [520] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
 [521] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
-[522] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[522] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [523] = { 6,	0,		SEN(io_pgetevents_time64),	"io_pgetevents"		},
 [524] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [525] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
diff -pruN 5.5-3/linux/arch_defs_.h 5.9-0ubuntu2/linux/arch_defs_.h
--- 5.5-3/linux/arch_defs_.h	2019-05-05 22:28:34.000000000 +0000
+++ 5.9-0ubuntu2/linux/arch_defs_.h	2020-06-01 14:15:16.000000000 +0000
@@ -1,16 +1,12 @@
 /*
  * Fallback file for arch-specific definitions.
  *
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifndef ARCH_TIMESIZE
-# define ARCH_TIMESIZE SIZEOF_LONG
-#endif
-
 #ifndef HAVE_ARCH_GETRVAL2
 # define HAVE_ARCH_GETRVAL2 0
 #endif
@@ -66,3 +62,15 @@
 #ifndef HAVE_ARCH_OLD_TIME64_SYSCALLS
 # define HAVE_ARCH_OLD_TIME64_SYSCALLS (SIZEOF_LONG == 8)
 #endif
+
+#ifndef MIN_KLONGSIZE
+# if SUPPORTED_PERSONALITIES > 1
+#  define MIN_KLONGSIZE 4
+# else
+#  define MIN_KLONGSIZE SIZEOF_KERNEL_LONG_T
+# endif
+#endif
+
+#ifndef HAVE_ARCH_TIMESPEC32
+# define HAVE_ARCH_TIMESPEC32 (MIN_KLONGSIZE == 4)
+#endif
diff -pruN 5.5-3/linux/arm/syscallent.h 5.9-0ubuntu2/linux/arm/syscallent.h
--- 5.5-3/linux/arm/syscallent.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/linux/arm/syscallent.h	2020-08-01 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995 Rick Sladkey <jrs@world.std.com>
- * Copyright (c) 1995-2019 The strace developers.
+ * Copyright (c) 1995-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -20,7 +20,7 @@
 [ 10] = { 1,	TF,		SEN(unlink),			"unlink"		},
 [ 11] = { 3,	TF|TP|TSD|SE|SI,	SEN(execve),			"execve"		},
 [ 12] = { 1,	TF,		SEN(chdir),			"chdir"			},
-[ 13] = { 1,	0,		SEN(time),			"time"			},
+[ 13] = { 1,	TCL,		SEN(time),			"time"			},
 [ 14] = { 3,	TF,		SEN(mknod),			"mknod"			},
 [ 15] = { 2,	TF,		SEN(chmod),			"chmod"			},
 [ 16] = { 3,	TF,		SEN(chown16),			"lchown"		},
@@ -44,7 +44,7 @@
 [ 34] = { 1,	0,		SEN(nice),			"nice"			},
 [ 35] = { 0,	0,		SEN(ftime),			"ftime"			},
 [ 36] = { 0,	0,		SEN(sync),			"sync"			},
-[ 37] = { 2,	TS,		SEN(kill),			"kill"			},
+[ 37] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [ 38] = { 2,	TF,		SEN(rename),			"rename"		},
 [ 39] = { 2,	TF,		SEN(mkdir),			"mkdir"			},
 [ 40] = { 1,	TF,		SEN(rmdir),			"rmdir"			},
@@ -85,8 +85,8 @@
 [ 75] = { 2,	0,		SEN(setrlimit),			"setrlimit"		},
 [ 76] = { 2,	0,		SEN(getrlimit),			"getrlimit"		},
 [ 77] = { 2,	0,		SEN(getrusage),			"getrusage"		},
-[ 78] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
-[ 79] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
+[ 78] = { 2,	TCL,		SEN(gettimeofday),		"gettimeofday"		},
+[ 79] = { 2,	TCL,		SEN(settimeofday),		"settimeofday"		},
 [ 80] = { 2,	TC,		SEN(getgroups16),		"getgroups"		},
 [ 81] = { 2,	TC,		SEN(setgroups16),		"setgroups"		},
 [ 82] = { 1,	TD,		SEN(oldselect),			"select"		},
@@ -131,7 +131,7 @@
 [121] = { 2,	0,		SEN(setdomainname),		"setdomainname"		},
 [122] = { 1,	0,		SEN(uname),			"uname"			},
 [123] = { 3,	0,		SEN(modify_ldt),		"modify_ldt"		},
-[124] = { 1,	0,		SEN(adjtimex32),		"adjtimex"		},
+[124] = { 1,	TCL,		SEN(adjtimex32),		"adjtimex"		},
 [125] = { 3,	TM|SI,		SEN(mprotect),			"mprotect"		},
 [126] = { 3,	TS,		SEN(sigprocmask),		"sigprocmask"		},
 [127] = { 2,	0,		SEN(create_module),		"create_module"		},
@@ -185,7 +185,7 @@
 [175] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [176] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [177] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
-[178] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[178] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [179] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [180] = { 6,	TD,		SEN(pread),			"pread64"		},
 [181] = { 6,	TD,		SEN(pwrite),			"pwrite64"		},
@@ -245,7 +245,7 @@
 [235] = { 2,	TF,		SEN(removexattr),		"removexattr"		},
 [236] = { 2,	TF,		SEN(removexattr),		"lremovexattr"		},
 [237] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
-[238] = { 2,	TS,		SEN(kill),			"tkill"			},
+[238] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [239] = { 4,	TD|TN,		SEN(sendfile64),		"sendfile64"		},
 [240] = { 6,	0,		SEN(futex_time32),		"futex"			},
 [241] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
@@ -269,13 +269,13 @@
 [259] = { 2,	0,		SEN(timer_gettime32),		"timer_gettime"		},
 [260] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [261] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[262] = { 2,	0,		SEN(clock_settime32),		"clock_settime"		},
-[263] = { 2,	0,		SEN(clock_gettime32),		"clock_gettime"		},
-[264] = { 2,	0,		SEN(clock_getres_time32),	"clock_getres"		},
+[262] = { 2,	TCL,		SEN(clock_settime32),		"clock_settime"		},
+[263] = { 2,	TCL,		SEN(clock_gettime32),		"clock_gettime"		},
+[264] = { 2,	TCL,		SEN(clock_getres_time32),	"clock_getres"		},
 [265] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
 [266] = { 3,	TF|TSF|TSFA,	SEN(statfs64),			"statfs64"		},
 [267] = { 3,	TD|TFSF|TSFA,	SEN(fstatfs64),			"fstatfs64"		},
-[268] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[268] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [269] = { 2,	TF,		SEN(utimes),			"utimes"		},
 [270] = { 6,	TD,		SEN(fadvise64_64),		"fadvise64_64"		},
 [271] = { 3,	0,		SEN(printargs),			"pciconfig_iobase"	},
@@ -344,7 +344,7 @@
 [334] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [335] = { 6,	TD,		SEN(pselect6_time32),		"pselect6"		},
 [336] = { 5,	TD,		SEN(ppoll_time32),		"ppoll"			},
-[337] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[337] = { 1,	0,		SEN(unshare),			"unshare"		},
 [338] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [339] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
 [340] = { 6,	TD,		SEN(splice),			"splice"		},
@@ -379,7 +379,7 @@
 [369] = { 4,	0,		SEN(prlimit64),			"prlimit64"		},
 [370] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [371] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[372] = { 2,	0,		SEN(clock_adjtime32),		"clock_adjtime"		},
+[372] = { 2,	TCL,		SEN(clock_adjtime32),		"clock_adjtime"		},
 [373] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [374] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
 [375] = { 2,	TD,		SEN(setns),			"setns"			},
@@ -404,7 +404,7 @@
 [394] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [395] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
 [396] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
-[397] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[397] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [398] = { 4,	0,		SEN(rseq),			"rseq"			},
 [399] = { 6,	0,		SEN(io_pgetevents_time32),	"io_pgetevents"		},
 [400] = { 4,	TM,		SEN(migrate_pages),		"migrate_pages"		},
diff -pruN 5.5-3/linux/avr32/syscallent.h 5.9-0ubuntu2/linux/avr32/syscallent.h
--- 5.5-3/linux/avr32/syscallent.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/linux/avr32/syscallent.h	2020-08-01 08:00:00.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2004-2009 Atmel Corporation
- * Copyright (c) 2009-2019 The strace developers.
+ * Copyright (c) 2009-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -19,7 +19,7 @@
 [ 10] = { 1,	TF,		SEN(unlink),			"unlink"		},
 [ 11] = { 3,	TF|TP|TSD|SE|SI,	SEN(execve),			"execve"		},
 [ 12] = { 1,	TF,		SEN(chdir),			"chdir"			},
-[ 13] = { 1,	0,		SEN(time),			"time"			},
+[ 13] = { 1,	TCL,		SEN(time),			"time"			},
 [ 14] = { 3,	TF,		SEN(mknod),			"mknod"			},
 [ 15] = { 2,	TF,		SEN(chmod),			"chmod"			},
 [ 16] = { 3,	TF,		SEN(chown),			"chown"			},
@@ -43,7 +43,7 @@
 [ 34] = { 1,	TF,		SEN(chroot),			"chroot"		},
 [ 35] = { 0,	0,		SEN(sync),			"sync"			},
 [ 36] = { 1,	TD,		SEN(fsync),			"fsync"			},
-[ 37] = { 2,	TS,		SEN(kill),			"kill"			},
+[ 37] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [ 38] = { 2,	TF,		SEN(rename),			"rename"		},
 [ 39] = { 2,	TF,		SEN(mkdir),			"mkdir"			},
 [ 40] = { 1,	TF,		SEN(rmdir),			"rmdir"			},
@@ -78,14 +78,14 @@
 [ 69] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [ 70] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [ 71] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
-[ 72] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[ 72] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [ 73] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [ 74] = { 2,	0,		SEN(sethostname),		"sethostname"		},
 [ 75] = { 2,	0,		SEN(setrlimit),			"setrlimit"		},
 [ 76] = { 2,	0,		SEN(getrlimit),			"getrlimit"		},
 [ 77] = { 2,	0,		SEN(getrusage),			"getrusage"		},
-[ 78] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
-[ 79] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
+[ 78] = { 2,	TCL,		SEN(gettimeofday),		"gettimeofday"		},
+[ 79] = { 2,	TCL,		SEN(settimeofday),		"settimeofday"		},
 [ 80] = { 2,	TC,		SEN(getgroups),			"getgroups"		},
 [ 81] = { 2,	TC,		SEN(setgroups),			"setgroups"		},
 [ 82] = { 5,	TD,		SEN(select),			"select"		},
@@ -118,7 +118,7 @@
 [109] = { 4,	TD|TN,		SEN(sendfile),			"sendfile"		},
 [110] = { 2,	0,		SEN(setdomainname),		"setdomainname"		},
 [111] = { 1,	0,		SEN(uname),			"uname"			},
-[112] = { 1,	0,		SEN(adjtimex32),		"adjtimex"		},
+[112] = { 1,	TCL,		SEN(adjtimex32),		"adjtimex"		},
 [113] = { 3,	TM|SI,		SEN(mprotect),			"mprotect"		},
 [114] = { 0,	TP,		SEN(vfork),			"vfork"			},
 [115] = { 3,	0,		SEN(init_module),		"init_module"		},
@@ -196,7 +196,7 @@
 [187] = { 2,	TF,		SEN(removexattr),		"removexattr"		},
 [188] = { 2,	TF,		SEN(removexattr),		"lremovexattr"		},
 [189] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
-[190] = { 2,	TS,		SEN(kill),			"tkill"			},
+[190] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [191] = { 4,	TD|TN,		SEN(sendfile64),		"sendfile64"		},
 [192] = { 6,	0,		SEN(futex_time32),		"futex"			},
 [193] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
@@ -221,13 +221,13 @@
 [212] = { 2,	0,		SEN(timer_gettime32),		"timer_gettime"		},
 [213] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [214] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[215] = { 2,	0,		SEN(clock_settime32),		"clock_settime"		},
-[216] = { 2,	0,		SEN(clock_gettime32),		"clock_gettime"		},
-[217] = { 2,	0,		SEN(clock_getres_time32),	"clock_getres"		},
+[215] = { 2,	TCL,		SEN(clock_settime32),		"clock_settime"		},
+[216] = { 2,	TCL,		SEN(clock_gettime32),		"clock_gettime"		},
+[217] = { 2,	TCL,		SEN(clock_getres_time32),	"clock_getres"		},
 [218] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
 [219] = { 3,	TF|TSF|TSFA,	SEN(statfs64),			"statfs64"		},
 [220] = { 3,	TD|TFSF|TSFA,	SEN(fstatfs64),			"fstatfs64"		},
-[221] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[221] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [222] = { },
 [223] = { 2,	TF,		SEN(utimes),			"utimes"		},
 [224] = { 6,	TD,		SEN(fadvise64_64),		"fadvise64_64"		},
@@ -264,7 +264,7 @@
 [255] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [256] = { 6,	TD,		SEN(pselect6_time32),		"pselect6"		},
 [257] = { 5,	TD,		SEN(ppoll_time32),		"ppoll"			},
-[258] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[258] = { 1,	0,		SEN(unshare),			"unshare"		},
 [259] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [260] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
 [261] = { 6,	TD,		SEN(splice),			"splice"		},
@@ -312,7 +312,7 @@
 [303] = { 4,	0,		SEN(prlimit64),			"prlimit64"		},
 [304] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [305] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[306] = { 2,	0,		SEN(clock_adjtime32),		"clock_adjtime"		},
+[306] = { 2,	TCL,		SEN(clock_adjtime32),		"clock_adjtime"		},
 [307] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [308] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
 [309] = { 6,	0,		SEN(process_vm_readv),		"process_vm_readv"	},
diff -pruN 5.5-3/linux/bfin/syscallent.h 5.9-0ubuntu2/linux/bfin/syscallent.h
--- 5.5-3/linux/bfin/syscallent.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/linux/bfin/syscallent.h	2020-08-01 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995 Rick Sladkey <jrs@world.std.com>
- * Copyright (c) 1995-2019 The strace developers.
+ * Copyright (c) 1995-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -20,7 +20,7 @@
 [ 10] = { 1,	TF,		SEN(unlink),			"unlink"		},
 [ 11] = { 3,	TF|TP|TSD|SE|SI,	SEN(execve),			"execve"		},
 [ 12] = { 1,	TF,		SEN(chdir),			"chdir"			},
-[ 13] = { 1,	0,		SEN(time),			"time"			},
+[ 13] = { 1,	TCL,		SEN(time),			"time"			},
 [ 14] = { 3,	TF,		SEN(mknod),			"mknod"			},
 [ 15] = { 2,	TF,		SEN(chmod),			"chmod"			},
 [ 16] = { 3,	TF,		SEN(chown16),			"chown"			},
@@ -44,7 +44,7 @@
 [ 34] = { 1,	0,		SEN(nice),			"nice"			},
 [ 35] = { 0,	0,		SEN(ftime),			"ftime"			},
 [ 36] = { 0,	0,		SEN(sync),			"sync"			},
-[ 37] = { 2,	TS,		SEN(kill),			"kill"			},
+[ 37] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [ 38] = { 2,	TF,		SEN(rename),			"rename"		},
 [ 39] = { 2,	TF,		SEN(mkdir),			"mkdir"			},
 [ 40] = { 1,	TF,		SEN(rmdir),			"rmdir"			},
@@ -85,8 +85,8 @@
 [ 75] = { 2,	0,		SEN(setrlimit),			"setrlimit"		},
 [ 76] = { 2,	0,		SEN(getrlimit),			"old_getrlimit"		},
 [ 77] = { 2,	0,		SEN(getrusage),			"getrusage"		},
-[ 78] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
-[ 79] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
+[ 78] = { 2,	TCL,		SEN(gettimeofday),		"gettimeofday"		},
+[ 79] = { 2,	TCL,		SEN(settimeofday),		"settimeofday"		},
 [ 80] = { 2,	TC,		SEN(getgroups16),		"getgroups"		},
 [ 81] = { 2,	TC,		SEN(setgroups16),		"setgroups"		},
 [ 82] = { 1,	TD,		SEN(oldselect),			"select"		},
@@ -131,7 +131,7 @@
 [121] = { 2,	0,		SEN(setdomainname),		"setdomainname"		},
 [122] = { 1,	0,		SEN(uname),			"uname"			},
 [123] = { 3,	0,		SEN(modify_ldt),		"modify_ldt"		},
-[124] = { 1,	0,		SEN(adjtimex32),		"adjtimex"		},
+[124] = { 1,	TCL,		SEN(adjtimex32),		"adjtimex"		},
 [125] = { 3,	TM|SI,		SEN(mprotect),			"mprotect"		},
 [126] = { 3,	TS,		SEN(sigprocmask),		"sigprocmask"		},
 [127] = { 2,	0,		SEN(create_module),		"create_module"		},
@@ -185,7 +185,7 @@
 [175] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [176] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [177] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
-[178] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[178] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [179] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [180] = { 5,	TD,		SEN(pread),			"pread"			},
 [181] = { 5,	TD,		SEN(pwrite),			"pwrite"		},
@@ -244,7 +244,7 @@
 [235] = { 2,	TF,		SEN(removexattr),		"removexattr"		},
 [236] = { 2,	TF,		SEN(removexattr),		"lremovexattr"		},
 [237] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
-[238] = { 2,	TS,		SEN(kill),			"tkill"			},
+[238] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [239] = { 4,	TD|TN,		SEN(sendfile64),		"sendfile64"		},
 [240] = { 6,	0,		SEN(futex_time32),		"futex"			},
 [241] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
@@ -271,13 +271,13 @@
 [262] = { 2,	0,		SEN(timer_gettime32),		"timer_gettime"		},
 [263] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [264] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[265] = { 2,	0,		SEN(clock_settime32),		"clock_settime"		},
-[266] = { 2,	0,		SEN(clock_gettime32),		"clock_gettime"		},
-[267] = { 2,	0,		SEN(clock_getres_time32),	"clock_getres"		},
+[265] = { 2,	TCL,		SEN(clock_settime32),		"clock_settime"		},
+[266] = { 2,	TCL,		SEN(clock_gettime32),		"clock_gettime"		},
+[267] = { 2,	TCL,		SEN(clock_getres_time32),	"clock_getres"		},
 [268] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
 [269] = { 3,	TF|TSF|TSFA,	SEN(statfs64),			"statfs64"		},
 [270] = { 3,	TD|TFSF|TSFA,	SEN(fstatfs64),			"fstatfs64"		},
-[271] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[271] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [272] = { 2,	TF,		SEN(utimes),			"utimes"		},
 [273] = { 6,	TD,		SEN(fadvise64_64),		"fadvise64_64"		},
 [274] = { 5,	0,		SEN(vserver),			"vserver"		},
@@ -316,7 +316,7 @@
 [307] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [308] = { 6,	TD,		SEN(pselect6_time32),		"pselect6"		},
 [309] = { 5,	TD,		SEN(ppoll_time32),		"ppoll"			},
-[310] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[310] = { 1,	0,		SEN(unshare),			"unshare"		},
 [311] = { 2,	0,		SEN(sram_alloc),		"sram_alloc"		},
 [312] = { 1,	0,		SEN(printargs),			"sram_free"		},
 [313] = { 3,	0,		SEN(printargs),			"dma_memcpy"		},
@@ -383,7 +383,7 @@
 [374] = { 3,	0,		SEN(cacheflush),		"cacheflush"		},
 [375] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [376] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[377] = { 2,	0,		SEN(clock_adjtime32),		"clock_adjtime"		},
+[377] = { 2,	TCL,		SEN(clock_adjtime32),		"clock_adjtime"		},
 [378] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [379] = { 2,	TD,		SEN(setns),			"setns"			},
 [380] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
diff -pruN 5.5-3/linux/csky/get_scno.c 5.9-0ubuntu2/linux/csky/get_scno.c
--- 5.5-3/linux/csky/get_scno.c	2019-03-24 12:12:58.000000000 +0000
+++ 5.9-0ubuntu2/linux/csky/get_scno.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -12,7 +12,7 @@ arch_get_scno(struct tcb *tcp)
 #if defined(__CSKYABIV2__)
 	tcp->scno = csky_regs.regs[3];
 #else
-	tcp->scno = csky_regs.r1;
+	tcp->scno = csky_regs.a1;
 #endif
 	return 1;
 }
diff -pruN 5.5-3/linux/csky/set_scno.c 5.9-0ubuntu2/linux/csky/set_scno.c
--- 5.5-3/linux/csky/set_scno.c	2019-08-15 20:23:19.000000000 +0000
+++ 5.9-0ubuntu2/linux/csky/set_scno.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -13,7 +13,7 @@ arch_set_scno(struct tcb *tcp, kernel_ul
 #if defined(__CSKYABIV2__)
 	csky_regs.regs[3] = scno;
 #else
-	csky_regs.r1 = scno;
+	csky_regs.a1 = scno;
 #endif
 	return set_regs(tcp->pid);
 }
diff -pruN 5.5-3/linux/dummy.h 5.9-0ubuntu2/linux/dummy.h
--- 5.5-3/linux/dummy.h	2019-07-09 15:42:40.000000000 +0000
+++ 5.9-0ubuntu2/linux/dummy.h	2020-09-23 16:29:35.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995 Rick Sladkey <jrs@world.std.com>
- * Copyright (c) 1995-2019 The strace developers.
+ * Copyright (c) 1995-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -53,6 +53,7 @@
 # define sys_getgid		sys_getuid
 # define sys_getgid16		sys_getuid16
 # define sys_getpeername		sys_getsockname
+# define sys_getppid		sys_getpid
 # define sys_getresgid		sys_getresuid
 # define sys_getresgid16		sys_getresuid16
 # define sys_lstat		sys_stat
@@ -87,10 +88,6 @@
 # define sys_vfork		sys_fork
 
 /* printargs does the right thing */
-# define sys_getpgrp		printargs
-# define sys_getpid		printargs
-# define sys_getppid		printargs
-# define sys_gettid		printargs
 # define sys_idle		printargs
 # define sys_munlockall		printargs
 # define sys_pause		printargs
@@ -108,10 +105,7 @@
 
 /* printargs_d does the right thing */
 # define sys_exit		printargs_d
-# define sys_getpgid		printargs_d
-# define sys_getsid		printargs_d
 # define sys_nice		printargs_d
-# define sys_setpgid		printargs_d
 # define sys_setpgrp		printargs_d
 # define sys_timer_delete	printargs_d
 # define sys_timer_getoverrun	printargs_d
diff -pruN 5.5-3/linux/hppa/arch_regs.c 5.9-0ubuntu2/linux/hppa/arch_regs.c
--- 5.5-3/linux/hppa/arch_regs.c	2019-03-18 02:40:16.000000000 +0000
+++ 5.9-0ubuntu2/linux/hppa/arch_regs.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,14 +1,11 @@
 /*
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-static unsigned long hppa_r28;
-
-#define PT_GR20 offsetof(struct pt_regs, gr[20])
-#define PT_GR28 offsetof(struct pt_regs, gr[28])
-
-#define ARCH_PC_PEEK_ADDR offsetof(struct pt_regs, iaoq[0])
-#define ARCH_SP_PEEK_ADDR offsetof(struct pt_regs, gr[30])
+static struct user_regs_struct hppa_regs;
+#define ARCH_REGS_FOR_GETREGS hppa_regs
+#define ARCH_PC_REG hppa_regs.iaoq[0]
+#define ARCH_SP_REG hppa_regs.gr[30]
diff -pruN 5.5-3/linux/hppa/get_error.c 5.9-0ubuntu2/linux/hppa/get_error.c
--- 5.5-3/linux/hppa/get_error.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/linux/hppa/get_error.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -10,10 +10,10 @@
 static void
 arch_get_error(struct tcb *tcp, const bool check_errno)
 {
-	if (check_errno && is_negated_errno(hppa_r28)) {
+	if (check_errno && is_negated_errno(hppa_regs.gr[28])) {
 		tcp->u_rval = -1;
-		tcp->u_error = -hppa_r28;
+		tcp->u_error = -hppa_regs.gr[28];
 	} else {
-		tcp->u_rval = hppa_r28;
+		tcp->u_rval = hppa_regs.gr[28];
 	}
 }
diff -pruN 5.5-3/linux/hppa/get_scno.c 5.9-0ubuntu2/linux/hppa/get_scno.c
--- 5.5-3/linux/hppa/get_scno.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/linux/hppa/get_scno.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -9,5 +9,6 @@
 static int
 arch_get_scno(struct tcb *tcp)
 {
-	return upeek(tcp, PT_GR20, &tcp->scno) < 0 ? -1 : 1;
+	tcp->scno = hppa_regs.gr[20];
+	return 1;
 }
diff -pruN 5.5-3/linux/hppa/get_syscall_args.c 5.9-0ubuntu2/linux/hppa/get_syscall_args.c
--- 5.5-3/linux/hppa/get_syscall_args.c	2019-03-18 02:40:16.000000000 +0000
+++ 5.9-0ubuntu2/linux/hppa/get_syscall_args.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -9,11 +9,7 @@
 static int
 arch_get_syscall_args(struct tcb *tcp)
 {
-	for (unsigned int i = 0; i < n_args(tcp); ++i) {
-		unsigned int addr = offsetof(struct pt_regs, gr[26 - i]);
-
-		if (upeek(tcp, addr, &tcp->u_arg[i]) < 0)
-			return -1;
-	}
+	for (unsigned int i = 0; i < n_args(tcp); ++i)
+		tcp->u_arg[i] = hppa_regs.gr[26 - i];
 	return 1;
 }
diff -pruN 5.5-3/linux/hppa/get_syscall_result.c 5.9-0ubuntu2/linux/hppa/get_syscall_result.c
--- 5.5-3/linux/hppa/get_syscall_result.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/linux/hppa/get_syscall_result.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-/*
- * Copyright (c) 2015-2018 The strace developers.
- * All rights reserved.
- *
- * SPDX-License-Identifier: LGPL-2.1-or-later
- */
-
-static int
-get_syscall_result_regs(struct tcb *tcp)
-{
-	return upeek(tcp, PT_GR28, &hppa_r28) < 0 ? -1 : 0;
-}
diff -pruN 5.5-3/linux/hppa/set_error.c 5.9-0ubuntu2/linux/hppa/set_error.c
--- 5.5-3/linux/hppa/set_error.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/linux/hppa/set_error.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -8,13 +8,13 @@
 static int
 arch_set_error(struct tcb *tcp)
 {
-	hppa_r28 = -tcp->u_error;
-	return upoke(tcp, PT_GR28, hppa_r28);
+	hppa_regs.gr[28] = -tcp->u_error;
+	return set_regs(tcp->pid);
 }
 
 static int
 arch_set_success(struct tcb *tcp)
 {
-	hppa_r28 = tcp->u_rval;
-	return upoke(tcp, PT_GR28, hppa_r28);
+	hppa_regs.gr[28] = tcp->u_rval;
+	return set_regs(tcp->pid);
 }
diff -pruN 5.5-3/linux/hppa/set_scno.c 5.9-0ubuntu2/linux/hppa/set_scno.c
--- 5.5-3/linux/hppa/set_scno.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/linux/hppa/set_scno.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -8,5 +8,8 @@
 static int
 arch_set_scno(struct tcb *tcp, kernel_ulong_t scno)
 {
-	return upoke(tcp, PT_GR20, scno);
+	if (ptrace_syscall_info_is_valid() && get_regs(tcp) < 0)
+		return -1;
+	hppa_regs.gr[20] = scno;
+	return set_regs(tcp->pid);
 }
diff -pruN 5.5-3/linux/hppa/syscallent.h 5.9-0ubuntu2/linux/hppa/syscallent.h
--- 5.5-3/linux/hppa/syscallent.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/linux/hppa/syscallent.h	2020-08-01 08:00:00.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2001 Hewlett-Packard, Matthew Wilcox
- * Copyright (c) 2001-2019 The strace developers.
+ * Copyright (c) 2001-2020 The strace developers.
  */
 
 [  0] = { 0,	0,		SEN(restart_syscall),		"restart_syscall"	},
@@ -16,7 +16,7 @@
 [ 10] = { 1,	TF,		SEN(unlink),			"unlink"		},
 [ 11] = { 3,	TF|TP|TSD|SE|SI,	SEN(execve),			"execve"		},
 [ 12] = { 1,	TF,		SEN(chdir),			"chdir"			},
-[ 13] = { 1,	0,		SEN(time),			"time"			},
+[ 13] = { 1,	TCL,		SEN(time),			"time"			},
 [ 14] = { 3,	TF,		SEN(mknod),			"mknod"			},
 [ 15] = { 2,	TF,		SEN(chmod),			"chmod"			},
 [ 16] = { 3,	TF,		SEN(chown),			"lchown"		},
@@ -40,7 +40,7 @@
 [ 34] = { 1,	0,		SEN(nice),			"nice"			},
 [ 35] = { 3,	TN,		SEN(accept),			"accept"		},
 [ 36] = { 0,	0,		SEN(sync),			"sync"			},
-[ 37] = { 2,	TS,		SEN(kill),			"kill"			},
+[ 37] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [ 38] = { 2,	TF,		SEN(rename),			"rename"		},
 [ 39] = { 2,	TF,		SEN(mkdir),			"mkdir"			},
 [ 40] = { 1,	TF,		SEN(rmdir),			"rmdir"			},
@@ -81,8 +81,8 @@
 [ 75] = { 2,	0,		SEN(setrlimit),			"setrlimit"		},
 [ 76] = { 2,	0,		SEN(getrlimit),			"getrlimit"		},
 [ 77] = { 2,	0,		SEN(getrusage),			"getrusage"		},
-[ 78] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
-[ 79] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
+[ 78] = { 2,	TCL,		SEN(gettimeofday),		"gettimeofday"		},
+[ 79] = { 2,	TCL,		SEN(settimeofday),		"settimeofday"		},
 [ 80] = { 2,	TC,		SEN(getgroups),			"getgroups"		},
 [ 81] = { 2,	TC,		SEN(setgroups),			"setgroups"		},
 [ 82] = { 6,	TN,		SEN(sendto),			"sendto"		},
@@ -127,7 +127,7 @@
 [121] = { 2,	0,		SEN(setdomainname),		"setdomainname"		},
 [122] = { 4,	TD|TN,		SEN(sendfile),			"sendfile"		},
 [123] = { 6,	TN,		SEN(recvfrom),			"recvfrom"		},
-[124] = { 1,	0,		SEN(adjtimex32),		"adjtimex"		},
+[124] = { 1,	TCL,		SEN(adjtimex32),		"adjtimex"		},
 [125] = { 3,	TM|SI,		SEN(mprotect),			"mprotect"		},
 [126] = { 3,	TS,		SEN(sigprocmask),		"sigprocmask"		},
 [127] = { 2,	0,		SEN(create_module),		"create_module"		},
@@ -181,7 +181,7 @@
 [175] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [176] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [177] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
-[178] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[178] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [179] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [180] = { 3,	TF,		SEN(chown),			"chown"			},
 [181] = { 5,	TN,		SEN(setsockopt),		"setsockopt"		},
@@ -211,7 +211,7 @@
 [205] = { 5,	0,		SEN(printargs),			"acl_set"		},
 [206] = { 0,	PU|NF,		SEN(gettid),			"gettid"		},
 [207] = { 4,	TD,		SEN(readahead),			"readahead"		},
-[208] = { 2,	TS,		SEN(kill),			"tkill"			},
+[208] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [209] = { 4,	TD|TN,		SEN(sendfile64),		"sendfile64"		},
 [210] = { 6,	0,		SEN(futex_time32),		"futex"			},
 [211] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
@@ -258,11 +258,11 @@
 [252] = { 2,	0,		SEN(timer_gettime32),		"timer_gettime"		},
 [253] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [254] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[255] = { 2,	0,		SEN(clock_settime32),		"clock_settime"		},
-[256] = { 2,	0,		SEN(clock_gettime32),		"clock_gettime"		},
-[257] = { 2,	0,		SEN(clock_getres_time32),	"clock_getres"		},
+[255] = { 2,	TCL,		SEN(clock_settime32),		"clock_settime"		},
+[256] = { 2,	TCL,		SEN(clock_gettime32),		"clock_gettime"		},
+[257] = { 2,	TCL,		SEN(clock_getres_time32),	"clock_getres"		},
 [258] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
-[259] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[259] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [260] = { 6,	TM,		SEN(mbind),			"mbind"			},
 [261] = { 5,	TM,		SEN(get_mempolicy),		"get_mempolicy"		},
 [262] = { 3,	TM,		SEN(set_mempolicy),		"set_mempolicy"		},
@@ -291,7 +291,7 @@
 [285] = { 4,	TD|TF,		SEN(readlinkat),		"readlinkat"		},
 [286] = { 3,	TD|TF,		SEN(fchmodat),			"fchmodat"		},
 [287] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
-[288] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[288] = { 1,	0,		SEN(unshare),			"unshare"		},
 [289] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [290] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
 [291] = { 6,	TD,		SEN(splice),			"splice"		},
@@ -327,7 +327,7 @@
 [321] = { 4,	0,		SEN(prlimit64),			"prlimit64"		},
 [322] = { 2,	TD,		SEN(fanotify_init),		"fanotify_init"		},
 [323] = { 6,	TD|TF,		SEN(fanotify_mark),		"fanotify_mark"		},
-[324] = { 2,	0,		SEN(clock_adjtime32),		"clock_adjtime"		},
+[324] = { 2,	TCL,		SEN(clock_adjtime32),		"clock_adjtime"		},
 [325] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [326] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
 [327] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
@@ -352,12 +352,13 @@
 [346] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
 [347] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
 [348] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
-[349] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[349] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [350] = { 6,	0,		SEN(io_pgetevents_time32),	"io_pgetevents"		},
 [351] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [352] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
 [353] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
 [354] = { 4,	0,		SEN(rseq),			"rseq"			},
-/* [355 ... 402] - reserved to sync up with other architectures */
+[355] = { 5,	TD,		SEN(kexec_file_load),		"kexec_file_load"	},
+/* [356 ... 402] - reserved to sync up with other architectures */
 #include "syscallent-common-32.h"
 #include "syscallent-common.h"
diff -pruN 5.5-3/linux/i386/syscallent.h 5.9-0ubuntu2/linux/i386/syscallent.h
--- 5.5-3/linux/i386/syscallent.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/linux/i386/syscallent.h	2020-08-01 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995 Rick Sladkey <jrs@world.std.com>
- * Copyright (c) 1995-2019 The strace developers.
+ * Copyright (c) 1995-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -20,7 +20,7 @@
 [ 10] = { 1,	TF,		SEN(unlink),			"unlink"		},
 [ 11] = { 3,	TF|TP|TSD|SE|SI,	SEN(execve),			"execve"		},
 [ 12] = { 1,	TF,		SEN(chdir),			"chdir"			},
-[ 13] = { 1,	0,		SEN(time),			"time"			},
+[ 13] = { 1,	TCL,		SEN(time),			"time"			},
 [ 14] = { 3,	TF,		SEN(mknod),			"mknod"			},
 [ 15] = { 2,	TF,		SEN(chmod),			"chmod"			},
 [ 16] = { 3,	TF,		SEN(chown16),			"lchown"		},
@@ -44,7 +44,7 @@
 [ 34] = { 1,	0,		SEN(nice),			"nice"			},
 [ 35] = { 0,	0,		SEN(ftime),			"ftime"			},
 [ 36] = { 0,	0,		SEN(sync),			"sync"			},
-[ 37] = { 2,	TS,		SEN(kill),			"kill"			},
+[ 37] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [ 38] = { 2,	TF,		SEN(rename),			"rename"		},
 [ 39] = { 2,	TF,		SEN(mkdir),			"mkdir"			},
 [ 40] = { 1,	TF,		SEN(rmdir),			"rmdir"			},
@@ -85,8 +85,8 @@
 [ 75] = { 2,	0,		SEN(setrlimit),			"setrlimit"		},
 [ 76] = { 2,	0,		SEN(getrlimit),			"getrlimit"		},
 [ 77] = { 2,	0,		SEN(getrusage),			"getrusage"		},
-[ 78] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
-[ 79] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
+[ 78] = { 2,	TCL,		SEN(gettimeofday),		"gettimeofday"		},
+[ 79] = { 2,	TCL,		SEN(settimeofday),		"settimeofday"		},
 [ 80] = { 2,	TC,		SEN(getgroups16),		"getgroups"		},
 [ 81] = { 2,	TC,		SEN(setgroups16),		"setgroups"		},
 [ 82] = { 1,	TD,		SEN(oldselect),			"select"		},
@@ -131,7 +131,7 @@
 [121] = { 2,	0,		SEN(setdomainname),		"setdomainname"		},
 [122] = { 1,	0,		SEN(uname),			"uname"			},
 [123] = { 3,	0,		SEN(modify_ldt),		"modify_ldt"		},
-[124] = { 1,	0,		SEN(adjtimex32),		"adjtimex"		},
+[124] = { 1,	TCL,		SEN(adjtimex32),		"adjtimex"		},
 [125] = { 3,	TM|SI,		SEN(mprotect),			"mprotect"		},
 [126] = { 3,	TS,		SEN(sigprocmask),		"sigprocmask"		},
 [127] = { 2,	0,		SEN(create_module),		"create_module"		},
@@ -185,7 +185,7 @@
 [175] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [176] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [177] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
-[178] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[178] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [179] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [180] = { 5,	TD,		SEN(pread),			"pread64"		},
 [181] = { 5,	TD,		SEN(pwrite),			"pwrite64"		},
@@ -244,7 +244,7 @@
 [235] = { 2,	TF,		SEN(removexattr),		"removexattr"		},
 [236] = { 2,	TF,		SEN(removexattr),		"lremovexattr"		},
 [237] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
-[238] = { 2,	TS,		SEN(kill),			"tkill"			},
+[238] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [239] = { 4,	TD|TN,		SEN(sendfile64),		"sendfile64"		},
 [240] = { 6,	0,		SEN(futex_time32),		"futex"			},
 [241] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
@@ -270,13 +270,13 @@
 [261] = { 2,	0,		SEN(timer_gettime32),		"timer_gettime"		},
 [262] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [263] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[264] = { 2,	0,		SEN(clock_settime32),		"clock_settime"		},
-[265] = { 2,	0,		SEN(clock_gettime32),		"clock_gettime"		},
-[266] = { 2,	0,		SEN(clock_getres_time32),	"clock_getres"		},
+[264] = { 2,	TCL,		SEN(clock_settime32),		"clock_settime"		},
+[265] = { 2,	TCL,		SEN(clock_gettime32),		"clock_gettime"		},
+[266] = { 2,	TCL,		SEN(clock_getres_time32),	"clock_getres"		},
 [267] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
 [268] = { 3,	TF|TSF|TSFA,	SEN(statfs64),			"statfs64"		},
 [269] = { 3,	TD|TFSF|TSFA,	SEN(fstatfs64),			"fstatfs64"		},
-[270] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[270] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [271] = { 2,	TF,		SEN(utimes),			"utimes"		},
 [272] = { 6,	TD,		SEN(fadvise64_64),		"fadvise64_64"		},
 [273] = { 5,	0,		SEN(vserver),			"vserver"		},
@@ -316,7 +316,7 @@
 [307] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [308] = { 6,	TD,		SEN(pselect6_time32),		"pselect6"		},
 [309] = { 5,	TD,		SEN(ppoll_time32),		"ppoll"			},
-[310] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[310] = { 1,	0,		SEN(unshare),			"unshare"		},
 [311] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [312] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
 [313] = { 6,	TD,		SEN(splice),			"splice"		},
@@ -349,7 +349,7 @@
 [340] = { 4,	0,		SEN(prlimit64),			"prlimit64"		},
 [341] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [342] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[343] = { 2,	0,		SEN(clock_adjtime32),		"clock_adjtime"		},
+[343] = { 2,	TCL,		SEN(clock_adjtime32),		"clock_adjtime"		},
 [344] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [345] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
 [346] = { 2,	TD,		SEN(setns),			"setns"			},
@@ -389,8 +389,8 @@
 [380] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [381] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
 [382] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
-[383] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
-[384] = { 2,	TP,		SEN(arch_prctl),		"arch_prctl"		},
+[383] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
+[384] = { 2,	0,		SEN(arch_prctl),		"arch_prctl"		},
 [385] = { 6,	0,		SEN(io_pgetevents_time32),	"io_pgetevents"		},
 [386] = { 4,	0,		SEN(rseq),			"rseq"			},
 /* room for arch specific calls */
diff -pruN 5.5-3/linux/ia64/syscallent.h 5.9-0ubuntu2/linux/ia64/syscallent.h
--- 5.5-3/linux/ia64/syscallent.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/linux/ia64/syscallent.h	2020-08-01 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 1999, 2001 Hewlett-Packard Co
  *                          David Mosberger-Tang <davidm@hpl.hp.com>
- * Copyright (c) 2000-2019 The strace developers.
+ * Copyright (c) 2000-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -49,7 +49,7 @@
 [BASE_NR +  26] = { 0,	0,		SEN(sync),			"sync"			},
 [BASE_NR +  27] = { 1,	TD,		SEN(fsync),			"fsync"			},
 [BASE_NR +  28] = { 1,	TD,		SEN(fdatasync),			"fdatasync"		},
-[BASE_NR +  29] = { 2,	TS,		SEN(kill),			"kill"			},
+[BASE_NR +  29] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [BASE_NR +  30] = { 2,	TF,		SEN(rename),			"rename"		},
 [BASE_NR +  31] = { 2,	TF,		SEN(mkdir),			"mkdir"			},
 [BASE_NR +  32] = { 1,	TF,		SEN(rmdir),			"rmdir"			},
@@ -83,8 +83,8 @@
 [BASE_NR +  60] = { 2,	0,		SEN(setrlimit),			"setrlimit"		},
 [BASE_NR +  61] = { 2,	0,		SEN(getrlimit),			"getrlimit"		},
 [BASE_NR +  62] = { 2,	0,		SEN(getrusage),			"getrusage"		},
-[BASE_NR +  63] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
-[BASE_NR +  64] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
+[BASE_NR +  63] = { 2,	TCL,		SEN(gettimeofday),		"gettimeofday"		},
+[BASE_NR +  64] = { 2,	TCL,		SEN(settimeofday),		"settimeofday"		},
 [BASE_NR +  65] = { 5,	TD,		SEN(select),			"select"		},
 [BASE_NR +  66] = { 3,	TD,		SEN(poll_time64),		"poll"			},
 [BASE_NR +  67] = { 2,	TF,		SEN(symlink),			"symlink"		},
@@ -127,7 +127,7 @@
 [BASE_NR + 104] = { 5,	TP,		SEN(clone),			"clone"			},
 [BASE_NR + 105] = { 2,	0,		SEN(setdomainname),		"setdomainname"		},
 [BASE_NR + 106] = { 1,	0,		SEN(uname),			"uname"			},
-[BASE_NR + 107] = { 1,	0,		SEN(adjtimex64),		"adjtimex"		},
+[BASE_NR + 107] = { 1,	TCL,		SEN(adjtimex64),		"adjtimex"		},
 [BASE_NR + 108] = { 2,	0,		SEN(create_module),		"create_module"		},
 [BASE_NR + 109] = { 3,	0,		SEN(init_module),		"init_module"		},
 [BASE_NR + 110] = { 2,	0,		SEN(delete_module),		"delete_module"		},
@@ -167,7 +167,7 @@
 [BASE_NR + 144] = { 2,	0,		SEN(nanosleep_time64),		"nanosleep"		},
 [BASE_NR + 145] = { 3,	0,		SEN(nfsservctl),		"nfsservctl"		},
 [BASE_NR + 146] = { 5,	TC,		SEN(prctl),			"prctl"			},
-[BASE_NR + 147] = { 0,	PU|NF,		SEN(getpagesize),		"getpagesize"		},
+[BASE_NR + 147] = { 0,	PU|NF,		SEN(getpagesize),		"old_getpagesize"	},
 [BASE_NR + 148] = { 6,	TD|TM|SI,	SEN(mmap_pgoff),		"mmap2"			},
 [BASE_NR + 149] = { 5,	0,		SEN(printargs),			"pciconfig_read"	},
 [BASE_NR + 150] = { 5,	0,		SEN(printargs),			"pciconfig_write"	},
@@ -176,7 +176,7 @@
 [BASE_NR + 153] = { 4,	TS,		SEN(rt_sigaction),		"rt_sigaction"		},
 [BASE_NR + 154] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [BASE_NR + 155] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
-[BASE_NR + 156] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[BASE_NR + 156] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [BASE_NR + 157] = { 0,	TS,		SEN(rt_sigreturn),		"rt_sigreturn"		},
 [BASE_NR + 158] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [BASE_NR + 159] = { 4,	TS,		SEN(rt_sigtimedwait_time64),	"rt_sigtimedwait"	},
@@ -225,13 +225,13 @@
 [BASE_NR + 202] = { 2,	TF,		SEN(removexattr),		"removexattr"		},
 [BASE_NR + 203] = { 2,	TF,		SEN(removexattr),		"lremovexattr"		},
 [BASE_NR + 204] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
-[BASE_NR + 205] = { 2,	TS,		SEN(kill),			"tkill"			},
+[BASE_NR + 205] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [BASE_NR + 206] = { 6,	0,		SEN(futex_time64),		"futex"			},
 [BASE_NR + 207] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
 [BASE_NR + 208] = { 3,	0,		SEN(sched_getaffinity),		"sched_getaffinity"	},
 [BASE_NR + 209] = { 1,	0,		SEN(set_tid_address),		"set_tid_address"	},
 [BASE_NR + 210] = { 4,	TD,		SEN(fadvise64),			"fadvise64"		},
-[BASE_NR + 211] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[BASE_NR + 211] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [BASE_NR + 212] = { 1,	TP|SE,		SEN(exit),			"exit_group"		},
 [BASE_NR + 213] = { 3,	0,		SEN(lookup_dcookie),		"lookup_dcookie"	},
 [BASE_NR + 214] = { 2,	TM,		SEN(io_setup),			"io_setup"		},
@@ -249,9 +249,9 @@
 [BASE_NR + 226] = { 2,	0,		SEN(timer_gettime64),		"timer_gettime"		},
 [BASE_NR + 227] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [BASE_NR + 228] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[BASE_NR + 229] = { 2,	0,		SEN(clock_settime64),		"clock_settime"		},
-[BASE_NR + 230] = { 2,	0,		SEN(clock_gettime64),		"clock_gettime"		},
-[BASE_NR + 231] = { 2,	0,		SEN(clock_getres_time64),	"clock_getres"		},
+[BASE_NR + 229] = { 2,	TCL,		SEN(clock_settime64),		"clock_settime"		},
+[BASE_NR + 230] = { 2,	TCL,		SEN(clock_gettime64),		"clock_gettime"		},
+[BASE_NR + 231] = { 2,	TCL,		SEN(clock_getres_time64),	"clock_getres"		},
 [BASE_NR + 232] = { 4,	0,		SEN(clock_nanosleep_time64),	"clock_nanosleep"	},
 [BASE_NR + 233] = { 3,	TD|TFSF|TSFA,	SEN(fstatfs64),			"fstatfs64"		},
 [BASE_NR + 234] = { 3,	TF|TSF|TSFA,	SEN(statfs64),			"statfs64"		},
@@ -292,7 +292,7 @@
 [BASE_NR + 269] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [BASE_NR + 270] = { 6,	TD,		SEN(pselect6_time64),		"pselect6"		},
 [BASE_NR + 271] = { 5,	TD,		SEN(ppoll_time64),		"ppoll"			},
-[BASE_NR + 272] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[BASE_NR + 272] = { 1,	0,		SEN(unshare),			"unshare"		},
 [BASE_NR + 273] = { 6,	TD,		SEN(splice),			"splice"		},
 [BASE_NR + 274] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [BASE_NR + 275] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
@@ -324,7 +324,7 @@
 [BASE_NR + 301] = { 4,	0,		SEN(prlimit64),			"prlimit64"		},
 [BASE_NR + 302] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [BASE_NR + 303] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[BASE_NR + 304] = { 2,	0,		SEN(clock_adjtime64),		"clock_adjtime"		},
+[BASE_NR + 304] = { 2,	TCL,		SEN(clock_adjtime64),		"clock_adjtime"		},
 [BASE_NR + 305] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [BASE_NR + 306] = { 2,	TD,		SEN(setns),			"setns"			},
 [BASE_NR + 307] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
@@ -346,7 +346,7 @@
 [BASE_NR + 323] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
 [BASE_NR + 324] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
 [BASE_NR + 325] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
-[BASE_NR + 326] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[BASE_NR + 326] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [BASE_NR + 327] = { 6,	0,		SEN(io_pgetevents_time64),	"io_pgetevents"		},
 [BASE_NR + 328] = { 5,	TD,		SEN(perf_event_open),		"perf_event_open"	},
 [BASE_NR + 329] = { 3,	0,		SEN(seccomp),			"seccomp"		},
diff -pruN 5.5-3/linux/inet_diag.h 5.9-0ubuntu2/linux/inet_diag.h
--- 5.5-3/linux/inet_diag.h	2018-12-30 15:35:21.000000000 +0000
+++ 5.9-0ubuntu2/linux/inet_diag.h	2020-09-06 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2018 The strace developers.
+ * Copyright (c) 2014-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -44,6 +44,8 @@ struct inet_diag_req_v2 {
 enum {
 	INET_DIAG_REQ_NONE,
 	INET_DIAG_REQ_BYTECODE,
+	INET_DIAG_REQ_SK_BPF_STORAGES,
+	INET_DIAG_REQ_PROTOCOL,
 };
 
 struct inet_diag_bc_op {
@@ -66,6 +68,7 @@ enum {
 	INET_DIAG_BC_MARK_COND,
 	INET_DIAG_BC_S_EQ,
 	INET_DIAG_BC_D_EQ,
+	INET_DIAG_BC_CGROUP_COND,
 };
 
 struct inet_diag_hostcond {
@@ -116,6 +119,10 @@ enum {
 	INET_DIAG_MARK,
 	INET_DIAG_BBRINFO,
 	INET_DIAG_CLASS_ID,
+	INET_DIAG_MD5SIG,
+	INET_DIAG_ULP_INFO,
+	INET_DIAG_SK_BPF_STORAGES,
+	INET_DIAG_CGROUP_ID,
 };
 
 /* INET_DIAG_MEM */
diff -pruN 5.5-3/linux/m68k/syscallent.h 5.9-0ubuntu2/linux/m68k/syscallent.h
--- 5.5-3/linux/m68k/syscallent.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/linux/m68k/syscallent.h	2020-08-01 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995 Rick Sladkey <jrs@world.std.com>
- * Copyright (c) 1995-2019 The strace developers.
+ * Copyright (c) 1995-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -20,7 +20,7 @@
 [ 10] = { 1,	TF,		SEN(unlink),			"unlink"		},
 [ 11] = { 3,	TF|TP|TSD|SE|SI,	SEN(execve),			"execve"		},
 [ 12] = { 1,	TF,		SEN(chdir),			"chdir"			},
-[ 13] = { 1,	0,		SEN(time),			"time"			},
+[ 13] = { 1,	TCL,		SEN(time),			"time"			},
 [ 14] = { 3,	TF,		SEN(mknod),			"mknod"			},
 [ 15] = { 2,	TF,		SEN(chmod),			"chmod"			},
 [ 16] = { 3,	TF,		SEN(chown16),			"chown"			},
@@ -44,7 +44,7 @@
 [ 34] = { 1,	0,		SEN(nice),			"nice"			},
 [ 35] = { 0,	0,		SEN(ftime),			"ftime"			},
 [ 36] = { 0,	0,		SEN(sync),			"sync"			},
-[ 37] = { 2,	TS,		SEN(kill),			"kill"			},
+[ 37] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [ 38] = { 2,	TF,		SEN(rename),			"rename"		},
 [ 39] = { 2,	TF,		SEN(mkdir),			"mkdir"			},
 [ 40] = { 1,	TF,		SEN(rmdir),			"rmdir"			},
@@ -85,8 +85,8 @@
 [ 75] = { 2,	0,		SEN(setrlimit),			"setrlimit"		},
 [ 76] = { 2,	0,		SEN(getrlimit),			"getrlimit"		},
 [ 77] = { 2,	0,		SEN(getrusage),			"getrusage"		},
-[ 78] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
-[ 79] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
+[ 78] = { 2,	TCL,		SEN(gettimeofday),		"gettimeofday"		},
+[ 79] = { 2,	TCL,		SEN(settimeofday),		"settimeofday"		},
 [ 80] = { 2,	TC,		SEN(getgroups16),		"getgroups"		},
 [ 81] = { 2,	TC,		SEN(setgroups16),		"setgroups"		},
 [ 82] = { 1,	TD,		SEN(oldselect),			"select"		},
@@ -131,7 +131,7 @@
 [121] = { 2,	0,		SEN(setdomainname),		"setdomainname"		},
 [122] = { 1,	0,		SEN(uname),			"uname"			},
 [123] = { 4,	0,		SEN(cacheflush),		"cacheflush"		},
-[124] = { 1,	0,		SEN(adjtimex32),		"adjtimex"		},
+[124] = { 1,	TCL,		SEN(adjtimex32),		"adjtimex"		},
 [125] = { 3,	TM|SI,		SEN(mprotect),			"mprotect"		},
 [126] = { 3,	TS,		SEN(sigprocmask),		"sigprocmask"		},
 [127] = { 2,	0,		SEN(create_module),		"create_module"		},
@@ -185,7 +185,7 @@
 [175] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [176] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [177] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
-[178] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[178] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [179] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [180] = { 5,	TD,		SEN(pread),			"pread64"		},
 [181] = { 5,	TD,		SEN(pwrite),			"pwrite64"		},
@@ -228,7 +228,7 @@
 [218 ... 219] = { },
 [220] = { 3,	TD,		SEN(getdents64),		"getdents64"		},
 [221] = { 0,	PU|NF,		SEN(gettid),			"gettid"		},
-[222] = { 2,	TS,		SEN(kill),			"tkill"			},
+[222] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [223] = { 5,	TF,		SEN(setxattr),			"setxattr"		},
 [224] = { 5,	TF,		SEN(setxattr),			"lsetxattr"		},
 [225] = { 5,	TD,		SEN(fsetxattr),			"fsetxattr"		},
@@ -265,13 +265,13 @@
 [256] = { 2,	0,		SEN(timer_gettime32),		"timer_gettime"		},
 [257] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [258] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[259] = { 2,	0,		SEN(clock_settime32),		"clock_settime"		},
-[260] = { 2,	0,		SEN(clock_gettime32),		"clock_gettime"		},
-[261] = { 2,	0,		SEN(clock_getres_time32),	"clock_getres"		},
+[259] = { 2,	TCL,		SEN(clock_settime32),		"clock_settime"		},
+[260] = { 2,	TCL,		SEN(clock_gettime32),		"clock_gettime"		},
+[261] = { 2,	TCL,		SEN(clock_getres_time32),	"clock_getres"		},
 [262] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
 [263] = { 3,	TF|TSF|TSFA,	SEN(statfs64),			"statfs64"		},
 [264] = { 3,	TD|TFSF|TSFA,	SEN(fstatfs64),			"fstatfs64"		},
-[265] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[265] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [266] = { 2,	TF,		SEN(utimes),			"utimes"		},
 [267] = { 6,	TD,		SEN(fadvise64_64),		"fadvise64_64"		},
 [268] = { 6,	TM,		SEN(mbind),			"mbind"			},
@@ -309,7 +309,7 @@
 [300] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [301] = { 6,	TD,		SEN(pselect6_time32),		"pselect6"		},
 [302] = { 5,	TD,		SEN(ppoll_time32),		"ppoll"			},
-[303] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[303] = { 1,	0,		SEN(unshare),			"unshare"		},
 [304] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [305] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
 [306] = { 6,	TD,		SEN(splice),			"splice"		},
@@ -348,7 +348,7 @@
 [339] = { 4,	0,		SEN(prlimit64),			"prlimit64"		},
 [340] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [341] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[342] = { 2,	0,		SEN(clock_adjtime32),		"clock_adjtime"		},
+[342] = { 2,	TCL,		SEN(clock_adjtime32),		"clock_adjtime"		},
 [343] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [344] = { 2,	TD,		SEN(setns),			"setns"			},
 [345] = { 6,	0,		SEN(process_vm_readv),		"process_vm_readv"	},
@@ -385,7 +385,7 @@
 [376] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
 [377] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
 [378] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
-[379] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[379] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [380] = { 3,	0,		SEN(seccomp),			"seccomp"		},
 [381] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [382] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
diff -pruN 5.5-3/linux/microblaze/syscallent.h 5.9-0ubuntu2/linux/microblaze/syscallent.h
--- 5.5-3/linux/microblaze/syscallent.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/linux/microblaze/syscallent.h	2020-08-01 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995 Rick Sladkey <jrs@world.std.com>
- * Copyright (c) 1995-2019 The strace developers.
+ * Copyright (c) 1995-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -20,7 +20,7 @@
 [ 10] = { 1,	TF,		SEN(unlink),			"unlink"		},
 [ 11] = { 3,	TF|TP|TSD|SE|SI,	SEN(execve),			"execve"		},
 [ 12] = { 1,	TF,		SEN(chdir),			"chdir"			},
-[ 13] = { 1,	0,		SEN(time),			"time"			},
+[ 13] = { 1,	TCL,		SEN(time),			"time"			},
 [ 14] = { 3,	TF,		SEN(mknod),			"mknod"			},
 [ 15] = { 2,	TF,		SEN(chmod),			"chmod"			},
 [ 16] = { 3,	TF,		SEN(chown16),			"lchown"		},
@@ -44,7 +44,7 @@
 [ 34] = { 1,	0,		SEN(nice),			"nice"			},
 [ 35] = { 0,	0,		SEN(ftime),			"ftime"			},
 [ 36] = { 0,	0,		SEN(sync),			"sync"			},
-[ 37] = { 2,	TS,		SEN(kill),			"kill"			},
+[ 37] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [ 38] = { 2,	TF,		SEN(rename),			"rename"		},
 [ 39] = { 2,	TF,		SEN(mkdir),			"mkdir"			},
 [ 40] = { 1,	TF,		SEN(rmdir),			"rmdir"			},
@@ -85,8 +85,8 @@
 [ 75] = { 2,	0,		SEN(setrlimit),			"setrlimit"		},
 [ 76] = { 2,	0,		SEN(getrlimit),			"getrlimit"		},
 [ 77] = { 2,	0,		SEN(getrusage),			"getrusage"		},
-[ 78] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
-[ 79] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
+[ 78] = { 2,	TCL,		SEN(gettimeofday),		"gettimeofday"		},
+[ 79] = { 2,	TCL,		SEN(settimeofday),		"settimeofday"		},
 [ 80] = { 2,	TC,		SEN(getgroups16),		"getgroups"		},
 [ 81] = { 2,	TC,		SEN(setgroups16),		"setgroups"		},
 [ 82] = { 1,	TD,		SEN(oldselect),			"select"		},
@@ -131,7 +131,7 @@
 [121] = { 2,	0,		SEN(setdomainname),		"setdomainname"		},
 [122] = { 1,	0,		SEN(uname),			"uname"			},
 [123] = { 3,	0,		SEN(modify_ldt),		"modify_ldt"		},
-[124] = { 1,	0,		SEN(adjtimex32),		"adjtimex"		},
+[124] = { 1,	TCL,		SEN(adjtimex32),		"adjtimex"		},
 [125] = { 3,	TM|SI,		SEN(mprotect),			"mprotect"		},
 [126] = { 3,	TS,		SEN(sigprocmask),		"sigprocmask"		},
 [127] = { 2,	0,		SEN(create_module),		"create_module"		},
@@ -185,7 +185,7 @@
 [175] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [176] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [177] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
-[178] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[178] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [179] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [180] = { 5,	TD,		SEN(pread),			"pread64"		},
 [181] = { 5,	TD,		SEN(pwrite),			"pwrite64"		},
@@ -244,7 +244,7 @@
 [235] = { 2,	TF,		SEN(removexattr),		"removexattr"		},
 [236] = { 2,	TF,		SEN(removexattr),		"lremovexattr"		},
 [237] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
-[238] = { 2,	TS,		SEN(kill),			"tkill"			},
+[238] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [239] = { 4,	TD|TN,		SEN(sendfile64),		"sendfile64"		},
 [240] = { 6,	0,		SEN(futex_time32),		"futex"			},
 [241] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
@@ -270,13 +270,13 @@
 [261] = { 2,	0,		SEN(timer_gettime32),		"timer_gettime"		},
 [262] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [263] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[264] = { 2,	0,		SEN(clock_settime32),		"clock_settime"		},
-[265] = { 2,	0,		SEN(clock_gettime32),		"clock_gettime"		},
-[266] = { 2,	0,		SEN(clock_getres_time32),	"clock_getres"		},
+[264] = { 2,	TCL,		SEN(clock_settime32),		"clock_settime"		},
+[265] = { 2,	TCL,		SEN(clock_gettime32),		"clock_gettime"		},
+[266] = { 2,	TCL,		SEN(clock_getres_time32),	"clock_getres"		},
 [267] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
 [268] = { 3,	TF|TSF|TSFA,	SEN(statfs64),			"statfs64"		},
 [269] = { 3,	TD|TFSF|TSFA,	SEN(fstatfs64),			"fstatfs64"		},
-[270] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[270] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [271] = { 2,	TF,		SEN(utimes),			"utimes"		},
 [272] = { 6,	TD,		SEN(fadvise64_64),		"fadvise64_64"		},
 [273] = { 5,	0,		SEN(vserver),			"vserver"		},
@@ -316,7 +316,7 @@
 [307] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [308] = { 6,	TD,		SEN(pselect6_time32),		"pselect6"		},
 [309] = { 5,	TD,		SEN(ppoll_time32),		"ppoll"			},
-[310] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[310] = { 1,	0,		SEN(unshare),			"unshare"		},
 [311] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [312] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
 [313] = { 6,	TD,		SEN(splice),			"splice"		},
@@ -379,7 +379,7 @@
 [370] = { 4,	0,		SEN(prlimit64),			"prlimit64"		},
 [371] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [372] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[373] = { 2,	0,		SEN(clock_adjtime32),		"clock_adjtime"		},
+[373] = { 2,	TCL,		SEN(clock_adjtime32),		"clock_adjtime"		},
 [374] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [375] = { 2,	TD,		SEN(setns),			"setns"			},
 [376] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
@@ -404,7 +404,7 @@
 [395] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [396] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
 [397] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
-[398] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[398] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [399] = { 6,	0,		SEN(io_pgetevents_time32),	"io_pgetevents"		},
 [400] = { 4,	0,		SEN(rseq),			"rseq"			},
 /* [401 ... 402] - unused */
diff -pruN 5.5-3/linux/mips/syscallent-compat.h 5.9-0ubuntu2/linux/mips/syscallent-compat.h
--- 5.5-3/linux/mips/syscallent-compat.h	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/linux/mips/syscallent-compat.h	2020-06-16 21:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013-2019 The strace developers.
+ * Copyright (c) 2013-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -42,7 +42,7 @@
 [  34] = { 0,	0,	SEN(printargs),		"svr4_nice"	},
 [  35] = { 0,	TF|TSF|TSFA,SEN(printargs),		"svr4_statfs"	},
 [  36] = { 0,	0,	SEN(printargs),		"svr4_sync"	},
-[  37] = { 0,	0,	SEN(printargs),		"svr4_kill"	},
+[  37] = { 0,	TP,	SEN(printargs),		"svr4_kill"	},
 [  38] = { 0,	TD|TFSF|TSFA,SEN(printargs),		"svr4_fstatfs"	},
 [  39] = { 0,	0,	SEN(printargs),		"svr4_setpgrp"	},
 [  40] = { 0,	0,	SEN(printargs),		"svr4_cxenix"	},
@@ -138,7 +138,7 @@
 [ 135] = { 0,	0,	SEN(printargs),		"svr4_nuname"	},
 [ 136] = { 0,	TC,	SEN(printargs),		"svr4_setegid"	},
 [ 137] = { 0,	0,	SEN(printargs),		"svr4_sysconf"	},
-[ 138] = { 0,	0,	SEN(printargs),		"svr4_adjtime"	},
+[ 138] = { 0,	TCL,	SEN(printargs),		"svr4_adjtime"	},
 [ 139] = { 0,	0,	SEN(printargs),		"svr4_sysinfo"	},
 [ 140] = { },
 [ 141] = { 0,	TC,	SEN(printargs),		"svr4_seteuid"	},
@@ -193,7 +193,7 @@
 [1034] = { 0,	0,	SEN(printargs),		"sysv_nice"	},
 [1035] = { 0,	TF|TSF|TSFA,SEN(printargs),		"sysv_statfs"	},
 [1036] = { 0,	0,	SEN(printargs),		"sysv_sync"	},
-[1037] = { 0,	0,	SEN(printargs),		"sysv_kill"	},
+[1037] = { 0,	TP,	SEN(printargs),		"sysv_kill"	},
 [1038] = { 0,	TD|TFSF|TSFA,SEN(printargs),		"sysv_fstatfs"	},
 [1039] = { 0,	0,	SEN(printargs),		"sysv_setpgrp"	},
 [1040] = { 0,	0,	SEN(printargs),		"sysv_syssgi"	},
@@ -278,7 +278,7 @@
 [1124] = { 0,	TC,	SEN(printargs),		"sysv_setreuid"	},
 [1125] = { 0,	0,	SEN(printargs),		"sysv_getitimer"	},
 [1126] = { 0,	0,	SEN(printargs),		"sysv_setitimer"	},
-[1127] = { 0,	0,	SEN(printargs),		"sysv_adjtime"	},
+[1127] = { 0,	TCL,	SEN(printargs),		"sysv_adjtime"	},
 [1128] = { 0,	0,	SEN(printargs),		"sysv_BSD_getime"	},
 [1129] = { 0,	0,	SEN(printargs),		"sysv_sproc"	},
 [1130] = { 0,	0,	SEN(printargs),		"sysv_prctl"	},
@@ -378,7 +378,7 @@
 [2034] = { 0,	0,	SEN(printargs),		"bsd43_nice"	},
 [2035] = { 0,	0,	SEN(printargs),		"bsd43_ftime"	},
 [2036] = { 0,	0,	SEN(printargs),		"bsd43_sync"	},
-[2037] = { 0,	0,	SEN(printargs),		"bsd43_kill"	},
+[2037] = { 0,	TP,	SEN(printargs),		"bsd43_kill"	},
 [2038] = { 0,	TF|TST|TSTA,SEN(printargs),		"bsd43_stat"	},
 [2039] = { 0,	0,	SEN(printargs),		"bsd43_oldsetpgrp"	},
 [2040] = { 0,	TF|TLST|TSTA,SEN(printargs),		"bsd43_lstat"	},
@@ -457,13 +457,13 @@
 [2113] = { 0,	0,	SEN(printargs),		"bsd43_oldrecvmsg"	},
 [2114] = { 0,	0,	SEN(printargs),		"bsd43_oldsendmsg"	},
 [2115] = { 0,	0,	SEN(printargs),		"bsd43_vtrace"	},
-[2116] = { 0,	0,	SEN(printargs),		"bsd43_gettimeofday"	},
+[2116] = { 0,	TCL,	SEN(printargs),		"bsd43_gettimeofday"	},
 [2117] = { 0,	0,	SEN(printargs),		"bsd43_getrusage"	},
 [2118] = { 0,	0,	SEN(printargs),		"bsd43_getsockopt"	},
 [2119] = { },
 [2120] = { 0,	0,	SEN(printargs),		"bsd43_readv"	},
 [2121] = { 0,	0,	SEN(printargs),		"bsd43_writev"	},
-[2122] = { 0,	0,	SEN(printargs),		"bsd43_settimeofday"	},
+[2122] = { 0,	TCL,	SEN(printargs),		"bsd43_settimeofday"	},
 [2123] = { 0,	0,	SEN(printargs),		"bsd43_fchown"	},
 [2124] = { 0,	0,	SEN(printargs),		"bsd43_fchmod"	},
 [2125] = { 0,	0,	SEN(printargs),		"bsd43_oldrecvfrom"	},
@@ -481,13 +481,13 @@
 [2137] = { 0,	0,	SEN(printargs),		"bsd43_rmdir"	},
 [2138] = { 0,	0,	SEN(printargs),		"bsd43_utimes"	},
 [2139] = { 0,	0,	SEN(printargs),		"bsd43_sigcleanup"	},
-[2140] = { 0,	0,	SEN(printargs),		"bsd43_adjtime"	},
+[2140] = { 0,	TCL,	SEN(printargs),		"bsd43_adjtime"	},
 [2141] = { 0,	0,	SEN(printargs),		"bsd43_oldgetpeername"	},
 [2142] = { 0,	0,	SEN(printargs),		"bsd43_gethostid"	},
 [2143] = { 0,	0,	SEN(printargs),		"bsd43_sethostid"	},
 [2144] = { 0,	0,	SEN(printargs),		"bsd43_getrlimit"	},
 [2145] = { 0,	0,	SEN(printargs),		"bsd43_setrlimit"	},
-[2146] = { 0,	0,	SEN(printargs),		"bsd43_killpg"	},
+[2146] = { 0,	TP,	SEN(printargs),		"bsd43_killpg"	},
 [2147] = { 0,	0,	SEN(printargs),		"bsd43_shmsys"	},
 [2148] = { 0,	0,	SEN(printargs),		"bsd43_quota"	},
 [2149] = { 0,	0,	SEN(printargs),		"bsd43_qquota"	},
@@ -571,7 +571,7 @@
 [3034] = { 0,	0,	SEN(printargs),		"posix_nice"	},
 [3035] = { 0,	TF|TSF|TSFA,SEN(printargs),		"posix_statfs"	},
 [3036] = { 0,	0,	SEN(printargs),		"posix_sync"	},
-[3037] = { 0,	0,	SEN(printargs),		"posix_kill"	},
+[3037] = { 0,	TP,	SEN(printargs),		"posix_kill"	},
 [3038] = { 0,	TD|TFSF|TSFA,SEN(printargs),		"posix_fstatfs"	},
 [3039] = { 0,	0,	SEN(printargs),		"posix_getpgrp"	},
 [3040] = { 0,	0,	SEN(printargs),		"posix_syssgi"	},
@@ -656,7 +656,7 @@
 [3124] = { 0,	TC,	SEN(printargs),		"posix_SGI_setreuid"	},
 [3125] = { 0,	0,	SEN(printargs),		"posix_getitimer"	},
 [3126] = { 0,	0,	SEN(printargs),		"posix_setitimer"	},
-[3127] = { 0,	0,	SEN(printargs),		"posix_adjtime"	},
+[3127] = { 0,	TCL,	SEN(printargs),		"posix_adjtime"	},
 [3128] = { 0,	0,	SEN(printargs),		"posix_SGI_bsdgettime"	},
 [3129] = { 0,	0,	SEN(printargs),		"posix_SGI_sproc"	},
 [3130] = { 0,	0,	SEN(printargs),		"posix_SGI_prctl"	},
@@ -689,7 +689,7 @@
 [3161] = { 0,	0,	SEN(printargs),		"posix_setpgid"	},
 [3162] = { 0,	TC,	SEN(printargs),		"posix_getgroups"	},
 [3163] = { 0,	TC,	SEN(printargs),		"posix_setgroups"	},
-[3164] = { 0,	0,	SEN(printargs),		"posix_gettimeofday"	},
+[3164] = { 0,	TCL,	SEN(printargs),		"posix_gettimeofday"	},
 [3165] = { 0,	0,	SEN(printargs),		"posix_getrusage"	},
 [3166] = { 0,	0,	SEN(printargs),		"posix_getrlimit"	},
 [3167] = { 0,	0,	SEN(printargs),		"posix_setrlimit"	},
diff -pruN 5.5-3/linux/mips/syscallent-n32.h 5.9-0ubuntu2/linux/mips/syscallent-n32.h
--- 5.5-3/linux/mips/syscallent-n32.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/linux/mips/syscallent-n32.h	2020-08-01 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013-2019 The strace developers.
+ * Copyright (c) 2013-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -68,7 +68,7 @@
 [BASE_NR +  57] = { 3,	TF|TP|TSD|SE|SI,	SEN(execve),			"execve"		},
 [BASE_NR +  58] = { 1,	TP|SE,		SEN(exit),			"exit"			},
 [BASE_NR +  59] = { 4,	TP,		SEN(wait4),			"wait4"			},
-[BASE_NR +  60] = { 2,	TS,		SEN(kill),			"kill"			},
+[BASE_NR +  60] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [BASE_NR +  61] = { 1,	0,		SEN(uname),			"uname"			},
 [BASE_NR +  62] = { 3,	TI,		SEN(semget),			"semget"		},
 [BASE_NR +  63] = { 3,	TI,		SEN(semop),			"semop"			},
@@ -102,7 +102,7 @@
 [BASE_NR +  91] = { 3,	TD,		SEN(fchown),			"fchown"		},
 [BASE_NR +  92] = { 3,	TF,		SEN(chown),			"lchown"		},
 [BASE_NR +  93] = { 1,	NF,		SEN(umask),			"umask"			},
-[BASE_NR +  94] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
+[BASE_NR +  94] = { 2,	TCL,		SEN(gettimeofday),		"gettimeofday"		},
 [BASE_NR +  95] = { 2,	0,		SEN(getrlimit),			"getrlimit"		},
 [BASE_NR +  96] = { 2,	0,		SEN(getrusage),			"getrusage"		},
 [BASE_NR +  97] = { 1,	0,		SEN(sysinfo),			"sysinfo"		},
@@ -135,7 +135,7 @@
 [BASE_NR + 124] = { 2,	TC,		SEN(capset),			"capset"		},
 [BASE_NR + 125] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [BASE_NR + 126] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
-[BASE_NR + 127] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[BASE_NR + 127] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [BASE_NR + 128] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [BASE_NR + 129] = { 2,	TS,		SEN(sigaltstack),		"sigaltstack"		},
 [BASE_NR + 130] = { 2,	TF,		SEN(utime),			"utime"			},
@@ -162,12 +162,12 @@
 [BASE_NR + 151] = { 2,	TF,		SEN(pivotroot),			"pivot_root"		},
 [BASE_NR + 152] = { 1,	0,		SEN(sysctl),			"_sysctl"		},
 [BASE_NR + 153] = { 5,	TC,		SEN(prctl),			"prctl"			},
-[BASE_NR + 154] = { 1,	0,		SEN(adjtimex32),		"adjtimex"		},
+[BASE_NR + 154] = { 1,	TCL,		SEN(adjtimex32),		"adjtimex"		},
 [BASE_NR + 155] = { 2,	0,		SEN(setrlimit),			"setrlimit"		},
 [BASE_NR + 156] = { 1,	TF,		SEN(chroot),			"chroot"		},
 [BASE_NR + 157] = { 0,	0,		SEN(sync),			"sync"			},
 [BASE_NR + 158] = { 1,	TF,		SEN(acct),			"acct"			},
-[BASE_NR + 159] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
+[BASE_NR + 159] = { 2,	TCL,		SEN(settimeofday),		"settimeofday"		},
 [BASE_NR + 160] = { 5,	TF,		SEN(mount),			"mount"			},
 [BASE_NR + 161] = { 2,	TF,		SEN(umount2),			"umount2"		},
 [BASE_NR + 162] = { 2,	TF,		SEN(swapon),			"swapon"		},
@@ -200,8 +200,8 @@
 [BASE_NR + 189] = { 2,	TF,		SEN(removexattr),		"removexattr"		},
 [BASE_NR + 190] = { 2,	TF,		SEN(removexattr),		"lremovexattr"		},
 [BASE_NR + 191] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
-[BASE_NR + 192] = { 2,	TS,		SEN(kill),			"tkill"			},
-[BASE_NR + 193] = { 1,	0,		SEN(time),			"time"			},
+[BASE_NR + 192] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
+[BASE_NR + 193] = { 1,	TCL,		SEN(time),			"time"			},
 [BASE_NR + 194] = { 6,	0,		SEN(futex_time32),		"futex"			},
 [BASE_NR + 195] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
 [BASE_NR + 196] = { 3,	0,		SEN(sched_getaffinity),		"sched_getaffinity"	},
@@ -233,11 +233,11 @@
 [BASE_NR + 222] = { 2,	0,		SEN(timer_gettime32),		"timer_gettime"		},
 [BASE_NR + 223] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [BASE_NR + 224] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[BASE_NR + 225] = { 2,	0,		SEN(clock_settime32),		"clock_settime"		},
-[BASE_NR + 226] = { 2,	0,		SEN(clock_gettime32),		"clock_gettime"		},
-[BASE_NR + 227] = { 2,	0,		SEN(clock_getres_time32),	"clock_getres"		},
+[BASE_NR + 225] = { 2,	TCL,		SEN(clock_settime32),		"clock_settime"		},
+[BASE_NR + 226] = { 2,	TCL,		SEN(clock_gettime32),		"clock_gettime"		},
+[BASE_NR + 227] = { 2,	TCL,		SEN(clock_getres_time32),	"clock_getres"		},
 [BASE_NR + 228] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
-[BASE_NR + 229] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[BASE_NR + 229] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [BASE_NR + 230] = { 2,	TF,		SEN(utimes),			"utimes"		},
 [BASE_NR + 231] = { 6,	TM,		SEN(mbind),			"mbind"			},
 [BASE_NR + 232] = { 5,	TM,		SEN(get_mempolicy),		"get_mempolicy"		},
@@ -274,7 +274,7 @@
 [BASE_NR + 263] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [BASE_NR + 264] = { 6,	TD,		SEN(pselect6_time32),		"pselect6"		},
 [BASE_NR + 265] = { 5,	TD,		SEN(ppoll_time32),		"ppoll"			},
-[BASE_NR + 266] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[BASE_NR + 266] = { 1,	0,		SEN(unshare),			"unshare"		},
 [BASE_NR + 267] = { 6,	TD,		SEN(splice),			"splice"		},
 [BASE_NR + 268] = { 4,	TD,		SEN(sync_file_range),		"sync_file_range"	},
 [BASE_NR + 269] = { 4,	TD,		SEN(tee),			"tee"			},
@@ -313,7 +313,7 @@
 [BASE_NR + 302] = { 4,	0,		SEN(prlimit64),			"prlimit64"		},
 [BASE_NR + 303] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [BASE_NR + 304] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[BASE_NR + 305] = { 2,	0,		SEN(clock_adjtime32),		"clock_adjtime"		},
+[BASE_NR + 305] = { 2,	TCL,		SEN(clock_adjtime32),		"clock_adjtime"		},
 [BASE_NR + 306] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [BASE_NR + 307] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
 [BASE_NR + 308] = { 2,	TD,		SEN(setns),			"setns"			},
@@ -338,7 +338,7 @@
 [BASE_NR + 327] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [BASE_NR + 328] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
 [BASE_NR + 329] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
-[BASE_NR + 330] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[BASE_NR + 330] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [BASE_NR + 331] = { 4,	0,		SEN(rseq),			"rseq"			},
 [BASE_NR + 332] = { 6,	0,		SEN(io_pgetevents_time32),	"io_pgetevents"		},
 # include "syscallent-common-32.h"
diff -pruN 5.5-3/linux/mips/syscallent-n64.h 5.9-0ubuntu2/linux/mips/syscallent-n64.h
--- 5.5-3/linux/mips/syscallent-n64.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/linux/mips/syscallent-n64.h	2020-08-01 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013-2019 The strace developers.
+ * Copyright (c) 2013-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -68,7 +68,7 @@
 [BASE_NR +  57] = { 3,	TF|TP|TSD|SE|SI,	SEN(execve),			"execve"		},
 [BASE_NR +  58] = { 1,	TP|SE,		SEN(exit),			"exit"			},
 [BASE_NR +  59] = { 4,	TP,		SEN(wait4),			"wait4"			},
-[BASE_NR +  60] = { 2,	TS,		SEN(kill),			"kill"			},
+[BASE_NR +  60] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [BASE_NR +  61] = { 1,	0,		SEN(uname),			"uname"			},
 [BASE_NR +  62] = { 3,	TI,		SEN(semget),			"semget"		},
 [BASE_NR +  63] = { 3,	TI,		SEN(semop),			"semop"			},
@@ -102,7 +102,7 @@
 [BASE_NR +  91] = { 3,	TD,		SEN(fchown),			"fchown"		},
 [BASE_NR +  92] = { 3,	TF,		SEN(chown),			"lchown"		},
 [BASE_NR +  93] = { 1,	NF,		SEN(umask),			"umask"			},
-[BASE_NR +  94] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
+[BASE_NR +  94] = { 2,	TCL,		SEN(gettimeofday),		"gettimeofday"		},
 [BASE_NR +  95] = { 2,	0,		SEN(getrlimit),			"getrlimit"		},
 [BASE_NR +  96] = { 2,	0,		SEN(getrusage),			"getrusage"		},
 [BASE_NR +  97] = { 1,	0,		SEN(sysinfo),			"sysinfo"		},
@@ -135,7 +135,7 @@
 [BASE_NR + 124] = { 2,	TC,		SEN(capset),			"capset"		},
 [BASE_NR + 125] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [BASE_NR + 126] = { 4,	TS,		SEN(rt_sigtimedwait_time64),	"rt_sigtimedwait"	},
-[BASE_NR + 127] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[BASE_NR + 127] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [BASE_NR + 128] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [BASE_NR + 129] = { 2,	TS,		SEN(sigaltstack),		"sigaltstack"		},
 [BASE_NR + 130] = { 2,	TF,		SEN(utime),			"utime"			},
@@ -162,12 +162,12 @@
 [BASE_NR + 151] = { 2,	TF,		SEN(pivotroot),			"pivot_root"		},
 [BASE_NR + 152] = { 1,	0,		SEN(sysctl),			"_sysctl"		},
 [BASE_NR + 153] = { 5,	TC,		SEN(prctl),			"prctl"			},
-[BASE_NR + 154] = { 1,	0,		SEN(adjtimex64),		"adjtimex"		},
+[BASE_NR + 154] = { 1,	TCL,		SEN(adjtimex64),		"adjtimex"		},
 [BASE_NR + 155] = { 2,	0,		SEN(setrlimit),			"setrlimit"		},
 [BASE_NR + 156] = { 1,	TF,		SEN(chroot),			"chroot"		},
 [BASE_NR + 157] = { 0,	0,		SEN(sync),			"sync"			},
 [BASE_NR + 158] = { 1,	TF,		SEN(acct),			"acct"			},
-[BASE_NR + 159] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
+[BASE_NR + 159] = { 2,	TCL,		SEN(settimeofday),		"settimeofday"		},
 [BASE_NR + 160] = { 5,	TF,		SEN(mount),			"mount"			},
 [BASE_NR + 161] = { 2,	TF,		SEN(umount2),			"umount2"		},
 [BASE_NR + 162] = { 2,	TF,		SEN(swapon),			"swapon"		},
@@ -200,8 +200,8 @@
 [BASE_NR + 189] = { 2,	TF,		SEN(removexattr),		"removexattr"		},
 [BASE_NR + 190] = { 2,	TF,		SEN(removexattr),		"lremovexattr"		},
 [BASE_NR + 191] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
-[BASE_NR + 192] = { 2,	TS,		SEN(kill),			"tkill"			},
-[BASE_NR + 193] = { 1,	0,		SEN(time),			"time"			},
+[BASE_NR + 192] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
+[BASE_NR + 193] = { 1,	TCL,		SEN(time),			"time"			},
 [BASE_NR + 194] = { 6,	0,		SEN(futex_time64),		"futex"			},
 [BASE_NR + 195] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
 [BASE_NR + 196] = { 3,	0,		SEN(sched_getaffinity),		"sched_getaffinity"	},
@@ -229,11 +229,11 @@
 [BASE_NR + 218] = { 2,	0,		SEN(timer_gettime64),		"timer_gettime"		},
 [BASE_NR + 219] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [BASE_NR + 220] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[BASE_NR + 221] = { 2,	0,		SEN(clock_settime64),		"clock_settime"		},
-[BASE_NR + 222] = { 2,	0,		SEN(clock_gettime64),		"clock_gettime"		},
-[BASE_NR + 223] = { 2,	0,		SEN(clock_getres_time64),	"clock_getres"		},
+[BASE_NR + 221] = { 2,	TCL,		SEN(clock_settime64),		"clock_settime"		},
+[BASE_NR + 222] = { 2,	TCL,		SEN(clock_gettime64),		"clock_gettime"		},
+[BASE_NR + 223] = { 2,	TCL,		SEN(clock_getres_time64),	"clock_getres"		},
 [BASE_NR + 224] = { 4,	0,		SEN(clock_nanosleep_time64),	"clock_nanosleep"	},
-[BASE_NR + 225] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[BASE_NR + 225] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [BASE_NR + 226] = { 2,	TF,		SEN(utimes),			"utimes"		},
 [BASE_NR + 227] = { 6,	TM,		SEN(mbind),			"mbind"			},
 [BASE_NR + 228] = { 5,	TM,		SEN(get_mempolicy),		"get_mempolicy"		},
@@ -270,7 +270,7 @@
 [BASE_NR + 259] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [BASE_NR + 260] = { 6,	TD,		SEN(pselect6_time64),		"pselect6"		},
 [BASE_NR + 261] = { 5,	TD,		SEN(ppoll_time64),		"ppoll"			},
-[BASE_NR + 262] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[BASE_NR + 262] = { 1,	0,		SEN(unshare),			"unshare"		},
 [BASE_NR + 263] = { 6,	TD,		SEN(splice),			"splice"		},
 [BASE_NR + 264] = { 4,	TD,		SEN(sync_file_range),		"sync_file_range"	},
 [BASE_NR + 265] = { 4,	TD,		SEN(tee),			"tee"			},
@@ -308,7 +308,7 @@
 [BASE_NR + 297] = { 4,	0,		SEN(prlimit64),			"prlimit64"		},
 [BASE_NR + 298] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [BASE_NR + 299] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[BASE_NR + 300] = { 2,	0,		SEN(clock_adjtime64),		"clock_adjtime"		},
+[BASE_NR + 300] = { 2,	TCL,		SEN(clock_adjtime64),		"clock_adjtime"		},
 [BASE_NR + 301] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [BASE_NR + 302] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
 [BASE_NR + 303] = { 2,	TD,		SEN(setns),			"setns"			},
@@ -334,7 +334,7 @@
 [BASE_NR + 323] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [BASE_NR + 324] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
 [BASE_NR + 325] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
-[BASE_NR + 326] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[BASE_NR + 326] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [BASE_NR + 327] = { 4,	0,		SEN(rseq),			"rseq"			},
 [BASE_NR + 328] = { 6,	0,		SEN(io_pgetevents_time64),	"io_pgetevents"		},
 # include "syscallent-common.h"
diff -pruN 5.5-3/linux/mips/syscallent-o32.h 5.9-0ubuntu2/linux/mips/syscallent-o32.h
--- 5.5-3/linux/mips/syscallent-o32.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/linux/mips/syscallent-o32.h	2020-08-01 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013-2019 The strace developers.
+ * Copyright (c) 2013-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -22,7 +22,7 @@
 [BASE_NR +  10] = { 1,	TF,		SEN(unlink),			"unlink"		},
 [BASE_NR +  11] = { 3,	TF|TP|TSD|SE|SI,	SEN(execve),			"execve"		},
 [BASE_NR +  12] = { 1,	TF,		SEN(chdir),			"chdir"			},
-[BASE_NR +  13] = { 1,	0,		SEN(time),			"time"			},
+[BASE_NR +  13] = { 1,	TCL,		SEN(time),			"time"			},
 [BASE_NR +  14] = { 3,	TF,		SEN(mknod),			"mknod"			},
 [BASE_NR +  15] = { 2,	TF,		SEN(chmod),			"chmod"			},
 [BASE_NR +  16] = { 3,	TF,		SEN(chown),			"lchown"		},
@@ -46,7 +46,7 @@
 [BASE_NR +  34] = { 1,	0,		SEN(nice),			"nice"			},
 [BASE_NR +  35] = { 1,	0,		SEN(ftime),			"ftime"			},
 [BASE_NR +  36] = { 0,	0,		SEN(sync),			"sync"			},
-[BASE_NR +  37] = { 2,	TS,		SEN(kill),			"kill"			},
+[BASE_NR +  37] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [BASE_NR +  38] = { 2,	TF,		SEN(rename),			"rename"		},
 [BASE_NR +  39] = { 2,	TF,		SEN(mkdir),			"mkdir"			},
 [BASE_NR +  40] = { 1,	TF,		SEN(rmdir),			"rmdir"			},
@@ -87,8 +87,8 @@
 [BASE_NR +  75] = { 2,	0,		SEN(setrlimit),			"setrlimit"		},
 [BASE_NR +  76] = { 2,	0,		SEN(getrlimit),			"getrlimit"		},
 [BASE_NR +  77] = { 2,	0,		SEN(getrusage),			"getrusage"		},
-[BASE_NR +  78] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
-[BASE_NR +  79] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
+[BASE_NR +  78] = { 2,	TCL,		SEN(gettimeofday),		"gettimeofday"		},
+[BASE_NR +  79] = { 2,	TCL,		SEN(settimeofday),		"settimeofday"		},
 [BASE_NR +  80] = { 2,	TC,		SEN(getgroups),			"getgroups"		},
 [BASE_NR +  81] = { 2,	TC,		SEN(setgroups),			"setgroups"		},
 [BASE_NR +  82] = { 0,	0,		SEN(printargs),			"reserved82"		},
@@ -133,7 +133,7 @@
 [BASE_NR + 121] = { 2,	0,		SEN(setdomainname),		"setdomainname"		},
 [BASE_NR + 122] = { 1,	0,		SEN(uname),			"uname"			},
 [BASE_NR + 123] = { 0,	0,		SEN(modify_ldt),		"modify_ldt"		},
-[BASE_NR + 124] = { 1,	0,		SEN(adjtimex32),		"adjtimex"		},
+[BASE_NR + 124] = { 1,	TCL,		SEN(adjtimex32),		"adjtimex"		},
 [BASE_NR + 125] = { 3,	TM|SI,		SEN(mprotect),			"mprotect"		},
 [BASE_NR + 126] = { 3,	TS,		SEN(sigprocmask),		"sigprocmask"		},
 [BASE_NR + 127] = { 2,	0,		SEN(create_module),		"create_module"		},
@@ -207,7 +207,7 @@
 [BASE_NR + 195] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [BASE_NR + 196] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [BASE_NR + 197] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
-[BASE_NR + 198] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[BASE_NR + 198] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [BASE_NR + 199] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [BASE_NR + 200] = { 6,	TD,		SEN(pread),			"pread64"		},
 [BASE_NR + 201] = { 6,	TD,		SEN(pwrite),			"pwrite64"		},
@@ -245,7 +245,7 @@
 [BASE_NR + 233] = { 2,	TF,		SEN(removexattr),		"removexattr"		},
 [BASE_NR + 234] = { 2,	TF,		SEN(removexattr),		"lremovexattr"		},
 [BASE_NR + 235] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
-[BASE_NR + 236] = { 2,	TS,		SEN(kill),			"tkill"			},
+[BASE_NR + 236] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [BASE_NR + 237] = { 4,	TD|TN,		SEN(sendfile64),		"sendfile64"		},
 [BASE_NR + 238] = { 6,	0,		SEN(futex_time32),		"futex"			},
 [BASE_NR + 239] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
@@ -271,11 +271,11 @@
 [BASE_NR + 259] = { 2,	0,		SEN(timer_gettime32),		"timer_gettime"		},
 [BASE_NR + 260] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [BASE_NR + 261] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[BASE_NR + 262] = { 2,	0,		SEN(clock_settime32),		"clock_settime"		},
-[BASE_NR + 263] = { 2,	0,		SEN(clock_gettime32),		"clock_gettime"		},
-[BASE_NR + 264] = { 2,	0,		SEN(clock_getres_time32),	"clock_getres"		},
+[BASE_NR + 262] = { 2,	TCL,		SEN(clock_settime32),		"clock_settime"		},
+[BASE_NR + 263] = { 2,	TCL,		SEN(clock_gettime32),		"clock_gettime"		},
+[BASE_NR + 264] = { 2,	TCL,		SEN(clock_getres_time32),	"clock_getres"		},
 [BASE_NR + 265] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
-[BASE_NR + 266] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[BASE_NR + 266] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [BASE_NR + 267] = { 2,	TF,		SEN(utimes),			"utimes"		},
 [BASE_NR + 268] = { 6,	TM,		SEN(mbind),			"mbind"			},
 [BASE_NR + 269] = { 5,	TM,		SEN(get_mempolicy),		"get_mempolicy"		},
@@ -312,7 +312,7 @@
 [BASE_NR + 300] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [BASE_NR + 301] = { 6,	TD,		SEN(pselect6_time32),		"pselect6"		},
 [BASE_NR + 302] = { 5,	TD,		SEN(ppoll_time32),		"ppoll"			},
-[BASE_NR + 303] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[BASE_NR + 303] = { 1,	0,		SEN(unshare),			"unshare"		},
 [BASE_NR + 304] = { 6,	TD,		SEN(splice),			"splice"		},
 [BASE_NR + 305] = { 7,	TD,		SEN(sync_file_range),		"sync_file_range"	},
 [BASE_NR + 306] = { 4,	TD,		SEN(tee),			"tee"			},
@@ -350,7 +350,7 @@
 [BASE_NR + 338] = { 4,	0,		SEN(prlimit64),			"prlimit64"		},
 [BASE_NR + 339] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [BASE_NR + 340] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[BASE_NR + 341] = { 2,	0,		SEN(clock_adjtime32),		"clock_adjtime"		},
+[BASE_NR + 341] = { 2,	TCL,		SEN(clock_adjtime32),		"clock_adjtime"		},
 [BASE_NR + 342] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [BASE_NR + 343] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
 [BASE_NR + 344] = { 2,	TD,		SEN(setns),			"setns"			},
@@ -375,7 +375,7 @@
 [BASE_NR + 363] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [BASE_NR + 364] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
 [BASE_NR + 365] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
-[BASE_NR + 366] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[BASE_NR + 366] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [BASE_NR + 367] = { 4,	0,		SEN(rseq),			"rseq"			},
 [BASE_NR + 368] = { 6,	0,		SEN(io_pgetevents_time32),	"io_pgetevents"		},
 /* room for arch specific calls */
diff -pruN 5.5-3/linux/powerpc/ioctls_arch0.h 5.9-0ubuntu2/linux/powerpc/ioctls_arch0.h
--- 5.5-3/linux/powerpc/ioctls_arch0.h	2020-01-27 13:21:44.000000000 +0000
+++ 5.9-0ubuntu2/linux/powerpc/ioctls_arch0.h	2020-07-06 21:52:24.000000000 +0000
@@ -89,6 +89,7 @@
 { "asm/ps3fb.h", "PS3FB_IOCTL_ON", _IOC_NONE, 0x7204, 0x00 },
 { "asm/ps3fb.h", "PS3FB_IOCTL_SCREENINFO", _IOC_READ, 0x7203, 0x04 },
 { "asm/ps3fb.h", "PS3FB_IOCTL_SETMODE", _IOC_WRITE, 0x7201, 0x04 },
+{ "asm/vas-api.h", "VAS_TX_WIN_OPEN", _IOC_WRITE, 0x7620, 0x40 },
 { "linux/kvm.h", "KVM_ALLOCATE_RMA", _IOC_READ, 0xaea9, 0x08 },
 { "linux/kvm.h", "KVM_ASSIGN_DEV_IRQ", _IOC_WRITE, 0xae70, 0x40 },
 { "linux/kvm.h", "KVM_ASSIGN_PCI_DEVICE", _IOC_READ, 0xae69, 0x40 },
diff -pruN 5.5-3/linux/powerpc/syscallent.h 5.9-0ubuntu2/linux/powerpc/syscallent.h
--- 5.5-3/linux/powerpc/syscallent.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/linux/powerpc/syscallent.h	2020-08-01 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995 Rick Sladkey <jrs@world.std.com>
- * Copyright (c) 1995-2019 The strace developers.
+ * Copyright (c) 1995-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -20,7 +20,7 @@
 [ 10] = { 1,	TF,		SEN(unlink),			"unlink"		},
 [ 11] = { 3,	TF|TP|TSD|SE|SI,	SEN(execve),			"execve"		},
 [ 12] = { 1,	TF,		SEN(chdir),			"chdir"			},
-[ 13] = { 1,	0,		SEN(time),			"time"			},
+[ 13] = { 1,	TCL,		SEN(time),			"time"			},
 [ 14] = { 3,	TF,		SEN(mknod),			"mknod"			},
 [ 15] = { 2,	TF,		SEN(chmod),			"chmod"			},
 [ 16] = { 3,	TF,		SEN(chown),			"lchown"		},
@@ -44,7 +44,7 @@
 [ 34] = { 1,	0,		SEN(nice),			"nice"			},
 [ 35] = { 0,	0,		SEN(ftime),			"ftime"			},
 [ 36] = { 0,	0,		SEN(sync),			"sync"			},
-[ 37] = { 2,	TS,		SEN(kill),			"kill"			},
+[ 37] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [ 38] = { 2,	TF,		SEN(rename),			"rename"		},
 [ 39] = { 2,	TF,		SEN(mkdir),			"mkdir"			},
 [ 40] = { 1,	TF,		SEN(rmdir),			"rmdir"			},
@@ -85,8 +85,8 @@
 [ 75] = { 2,	0,		SEN(setrlimit),			"setrlimit"		},
 [ 76] = { 2,	0,		SEN(getrlimit),			"getrlimit"		},
 [ 77] = { 2,	0,		SEN(getrusage),			"getrusage"		},
-[ 78] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
-[ 79] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
+[ 78] = { 2,	TCL,		SEN(gettimeofday),		"gettimeofday"		},
+[ 79] = { 2,	TCL,		SEN(settimeofday),		"settimeofday"		},
 [ 80] = { 2,	TC,		SEN(getgroups),			"getgroups"		},
 [ 81] = { 2,	TC,		SEN(setgroups),			"setgroups"		},
 [ 82] = { 1,	TD,		SEN(oldselect),			"select"		},
@@ -131,7 +131,7 @@
 [121] = { 2,	0,		SEN(setdomainname),		"setdomainname"		},
 [122] = { 1,	0,		SEN(uname),			"uname"			},
 [123] = { 5,	0,		SEN(printargs),			"modify_ldt"		},
-[124] = { 1,	0,		SEN(adjtimex32),		"adjtimex"		},
+[124] = { 1,	TCL,		SEN(adjtimex32),		"adjtimex"		},
 [125] = { 3,	TM|SI,		SEN(mprotect),			"mprotect"		},
 [126] = { 3,	TS,		SEN(sigprocmask),		"sigprocmask"		},
 [127] = { 2,	0,		SEN(create_module),		"create_module"		},
@@ -184,7 +184,7 @@
 [174] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [175] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [176] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
-[177] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[177] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [178] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [179] = { 6,	TD,		SEN(pread),			"pread64"		},
 [180] = { 6,	TD,		SEN(pwrite),			"pwrite64"		},
@@ -215,7 +215,7 @@
 [205] = { 3,	TM,		SEN(madvise),			"madvise"		},
 [206] = { 3,	TM,		SEN(mincore),			"mincore"		},
 [207] = { 0,	PU|NF,		SEN(gettid),			"gettid"		},
-[208] = { 2,	TS,		SEN(kill),			"tkill"			},
+[208] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [209] = { 5,	TF,		SEN(setxattr),			"setxattr"		},
 [210] = { 5,	TF,		SEN(setxattr),			"lsetxattr"		},
 [211] = { 5,	TD,		SEN(fsetxattr),			"fsetxattr"		},
@@ -252,12 +252,12 @@
 [242] = { 2,	0,		SEN(timer_gettime32),		"timer_gettime"		},
 [243] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [244] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[245] = { 2,	0,		SEN(clock_settime32),		"clock_settime"		},
-[246] = { 2,	0,		SEN(clock_gettime32),		"clock_gettime"		},
-[247] = { 2,	0,		SEN(clock_getres_time32),	"clock_getres"		},
+[245] = { 2,	TCL,		SEN(clock_settime32),		"clock_settime"		},
+[246] = { 2,	TCL,		SEN(clock_gettime32),		"clock_gettime"		},
+[247] = { 2,	TCL,		SEN(clock_getres_time32),	"clock_getres"		},
 [248] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
 [249] = { 2,	0,		SEN(printargs),			"swapcontext"		},
-[250] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[250] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [251] = { 2,	TF,		SEN(utimes),			"utimes"		},
 [252] = { 3,	TF|TSF|TSFA,	SEN(statfs64),			"statfs64"		},
 [253] = { 3,	TD|TFSF|TSFA,	SEN(fstatfs64),			"fstatfs64"		},
@@ -289,7 +289,7 @@
 [279] = { 4,	0,		SEN(printargs),			"spu_create"		},
 [280] = { 6,	TD,		SEN(pselect6_time32),		"pselect6"		},
 [281] = { 5,	TD,		SEN(ppoll_time32),		"ppoll"			},
-[282] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[282] = { 1,	0,		SEN(unshare),			"unshare"		},
 [283] = { 6,	TD,		SEN(splice),			"splice"		},
 [284] = { 4,	TD,		SEN(tee),			"tee"			},
 [285] = { 4,	TD,		SEN(vmsplice),			"vmsplice"		},
@@ -354,7 +354,7 @@
 [344] = { 4,	TN,		SEN(accept4),			"accept4"		},
 [345] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [346] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[347] = { 2,	0,		SEN(clock_adjtime32),		"clock_adjtime"		},
+[347] = { 2,	TCL,		SEN(clock_adjtime32),		"clock_adjtime"		},
 [348] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [349] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
 [350] = { 2,	TD,		SEN(setns),			"setns"			},
@@ -379,7 +379,7 @@
 [380] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
 [381] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
 [382] = { 5,	TD,		SEN(kexec_file_load),		"kexec_file_load"	},
-[383] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[383] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [384] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
 [385] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
 [386] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
diff -pruN 5.5-3/linux/powerpc64/syscallent.h 5.9-0ubuntu2/linux/powerpc64/syscallent.h
--- 5.5-3/linux/powerpc64/syscallent.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/linux/powerpc64/syscallent.h	2020-08-01 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995 Rick Sladkey <jrs@world.std.com>
- * Copyright (c) 1995-2019 The strace developers.
+ * Copyright (c) 1995-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -20,7 +20,7 @@
 [ 10] = { 1,	TF,		SEN(unlink),			"unlink"		},
 [ 11] = { 3,	TF|TP|TSD|SE|SI,	SEN(execve),			"execve"		},
 [ 12] = { 1,	TF,		SEN(chdir),			"chdir"			},
-[ 13] = { 1,	0,		SEN(time),			"time"			},
+[ 13] = { 1,	TCL,		SEN(time),			"time"			},
 [ 14] = { 3,	TF,		SEN(mknod),			"mknod"			},
 [ 15] = { 2,	TF,		SEN(chmod),			"chmod"			},
 [ 16] = { 3,	TF,		SEN(chown),			"lchown"		},
@@ -44,7 +44,7 @@
 [ 34] = { 1,	0,		SEN(nice),			"nice"			},
 [ 35] = { 0,	0,		SEN(ftime),			"ftime"			},
 [ 36] = { 0,	0,		SEN(sync),			"sync"			},
-[ 37] = { 2,	TS,		SEN(kill),			"kill"			},
+[ 37] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [ 38] = { 2,	TF,		SEN(rename),			"rename"		},
 [ 39] = { 2,	TF,		SEN(mkdir),			"mkdir"			},
 [ 40] = { 1,	TF,		SEN(rmdir),			"rmdir"			},
@@ -85,8 +85,8 @@
 [ 75] = { 2,	0,		SEN(setrlimit),			"setrlimit"		},
 [ 76] = { 2,	0,		SEN(getrlimit),			"getrlimit"		},
 [ 77] = { 2,	0,		SEN(getrusage),			"getrusage"		},
-[ 78] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
-[ 79] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
+[ 78] = { 2,	TCL,		SEN(gettimeofday),		"gettimeofday"		},
+[ 79] = { 2,	TCL,		SEN(settimeofday),		"settimeofday"		},
 [ 80] = { 2,	TC,		SEN(getgroups),			"getgroups"		},
 [ 81] = { 2,	TC,		SEN(setgroups),			"setgroups"		},
 [ 82] = { 1,	TD,		SEN(oldselect),			"select"		},
@@ -131,7 +131,7 @@
 [121] = { 2,	0,		SEN(setdomainname),		"setdomainname"		},
 [122] = { 1,	0,		SEN(uname),			"uname"			},
 [123] = { 5,	0,		SEN(printargs),			"modify_ldt"		},
-[124] = { 1,	0,		SEN(adjtimex64),		"adjtimex"		},
+[124] = { 1,	TCL,		SEN(adjtimex64),		"adjtimex"		},
 [125] = { 3,	TM|SI,		SEN(mprotect),			"mprotect"		},
 [126] = { 3,	TS,		SEN(sigprocmask),		"sigprocmask"		},
 [127] = { 2,	0,		SEN(create_module),		"create_module"		},
@@ -184,7 +184,7 @@
 [174] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [175] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [176] = { 4,	TS,		SEN(rt_sigtimedwait_time64),	"rt_sigtimedwait"	},
-[177] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[177] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [178] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [179] = { 4,	TD,		SEN(pread),			"pread64"		},
 [180] = { 4,	TD,		SEN(pwrite),			"pwrite64"		},
@@ -210,7 +210,7 @@
 [205] = { 3,	TM,		SEN(madvise),			"madvise"		},
 [206] = { 3,	TM,		SEN(mincore),			"mincore"		},
 [207] = { 0,	PU|NF,		SEN(gettid),			"gettid"		},
-[208] = { 2,	TS,		SEN(kill),			"tkill"			},
+[208] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [209] = { 5,	TF,		SEN(setxattr),			"setxattr"		},
 [210] = { 5,	TF,		SEN(setxattr),			"lsetxattr"		},
 [211] = { 5,	TD,		SEN(fsetxattr),			"fsetxattr"		},
@@ -247,12 +247,12 @@
 [242] = { 2,	0,		SEN(timer_gettime64),		"timer_gettime"		},
 [243] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [244] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[245] = { 2,	0,		SEN(clock_settime64),		"clock_settime"		},
-[246] = { 2,	0,		SEN(clock_gettime64),		"clock_gettime"		},
-[247] = { 2,	0,		SEN(clock_getres_time64),	"clock_getres"		},
+[245] = { 2,	TCL,		SEN(clock_settime64),		"clock_settime"		},
+[246] = { 2,	TCL,		SEN(clock_gettime64),		"clock_gettime"		},
+[247] = { 2,	TCL,		SEN(clock_getres_time64),	"clock_getres"		},
 [248] = { 4,	0,		SEN(clock_nanosleep_time64),	"clock_nanosleep"	},
 [249] = { 2,	0,		SEN(printargs),			"swapcontext"		},
-[250] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[250] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [251] = { 2,	TF,		SEN(utimes),			"utimes"		},
 [252] = { 3,	TF|TSF|TSFA,	SEN(statfs64),			"statfs64"		},
 [253] = { 3,	TD|TFSF|TSFA,	SEN(fstatfs64),			"fstatfs64"		},
@@ -284,7 +284,7 @@
 [279] = { 4,	0,		SEN(printargs),			"spu_create"		},
 [280] = { 6,	TD,		SEN(pselect6_time64),		"pselect6"		},
 [281] = { 5,	TD,		SEN(ppoll_time64),		"ppoll"			},
-[282] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[282] = { 1,	0,		SEN(unshare),			"unshare"		},
 [283] = { 6,	TD,		SEN(splice),			"splice"		},
 [284] = { 4,	TD,		SEN(tee),			"tee"			},
 [285] = { 4,	TD,		SEN(vmsplice),			"vmsplice"		},
@@ -349,7 +349,7 @@
 [344] = { 4,	TN,		SEN(accept4),			"accept4"		},
 [345] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [346] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[347] = { 2,	0,		SEN(clock_adjtime64),		"clock_adjtime"		},
+[347] = { 2,	TCL,		SEN(clock_adjtime64),		"clock_adjtime"		},
 [348] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [349] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
 [350] = { 2,	TD,		SEN(setns),			"setns"			},
@@ -374,7 +374,7 @@
 [380] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
 [381] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
 [382] = { 5,	TD,		SEN(kexec_file_load),		"kexec_file_load"	},
-[383] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[383] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [384] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
 [385] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
 [386] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
diff -pruN 5.5-3/linux/s390/arch_regs.c 5.9-0ubuntu2/linux/s390/arch_regs.c
--- 5.5-3/linux/s390/arch_regs.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/linux/s390/arch_regs.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,12 +1,12 @@
 /*
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 /* PTRACE_GETREGSET on S390 is available since linux v2.6.27. */
-static struct user_regs_struct s390_regset;
+static s390_regs s390_regset;
 #define ARCH_REGS_FOR_GETREGSET s390_regset
 #define ARCH_PC_REG s390_regset.psw.addr
 #define ARCH_SP_REG s390_regset.gprs[15]
diff -pruN 5.5-3/linux/s390/ioctls_arch0.h 5.9-0ubuntu2/linux/s390/ioctls_arch0.h
--- 5.5-3/linux/s390/ioctls_arch0.h	2019-11-13 14:06:38.000000000 +0000
+++ 5.9-0ubuntu2/linux/s390/ioctls_arch0.h	2020-06-01 13:19:11.000000000 +0000
@@ -124,6 +124,7 @@
 { "linux/kvm.h", "KVM_REGISTER_COALESCED_MMIO", _IOC_WRITE, 0xae67, 0x10 },
 { "linux/kvm.h", "KVM_REINJECT_CONTROL", _IOC_NONE, 0xae71, 0x00 },
 { "linux/kvm.h", "KVM_RUN", _IOC_NONE, 0xae80, 0x00 },
+{ "linux/kvm.h", "KVM_S390_CLEAR_RESET", _IOC_NONE, 0xaec4, 0x00 },
 { "linux/kvm.h", "KVM_S390_ENABLE_SIE", _IOC_NONE, 0xae06, 0x00 },
 { "linux/kvm.h", "KVM_S390_GET_CMMA_BITS", _IOC_READ|_IOC_WRITE, 0xaeb8, 0x20 },
 { "linux/kvm.h", "KVM_S390_GET_IRQ_STATE", _IOC_WRITE, 0xaeb6, 0x20 },
@@ -132,6 +133,8 @@
 { "linux/kvm.h", "KVM_S390_INTERRUPT", _IOC_WRITE, 0xae94, 0x10 },
 { "linux/kvm.h", "KVM_S390_IRQ", _IOC_WRITE, 0xaeb4, 0x48 },
 { "linux/kvm.h", "KVM_S390_MEM_OP", _IOC_WRITE, 0xaeb1, 0x40 },
+{ "linux/kvm.h", "KVM_S390_NORMAL_RESET", _IOC_NONE, 0xaec3, 0x00 },
+{ "linux/kvm.h", "KVM_S390_PV_COMMAND", _IOC_READ|_IOC_WRITE, 0xaec5, 0x20 },
 { "linux/kvm.h", "KVM_S390_SET_CMMA_BITS", _IOC_WRITE, 0xaeb9, 0x20 },
 { "linux/kvm.h", "KVM_S390_SET_INITIAL_PSW", _IOC_WRITE, 0xae96, 0x10 },
 { "linux/kvm.h", "KVM_S390_SET_IRQ_STATE", _IOC_WRITE, 0xaeb5, 0x20 },
diff -pruN 5.5-3/linux/s390/syscallent.h 5.9-0ubuntu2/linux/s390/syscallent.h
--- 5.5-3/linux/s390/syscallent.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/linux/s390/syscallent.h	2020-08-01 08:00:00.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2000 IBM Deutschland Entwicklung GmbH, IBM Coporation
- * Copyright (c) 2000-2019 The strace developers.
+ * Copyright (c) 2000-2020 The strace developers.
  * Authors: Ulrich Weigand <Ulrich.Weigand@de.ibm.com>
  *          D.J. Barrow  <barrow_dj@mail.yahoo.com,djbarrow@de.ibm.com>
  * All rights reserved.
@@ -22,7 +22,7 @@
 [ 10] = { 1,	TF,		SEN(unlink),			"unlink"		},
 [ 11] = { 3,	TF|TP|TSD|SE|SI,	SEN(execve),			"execve"		},
 [ 12] = { 1,	TF,		SEN(chdir),			"chdir"			},
-[ 13] = { 1,	0,		SEN(time),			"time"			},
+[ 13] = { 1,	TCL,		SEN(time),			"time"			},
 [ 14] = { 3,	TF,		SEN(mknod),			"mknod"			},
 [ 15] = { 2,	TF,		SEN(chmod),			"chmod"			},
 [ 16] = { 3,	TF,		SEN(chown16),			"lchown"		},
@@ -46,7 +46,7 @@
 [ 34] = { 1,	0,		SEN(nice),			"nice"			},
 [ 35] = { },
 [ 36] = { 0,	0,		SEN(sync),			"sync"			},
-[ 37] = { 2,	TS,		SEN(kill),			"kill"			},
+[ 37] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [ 38] = { 2,	TF,		SEN(rename),			"rename"		},
 [ 39] = { 2,	TF,		SEN(mkdir),			"mkdir"			},
 [ 40] = { 1,	TF,		SEN(rmdir),			"rmdir"			},
@@ -87,8 +87,8 @@
 [ 75] = { 2,	0,		SEN(setrlimit),			"setrlimit"		},
 [ 76] = { 2,	0,		SEN(getrlimit),			"getrlimit"		},
 [ 77] = { 2,	0,		SEN(getrusage),			"getrusage"		},
-[ 78] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
-[ 79] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
+[ 78] = { 2,	TCL,		SEN(gettimeofday),		"gettimeofday"		},
+[ 79] = { 2,	TCL,		SEN(settimeofday),		"settimeofday"		},
 [ 80] = { 2,	TC,		SEN(getgroups16),		"getgroups"		},
 [ 81] = { 2,	TC,		SEN(setgroups16),		"setgroups"		},
 [ 82] = { },
@@ -133,7 +133,7 @@
 [121] = { 2,	0,		SEN(setdomainname),		"setdomainname"		},
 [122] = { 1,	0,		SEN(uname),			"uname"			},
 [123] = { },
-[124] = { 1,	0,		SEN(adjtimex32),		"adjtimex"		},
+[124] = { 1,	TCL,		SEN(adjtimex32),		"adjtimex"		},
 [125] = { 3,	TM|SI,		SEN(mprotect),			"mprotect"		},
 [126] = { 3,	TS,		SEN(sigprocmask),		"sigprocmask"		},
 [127] = { 2,	0,		SEN(create_module),		"create_module"		},
@@ -187,7 +187,7 @@
 [175] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [176] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [177] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
-[178] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[178] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [179] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [180] = { 5,	TD,		SEN(pread),			"pread64"		},
 [181] = { 5,	TD,		SEN(pwrite),			"pwrite64"		},
@@ -246,11 +246,11 @@
 [234] = { 2,	TF,		SEN(removexattr),		"lremovexattr"		},
 [235] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
 [236] = { 0,	PU|NF,		SEN(gettid),			"gettid"		},
-[237] = { 2,	TS,		SEN(kill),			"tkill"			},
+[237] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [238] = { 6,	0,		SEN(futex_time32),		"futex"			},
 [239] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
 [240] = { 3,	0,		SEN(sched_getaffinity),		"sched_getaffinity"	},
-[241] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[241] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [242] = { },
 [243] = { 2,	TM,		SEN(io_setup),			"io_setup"		},
 [244] = { 1,	TM,		SEN(io_destroy),		"io_destroy"		},
@@ -268,9 +268,9 @@
 [256] = { 2,	0,		SEN(timer_gettime32),		"timer_gettime"		},
 [257] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [258] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[259] = { 2,	0,		SEN(clock_settime32),		"clock_settime"		},
-[260] = { 2,	0,		SEN(clock_gettime32),		"clock_gettime"		},
-[261] = { 2,	0,		SEN(clock_getres_time32),	"clock_getres"		},
+[259] = { 2,	TCL,		SEN(clock_settime32),		"clock_settime"		},
+[260] = { 2,	TCL,		SEN(clock_gettime32),		"clock_gettime"		},
+[261] = { 2,	TCL,		SEN(clock_getres_time32),	"clock_getres"		},
 [262] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
 [263] = { 5,	0,		SEN(vserver),			"vserver"		},
 [264] = { 6,	TD,		SEN(fadvise64_64),		"fadvise64_64"		},
@@ -312,7 +312,7 @@
 [300] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [301] = { 6,	TD,		SEN(pselect6_time32),		"pselect6"		},
 [302] = { 5,	TD,		SEN(ppoll_time32),		"ppoll"			},
-[303] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[303] = { 1,	0,		SEN(unshare),			"unshare"		},
 [304] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [305] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
 [306] = { 6,	TD,		SEN(splice),			"splice"		},
@@ -346,7 +346,7 @@
 [334] = { 4,	0,		SEN(prlimit64),			"prlimit64"		},
 [335] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [336] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[337] = { 2,	0,		SEN(clock_adjtime32),		"clock_adjtime"		},
+[337] = { 2,	TCL,		SEN(clock_adjtime32),		"clock_adjtime"		},
 [338] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [339] = { 2,	TD,		SEN(setns),			"setns"			},
 [340] = { 6,	0,		SEN(process_vm_readv),		"process_vm_readv"	},
@@ -388,7 +388,7 @@
 [376] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
 [377] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
 [378] = { 2,	0,		SEN(s390_guarded_storage),	"s390_guarded_storage"	},
-[379] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[379] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [380] = { 4,	0,		SEN(s390_sthyi),		"s390_sthyi"		},
 [381] = { 5,	TD,		SEN(kexec_file_load),		"kexec_file_load"	},
 [382] = { 6,	0,		SEN(io_pgetevents_time32),	"io_pgetevents"		},
diff -pruN 5.5-3/linux/s390x/ioctls_arch0.h 5.9-0ubuntu2/linux/s390x/ioctls_arch0.h
--- 5.5-3/linux/s390x/ioctls_arch0.h	2019-11-13 14:06:38.000000000 +0000
+++ 5.9-0ubuntu2/linux/s390x/ioctls_arch0.h	2020-06-01 13:19:11.000000000 +0000
@@ -124,6 +124,7 @@
 { "linux/kvm.h", "KVM_REGISTER_COALESCED_MMIO", _IOC_WRITE, 0xae67, 0x10 },
 { "linux/kvm.h", "KVM_REINJECT_CONTROL", _IOC_NONE, 0xae71, 0x00 },
 { "linux/kvm.h", "KVM_RUN", _IOC_NONE, 0xae80, 0x00 },
+{ "linux/kvm.h", "KVM_S390_CLEAR_RESET", _IOC_NONE, 0xaec4, 0x00 },
 { "linux/kvm.h", "KVM_S390_ENABLE_SIE", _IOC_NONE, 0xae06, 0x00 },
 { "linux/kvm.h", "KVM_S390_GET_CMMA_BITS", _IOC_READ|_IOC_WRITE, 0xaeb8, 0x20 },
 { "linux/kvm.h", "KVM_S390_GET_IRQ_STATE", _IOC_WRITE, 0xaeb6, 0x20 },
@@ -132,6 +133,8 @@
 { "linux/kvm.h", "KVM_S390_INTERRUPT", _IOC_WRITE, 0xae94, 0x10 },
 { "linux/kvm.h", "KVM_S390_IRQ", _IOC_WRITE, 0xaeb4, 0x48 },
 { "linux/kvm.h", "KVM_S390_MEM_OP", _IOC_WRITE, 0xaeb1, 0x40 },
+{ "linux/kvm.h", "KVM_S390_NORMAL_RESET", _IOC_NONE, 0xaec3, 0x00 },
+{ "linux/kvm.h", "KVM_S390_PV_COMMAND", _IOC_READ|_IOC_WRITE, 0xaec5, 0x20 },
 { "linux/kvm.h", "KVM_S390_SET_CMMA_BITS", _IOC_WRITE, 0xaeb9, 0x20 },
 { "linux/kvm.h", "KVM_S390_SET_INITIAL_PSW", _IOC_WRITE, 0xae96, 0x10 },
 { "linux/kvm.h", "KVM_S390_SET_IRQ_STATE", _IOC_WRITE, 0xaeb5, 0x20 },
diff -pruN 5.5-3/linux/s390x/syscallent.h 5.9-0ubuntu2/linux/s390x/syscallent.h
--- 5.5-3/linux/s390x/syscallent.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/linux/s390x/syscallent.h	2020-08-01 08:00:00.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2000 IBM Deutschland Entwicklung GmbH, IBM Coporation
- * Copyright (c) 2000-2019 The strace developers.
+ * Copyright (c) 2000-2020 The strace developers.
  * Author: Ulrich Weigand <Ulrich.Weigand@de.ibm.com>
  * All rights reserved.
  *
@@ -45,7 +45,7 @@
 [ 34] = { 1,	0,		SEN(nice),			"nice"			},
 [ 35] = { },
 [ 36] = { 0,	0,		SEN(sync),			"sync"			},
-[ 37] = { 2,	TS,		SEN(kill),			"kill"			},
+[ 37] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [ 38] = { 2,	TF,		SEN(rename),			"rename"		},
 [ 39] = { 2,	TF,		SEN(mkdir),			"mkdir"			},
 [ 40] = { 1,	TF,		SEN(rmdir),			"rmdir"			},
@@ -83,8 +83,8 @@
 [ 75] = { 2,	0,		SEN(setrlimit),			"setrlimit"		},
 [ 76] = { },
 [ 77] = { 2,	0,		SEN(getrusage),			"getrusage"		},
-[ 78] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
-[ 79] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
+[ 78] = { 2,	TCL,		SEN(gettimeofday),		"gettimeofday"		},
+[ 79] = { 2,	TCL,		SEN(settimeofday),		"settimeofday"		},
 [ 80 ... 82] = { },
 [ 83] = { 2,	TF,		SEN(symlink),			"symlink"		},
 [ 84] = { },
@@ -127,7 +127,7 @@
 [121] = { 2,	0,		SEN(setdomainname),		"setdomainname"		},
 [122] = { 1,	0,		SEN(uname),			"uname"			},
 [123] = { },
-[124] = { 1,	0,		SEN(adjtimex64),		"adjtimex"		},
+[124] = { 1,	TCL,		SEN(adjtimex64),		"adjtimex"		},
 [125] = { 3,	TM|SI,		SEN(mprotect),			"mprotect"		},
 [126] = { 3,	TS,		SEN(sigprocmask),		"sigprocmask"		},
 [127] = { 2,	0,		SEN(create_module),		"create_module"		},
@@ -176,7 +176,7 @@
 [175] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [176] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [177] = { 4,	TS,		SEN(rt_sigtimedwait_time64),	"rt_sigtimedwait"	},
-[178] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[178] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [179] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [180] = { 4,	TD,		SEN(pread),			"pread64"		},
 [181] = { 4,	TD,		SEN(pwrite),			"pwrite64"		},
@@ -230,11 +230,11 @@
 [234] = { 2,	TF,		SEN(removexattr),		"lremovexattr"		},
 [235] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
 [236] = { 0,	PU|NF,		SEN(gettid),			"gettid"		},
-[237] = { 2,	TS,		SEN(kill),			"tkill"			},
+[237] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [238] = { 6,	0,		SEN(futex_time64),		"futex"			},
 [239] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
 [240] = { 3,	0,		SEN(sched_getaffinity),		"sched_getaffinity"	},
-[241] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[241] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [242] = { },
 [243] = { 2,	TM,		SEN(io_setup),			"io_setup"		},
 [244] = { 1,	TM,		SEN(io_destroy),		"io_destroy"		},
@@ -252,9 +252,9 @@
 [256] = { 2,	0,		SEN(timer_gettime64),		"timer_gettime"		},
 [257] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [258] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[259] = { 2,	0,		SEN(clock_settime64),		"clock_settime"		},
-[260] = { 2,	0,		SEN(clock_gettime64),		"clock_gettime"		},
-[261] = { 2,	0,		SEN(clock_getres_time64),	"clock_getres"		},
+[259] = { 2,	TCL,		SEN(clock_settime64),		"clock_settime"		},
+[260] = { 2,	TCL,		SEN(clock_gettime64),		"clock_gettime"		},
+[261] = { 2,	TCL,		SEN(clock_getres_time64),	"clock_getres"		},
 [262] = { 4,	0,		SEN(clock_nanosleep_time64),	"clock_nanosleep"	},
 [263] = { 5,	0,		SEN(vserver),			"vserver"		},
 [264] = { },
@@ -296,7 +296,7 @@
 [300] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [301] = { 6,	TD,		SEN(pselect6_time64),		"pselect6"		},
 [302] = { 5,	TD,		SEN(ppoll_time64),		"ppoll"			},
-[303] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[303] = { 1,	0,		SEN(unshare),			"unshare"		},
 [304] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [305] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
 [306] = { 6,	TD,		SEN(splice),			"splice"		},
@@ -330,7 +330,7 @@
 [334] = { 4,	0,		SEN(prlimit64),			"prlimit64"		},
 [335] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [336] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[337] = { 2,	0,		SEN(clock_adjtime64),		"clock_adjtime"		},
+[337] = { 2,	TCL,		SEN(clock_adjtime64),		"clock_adjtime"		},
 [338] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [339] = { 2,	TD,		SEN(setns),			"setns"			},
 [340] = { 6,	0,		SEN(process_vm_readv),		"process_vm_readv"	},
@@ -372,7 +372,7 @@
 [376] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
 [377] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
 [378] = { 2,	0,		SEN(s390_guarded_storage),	"s390_guarded_storage"	},
-[379] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[379] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [380] = { 4,	0,		SEN(s390_sthyi),		"s390_sthyi"		},
 [381] = { 5,	TD,		SEN(kexec_file_load),		"kexec_file_load"	},
 [382] = { 6,	0,		SEN(io_pgetevents_time64),	"io_pgetevents"		},
diff -pruN 5.5-3/linux/sh/arch_getrval2.c 5.9-0ubuntu2/linux/sh/arch_getrval2.c
--- 5.5-3/linux/sh/arch_getrval2.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/linux/sh/arch_getrval2.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -8,8 +8,5 @@
 long
 getrval2(struct tcb *tcp)
 {
-	unsigned long val;
-	if (upeek(tcp, 4*(REG_REG0+1), &val) < 0)
-		return -1;
-	return val;
+	return sh_regs.regs[1];
 }
diff -pruN 5.5-3/linux/sh/arch_regs.c 5.9-0ubuntu2/linux/sh/arch_regs.c
--- 5.5-3/linux/sh/arch_regs.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/linux/sh/arch_regs.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,10 +1,11 @@
 /*
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-static unsigned long sh_r0;
-#define ARCH_PC_PEEK_ADDR (4 * REG_PC)
-#define ARCH_SP_PEEK_ADDR (4 * 15)
+static struct pt_regs sh_regs;
+#define ARCH_REGS_FOR_GETREGS sh_regs
+#define ARCH_PC_REG sh_regs.pc
+#define ARCH_SP_REG sh_regs.regs[15]
diff -pruN 5.5-3/linux/sh/get_error.c 5.9-0ubuntu2/linux/sh/get_error.c
--- 5.5-3/linux/sh/get_error.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/linux/sh/get_error.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -10,10 +10,10 @@
 static void
 arch_get_error(struct tcb *tcp, const bool check_errno)
 {
-	if (check_errno && is_negated_errno(sh_r0)) {
+	if (check_errno && is_negated_errno(sh_regs.regs[0])) {
 		tcp->u_rval = -1;
-		tcp->u_error = -sh_r0;
+		tcp->u_error = -sh_regs.regs[0];
 	} else {
-		tcp->u_rval = sh_r0;
+		tcp->u_rval = sh_regs.regs[0];
 	}
 }
diff -pruN 5.5-3/linux/sh/get_scno.c 5.9-0ubuntu2/linux/sh/get_scno.c
--- 5.5-3/linux/sh/get_scno.c	2019-07-11 17:51:22.000000000 +0000
+++ 5.9-0ubuntu2/linux/sh/get_scno.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -9,25 +9,6 @@
 static int
 arch_get_scno(struct tcb *tcp)
 {
-	kernel_ulong_t scno = 0;
-
-	/*
-	 * In the new syscall ABI, the system call number is in R3.
-	 */
-	if (upeek(tcp, 4*(REG_REG0+3), &scno) < 0)
-		return -1;
-
-	if ((long) scno < 0) {
-		/* Odd as it may seem, a glibc bug has been known to cause
-		   glibc to issue bogus negative syscall numbers.  So for
-		   our purposes, make strace print what it *should* have been */
-		kernel_ulong_t correct_scno = (scno & 0xff);
-		debug_msg("Detected glibc bug: bogus system call number = %ld,"
-			  " correcting to %ld",
-			  scno, correct_scno);
-		scno = correct_scno;
-	}
-
-	tcp->scno = scno;
+	tcp->scno = sh_regs.regs[3];
 	return 1;
 }
diff -pruN 5.5-3/linux/sh/get_syscall_args.c 5.9-0ubuntu2/linux/sh/get_syscall_args.c
--- 5.5-3/linux/sh/get_syscall_args.c	2019-03-18 02:40:16.000000000 +0000
+++ 5.9-0ubuntu2/linux/sh/get_syscall_args.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -9,18 +9,9 @@
 static int
 arch_get_syscall_args(struct tcb *tcp)
 {
-	static const int syscall_regs[MAX_ARGS] = {
-		4 * (REG_REG0+4),
-		4 * (REG_REG0+5),
-		4 * (REG_REG0+6),
-		4 * (REG_REG0+7),
-		4 * (REG_REG0  ),
-		4 * (REG_REG0+1)
-	};
-	unsigned int i;
+	static const unsigned int syscall_regs[MAX_ARGS] = { 4, 5, 6, 7, 0, 1 };
 
-	for (i = 0; i < n_args(tcp); ++i)
-		if (upeek(tcp, syscall_regs[i], &tcp->u_arg[i]) < 0)
-			return -1;
+	for (unsigned int i = 0; i < n_args(tcp); ++i)
+		tcp->u_arg[i] = sh_regs.regs[syscall_regs[i]];
 	return 1;
 }
diff -pruN 5.5-3/linux/sh/get_syscall_result.c 5.9-0ubuntu2/linux/sh/get_syscall_result.c
--- 5.5-3/linux/sh/get_syscall_result.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/linux/sh/get_syscall_result.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,13 +0,0 @@
-/*
- * Copyright (c) 2015-2018 The strace developers.
- * All rights reserved.
- *
- * SPDX-License-Identifier: LGPL-2.1-or-later
- */
-
-static int
-get_syscall_result_regs(struct tcb *tcp)
-{
-	/* new syscall ABI returns result in R0 */
-	return upeek(tcp, 4 * REG_REG0, &sh_r0) < 0 ? -1 : 0;
-}
diff -pruN 5.5-3/linux/sh/set_error.c 5.9-0ubuntu2/linux/sh/set_error.c
--- 5.5-3/linux/sh/set_error.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/linux/sh/set_error.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -8,13 +8,13 @@
 static int
 arch_set_error(struct tcb *tcp)
 {
-	sh_r0 = -tcp->u_error;
-	return upoke(tcp, 4 * REG_REG0, sh_r0);
+	sh_regs.regs[0] = -tcp->u_error;
+	return set_regs(tcp->pid);
 }
 
 static int
 arch_set_success(struct tcb *tcp)
 {
-	sh_r0 = tcp->u_rval;
-	return upoke(tcp, 4 * REG_REG0, sh_r0);
+	sh_regs.regs[0] = tcp->u_rval;
+	return set_regs(tcp->pid);
 }
diff -pruN 5.5-3/linux/sh/set_scno.c 5.9-0ubuntu2/linux/sh/set_scno.c
--- 5.5-3/linux/sh/set_scno.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/linux/sh/set_scno.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -8,5 +8,8 @@
 static int
 arch_set_scno(struct tcb *tcp, kernel_ulong_t scno)
 {
-	return upoke(tcp, 4 * (REG_REG0 + 3), scno);
+	if (ptrace_syscall_info_is_valid() && get_regs(tcp) < 0)
+		return -1;
+	sh_regs.regs[3] = scno;
+	return set_regs(tcp->pid);
 }
diff -pruN 5.5-3/linux/sh/syscallent.h 5.9-0ubuntu2/linux/sh/syscallent.h
--- 5.5-3/linux/sh/syscallent.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/linux/sh/syscallent.h	2020-08-01 08:00:00.000000000 +0000
@@ -3,7 +3,7 @@
  * Copyright (c) 1993, 1994, 1995 Rick Sladkey <jrs@world.std.com>
  * Copyright (c) 2000 PocketPenguins Inc.  Linux for Hitachi SuperH
  *                    port by Greg Banks <gbanks@pocketpenguins.com>
- * Copyright (c) 2000-2019 The strace developers.
+ * Copyright (c) 2000-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -22,7 +22,7 @@
 [ 10] = { 1,	TF,		SEN(unlink),			"unlink"		},
 [ 11] = { 3,	TF|TP|TSD|SE|SI,	SEN(execve),			"execve"		},
 [ 12] = { 1,	TF,		SEN(chdir),			"chdir"			},
-[ 13] = { 1,	0,		SEN(time),			"time"			},
+[ 13] = { 1,	TCL,		SEN(time),			"time"			},
 [ 14] = { 3,	TF,		SEN(mknod),			"mknod"			},
 [ 15] = { 2,	TF,		SEN(chmod),			"chmod"			},
 [ 16] = { 3,	TF,		SEN(chown16),			"lchown"		},
@@ -46,7 +46,7 @@
 [ 34] = { 1,	0,		SEN(nice),			"nice"			},
 [ 35] = { 0,	0,		SEN(ftime),			"ftime"			},
 [ 36] = { 0,	0,		SEN(sync),			"sync"			},
-[ 37] = { 2,	TS,		SEN(kill),			"kill"			},
+[ 37] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [ 38] = { 2,	TF,		SEN(rename),			"rename"		},
 [ 39] = { 2,	TF,		SEN(mkdir),			"mkdir"			},
 [ 40] = { 1,	TF,		SEN(rmdir),			"rmdir"			},
@@ -87,8 +87,8 @@
 [ 75] = { 2,	0,		SEN(setrlimit),			"setrlimit"		},
 [ 76] = { 2,	0,		SEN(getrlimit),			"getrlimit"		},
 [ 77] = { 2,	0,		SEN(getrusage),			"getrusage"		},
-[ 78] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
-[ 79] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
+[ 78] = { 2,	TCL,		SEN(gettimeofday),		"gettimeofday"		},
+[ 79] = { 2,	TCL,		SEN(settimeofday),		"settimeofday"		},
 [ 80] = { 2,	TC,		SEN(getgroups16),		"getgroups"		},
 [ 81] = { 2,	TC,		SEN(setgroups16),		"setgroups"		},
 [ 82] = { 1,	TD,		SEN(oldselect),			"select"		},
@@ -133,7 +133,7 @@
 [121] = { 2,	0,		SEN(setdomainname),		"setdomainname"		},
 [122] = { 1,	0,		SEN(uname),			"uname"			},
 [123] = { 3,	0,		SEN(cacheflush),		"cacheflush"		},
-[124] = { 1,	0,		SEN(adjtimex32),		"adjtimex"		},
+[124] = { 1,	TCL,		SEN(adjtimex32),		"adjtimex"		},
 [125] = { 3,	TM|SI,		SEN(mprotect),			"mprotect"		},
 [126] = { 3,	TS,		SEN(sigprocmask),		"sigprocmask"		},
 [127] = { 2,	0,		SEN(create_module),		"create_module"		},
@@ -187,7 +187,7 @@
 [175] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [176] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [177] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
-[178] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[178] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [179] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [180] = { 6,	TD,		SEN(pread),			"pread64"		},
 [181] = { 6,	TD,		SEN(pwrite),			"pwrite64"		},
@@ -245,7 +245,7 @@
 [235] = { 2,	TF,		SEN(removexattr),		"removexattr"		},
 [236] = { 2,	TF,		SEN(removexattr),		"lremovexattr"		},
 [237] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
-[238] = { 2,	TS,		SEN(kill),			"tkill"			},
+[238] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [239] = { 4,	TD|TN,		SEN(sendfile64),		"sendfile64"		},
 [240] = { 6,	0,		SEN(futex_time32),		"futex"			},
 [241] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
@@ -270,13 +270,13 @@
 [261] = { 2,	0,		SEN(timer_gettime32),		"timer_gettime"		},
 [262] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [263] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[264] = { 2,	0,		SEN(clock_settime32),		"clock_settime"		},
-[265] = { 2,	0,		SEN(clock_gettime32),		"clock_gettime"		},
-[266] = { 2,	0,		SEN(clock_getres_time32),	"clock_getres"		},
+[264] = { 2,	TCL,		SEN(clock_settime32),		"clock_settime"		},
+[265] = { 2,	TCL,		SEN(clock_gettime32),		"clock_gettime"		},
+[266] = { 2,	TCL,		SEN(clock_getres_time32),	"clock_getres"		},
 [267] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
 [268] = { 3,	TF|TSF|TSFA,	SEN(statfs64),			"statfs64"		},
 [269] = { 3,	TD|TFSF|TSFA,	SEN(fstatfs64),			"fstatfs64"		},
-[270] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[270] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [271] = { 2,	TF,		SEN(utimes),			"utimes"		},
 [272] = { 6,	TD,		SEN(fadvise64_64),		"fadvise64_64"		},
 [273] = { },
@@ -316,7 +316,7 @@
 [307] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [308] = { 6,	TD,		SEN(pselect6_time32),		"pselect6"		},
 [309] = { 5,	TD,		SEN(ppoll_time32),		"ppoll"			},
-[310] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[310] = { 1,	0,		SEN(unshare),			"unshare"		},
 [311] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [312] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
 [313] = { 6,	TD,		SEN(splice),			"splice"		},
@@ -367,7 +367,7 @@
 [358] = { 4,	TN,		SEN(accept4),			"accept4"		},
 [359] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [360] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[361] = { 2,	0,		SEN(clock_adjtime32),		"clock_adjtime"		},
+[361] = { 2,	TCL,		SEN(clock_adjtime32),		"clock_adjtime"		},
 [362] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [363] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
 [364] = { 2,	TD,		SEN(setns),			"setns"			},
@@ -389,7 +389,7 @@
 [380] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
 [381] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
 [382] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
-[383] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[383] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [384] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [385] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
 [386] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
diff -pruN 5.5-3/linux/sh64/arch_regs.c 5.9-0ubuntu2/linux/sh64/arch_regs.c
--- 5.5-3/linux/sh64/arch_regs.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/linux/sh64/arch_regs.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,10 +1,11 @@
 /*
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-static unsigned long sh64_r9;
-#define ARCH_PC_PEEK_ADDR REG_PC
-#define ARCH_SP_PEEK_ADDR REG_GENERAL(15)
+static struct pt_regs sh64_regs;
+#define ARCH_REGS_FOR_GETREGS sh64_regs
+#define ARCH_PC_REG sh64_regs.pc
+#define ARCH_SP_REG sh64_regs.regs[15]
diff -pruN 5.5-3/linux/sh64/arch_regs.h 5.9-0ubuntu2/linux/sh64/arch_regs.h
--- 5.5-3/linux/sh64/arch_regs.h	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/linux/sh64/arch_regs.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,22 +0,0 @@
-/*
- * Copyright (c) 2015-2018 The strace developers.
- * All rights reserved.
- *
- * SPDX-License-Identifier: LGPL-2.1-or-later
- */
-
-/* SH64 Linux - this code assumes the following kernel API for system calls:
-	PC           Offset 0
-	System Call  Offset 16 (actually, (syscall no.) | (0x1n << 16),
-		     where n = no. of parameters.
-	Other regs   Offset 24+
-
-	On entry:    R2-7 = parameters 1-6 (as many as necessary)
-	On return:   R9   = result.
-*/
-
-/* Offset for peeks of registers */
-#define REG_OFFSET	(24)
-#define REG_GENERAL(x)	(8*(x)+REG_OFFSET)
-#define REG_PC		(0*8)
-#define REG_SYSCALL	(2*8)
diff -pruN 5.5-3/linux/sh64/get_error.c 5.9-0ubuntu2/linux/sh64/get_error.c
--- 5.5-3/linux/sh64/get_error.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/linux/sh64/get_error.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -10,10 +10,10 @@
 static void
 arch_get_error(struct tcb *tcp, const bool check_errno)
 {
-	if (check_errno && is_negated_errno(sh64_r9)) {
+	if (check_errno && is_negated_errno(sh64_regs.regs[9])) {
 		tcp->u_rval = -1;
-		tcp->u_error = -sh64_r9;
+		tcp->u_error = -sh64_regs.regs[9];
 	} else {
-		tcp->u_rval = sh64_r9;
+		tcp->u_rval = sh64_regs.regs[9];
 	}
 }
diff -pruN 5.5-3/linux/sh64/get_scno.c 5.9-0ubuntu2/linux/sh64/get_scno.c
--- 5.5-3/linux/sh64/get_scno.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/linux/sh64/get_scno.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -9,8 +9,6 @@
 static int
 arch_get_scno(struct tcb *tcp)
 {
-	if (upeek(tcp, REG_SYSCALL, &tcp->scno) < 0)
-		return -1;
-	tcp->scno &= 0xffff;
+	tcp->scno = sh64_regs.regs[9];
 	return 1;
 }
diff -pruN 5.5-3/linux/sh64/get_syscall_args.c 5.9-0ubuntu2/linux/sh64/get_syscall_args.c
--- 5.5-3/linux/sh64/get_syscall_args.c	2019-03-18 02:40:16.000000000 +0000
+++ 5.9-0ubuntu2/linux/sh64/get_syscall_args.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -9,13 +9,7 @@
 static int
 arch_get_syscall_args(struct tcb *tcp)
 {
-	/* Registers used by SH5 Linux system calls for parameters */
-	static const int syscall_regs[MAX_ARGS] = { 2, 3, 4, 5, 6, 7 };
-	unsigned int i;
-
-	for (i = 0; i < n_args(tcp); ++i)
-		if (upeek(tcp, REG_GENERAL(syscall_regs[i]),
-			  &tcp->u_arg[i]) < 0)
-			return -1;
+	for (unsigned int i = 0; i < n_args(tcp); ++i)
+		tcp->u_arg[i] = sh64_regs.regs[i + 2];
 	return 1;
 }
diff -pruN 5.5-3/linux/sh64/get_syscall_result.c 5.9-0ubuntu2/linux/sh64/get_syscall_result.c
--- 5.5-3/linux/sh64/get_syscall_result.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/linux/sh64/get_syscall_result.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,13 +0,0 @@
-/*
- * Copyright (c) 2015-2018 The strace developers.
- * All rights reserved.
- *
- * SPDX-License-Identifier: LGPL-2.1-or-later
- */
-
-static int
-get_syscall_result_regs(struct tcb *tcp)
-{
-	/* ABI defines result returned in r9 */
-	return upeek(tcp, REG_GENERAL(9), &sh64_r9) < 0 ? -1 : 0;
-}
diff -pruN 5.5-3/linux/sh64/set_error.c 5.9-0ubuntu2/linux/sh64/set_error.c
--- 5.5-3/linux/sh64/set_error.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/linux/sh64/set_error.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -8,13 +8,13 @@
 static int
 arch_set_error(struct tcb *tcp)
 {
-	sh64_r9 = -tcp->u_error;
-	return upoke(tcp, REG_GENERAL(9), sh64_r9);
+	sh64_regs.regs[9] = -tcp->u_error;
+	return set_regs(tcp->pid);
 }
 
 static int
 arch_set_success(struct tcb *tcp)
 {
-	sh64_r9 = tcp->u_rval;
-	return upoke(tcp, REG_GENERAL(9), sh64_r9);
+	sh64_regs.regs[9] = tcp->u_rval;
+	return set_regs(tcp->pid);
 }
diff -pruN 5.5-3/linux/sh64/set_scno.c 5.9-0ubuntu2/linux/sh64/set_scno.c
--- 5.5-3/linux/sh64/set_scno.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/linux/sh64/set_scno.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -8,5 +8,8 @@
 static int
 arch_set_scno(struct tcb *tcp, kernel_ulong_t scno)
 {
-	return upoke(tcp, REG_SYSCALL, scno);
+	if (ptrace_syscall_info_is_valid() && get_regs(tcp) < 0)
+		return -1;
+	sh64_regs.regs[9] = scno;
+	return set_regs(tcp->pid);
 }
diff -pruN 5.5-3/linux/sh64/syscallent.h 5.9-0ubuntu2/linux/sh64/syscallent.h
--- 5.5-3/linux/sh64/syscallent.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/linux/sh64/syscallent.h	2020-08-01 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995 Rick Sladkey <jrs@world.std.com>
- * Copyright (c) 1995-2019 The strace developers.
+ * Copyright (c) 1995-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -20,7 +20,7 @@
 [ 10] = { 1,	TF,		SEN(unlink),			"unlink"		},
 [ 11] = { 3,	TF|TP|TSD|SE|SI,	SEN(execve),			"execve"		},
 [ 12] = { 1,	TF,		SEN(chdir),			"chdir"			},
-[ 13] = { 1,	0,		SEN(time),			"time"			},
+[ 13] = { 1,	TCL,		SEN(time),			"time"			},
 [ 14] = { 3,	TF,		SEN(mknod),			"mknod"			},
 [ 15] = { 2,	TF,		SEN(chmod),			"chmod"			},
 [ 16] = { 3,	TF,		SEN(chown16),			"lchown"		},
@@ -44,7 +44,7 @@
 [ 34] = { 1,	0,		SEN(nice),			"nice"			},
 [ 35] = { 0,	0,		SEN(ftime),			"ftime"			},
 [ 36] = { 0,	0,		SEN(sync),			"sync"			},
-[ 37] = { 2,	TS,		SEN(kill),			"kill"			},
+[ 37] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [ 38] = { 2,	TF,		SEN(rename),			"rename"		},
 [ 39] = { 2,	TF,		SEN(mkdir),			"mkdir"			},
 [ 40] = { 1,	TF,		SEN(rmdir),			"rmdir"			},
@@ -85,8 +85,8 @@
 [ 75] = { 2,	0,		SEN(setrlimit),			"setrlimit"		},
 [ 76] = { 2,	0,		SEN(getrlimit),			"getrlimit"		},
 [ 77] = { 2,	0,		SEN(getrusage),			"getrusage"		},
-[ 78] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
-[ 79] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
+[ 78] = { 2,	TCL,		SEN(gettimeofday),		"gettimeofday"		},
+[ 79] = { 2,	TCL,		SEN(settimeofday),		"settimeofday"		},
 [ 80] = { 2,	TC,		SEN(getgroups16),		"getgroups"		},
 [ 81] = { 2,	TC,		SEN(setgroups16),		"setgroups"		},
 [ 82] = { },
@@ -131,7 +131,7 @@
 [121] = { 2,	0,		SEN(setdomainname),		"setdomainname"		},
 [122] = { 1,	0,		SEN(uname),			"uname"			},
 [123] = { 3,	0,		SEN(printargs),			"cacheflush"		},
-[124] = { 1,	0,		SEN(adjtimex64),		"adjtimex"		},
+[124] = { 1,	TCL,		SEN(adjtimex64),		"adjtimex"		},
 [125] = { 3,	TM|SI,		SEN(mprotect),			"mprotect"		},
 [126] = { 3,	TS,		SEN(sigprocmask),		"sigprocmask"		},
 [127] = { 2,	0,		SEN(create_module),		"create_module"		},
@@ -185,7 +185,7 @@
 [175] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [176] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [177] = { 4,	TS,		SEN(rt_sigtimedwait_time64),	"rt_sigtimedwait"	},
-[178] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[178] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [179] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [180] = { 4,	TD,		SEN(pread),			"pread64"		},
 [181] = { 4,	TD,		SEN(pwrite),			"pwrite64"		},
@@ -271,7 +271,7 @@
 [263] = { 2,	TF,		SEN(removexattr),		"removexattr"		},
 [264] = { 2,	TF,		SEN(removexattr),		"lremovexattr"		},
 [265] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
-[266] = { 2,	TS,		SEN(kill),			"tkill"			},
+[266] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [267] = { 4,	TD|TN,		SEN(sendfile64),		"sendfile64"		},
 [268] = { 6,	0,		SEN(futex_time64),		"futex"			},
 [269] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
@@ -296,13 +296,13 @@
 [289] = { 2,	0,		SEN(timer_gettime64),		"timer_gettime"		},
 [290] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [291] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[292] = { 2,	0,		SEN(clock_settime64),		"clock_settime"		},
-[293] = { 2,	0,		SEN(clock_gettime64),		"clock_gettime"		},
-[294] = { 2,	0,		SEN(clock_getres_time64),	"clock_getres"		},
+[292] = { 2,	TCL,		SEN(clock_settime64),		"clock_settime"		},
+[293] = { 2,	TCL,		SEN(clock_gettime64),		"clock_gettime"		},
+[294] = { 2,	TCL,		SEN(clock_getres_time64),	"clock_getres"		},
 [295] = { 4,	0,		SEN(clock_nanosleep_time64),	"clock_nanosleep"	},
 [296] = { 3,	TF|TSF|TSFA,	SEN(statfs64),			"statfs64"		},
 [297] = { 3,	TD|TFSF|TSFA,	SEN(fstatfs64),			"fstatfs64"		},
-[298] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[298] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [299] = { 2,	TF,		SEN(utimes),			"utimes"		},
 [300] = { 4,	TD,		SEN(fadvise64_64),		"fadvise64_64"		},
 [301] = { },
@@ -342,7 +342,7 @@
 [335] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [336] = { 6,	TD,		SEN(pselect6_time64),		"pselect6"		},
 [337] = { 5,	TD,		SEN(ppoll_time64),		"ppoll"			},
-[338] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[338] = { 1,	0,		SEN(unshare),			"unshare"		},
 [339] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [340] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
 [341] = { 6,	TD,		SEN(splice),			"splice"		},
@@ -376,7 +376,7 @@
 [369] = { 4,	0,		SEN(prlimit64),			"prlimit64"		},
 [370] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [371] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[372] = { 2,	0,		SEN(clock_adjtime64),		"clock_adjtime"		},
+[372] = { 2,	TCL,		SEN(clock_adjtime64),		"clock_adjtime"		},
 [373] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [374] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
 [375] = { 2,	TD,		SEN(setns),			"setns"			},
diff -pruN 5.5-3/linux/sparc/syscallent.h 5.9-0ubuntu2/linux/sparc/syscallent.h
--- 5.5-3/linux/sparc/syscallent.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/linux/sparc/syscallent.h	2020-08-01 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999-2019 The strace developers.
+ * Copyright (c) 1999-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -42,7 +42,7 @@
 [ 34] = { 1,	0,		SEN(nice),			"nice"			},
 [ 35] = { 3,	TF,		SEN(chown),			"chown32"		},
 [ 36] = { 0,	0,		SEN(sync),			"sync"			},
-[ 37] = { 2,	TS,		SEN(kill),			"kill"			},
+[ 37] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [ 38] = { 2,	TF|TST|TSTA,	SEN(stat),			"stat"			},
 [ 39] = { 4,	TD|TN,		SEN(sendfile),			"sendfile"		},
 [ 40] = { 2,	TF|TLST|TSTA,	SEN(lstat),			"lstat"			},
@@ -111,7 +111,7 @@
 [103] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [104] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [105] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
-[106] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[106] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [107] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [108] = { 3,	TC,		SEN(setresuid),			"setresuid32"		},
 [109] = { 3,	TC,		SEN(getresuid),			"getresuid32"		},
@@ -121,13 +121,13 @@
 [113] = { 3,	TN,		SEN(recvmsg),			"recvmsg"		},
 [114] = { 3,	TN,		SEN(sendmsg),			"sendmsg"		},
 [115] = { 2,	TC,		SEN(getgroups),			"getgroups32"		},
-[116] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
+[116] = { 2,	TCL,		SEN(gettimeofday),		"gettimeofday"		},
 [117] = { 2,	0,		SEN(getrusage),			"getrusage"		},
 [118] = { 5,	TN,		SEN(getsockopt),		"getsockopt"		},
 [119] = { 2,	TF,		SEN(getcwd),			"getcwd"		},
 [120] = { 3,	TD,		SEN(readv),			"readv"			},
 [121] = { 3,	TD,		SEN(writev),			"writev"		},
-[122] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
+[122] = { 2,	TCL,		SEN(settimeofday),		"settimeofday"		},
 [123] = { 3,	TD,		SEN(fchown16),			"fchown"		},
 [124] = { 2,	TD,		SEN(fchmod),			"fchmod"		},
 [125] = { 6,	TN,		SEN(recvfrom),			"recvfrom"		},
@@ -192,7 +192,7 @@
 [184] = { 5,	0,		SEN(query_module),		"query_module"		},
 [185] = { 2,	0,		SEN(setpgid),			"setpgid"		},
 [186] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
-[187] = { 2,	TS,		SEN(kill),			"tkill"			},
+[187] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [188] = { 1,	TP|SE,		SEN(exit),			"exit_group"		},
 [189] = { 1,	0,		SEN(uname),			"uname"			},
 [190] = { 3,	0,		SEN(init_module),		"init_module"		},
@@ -216,7 +216,7 @@
 [208] = { 4,	0,		SEN(lookup_dcookie),		"lookup_dcookie"	},
 [209] = { 5,	TD,		SEN(fadvise64),			"fadvise64"		},
 [210] = { 6,	TD,		SEN(fadvise64_64),		"fadvise64_64"		},
-[211] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[211] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [212] = { 3,	TP,		SEN(waitpid),			"waitpid"		},
 [213] = { 1,	TF,		SEN(swapoff),			"swapoff"		},
 [214] = { 1,	0,		SEN(sysinfo),			"sysinfo"		},
@@ -224,7 +224,7 @@
 [216] = { 0,	TS,		SEN(sigreturn),			"sigreturn"		},
 [217] = { 5,	TP,		SEN(clone),			"clone"			},
 [218] = { 2,	0,		SEN(ioprio_get),		"ioprio_get"		},
-[219] = { 1,	0,		SEN(adjtimex32),		"adjtimex"		},
+[219] = { 1,	TCL,		SEN(adjtimex32),		"adjtimex"		},
 [220] = { 3,	TS,		SEN(sigprocmask),		"sigprocmask"		},
 [221] = { 2,	0,		SEN(create_module),		"create_module"		},
 [222] = { 2,	0,		SEN(delete_module),		"delete_module"		},
@@ -236,7 +236,7 @@
 [228] = { 1,	TC|NF,		SEN(setfsuid16),		"setfsuid"		},
 [229] = { 1,	TC|NF,		SEN(setfsgid16),		"setfsgid"		},
 [230] = { 5,	TD,		SEN(select),			"_newselect"		},
-[231] = { 1,	0,		SEN(time),			"time"			},
+[231] = { 1,	TCL,		SEN(time),			"time"			},
 [232] = { 6,	TD,		SEN(splice),			"splice"		},
 [233] = { 1,	0,		SEN(stime),			"stime"			},
 [234] = { 3,	TF|TSF|TSFA,	SEN(statfs64),			"statfs64"		},
@@ -261,9 +261,9 @@
 [253] = { 1,	TD,		SEN(fdatasync),			"fdatasync"		},
 [254] = { 3,	0,		SEN(nfsservctl),		"nfsservctl"		},
 [255] = { 6,	TD,		SEN(sync_file_range),		"sync_file_range"	},
-[256] = { 2,	0,		SEN(clock_settime32),		"clock_settime"		},
-[257] = { 2,	0,		SEN(clock_gettime32),		"clock_gettime"		},
-[258] = { 2,	0,		SEN(clock_getres_time32),	"clock_getres"		},
+[256] = { 2,	TCL,		SEN(clock_settime32),		"clock_settime"		},
+[257] = { 2,	TCL,		SEN(clock_gettime32),		"clock_gettime"		},
+[258] = { 2,	TCL,		SEN(clock_getres_time32),	"clock_getres"		},
 [259] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
 [260] = { 3,	0,		SEN(sched_getaffinity),		"sched_getaffinity"	},
 [261] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
@@ -272,7 +272,7 @@
 [264] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [265] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
 [266] = { 3,	0,		SEN(timer_create),		"timer_create"		},
-[267] = { },
+[267] = { 5,	0,		SEN(vserver),			"vserver"		},
 [268] = { 2,	TM,		SEN(io_setup),			"io_setup"		},
 [269] = { 1,	TM,		SEN(io_destroy),		"io_destroy"		},
 [270] = { 3,	0,		SEN(io_submit),			"io_submit"		},
@@ -304,7 +304,7 @@
 [296] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [297] = { 6,	TD,		SEN(pselect6_time32),		"pselect6"		},
 [298] = { 5,	TD,		SEN(ppoll_time32),		"ppoll"			},
-[299] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[299] = { 1,	0,		SEN(unshare),			"unshare"		},
 [300] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [301] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
 [302] = { 4,	TM,		SEN(migrate_pages),		"migrate_pages"		},
@@ -339,7 +339,7 @@
 [331] = { 4,	0,		SEN(prlimit64),			"prlimit64"		},
 [332] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [333] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[334] = { 2,	0,		SEN(clock_adjtime32),		"clock_adjtime"		},
+[334] = { 2,	TCL,		SEN(clock_adjtime32),		"clock_adjtime"		},
 [335] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [336] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
 [337] = { 2,	TD,		SEN(setns),			"setns"			},
@@ -365,7 +365,7 @@
 [357] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
 [358] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
 [359] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
-[360] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[360] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [361] = { 6,	0,		SEN(io_pgetevents_time32),	"io_pgetevents"		},
 [362] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [363] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
diff -pruN 5.5-3/linux/sparc64/syscallent.h 5.9-0ubuntu2/linux/sparc64/syscallent.h
--- 5.5-3/linux/sparc64/syscallent.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/linux/sparc64/syscallent.h	2020-08-01 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2004-2019 The strace developers.
+ * Copyright (c) 2004-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -41,7 +41,7 @@
 [ 34] = { 1,	0,		SEN(nice),			"nice"			},
 [ 35] = { },
 [ 36] = { 0,	0,		SEN(sync),			"sync"			},
-[ 37] = { 2,	TS,		SEN(kill),			"kill"			},
+[ 37] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [ 38] = { 2,	TF|TST|TSTA,	SEN(stat),			"stat"			},
 [ 39] = { 4,	TD|TN,		SEN(sendfile),			"sendfile"		},
 [ 40] = { 2,	TF|TLST|TSTA,	SEN(lstat),			"lstat"			},
@@ -109,7 +109,7 @@
 [103] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [104] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [105] = { 4,	TS,		SEN(rt_sigtimedwait_time64),	"rt_sigtimedwait"	},
-[106] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[106] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [107] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [108] = { 3,	TC,		SEN(setresuid),			"setresuid"		},
 [109] = { 3,	TC,		SEN(getresuid),			"getresuid"		},
@@ -119,13 +119,13 @@
 [113] = { 3,	TN,		SEN(recvmsg),			"recvmsg"		},
 [114] = { 3,	TN,		SEN(sendmsg),			"sendmsg"		},
 [115] = { },
-[116] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
+[116] = { 2,	TCL,		SEN(gettimeofday),		"gettimeofday"		},
 [117] = { 2,	0,		SEN(getrusage),			"getrusage"		},
 [118] = { 5,	TN,		SEN(getsockopt),		"getsockopt"		},
 [119] = { 2,	TF,		SEN(getcwd),			"getcwd"		},
 [120] = { 3,	TD,		SEN(readv),			"readv"			},
 [121] = { 3,	TD,		SEN(writev),			"writev"		},
-[122] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
+[122] = { 2,	TCL,		SEN(settimeofday),		"settimeofday"		},
 [123] = { 3,	TD,		SEN(fchown),			"fchown"		},
 [124] = { 2,	TD,		SEN(fchmod),			"fchmod"		},
 [125] = { 6,	TN,		SEN(recvfrom),			"recvfrom"		},
@@ -190,7 +190,7 @@
 [184] = { 5,	0,		SEN(query_module),		"query_module"		},
 [185] = { 2,	0,		SEN(setpgid),			"setpgid"		},
 [186] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
-[187] = { 2,	TS,		SEN(kill),			"tkill"			},
+[187] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
 [188] = { 1,	TP|SE,		SEN(exit),			"exit_group"		},
 [189] = { 1,	0,		SEN(uname),			"uname"			},
 [190] = { 3,	0,		SEN(init_module),		"init_module"		},
@@ -214,7 +214,7 @@
 [208] = { 3,	0,		SEN(lookup_dcookie),		"lookup_dcookie"	},
 [209] = { 4,	TD,		SEN(fadvise64),			"fadvise64"		},
 [210] = { 4,	TD,		SEN(fadvise64_64),		"fadvise64_64"		},
-[211] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[211] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [212] = { 3,	TP,		SEN(waitpid),			"waitpid"		},
 [213] = { 1,	TF,		SEN(swapoff),			"swapoff"		},
 [214] = { 1,	0,		SEN(sysinfo),			"sysinfo"		},
@@ -222,7 +222,7 @@
 [216] = { 0,	TS,		SEN(sigreturn),			"sigreturn"		},
 [217] = { 5,	TP,		SEN(clone),			"clone"			},
 [218] = { 2,	0,		SEN(ioprio_get),		"ioprio_get"		},
-[219] = { 1,	0,		SEN(adjtimex64),		"adjtimex"		},
+[219] = { 1,	TCL,		SEN(adjtimex64),		"adjtimex"		},
 [220] = { 3,	TS,		SEN(sigprocmask),		"sigprocmask"		},
 [221] = { 2,	0,		SEN(create_module),		"create_module"		},
 [222] = { 2,	0,		SEN(delete_module),		"delete_module"		},
@@ -259,9 +259,9 @@
 [253] = { 1,	TD,		SEN(fdatasync),			"fdatasync"		},
 [254] = { 3,	0,		SEN(nfsservctl),		"nfsservctl"		},
 [255] = { 4,	TD,		SEN(sync_file_range),		"sync_file_range"	},
-[256] = { 2,	0,		SEN(clock_settime64),		"clock_settime"		},
-[257] = { 2,	0,		SEN(clock_gettime64),		"clock_gettime"		},
-[258] = { 2,	0,		SEN(clock_getres_time64),	"clock_getres"		},
+[256] = { 2,	TCL,		SEN(clock_settime64),		"clock_settime"		},
+[257] = { 2,	TCL,		SEN(clock_gettime64),		"clock_gettime"		},
+[258] = { 2,	TCL,		SEN(clock_getres_time64),	"clock_getres"		},
 [259] = { 4,	0,		SEN(clock_nanosleep_time64),	"clock_nanosleep"	},
 [260] = { 3,	0,		SEN(sched_getaffinity),		"sched_getaffinity"	},
 [261] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
@@ -270,7 +270,7 @@
 [264] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [265] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
 [266] = { 3,	0,		SEN(timer_create),		"timer_create"		},
-[267] = { },
+[267] = { 5,	0,		SEN(vserver),			"vserver"		},
 [268] = { 2,	TM,		SEN(io_setup),			"io_setup"		},
 [269] = { 1,	TM,		SEN(io_destroy),		"io_destroy"		},
 [270] = { 3,	0,		SEN(io_submit),			"io_submit"		},
@@ -302,7 +302,7 @@
 [296] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [297] = { 6,	TD,		SEN(pselect6_time64),		"pselect6"		},
 [298] = { 5,	TD,		SEN(ppoll_time64),		"ppoll"			},
-[299] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[299] = { 1,	0,		SEN(unshare),			"unshare"		},
 [300] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [301] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
 [302] = { 4,	TM,		SEN(migrate_pages),		"migrate_pages"		},
@@ -337,7 +337,7 @@
 [331] = { 4,	0,		SEN(prlimit64),			"prlimit64"		},
 [332] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [333] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[334] = { 2,	0,		SEN(clock_sparc64_adjtime),	"clock_adjtime"		},
+[334] = { 2,	TCL,		SEN(clock_sparc64_adjtime),	"clock_adjtime"		},
 [335] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [336] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
 [337] = { 2,	TD,		SEN(setns),			"setns"			},
@@ -363,7 +363,7 @@
 [357] = { 6,	TD,		SEN(copy_file_range),		"copy_file_range"	},
 [358] = { 6,	TD,		SEN(preadv2),			"preadv2"		},
 [359] = { 6,	TD,		SEN(pwritev2),			"pwritev2"		},
-[360] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[360] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [361] = { 6,	0,		SEN(io_pgetevents_time64),	"io_pgetevents"		},
 [362] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [363] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
diff -pruN 5.5-3/linux/syscallent-common.h 5.9-0ubuntu2/linux/syscallent-common.h
--- 5.5-3/linux/syscallent-common.h	2019-09-23 11:58:41.000000000 +0000
+++ 5.9-0ubuntu2/linux/syscallent-common.h	2020-09-06 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2019 The strace developers.
+ * Copyright (c) 2019-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -8,7 +8,7 @@
 #ifndef BASE_NR
 # define BASE_NR 0
 #endif
-[BASE_NR + 424] = { 4,	TD|TS,		SEN(pidfd_send_signal),		"pidfd_send_signal"	},
+[BASE_NR + 424] = { 4,	TD|TS|TP,		SEN(pidfd_send_signal),		"pidfd_send_signal"	},
 [BASE_NR + 425] = { 2,	TD,		SEN(io_uring_setup),		"io_uring_setup"	},
 [BASE_NR + 426] = { 6,	TD|TS,		SEN(io_uring_enter),		"io_uring_enter"	},
 [BASE_NR + 427] = { 4,	TD|TM,		SEN(io_uring_register),		"io_uring_register"	},
@@ -20,3 +20,7 @@
 [BASE_NR + 433] = { 3,	TD|TF,		SEN(fspick),			"fspick"		},
 [BASE_NR + 434] = { 2,	TD,		SEN(pidfd_open),		"pidfd_open"		},
 [BASE_NR + 435] = { 2,	TP,		SEN(clone3),			"clone3"		},
+[BASE_NR + 436] = { 3,	TD,		SEN(close_range),		"close_range"		},
+[BASE_NR + 437] = { 4,	TD|TF,		SEN(openat2),			"openat2"		},
+[BASE_NR + 438] = { 3,	TD,		SEN(pidfd_getfd),		"pidfd_getfd"		},
+[BASE_NR + 439] = { 4,	TD|TF,		SEN(faccessat2),		"faccessat2"		},
diff -pruN 5.5-3/linux/x32/arch_defs_.h 5.9-0ubuntu2/linux/x32/arch_defs_.h
--- 5.5-3/linux/x32/arch_defs_.h	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/linux/x32/arch_defs_.h	2020-04-19 01:22:29.000000000 +0000
@@ -5,7 +5,6 @@
  * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#define ARCH_TIMESIZE 8
 #define ARCH_SIZEOF_STRUCT_MSQID64_DS 120
 #define HAVE_ARCH_OLD_MMAP 1
 #define HAVE_ARCH_OLD_SELECT 1
diff -pruN 5.5-3/linux/x32/ioctls_inc0.h 5.9-0ubuntu2/linux/x32/ioctls_inc0.h
--- 5.5-3/linux/x32/ioctls_inc0.h	2020-01-27 13:21:44.000000000 +0000
+++ 5.9-0ubuntu2/linux/x32/ioctls_inc0.h	2020-09-23 16:29:35.000000000 +0000
@@ -155,6 +155,7 @@
 { "drm/drm.h", "DRM_IOCTL_MODE_GETCRTC", _IOC_READ|_IOC_WRITE, 0x64a1, 0x68 },
 { "drm/drm.h", "DRM_IOCTL_MODE_GETENCODER", _IOC_READ|_IOC_WRITE, 0x64a6, 0x14 },
 { "drm/drm.h", "DRM_IOCTL_MODE_GETFB", _IOC_READ|_IOC_WRITE, 0x64ad, 0x1c },
+{ "drm/drm.h", "DRM_IOCTL_MODE_GETFB2", _IOC_READ|_IOC_WRITE, 0x64ce, 0x68 },
 { "drm/drm.h", "DRM_IOCTL_MODE_GETGAMMA", _IOC_READ|_IOC_WRITE, 0x64a4, 0x20 },
 { "drm/drm.h", "DRM_IOCTL_MODE_GETPLANE", _IOC_READ|_IOC_WRITE, 0x64b6, 0x20 },
 { "drm/drm.h", "DRM_IOCTL_MODE_GETPLANERESOURCES", _IOC_READ|_IOC_WRITE, 0x64b5, 0x10 },
@@ -268,6 +269,7 @@
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_MADVISE", _IOC_READ|_IOC_WRITE, 0x6466, 0x0c },
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_MMAP", _IOC_READ|_IOC_WRITE, 0x645e, 0x28 },
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_MMAP_GTT", _IOC_READ|_IOC_WRITE, 0x6464, 0x10 },
+{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_MMAP_OFFSET", _IOC_READ|_IOC_WRITE, 0x6464, 0x20 },
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_PIN", _IOC_READ|_IOC_WRITE, 0x6455, 0x18 },
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_PREAD", _IOC_WRITE, 0x645c, 0x20 },
 { "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_PWRITE", _IOC_WRITE, 0x645d, 0x20 },
@@ -330,7 +332,7 @@
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_INFO", _IOC_READ|_IOC_WRITE, 0x6443, 0x18 },
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_MADVISE", _IOC_READ|_IOC_WRITE, 0x6448, 0x0c },
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_NEW", _IOC_READ|_IOC_WRITE, 0x6442, 0x10 },
-{ "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_SUBMIT", _IOC_READ|_IOC_WRITE, 0x6446, 0x28 },
+{ "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_SUBMIT", _IOC_READ|_IOC_WRITE, 0x6446, 0x48 },
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_GET_PARAM", _IOC_READ|_IOC_WRITE, 0x6440, 0x10 },
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_SUBMITQUEUE_CLOSE", _IOC_WRITE, 0x644b, 0x04 },
 { "drm/msm_drm.h", "DRM_IOCTL_MSM_SUBMITQUEUE_NEW", _IOC_READ|_IOC_WRITE, 0x644a, 0x0c },
@@ -695,6 +697,7 @@
 { "linux/btrfs.h", "BTRFS_IOC_SNAP_CREATE", _IOC_WRITE, 0x9401, 0x1000 },
 { "linux/btrfs.h", "BTRFS_IOC_SNAP_CREATE_V2", _IOC_WRITE, 0x9417, 0x1000 },
 { "linux/btrfs.h", "BTRFS_IOC_SNAP_DESTROY", _IOC_WRITE, 0x940f, 0x1000 },
+{ "linux/btrfs.h", "BTRFS_IOC_SNAP_DESTROY_V2", _IOC_WRITE, 0x943f, 0x1000 },
 { "linux/btrfs.h", "BTRFS_IOC_SPACE_INFO", _IOC_READ|_IOC_WRITE, 0x9414, 0x10 },
 { "linux/btrfs.h", "BTRFS_IOC_START_SYNC", _IOC_READ, 0x9418, 0x08 },
 { "linux/btrfs.h", "BTRFS_IOC_SUBVOL_CREATE", _IOC_WRITE, 0x940e, 0x1000 },
@@ -830,7 +833,9 @@
 { "linux/dm-ioctl.h", "DM_TARGET_MSG", _IOC_READ|_IOC_WRITE, 0xfd0e, 0x138 },
 { "linux/dm-ioctl.h", "DM_VERSION", _IOC_READ|_IOC_WRITE, 0xfd00, 0x138 },
 { "linux/dma-buf.h", "DMA_BUF_IOCTL_SYNC", _IOC_WRITE, 0x6200, 0x08 },
-{ "linux/dma-buf.h", "DMA_BUF_SET_NAME", _IOC_WRITE, 0x6201, 0x04 },
+{ "linux/dma-buf.h", "DMA_BUF_SET_NAME_A", _IOC_WRITE, 0x6201, 0x04 },
+{ "linux/dma-buf.h", "DMA_BUF_SET_NAME_B", _IOC_WRITE, 0x6201, 0x08 },
+{ "linux/dma-heap.h", "DMA_HEAP_IOCTL_ALLOC", _IOC_READ|_IOC_WRITE, 0x4800, 0x18 },
 { "linux/dn.h", "OSIOCGNETADDR", _IOC_READ, 0x89e1, 0x04 },
 { "linux/dn.h", "OSIOCSNETADDR", _IOC_WRITE, 0x89e0, 0x04 },
 { "linux/dn.h", "SIOCGNETADDR", _IOC_READ, 0x89e1, 0x04 },
@@ -987,15 +992,21 @@
 { "linux/firewire-cdev.h", "FW_CDEV_IOC_START_ISO", _IOC_WRITE, 0x230a, 0x10 },
 { "linux/firewire-cdev.h", "FW_CDEV_IOC_STOP_ISO", _IOC_WRITE, 0x230b, 0x04 },
 { "linux/fpga-dfl.h", "DFL_FPGA_CHECK_EXTENSION", _IOC_NONE, 0xb601, 0x00 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_FME_ERR_GET_IRQ_NUM", _IOC_READ, 0xb683, 0x04 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_FME_ERR_SET_IRQ", _IOC_WRITE, 0xb684, 0x08 },
 { "linux/fpga-dfl.h", "DFL_FPGA_FME_PORT_ASSIGN", _IOC_WRITE, 0xb682, 0x04 },
 { "linux/fpga-dfl.h", "DFL_FPGA_FME_PORT_PR", _IOC_NONE, 0xb680, 0x00 },
 { "linux/fpga-dfl.h", "DFL_FPGA_FME_PORT_RELEASE", _IOC_WRITE, 0xb681, 0x04 },
 { "linux/fpga-dfl.h", "DFL_FPGA_GET_API_VERSION", _IOC_NONE, 0xb600, 0x00 },
 { "linux/fpga-dfl.h", "DFL_FPGA_PORT_DMA_MAP", _IOC_NONE, 0xb643, 0x00 },
 { "linux/fpga-dfl.h", "DFL_FPGA_PORT_DMA_UNMAP", _IOC_NONE, 0xb644, 0x00 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_ERR_GET_IRQ_NUM", _IOC_READ, 0xb645, 0x04 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_ERR_SET_IRQ", _IOC_WRITE, 0xb646, 0x08 },
 { "linux/fpga-dfl.h", "DFL_FPGA_PORT_GET_INFO", _IOC_NONE, 0xb641, 0x00 },
 { "linux/fpga-dfl.h", "DFL_FPGA_PORT_GET_REGION_INFO", _IOC_NONE, 0xb642, 0x00 },
 { "linux/fpga-dfl.h", "DFL_FPGA_PORT_RESET", _IOC_NONE, 0xb640, 0x00 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_UINT_GET_IRQ_NUM", _IOC_READ, 0xb647, 0x04 },
+{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_UINT_SET_IRQ", _IOC_WRITE, 0xb648, 0x08 },
 { "linux/fs.h", "BLKALIGNOFF", _IOC_NONE, 0x127a, 0x00 },
 { "linux/fs.h", "BLKBSZGET", _IOC_READ, 0x1270, 0x04 },
 { "linux/fs.h", "BLKBSZSET", _IOC_WRITE, 0x1271, 0x04 },
@@ -1047,6 +1058,7 @@
 { "linux/fs.h", "FS_IOC_SETVERSION", _IOC_WRITE, 0x7602, 0x04 },
 { "linux/fscrypt.h", "FS_IOC_ADD_ENCRYPTION_KEY", _IOC_READ|_IOC_WRITE, 0x6617, 0x50 },
 { "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_KEY_STATUS", _IOC_READ|_IOC_WRITE, 0x661a, 0x80 },
+{ "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_NONCE", _IOC_READ, 0x661b, 0x10 },
 { "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_POLICY", _IOC_WRITE, 0x6615, 0x0c },
 { "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_POLICY_EX", _IOC_READ|_IOC_WRITE, 0x6616, 0x09 },
 { "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_PWSALT", _IOC_WRITE, 0x6614, 0x10 },
@@ -1092,10 +1104,6 @@
 { "linux/genwqe/genwqe_card.h", "GENWQE_WRITE_REG16", _IOC_WRITE, 0xa523, 0x10 },
 { "linux/genwqe/genwqe_card.h", "GENWQE_WRITE_REG32", _IOC_WRITE, 0xa521, 0x10 },
 { "linux/genwqe/genwqe_card.h", "GENWQE_WRITE_REG64", _IOC_WRITE, 0xa51f, 0x10 },
-{ "linux/gigaset_dev.h", "GIGASET_BRKCHARS", _IOC_WRITE, 0x4702, 0x06 },
-{ "linux/gigaset_dev.h", "GIGASET_CONFIG", _IOC_READ|_IOC_WRITE, 0x4701, 0x04 },
-{ "linux/gigaset_dev.h", "GIGASET_REDIR", _IOC_READ|_IOC_WRITE, 0x4700, 0x04 },
-{ "linux/gigaset_dev.h", "GIGASET_VERSION", _IOC_READ|_IOC_WRITE, 0x4703, 0x10 },
 { "linux/gpio.h", "GPIOHANDLE_GET_LINE_VALUES_IOCTL", _IOC_READ|_IOC_WRITE, 0xb408, 0x40 },
 { "linux/gpio.h", "GPIOHANDLE_SET_CONFIG_IOCTL", _IOC_READ|_IOC_WRITE, 0xb40a, 0x54 },
 { "linux/gpio.h", "GPIOHANDLE_SET_LINE_VALUES_IOCTL", _IOC_READ|_IOC_WRITE, 0xb409, 0x40 },
@@ -1103,6 +1111,8 @@
 { "linux/gpio.h", "GPIO_GET_LINEEVENT_IOCTL", _IOC_READ|_IOC_WRITE, 0xb404, 0x30 },
 { "linux/gpio.h", "GPIO_GET_LINEHANDLE_IOCTL", _IOC_READ|_IOC_WRITE, 0xb403, 0x16c },
 { "linux/gpio.h", "GPIO_GET_LINEINFO_IOCTL", _IOC_READ|_IOC_WRITE, 0xb402, 0x48 },
+{ "linux/gpio.h", "GPIO_GET_LINEINFO_UNWATCH_IOCTL", _IOC_READ|_IOC_WRITE, 0xb40c, 0x04 },
+{ "linux/gpio.h", "GPIO_GET_LINEINFO_WATCH_IOCTL", _IOC_READ|_IOC_WRITE, 0xb40b, 0x48 },
 { "linux/gsmmux.h", "GSMIOC_DISABLE_NET", _IOC_NONE, 0x4703, 0x00 },
 { "linux/gsmmux.h", "GSMIOC_ENABLE_NET", _IOC_WRITE, 0x4702, 0x34 },
 { "linux/gsmmux.h", "GSMIOC_GETCONF", _IOC_READ, 0x4700, 0x4c },
@@ -1346,6 +1356,7 @@
 { "linux/kd.h", "PIO_UNISCRNMAP", 0, 0x4B6A, 0 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_ACQUIRE_VM", _IOC_WRITE, 0x4b15, 0x08 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_ALLOC_MEMORY_OF_GPU", _IOC_READ|_IOC_WRITE, 0x4b16, 0x28 },
+{ "linux/kfd_ioctl.h", "AMDKFD_IOC_ALLOC_QUEUE_GWS", _IOC_READ|_IOC_WRITE, 0x4b1e, 0x10 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_CREATE_EVENT", _IOC_READ|_IOC_WRITE, 0x4b08, 0x20 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_CREATE_QUEUE", _IOC_READ|_IOC_WRITE, 0x4b02, 0x58 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_DBG_ADDRESS_WATCH", _IOC_WRITE, 0x4b0f, 0x10 },
@@ -1370,6 +1381,7 @@
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_SET_MEMORY_POLICY", _IOC_WRITE, 0x4b04, 0x20 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_SET_SCRATCH_BACKING_VA", _IOC_READ|_IOC_WRITE, 0x4b11, 0x10 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_SET_TRAP_HANDLER", _IOC_WRITE, 0x4b13, 0x18 },
+{ "linux/kfd_ioctl.h", "AMDKFD_IOC_SMI_EVENTS", _IOC_READ|_IOC_WRITE, 0x4b1f, 0x08 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_UNMAP_MEMORY_FROM_GPU", _IOC_READ|_IOC_WRITE, 0x4b19, 0x18 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_UPDATE_QUEUE", _IOC_WRITE, 0x4b07, 0x18 },
 { "linux/kfd_ioctl.h", "AMDKFD_IOC_WAIT_EVENTS", _IOC_READ|_IOC_WRITE, 0x4b0c, 0x18 },
@@ -1403,6 +1415,7 @@
 { "linux/lirc.h", "LIRC_SET_WIDEBAND_RECEIVER", _IOC_WRITE, 0x6923, 0x04 },
 { "linux/loop.h", "LOOP_CHANGE_FD", 0, 0x4C06, 0 },
 { "linux/loop.h", "LOOP_CLR_FD", 0, 0x4C01, 0 },
+{ "linux/loop.h", "LOOP_CONFIGURE", 0, 0x4C0A, 0 },
 { "linux/loop.h", "LOOP_CTL_ADD", 0, 0x4C80, 0 },
 { "linux/loop.h", "LOOP_CTL_GET_FREE", 0, 0x4C82, 0 },
 { "linux/loop.h", "LOOP_CTL_REMOVE", 0, 0x4C81, 0 },
@@ -1547,6 +1560,7 @@
 { "linux/omapfb.h", "OMAPFB_WAITFORGO", _IOC_NONE, 0x4f3c, 0x00 },
 { "linux/omapfb.h", "OMAPFB_WAITFORVSYNC", _IOC_NONE, 0x4f39, 0x00 },
 { "linux/pcitest.h", "PCITEST_BAR", _IOC_NONE, 0x5001, 0x00 },
+{ "linux/pcitest.h", "PCITEST_CLEAR_IRQ", _IOC_NONE, 0x5010, 0x00 },
 { "linux/pcitest.h", "PCITEST_COPY", _IOC_WRITE, 0x5006, 0x04 },
 { "linux/pcitest.h", "PCITEST_GET_IRQTYPE", _IOC_NONE, 0x5009, 0x00 },
 { "linux/pcitest.h", "PCITEST_LEGACY_IRQ", _IOC_NONE, 0x5002, 0x00 },
@@ -1707,6 +1721,8 @@
 { "linux/raw.h", "RAW_GETBIND", _IOC_NONE, 0xac01, 0x00 },
 { "linux/raw.h", "RAW_SETBIND", _IOC_NONE, 0xac00, 0x00 },
 { "linux/reiserfs_fs.h", "REISERFS_IOC_UNPACK", _IOC_WRITE, 0xcd01, 0x04 },
+{ "linux/remoteproc_cdev.h", "RPROC_GET_SHUTDOWN_ON_RELEASE", _IOC_READ, 0xb702, 0x04 },
+{ "linux/remoteproc_cdev.h", "RPROC_SET_SHUTDOWN_ON_RELEASE", _IOC_WRITE, 0xb701, 0x04 },
 { "linux/rfkill.h", "RFKILL_IOCTL_NOINPUT", _IOC_NONE, 0x5201, 0x00 },
 { "linux/rio_cm_cdev.h", "RIO_CM_CHAN_ACCEPT", _IOC_READ|_IOC_WRITE, 0x6307, 0x08 },
 { "linux/rio_cm_cdev.h", "RIO_CM_CHAN_BIND", _IOC_WRITE, 0x6305, 0x08 },
@@ -1784,7 +1800,8 @@
 { "linux/scif_ioctl.h", "SCIF_VREADFROM", _IOC_READ|_IOC_WRITE, 0x730c, 0x28 },
 { "linux/scif_ioctl.h", "SCIF_VWRITETO", _IOC_READ|_IOC_WRITE, 0x730d, 0x28 },
 { "linux/scif_ioctl.h", "SCIF_WRITETO", _IOC_READ|_IOC_WRITE, 0x730b, 0x28 },
-{ "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_ID_VALID", _IOC_READ, 0x2102, 0x08 },
+{ "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_ADDFD", _IOC_WRITE, 0x2103, 0x18 },
+{ "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_ID_VALID", _IOC_WRITE, 0x2102, 0x08 },
 { "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_RECV", _IOC_READ|_IOC_WRITE, 0x2100, 0x50 },
 { "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_SEND", _IOC_READ|_IOC_WRITE, 0x2101, 0x18 },
 { "linux/sed-opal.h", "IOC_OPAL_ACTIVATE_LSP", _IOC_WRITE, 0x70df, 0x118 },
@@ -2100,6 +2117,22 @@
 { "linux/usb/iowarrior.h", "IOW_GETINFO", _IOC_READ, 0xc003, 0x28 },
 { "linux/usb/iowarrior.h", "IOW_READ", _IOC_WRITE, 0xc002, 0x04 },
 { "linux/usb/iowarrior.h", "IOW_WRITE", _IOC_WRITE, 0xc001, 0x04 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_CONFIGURE", _IOC_NONE, 0x5509, 0x00 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP0_READ", _IOC_READ|_IOC_WRITE, 0x5504, 0x08 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP0_STALL", _IOC_NONE, 0x550c, 0x00 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP0_WRITE", _IOC_WRITE, 0x5503, 0x08 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EPS_INFO", _IOC_READ, 0x550b, 0x3c0 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_CLEAR_HALT", _IOC_WRITE, 0x550e, 0x04 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_DISABLE", _IOC_WRITE, 0x5506, 0x04 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_ENABLE", _IOC_WRITE, 0x5505, 0x09 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_READ", _IOC_READ|_IOC_WRITE, 0x5508, 0x08 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_SET_HALT", _IOC_WRITE, 0x550d, 0x04 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_SET_WEDGE", _IOC_WRITE, 0x550f, 0x04 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_WRITE", _IOC_WRITE, 0x5507, 0x08 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EVENT_FETCH", _IOC_READ, 0x5502, 0x08 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_INIT", _IOC_WRITE, 0x5500, 0x101 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_RUN", _IOC_NONE, 0x5501, 0x00 },
+{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_VBUS_DRAW", _IOC_WRITE, 0x550a, 0x04 },
 { "linux/usb/tmc.h", "USBTMC488_IOCTL_GET_CAPS", _IOC_READ, 0x5b11, 0x01 },
 { "linux/usb/tmc.h", "USBTMC488_IOCTL_GOTO_LOCAL", _IOC_NONE, 0x5b14, 0x00 },
 { "linux/usb/tmc.h", "USBTMC488_IOCTL_LOCAL_LOCKOUT", _IOC_NONE, 0x5b15, 0x00 },
@@ -2169,6 +2202,7 @@
 { "linux/userfaultfd.h", "UFFDIO_REGISTER", _IOC_READ|_IOC_WRITE, 0xaa00, 0x20 },
 { "linux/userfaultfd.h", "UFFDIO_UNREGISTER", _IOC_READ, 0xaa01, 0x10 },
 { "linux/userfaultfd.h", "UFFDIO_WAKE", _IOC_READ, 0xaa02, 0x10 },
+{ "linux/userfaultfd.h", "UFFDIO_WRITEPROTECT", _IOC_READ|_IOC_WRITE, 0xaa06, 0x18 },
 { "linux/userfaultfd.h", "UFFDIO_ZEROPAGE", _IOC_READ|_IOC_WRITE, 0xaa04, 0x20 },
 { "linux/uvcvideo.h", "UVCIOC_CTRL_MAP", _IOC_READ|_IOC_WRITE, 0x7520, 0x58 },
 { "linux/uvcvideo.h", "UVCIOC_CTRL_QUERY", _IOC_READ|_IOC_WRITE, 0x7521, 0x0c },
@@ -2179,10 +2213,12 @@
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_G_FMT", _IOC_READ|_IOC_WRITE, 0x5604, 0x58 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_G_FRAME_INTERVAL", _IOC_READ|_IOC_WRITE, 0x5615, 0x30 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_G_SELECTION", _IOC_READ|_IOC_WRITE, 0x563d, 0x40 },
+{ "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_QUERYCAP", _IOC_READ, 0x5600, 0x40 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_S_CROP", _IOC_READ|_IOC_WRITE, 0x563c, 0x38 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_S_FMT", _IOC_READ|_IOC_WRITE, 0x5605, 0x58 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_S_FRAME_INTERVAL", _IOC_READ|_IOC_WRITE, 0x5616, 0x30 },
 { "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_S_SELECTION", _IOC_READ|_IOC_WRITE, 0x563e, 0x40 },
+{ "linux/vboxguest.h", "VBG_IOCTL_ACQUIRE_GUEST_CAPABILITIES", _IOC_READ|_IOC_WRITE, 0x560d, 0x24 },
 { "linux/vboxguest.h", "VBG_IOCTL_CHANGE_FILTER_MASK", _IOC_READ|_IOC_WRITE, 0x560c, 0x20 },
 { "linux/vboxguest.h", "VBG_IOCTL_CHANGE_GUEST_CAPABILITIES", _IOC_READ|_IOC_WRITE, 0x560e, 0x20 },
 { "linux/vboxguest.h", "VBG_IOCTL_CHECK_BALLOON", _IOC_READ|_IOC_WRITE, 0x5611, 0x20 },
@@ -2190,10 +2226,11 @@
 { "linux/vboxguest.h", "VBG_IOCTL_HGCM_CONNECT", _IOC_READ|_IOC_WRITE, 0x5604, 0x9c },
 { "linux/vboxguest.h", "VBG_IOCTL_HGCM_DISCONNECT", _IOC_READ|_IOC_WRITE, 0x5605, 0x1c },
 { "linux/vboxguest.h", "VBG_IOCTL_INTERRUPT_ALL_WAIT_FOR_EVENTS", _IOC_READ|_IOC_WRITE, 0x560b, 0x18 },
-{ "linux/vboxguest.h", "VBG_IOCTL_VMMDEV_REQUEST_BIG", _IOC_READ|_IOC_WRITE, 0x5603, 0x00 },
+{ "linux/vboxguest.h", "VBG_IOCTL_VMMDEV_REQUEST_BIG", _IOC_NONE, 0x5603, 0x00 },
 { "linux/vboxguest.h", "VBG_IOCTL_WAIT_FOR_EVENTS", _IOC_READ|_IOC_WRITE, 0x560a, 0x20 },
 { "linux/vboxguest.h", "VBG_IOCTL_WRITE_CORE_DUMP", _IOC_READ|_IOC_WRITE, 0x5613, 0x1c },
 { "linux/vfio.h", "VFIO_CHECK_EXTENSION", _IOC_NONE, 0x3b65, 0x00 },
+{ "linux/vfio.h", "VFIO_DEVICE_FEATURE", _IOC_NONE, 0x3b75, 0x00 },
 { "linux/vfio.h", "VFIO_DEVICE_GET_GFX_DMABUF", _IOC_NONE, 0x3b73, 0x00 },
 { "linux/vfio.h", "VFIO_DEVICE_GET_INFO", _IOC_NONE, 0x3b6b, 0x00 },
 { "linux/vfio.h", "VFIO_DEVICE_GET_IRQ_INFO", _IOC_NONE, 0x3b6d, 0x00 },
@@ -2210,6 +2247,7 @@
 { "linux/vfio.h", "VFIO_GROUP_GET_STATUS", _IOC_NONE, 0x3b67, 0x00 },
 { "linux/vfio.h", "VFIO_GROUP_SET_CONTAINER", _IOC_NONE, 0x3b68, 0x00 },
 { "linux/vfio.h", "VFIO_GROUP_UNSET_CONTAINER", _IOC_NONE, 0x3b69, 0x00 },
+{ "linux/vfio.h", "VFIO_IOMMU_DIRTY_PAGES", _IOC_NONE, 0x3b75, 0x00 },
 { "linux/vfio.h", "VFIO_IOMMU_DISABLE", _IOC_NONE, 0x3b74, 0x00 },
 { "linux/vfio.h", "VFIO_IOMMU_ENABLE", _IOC_NONE, 0x3b73, 0x00 },
 { "linux/vfio.h", "VFIO_IOMMU_GET_INFO", _IOC_NONE, 0x3b70, 0x00 },
@@ -2247,6 +2285,14 @@
 { "linux/vhost.h", "VHOST_SET_VRING_ERR", _IOC_WRITE, 0xaf22, 0x08 },
 { "linux/vhost.h", "VHOST_SET_VRING_KICK", _IOC_WRITE, 0xaf20, 0x08 },
 { "linux/vhost.h", "VHOST_SET_VRING_NUM", _IOC_WRITE, 0xaf10, 0x08 },
+{ "linux/vhost.h", "VHOST_VDPA_GET_CONFIG", _IOC_READ, 0xaf73, 0x08 },
+{ "linux/vhost.h", "VHOST_VDPA_GET_DEVICE_ID", _IOC_READ, 0xaf70, 0x04 },
+{ "linux/vhost.h", "VHOST_VDPA_GET_STATUS", _IOC_READ, 0xaf71, 0x01 },
+{ "linux/vhost.h", "VHOST_VDPA_GET_VRING_NUM", _IOC_READ, 0xaf76, 0x02 },
+{ "linux/vhost.h", "VHOST_VDPA_SET_CONFIG", _IOC_WRITE, 0xaf74, 0x08 },
+{ "linux/vhost.h", "VHOST_VDPA_SET_CONFIG_CALL", _IOC_WRITE, 0xaf77, 0x04 },
+{ "linux/vhost.h", "VHOST_VDPA_SET_STATUS", _IOC_WRITE, 0xaf72, 0x01 },
+{ "linux/vhost.h", "VHOST_VDPA_SET_VRING_ENABLE", _IOC_WRITE, 0xaf75, 0x08 },
 { "linux/vhost.h", "VHOST_VSOCK_SET_GUEST_CID", _IOC_WRITE, 0xaf60, 0x08 },
 { "linux/vhost.h", "VHOST_VSOCK_SET_RUNNING", _IOC_WRITE, 0xaf61, 0x04 },
 { "linux/videodev2.h", "VIDIOC_CREATE_BUFS", _IOC_READ|_IOC_WRITE, 0x565c, 0xf8 },
@@ -2369,6 +2415,8 @@
 { "linux/vt.h", "VT_WAITACTIVE", 0, 0x5607, 0 },
 { "linux/vt.h", "VT_WAITEVENT", 0, 0x560E, 0 },
 { "linux/vtpm_proxy.h", "VTPM_PROXY_IOC_NEW_DEV", _IOC_READ|_IOC_WRITE, 0xa100, 0x14 },
+{ "linux/watch_queue.h", "IOC_WATCH_QUEUE_SET_FILTER", _IOC_NONE, 0x5761, 0x00 },
+{ "linux/watch_queue.h", "IOC_WATCH_QUEUE_SET_SIZE", _IOC_NONE, 0x5760, 0x00 },
 { "linux/watchdog.h", "WDIOC_GETBOOTSTATUS", _IOC_READ, 0x5702, 0x04 },
 { "linux/watchdog.h", "WDIOC_GETPRETIMEOUT", _IOC_READ, 0x5709, 0x04 },
 { "linux/watchdog.h", "WDIOC_GETSTATUS", _IOC_READ, 0x5701, 0x04 },
@@ -2444,6 +2492,11 @@
 { "media/i2c/saa6588.h", "SAA6588_CMD_READ", _IOC_READ, 0x5203, 0x04 },
 { "media/v4l2-common.h", "TUNER_SET_CONFIG", _IOC_WRITE, 0x645c, 0x08 },
 { "media/v4l2-common.h", "VIDIOC_INT_RESET", _IOC_WRITE, 0x6466, 0x04 },
+{ "media/v4l2-ioctl.h", "VIDIOC_DQBUF_TIME32", _IOC_READ|_IOC_WRITE, 0x5611, 0x44 },
+{ "media/v4l2-ioctl.h", "VIDIOC_DQEVENT_TIME32", _IOC_READ, 0x5659, 0x80 },
+{ "media/v4l2-ioctl.h", "VIDIOC_PREPARE_BUF_TIME32", _IOC_READ|_IOC_WRITE, 0x565d, 0x44 },
+{ "media/v4l2-ioctl.h", "VIDIOC_QBUF_TIME32", _IOC_READ|_IOC_WRITE, 0x560f, 0x44 },
+{ "media/v4l2-ioctl.h", "VIDIOC_QUERYBUF_TIME32", _IOC_READ|_IOC_WRITE, 0x5609, 0x44 },
 { "media/v4l2-subdev.h", "V4L2_DEVICE_NOTIFY_EVENT", _IOC_WRITE, 0x7602, 0x88 },
 { "media/v4l2-subdev.h", "V4L2_SUBDEV_IR_RX_NOTIFY", _IOC_WRITE, 0x7600, 0x04 },
 { "media/v4l2-subdev.h", "V4L2_SUBDEV_IR_TX_NOTIFY", _IOC_WRITE, 0x7601, 0x04 },
@@ -2472,6 +2525,9 @@
 { "misc/ocxl.h", "OCXL_IOCTL_IRQ_ALLOC", _IOC_READ, 0xca11, 0x08 },
 { "misc/ocxl.h", "OCXL_IOCTL_IRQ_FREE", _IOC_WRITE, 0xca12, 0x08 },
 { "misc/ocxl.h", "OCXL_IOCTL_IRQ_SET_FD", _IOC_WRITE, 0xca13, 0x10 },
+{ "misc/uacce/hisi_qm.h", "UACCE_CMD_QM_SET_QP_CTX", _IOC_READ|_IOC_WRITE, 0x480a, 0x04 },
+{ "misc/uacce/uacce.h", "UACCE_CMD_PUT_Q", _IOC_NONE, 0x5701, 0x00 },
+{ "misc/uacce/uacce.h", "UACCE_CMD_START_Q", _IOC_NONE, 0x5700, 0x00 },
 { "misc/xilinx_sdfec.h", "XSDFEC_ADD_LDPC_CODE_PARAMS", _IOC_WRITE, 0x6605, 0x4c },
 { "misc/xilinx_sdfec.h", "XSDFEC_CLEAR_STATS", _IOC_NONE, 0x660b, 0x00 },
 { "misc/xilinx_sdfec.h", "XSDFEC_GET_CONFIG", _IOC_READ, 0x6606, 0x1c },
@@ -2724,7 +2780,8 @@
 { "sound/asound.h", "SNDRV_TIMER_IOCTL_START", _IOC_NONE, 0x54a0, 0x00 },
 { "sound/asound.h", "SNDRV_TIMER_IOCTL_STATUS", _IOC_READ, 0x5414, 0x60 },
 { "sound/asound.h", "SNDRV_TIMER_IOCTL_STOP", _IOC_NONE, 0x54a1, 0x00 },
-{ "sound/asound.h", "SNDRV_TIMER_IOCTL_TREAD", _IOC_WRITE, 0x5402, 0x04 },
+{ "sound/asound.h", "SNDRV_TIMER_IOCTL_TREAD64", _IOC_WRITE, 0x54a4, 0x04 },
+{ "sound/asound.h", "SNDRV_TIMER_IOCTL_TREAD_OLD", _IOC_WRITE, 0x5402, 0x04 },
 { "sound/asound_fm.h", "SNDRV_DM_FM_IOCTL_CLEAR_PATCHES", _IOC_NONE, 0x4840, 0x00 },
 { "sound/asound_fm.h", "SNDRV_DM_FM_IOCTL_INFO", _IOC_READ, 0x4820, 0x02 },
 { "sound/asound_fm.h", "SNDRV_DM_FM_IOCTL_PLAY_NOTE", _IOC_WRITE, 0x4822, 0x0c },
@@ -2782,6 +2839,10 @@
 { "sound/hdspm.h", "SNDRV_HDSPM_IOCTL_GET_PEAK_RMS", _IOC_READ, 0x4842, 0x908 },
 { "sound/hdspm.h", "SNDRV_HDSPM_IOCTL_GET_STATUS", _IOC_READ, 0x4847, 0x20 },
 { "sound/hdspm.h", "SNDRV_HDSPM_IOCTL_GET_VERSION", _IOC_READ, 0x4848, 0x24 },
+{ "sound/pcm.h", "SNDRV_PCM_IOCTL_STATUS32", _IOC_READ, 0x4120, 0x6c },
+{ "sound/pcm.h", "SNDRV_PCM_IOCTL_STATUS64", _IOC_READ, 0x4120, 0x80 },
+{ "sound/pcm.h", "SNDRV_PCM_IOCTL_STATUS_EXT32", _IOC_READ|_IOC_WRITE, 0x4124, 0x6c },
+{ "sound/pcm.h", "SNDRV_PCM_IOCTL_STATUS_EXT64", _IOC_READ|_IOC_WRITE, 0x4124, 0x80 },
 { "sound/sb16_csp.h", "SNDRV_SB_CSP_IOCTL_INFO", _IOC_READ, 0x4810, 0x28 },
 { "sound/sb16_csp.h", "SNDRV_SB_CSP_IOCTL_LOAD_CODE", _IOC_WRITE, 0x4811, 0x3012 },
 { "sound/sb16_csp.h", "SNDRV_SB_CSP_IOCTL_PAUSE", _IOC_NONE, 0x4815, 0x00 },
@@ -2808,15 +2869,6 @@
 { "staging/android/ashmem.h", "ASHMEM_UNPIN", _IOC_WRITE, 0x7708, 0x08 },
 { "staging/android/ion.h", "ION_IOC_ALLOC", _IOC_READ|_IOC_WRITE, 0x4900, 0x18 },
 { "staging/android/ion.h", "ION_IOC_HEAP_QUERY", _IOC_READ|_IOC_WRITE, 0x4908, 0x18 },
-{ "staging/android/vsoc_shm.h", "VSOC_COND_WAIT", _IOC_READ|_IOC_WRITE, 0xf507, 0x20 },
-{ "staging/android/vsoc_shm.h", "VSOC_COND_WAKE", _IOC_NONE, 0xf508, 0x00 },
-{ "staging/android/vsoc_shm.h", "VSOC_CREATE_FD_SCOPED_PERMISSION", _IOC_WRITE, 0xf500, 0x10 },
-{ "staging/android/vsoc_shm.h", "VSOC_DESCRIBE_REGION", _IOC_READ, 0xf504, 0x3c },
-{ "staging/android/vsoc_shm.h", "VSOC_GET_FD_SCOPED_PERMISSION", _IOC_READ, 0xf501, 0x10 },
-{ "staging/android/vsoc_shm.h", "VSOC_MAYBE_SEND_INTERRUPT_TO_HOST", _IOC_NONE, 0xf502, 0x00 },
-{ "staging/android/vsoc_shm.h", "VSOC_SELF_INTERRUPT", _IOC_NONE, 0xf505, 0x00 },
-{ "staging/android/vsoc_shm.h", "VSOC_SEND_INTERRUPT_TO_HOST", _IOC_NONE, 0xf506, 0x00 },
-{ "staging/android/vsoc_shm.h", "VSOC_WAIT_FOR_INCOMING_INTERRUPT", _IOC_NONE, 0xf503, 0x00 },
 { "video/da8xx-fb.h", "FBIGET_BRIGHTNESS", _IOC_READ, 0x4603, 0x04 },
 { "video/da8xx-fb.h", "FBIGET_COLOR", _IOC_READ, 0x4605, 0x04 },
 { "video/da8xx-fb.h", "FBIOGET_CONTRAST", _IOC_READ, 0x4601, 0x04 },
diff -pruN 5.5-3/linux/x32/syscallent.h 5.9-0ubuntu2/linux/x32/syscallent.h
--- 5.5-3/linux/x32/syscallent.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/linux/x32/syscallent.h	2020-08-01 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2019 The strace developers.
+ * Copyright (c) 2012-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -67,7 +67,7 @@
 [ 59] = { 3,	TF|TP|SE|SI,	SEN(printargs),			"execve#64"		},
 [ 60] = { 1,	TP|SE,		SEN(exit),			"exit"			},
 [ 61] = { 4,	TP,		SEN(wait4),			"wait4"			},
-[ 62] = { 2,	TS,		SEN(kill),			"kill"			},
+[ 62] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [ 63] = { 1,	0,		SEN(uname),			"uname"			},
 [ 64] = { 3,	TI,		SEN(semget),			"semget"		},
 [ 65] = { 3,	TI,		SEN(semop),			"semop"			},
@@ -101,7 +101,7 @@
 [ 93] = { 3,	TD,		SEN(fchown),			"fchown"		},
 [ 94] = { 3,	TF,		SEN(chown),			"lchown"		},
 [ 95] = { 1,	NF,		SEN(umask),			"umask"			},
-[ 96] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
+[ 96] = { 2,	TCL,		SEN(gettimeofday),		"gettimeofday"		},
 [ 97] = { 2,	0,		SEN(getrlimit),			"getrlimit"		},
 [ 98] = { 2,	0,		SEN(getrusage),			"getrusage"		},
 [ 99] = { 1,	0,		SEN(sysinfo),			"sysinfo"		},
@@ -134,7 +134,7 @@
 [126] = { 2,	TC,		SEN(capset),			"capset"		},
 [127] = { 2,	TS,		SEN(printargs),			"rt_sigpending#64"	},
 [128] = { 4,	TS,		SEN(printargs),			"rt_sigtimedwait#64"	},
-[129] = { 3,	TS,		SEN(printargs),			"rt_sigqueueinfo#64"	},
+[129] = { 3,	TS|TP,		SEN(printargs),			"rt_sigqueueinfo#64"	},
 [130] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [131] = { 2,	TS,		SEN(printargs),			"sigaltstack#64"	},
 [132] = { 2,	TF,		SEN(utime),			"utime"			},
@@ -163,13 +163,13 @@
 [155] = { 2,	TF,		SEN(pivotroot),			"pivot_root"		},
 [156] = { 1,	0,		SEN(printargs),			"_sysctl#64"		},
 [157] = { 5,	TC,		SEN(prctl),			"prctl"			},
-[158] = { 2,	TP,		SEN(arch_prctl),		"arch_prctl"		},
-[159] = { 1,	0,		SEN(adjtimex64),		"adjtimex"		},
+[158] = { 2,	0,		SEN(arch_prctl),		"arch_prctl"		},
+[159] = { 1,	TCL,		SEN(adjtimex64),		"adjtimex"		},
 [160] = { 2,	0,		SEN(setrlimit),			"setrlimit"		},
 [161] = { 1,	TF,		SEN(chroot),			"chroot"		},
 [162] = { 0,	0,		SEN(sync),			"sync"			},
 [163] = { 1,	TF,		SEN(acct),			"acct"			},
-[164] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
+[164] = { 2,	TCL,		SEN(settimeofday),		"settimeofday"		},
 [165] = { 5,	TF,		SEN(mount),			"mount"			},
 [166] = { 2,	TF,		SEN(umount2),			"umount2"		},
 [167] = { 2,	TF,		SEN(swapon),			"swapon"		},
@@ -205,8 +205,8 @@
 [197] = { 2,	TF,		SEN(removexattr),		"removexattr"		},
 [198] = { 2,	TF,		SEN(removexattr),		"lremovexattr"		},
 [199] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
-[200] = { 2,	TS,		SEN(kill),			"tkill"			},
-[201] = { 1,	0,		SEN(time),			"time"			},
+[200] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
+[201] = { 1,	TCL,		SEN(time),			"time"			},
 [202] = { 6,	0,		SEN(futex_time64),		"futex"			},
 [203] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
 [204] = { 3,	0,		SEN(sched_getaffinity),		"sched_getaffinity"	},
@@ -232,14 +232,14 @@
 [224] = { 2,	0,		SEN(timer_gettime64),		"timer_gettime"		},
 [225] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [226] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[227] = { 2,	0,		SEN(clock_settime64),		"clock_settime"		},
-[228] = { 2,	0,		SEN(clock_gettime64),		"clock_gettime"		},
-[229] = { 2,	0,		SEN(clock_getres_time64),	"clock_getres"		},
+[227] = { 2,	TCL,		SEN(clock_settime64),		"clock_settime"		},
+[228] = { 2,	TCL,		SEN(clock_gettime64),		"clock_gettime"		},
+[229] = { 2,	TCL,		SEN(clock_getres_time64),	"clock_getres"		},
 [230] = { 4,	0,		SEN(clock_nanosleep_time64),	"clock_nanosleep"	},
 [231] = { 1,	TP|SE,		SEN(exit),			"exit_group"		},
 [232] = { 4,	TD,		SEN(epoll_wait),		"epoll_wait"		},
 [233] = { 4,	TD,		SEN(epoll_ctl),			"epoll_ctl"		},
-[234] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[234] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [235] = { 2,	TF,		SEN(utimes),			"utimes"		},
 [236] = { 5,	0,		SEN(printargs),			"vserver#64"		},
 [237] = { 6,	TM,		SEN(mbind),			"mbind"			},
@@ -277,7 +277,7 @@
 [269] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [270] = { 6,	TD,		SEN(pselect6_time64),		"pselect6"		},
 [271] = { 5,	TD,		SEN(ppoll_time64),		"ppoll"			},
-[272] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[272] = { 1,	0,		SEN(unshare),			"unshare"		},
 [273] = { 2,	0,		SEN(printargs),			"set_robust_list#64"	},
 [274] = { 3,	0,		SEN(printargs),			"get_robust_list#64"	},
 [275] = { 6,	TD,		SEN(splice),			"splice"		},
@@ -310,7 +310,7 @@
 [302] = { 4,	0,		SEN(prlimit64),			"prlimit64"		},
 [303] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [304] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[305] = { 2,	0,		SEN(clock_adjtime64),		"clock_adjtime"		},
+[305] = { 2,	TCL,		SEN(clock_adjtime64),		"clock_adjtime"		},
 [306] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [307] = { 4,	TN,		SEN(printargs),			"sendmmsg#64"		},
 [308] = { 2,	TD,		SEN(setns),			"setns"			},
@@ -337,7 +337,7 @@
 [329] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [330] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
 [331] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
-[332] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[332] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [333] = { 6,	0,		SEN(io_pgetevents_time64),	"io_pgetevents"		},
 [334] = { 4,	0,		SEN(rseq),			"rseq"			},
 /* [335 ... 423] - reserved to sync up with other architectures */
@@ -358,7 +358,7 @@
 [521] = { 4,	CST,		SEN(ptrace),			"ptrace"		},
 [522] = { 2,	CST|TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [523] = { 4,	CST|TS,		SEN(rt_sigtimedwait_time64),	"rt_sigtimedwait"	},
-[524] = { 3,	CST|TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[524] = { 3,	CST|TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [525] = { 2,	CST|TS,		SEN(sigaltstack),		"sigaltstack"		},
 [526] = { 3,	CST,		SEN(timer_create),		"timer_create"		},
 [527] = { 2,	CST|TD,		SEN(mq_notify),			"mq_notify"		},
diff -pruN 5.5-3/linux/x86_64/arch_defs_.h 5.9-0ubuntu2/linux/x86_64/arch_defs_.h
--- 5.5-3/linux/x86_64/arch_defs_.h	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/linux/x86_64/arch_defs_.h	2020-04-15 13:39:57.000000000 +0000
@@ -13,3 +13,6 @@
 #define PERSONALITY0_AUDIT_ARCH { AUDIT_ARCH_X86_64, 0 }
 #define PERSONALITY1_AUDIT_ARCH { AUDIT_ARCH_I386,   0 }
 #define PERSONALITY2_AUDIT_ARCH { AUDIT_ARCH_X86_64, __X32_SYSCALL_BIT }
+#ifndef __X32_SYSCALL_BIT
+# define __X32_SYSCALL_BIT 0x40000000UL
+#endif
diff -pruN 5.5-3/linux/x86_64/arch_get_personality.c 5.9-0ubuntu2/linux/x86_64/arch_get_personality.c
--- 5.5-3/linux/x86_64/arch_get_personality.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/linux/x86_64/arch_get_personality.c	2020-04-15 13:39:57.000000000 +0000
@@ -21,10 +21,6 @@ get_personality_from_syscall_info(const
 
 	kernel_ulong_t scno = sci->entry.nr;
 
-# ifndef __X32_SYSCALL_BIT
-#  define __X32_SYSCALL_BIT	0x40000000
-# endif
-
 	if (pers == 0 && (scno & __X32_SYSCALL_BIT)) {
 		/*
 		 * Syscall number -1 requires special treatment:
diff -pruN 5.5-3/linux/x86_64/arch_kvm.c 5.9-0ubuntu2/linux/x86_64/arch_kvm.c
--- 5.5-3/linux/x86_64/arch_kvm.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/linux/x86_64/arch_kvm.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2018 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -104,14 +104,7 @@ arch_print_kvm_sregs(struct tcb *const t
 	PRINT_FIELD_U(", ", *sregs, cr8);
 	PRINT_FIELD_U(", ", *sregs, efer);
 	PRINT_FIELD_X(", ", *sregs, apic_base);
-	tprints(", interrupt_bitmap=[");
-
-	unsigned int i;
-	for (i = 0; i < ARRAY_SIZE(sregs->interrupt_bitmap); i++) {
-		if (i != 0)
-			tprints(", ");
-		tprintf("%#" PRI__x64, sregs->interrupt_bitmap[i]);
-	}
-	tprints("]}");
+	PRINT_FIELD_X_ARRAY(", ", *sregs, interrupt_bitmap);
+	tprints("}");
 }
 #endif	/* HAVE_STRUCT_KVM_SREGS */
diff -pruN 5.5-3/linux/x86_64/get_scno.c 5.9-0ubuntu2/linux/x86_64/get_scno.c
--- 5.5-3/linux/x86_64/get_scno.c	2018-12-30 15:35:21.000000000 +0000
+++ 5.9-0ubuntu2/linux/x86_64/get_scno.c	2020-06-01 14:15:16.000000000 +0000
@@ -5,7 +5,7 @@
  * Copyright (c) 2008-2013 Denys Vlasenko <vda.linux@googlemail.com>
  * Copyright (c) 2012 H.J. Lu <hongjiu.lu@intel.com>
  * Copyright (c) 2010-2015 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -18,10 +18,6 @@ arch_get_scno(struct tcb *tcp)
 	kernel_ulong_t scno = 0;
 	unsigned int currpers;
 
-#ifndef __X32_SYSCALL_BIT
-# define __X32_SYSCALL_BIT	0x40000000
-#endif
-
 	/*
 	 * GETREGSET of NT_PRSTATUS tells us regset size,
 	 * which unambiguously detects i386.
diff -pruN 5.5-3/linux/x86_64/syscallent.h 5.9-0ubuntu2/linux/x86_64/syscallent.h
--- 5.5-3/linux/x86_64/syscallent.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/linux/x86_64/syscallent.h	2020-08-01 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2002-2019 The strace developers.
+ * Copyright (c) 2002-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -67,7 +67,7 @@
 [ 59] = { 3,	TF|TP|TSD|SE|SI,	SEN(execve),			"execve"		},
 [ 60] = { 1,	TP|SE,		SEN(exit),			"exit"			},
 [ 61] = { 4,	TP,		SEN(wait4),			"wait4"			},
-[ 62] = { 2,	TS,		SEN(kill),			"kill"			},
+[ 62] = { 2,	TS|TP,		SEN(kill),			"kill"			},
 [ 63] = { 1,	0,		SEN(uname),			"uname"			},
 [ 64] = { 3,	TI,		SEN(semget),			"semget"		},
 [ 65] = { 3,	TI,		SEN(semop),			"semop"			},
@@ -101,7 +101,7 @@
 [ 93] = { 3,	TD,		SEN(fchown),			"fchown"		},
 [ 94] = { 3,	TF,		SEN(chown),			"lchown"		},
 [ 95] = { 1,	NF,		SEN(umask),			"umask"			},
-[ 96] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
+[ 96] = { 2,	TCL,		SEN(gettimeofday),		"gettimeofday"		},
 [ 97] = { 2,	0,		SEN(getrlimit),			"getrlimit"		},
 [ 98] = { 2,	0,		SEN(getrusage),			"getrusage"		},
 [ 99] = { 1,	0,		SEN(sysinfo),			"sysinfo"		},
@@ -134,7 +134,7 @@
 [126] = { 2,	TC,		SEN(capset),			"capset"		},
 [127] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [128] = { 4,	TS,		SEN(rt_sigtimedwait_time64),	"rt_sigtimedwait"	},
-[129] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[129] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [130] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [131] = { 2,	TS,		SEN(sigaltstack),		"sigaltstack"		},
 [132] = { 2,	TF,		SEN(utime),			"utime"			},
@@ -163,13 +163,13 @@
 [155] = { 2,	TF,		SEN(pivotroot),			"pivot_root"		},
 [156] = { 1,	0,		SEN(sysctl),			"_sysctl"		},
 [157] = { 5,	TC,		SEN(prctl),			"prctl"			},
-[158] = { 2,	TP,		SEN(arch_prctl),		"arch_prctl"		},
-[159] = { 1,	0,		SEN(adjtimex64),		"adjtimex"		},
+[158] = { 2,	0,		SEN(arch_prctl),		"arch_prctl"		},
+[159] = { 1,	TCL,		SEN(adjtimex64),		"adjtimex"		},
 [160] = { 2,	0,		SEN(setrlimit),			"setrlimit"		},
 [161] = { 1,	TF,		SEN(chroot),			"chroot"		},
 [162] = { 0,	0,		SEN(sync),			"sync"			},
 [163] = { 1,	TF,		SEN(acct),			"acct"			},
-[164] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
+[164] = { 2,	TCL,		SEN(settimeofday),		"settimeofday"		},
 [165] = { 5,	TF,		SEN(mount),			"mount"			},
 [166] = { 2,	TF,		SEN(umount2),			"umount2"		},
 [167] = { 2,	TF,		SEN(swapon),			"swapon"		},
@@ -205,8 +205,8 @@
 [197] = { 2,	TF,		SEN(removexattr),		"removexattr"		},
 [198] = { 2,	TF,		SEN(removexattr),		"lremovexattr"		},
 [199] = { 2,	TD,		SEN(fremovexattr),		"fremovexattr"		},
-[200] = { 2,	TS,		SEN(kill),			"tkill"			},
-[201] = { 1,	0,		SEN(time),			"time"			},
+[200] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
+[201] = { 1,	TCL,		SEN(time),			"time"			},
 [202] = { 6,	0,		SEN(futex_time64),		"futex"			},
 [203] = { 3,	0,		SEN(sched_setaffinity),		"sched_setaffinity"	},
 [204] = { 3,	0,		SEN(sched_getaffinity),		"sched_getaffinity"	},
@@ -232,14 +232,14 @@
 [224] = { 2,	0,		SEN(timer_gettime64),		"timer_gettime"		},
 [225] = { 1,	0,		SEN(timer_getoverrun),		"timer_getoverrun"	},
 [226] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
-[227] = { 2,	0,		SEN(clock_settime64),		"clock_settime"		},
-[228] = { 2,	0,		SEN(clock_gettime64),		"clock_gettime"		},
-[229] = { 2,	0,		SEN(clock_getres_time64),	"clock_getres"		},
+[227] = { 2,	TCL,		SEN(clock_settime64),		"clock_settime"		},
+[228] = { 2,	TCL,		SEN(clock_gettime64),		"clock_gettime"		},
+[229] = { 2,	TCL,		SEN(clock_getres_time64),	"clock_getres"		},
 [230] = { 4,	0,		SEN(clock_nanosleep_time64),	"clock_nanosleep"	},
 [231] = { 1,	TP|SE,		SEN(exit),			"exit_group"		},
 [232] = { 4,	TD,		SEN(epoll_wait),		"epoll_wait"		},
 [233] = { 4,	TD,		SEN(epoll_ctl),			"epoll_ctl"		},
-[234] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[234] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [235] = { 2,	TF,		SEN(utimes),			"utimes"		},
 [236] = { 5,	0,		SEN(vserver),			"vserver"		},
 [237] = { 6,	TM,		SEN(mbind),			"mbind"			},
@@ -277,7 +277,7 @@
 [269] = { 3,	TD|TF,		SEN(faccessat),			"faccessat"		},
 [270] = { 6,	TD,		SEN(pselect6_time64),		"pselect6"		},
 [271] = { 5,	TD,		SEN(ppoll_time64),		"ppoll"			},
-[272] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[272] = { 1,	0,		SEN(unshare),			"unshare"		},
 [273] = { 2,	0,		SEN(set_robust_list),		"set_robust_list"	},
 [274] = { 3,	0,		SEN(get_robust_list),		"get_robust_list"	},
 [275] = { 6,	TD,		SEN(splice),			"splice"		},
@@ -310,7 +310,7 @@
 [302] = { 4,	0,		SEN(prlimit64),			"prlimit64"		},
 [303] = { 5,	TD|TF,		SEN(name_to_handle_at),		"name_to_handle_at"	},
 [304] = { 3,	TD,		SEN(open_by_handle_at),		"open_by_handle_at"	},
-[305] = { 2,	0,		SEN(clock_adjtime64),		"clock_adjtime"		},
+[305] = { 2,	TCL,		SEN(clock_adjtime64),		"clock_adjtime"		},
 [306] = { 1,	TD,		SEN(syncfs),			"syncfs"		},
 [307] = { 4,	TN,		SEN(sendmmsg),			"sendmmsg"		},
 [308] = { 2,	TD,		SEN(setns),			"setns"			},
@@ -337,7 +337,7 @@
 [329] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [330] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
 [331] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
-[332] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[332] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [333] = { 6,	0,		SEN(io_pgetevents_time64),	"io_pgetevents"		},
 [334] = { 4,	0,		SEN(rseq),			"rseq"			},
 /* [335 ... 423] - reserved to sync up with other architectures */
diff -pruN 5.5-3/linux/xtensa/arch_regs.c 5.9-0ubuntu2/linux/xtensa/arch_regs.c
--- 5.5-3/linux/xtensa/arch_regs.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/linux/xtensa/arch_regs.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,10 +1,11 @@
 /*
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-static unsigned long xtensa_a2;
-#define ARCH_PC_PEEK_ADDR REG_PC
-#define ARCH_SP_PEEK_ADDR (REG_A_BASE + 1)
+static struct user_pt_regs xtensa_regs;
+#define ARCH_REGS_FOR_GETREGS xtensa_regs
+#define ARCH_PC_REG xtensa_regs.pc
+#define ARCH_SP_REG xtensa_regs.a[1]
diff -pruN 5.5-3/linux/xtensa/get_error.c 5.9-0ubuntu2/linux/xtensa/get_error.c
--- 5.5-3/linux/xtensa/get_error.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/linux/xtensa/get_error.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -10,10 +10,10 @@
 static void
 arch_get_error(struct tcb *tcp, const bool check_errno)
 {
-	if (check_errno && is_negated_errno(xtensa_a2)) {
+	if (check_errno && is_negated_errno(xtensa_regs.a[2])) {
 		tcp->u_rval = -1;
-		tcp->u_error = -xtensa_a2;
+		tcp->u_error = -xtensa_regs.a[2];
 	} else {
-		tcp->u_rval = xtensa_a2;
+		tcp->u_rval = xtensa_regs.a[2];
 	}
 }
diff -pruN 5.5-3/linux/xtensa/get_syscall_args.c 5.9-0ubuntu2/linux/xtensa/get_syscall_args.c
--- 5.5-3/linux/xtensa/get_syscall_args.c	2019-03-18 02:40:16.000000000 +0000
+++ 5.9-0ubuntu2/linux/xtensa/get_syscall_args.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -9,19 +9,9 @@
 static int
 arch_get_syscall_args(struct tcb *tcp)
 {
-	/* arg0: a6, arg1: a3, arg2: a4, arg3: a5, arg4: a8, arg5: a9 */
-	static const int xtensaregs[MAX_ARGS] = {
-		REG_A_BASE + 6,
-		REG_A_BASE + 3,
-		REG_A_BASE + 4,
-		REG_A_BASE + 5,
-		REG_A_BASE + 8,
-		REG_A_BASE + 9
-	};
-	unsigned int i;
+	static const unsigned int syscall_regs[MAX_ARGS] = { 6, 3, 4, 5, 8, 9 };
 
-	for (i = 0; i < n_args(tcp); ++i)
-		if (upeek(tcp, xtensaregs[i], &tcp->u_arg[i]) < 0)
-			return -1;
+	for (unsigned int i = 0; i < n_args(tcp); ++i)
+		tcp->u_arg[i] = xtensa_regs.a[syscall_regs[i]];
 	return 1;
 }
diff -pruN 5.5-3/linux/xtensa/get_syscall_result.c 5.9-0ubuntu2/linux/xtensa/get_syscall_result.c
--- 5.5-3/linux/xtensa/get_syscall_result.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/linux/xtensa/get_syscall_result.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-/*
- * Copyright (c) 2015-2018 The strace developers.
- * All rights reserved.
- *
- * SPDX-License-Identifier: LGPL-2.1-or-later
- */
-
-static int
-get_syscall_result_regs(struct tcb *tcp)
-{
-	return upeek(tcp, REG_A_BASE + 2, &xtensa_a2) < 0 ? -1 : 0;
-}
diff -pruN 5.5-3/linux/xtensa/set_error.c 5.9-0ubuntu2/linux/xtensa/set_error.c
--- 5.5-3/linux/xtensa/set_error.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/linux/xtensa/set_error.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -8,13 +8,13 @@
 static int
 arch_set_error(struct tcb *tcp)
 {
-	xtensa_a2 = -tcp->u_error;
-	return upoke(tcp, REG_A_BASE + 2, xtensa_a2);
+	xtensa_regs.a[2] = -tcp->u_error;
+	return set_regs(tcp->pid);
 }
 
 static int
 arch_set_success(struct tcb *tcp)
 {
-	xtensa_a2 = tcp->u_rval;
-	return upoke(tcp, REG_A_BASE + 2, xtensa_a2);
+	xtensa_regs.a[2] = tcp->u_rval;
+	return set_regs(tcp->pid);
 }
diff -pruN 5.5-3/linux/xtensa/syscallent.h 5.9-0ubuntu2/linux/xtensa/syscallent.h
--- 5.5-3/linux/xtensa/syscallent.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/linux/xtensa/syscallent.h	2020-08-01 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013-2019 The strace developers.
+ * Copyright (c) 2013-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -123,9 +123,9 @@
 [120] = { 0,	PU|NF,		SEN(getpid),			"getpid"		},
 [121] = { 4,	TP,		SEN(wait4),			"wait4"			},
 [122] = { 5,	TP,		SEN(waitid),			"waitid"		},
-[123] = { 2,	TS,		SEN(kill),			"kill"			},
-[124] = { 2,	TS,		SEN(kill),			"tkill"			},
-[125] = { 3,	TS,		SEN(tgkill),			"tgkill"		},
+[123] = { 2,	TS|TP,		SEN(kill),			"kill"			},
+[124] = { 2,	TS|TP,		SEN(tkill),			"tkill"			},
+[125] = { 3,	TS|TP,		SEN(tgkill),			"tgkill"		},
 [126] = { 1,	0,		SEN(set_tid_address),		"set_tid_address"	},
 [127] = { 0,	PU|NF,		SEN(gettid),			"gettid"		},
 [128] = { 0,	0,		SEN(setsid),			"setsid"		},
@@ -191,9 +191,9 @@
 [189] = { 2,	0,		SEN(getrlimit),			"getrlimit"		},
 [190] = { 2,	0,		SEN(getrusage),			"getrusage"		},
 [191] = { 6,	0,		SEN(futex_time32),		"futex"			},
-[192] = { 2,	0,		SEN(gettimeofday),		"gettimeofday"		},
-[193] = { 2,	0,		SEN(settimeofday),		"settimeofday"		},
-[194] = { 1,	0,		SEN(adjtimex32),		"adjtimex"		},
+[192] = { 2,	TCL,		SEN(gettimeofday),		"gettimeofday"		},
+[193] = { 2,	TCL,		SEN(settimeofday),		"settimeofday"		},
+[194] = { 1,	TCL,		SEN(adjtimex32),		"adjtimex"		},
 [195] = { 2,	0,		SEN(nanosleep_time32),		"nanosleep"		},
 [196] = { 2,	TC,		SEN(getgroups),			"getgroups"		},
 [197] = { 2,	TC,		SEN(setgroups),			"setgroups"		},
@@ -227,7 +227,7 @@
 [227] = { 4,	TS,		SEN(rt_sigprocmask),		"rt_sigprocmask"	},
 [228] = { 2,	TS,		SEN(rt_sigpending),		"rt_sigpending"		},
 [229] = { 4,	TS,		SEN(rt_sigtimedwait_time32),	"rt_sigtimedwait"	},
-[230] = { 3,	TS,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
+[230] = { 3,	TS|TP,		SEN(rt_sigqueueinfo),		"rt_sigqueueinfo"	},
 [231] = { 2,	TS,		SEN(rt_sigsuspend),		"rt_sigsuspend"		},
 [232] = { 4,	TD,		SEN(mq_open),			"mq_open"		},
 [233] = { 1,	0,		SEN(mq_unlink),			"mq_unlink"		},
@@ -241,9 +241,9 @@
 [241] = { 3,	0,		SEN(io_submit),			"io_submit"		},
 [242] = { 5,	0,		SEN(io_getevents_time32),	"io_getevents"		},
 [243] = { 3,	0,		SEN(io_cancel),			"io_cancel"		},
-[244] = { 2,	0,		SEN(clock_settime32),		"clock_settime"		},
-[245] = { 2,	0,		SEN(clock_gettime32),		"clock_gettime"		},
-[246] = { 2,	0,		SEN(clock_getres_time32),	"clock_getres"		},
+[244] = { 2,	TCL,		SEN(clock_settime32),		"clock_settime"		},
+[245] = { 2,	TCL,		SEN(clock_gettime32),		"clock_gettime"		},
+[246] = { 2,	TCL,		SEN(clock_getres_time32),	"clock_getres"		},
 [247] = { 4,	0,		SEN(clock_nanosleep_time32),	"clock_nanosleep"	},
 [248] = { 3,	0,		SEN(timer_create),		"timer_create"		},
 [249] = { 1,	0,		SEN(timer_delete),		"timer_delete"		},
@@ -263,7 +263,7 @@
 [263] = { 6,	TM,		SEN(mbind),			"mbind"			},
 [264] = { 5,	TM,		SEN(get_mempolicy),		"get_mempolicy"		},
 [265] = { 3,	TM,		SEN(set_mempolicy),		"set_mempolicy"		},
-[266] = { 1,	TP,		SEN(unshare),			"unshare"		},
+[266] = { 1,	0,		SEN(unshare),			"unshare"		},
 [267] = { 6,	TM,		SEN(move_pages),		"move_pages"		},
 [268] = { 6,	TD,		SEN(splice),			"splice"		},
 [269] = { 4,	TD,		SEN(tee),			"tee"			},
@@ -324,7 +324,7 @@
 [326] = { 6,	TD,		SEN(sync_file_range2),		"sync_file_range2"	},
 [327] = { 5,	TD,		SEN(perf_event_open),		"perf_event_open"	},
 [328] = { 4,	TP|TS,		SEN(rt_tgsigqueueinfo),		"rt_tgsigqueueinfo"	},
-[329] = { 2,	0,		SEN(clock_adjtime32),		"clock_adjtime"		},
+[329] = { 2,	TCL,		SEN(clock_adjtime32),		"clock_adjtime"		},
 [330] = { 4,	0,		SEN(prlimit64),			"prlimit64"		},
 [331] = { 5,	0,		SEN(kcmp),			"kcmp"			},
 [332] = { 3,	TD,		SEN(finit_module),		"finit_module"		},
@@ -346,7 +346,7 @@
 [348] = { 4,	TM|SI,		SEN(pkey_mprotect),		"pkey_mprotect"		},
 [349] = { 2,	0,		SEN(pkey_alloc),		"pkey_alloc"		},
 [350] = { 1,	0,		SEN(pkey_free),			"pkey_free"		},
-[351] = { 5,	TD|TF|TSTA,	SEN(statx),			"statx"			},
+[351] = { 5,	TD|TF|TFST|TSTA,SEN(statx),			"statx"			},
 [352] = { 4,	0,		SEN(rseq),			"rseq"			},
 /* [353 ... 402] - reserved to sync up with other architectures */
 #include "syscallent-common-32.h"
diff -pruN 5.5-3/list.h 5.9-0ubuntu2/list.h
--- 5.5-3/list.h	2019-03-18 02:40:16.000000000 +0000
+++ 5.9-0ubuntu2/list.h	2020-04-03 22:58:26.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Some simple implementation of lists similar to the one used in the kernel.
  *
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -33,7 +33,7 @@
  * to the next and the previous items in the list, respectively.  Note that
  * they do not perform additional checks for the validity of these pointers,
  * so they have to be guarded with respective list_head/list_tail checks in case
- * of lists with designated heads (where the list's head is not embedded withing
+ * of lists with designated heads (where the list's head is not embedded within
  * a list item.
  *
  * list_{insert,append,remove,remove_tail,remove_head,replace} provide some
diff -pruN 5.5-3/loop.c 5.9-0ubuntu2/loop.c
--- 5.5-3/loop.c	2018-12-30 15:35:21.000000000 +0000
+++ 5.9-0ubuntu2/loop.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,14 +1,13 @@
 /*
  * Copyright (c) 2012 The Chromium OS Authors.
- * Copyright (c) 2012-2018 The strace developers.
+ * Copyright (c) 2012-2020 The strace developers.
  * Written by Mike Frysinger <vapier@gentoo.org>.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #include "defs.h"
-#include <linux/ioctl.h>
-#include <linux/loop.h>
+#include "types/loop.h"
 
 typedef struct loop_info struct_loop_info;
 
@@ -34,30 +33,28 @@ decode_loop_info(struct tcb *const tcp,
 	if (umove_or_printaddr(tcp, addr, &info))
 		return;
 
-	tprintf("{lo_number=%d", info.lo_number);
+	PRINT_FIELD_D("{", info, lo_number);
 
 	if (!abbrev(tcp)) {
 		PRINT_FIELD_DEV(", ", info, lo_device);
-		tprintf(", lo_inode=%" PRI_klu, (kernel_ulong_t) info.lo_inode);
+		PRINT_FIELD_U(", ", info, lo_inode);
 		PRINT_FIELD_DEV(", ", info, lo_rdevice);
 	}
 
-	tprintf(", lo_offset=%#x", info.lo_offset);
+	PRINT_FIELD_X(", ", info, lo_offset);
 
 	if (!abbrev(tcp) || info.lo_encrypt_type != LO_CRYPT_NONE) {
-		tprints(", lo_encrypt_type=");
-		printxval(loop_crypt_type_options, info.lo_encrypt_type,
-			"LO_CRYPT_???");
+		PRINT_FIELD_XVAL(", ", info, lo_encrypt_type,
+				 loop_crypt_type_options, "LO_CRYPT_???");
 		/*
-		 * It is converted to unsigned before use in kernel, see
-		 * loop_info64_from_old in drivers/block/loop.c
+		 * It is converted to unsigned before use in the kernel,
+		 * see loop_info64_from_old in drivers/block/loop.c
 		 */
-		tprintf(", lo_encrypt_key_size=%" PRIu32,
-			(uint32_t) info.lo_encrypt_key_size);
+		PRINT_FIELD_U(", ", info, lo_encrypt_key_size);
 	}
 
-	tprints(", lo_flags=");
-	printflags(loop_flags_options, info.lo_flags, "LO_FLAGS_???");
+	PRINT_FIELD_FLAGS(", ", info, lo_flags,
+			  loop_flags_options, "LO_FLAGS_???");
 
 	PRINT_FIELD_CSTRING(", ", info, lo_name);
 
@@ -68,68 +65,88 @@ decode_loop_info(struct tcb *const tcp,
 					  lo_encrypt_key_size, 0);
 	}
 
-	if (!abbrev(tcp))
-		tprintf(", lo_init=[%#" PRI_klx ", %#" PRI_klx "]"
-			", reserved=[%#hhx, %#hhx, %#hhx, %#hhx]}",
-			(kernel_ulong_t) info.lo_init[0],
-			(kernel_ulong_t) info.lo_init[1],
-			info.reserved[0], info.reserved[1],
-			info.reserved[2], info.reserved[3]);
-	else
-		tprints(", ...}");
+	if (!abbrev(tcp)) {
+		PRINT_FIELD_X_ARRAY(", ", info, lo_init);
+		PRINT_FIELD_X_ARRAY(", ", info, reserved);
+	} else {
+		tprints(", ...");
+	}
+
+	tprints("}");
 }
 
 static void
-decode_loop_info64(struct tcb *const tcp, const kernel_ulong_t addr)
+print_loop_info64(struct tcb *const tcp, const struct loop_info64 *const info64)
 {
-	struct loop_info64 info64;
-
-	tprints(", ");
-	if (umove_or_printaddr(tcp, addr, &info64))
-		return;
-
 	if (!abbrev(tcp)) {
-		PRINT_FIELD_DEV("{", info64, lo_device);
-		tprintf(", lo_inode=%" PRIu64, (uint64_t) info64.lo_inode);
-		PRINT_FIELD_DEV(", ", info64, lo_rdevice);
-		tprintf(", lo_offset=%#" PRIx64 ", lo_sizelimit=%" PRIu64
-			", lo_number=%" PRIu32,
-			(uint64_t) info64.lo_offset,
-			(uint64_t) info64.lo_sizelimit,
-			(uint32_t) info64.lo_number);
+		PRINT_FIELD_DEV("{", *info64, lo_device);
+		PRINT_FIELD_U(", ", *info64, lo_inode);
+		PRINT_FIELD_DEV(", ", *info64, lo_rdevice);
+		PRINT_FIELD_X(", ", *info64, lo_offset);
+		PRINT_FIELD_U(", ", *info64, lo_sizelimit);
+		PRINT_FIELD_U(", ", *info64, lo_number);
 	} else {
-		tprintf("{lo_offset=%#" PRIx64 ", lo_number=%" PRIu32,
-			(uint64_t) info64.lo_offset,
-			(uint32_t) info64.lo_number);
+		PRINT_FIELD_X("{", *info64, lo_offset);
+		PRINT_FIELD_U(", ", *info64, lo_number);
 	}
 
-	if (!abbrev(tcp) || info64.lo_encrypt_type != LO_CRYPT_NONE) {
-		tprints(", lo_encrypt_type=");
-		printxval(loop_crypt_type_options, info64.lo_encrypt_type,
-			"LO_CRYPT_???");
-		tprintf(", lo_encrypt_key_size=%" PRIu32,
-			info64.lo_encrypt_key_size);
+	if (!abbrev(tcp) || info64->lo_encrypt_type != LO_CRYPT_NONE) {
+		PRINT_FIELD_XVAL(", ", *info64, lo_encrypt_type,
+				 loop_crypt_type_options, "LO_CRYPT_???");
+		PRINT_FIELD_U(", ", *info64, lo_encrypt_key_size);
 	}
 
-	tprints(", lo_flags=");
-	printflags(loop_flags_options, info64.lo_flags, "LO_FLAGS_???");
+	PRINT_FIELD_FLAGS(", ", *info64, lo_flags,
+			  loop_flags_options, "LO_FLAGS_???");
 
-	PRINT_FIELD_CSTRING(", ", info64, lo_file_name);
+	PRINT_FIELD_CSTRING(", ", *info64, lo_file_name);
 
-	if (!abbrev(tcp) || info64.lo_encrypt_type != LO_CRYPT_NONE) {
-		PRINT_FIELD_CSTRING(", ", info64, lo_crypt_name);
+	if (!abbrev(tcp) || info64->lo_encrypt_type != LO_CRYPT_NONE) {
+		PRINT_FIELD_CSTRING(", ", *info64, lo_crypt_name);
 		const unsigned int lo_encrypt_key_size =
-			MIN((unsigned) info64.lo_encrypt_key_size, LO_KEY_SIZE);
-		PRINT_FIELD_STRING(", ", info64, lo_encrypt_key,
+			MIN((unsigned) info64->lo_encrypt_key_size, LO_KEY_SIZE);
+		PRINT_FIELD_STRING(", ", *info64, lo_encrypt_key,
 					  lo_encrypt_key_size, 0);
 	}
 
 	if (!abbrev(tcp))
-		tprintf(", lo_init=[%#" PRIx64 ", %#" PRIx64 "]}",
-			(uint64_t) info64.lo_init[0],
-			(uint64_t) info64.lo_init[1]);
+		PRINT_FIELD_X_ARRAY(", ", *info64, lo_init);
 	else
-		tprints(", ...}");
+		tprints(", ...");
+
+	tprints("}");
+}
+
+static void
+decode_loop_info64(struct tcb *const tcp, const kernel_ulong_t addr)
+{
+	struct loop_info64 info64;
+
+	tprints(", ");
+	if (!umove_or_printaddr(tcp, addr, &info64))
+		print_loop_info64(tcp, &info64);
+}
+
+static void
+decode_loop_config(struct tcb *const tcp, const kernel_ulong_t addr)
+{
+	struct_loop_config config;
+
+	tprints(", ");
+	if (umove_or_printaddr(tcp, addr, &config))
+		return;
+
+	PRINT_FIELD_FD("{", config, fd, tcp);
+
+	PRINT_FIELD_U(", ", config, block_size);
+
+	tprints(", info=");
+	print_loop_info64(tcp, &config.info);
+
+	if (!IS_ARRAY_ZERO(config.__reserved))
+		PRINT_FIELD_X_ARRAY(", ", config, __reserved);
+
+	tprints("}");
 }
 
 MPERS_PRINTER_DECL(int, loop_ioctl,
@@ -153,6 +170,10 @@ MPERS_PRINTER_DECL(int, loop_ioctl,
 		decode_loop_info64(tcp, arg);
 		break;
 
+	case LOOP_CONFIGURE:
+		decode_loop_config(tcp, arg);
+		break;
+
 	case LOOP_CLR_FD:
 	case LOOP_SET_CAPACITY:
 	/* newer loop-control stuff */
diff -pruN 5.5-3/m4/ax_prog_cc_for_build.m4 5.9-0ubuntu2/m4/ax_prog_cc_for_build.m4
--- 5.5-3/m4/ax_prog_cc_for_build.m4	2019-11-28 19:30:05.000000000 +0000
+++ 5.9-0ubuntu2/m4/ax_prog_cc_for_build.m4	2020-04-03 22:58:26.000000000 +0000
@@ -26,7 +26,7 @@
 # LICENSE
 #
 #   Copyright (c) 2008 Paolo Bonzini <bonzini@gnu.org>
-#   Copyright (c) 2008-2019 The strace developers.
+#   Copyright (c) 2008-2020 The strace developers.
 #
 #   Copying and distribution of this file, with or without modification, are
 #   permitted in any medium without royalty provided the copyright notice
@@ -77,6 +77,8 @@ pushdef([ac_cv_host_os], ac_cv_build_os)
 pushdef([am_cv_prog_cc_c_o], am_cv_build_prog_cc_c_o)dnl
 pushdef([am_cv_CC_dependencies_compiler_type], am_cv_build_CC_dependencies_compiler_type)dnl
 pushdef([gl_unknown_warnings_are_errors], gl_build_unknown_warnings_are_errors)dnl
+pushdef([st_cv_enable_Werror], st_cv_build_enable_Werror)dnl
+pushdef([st_cv_cc_enable_Werror], st_cv_build_cc_enable_Werror)dnl
 
 st_SAVE_VAR([ac_c_decl_warn_flag])
 st_SAVE_VAR([ac_c_preproc_warn_flag])
@@ -112,6 +114,8 @@ st_RESTORE_VAR([ac_c_decl_warn_flag])
 
 dnl Restore the old definitions
 dnl
+popdef([st_cv_cc_enable_Werror])dnl
+popdef([st_cv_enable_Werror])dnl
 popdef([gl_unknown_warnings_are_errors])dnl
 popdef([am_cv_CC_dependencies_compiler_type])dnl
 popdef([am_cv_prog_cc_c_o])dnl
diff -pruN 5.5-3/m4/bpf_attr.m4 5.9-0ubuntu2/m4/bpf_attr.m4
--- 5.5-3/m4/bpf_attr.m4	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/m4/bpf_attr.m4	2020-09-24 09:18:43.000000000 +0000
@@ -4,6 +4,7 @@ AC_DEFUN([st_BPF_ATTR], [dnl
 		struct bpf_map_info.btf_id,
 		struct bpf_map_info.btf_key_type_id,
 		struct bpf_map_info.btf_value_type_id,
+		struct bpf_map_info.btf_vmlinux_value_type_id,
 		struct bpf_map_info.id,
 		struct bpf_map_info.ifindex,
 		struct bpf_map_info.key_size,
@@ -48,6 +49,14 @@ AC_DEFUN([st_BPF_ATTR], [dnl
 		union bpf_attr.attach_flags,
 		union bpf_attr.attach_prog_fd,
 		union bpf_attr.attach_type,
+		union bpf_attr.batch.count,
+		union bpf_attr.batch.elem_flags,
+		union bpf_attr.batch.flags,
+		union bpf_attr.batch.in_batch,
+		union bpf_attr.batch.keys,
+		union bpf_attr.batch.map_fd,
+		union bpf_attr.batch.out_batch,
+		union bpf_attr.batch.values,
 		union bpf_attr.bpf_fd,
 		union bpf_attr.btf,
 		union bpf_attr.btf_fd,
@@ -58,6 +67,7 @@ AC_DEFUN([st_BPF_ATTR], [dnl
 		union bpf_attr.btf_log_size,
 		union bpf_attr.btf_size,
 		union bpf_attr.btf_value_type_id,
+		union bpf_attr.btf_vmlinux_value_type_id,
 		union bpf_attr.dummy,
 		union bpf_attr.expected_attach_type,
 		union bpf_attr.file_flags,
@@ -78,6 +88,14 @@ AC_DEFUN([st_BPF_ATTR], [dnl
 		union bpf_attr.line_info,
 		union bpf_attr.line_info_cnt,
 		union bpf_attr.line_info_rec_size,
+		union bpf_attr.link_create.attach_type,
+		union bpf_attr.link_create.flags,
+		union bpf_attr.link_create.prog_fd,
+		union bpf_attr.link_create.target_fd,
+		union bpf_attr.link_update.flags,
+		union bpf_attr.link_update.link_fd,
+		union bpf_attr.link_update.new_prog_fd,
+		union bpf_attr.link_update.old_prog_fd,
 		union bpf_attr.log_buf,
 		union bpf_attr.log_level,
 		union bpf_attr.log_size,
@@ -107,6 +125,7 @@ AC_DEFUN([st_BPF_ATTR], [dnl
 		union bpf_attr.query.target_fd,
 		union bpf_attr.raw_tracepoint.name,
 		union bpf_attr.raw_tracepoint.prog_fd,
+		union bpf_attr.replace_bpf_fd,
 		union bpf_attr.start_id,
 		union bpf_attr.target_fd,
 		union bpf_attr.task_fd_query.buf,
diff -pruN 5.5-3/m4/st_warn_cflags.m4 5.9-0ubuntu2/m4/st_warn_cflags.m4
--- 5.5-3/m4/st_warn_cflags.m4	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/m4/st_warn_cflags.m4	2020-04-03 22:58:26.000000000 +0000
@@ -1,11 +1,38 @@
 #!/usr/bin/m4
 #
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: LGPL-2.1-or-later
 
 AC_DEFUN([st_WARN_CFLAGS], [dnl
+AC_CACHE_CHECK([whether $[]_AC_CC[] is fresh enough for -Werror],
+	       [st_cv_cc_enable_Werror],
+               [AC_COMPILE_IFELSE([AC_LANG_PROGRAM([[
+#if defined __GNUC__ && defined __GNUC_MINOR__
+# define GNUC_PREREQ(maj, min) ((__GNUC__ << 16) + __GNUC_MINOR__ >= ((maj) << 16) + (min))
+#else
+# define GNUC_PREREQ(maj, min) 0
+#endif
+
+#if defined __clang__ && defined __clang_major__ && defined __clang_minor__
+# define CLANG_PREREQ(maj, min) ((__clang_major__ << 16) + __clang_minor__ >= ((maj) << 16) + (min))
+#else
+# define CLANG_PREREQ(maj, min) 0
+#endif
+]],
+			       [[int i[GNUC_PREREQ(4, 8) + CLANG_PREREQ(6, 0) > 0 ? 1 : - 1];]])],
+			       [st_cv_cc_enable_Werror=yes],
+			       [st_cv_cc_enable_Werror=no])])
+AC_CACHE_CHECK([whether to try $[]_AC_CC[] with -Werror by default],
+	       [st_cv_enable_Werror],
+	       [if test "$st_cv_cc_enable_Werror" != yes; then
+		  st_cv_enable_Werror='no, the compiler is too old'
+		elif test "$arch_enable_Werror" != yes; then
+		  st_cv_enable_Werror='no, architecture is not ready'
+		else
+		  st_cv_enable_Werror=yes
+		fi])
 gl_WARN_ADD([-Wall])
 gl_WARN_ADD([-Wempty-body])
 gl_WARN_ADD([-Wformat-security])
@@ -23,12 +50,15 @@ gl_WARN_ADD([-Wsign-compare])
 gl_WARN_ADD([-Wtype-limits])
 gl_WARN_ADD([-Wwrite-strings])
 AC_ARG_ENABLE([gcc-Werror],
-  [AS_HELP_STRING([--enable-gcc-Werror], [turn on gcc's -Werror option])],
-  [case $enableval in
-     yes) gl_WARN_ADD([-Werror]) ;;
-     no)  ;;
-     *)   AC_MSG_ERROR([bad value $enableval for gcc-Werror option]) ;;
-   esac]
-)
+	      [AS_HELP_STRING([--enable-gcc-Werror],
+			      [turn on gcc's -Werror option])],
+	      [case "$enable_gcc_Werror" in
+		yes|no|no,*) ;;
+		*) AC_MSG_ERROR([bad value $enable_gcc_Werror for gcc-Werror option]) ;;
+	       esac],
+	      [enable_gcc_Werror="$st_cv_enable_Werror"])
+if test "$enable_gcc_Werror" = yes; then
+  gl_WARN_ADD([-Werror])
+fi
 AC_SUBST([WARN_CFLAGS])
 ])
diff -pruN 5.5-3/Makefile.am 5.9-0ubuntu2/Makefile.am
--- 5.5-3/Makefile.am	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/Makefile.am	2020-09-23 16:28:11.000000000 +0000
@@ -27,7 +27,7 @@ ARCH		= @arch@
 
 READELF		= @READELF@
 
-ACLOCAL_AMFLAGS = -I m4 -I types
+ACLOCAL_AMFLAGS = -I m4 -I types -I xlat
 AM_CFLAGS = $(WARN_CFLAGS)
 AM_CPPFLAGS = -I$(builddir)/$(OS)/$(ARCH) \
 	      -I$(srcdir)/$(OS)/$(ARCH) \
@@ -46,29 +46,12 @@ strace_CPPFLAGS = $(AM_CPPFLAGS)
 strace_CFLAGS = $(AM_CFLAGS)
 strace_LDFLAGS =
 strace_LDADD = libstrace.a $(clock_LIBS) $(timer_LIBS)
-noinst_LIBRARIES = libstrace.a
+strace_SOURCES = strace.c
 
+noinst_LIBRARIES = libstrace.a
 libstrace_a_CPPFLAGS = $(strace_CPPFLAGS)
 libstrace_a_CFLAGS = $(strace_CFLAGS)
 libstrace_a_SOURCES =	\
-	fetch_indirect_syscall_args.c \
-	fstatfs.c \
-	fstatfs64.c \
-	getpagesize.c \
-	ipc.c \
-	mmap_cache.c	\
-	mmap_cache.h	\
-	sigreturn.c	\
-	socketcall.c \
-	statfs.c \
-	statfs64.c \
-	sync_file_range.c \
-	sync_file_range2.c \
-	upeek.c		\
-	upoke.c		\
-	# end of libstrace_a_SOURCES
-
-strace_SOURCES =	\
 	access.c	\
 	affinity.c	\
 	aio.c		\
@@ -93,6 +76,7 @@ strace_SOURCES =	\
 	chdir.c		\
 	chmod.c		\
 	clone.c		\
+	close_range.c	\
 	copy_file_range.c \
 	count.c		\
 	defs.h		\
@@ -101,7 +85,9 @@ strace_SOURCES =	\
 	desc.c		\
 	dirent.c	\
 	dirent64.c	\
+	dirent_types.c	\
 	dm.c		\
+	dup.c		\
 	dyxlat.c	\
 	empty.h		\
 	epoll.c		\
@@ -118,6 +104,7 @@ strace_SOURCES =	\
 	fchownat.c	\
 	fcntl.c		\
 	fetch_bpf_fprog.c \
+	fetch_indirect_syscall_args.c \
 	fetch_struct_flock.c \
 	fetch_struct_keyctl_kdf_params.c \
 	fetch_struct_mmsghdr.c \
@@ -139,6 +126,8 @@ strace_SOURCES =	\
 	fsmount.c	\
 	fsopen.c	\
 	fspick.c	\
+	fstatfs.c \
+	fstatfs64.c \
 	futex.c		\
 	gcc_compat.h	\
 	get_personality.c \
@@ -146,6 +135,8 @@ strace_SOURCES =	\
 	get_robust_list.c \
 	getcpu.c	\
 	getcwd.c	\
+	getpagesize.c \
+	getpid.c	\
 	getrandom.c	\
 	hdio.c		\
 	hostname.c	\
@@ -157,17 +148,22 @@ strace_SOURCES =	\
 	ioperm.c	\
 	iopl.c		\
 	ioprio.c	\
+	ipc.c \
 	ipc_defs.h	\
 	ipc_msg.c	\
 	ipc_msgctl.c	\
 	ipc_sem.c	\
+	ipc_semctl.c	\
 	ipc_shm.c	\
 	ipc_shmctl.c	\
 	kcmp.c		\
+	kernel_dirent.h	\
+	kernel_rusage.h	\
 	kernel_timespec.h \
 	kernel_timeval.h \
 	kernel_timex.h	\
 	kernel_types.h	\
+	kernel_v4l2_types.h \
 	kexec.c		\
 	keyctl.c	\
 	keyctl_kdf_params.h \
@@ -189,6 +185,8 @@ strace_SOURCES =	\
 	membarrier.c	\
 	memfd_create.c	\
 	mknod.c		\
+	mmap_cache.c	\
+	mmap_cache.h	\
 	mmap_notify.c	\
 	mmap_notify.h	\
 	mmsghdr.c	\
@@ -236,7 +234,9 @@ strace_SOURCES =	\
 	perf_event_struct.h \
 	perf_ioctl.c	\
 	personality.c	\
+	pidfd_getfd.c	\
 	pidfd_open.c	\
+	pidns.c		\
 	pkeys.c		\
 	poll.c		\
 	prctl.c		\
@@ -254,8 +254,8 @@ strace_SOURCES =	\
 	print_sigevent.c \
 	print_statfs.c	\
 	print_struct_stat.c \
+	print_syscall_number.c \
 	print_time.c	\
-	print_timespec.c \
 	print_timespec.h \
 	print_timespec32.c \
 	print_timespec64.c \
@@ -314,8 +314,10 @@ strace_SOURCES =	\
 	sigevent.h	\
 	signal.c	\
 	signalfd.c	\
+	sigreturn.c	\
 	sock.c		\
 	sockaddr.c	\
+	socketcall.c \
 	socketutils.c	\
 	sparc.c		\
 	sram_alloc.c	\
@@ -324,14 +326,17 @@ strace_SOURCES =	\
 	stat.h		\
 	stat64.c	\
 	statfs.c	\
+	statfs.c \
 	statfs.h	\
+	statfs64.c \
 	static_assert.h	\
 	statx.c		\
 	statx.h		\
-	strace.c	\
 	string_to_uint.c \
 	string_to_uint.h \
 	swapon.c	\
+	sync_file_range.c \
+	sync_file_range2.c \
 	syscall.c	\
 	sysctl.c	\
 	sysent.h	\
@@ -340,10 +345,13 @@ strace_SOURCES =	\
 	sysinfo.c	\
 	syslog.c	\
 	sysmips.c	\
+	tee.c		\
 	term.c		\
 	time.c		\
 	times.c		\
 	trace_event.h	\
+	trie.c 		\
+	trie.h 		\
 	truncate.c	\
 	ubi.c		\
 	ucopy.c		\
@@ -352,6 +360,8 @@ strace_SOURCES =	\
 	umask.c		\
 	umount.c	\
 	uname.c		\
+	upeek.c		\
+	upoke.c		\
 	userfaultfd.c	\
 	ustat.c		\
 	util.c		\
@@ -363,6 +373,8 @@ strace_SOURCES =	\
 	watchdog_ioctl.c \
 	xattr.c		\
 	xfs_quota_stat.h \
+	xgetdents.c	\
+	xgetdents.h	\
 	xlat.c		\
 	xlat.h		\
 	xmalloc.c	\
@@ -370,21 +382,21 @@ strace_SOURCES =	\
 	xstring.h	\
 	$(TYPES_HEADER_FILES) \
 	$(strace_SOURCES_check) \
-	# end of strace_SOURCES
+	# end of libstrace_a_SOURCES
 
 strace_SOURCES_check = bpf_attr_check.c $(TYPES_CHECK_FILES)
 
 if ENABLE_STACKTRACE
-strace_SOURCES += unwind.c unwind.h
+libstrace_a_SOURCES += unwind.c unwind.h
 if USE_LIBDW
-strace_SOURCES += unwind-libdw.c
+libstrace_a_SOURCES += unwind-libdw.c
 strace_CPPFLAGS += $(libdw_CPPFLAGS)
 strace_CFLAGS += $(libdw_CFLAGS)
 strace_LDFLAGS += $(libdw_LDFLAGS)
 strace_LDADD += $(libdw_LIBS)
 endif
 if USE_LIBUNWIND
-strace_SOURCES += unwind-libunwind.c
+libstrace_a_SOURCES += unwind-libunwind.c
 strace_CPPFLAGS += $(libunwind_CPPFLAGS)
 strace_LDFLAGS += $(libunwind_LDFLAGS)
 strace_LDADD += $(libunwind_LIBS)
@@ -400,7 +412,7 @@ endif
 CODE_COVERAGE_BRANCH_COVERAGE = 1
 CODE_COVERAGE_GENHTML_OPTIONS = $(CODE_COVERAGE_GENHTML_OPTIONS_DEFAULT) \
 	--prefix $(shell cd $(abs_top_srcdir)/.. && pwd || echo .)
-CODE_COVERAGE_IGNORE_PATTERN = '/usr/include/*'
+CODE_COVERAGE_IGNORE_PATTERN = '/usr/include/*' '*/tests/*' '*/tests-m32/*' '*/tests-mx32/*'
 strace_CPPFLAGS += $(CODE_COVERAGE_CPPFLAGS)
 strace_CFLAGS += $(CODE_COVERAGE_CFLAGS)
 strace_LDADD += $(CODE_COVERAGE_LIBS)
@@ -443,6 +455,7 @@ EXTRA_DIST =				\
 	linux/32/ioctls_inc_align16.h	\
 	linux/32/ioctls_inc_align32.h	\
 	linux/32/ioctls_inc_align64.h	\
+	linux/32/syscallent-time32.h	\
 	linux/32/syscallent.h		\
 	linux/64/ioctls_inc.h		\
 	linux/64/syscallent.h		\
@@ -557,7 +570,6 @@ EXTRA_DIST =				\
 	linux/hppa/get_error.c		\
 	linux/hppa/get_scno.c		\
 	linux/hppa/get_syscall_args.c	\
-	linux/hppa/get_syscall_result.c	\
 	linux/hppa/ioctls_arch0.h	\
 	linux/hppa/ioctls_inc0.h	\
 	linux/hppa/raw_syscall.h	\
@@ -799,7 +811,6 @@ EXTRA_DIST =				\
 	linux/sh/get_error.c		\
 	linux/sh/get_scno.c		\
 	linux/sh/get_syscall_args.c	\
-	linux/sh/get_syscall_result.c	\
 	linux/sh/ioctls_arch0.h		\
 	linux/sh/ioctls_inc0.h		\
 	linux/sh/raw_syscall.h		\
@@ -810,11 +821,9 @@ EXTRA_DIST =				\
 	linux/sh/userent0.h		\
 	linux/sh64/arch_defs_.h		\
 	linux/sh64/arch_regs.c		\
-	linux/sh64/arch_regs.h		\
 	linux/sh64/get_error.c		\
 	linux/sh64/get_scno.c		\
 	linux/sh64/get_syscall_args.c	\
-	linux/sh64/get_syscall_result.c	\
 	linux/sh64/ioctls_arch0.h	\
 	linux/sh64/ioctls_inc0.h	\
 	linux/sh64/raw_syscall.h	\
@@ -950,7 +959,6 @@ EXTRA_DIST =				\
 	linux/xtensa/get_error.c	\
 	linux/xtensa/get_scno.c		\
 	linux/xtensa/get_syscall_args.c	\
-	linux/xtensa/get_syscall_result.c	\
 	linux/xtensa/ioctls_arch0.h	\
 	linux/xtensa/ioctls_inc0.h	\
 	linux/xtensa/raw_syscall.h	\
diff -pruN 5.5-3/Makefile.in 5.9-0ubuntu2/Makefile.in
--- 5.5-3/Makefile.in	2020-02-06 16:23:35.000000000 +0000
+++ 5.9-0ubuntu2/Makefile.in	2020-09-24 09:19:00.000000000 +0000
@@ -1,7 +1,7 @@
-# Makefile.in generated by automake 1.16.1 from Makefile.am.
+# Makefile.in generated by automake 1.16.2 from Makefile.am.
 # @configure_input@
 
-# Copyright (C) 1994-2018 Free Software Foundation, Inc.
+# Copyright (C) 1994-2020 Free Software Foundation, Inc.
 
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -132,13 +132,47 @@ bin_PROGRAMS = strace$(EXEEXT)
 @HAVE_MX32_MPERS_TRUE@am__append_21 = $(mpers_mx32_targets)
 subdir = .
 ACLOCAL_M4 = $(top_srcdir)/aclocal.m4
-am__aclocal_m4_deps = $(top_srcdir)/types/check-cryptouser.m4 \
+am__aclocal_m4_deps = $(top_srcdir)/xlat/btrfs_compress_types.m4 \
+	$(top_srcdir)/xlat/close_range_flags.m4 \
+	$(top_srcdir)/xlat/loop_flags_options.m4 \
+	$(top_srcdir)/xlat/rtnl_ifla_xdp_attached_mode.m4 \
+	$(top_srcdir)/xlat/rtnl_ifla_xdp_attrs.m4 \
+	$(top_srcdir)/xlat/rtnl_link_attrs.m4 \
+	$(top_srcdir)/xlat/rtnl_tc_action_attrs.m4 \
+	$(top_srcdir)/xlat/rtnl_tca_stab_attrs.m4 \
+	$(top_srcdir)/xlat/rtnl_tca_stats_attrs.m4 \
+	$(top_srcdir)/xlat/st_check_enums.m4 \
+	$(top_srcdir)/xlat/sysctl_kern.m4 \
+	$(top_srcdir)/xlat/sysctl_net.m4 \
+	$(top_srcdir)/xlat/sysctl_net_core.m4 \
+	$(top_srcdir)/xlat/sysctl_net_ipv4.m4 \
+	$(top_srcdir)/xlat/sysctl_net_ipv4_conf.m4 \
+	$(top_srcdir)/xlat/sysctl_net_ipv4_route.m4 \
+	$(top_srcdir)/xlat/sysctl_net_ipv6.m4 \
+	$(top_srcdir)/xlat/sysctl_net_ipv6_route.m4 \
+	$(top_srcdir)/xlat/sysctl_net_unix.m4 \
+	$(top_srcdir)/xlat/sysctl_root.m4 \
+	$(top_srcdir)/xlat/sysctl_vm.m4 \
+	$(top_srcdir)/xlat/v4l2_buf_types.m4 \
+	$(top_srcdir)/xlat/v4l2_colorspaces.m4 \
+	$(top_srcdir)/xlat/v4l2_control_types.m4 \
+	$(top_srcdir)/xlat/v4l2_fields.m4 \
+	$(top_srcdir)/xlat/v4l2_framesize_types.m4 \
+	$(top_srcdir)/xlat/v4l2_memories.m4 \
+	$(top_srcdir)/xlat/v4l2_tuner_types.m4 \
+	$(top_srcdir)/xlat/waitid_types.m4 \
+	$(top_srcdir)/types/check-btrfs.m4 \
+	$(top_srcdir)/types/check-cryptouser.m4 \
 	$(top_srcdir)/types/check-evdev.m4 \
 	$(top_srcdir)/types/check-io_uring.m4 \
+	$(top_srcdir)/types/check-loop.m4 \
+	$(top_srcdir)/types/check-openat2.m4 \
 	$(top_srcdir)/types/check-rtnl_link.m4 \
 	$(top_srcdir)/types/check-rtnl_mdb.m4 \
 	$(top_srcdir)/types/check-rtnl_neightbl.m4 \
 	$(top_srcdir)/types/check-rtnl_route.m4 \
+	$(top_srcdir)/types/check-tee.m4 \
+	$(top_srcdir)/types/check-v4l2.m4 \
 	$(top_srcdir)/types/st_check_types.m4 \
 	$(top_srcdir)/m4/ax_code_coverage.m4 \
 	$(top_srcdir)/m4/ax_prog_cc_for_build.m4 \
@@ -166,7 +200,6 @@ am__installdirs = "$(DESTDIR)$(bindir)"
 	"$(DESTDIR)$(man1dir)"
 PROGRAMS = $(bin_PROGRAMS)
 LIBRARIES = $(noinst_LIBRARIES)
-AR = ar
 ARFLAGS = cru
 AM_V_AR = $(am__v_AR_@AM_V@)
 am__v_AR_ = $(am__v_AR_@AM_DEFAULT_V@)
@@ -179,12 +212,13 @@ am__libmpers_m32_a_SOURCES_DIST = block.
 	fetch_struct_keyctl_kdf_params.c fetch_struct_mmsghdr.c \
 	fetch_struct_msghdr.c fetch_struct_stat.c \
 	fetch_struct_stat64.c fetch_struct_statfs.c \
-	fetch_struct_xfs_quotastat.c hdio.c ipc_msgctl.c ipc_shmctl.c \
-	loop.c mtd.c perf_ioctl.c print_aio_sigset.c print_group_req.c \
-	print_mq_attr.c print_msgbuf.c print_sg_req_info.c \
-	print_sigevent.c print_time.c print_timespec.c print_timeval.c \
-	printrusage.c printsiginfo.c rt_sigreturn.c rtc.c sg_io_v3.c \
-	sigaltstack.c sock.c sysinfo.c times.c ustat.c utime.c v4l2.c
+	fetch_struct_xfs_quotastat.c hdio.c ipc_msgctl.c ipc_semctl.c \
+	ipc_shmctl.c loop.c mtd.c perf_ioctl.c print_aio_sigset.c \
+	print_group_req.c print_mq_attr.c print_msgbuf.c \
+	print_sg_req_info.c print_sigevent.c print_time.c \
+	print_timeval.c printrusage.c printsiginfo.c rt_sigreturn.c \
+	rtc.c sg_io_v3.c sigaltstack.c sock.c sysinfo.c times.c \
+	ustat.c utime.c v4l2.c
 am__objects_1 = libmpers_m32_a-block.$(OBJEXT) \
 	libmpers_m32_a-btrfs.$(OBJEXT) libmpers_m32_a-dirent.$(OBJEXT) \
 	libmpers_m32_a-evdev_mpers.$(OBJEXT) \
@@ -199,6 +233,7 @@ am__objects_1 = libmpers_m32_a-block.$(O
 	libmpers_m32_a-fetch_struct_xfs_quotastat.$(OBJEXT) \
 	libmpers_m32_a-hdio.$(OBJEXT) \
 	libmpers_m32_a-ipc_msgctl.$(OBJEXT) \
+	libmpers_m32_a-ipc_semctl.$(OBJEXT) \
 	libmpers_m32_a-ipc_shmctl.$(OBJEXT) \
 	libmpers_m32_a-loop.$(OBJEXT) libmpers_m32_a-mtd.$(OBJEXT) \
 	libmpers_m32_a-perf_ioctl.$(OBJEXT) \
@@ -209,7 +244,6 @@ am__objects_1 = libmpers_m32_a-block.$(O
 	libmpers_m32_a-print_sg_req_info.$(OBJEXT) \
 	libmpers_m32_a-print_sigevent.$(OBJEXT) \
 	libmpers_m32_a-print_time.$(OBJEXT) \
-	libmpers_m32_a-print_timespec.$(OBJEXT) \
 	libmpers_m32_a-print_timeval.$(OBJEXT) \
 	libmpers_m32_a-printrusage.$(OBJEXT) \
 	libmpers_m32_a-printsiginfo.$(OBJEXT) \
@@ -228,12 +262,13 @@ am__libmpers_mx32_a_SOURCES_DIST = block
 	fetch_struct_keyctl_kdf_params.c fetch_struct_mmsghdr.c \
 	fetch_struct_msghdr.c fetch_struct_stat.c \
 	fetch_struct_stat64.c fetch_struct_statfs.c \
-	fetch_struct_xfs_quotastat.c hdio.c ipc_msgctl.c ipc_shmctl.c \
-	loop.c mtd.c perf_ioctl.c print_aio_sigset.c print_group_req.c \
-	print_mq_attr.c print_msgbuf.c print_sg_req_info.c \
-	print_sigevent.c print_time.c print_timespec.c print_timeval.c \
-	printrusage.c printsiginfo.c rt_sigreturn.c rtc.c sg_io_v3.c \
-	sigaltstack.c sock.c sysinfo.c times.c ustat.c utime.c v4l2.c
+	fetch_struct_xfs_quotastat.c hdio.c ipc_msgctl.c ipc_semctl.c \
+	ipc_shmctl.c loop.c mtd.c perf_ioctl.c print_aio_sigset.c \
+	print_group_req.c print_mq_attr.c print_msgbuf.c \
+	print_sg_req_info.c print_sigevent.c print_time.c \
+	print_timeval.c printrusage.c printsiginfo.c rt_sigreturn.c \
+	rtc.c sg_io_v3.c sigaltstack.c sock.c sysinfo.c times.c \
+	ustat.c utime.c v4l2.c
 am__objects_2 = libmpers_mx32_a-block.$(OBJEXT) \
 	libmpers_mx32_a-btrfs.$(OBJEXT) \
 	libmpers_mx32_a-dirent.$(OBJEXT) \
@@ -249,6 +284,7 @@ am__objects_2 = libmpers_mx32_a-block.$(
 	libmpers_mx32_a-fetch_struct_xfs_quotastat.$(OBJEXT) \
 	libmpers_mx32_a-hdio.$(OBJEXT) \
 	libmpers_mx32_a-ipc_msgctl.$(OBJEXT) \
+	libmpers_mx32_a-ipc_semctl.$(OBJEXT) \
 	libmpers_mx32_a-ipc_shmctl.$(OBJEXT) \
 	libmpers_mx32_a-loop.$(OBJEXT) libmpers_mx32_a-mtd.$(OBJEXT) \
 	libmpers_mx32_a-perf_ioctl.$(OBJEXT) \
@@ -259,7 +295,6 @@ am__objects_2 = libmpers_mx32_a-block.$(
 	libmpers_mx32_a-print_sg_req_info.$(OBJEXT) \
 	libmpers_mx32_a-print_sigevent.$(OBJEXT) \
 	libmpers_mx32_a-print_time.$(OBJEXT) \
-	libmpers_mx32_a-print_timespec.$(OBJEXT) \
 	libmpers_mx32_a-print_timeval.$(OBJEXT) \
 	libmpers_mx32_a-printrusage.$(OBJEXT) \
 	libmpers_mx32_a-printsiginfo.$(OBJEXT) \
@@ -276,49 +311,40 @@ am__objects_2 = libmpers_mx32_a-block.$(
 libmpers_mx32_a_OBJECTS = $(am_libmpers_mx32_a_OBJECTS)
 libstrace_a_AR = $(AR) $(ARFLAGS)
 libstrace_a_LIBADD =
-am_libstrace_a_OBJECTS =  \
-	libstrace_a-fetch_indirect_syscall_args.$(OBJEXT) \
-	libstrace_a-fstatfs.$(OBJEXT) libstrace_a-fstatfs64.$(OBJEXT) \
-	libstrace_a-getpagesize.$(OBJEXT) libstrace_a-ipc.$(OBJEXT) \
-	libstrace_a-mmap_cache.$(OBJEXT) \
-	libstrace_a-sigreturn.$(OBJEXT) \
-	libstrace_a-socketcall.$(OBJEXT) libstrace_a-statfs.$(OBJEXT) \
-	libstrace_a-statfs64.$(OBJEXT) \
-	libstrace_a-sync_file_range.$(OBJEXT) \
-	libstrace_a-sync_file_range2.$(OBJEXT) \
-	libstrace_a-upeek.$(OBJEXT) libstrace_a-upoke.$(OBJEXT)
-libstrace_a_OBJECTS = $(am_libstrace_a_OBJECTS)
-am__strace_SOURCES_DIST = access.c affinity.c aio.c alpha.c \
+am__libstrace_a_SOURCES_DIST = access.c affinity.c aio.c alpha.c \
 	arch_defs.h basic_filters.c bind.c bjm.c block.c bpf.c \
 	bpf_attr.h bpf_filter.c bpf_filter.h bpf_fprog.h \
 	bpf_seccomp_filter.c bpf_sock_filter.c btrfs.c cacheflush.c \
 	capability.c caps0.h caps1.h chdir.c chmod.c clone.c \
-	copy_file_range.c count.c defs.h delay.c delay.h desc.c \
-	dirent.c dirent64.c dm.c dyxlat.c empty.h epoll.c \
-	error_prints.c error_prints.h evdev.c evdev_mpers.c eventfd.c \
-	execve.c f_owner_ex.h fadvise.c fallocate.c fanotify.c \
-	fchownat.c fcntl.c fetch_bpf_fprog.c fetch_struct_flock.c \
+	close_range.c copy_file_range.c count.c defs.h delay.c delay.h \
+	desc.c dirent.c dirent64.c dirent_types.c dm.c dup.c dyxlat.c \
+	empty.h epoll.c error_prints.c error_prints.h evdev.c \
+	evdev_mpers.c eventfd.c execve.c f_owner_ex.h fadvise.c \
+	fallocate.c fanotify.c fchownat.c fcntl.c fetch_bpf_fprog.c \
+	fetch_indirect_syscall_args.c fetch_struct_flock.c \
 	fetch_struct_keyctl_kdf_params.c fetch_struct_mmsghdr.c \
 	fetch_struct_msghdr.c fetch_struct_stat.c \
 	fetch_struct_stat64.c fetch_struct_statfs.c \
 	fetch_struct_xfs_quotastat.c file_handle.c file_ioctl.c \
 	filter.h filter_qualify.c filter_seccomp.c filter_seccomp.h \
 	flock.c flock.h fs_x_ioctl.c fsconfig.c fsmount.c fsopen.c \
-	fspick.c futex.c gcc_compat.h get_personality.c \
-	get_personality.h get_robust_list.c getcpu.c getcwd.c \
-	getrandom.c hdio.c hostname.c inotify.c inotify_ioctl.c io.c \
-	io_uring.c ioctl.c ioperm.c iopl.c ioprio.c ipc_defs.h \
-	ipc_msg.c ipc_msgctl.c ipc_sem.c ipc_shm.c ipc_shmctl.c kcmp.c \
-	kernel_timespec.h kernel_timeval.h kernel_timex.h \
-	kernel_types.h kexec.c keyctl.c keyctl_kdf_params.h \
+	fspick.c fstatfs.c fstatfs64.c futex.c gcc_compat.h \
+	get_personality.c get_personality.h get_robust_list.c getcpu.c \
+	getcwd.c getpagesize.c getpid.c getrandom.c hdio.c hostname.c \
+	inotify.c inotify_ioctl.c io.c io_uring.c ioctl.c ioperm.c \
+	iopl.c ioprio.c ipc.c ipc_defs.h ipc_msg.c ipc_msgctl.c \
+	ipc_sem.c ipc_semctl.c ipc_shm.c ipc_shmctl.c kcmp.c \
+	kernel_dirent.h kernel_rusage.h kernel_timespec.h \
+	kernel_timeval.h kernel_timex.h kernel_types.h \
+	kernel_v4l2_types.h kexec.c keyctl.c keyctl_kdf_params.h \
 	kill_save_errno.h kvm.c largefile_wrappers.h ldt.c link.c \
 	linux/asm_stat.h linux/x32/asm_stat.h linux/x86_64/asm_stat.h \
 	list.h listen.c lookup_dcookie.c loop.c lseek.c macros.h mem.c \
-	membarrier.c memfd_create.c mknod.c mmap_notify.c \
-	mmap_notify.h mmsghdr.c mount.c move_mount.c mpers_type.h mq.c \
-	msghdr.c msghdr.h mtd.c native_defs.h nbd_ioctl.c \
-	negated_errno.h net.c netlink.c netlink.h netlink_crypto.c \
-	netlink_inet_diag.c netlink_kobject_uevent.c \
+	membarrier.c memfd_create.c mknod.c mmap_cache.c mmap_cache.h \
+	mmap_notify.c mmap_notify.h mmsghdr.c mount.c move_mount.c \
+	mpers_type.h mq.c msghdr.c msghdr.h mtd.c native_defs.h \
+	nbd_ioctl.c negated_errno.h net.c netlink.c netlink.h \
+	netlink_crypto.c netlink_inet_diag.c netlink_kobject_uevent.c \
 	netlink_kobject_uevent.h netlink_netfilter.c \
 	netlink_netlink_diag.c netlink_packet_diag.c netlink_route.c \
 	netlink_route.h netlink_selinux.c netlink_smc_diag.c \
@@ -326,13 +352,13 @@ am__strace_SOURCES_DIST = access.c affin
 	nlattr.c nlattr.h nsfs.c nsfs.h nsig.h numa.c number_set.c \
 	number_set.h oldstat.c open.c open_tree.c or1k_atomic.c \
 	pathtrace.c perf.c perf_event_struct.h perf_ioctl.c \
-	personality.c pidfd_open.c pkeys.c poll.c prctl.c \
-	print_aio_sigset.c print_dev_t.c print_fields.h \
+	personality.c pidfd_getfd.c pidfd_open.c pidns.c pkeys.c \
+	poll.c prctl.c print_aio_sigset.c print_dev_t.c print_fields.h \
 	print_group_req.c print_ifindex.c print_instruction_pointer.c \
 	print_kernel_version.c print_mac.c print_mq_attr.c \
 	print_msgbuf.c print_sg_req_info.c print_sigevent.c \
-	print_statfs.c print_struct_stat.c print_time.c \
-	print_timespec.c print_timespec.h print_timespec32.c \
+	print_statfs.c print_struct_stat.c print_syscall_number.c \
+	print_time.c print_timespec.h print_timespec32.c \
 	print_timespec64.c print_timeval.c print_timeval64.c \
 	print_timex.c print_timex.h print_utils.h printmode.c \
 	printrusage.c printsiginfo.c printsiginfo.h process.c \
@@ -345,168 +371,222 @@ am__strace_SOURCES_DIST = access.c affin
 	rtnl_route.c rtnl_rule.c rtnl_tc.c rtnl_tc_action.c s390.c \
 	sched.c sched_attr.h scsi.c seccomp.c sendfile.c sg_io_v3.c \
 	sg_io_v4.c shutdown.c sigaltstack.c sigevent.h signal.c \
-	signalfd.c sock.c sockaddr.c socketutils.c sparc.c \
-	sram_alloc.c stage_output.c stat.c stat.h stat64.c statfs.c \
-	statfs.h static_assert.h statx.c statx.h strace.c \
-	string_to_uint.c string_to_uint.h swapon.c syscall.c sysctl.c \
+	signalfd.c sigreturn.c sock.c sockaddr.c socketcall.c \
+	socketutils.c sparc.c sram_alloc.c stage_output.c stat.c \
+	stat.h stat64.c statfs.c statfs.h statfs64.c static_assert.h \
+	statx.c statx.h string_to_uint.c string_to_uint.h swapon.c \
+	sync_file_range.c sync_file_range2.c syscall.c sysctl.c \
 	sysent.h sysent_shorthand_defs.h sysent_shorthand_undefs.h \
-	sysinfo.c syslog.c sysmips.c term.c time.c times.c \
-	trace_event.h truncate.c ubi.c ucopy.c uid.c uid16.c umask.c \
-	umount.c uname.c userfaultfd.c ustat.c util.c utime.c utimes.c \
-	v4l2.c wait.c wait.h watchdog_ioctl.c xattr.c xfs_quota_stat.h \
-	xlat.c xlat.h xmalloc.c xmalloc.h xstring.h types/cryptouser.h \
-	types/evdev.h types/io_uring.h types/rtnl_link.h \
-	types/rtnl_mdb.h types/rtnl_neightbl.h types/rtnl_route.h \
-	bpf_attr_check.c types/check-cryptouser.c types/check-evdev.c \
-	types/check-io_uring.c types/check-rtnl_link.c \
+	sysinfo.c syslog.c sysmips.c tee.c term.c time.c times.c \
+	trace_event.h trie.c trie.h truncate.c ubi.c ucopy.c uid.c \
+	uid16.c umask.c umount.c uname.c upeek.c upoke.c userfaultfd.c \
+	ustat.c util.c utime.c utimes.c v4l2.c wait.c wait.h \
+	watchdog_ioctl.c xattr.c xfs_quota_stat.h xgetdents.c \
+	xgetdents.h xlat.c xlat.h xmalloc.c xmalloc.h xstring.h \
+	types/btrfs.h types/cryptouser.h types/evdev.h \
+	types/io_uring.h types/loop.h types/openat2.h \
+	types/rtnl_link.h types/rtnl_mdb.h types/rtnl_neightbl.h \
+	types/rtnl_route.h types/tee.h types/v4l2.h bpf_attr_check.c \
+	types/check-btrfs.c types/check-cryptouser.c \
+	types/check-evdev.c types/check-io_uring.c types/check-loop.c \
+	types/check-openat2.c types/check-rtnl_link.c \
 	types/check-rtnl_mdb.c types/check-rtnl_neightbl.c \
-	types/check-rtnl_route.c unwind.c unwind.h unwind-libdw.c \
-	unwind-libunwind.c
+	types/check-rtnl_route.c types/check-tee.c types/check-v4l2.c \
+	unwind.c unwind.h unwind-libdw.c unwind-libunwind.c
 am__objects_3 =
 am__dirstamp = $(am__leading_dot)dirstamp
-am__objects_4 = types/strace-check-cryptouser.$(OBJEXT) \
-	types/strace-check-evdev.$(OBJEXT) \
-	types/strace-check-io_uring.$(OBJEXT) \
-	types/strace-check-rtnl_link.$(OBJEXT) \
-	types/strace-check-rtnl_mdb.$(OBJEXT) \
-	types/strace-check-rtnl_neightbl.$(OBJEXT) \
-	types/strace-check-rtnl_route.$(OBJEXT)
-am__objects_5 = strace-bpf_attr_check.$(OBJEXT) $(am__objects_4)
-@ENABLE_STACKTRACE_TRUE@am__objects_6 = strace-unwind.$(OBJEXT)
-@ENABLE_STACKTRACE_TRUE@@USE_LIBDW_TRUE@am__objects_7 = strace-unwind-libdw.$(OBJEXT)
-@ENABLE_STACKTRACE_TRUE@@USE_LIBUNWIND_TRUE@am__objects_8 = strace-unwind-libunwind.$(OBJEXT)
-am_strace_OBJECTS = strace-access.$(OBJEXT) strace-affinity.$(OBJEXT) \
-	strace-aio.$(OBJEXT) strace-alpha.$(OBJEXT) \
-	strace-basic_filters.$(OBJEXT) strace-bind.$(OBJEXT) \
-	strace-bjm.$(OBJEXT) strace-block.$(OBJEXT) \
-	strace-bpf.$(OBJEXT) strace-bpf_filter.$(OBJEXT) \
-	strace-bpf_seccomp_filter.$(OBJEXT) \
-	strace-bpf_sock_filter.$(OBJEXT) strace-btrfs.$(OBJEXT) \
-	strace-cacheflush.$(OBJEXT) strace-capability.$(OBJEXT) \
-	strace-chdir.$(OBJEXT) strace-chmod.$(OBJEXT) \
-	strace-clone.$(OBJEXT) strace-copy_file_range.$(OBJEXT) \
-	strace-count.$(OBJEXT) strace-delay.$(OBJEXT) \
-	strace-desc.$(OBJEXT) strace-dirent.$(OBJEXT) \
-	strace-dirent64.$(OBJEXT) strace-dm.$(OBJEXT) \
-	strace-dyxlat.$(OBJEXT) strace-epoll.$(OBJEXT) \
-	strace-error_prints.$(OBJEXT) strace-evdev.$(OBJEXT) \
-	strace-evdev_mpers.$(OBJEXT) strace-eventfd.$(OBJEXT) \
-	strace-execve.$(OBJEXT) strace-fadvise.$(OBJEXT) \
-	strace-fallocate.$(OBJEXT) strace-fanotify.$(OBJEXT) \
-	strace-fchownat.$(OBJEXT) strace-fcntl.$(OBJEXT) \
-	strace-fetch_bpf_fprog.$(OBJEXT) \
-	strace-fetch_struct_flock.$(OBJEXT) \
-	strace-fetch_struct_keyctl_kdf_params.$(OBJEXT) \
-	strace-fetch_struct_mmsghdr.$(OBJEXT) \
-	strace-fetch_struct_msghdr.$(OBJEXT) \
-	strace-fetch_struct_stat.$(OBJEXT) \
-	strace-fetch_struct_stat64.$(OBJEXT) \
-	strace-fetch_struct_statfs.$(OBJEXT) \
-	strace-fetch_struct_xfs_quotastat.$(OBJEXT) \
-	strace-file_handle.$(OBJEXT) strace-file_ioctl.$(OBJEXT) \
-	strace-filter_qualify.$(OBJEXT) \
-	strace-filter_seccomp.$(OBJEXT) strace-flock.$(OBJEXT) \
-	strace-fs_x_ioctl.$(OBJEXT) strace-fsconfig.$(OBJEXT) \
-	strace-fsmount.$(OBJEXT) strace-fsopen.$(OBJEXT) \
-	strace-fspick.$(OBJEXT) strace-futex.$(OBJEXT) \
-	strace-get_personality.$(OBJEXT) \
-	strace-get_robust_list.$(OBJEXT) strace-getcpu.$(OBJEXT) \
-	strace-getcwd.$(OBJEXT) strace-getrandom.$(OBJEXT) \
-	strace-hdio.$(OBJEXT) strace-hostname.$(OBJEXT) \
-	strace-inotify.$(OBJEXT) strace-inotify_ioctl.$(OBJEXT) \
-	strace-io.$(OBJEXT) strace-io_uring.$(OBJEXT) \
-	strace-ioctl.$(OBJEXT) strace-ioperm.$(OBJEXT) \
-	strace-iopl.$(OBJEXT) strace-ioprio.$(OBJEXT) \
-	strace-ipc_msg.$(OBJEXT) strace-ipc_msgctl.$(OBJEXT) \
-	strace-ipc_sem.$(OBJEXT) strace-ipc_shm.$(OBJEXT) \
-	strace-ipc_shmctl.$(OBJEXT) strace-kcmp.$(OBJEXT) \
-	strace-kexec.$(OBJEXT) strace-keyctl.$(OBJEXT) \
-	strace-kvm.$(OBJEXT) strace-ldt.$(OBJEXT) \
-	strace-link.$(OBJEXT) strace-listen.$(OBJEXT) \
-	strace-lookup_dcookie.$(OBJEXT) strace-loop.$(OBJEXT) \
-	strace-lseek.$(OBJEXT) strace-mem.$(OBJEXT) \
-	strace-membarrier.$(OBJEXT) strace-memfd_create.$(OBJEXT) \
-	strace-mknod.$(OBJEXT) strace-mmap_notify.$(OBJEXT) \
-	strace-mmsghdr.$(OBJEXT) strace-mount.$(OBJEXT) \
-	strace-move_mount.$(OBJEXT) strace-mq.$(OBJEXT) \
-	strace-msghdr.$(OBJEXT) strace-mtd.$(OBJEXT) \
-	strace-nbd_ioctl.$(OBJEXT) strace-net.$(OBJEXT) \
-	strace-netlink.$(OBJEXT) strace-netlink_crypto.$(OBJEXT) \
-	strace-netlink_inet_diag.$(OBJEXT) \
-	strace-netlink_kobject_uevent.$(OBJEXT) \
-	strace-netlink_netfilter.$(OBJEXT) \
-	strace-netlink_netlink_diag.$(OBJEXT) \
-	strace-netlink_packet_diag.$(OBJEXT) \
-	strace-netlink_route.$(OBJEXT) \
-	strace-netlink_selinux.$(OBJEXT) \
-	strace-netlink_smc_diag.$(OBJEXT) \
-	strace-netlink_sock_diag.$(OBJEXT) \
-	strace-netlink_unix_diag.$(OBJEXT) strace-nlattr.$(OBJEXT) \
-	strace-nsfs.$(OBJEXT) strace-numa.$(OBJEXT) \
-	strace-number_set.$(OBJEXT) strace-oldstat.$(OBJEXT) \
-	strace-open.$(OBJEXT) strace-open_tree.$(OBJEXT) \
-	strace-or1k_atomic.$(OBJEXT) strace-pathtrace.$(OBJEXT) \
-	strace-perf.$(OBJEXT) strace-perf_ioctl.$(OBJEXT) \
-	strace-personality.$(OBJEXT) strace-pidfd_open.$(OBJEXT) \
-	strace-pkeys.$(OBJEXT) strace-poll.$(OBJEXT) \
-	strace-prctl.$(OBJEXT) strace-print_aio_sigset.$(OBJEXT) \
-	strace-print_dev_t.$(OBJEXT) strace-print_group_req.$(OBJEXT) \
-	strace-print_ifindex.$(OBJEXT) \
-	strace-print_instruction_pointer.$(OBJEXT) \
-	strace-print_kernel_version.$(OBJEXT) \
-	strace-print_mac.$(OBJEXT) strace-print_mq_attr.$(OBJEXT) \
-	strace-print_msgbuf.$(OBJEXT) \
-	strace-print_sg_req_info.$(OBJEXT) \
-	strace-print_sigevent.$(OBJEXT) strace-print_statfs.$(OBJEXT) \
-	strace-print_struct_stat.$(OBJEXT) strace-print_time.$(OBJEXT) \
-	strace-print_timespec.$(OBJEXT) \
-	strace-print_timespec32.$(OBJEXT) \
-	strace-print_timespec64.$(OBJEXT) \
-	strace-print_timeval.$(OBJEXT) \
-	strace-print_timeval64.$(OBJEXT) strace-print_timex.$(OBJEXT) \
-	strace-printmode.$(OBJEXT) strace-printrusage.$(OBJEXT) \
-	strace-printsiginfo.$(OBJEXT) strace-process.$(OBJEXT) \
-	strace-process_vm.$(OBJEXT) strace-ptp.$(OBJEXT) \
-	strace-ptrace_syscall_info.$(OBJEXT) strace-quota.$(OBJEXT) \
-	strace-random_ioctl.$(OBJEXT) strace-readahead.$(OBJEXT) \
-	strace-readlink.$(OBJEXT) strace-reboot.$(OBJEXT) \
-	strace-renameat.$(OBJEXT) strace-resource.$(OBJEXT) \
-	strace-retval.$(OBJEXT) strace-riscv.$(OBJEXT) \
-	strace-rt_sigframe.$(OBJEXT) strace-rt_sigreturn.$(OBJEXT) \
-	strace-rtc.$(OBJEXT) strace-rtnl_addr.$(OBJEXT) \
-	strace-rtnl_addrlabel.$(OBJEXT) strace-rtnl_dcb.$(OBJEXT) \
-	strace-rtnl_link.$(OBJEXT) strace-rtnl_mdb.$(OBJEXT) \
-	strace-rtnl_neigh.$(OBJEXT) strace-rtnl_neightbl.$(OBJEXT) \
-	strace-rtnl_netconf.$(OBJEXT) strace-rtnl_nsid.$(OBJEXT) \
-	strace-rtnl_route.$(OBJEXT) strace-rtnl_rule.$(OBJEXT) \
-	strace-rtnl_tc.$(OBJEXT) strace-rtnl_tc_action.$(OBJEXT) \
-	strace-s390.$(OBJEXT) strace-sched.$(OBJEXT) \
-	strace-scsi.$(OBJEXT) strace-seccomp.$(OBJEXT) \
-	strace-sendfile.$(OBJEXT) strace-sg_io_v3.$(OBJEXT) \
-	strace-sg_io_v4.$(OBJEXT) strace-shutdown.$(OBJEXT) \
-	strace-sigaltstack.$(OBJEXT) strace-signal.$(OBJEXT) \
-	strace-signalfd.$(OBJEXT) strace-sock.$(OBJEXT) \
-	strace-sockaddr.$(OBJEXT) strace-socketutils.$(OBJEXT) \
-	strace-sparc.$(OBJEXT) strace-sram_alloc.$(OBJEXT) \
-	strace-stage_output.$(OBJEXT) strace-stat.$(OBJEXT) \
-	strace-stat64.$(OBJEXT) strace-statfs.$(OBJEXT) \
-	strace-statx.$(OBJEXT) strace-strace.$(OBJEXT) \
-	strace-string_to_uint.$(OBJEXT) strace-swapon.$(OBJEXT) \
-	strace-syscall.$(OBJEXT) strace-sysctl.$(OBJEXT) \
-	strace-sysinfo.$(OBJEXT) strace-syslog.$(OBJEXT) \
-	strace-sysmips.$(OBJEXT) strace-term.$(OBJEXT) \
-	strace-time.$(OBJEXT) strace-times.$(OBJEXT) \
-	strace-truncate.$(OBJEXT) strace-ubi.$(OBJEXT) \
-	strace-ucopy.$(OBJEXT) strace-uid.$(OBJEXT) \
-	strace-uid16.$(OBJEXT) strace-umask.$(OBJEXT) \
-	strace-umount.$(OBJEXT) strace-uname.$(OBJEXT) \
-	strace-userfaultfd.$(OBJEXT) strace-ustat.$(OBJEXT) \
-	strace-util.$(OBJEXT) strace-utime.$(OBJEXT) \
-	strace-utimes.$(OBJEXT) strace-v4l2.$(OBJEXT) \
-	strace-wait.$(OBJEXT) strace-watchdog_ioctl.$(OBJEXT) \
-	strace-xattr.$(OBJEXT) strace-xlat.$(OBJEXT) \
-	strace-xmalloc.$(OBJEXT) $(am__objects_3) $(am__objects_5) \
-	$(am__objects_6) $(am__objects_7) $(am__objects_8)
+am__objects_4 = types/libstrace_a-check-btrfs.$(OBJEXT) \
+	types/libstrace_a-check-cryptouser.$(OBJEXT) \
+	types/libstrace_a-check-evdev.$(OBJEXT) \
+	types/libstrace_a-check-io_uring.$(OBJEXT) \
+	types/libstrace_a-check-loop.$(OBJEXT) \
+	types/libstrace_a-check-openat2.$(OBJEXT) \
+	types/libstrace_a-check-rtnl_link.$(OBJEXT) \
+	types/libstrace_a-check-rtnl_mdb.$(OBJEXT) \
+	types/libstrace_a-check-rtnl_neightbl.$(OBJEXT) \
+	types/libstrace_a-check-rtnl_route.$(OBJEXT) \
+	types/libstrace_a-check-tee.$(OBJEXT) \
+	types/libstrace_a-check-v4l2.$(OBJEXT)
+am__objects_5 = libstrace_a-bpf_attr_check.$(OBJEXT) $(am__objects_4)
+@ENABLE_STACKTRACE_TRUE@am__objects_6 = libstrace_a-unwind.$(OBJEXT)
+@ENABLE_STACKTRACE_TRUE@@USE_LIBDW_TRUE@am__objects_7 = libstrace_a-unwind-libdw.$(OBJEXT)
+@ENABLE_STACKTRACE_TRUE@@USE_LIBUNWIND_TRUE@am__objects_8 = libstrace_a-unwind-libunwind.$(OBJEXT)
+am_libstrace_a_OBJECTS = libstrace_a-access.$(OBJEXT) \
+	libstrace_a-affinity.$(OBJEXT) libstrace_a-aio.$(OBJEXT) \
+	libstrace_a-alpha.$(OBJEXT) \
+	libstrace_a-basic_filters.$(OBJEXT) libstrace_a-bind.$(OBJEXT) \
+	libstrace_a-bjm.$(OBJEXT) libstrace_a-block.$(OBJEXT) \
+	libstrace_a-bpf.$(OBJEXT) libstrace_a-bpf_filter.$(OBJEXT) \
+	libstrace_a-bpf_seccomp_filter.$(OBJEXT) \
+	libstrace_a-bpf_sock_filter.$(OBJEXT) \
+	libstrace_a-btrfs.$(OBJEXT) libstrace_a-cacheflush.$(OBJEXT) \
+	libstrace_a-capability.$(OBJEXT) libstrace_a-chdir.$(OBJEXT) \
+	libstrace_a-chmod.$(OBJEXT) libstrace_a-clone.$(OBJEXT) \
+	libstrace_a-close_range.$(OBJEXT) \
+	libstrace_a-copy_file_range.$(OBJEXT) \
+	libstrace_a-count.$(OBJEXT) libstrace_a-delay.$(OBJEXT) \
+	libstrace_a-desc.$(OBJEXT) libstrace_a-dirent.$(OBJEXT) \
+	libstrace_a-dirent64.$(OBJEXT) \
+	libstrace_a-dirent_types.$(OBJEXT) libstrace_a-dm.$(OBJEXT) \
+	libstrace_a-dup.$(OBJEXT) libstrace_a-dyxlat.$(OBJEXT) \
+	libstrace_a-epoll.$(OBJEXT) libstrace_a-error_prints.$(OBJEXT) \
+	libstrace_a-evdev.$(OBJEXT) libstrace_a-evdev_mpers.$(OBJEXT) \
+	libstrace_a-eventfd.$(OBJEXT) libstrace_a-execve.$(OBJEXT) \
+	libstrace_a-fadvise.$(OBJEXT) libstrace_a-fallocate.$(OBJEXT) \
+	libstrace_a-fanotify.$(OBJEXT) libstrace_a-fchownat.$(OBJEXT) \
+	libstrace_a-fcntl.$(OBJEXT) \
+	libstrace_a-fetch_bpf_fprog.$(OBJEXT) \
+	libstrace_a-fetch_indirect_syscall_args.$(OBJEXT) \
+	libstrace_a-fetch_struct_flock.$(OBJEXT) \
+	libstrace_a-fetch_struct_keyctl_kdf_params.$(OBJEXT) \
+	libstrace_a-fetch_struct_mmsghdr.$(OBJEXT) \
+	libstrace_a-fetch_struct_msghdr.$(OBJEXT) \
+	libstrace_a-fetch_struct_stat.$(OBJEXT) \
+	libstrace_a-fetch_struct_stat64.$(OBJEXT) \
+	libstrace_a-fetch_struct_statfs.$(OBJEXT) \
+	libstrace_a-fetch_struct_xfs_quotastat.$(OBJEXT) \
+	libstrace_a-file_handle.$(OBJEXT) \
+	libstrace_a-file_ioctl.$(OBJEXT) \
+	libstrace_a-filter_qualify.$(OBJEXT) \
+	libstrace_a-filter_seccomp.$(OBJEXT) \
+	libstrace_a-flock.$(OBJEXT) libstrace_a-fs_x_ioctl.$(OBJEXT) \
+	libstrace_a-fsconfig.$(OBJEXT) libstrace_a-fsmount.$(OBJEXT) \
+	libstrace_a-fsopen.$(OBJEXT) libstrace_a-fspick.$(OBJEXT) \
+	libstrace_a-fstatfs.$(OBJEXT) libstrace_a-fstatfs64.$(OBJEXT) \
+	libstrace_a-futex.$(OBJEXT) \
+	libstrace_a-get_personality.$(OBJEXT) \
+	libstrace_a-get_robust_list.$(OBJEXT) \
+	libstrace_a-getcpu.$(OBJEXT) libstrace_a-getcwd.$(OBJEXT) \
+	libstrace_a-getpagesize.$(OBJEXT) libstrace_a-getpid.$(OBJEXT) \
+	libstrace_a-getrandom.$(OBJEXT) libstrace_a-hdio.$(OBJEXT) \
+	libstrace_a-hostname.$(OBJEXT) libstrace_a-inotify.$(OBJEXT) \
+	libstrace_a-inotify_ioctl.$(OBJEXT) libstrace_a-io.$(OBJEXT) \
+	libstrace_a-io_uring.$(OBJEXT) libstrace_a-ioctl.$(OBJEXT) \
+	libstrace_a-ioperm.$(OBJEXT) libstrace_a-iopl.$(OBJEXT) \
+	libstrace_a-ioprio.$(OBJEXT) libstrace_a-ipc.$(OBJEXT) \
+	libstrace_a-ipc_msg.$(OBJEXT) libstrace_a-ipc_msgctl.$(OBJEXT) \
+	libstrace_a-ipc_sem.$(OBJEXT) libstrace_a-ipc_semctl.$(OBJEXT) \
+	libstrace_a-ipc_shm.$(OBJEXT) libstrace_a-ipc_shmctl.$(OBJEXT) \
+	libstrace_a-kcmp.$(OBJEXT) libstrace_a-kexec.$(OBJEXT) \
+	libstrace_a-keyctl.$(OBJEXT) libstrace_a-kvm.$(OBJEXT) \
+	libstrace_a-ldt.$(OBJEXT) libstrace_a-link.$(OBJEXT) \
+	libstrace_a-listen.$(OBJEXT) \
+	libstrace_a-lookup_dcookie.$(OBJEXT) \
+	libstrace_a-loop.$(OBJEXT) libstrace_a-lseek.$(OBJEXT) \
+	libstrace_a-mem.$(OBJEXT) libstrace_a-membarrier.$(OBJEXT) \
+	libstrace_a-memfd_create.$(OBJEXT) libstrace_a-mknod.$(OBJEXT) \
+	libstrace_a-mmap_cache.$(OBJEXT) \
+	libstrace_a-mmap_notify.$(OBJEXT) \
+	libstrace_a-mmsghdr.$(OBJEXT) libstrace_a-mount.$(OBJEXT) \
+	libstrace_a-move_mount.$(OBJEXT) libstrace_a-mq.$(OBJEXT) \
+	libstrace_a-msghdr.$(OBJEXT) libstrace_a-mtd.$(OBJEXT) \
+	libstrace_a-nbd_ioctl.$(OBJEXT) libstrace_a-net.$(OBJEXT) \
+	libstrace_a-netlink.$(OBJEXT) \
+	libstrace_a-netlink_crypto.$(OBJEXT) \
+	libstrace_a-netlink_inet_diag.$(OBJEXT) \
+	libstrace_a-netlink_kobject_uevent.$(OBJEXT) \
+	libstrace_a-netlink_netfilter.$(OBJEXT) \
+	libstrace_a-netlink_netlink_diag.$(OBJEXT) \
+	libstrace_a-netlink_packet_diag.$(OBJEXT) \
+	libstrace_a-netlink_route.$(OBJEXT) \
+	libstrace_a-netlink_selinux.$(OBJEXT) \
+	libstrace_a-netlink_smc_diag.$(OBJEXT) \
+	libstrace_a-netlink_sock_diag.$(OBJEXT) \
+	libstrace_a-netlink_unix_diag.$(OBJEXT) \
+	libstrace_a-nlattr.$(OBJEXT) libstrace_a-nsfs.$(OBJEXT) \
+	libstrace_a-numa.$(OBJEXT) libstrace_a-number_set.$(OBJEXT) \
+	libstrace_a-oldstat.$(OBJEXT) libstrace_a-open.$(OBJEXT) \
+	libstrace_a-open_tree.$(OBJEXT) \
+	libstrace_a-or1k_atomic.$(OBJEXT) \
+	libstrace_a-pathtrace.$(OBJEXT) libstrace_a-perf.$(OBJEXT) \
+	libstrace_a-perf_ioctl.$(OBJEXT) \
+	libstrace_a-personality.$(OBJEXT) \
+	libstrace_a-pidfd_getfd.$(OBJEXT) \
+	libstrace_a-pidfd_open.$(OBJEXT) libstrace_a-pidns.$(OBJEXT) \
+	libstrace_a-pkeys.$(OBJEXT) libstrace_a-poll.$(OBJEXT) \
+	libstrace_a-prctl.$(OBJEXT) \
+	libstrace_a-print_aio_sigset.$(OBJEXT) \
+	libstrace_a-print_dev_t.$(OBJEXT) \
+	libstrace_a-print_group_req.$(OBJEXT) \
+	libstrace_a-print_ifindex.$(OBJEXT) \
+	libstrace_a-print_instruction_pointer.$(OBJEXT) \
+	libstrace_a-print_kernel_version.$(OBJEXT) \
+	libstrace_a-print_mac.$(OBJEXT) \
+	libstrace_a-print_mq_attr.$(OBJEXT) \
+	libstrace_a-print_msgbuf.$(OBJEXT) \
+	libstrace_a-print_sg_req_info.$(OBJEXT) \
+	libstrace_a-print_sigevent.$(OBJEXT) \
+	libstrace_a-print_statfs.$(OBJEXT) \
+	libstrace_a-print_struct_stat.$(OBJEXT) \
+	libstrace_a-print_syscall_number.$(OBJEXT) \
+	libstrace_a-print_time.$(OBJEXT) \
+	libstrace_a-print_timespec32.$(OBJEXT) \
+	libstrace_a-print_timespec64.$(OBJEXT) \
+	libstrace_a-print_timeval.$(OBJEXT) \
+	libstrace_a-print_timeval64.$(OBJEXT) \
+	libstrace_a-print_timex.$(OBJEXT) \
+	libstrace_a-printmode.$(OBJEXT) \
+	libstrace_a-printrusage.$(OBJEXT) \
+	libstrace_a-printsiginfo.$(OBJEXT) \
+	libstrace_a-process.$(OBJEXT) libstrace_a-process_vm.$(OBJEXT) \
+	libstrace_a-ptp.$(OBJEXT) \
+	libstrace_a-ptrace_syscall_info.$(OBJEXT) \
+	libstrace_a-quota.$(OBJEXT) libstrace_a-random_ioctl.$(OBJEXT) \
+	libstrace_a-readahead.$(OBJEXT) libstrace_a-readlink.$(OBJEXT) \
+	libstrace_a-reboot.$(OBJEXT) libstrace_a-renameat.$(OBJEXT) \
+	libstrace_a-resource.$(OBJEXT) libstrace_a-retval.$(OBJEXT) \
+	libstrace_a-riscv.$(OBJEXT) libstrace_a-rt_sigframe.$(OBJEXT) \
+	libstrace_a-rt_sigreturn.$(OBJEXT) libstrace_a-rtc.$(OBJEXT) \
+	libstrace_a-rtnl_addr.$(OBJEXT) \
+	libstrace_a-rtnl_addrlabel.$(OBJEXT) \
+	libstrace_a-rtnl_dcb.$(OBJEXT) libstrace_a-rtnl_link.$(OBJEXT) \
+	libstrace_a-rtnl_mdb.$(OBJEXT) \
+	libstrace_a-rtnl_neigh.$(OBJEXT) \
+	libstrace_a-rtnl_neightbl.$(OBJEXT) \
+	libstrace_a-rtnl_netconf.$(OBJEXT) \
+	libstrace_a-rtnl_nsid.$(OBJEXT) \
+	libstrace_a-rtnl_route.$(OBJEXT) \
+	libstrace_a-rtnl_rule.$(OBJEXT) libstrace_a-rtnl_tc.$(OBJEXT) \
+	libstrace_a-rtnl_tc_action.$(OBJEXT) \
+	libstrace_a-s390.$(OBJEXT) libstrace_a-sched.$(OBJEXT) \
+	libstrace_a-scsi.$(OBJEXT) libstrace_a-seccomp.$(OBJEXT) \
+	libstrace_a-sendfile.$(OBJEXT) libstrace_a-sg_io_v3.$(OBJEXT) \
+	libstrace_a-sg_io_v4.$(OBJEXT) libstrace_a-shutdown.$(OBJEXT) \
+	libstrace_a-sigaltstack.$(OBJEXT) libstrace_a-signal.$(OBJEXT) \
+	libstrace_a-signalfd.$(OBJEXT) libstrace_a-sigreturn.$(OBJEXT) \
+	libstrace_a-sock.$(OBJEXT) libstrace_a-sockaddr.$(OBJEXT) \
+	libstrace_a-socketcall.$(OBJEXT) \
+	libstrace_a-socketutils.$(OBJEXT) libstrace_a-sparc.$(OBJEXT) \
+	libstrace_a-sram_alloc.$(OBJEXT) \
+	libstrace_a-stage_output.$(OBJEXT) libstrace_a-stat.$(OBJEXT) \
+	libstrace_a-stat64.$(OBJEXT) libstrace_a-statfs.$(OBJEXT) \
+	libstrace_a-statfs.$(OBJEXT) libstrace_a-statfs64.$(OBJEXT) \
+	libstrace_a-statx.$(OBJEXT) \
+	libstrace_a-string_to_uint.$(OBJEXT) \
+	libstrace_a-swapon.$(OBJEXT) \
+	libstrace_a-sync_file_range.$(OBJEXT) \
+	libstrace_a-sync_file_range2.$(OBJEXT) \
+	libstrace_a-syscall.$(OBJEXT) libstrace_a-sysctl.$(OBJEXT) \
+	libstrace_a-sysinfo.$(OBJEXT) libstrace_a-syslog.$(OBJEXT) \
+	libstrace_a-sysmips.$(OBJEXT) libstrace_a-tee.$(OBJEXT) \
+	libstrace_a-term.$(OBJEXT) libstrace_a-time.$(OBJEXT) \
+	libstrace_a-times.$(OBJEXT) libstrace_a-trie.$(OBJEXT) \
+	libstrace_a-truncate.$(OBJEXT) libstrace_a-ubi.$(OBJEXT) \
+	libstrace_a-ucopy.$(OBJEXT) libstrace_a-uid.$(OBJEXT) \
+	libstrace_a-uid16.$(OBJEXT) libstrace_a-umask.$(OBJEXT) \
+	libstrace_a-umount.$(OBJEXT) libstrace_a-uname.$(OBJEXT) \
+	libstrace_a-upeek.$(OBJEXT) libstrace_a-upoke.$(OBJEXT) \
+	libstrace_a-userfaultfd.$(OBJEXT) libstrace_a-ustat.$(OBJEXT) \
+	libstrace_a-util.$(OBJEXT) libstrace_a-utime.$(OBJEXT) \
+	libstrace_a-utimes.$(OBJEXT) libstrace_a-v4l2.$(OBJEXT) \
+	libstrace_a-wait.$(OBJEXT) \
+	libstrace_a-watchdog_ioctl.$(OBJEXT) \
+	libstrace_a-xattr.$(OBJEXT) libstrace_a-xgetdents.$(OBJEXT) \
+	libstrace_a-xlat.$(OBJEXT) libstrace_a-xmalloc.$(OBJEXT) \
+	$(am__objects_3) $(am__objects_5) $(am__objects_6) \
+	$(am__objects_7) $(am__objects_8)
+libstrace_a_OBJECTS = $(am_libstrace_a_OBJECTS)
+am_strace_OBJECTS = strace-strace.$(OBJEXT)
 strace_OBJECTS = $(am_strace_OBJECTS)
 am__DEPENDENCIES_1 =
 @ENABLE_STACKTRACE_TRUE@@USE_LIBDW_TRUE@am__DEPENDENCIES_2 =  \
@@ -577,6 +657,7 @@ am__depfiles_remade = ./$(DEPDIR)/libmpe
 	./$(DEPDIR)/libmpers_m32_a-fetch_struct_xfs_quotastat.Po \
 	./$(DEPDIR)/libmpers_m32_a-hdio.Po \
 	./$(DEPDIR)/libmpers_m32_a-ipc_msgctl.Po \
+	./$(DEPDIR)/libmpers_m32_a-ipc_semctl.Po \
 	./$(DEPDIR)/libmpers_m32_a-ipc_shmctl.Po \
 	./$(DEPDIR)/libmpers_m32_a-loop.Po \
 	./$(DEPDIR)/libmpers_m32_a-mtd.Po \
@@ -588,7 +669,6 @@ am__depfiles_remade = ./$(DEPDIR)/libmpe
 	./$(DEPDIR)/libmpers_m32_a-print_sg_req_info.Po \
 	./$(DEPDIR)/libmpers_m32_a-print_sigevent.Po \
 	./$(DEPDIR)/libmpers_m32_a-print_time.Po \
-	./$(DEPDIR)/libmpers_m32_a-print_timespec.Po \
 	./$(DEPDIR)/libmpers_m32_a-print_timeval.Po \
 	./$(DEPDIR)/libmpers_m32_a-printrusage.Po \
 	./$(DEPDIR)/libmpers_m32_a-printsiginfo.Po \
@@ -617,6 +697,7 @@ am__depfiles_remade = ./$(DEPDIR)/libmpe
 	./$(DEPDIR)/libmpers_mx32_a-fetch_struct_xfs_quotastat.Po \
 	./$(DEPDIR)/libmpers_mx32_a-hdio.Po \
 	./$(DEPDIR)/libmpers_mx32_a-ipc_msgctl.Po \
+	./$(DEPDIR)/libmpers_mx32_a-ipc_semctl.Po \
 	./$(DEPDIR)/libmpers_mx32_a-ipc_shmctl.Po \
 	./$(DEPDIR)/libmpers_mx32_a-loop.Po \
 	./$(DEPDIR)/libmpers_mx32_a-mtd.Po \
@@ -628,7 +709,6 @@ am__depfiles_remade = ./$(DEPDIR)/libmpe
 	./$(DEPDIR)/libmpers_mx32_a-print_sg_req_info.Po \
 	./$(DEPDIR)/libmpers_mx32_a-print_sigevent.Po \
 	./$(DEPDIR)/libmpers_mx32_a-print_time.Po \
-	./$(DEPDIR)/libmpers_mx32_a-print_timespec.Po \
 	./$(DEPDIR)/libmpers_mx32_a-print_timeval.Po \
 	./$(DEPDIR)/libmpers_mx32_a-printrusage.Po \
 	./$(DEPDIR)/libmpers_mx32_a-printsiginfo.Po \
@@ -642,185 +722,272 @@ am__depfiles_remade = ./$(DEPDIR)/libmpe
 	./$(DEPDIR)/libmpers_mx32_a-ustat.Po \
 	./$(DEPDIR)/libmpers_mx32_a-utime.Po \
 	./$(DEPDIR)/libmpers_mx32_a-v4l2.Po \
+	./$(DEPDIR)/libstrace_a-access.Po \
+	./$(DEPDIR)/libstrace_a-affinity.Po \
+	./$(DEPDIR)/libstrace_a-aio.Po \
+	./$(DEPDIR)/libstrace_a-alpha.Po \
+	./$(DEPDIR)/libstrace_a-basic_filters.Po \
+	./$(DEPDIR)/libstrace_a-bind.Po ./$(DEPDIR)/libstrace_a-bjm.Po \
+	./$(DEPDIR)/libstrace_a-block.Po \
+	./$(DEPDIR)/libstrace_a-bpf.Po \
+	./$(DEPDIR)/libstrace_a-bpf_attr_check.Po \
+	./$(DEPDIR)/libstrace_a-bpf_filter.Po \
+	./$(DEPDIR)/libstrace_a-bpf_seccomp_filter.Po \
+	./$(DEPDIR)/libstrace_a-bpf_sock_filter.Po \
+	./$(DEPDIR)/libstrace_a-btrfs.Po \
+	./$(DEPDIR)/libstrace_a-cacheflush.Po \
+	./$(DEPDIR)/libstrace_a-capability.Po \
+	./$(DEPDIR)/libstrace_a-chdir.Po \
+	./$(DEPDIR)/libstrace_a-chmod.Po \
+	./$(DEPDIR)/libstrace_a-clone.Po \
+	./$(DEPDIR)/libstrace_a-close_range.Po \
+	./$(DEPDIR)/libstrace_a-copy_file_range.Po \
+	./$(DEPDIR)/libstrace_a-count.Po \
+	./$(DEPDIR)/libstrace_a-delay.Po \
+	./$(DEPDIR)/libstrace_a-desc.Po \
+	./$(DEPDIR)/libstrace_a-dirent.Po \
+	./$(DEPDIR)/libstrace_a-dirent64.Po \
+	./$(DEPDIR)/libstrace_a-dirent_types.Po \
+	./$(DEPDIR)/libstrace_a-dm.Po ./$(DEPDIR)/libstrace_a-dup.Po \
+	./$(DEPDIR)/libstrace_a-dyxlat.Po \
+	./$(DEPDIR)/libstrace_a-epoll.Po \
+	./$(DEPDIR)/libstrace_a-error_prints.Po \
+	./$(DEPDIR)/libstrace_a-evdev.Po \
+	./$(DEPDIR)/libstrace_a-evdev_mpers.Po \
+	./$(DEPDIR)/libstrace_a-eventfd.Po \
+	./$(DEPDIR)/libstrace_a-execve.Po \
+	./$(DEPDIR)/libstrace_a-fadvise.Po \
+	./$(DEPDIR)/libstrace_a-fallocate.Po \
+	./$(DEPDIR)/libstrace_a-fanotify.Po \
+	./$(DEPDIR)/libstrace_a-fchownat.Po \
+	./$(DEPDIR)/libstrace_a-fcntl.Po \
+	./$(DEPDIR)/libstrace_a-fetch_bpf_fprog.Po \
 	./$(DEPDIR)/libstrace_a-fetch_indirect_syscall_args.Po \
+	./$(DEPDIR)/libstrace_a-fetch_struct_flock.Po \
+	./$(DEPDIR)/libstrace_a-fetch_struct_keyctl_kdf_params.Po \
+	./$(DEPDIR)/libstrace_a-fetch_struct_mmsghdr.Po \
+	./$(DEPDIR)/libstrace_a-fetch_struct_msghdr.Po \
+	./$(DEPDIR)/libstrace_a-fetch_struct_stat.Po \
+	./$(DEPDIR)/libstrace_a-fetch_struct_stat64.Po \
+	./$(DEPDIR)/libstrace_a-fetch_struct_statfs.Po \
+	./$(DEPDIR)/libstrace_a-fetch_struct_xfs_quotastat.Po \
+	./$(DEPDIR)/libstrace_a-file_handle.Po \
+	./$(DEPDIR)/libstrace_a-file_ioctl.Po \
+	./$(DEPDIR)/libstrace_a-filter_qualify.Po \
+	./$(DEPDIR)/libstrace_a-filter_seccomp.Po \
+	./$(DEPDIR)/libstrace_a-flock.Po \
+	./$(DEPDIR)/libstrace_a-fs_x_ioctl.Po \
+	./$(DEPDIR)/libstrace_a-fsconfig.Po \
+	./$(DEPDIR)/libstrace_a-fsmount.Po \
+	./$(DEPDIR)/libstrace_a-fsopen.Po \
+	./$(DEPDIR)/libstrace_a-fspick.Po \
 	./$(DEPDIR)/libstrace_a-fstatfs.Po \
 	./$(DEPDIR)/libstrace_a-fstatfs64.Po \
+	./$(DEPDIR)/libstrace_a-futex.Po \
+	./$(DEPDIR)/libstrace_a-get_personality.Po \
+	./$(DEPDIR)/libstrace_a-get_robust_list.Po \
+	./$(DEPDIR)/libstrace_a-getcpu.Po \
+	./$(DEPDIR)/libstrace_a-getcwd.Po \
 	./$(DEPDIR)/libstrace_a-getpagesize.Po \
+	./$(DEPDIR)/libstrace_a-getpid.Po \
+	./$(DEPDIR)/libstrace_a-getrandom.Po \
+	./$(DEPDIR)/libstrace_a-hdio.Po \
+	./$(DEPDIR)/libstrace_a-hostname.Po \
+	./$(DEPDIR)/libstrace_a-inotify.Po \
+	./$(DEPDIR)/libstrace_a-inotify_ioctl.Po \
+	./$(DEPDIR)/libstrace_a-io.Po \
+	./$(DEPDIR)/libstrace_a-io_uring.Po \
+	./$(DEPDIR)/libstrace_a-ioctl.Po \
+	./$(DEPDIR)/libstrace_a-ioperm.Po \
+	./$(DEPDIR)/libstrace_a-iopl.Po \
+	./$(DEPDIR)/libstrace_a-ioprio.Po \
 	./$(DEPDIR)/libstrace_a-ipc.Po \
+	./$(DEPDIR)/libstrace_a-ipc_msg.Po \
+	./$(DEPDIR)/libstrace_a-ipc_msgctl.Po \
+	./$(DEPDIR)/libstrace_a-ipc_sem.Po \
+	./$(DEPDIR)/libstrace_a-ipc_semctl.Po \
+	./$(DEPDIR)/libstrace_a-ipc_shm.Po \
+	./$(DEPDIR)/libstrace_a-ipc_shmctl.Po \
+	./$(DEPDIR)/libstrace_a-kcmp.Po \
+	./$(DEPDIR)/libstrace_a-kexec.Po \
+	./$(DEPDIR)/libstrace_a-keyctl.Po \
+	./$(DEPDIR)/libstrace_a-kvm.Po ./$(DEPDIR)/libstrace_a-ldt.Po \
+	./$(DEPDIR)/libstrace_a-link.Po \
+	./$(DEPDIR)/libstrace_a-listen.Po \
+	./$(DEPDIR)/libstrace_a-lookup_dcookie.Po \
+	./$(DEPDIR)/libstrace_a-loop.Po \
+	./$(DEPDIR)/libstrace_a-lseek.Po \
+	./$(DEPDIR)/libstrace_a-mem.Po \
+	./$(DEPDIR)/libstrace_a-membarrier.Po \
+	./$(DEPDIR)/libstrace_a-memfd_create.Po \
+	./$(DEPDIR)/libstrace_a-mknod.Po \
 	./$(DEPDIR)/libstrace_a-mmap_cache.Po \
+	./$(DEPDIR)/libstrace_a-mmap_notify.Po \
+	./$(DEPDIR)/libstrace_a-mmsghdr.Po \
+	./$(DEPDIR)/libstrace_a-mount.Po \
+	./$(DEPDIR)/libstrace_a-move_mount.Po \
+	./$(DEPDIR)/libstrace_a-mq.Po \
+	./$(DEPDIR)/libstrace_a-msghdr.Po \
+	./$(DEPDIR)/libstrace_a-mtd.Po \
+	./$(DEPDIR)/libstrace_a-nbd_ioctl.Po \
+	./$(DEPDIR)/libstrace_a-net.Po \
+	./$(DEPDIR)/libstrace_a-netlink.Po \
+	./$(DEPDIR)/libstrace_a-netlink_crypto.Po \
+	./$(DEPDIR)/libstrace_a-netlink_inet_diag.Po \
+	./$(DEPDIR)/libstrace_a-netlink_kobject_uevent.Po \
+	./$(DEPDIR)/libstrace_a-netlink_netfilter.Po \
+	./$(DEPDIR)/libstrace_a-netlink_netlink_diag.Po \
+	./$(DEPDIR)/libstrace_a-netlink_packet_diag.Po \
+	./$(DEPDIR)/libstrace_a-netlink_route.Po \
+	./$(DEPDIR)/libstrace_a-netlink_selinux.Po \
+	./$(DEPDIR)/libstrace_a-netlink_smc_diag.Po \
+	./$(DEPDIR)/libstrace_a-netlink_sock_diag.Po \
+	./$(DEPDIR)/libstrace_a-netlink_unix_diag.Po \
+	./$(DEPDIR)/libstrace_a-nlattr.Po \
+	./$(DEPDIR)/libstrace_a-nsfs.Po \
+	./$(DEPDIR)/libstrace_a-numa.Po \
+	./$(DEPDIR)/libstrace_a-number_set.Po \
+	./$(DEPDIR)/libstrace_a-oldstat.Po \
+	./$(DEPDIR)/libstrace_a-open.Po \
+	./$(DEPDIR)/libstrace_a-open_tree.Po \
+	./$(DEPDIR)/libstrace_a-or1k_atomic.Po \
+	./$(DEPDIR)/libstrace_a-pathtrace.Po \
+	./$(DEPDIR)/libstrace_a-perf.Po \
+	./$(DEPDIR)/libstrace_a-perf_ioctl.Po \
+	./$(DEPDIR)/libstrace_a-personality.Po \
+	./$(DEPDIR)/libstrace_a-pidfd_getfd.Po \
+	./$(DEPDIR)/libstrace_a-pidfd_open.Po \
+	./$(DEPDIR)/libstrace_a-pidns.Po \
+	./$(DEPDIR)/libstrace_a-pkeys.Po \
+	./$(DEPDIR)/libstrace_a-poll.Po \
+	./$(DEPDIR)/libstrace_a-prctl.Po \
+	./$(DEPDIR)/libstrace_a-print_aio_sigset.Po \
+	./$(DEPDIR)/libstrace_a-print_dev_t.Po \
+	./$(DEPDIR)/libstrace_a-print_group_req.Po \
+	./$(DEPDIR)/libstrace_a-print_ifindex.Po \
+	./$(DEPDIR)/libstrace_a-print_instruction_pointer.Po \
+	./$(DEPDIR)/libstrace_a-print_kernel_version.Po \
+	./$(DEPDIR)/libstrace_a-print_mac.Po \
+	./$(DEPDIR)/libstrace_a-print_mq_attr.Po \
+	./$(DEPDIR)/libstrace_a-print_msgbuf.Po \
+	./$(DEPDIR)/libstrace_a-print_sg_req_info.Po \
+	./$(DEPDIR)/libstrace_a-print_sigevent.Po \
+	./$(DEPDIR)/libstrace_a-print_statfs.Po \
+	./$(DEPDIR)/libstrace_a-print_struct_stat.Po \
+	./$(DEPDIR)/libstrace_a-print_syscall_number.Po \
+	./$(DEPDIR)/libstrace_a-print_time.Po \
+	./$(DEPDIR)/libstrace_a-print_timespec32.Po \
+	./$(DEPDIR)/libstrace_a-print_timespec64.Po \
+	./$(DEPDIR)/libstrace_a-print_timeval.Po \
+	./$(DEPDIR)/libstrace_a-print_timeval64.Po \
+	./$(DEPDIR)/libstrace_a-print_timex.Po \
+	./$(DEPDIR)/libstrace_a-printmode.Po \
+	./$(DEPDIR)/libstrace_a-printrusage.Po \
+	./$(DEPDIR)/libstrace_a-printsiginfo.Po \
+	./$(DEPDIR)/libstrace_a-process.Po \
+	./$(DEPDIR)/libstrace_a-process_vm.Po \
+	./$(DEPDIR)/libstrace_a-ptp.Po \
+	./$(DEPDIR)/libstrace_a-ptrace_syscall_info.Po \
+	./$(DEPDIR)/libstrace_a-quota.Po \
+	./$(DEPDIR)/libstrace_a-random_ioctl.Po \
+	./$(DEPDIR)/libstrace_a-readahead.Po \
+	./$(DEPDIR)/libstrace_a-readlink.Po \
+	./$(DEPDIR)/libstrace_a-reboot.Po \
+	./$(DEPDIR)/libstrace_a-renameat.Po \
+	./$(DEPDIR)/libstrace_a-resource.Po \
+	./$(DEPDIR)/libstrace_a-retval.Po \
+	./$(DEPDIR)/libstrace_a-riscv.Po \
+	./$(DEPDIR)/libstrace_a-rt_sigframe.Po \
+	./$(DEPDIR)/libstrace_a-rt_sigreturn.Po \
+	./$(DEPDIR)/libstrace_a-rtc.Po \
+	./$(DEPDIR)/libstrace_a-rtnl_addr.Po \
+	./$(DEPDIR)/libstrace_a-rtnl_addrlabel.Po \
+	./$(DEPDIR)/libstrace_a-rtnl_dcb.Po \
+	./$(DEPDIR)/libstrace_a-rtnl_link.Po \
+	./$(DEPDIR)/libstrace_a-rtnl_mdb.Po \
+	./$(DEPDIR)/libstrace_a-rtnl_neigh.Po \
+	./$(DEPDIR)/libstrace_a-rtnl_neightbl.Po \
+	./$(DEPDIR)/libstrace_a-rtnl_netconf.Po \
+	./$(DEPDIR)/libstrace_a-rtnl_nsid.Po \
+	./$(DEPDIR)/libstrace_a-rtnl_route.Po \
+	./$(DEPDIR)/libstrace_a-rtnl_rule.Po \
+	./$(DEPDIR)/libstrace_a-rtnl_tc.Po \
+	./$(DEPDIR)/libstrace_a-rtnl_tc_action.Po \
+	./$(DEPDIR)/libstrace_a-s390.Po \
+	./$(DEPDIR)/libstrace_a-sched.Po \
+	./$(DEPDIR)/libstrace_a-scsi.Po \
+	./$(DEPDIR)/libstrace_a-seccomp.Po \
+	./$(DEPDIR)/libstrace_a-sendfile.Po \
+	./$(DEPDIR)/libstrace_a-sg_io_v3.Po \
+	./$(DEPDIR)/libstrace_a-sg_io_v4.Po \
+	./$(DEPDIR)/libstrace_a-shutdown.Po \
+	./$(DEPDIR)/libstrace_a-sigaltstack.Po \
+	./$(DEPDIR)/libstrace_a-signal.Po \
+	./$(DEPDIR)/libstrace_a-signalfd.Po \
 	./$(DEPDIR)/libstrace_a-sigreturn.Po \
+	./$(DEPDIR)/libstrace_a-sock.Po \
+	./$(DEPDIR)/libstrace_a-sockaddr.Po \
 	./$(DEPDIR)/libstrace_a-socketcall.Po \
+	./$(DEPDIR)/libstrace_a-socketutils.Po \
+	./$(DEPDIR)/libstrace_a-sparc.Po \
+	./$(DEPDIR)/libstrace_a-sram_alloc.Po \
+	./$(DEPDIR)/libstrace_a-stage_output.Po \
+	./$(DEPDIR)/libstrace_a-stat.Po \
+	./$(DEPDIR)/libstrace_a-stat64.Po \
 	./$(DEPDIR)/libstrace_a-statfs.Po \
 	./$(DEPDIR)/libstrace_a-statfs64.Po \
+	./$(DEPDIR)/libstrace_a-statx.Po \
+	./$(DEPDIR)/libstrace_a-string_to_uint.Po \
+	./$(DEPDIR)/libstrace_a-swapon.Po \
 	./$(DEPDIR)/libstrace_a-sync_file_range.Po \
 	./$(DEPDIR)/libstrace_a-sync_file_range2.Po \
+	./$(DEPDIR)/libstrace_a-syscall.Po \
+	./$(DEPDIR)/libstrace_a-sysctl.Po \
+	./$(DEPDIR)/libstrace_a-sysinfo.Po \
+	./$(DEPDIR)/libstrace_a-syslog.Po \
+	./$(DEPDIR)/libstrace_a-sysmips.Po \
+	./$(DEPDIR)/libstrace_a-tee.Po ./$(DEPDIR)/libstrace_a-term.Po \
+	./$(DEPDIR)/libstrace_a-time.Po \
+	./$(DEPDIR)/libstrace_a-times.Po \
+	./$(DEPDIR)/libstrace_a-trie.Po \
+	./$(DEPDIR)/libstrace_a-truncate.Po \
+	./$(DEPDIR)/libstrace_a-ubi.Po \
+	./$(DEPDIR)/libstrace_a-ucopy.Po \
+	./$(DEPDIR)/libstrace_a-uid.Po \
+	./$(DEPDIR)/libstrace_a-uid16.Po \
+	./$(DEPDIR)/libstrace_a-umask.Po \
+	./$(DEPDIR)/libstrace_a-umount.Po \
+	./$(DEPDIR)/libstrace_a-uname.Po \
+	./$(DEPDIR)/libstrace_a-unwind-libdw.Po \
+	./$(DEPDIR)/libstrace_a-unwind-libunwind.Po \
+	./$(DEPDIR)/libstrace_a-unwind.Po \
 	./$(DEPDIR)/libstrace_a-upeek.Po \
-	./$(DEPDIR)/libstrace_a-upoke.Po ./$(DEPDIR)/strace-access.Po \
-	./$(DEPDIR)/strace-affinity.Po ./$(DEPDIR)/strace-aio.Po \
-	./$(DEPDIR)/strace-alpha.Po \
-	./$(DEPDIR)/strace-basic_filters.Po ./$(DEPDIR)/strace-bind.Po \
-	./$(DEPDIR)/strace-bjm.Po ./$(DEPDIR)/strace-block.Po \
-	./$(DEPDIR)/strace-bpf.Po ./$(DEPDIR)/strace-bpf_attr_check.Po \
-	./$(DEPDIR)/strace-bpf_filter.Po \
-	./$(DEPDIR)/strace-bpf_seccomp_filter.Po \
-	./$(DEPDIR)/strace-bpf_sock_filter.Po \
-	./$(DEPDIR)/strace-btrfs.Po ./$(DEPDIR)/strace-cacheflush.Po \
-	./$(DEPDIR)/strace-capability.Po ./$(DEPDIR)/strace-chdir.Po \
-	./$(DEPDIR)/strace-chmod.Po ./$(DEPDIR)/strace-clone.Po \
-	./$(DEPDIR)/strace-copy_file_range.Po \
-	./$(DEPDIR)/strace-count.Po ./$(DEPDIR)/strace-delay.Po \
-	./$(DEPDIR)/strace-desc.Po ./$(DEPDIR)/strace-dirent.Po \
-	./$(DEPDIR)/strace-dirent64.Po ./$(DEPDIR)/strace-dm.Po \
-	./$(DEPDIR)/strace-dyxlat.Po ./$(DEPDIR)/strace-epoll.Po \
-	./$(DEPDIR)/strace-error_prints.Po ./$(DEPDIR)/strace-evdev.Po \
-	./$(DEPDIR)/strace-evdev_mpers.Po \
-	./$(DEPDIR)/strace-eventfd.Po ./$(DEPDIR)/strace-execve.Po \
-	./$(DEPDIR)/strace-fadvise.Po ./$(DEPDIR)/strace-fallocate.Po \
-	./$(DEPDIR)/strace-fanotify.Po ./$(DEPDIR)/strace-fchownat.Po \
-	./$(DEPDIR)/strace-fcntl.Po \
-	./$(DEPDIR)/strace-fetch_bpf_fprog.Po \
-	./$(DEPDIR)/strace-fetch_struct_flock.Po \
-	./$(DEPDIR)/strace-fetch_struct_keyctl_kdf_params.Po \
-	./$(DEPDIR)/strace-fetch_struct_mmsghdr.Po \
-	./$(DEPDIR)/strace-fetch_struct_msghdr.Po \
-	./$(DEPDIR)/strace-fetch_struct_stat.Po \
-	./$(DEPDIR)/strace-fetch_struct_stat64.Po \
-	./$(DEPDIR)/strace-fetch_struct_statfs.Po \
-	./$(DEPDIR)/strace-fetch_struct_xfs_quotastat.Po \
-	./$(DEPDIR)/strace-file_handle.Po \
-	./$(DEPDIR)/strace-file_ioctl.Po \
-	./$(DEPDIR)/strace-filter_qualify.Po \
-	./$(DEPDIR)/strace-filter_seccomp.Po \
-	./$(DEPDIR)/strace-flock.Po ./$(DEPDIR)/strace-fs_x_ioctl.Po \
-	./$(DEPDIR)/strace-fsconfig.Po ./$(DEPDIR)/strace-fsmount.Po \
-	./$(DEPDIR)/strace-fsopen.Po ./$(DEPDIR)/strace-fspick.Po \
-	./$(DEPDIR)/strace-futex.Po \
-	./$(DEPDIR)/strace-get_personality.Po \
-	./$(DEPDIR)/strace-get_robust_list.Po \
-	./$(DEPDIR)/strace-getcpu.Po ./$(DEPDIR)/strace-getcwd.Po \
-	./$(DEPDIR)/strace-getrandom.Po ./$(DEPDIR)/strace-hdio.Po \
-	./$(DEPDIR)/strace-hostname.Po ./$(DEPDIR)/strace-inotify.Po \
-	./$(DEPDIR)/strace-inotify_ioctl.Po ./$(DEPDIR)/strace-io.Po \
-	./$(DEPDIR)/strace-io_uring.Po ./$(DEPDIR)/strace-ioctl.Po \
-	./$(DEPDIR)/strace-ioperm.Po ./$(DEPDIR)/strace-iopl.Po \
-	./$(DEPDIR)/strace-ioprio.Po ./$(DEPDIR)/strace-ipc_msg.Po \
-	./$(DEPDIR)/strace-ipc_msgctl.Po ./$(DEPDIR)/strace-ipc_sem.Po \
-	./$(DEPDIR)/strace-ipc_shm.Po ./$(DEPDIR)/strace-ipc_shmctl.Po \
-	./$(DEPDIR)/strace-kcmp.Po ./$(DEPDIR)/strace-kexec.Po \
-	./$(DEPDIR)/strace-keyctl.Po ./$(DEPDIR)/strace-kvm.Po \
-	./$(DEPDIR)/strace-ldt.Po ./$(DEPDIR)/strace-link.Po \
-	./$(DEPDIR)/strace-listen.Po \
-	./$(DEPDIR)/strace-lookup_dcookie.Po \
-	./$(DEPDIR)/strace-loop.Po ./$(DEPDIR)/strace-lseek.Po \
-	./$(DEPDIR)/strace-mem.Po ./$(DEPDIR)/strace-membarrier.Po \
-	./$(DEPDIR)/strace-memfd_create.Po ./$(DEPDIR)/strace-mknod.Po \
-	./$(DEPDIR)/strace-mmap_notify.Po \
-	./$(DEPDIR)/strace-mmsghdr.Po ./$(DEPDIR)/strace-mount.Po \
-	./$(DEPDIR)/strace-move_mount.Po ./$(DEPDIR)/strace-mq.Po \
-	./$(DEPDIR)/strace-msghdr.Po ./$(DEPDIR)/strace-mtd.Po \
-	./$(DEPDIR)/strace-nbd_ioctl.Po ./$(DEPDIR)/strace-net.Po \
-	./$(DEPDIR)/strace-netlink.Po \
-	./$(DEPDIR)/strace-netlink_crypto.Po \
-	./$(DEPDIR)/strace-netlink_inet_diag.Po \
-	./$(DEPDIR)/strace-netlink_kobject_uevent.Po \
-	./$(DEPDIR)/strace-netlink_netfilter.Po \
-	./$(DEPDIR)/strace-netlink_netlink_diag.Po \
-	./$(DEPDIR)/strace-netlink_packet_diag.Po \
-	./$(DEPDIR)/strace-netlink_route.Po \
-	./$(DEPDIR)/strace-netlink_selinux.Po \
-	./$(DEPDIR)/strace-netlink_smc_diag.Po \
-	./$(DEPDIR)/strace-netlink_sock_diag.Po \
-	./$(DEPDIR)/strace-netlink_unix_diag.Po \
-	./$(DEPDIR)/strace-nlattr.Po ./$(DEPDIR)/strace-nsfs.Po \
-	./$(DEPDIR)/strace-numa.Po ./$(DEPDIR)/strace-number_set.Po \
-	./$(DEPDIR)/strace-oldstat.Po ./$(DEPDIR)/strace-open.Po \
-	./$(DEPDIR)/strace-open_tree.Po \
-	./$(DEPDIR)/strace-or1k_atomic.Po \
-	./$(DEPDIR)/strace-pathtrace.Po ./$(DEPDIR)/strace-perf.Po \
-	./$(DEPDIR)/strace-perf_ioctl.Po \
-	./$(DEPDIR)/strace-personality.Po \
-	./$(DEPDIR)/strace-pidfd_open.Po ./$(DEPDIR)/strace-pkeys.Po \
-	./$(DEPDIR)/strace-poll.Po ./$(DEPDIR)/strace-prctl.Po \
-	./$(DEPDIR)/strace-print_aio_sigset.Po \
-	./$(DEPDIR)/strace-print_dev_t.Po \
-	./$(DEPDIR)/strace-print_group_req.Po \
-	./$(DEPDIR)/strace-print_ifindex.Po \
-	./$(DEPDIR)/strace-print_instruction_pointer.Po \
-	./$(DEPDIR)/strace-print_kernel_version.Po \
-	./$(DEPDIR)/strace-print_mac.Po \
-	./$(DEPDIR)/strace-print_mq_attr.Po \
-	./$(DEPDIR)/strace-print_msgbuf.Po \
-	./$(DEPDIR)/strace-print_sg_req_info.Po \
-	./$(DEPDIR)/strace-print_sigevent.Po \
-	./$(DEPDIR)/strace-print_statfs.Po \
-	./$(DEPDIR)/strace-print_struct_stat.Po \
-	./$(DEPDIR)/strace-print_time.Po \
-	./$(DEPDIR)/strace-print_timespec.Po \
-	./$(DEPDIR)/strace-print_timespec32.Po \
-	./$(DEPDIR)/strace-print_timespec64.Po \
-	./$(DEPDIR)/strace-print_timeval.Po \
-	./$(DEPDIR)/strace-print_timeval64.Po \
-	./$(DEPDIR)/strace-print_timex.Po \
-	./$(DEPDIR)/strace-printmode.Po \
-	./$(DEPDIR)/strace-printrusage.Po \
-	./$(DEPDIR)/strace-printsiginfo.Po \
-	./$(DEPDIR)/strace-process.Po ./$(DEPDIR)/strace-process_vm.Po \
-	./$(DEPDIR)/strace-ptp.Po \
-	./$(DEPDIR)/strace-ptrace_syscall_info.Po \
-	./$(DEPDIR)/strace-quota.Po ./$(DEPDIR)/strace-random_ioctl.Po \
-	./$(DEPDIR)/strace-readahead.Po ./$(DEPDIR)/strace-readlink.Po \
-	./$(DEPDIR)/strace-reboot.Po ./$(DEPDIR)/strace-renameat.Po \
-	./$(DEPDIR)/strace-resource.Po ./$(DEPDIR)/strace-retval.Po \
-	./$(DEPDIR)/strace-riscv.Po ./$(DEPDIR)/strace-rt_sigframe.Po \
-	./$(DEPDIR)/strace-rt_sigreturn.Po ./$(DEPDIR)/strace-rtc.Po \
-	./$(DEPDIR)/strace-rtnl_addr.Po \
-	./$(DEPDIR)/strace-rtnl_addrlabel.Po \
-	./$(DEPDIR)/strace-rtnl_dcb.Po ./$(DEPDIR)/strace-rtnl_link.Po \
-	./$(DEPDIR)/strace-rtnl_mdb.Po \
-	./$(DEPDIR)/strace-rtnl_neigh.Po \
-	./$(DEPDIR)/strace-rtnl_neightbl.Po \
-	./$(DEPDIR)/strace-rtnl_netconf.Po \
-	./$(DEPDIR)/strace-rtnl_nsid.Po \
-	./$(DEPDIR)/strace-rtnl_route.Po \
-	./$(DEPDIR)/strace-rtnl_rule.Po ./$(DEPDIR)/strace-rtnl_tc.Po \
-	./$(DEPDIR)/strace-rtnl_tc_action.Po \
-	./$(DEPDIR)/strace-s390.Po ./$(DEPDIR)/strace-sched.Po \
-	./$(DEPDIR)/strace-scsi.Po ./$(DEPDIR)/strace-seccomp.Po \
-	./$(DEPDIR)/strace-sendfile.Po ./$(DEPDIR)/strace-sg_io_v3.Po \
-	./$(DEPDIR)/strace-sg_io_v4.Po ./$(DEPDIR)/strace-shutdown.Po \
-	./$(DEPDIR)/strace-sigaltstack.Po ./$(DEPDIR)/strace-signal.Po \
-	./$(DEPDIR)/strace-signalfd.Po ./$(DEPDIR)/strace-sock.Po \
-	./$(DEPDIR)/strace-sockaddr.Po \
-	./$(DEPDIR)/strace-socketutils.Po ./$(DEPDIR)/strace-sparc.Po \
-	./$(DEPDIR)/strace-sram_alloc.Po \
-	./$(DEPDIR)/strace-stage_output.Po ./$(DEPDIR)/strace-stat.Po \
-	./$(DEPDIR)/strace-stat64.Po ./$(DEPDIR)/strace-statfs.Po \
-	./$(DEPDIR)/strace-statx.Po ./$(DEPDIR)/strace-strace.Po \
-	./$(DEPDIR)/strace-string_to_uint.Po \
-	./$(DEPDIR)/strace-swapon.Po ./$(DEPDIR)/strace-syscall.Po \
-	./$(DEPDIR)/strace-sysctl.Po ./$(DEPDIR)/strace-sysinfo.Po \
-	./$(DEPDIR)/strace-syslog.Po ./$(DEPDIR)/strace-sysmips.Po \
-	./$(DEPDIR)/strace-term.Po ./$(DEPDIR)/strace-time.Po \
-	./$(DEPDIR)/strace-times.Po ./$(DEPDIR)/strace-truncate.Po \
-	./$(DEPDIR)/strace-ubi.Po ./$(DEPDIR)/strace-ucopy.Po \
-	./$(DEPDIR)/strace-uid.Po ./$(DEPDIR)/strace-uid16.Po \
-	./$(DEPDIR)/strace-umask.Po ./$(DEPDIR)/strace-umount.Po \
-	./$(DEPDIR)/strace-uname.Po ./$(DEPDIR)/strace-unwind-libdw.Po \
-	./$(DEPDIR)/strace-unwind-libunwind.Po \
-	./$(DEPDIR)/strace-unwind.Po ./$(DEPDIR)/strace-userfaultfd.Po \
-	./$(DEPDIR)/strace-ustat.Po ./$(DEPDIR)/strace-util.Po \
-	./$(DEPDIR)/strace-utime.Po ./$(DEPDIR)/strace-utimes.Po \
-	./$(DEPDIR)/strace-v4l2.Po ./$(DEPDIR)/strace-wait.Po \
-	./$(DEPDIR)/strace-watchdog_ioctl.Po \
-	./$(DEPDIR)/strace-xattr.Po ./$(DEPDIR)/strace-xlat.Po \
-	./$(DEPDIR)/strace-xmalloc.Po \
-	types/$(DEPDIR)/strace-check-cryptouser.Po \
-	types/$(DEPDIR)/strace-check-evdev.Po \
-	types/$(DEPDIR)/strace-check-io_uring.Po \
-	types/$(DEPDIR)/strace-check-rtnl_link.Po \
-	types/$(DEPDIR)/strace-check-rtnl_mdb.Po \
-	types/$(DEPDIR)/strace-check-rtnl_neightbl.Po \
-	types/$(DEPDIR)/strace-check-rtnl_route.Po
+	./$(DEPDIR)/libstrace_a-upoke.Po \
+	./$(DEPDIR)/libstrace_a-userfaultfd.Po \
+	./$(DEPDIR)/libstrace_a-ustat.Po \
+	./$(DEPDIR)/libstrace_a-util.Po \
+	./$(DEPDIR)/libstrace_a-utime.Po \
+	./$(DEPDIR)/libstrace_a-utimes.Po \
+	./$(DEPDIR)/libstrace_a-v4l2.Po \
+	./$(DEPDIR)/libstrace_a-wait.Po \
+	./$(DEPDIR)/libstrace_a-watchdog_ioctl.Po \
+	./$(DEPDIR)/libstrace_a-xattr.Po \
+	./$(DEPDIR)/libstrace_a-xgetdents.Po \
+	./$(DEPDIR)/libstrace_a-xlat.Po \
+	./$(DEPDIR)/libstrace_a-xmalloc.Po \
+	./$(DEPDIR)/strace-strace.Po \
+	types/$(DEPDIR)/libstrace_a-check-btrfs.Po \
+	types/$(DEPDIR)/libstrace_a-check-cryptouser.Po \
+	types/$(DEPDIR)/libstrace_a-check-evdev.Po \
+	types/$(DEPDIR)/libstrace_a-check-io_uring.Po \
+	types/$(DEPDIR)/libstrace_a-check-loop.Po \
+	types/$(DEPDIR)/libstrace_a-check-openat2.Po \
+	types/$(DEPDIR)/libstrace_a-check-rtnl_link.Po \
+	types/$(DEPDIR)/libstrace_a-check-rtnl_mdb.Po \
+	types/$(DEPDIR)/libstrace_a-check-rtnl_neightbl.Po \
+	types/$(DEPDIR)/libstrace_a-check-rtnl_route.Po \
+	types/$(DEPDIR)/libstrace_a-check-tee.Po \
+	types/$(DEPDIR)/libstrace_a-check-v4l2.Po
 am__mv = mv -f
 AM_V_lt = $(am__v_lt_@AM_V@)
 am__v_lt_ = $(am__v_lt_@AM_DEFAULT_V@)
@@ -841,8 +1008,8 @@ am__v_CCLD_1 =
 SOURCES = $(libmpers_m32_a_SOURCES) $(libmpers_mx32_a_SOURCES) \
 	$(libstrace_a_SOURCES) $(strace_SOURCES)
 DIST_SOURCES = $(am__libmpers_m32_a_SOURCES_DIST) \
-	$(am__libmpers_mx32_a_SOURCES_DIST) $(libstrace_a_SOURCES) \
-	$(am__strace_SOURCES_DIST)
+	$(am__libmpers_mx32_a_SOURCES_DIST) \
+	$(am__libstrace_a_SOURCES_DIST) $(strace_SOURCES)
 RECURSIVE_TARGETS = all-recursive check-recursive cscopelist-recursive \
 	ctags-recursive dvi-recursive html-recursive info-recursive \
 	install-data-recursive install-dvi-recursive \
@@ -871,8 +1038,8 @@ am__extra_recursive_targets = check-valg
 	check-valgrind-memcheck-recursive \
 	check-valgrind-helgrind-recursive check-valgrind-drd-recursive \
 	check-valgrind-sgcheck-recursive
-am__tagged_files = $(HEADERS) $(SOURCES) $(TAGS_FILES) \
-	$(LISP)config.h.in
+am__tagged_files = $(HEADERS) $(SOURCES) $(TAGS_FILES) $(LISP) \
+	config.h.in
 # Read a list of newline-separated strings from the standard input,
 # and print each of them once, without duplicates.  Input order is
 # *not* preserved.
@@ -898,8 +1065,8 @@ am__DIST_COMMON = $(srcdir)/Makefile.in
 	$(srcdir)/strace-log-merge.1.in $(srcdir)/strace.1.in \
 	$(srcdir)/strace.spec.in $(srcdir)/types/Makemodule.am \
 	$(srcdir)/xlat/Makemodule.am $(top_srcdir)/debian/changelog.in \
-	AUTHORS COPYING INSTALL NEWS README compile config.guess \
-	config.sub depcomp install-sh missing
+	AUTHORS COPYING INSTALL NEWS README ar-lib compile \
+	config.guess config.sub depcomp install-sh missing
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
 distdir = $(PACKAGE)-$(VERSION)
 top_distdir = $(distdir)
@@ -938,6 +1105,8 @@ am__relativize = \
 DIST_ARCHIVES = $(distdir).tar.gz $(distdir).tar.xz
 GZIP_ENV = --best
 DIST_TARGETS = dist-xz dist-gzip
+# Exists only to be overridden by the user if desired.
+AM_DISTCHECK_DVI_TARGET = dvi
 distuninstallcheck_listfiles = find . -type f -print
 am__distuninstallcheck_listfiles = $(distuninstallcheck_listfiles) \
   | sed 's|^\./|$(prefix)/|' | grep -v '$(infodir)/dir$$'
@@ -945,6 +1114,7 @@ distcleancheck_listfiles = find . -type
 ACLOCAL = @ACLOCAL@
 AMTAR = @AMTAR@
 AM_DEFAULT_VERBOSITY = @AM_DEFAULT_VERBOSITY@
+AR = @AR@
 AUTOCONF = @AUTOCONF@
 AUTOHEADER = @AUTOHEADER@
 AUTOMAKE = @AUTOMAKE@
@@ -1016,7 +1186,6 @@ PACKAGE_TARNAME = @PACKAGE_TARNAME@
 PACKAGE_URL = @PACKAGE_URL@
 PACKAGE_VERSION = @PACKAGE_VERSION@
 PATH_SEPARATOR = @PATH_SEPARATOR@
-PERL = @PERL@
 RANLIB = @RANLIB@
 READELF = @READELF@
 RPM_CHANGELOGTIME = @RPM_CHANGELOGTIME@
@@ -1035,6 +1204,7 @@ abs_builddir = @abs_builddir@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CC_FOR_BUILD = @ac_ct_CC_FOR_BUILD@
 am__include = @am__include@
@@ -1112,7 +1282,7 @@ bin_SCRIPTS = strace-graph strace-log-me
 OS = linux
 # ARCH is `i386', `m68k', `sparc', etc.
 ARCH = @arch@
-ACLOCAL_AMFLAGS = -I m4 -I types
+ACLOCAL_AMFLAGS = -I m4 -I types -I xlat
 AM_CFLAGS = $(WARN_CFLAGS)
 AM_CPPFLAGS = -I$(builddir)/$(OS)/$(ARCH) \
 	      -I$(srcdir)/$(OS)/$(ARCH) \
@@ -1123,10 +1293,9 @@ AM_CPPFLAGS = -I$(builddir)/$(OS)/$(ARCH
 
 AM_CFLAGS_FOR_BUILD = $(WARN_CFLAGS_FOR_BUILD)
 AM_CPPFLAGS_FOR_BUILD = $(AM_CPPFLAGS)
-TYPES_HEADER_FILES = types/cryptouser.h types/evdev.h types/io_uring.h types/rtnl_link.h types/rtnl_mdb.h types/rtnl_neightbl.h types/rtnl_route.h 
-TYPES_CHECK_FILES = types/check-cryptouser.c types/check-evdev.c types/check-io_uring.c types/check-rtnl_link.c types/check-rtnl_mdb.c types/check-rtnl_neightbl.c types/check-rtnl_route.c 
-TYPES_M4_FILES = types/check-cryptouser.m4 types/check-evdev.m4 types/check-io_uring.m4 types/check-rtnl_link.m4 types/check-rtnl_mdb.m4 types/check-rtnl_neightbl.m4 types/check-rtnl_route.m4 
-XLAT_INPUT_FILES = xlat/access_flags.in xlat/addrfams.in \
+TYPES_HEADER_FILES = types/btrfs.h types/cryptouser.h types/evdev.h types/io_uring.h types/loop.h types/openat2.h types/rtnl_link.h types/rtnl_mdb.h types/rtnl_neightbl.h types/rtnl_route.h types/tee.h types/v4l2.h 
+TYPES_CHECK_FILES = types/check-btrfs.c types/check-cryptouser.c types/check-evdev.c types/check-io_uring.c types/check-loop.c types/check-openat2.c types/check-rtnl_link.c types/check-rtnl_mdb.c types/check-rtnl_neightbl.c types/check-rtnl_route.c types/check-tee.c types/check-v4l2.c 
+XLAT_INPUT_FILES = xlat/access_modes.in xlat/addrfams.in \
 	xlat/adjtimex_modes.in xlat/adjtimex_state.in \
 	xlat/adjtimex_status.in xlat/advise.in xlat/af_packet_types.in \
 	xlat/af_packet_versions.in xlat/aio_cmds.in \
@@ -1168,7 +1337,8 @@ XLAT_INPUT_FILES = xlat/access_flags.in
 	xlat/caif_protocols.in xlat/can_protocols.in xlat/cap.in \
 	xlat/cap_mask0.in xlat/cap_mask1.in xlat/cap_version.in \
 	xlat/clockflags.in xlat/clocknames.in xlat/clone3_flags.in \
-	xlat/clone_flags.in xlat/cpuclocknames.in xlat/crypto_msgs.in \
+	xlat/clone_flags.in xlat/close_range_flags.in \
+	xlat/cpuclocknames.in xlat/crypto_msgs.in \
 	xlat/crypto_nl_attrs.in xlat/dcb_commands.in \
 	xlat/delete_module_flags.in xlat/dirent_types.in \
 	xlat/dm_flags.in xlat/ebpf_class.in xlat/ebpf_mode.in \
@@ -1182,32 +1352,33 @@ XLAT_INPUT_FILES = xlat/access_flags.in
 	xlat/evdev_leds.in xlat/evdev_misc.in xlat/evdev_mtslots.in \
 	xlat/evdev_prop.in xlat/evdev_relative_axes.in \
 	xlat/evdev_snd.in xlat/evdev_switch.in xlat/f_owner_types.in \
-	xlat/f_seals.in xlat/falloc_flags.in xlat/fan_classes.in \
-	xlat/fan_event_flags.in xlat/fan_init_flags.in \
-	xlat/fan_mark_flags.in xlat/fcntlcmds.in xlat/fdflags.in \
-	xlat/fib_rule_actions.in xlat/fib_rule_flags.in \
-	xlat/fiemap_extent_flags.in xlat/fiemap_flags.in \
-	xlat/flockcmds.in xlat/fsconfig_cmds.in xlat/fsmagic.in \
-	xlat/fsmount_flags.in xlat/fsopen_flags.in \
+	xlat/f_seals.in xlat/faccessat_flags.in xlat/falloc_flags.in \
+	xlat/fan_classes.in xlat/fan_event_flags.in \
+	xlat/fan_init_flags.in xlat/fan_mark_flags.in \
+	xlat/fcntlcmds.in xlat/fdflags.in xlat/fib_rule_actions.in \
+	xlat/fib_rule_flags.in xlat/fiemap_extent_flags.in \
+	xlat/fiemap_flags.in xlat/flockcmds.in xlat/fsconfig_cmds.in \
+	xlat/fsmagic.in xlat/fsmount_flags.in xlat/fsopen_flags.in \
 	xlat/fspick_flags.in xlat/futexbitset.in xlat/futexops.in \
 	xlat/futexwakecmps.in xlat/futexwakeops.in \
 	xlat/get_mempolicy_flags.in xlat/getrandom_flags.in \
 	xlat/getsock_ip_options.in xlat/getsock_ipv6_options.in \
 	xlat/getsock_options.in xlat/hci_channels.in \
-	xlat/hw_breakpoint_len.in xlat/hw_breakpoint_type.in \
-	xlat/icmpfilterflags.in xlat/if_dqblk_valid.in \
-	xlat/if_dqinfo_flags.in xlat/if_dqinfo_valid.in \
-	xlat/ifaddrflags.in xlat/iffflags.in xlat/in6_addr_gen_mode.in \
-	xlat/inet6_devconf_indices.in xlat/inet6_if_flags.in \
-	xlat/inet_devconf_indices.in xlat/inet_diag_attrs.in \
-	xlat/inet_diag_bytecodes.in xlat/inet_diag_extended_flags.in \
-	xlat/inet_diag_req_attrs.in xlat/inet_protocols.in \
-	xlat/inotify_flags.in xlat/inotify_init_flags.in \
-	xlat/ioctl_dirs.in xlat/ioprio_class.in xlat/ioprio_who.in \
-	xlat/ip_cmsg_types.in xlat/ip_type_of_services.in \
-	xlat/ipc_msg_flags.in xlat/ipc_private.in xlat/ipccalls.in \
-	xlat/irda_protocols.in xlat/isdn_protocols.in \
-	xlat/itimer_which.in xlat/kcm_protocols.in xlat/kcmp_types.in \
+	xlat/hdio_drive_cmds.in xlat/hw_breakpoint_len.in \
+	xlat/hw_breakpoint_type.in xlat/icmpfilterflags.in \
+	xlat/if_dqblk_valid.in xlat/if_dqinfo_flags.in \
+	xlat/if_dqinfo_valid.in xlat/ifaddrflags.in xlat/iffflags.in \
+	xlat/in6_addr_gen_mode.in xlat/inet6_devconf_indices.in \
+	xlat/inet6_if_flags.in xlat/inet_devconf_indices.in \
+	xlat/inet_diag_attrs.in xlat/inet_diag_bytecodes.in \
+	xlat/inet_diag_extended_flags.in xlat/inet_diag_req_attrs.in \
+	xlat/inet_protocols.in xlat/inotify_flags.in \
+	xlat/inotify_init_flags.in xlat/ioctl_dirs.in \
+	xlat/ioprio_class.in xlat/ioprio_who.in xlat/ip_cmsg_types.in \
+	xlat/ip_type_of_services.in xlat/ipc_msg_flags.in \
+	xlat/ipc_private.in xlat/ipccalls.in xlat/irda_protocols.in \
+	xlat/isdn_protocols.in xlat/itimer_which.in \
+	xlat/kcm_protocols.in xlat/kcmp_types.in \
 	xlat/kexec_arch_values.in xlat/kexec_file_load_flags.in \
 	xlat/kexec_load_flags.in xlat/key_perms.in xlat/key_reqkeys.in \
 	xlat/key_spec.in xlat/keyctl_caps0.in xlat/keyctl_caps1.in \
@@ -1254,11 +1425,12 @@ XLAT_INPUT_FILES = xlat/access_flags.in
 	xlat/nl_xfrm_types.in xlat/nlmsgerr_attrs.in \
 	xlat/notifyflags.in xlat/nt_descriptor_types.in \
 	xlat/numa_node.in xlat/open_access_modes.in \
-	xlat/open_mode_flags.in xlat/open_tree_flags.in \
-	xlat/packet_diag_attrs.in xlat/packet_diag_info_flags.in \
-	xlat/packet_diag_show.in xlat/packet_mreq_type.in \
-	xlat/perf_attr_size.in xlat/perf_branch_sample_type.in \
-	xlat/perf_event_open_flags.in xlat/perf_event_read_format.in \
+	xlat/open_mode_flags.in xlat/open_resolve_flags.in \
+	xlat/open_tree_flags.in xlat/packet_diag_attrs.in \
+	xlat/packet_diag_info_flags.in xlat/packet_diag_show.in \
+	xlat/packet_mreq_type.in xlat/perf_attr_size.in \
+	xlat/perf_branch_sample_type.in xlat/perf_event_open_flags.in \
+	xlat/perf_event_read_format.in \
 	xlat/perf_event_sample_format.in xlat/perf_hw_cache_id.in \
 	xlat/perf_hw_cache_op_id.in xlat/perf_hw_cache_op_result_id.in \
 	xlat/perf_hw_id.in xlat/perf_ioctl_cmds.in \
@@ -1281,7 +1453,8 @@ XLAT_INPUT_FILES = xlat/access_flags.in
 	xlat/riscv_flush_icache_flags.in xlat/route_nexthop_flags.in \
 	xlat/routing_flags.in xlat/routing_protocols.in \
 	xlat/routing_scopes.in xlat/routing_table_ids.in \
-	xlat/routing_types.in xlat/rtnl_addr_attrs.in \
+	xlat/routing_types.in xlat/rtc_ioctl_cmds.in \
+	xlat/rtc_vl_flags.in xlat/rtnl_addr_attrs.in \
 	xlat/rtnl_addrlabel_attrs.in xlat/rtnl_dcb_attrs.in \
 	xlat/rtnl_ifla_af_spec_inet6_attrs.in \
 	xlat/rtnl_ifla_af_spec_inet_attrs.in \
@@ -1302,8 +1475,9 @@ XLAT_INPUT_FILES = xlat/access_flags.in
 	xlat/rtnl_route_attrs.in xlat/rtnl_rta_metrics_attrs.in \
 	xlat/rtnl_rule_attrs.in xlat/rtnl_tc_action_attrs.in \
 	xlat/rtnl_tc_attrs.in xlat/rtnl_tca_act_flags.in \
-	xlat/rtnl_tca_stab_attrs.in xlat/rtnl_tca_stats_attrs.in \
-	xlat/rwf_flags.in xlat/s390_guarded_storage_commands.in \
+	xlat/rtnl_tca_act_hw_stats.in xlat/rtnl_tca_stab_attrs.in \
+	xlat/rtnl_tca_stats_attrs.in xlat/rwf_flags.in \
+	xlat/s390_guarded_storage_commands.in \
 	xlat/s390_runtime_instr_commands.in \
 	xlat/s390_sthyi_function_codes.in xlat/sa_handler_values.in \
 	xlat/sched_flags.in xlat/schedulers.in xlat/scmvals.in \
@@ -1356,34 +1530,44 @@ XLAT_INPUT_FILES = xlat/access_flags.in
 	xlat/syslog_action_type.in xlat/syslog_console_levels.in \
 	xlat/sysmips_operations.in xlat/tcflsh_options.in \
 	xlat/tcp_state_flags.in xlat/tcp_states.in \
-	xlat/tcxonc_options.in xlat/timerfdflags.in \
-	xlat/tun_device_types.in xlat/ubi_volume_props.in \
-	xlat/ubi_volume_types.in xlat/uffd_api_features.in \
-	xlat/uffd_api_flags.in xlat/uffd_copy_flags.in \
-	xlat/uffd_flags.in xlat/uffd_register_ioctl_flags.in \
+	xlat/tcxonc_options.in xlat/tee_ioctl_cmds.in \
+	xlat/tee_ioctl_gen_caps.in xlat/tee_ioctl_impl_ids.in \
+	xlat/tee_ioctl_login_types.in xlat/tee_ioctl_max_arg_size.in \
+	xlat/tee_ioctl_optee_caps.in xlat/tee_ioctl_origins.in \
+	xlat/tee_ioctl_param_attr_types.in xlat/tee_ioctl_shm_flags.in \
+	xlat/timerfdflags.in xlat/tun_device_types.in \
+	xlat/ubi_volume_props.in xlat/ubi_volume_types.in \
+	xlat/uffd_api_features.in xlat/uffd_api_flags.in \
+	xlat/uffd_copy_flags.in xlat/uffd_flags.in \
+	xlat/uffd_register_ioctl_flags.in \
 	xlat/uffd_register_mode_flags.in xlat/uffd_zeropage_flags.in \
 	xlat/umount_flags.in xlat/unix_diag_attrs.in \
 	xlat/unix_diag_show.in xlat/unshare_flags.in \
-	xlat/uring_enter_flags.in xlat/uring_register_opcodes.in \
-	xlat/uring_setup_features.in xlat/uring_setup_flags.in \
-	xlat/usagewho.in xlat/v4l2_buf_flags.in xlat/v4l2_buf_types.in \
-	xlat/v4l2_capture_modes.in xlat/v4l2_colorspaces.in \
-	xlat/v4l2_control_classes.in xlat/v4l2_control_flags.in \
-	xlat/v4l2_control_id_bases.in xlat/v4l2_control_ids.in \
+	xlat/uring_cqring_flags.in xlat/uring_enter_flags.in \
+	xlat/uring_op_flags.in xlat/uring_ops.in \
+	xlat/uring_register_opcodes.in xlat/uring_setup_features.in \
+	xlat/uring_setup_flags.in xlat/usagewho.in \
+	xlat/v4l2_buf_flags.in xlat/v4l2_buf_flags_masks.in \
+	xlat/v4l2_buf_flags_ts_src.in xlat/v4l2_buf_flags_ts_type.in \
+	xlat/v4l2_buf_types.in xlat/v4l2_capture_modes.in \
+	xlat/v4l2_colorspaces.in xlat/v4l2_control_classes.in \
+	xlat/v4l2_control_flags.in xlat/v4l2_control_id_bases.in \
+	xlat/v4l2_control_ids.in xlat/v4l2_control_query_flags.in \
 	xlat/v4l2_control_types.in \
 	xlat/v4l2_device_capabilities_flags.in xlat/v4l2_fields.in \
 	xlat/v4l2_format_description_flags.in \
 	xlat/v4l2_frameinterval_types.in xlat/v4l2_framesize_types.in \
-	xlat/v4l2_input_types.in xlat/v4l2_memories.in \
-	xlat/v4l2_pix_fmts.in xlat/v4l2_sdr_fmts.in \
-	xlat/v4l2_sliced_flags.in xlat/v4l2_streaming_capabilities.in \
+	xlat/v4l2_input_types.in xlat/v4l2_ioctl_cmds.in \
+	xlat/v4l2_memories.in xlat/v4l2_pix_fmts.in \
+	xlat/v4l2_sdr_fmts.in xlat/v4l2_sliced_flags.in \
+	xlat/v4l2_streaming_capabilities.in \
 	xlat/v4l2_tuner_audmodes.in xlat/v4l2_tuner_capabilities.in \
 	xlat/v4l2_tuner_rxsubchanses.in xlat/v4l2_tuner_types.in \
 	xlat/v4l2_vbi_flags.in xlat/wait4_options.in \
 	xlat/waitid_types.in xlat/watchdog_ioctl_cmds.in \
 	xlat/whence_codes.in xlat/xattrflags.in xlat/xdp_flags.in \
 	xlat/xfs_dqblk_flags.in xlat/xfs_quota_flags.in
-XLAT_HEADER_FILES = xlat/access_flags.h xlat/addrfams.h \
+XLAT_HEADER_FILES = xlat/access_modes.h xlat/addrfams.h \
 	xlat/adjtimex_modes.h xlat/adjtimex_state.h \
 	xlat/adjtimex_status.h xlat/advise.h xlat/af_packet_types.h \
 	xlat/af_packet_versions.h xlat/aio_cmds.h \
@@ -1423,22 +1607,24 @@ XLAT_HEADER_FILES = xlat/access_flags.h
 	xlat/caif_protocols.h xlat/can_protocols.h xlat/cap.h \
 	xlat/cap_mask0.h xlat/cap_mask1.h xlat/cap_version.h \
 	xlat/clockflags.h xlat/clocknames.h xlat/clone3_flags.h \
-	xlat/clone_flags.h xlat/cpuclocknames.h xlat/crypto_msgs.h \
-	xlat/crypto_nl_attrs.h xlat/dcb_commands.h \
-	xlat/delete_module_flags.h xlat/dirent_types.h xlat/dm_flags.h \
-	xlat/ebpf_class.h xlat/ebpf_mode.h xlat/ebpf_op_alu.h \
-	xlat/ebpf_op_jmp.h xlat/ebpf_regs.h xlat/ebpf_size.h \
-	xlat/efd_flags.h xlat/elf_em.h xlat/epollctls.h \
-	xlat/epollevents.h xlat/epollflags.h xlat/ethernet_protocols.h \
-	xlat/evdev_abs.h xlat/evdev_autorepeat.h xlat/evdev_ev.h \
-	xlat/evdev_ff_status.h xlat/evdev_ff_types.h \
-	xlat/evdev_ioctl_cmds.h xlat/evdev_keycode.h xlat/evdev_leds.h \
-	xlat/evdev_misc.h xlat/evdev_mtslots.h xlat/evdev_prop.h \
+	xlat/clone_flags.h xlat/close_range_flags.h \
+	xlat/cpuclocknames.h xlat/crypto_msgs.h xlat/crypto_nl_attrs.h \
+	xlat/dcb_commands.h xlat/delete_module_flags.h \
+	xlat/dirent_types.h xlat/dm_flags.h xlat/ebpf_class.h \
+	xlat/ebpf_mode.h xlat/ebpf_op_alu.h xlat/ebpf_op_jmp.h \
+	xlat/ebpf_regs.h xlat/ebpf_size.h xlat/efd_flags.h \
+	xlat/elf_em.h xlat/epollctls.h xlat/epollevents.h \
+	xlat/epollflags.h xlat/ethernet_protocols.h xlat/evdev_abs.h \
+	xlat/evdev_autorepeat.h xlat/evdev_ev.h xlat/evdev_ff_status.h \
+	xlat/evdev_ff_types.h xlat/evdev_ioctl_cmds.h \
+	xlat/evdev_keycode.h xlat/evdev_leds.h xlat/evdev_misc.h \
+	xlat/evdev_mtslots.h xlat/evdev_prop.h \
 	xlat/evdev_relative_axes.h xlat/evdev_snd.h \
 	xlat/evdev_switch.h xlat/f_owner_types.h xlat/f_seals.h \
-	xlat/falloc_flags.h xlat/fan_classes.h xlat/fan_event_flags.h \
-	xlat/fan_init_flags.h xlat/fan_mark_flags.h xlat/fcntlcmds.h \
-	xlat/fdflags.h xlat/fib_rule_actions.h xlat/fib_rule_flags.h \
+	xlat/faccessat_flags.h xlat/falloc_flags.h xlat/fan_classes.h \
+	xlat/fan_event_flags.h xlat/fan_init_flags.h \
+	xlat/fan_mark_flags.h xlat/fcntlcmds.h xlat/fdflags.h \
+	xlat/fib_rule_actions.h xlat/fib_rule_flags.h \
 	xlat/fiemap_extent_flags.h xlat/fiemap_flags.h \
 	xlat/flockcmds.h xlat/fsconfig_cmds.h xlat/fsmagic.h \
 	xlat/fsmount_flags.h xlat/fsopen_flags.h xlat/fspick_flags.h \
@@ -1446,31 +1632,31 @@ XLAT_HEADER_FILES = xlat/access_flags.h
 	xlat/futexwakeops.h xlat/get_mempolicy_flags.h \
 	xlat/getrandom_flags.h xlat/getsock_ip_options.h \
 	xlat/getsock_ipv6_options.h xlat/getsock_options.h \
-	xlat/hci_channels.h xlat/hw_breakpoint_len.h \
-	xlat/hw_breakpoint_type.h xlat/icmpfilterflags.h \
-	xlat/if_dqblk_valid.h xlat/if_dqinfo_flags.h \
-	xlat/if_dqinfo_valid.h xlat/ifaddrflags.h xlat/iffflags.h \
-	xlat/in6_addr_gen_mode.h xlat/inet6_devconf_indices.h \
-	xlat/inet6_if_flags.h xlat/inet_devconf_indices.h \
-	xlat/inet_diag_attrs.h xlat/inet_diag_bytecodes.h \
-	xlat/inet_diag_extended_flags.h xlat/inet_diag_req_attrs.h \
-	xlat/inet_protocols.h xlat/inotify_flags.h \
-	xlat/inotify_init_flags.h xlat/ioctl_dirs.h \
-	xlat/ioprio_class.h xlat/ioprio_who.h xlat/ip_cmsg_types.h \
-	xlat/ip_type_of_services.h xlat/ipc_msg_flags.h \
-	xlat/ipc_private.h xlat/ipccalls.h xlat/irda_protocols.h \
-	xlat/isdn_protocols.h xlat/itimer_which.h xlat/kcm_protocols.h \
-	xlat/kcmp_types.h xlat/kexec_arch_values.h \
-	xlat/kexec_file_load_flags.h xlat/kexec_load_flags.h \
-	xlat/key_perms.h xlat/key_reqkeys.h xlat/key_spec.h \
-	xlat/keyctl_caps0.h xlat/keyctl_caps1.h xlat/keyctl_commands.h \
-	xlat/keyctl_move_flags.h xlat/keyctl_pkey_ops.h xlat/kvm_cap.h \
-	xlat/kvm_cpuid_flags.h xlat/kvm_exit_reason.h \
-	xlat/kvm_mem_flags.h xlat/lockfcmds.h xlat/loop_cmds.h \
-	xlat/loop_crypt_type_options.h xlat/loop_flags_options.h \
-	xlat/lwtunnel_encap_types.h xlat/madvise_cmds.h \
-	xlat/mbind_flags.h xlat/mctl_sync.h xlat/mdb_flags.h \
-	xlat/mdb_states.h xlat/membarrier_cmds.h \
+	xlat/hci_channels.h xlat/hdio_drive_cmds.h \
+	xlat/hw_breakpoint_len.h xlat/hw_breakpoint_type.h \
+	xlat/icmpfilterflags.h xlat/if_dqblk_valid.h \
+	xlat/if_dqinfo_flags.h xlat/if_dqinfo_valid.h \
+	xlat/ifaddrflags.h xlat/iffflags.h xlat/in6_addr_gen_mode.h \
+	xlat/inet6_devconf_indices.h xlat/inet6_if_flags.h \
+	xlat/inet_devconf_indices.h xlat/inet_diag_attrs.h \
+	xlat/inet_diag_bytecodes.h xlat/inet_diag_extended_flags.h \
+	xlat/inet_diag_req_attrs.h xlat/inet_protocols.h \
+	xlat/inotify_flags.h xlat/inotify_init_flags.h \
+	xlat/ioctl_dirs.h xlat/ioprio_class.h xlat/ioprio_who.h \
+	xlat/ip_cmsg_types.h xlat/ip_type_of_services.h \
+	xlat/ipc_msg_flags.h xlat/ipc_private.h xlat/ipccalls.h \
+	xlat/irda_protocols.h xlat/isdn_protocols.h \
+	xlat/itimer_which.h xlat/kcm_protocols.h xlat/kcmp_types.h \
+	xlat/kexec_arch_values.h xlat/kexec_file_load_flags.h \
+	xlat/kexec_load_flags.h xlat/key_perms.h xlat/key_reqkeys.h \
+	xlat/key_spec.h xlat/keyctl_caps0.h xlat/keyctl_caps1.h \
+	xlat/keyctl_commands.h xlat/keyctl_move_flags.h \
+	xlat/keyctl_pkey_ops.h xlat/kvm_cap.h xlat/kvm_cpuid_flags.h \
+	xlat/kvm_exit_reason.h xlat/kvm_mem_flags.h xlat/lockfcmds.h \
+	xlat/loop_cmds.h xlat/loop_crypt_type_options.h \
+	xlat/loop_flags_options.h xlat/lwtunnel_encap_types.h \
+	xlat/madvise_cmds.h xlat/mbind_flags.h xlat/mctl_sync.h \
+	xlat/mdb_flags.h xlat/mdb_states.h xlat/membarrier_cmds.h \
 	xlat/memfd_create_flags.h xlat/mlock_flags.h \
 	xlat/mlockall_flags.h xlat/mmap_flags.h xlat/mmap_prot.h \
 	xlat/modem_flags.h xlat/modetypes.h xlat/module_init_flags.h \
@@ -1504,15 +1690,15 @@ XLAT_HEADER_FILES = xlat/access_flags.h
 	xlat/nl_xfrm_types.h xlat/nlmsgerr_attrs.h xlat/notifyflags.h \
 	xlat/nt_descriptor_types.h xlat/numa_node.h \
 	xlat/open_access_modes.h xlat/open_mode_flags.h \
-	xlat/open_tree_flags.h xlat/packet_diag_attrs.h \
-	xlat/packet_diag_info_flags.h xlat/packet_diag_show.h \
-	xlat/packet_mreq_type.h xlat/perf_attr_size.h \
-	xlat/perf_branch_sample_type.h xlat/perf_event_open_flags.h \
-	xlat/perf_event_read_format.h xlat/perf_event_sample_format.h \
-	xlat/perf_hw_cache_id.h xlat/perf_hw_cache_op_id.h \
-	xlat/perf_hw_cache_op_result_id.h xlat/perf_hw_id.h \
-	xlat/perf_ioctl_cmds.h xlat/perf_ioctl_flags.h \
-	xlat/perf_sw_ids.h xlat/perf_type_id.h \
+	xlat/open_resolve_flags.h xlat/open_tree_flags.h \
+	xlat/packet_diag_attrs.h xlat/packet_diag_info_flags.h \
+	xlat/packet_diag_show.h xlat/packet_mreq_type.h \
+	xlat/perf_attr_size.h xlat/perf_branch_sample_type.h \
+	xlat/perf_event_open_flags.h xlat/perf_event_read_format.h \
+	xlat/perf_event_sample_format.h xlat/perf_hw_cache_id.h \
+	xlat/perf_hw_cache_op_id.h xlat/perf_hw_cache_op_result_id.h \
+	xlat/perf_hw_id.h xlat/perf_ioctl_cmds.h \
+	xlat/perf_ioctl_flags.h xlat/perf_sw_ids.h xlat/perf_type_id.h \
 	xlat/personality_flags.h xlat/personality_types.h \
 	xlat/phonet_protocols.h xlat/pkey_access.h xlat/pollflags.h \
 	xlat/pr_cap_ambient.h xlat/pr_dumpable.h xlat/pr_fp_mode.h \
@@ -1530,9 +1716,9 @@ XLAT_HEADER_FILES = xlat/access_flags.h
 	xlat/riscv_flush_icache_flags.h xlat/route_nexthop_flags.h \
 	xlat/routing_flags.h xlat/routing_protocols.h \
 	xlat/routing_scopes.h xlat/routing_table_ids.h \
-	xlat/routing_types.h xlat/rtnl_addr_attrs.h \
-	xlat/rtnl_addrlabel_attrs.h xlat/rtnl_dcb_attrs.h \
-	xlat/rtnl_ifla_af_spec_inet6_attrs.h \
+	xlat/routing_types.h xlat/rtc_ioctl_cmds.h xlat/rtc_vl_flags.h \
+	xlat/rtnl_addr_attrs.h xlat/rtnl_addrlabel_attrs.h \
+	xlat/rtnl_dcb_attrs.h xlat/rtnl_ifla_af_spec_inet6_attrs.h \
 	xlat/rtnl_ifla_af_spec_inet_attrs.h \
 	xlat/rtnl_ifla_brport_attrs.h xlat/rtnl_ifla_events.h \
 	xlat/rtnl_ifla_info_attrs.h \
@@ -1549,8 +1735,9 @@ XLAT_HEADER_FILES = xlat/access_flags.h
 	xlat/rtnl_route_attrs.h xlat/rtnl_rta_metrics_attrs.h \
 	xlat/rtnl_rule_attrs.h xlat/rtnl_tc_action_attrs.h \
 	xlat/rtnl_tc_attrs.h xlat/rtnl_tca_act_flags.h \
-	xlat/rtnl_tca_stab_attrs.h xlat/rtnl_tca_stats_attrs.h \
-	xlat/rwf_flags.h xlat/s390_guarded_storage_commands.h \
+	xlat/rtnl_tca_act_hw_stats.h xlat/rtnl_tca_stab_attrs.h \
+	xlat/rtnl_tca_stats_attrs.h xlat/rwf_flags.h \
+	xlat/s390_guarded_storage_commands.h \
 	xlat/s390_runtime_instr_commands.h \
 	xlat/s390_sthyi_function_codes.h xlat/sa_handler_values.h \
 	xlat/sched_flags.h xlat/schedulers.h xlat/scmvals.h \
@@ -1600,26 +1787,34 @@ XLAT_HEADER_FILES = xlat/access_flags.h
 	xlat/sysctl_root.h xlat/sysctl_vm.h xlat/syslog_action_type.h \
 	xlat/syslog_console_levels.h xlat/sysmips_operations.h \
 	xlat/tcflsh_options.h xlat/tcp_state_flags.h xlat/tcp_states.h \
-	xlat/tcxonc_options.h xlat/timerfdflags.h \
-	xlat/tun_device_types.h xlat/ubi_volume_props.h \
-	xlat/ubi_volume_types.h xlat/uffd_api_features.h \
-	xlat/uffd_api_flags.h xlat/uffd_copy_flags.h xlat/uffd_flags.h \
+	xlat/tcxonc_options.h xlat/tee_ioctl_cmds.h \
+	xlat/tee_ioctl_gen_caps.h xlat/tee_ioctl_impl_ids.h \
+	xlat/tee_ioctl_login_types.h xlat/tee_ioctl_max_arg_size.h \
+	xlat/tee_ioctl_optee_caps.h xlat/tee_ioctl_origins.h \
+	xlat/tee_ioctl_param_attr_types.h xlat/tee_ioctl_shm_flags.h \
+	xlat/timerfdflags.h xlat/tun_device_types.h \
+	xlat/ubi_volume_props.h xlat/ubi_volume_types.h \
+	xlat/uffd_api_features.h xlat/uffd_api_flags.h \
+	xlat/uffd_copy_flags.h xlat/uffd_flags.h \
 	xlat/uffd_register_ioctl_flags.h \
 	xlat/uffd_register_mode_flags.h xlat/uffd_zeropage_flags.h \
 	xlat/umount_flags.h xlat/unix_diag_attrs.h \
 	xlat/unix_diag_show.h xlat/unshare_flags.h \
-	xlat/uring_enter_flags.h xlat/uring_register_opcodes.h \
-	xlat/uring_setup_features.h xlat/uring_setup_flags.h \
-	xlat/usagewho.h xlat/v4l2_buf_flags.h xlat/v4l2_buf_types.h \
+	xlat/uring_cqring_flags.h xlat/uring_enter_flags.h \
+	xlat/uring_op_flags.h xlat/uring_ops.h \
+	xlat/uring_register_opcodes.h xlat/uring_setup_features.h \
+	xlat/uring_setup_flags.h xlat/usagewho.h xlat/v4l2_buf_flags.h \
+	xlat/v4l2_buf_flags_masks.h xlat/v4l2_buf_flags_ts_src.h \
+	xlat/v4l2_buf_flags_ts_type.h xlat/v4l2_buf_types.h \
 	xlat/v4l2_capture_modes.h xlat/v4l2_colorspaces.h \
 	xlat/v4l2_control_classes.h xlat/v4l2_control_flags.h \
 	xlat/v4l2_control_id_bases.h xlat/v4l2_control_ids.h \
-	xlat/v4l2_control_types.h \
+	xlat/v4l2_control_query_flags.h xlat/v4l2_control_types.h \
 	xlat/v4l2_device_capabilities_flags.h xlat/v4l2_fields.h \
 	xlat/v4l2_format_description_flags.h \
 	xlat/v4l2_frameinterval_types.h xlat/v4l2_framesize_types.h \
-	xlat/v4l2_input_types.h xlat/v4l2_memories.h \
-	xlat/v4l2_pix_fmts.h xlat/v4l2_sdr_fmts.h \
+	xlat/v4l2_input_types.h xlat/v4l2_ioctl_cmds.h \
+	xlat/v4l2_memories.h xlat/v4l2_pix_fmts.h xlat/v4l2_sdr_fmts.h \
 	xlat/v4l2_sliced_flags.h xlat/v4l2_streaming_capabilities.h \
 	xlat/v4l2_tuner_audmodes.h xlat/v4l2_tuner_capabilities.h \
 	xlat/v4l2_tuner_rxsubchanses.h xlat/v4l2_tuner_types.h \
@@ -1634,75 +1829,62 @@ strace_LDFLAGS = $(am__append_5) $(am__a
 strace_LDADD = libstrace.a $(clock_LIBS) $(timer_LIBS) $(am__append_6) \
 	$(am__append_10) $(am__append_13) $(CODE_COVERAGE_LIBS) \
 	$(am__append_14) $(am__append_18)
+strace_SOURCES = strace.c
 noinst_LIBRARIES = libstrace.a $(am__append_15) $(am__append_19)
 libstrace_a_CPPFLAGS = $(strace_CPPFLAGS)
 libstrace_a_CFLAGS = $(strace_CFLAGS)
-libstrace_a_SOURCES = \
-	fetch_indirect_syscall_args.c \
-	fstatfs.c \
-	fstatfs64.c \
-	getpagesize.c \
-	ipc.c \
-	mmap_cache.c	\
-	mmap_cache.h	\
-	sigreturn.c	\
-	socketcall.c \
-	statfs.c \
-	statfs64.c \
-	sync_file_range.c \
-	sync_file_range2.c \
-	upeek.c		\
-	upoke.c		\
-	# end of libstrace_a_SOURCES
-
-strace_SOURCES = access.c affinity.c aio.c alpha.c arch_defs.h \
+libstrace_a_SOURCES = access.c affinity.c aio.c alpha.c arch_defs.h \
 	basic_filters.c bind.c bjm.c block.c bpf.c bpf_attr.h \
 	bpf_filter.c bpf_filter.h bpf_fprog.h bpf_seccomp_filter.c \
 	bpf_sock_filter.c btrfs.c cacheflush.c capability.c caps0.h \
-	caps1.h chdir.c chmod.c clone.c copy_file_range.c count.c \
-	defs.h delay.c delay.h desc.c dirent.c dirent64.c dm.c \
-	dyxlat.c empty.h epoll.c error_prints.c error_prints.h evdev.c \
-	evdev_mpers.c eventfd.c execve.c f_owner_ex.h fadvise.c \
-	fallocate.c fanotify.c fchownat.c fcntl.c fetch_bpf_fprog.c \
-	fetch_struct_flock.c fetch_struct_keyctl_kdf_params.c \
-	fetch_struct_mmsghdr.c fetch_struct_msghdr.c \
-	fetch_struct_stat.c fetch_struct_stat64.c \
-	fetch_struct_statfs.c fetch_struct_xfs_quotastat.c \
-	file_handle.c file_ioctl.c filter.h filter_qualify.c \
-	filter_seccomp.c filter_seccomp.h flock.c flock.h fs_x_ioctl.c \
-	fsconfig.c fsmount.c fsopen.c fspick.c futex.c gcc_compat.h \
+	caps1.h chdir.c chmod.c clone.c close_range.c \
+	copy_file_range.c count.c defs.h delay.c delay.h desc.c \
+	dirent.c dirent64.c dirent_types.c dm.c dup.c dyxlat.c empty.h \
+	epoll.c error_prints.c error_prints.h evdev.c evdev_mpers.c \
+	eventfd.c execve.c f_owner_ex.h fadvise.c fallocate.c \
+	fanotify.c fchownat.c fcntl.c fetch_bpf_fprog.c \
+	fetch_indirect_syscall_args.c fetch_struct_flock.c \
+	fetch_struct_keyctl_kdf_params.c fetch_struct_mmsghdr.c \
+	fetch_struct_msghdr.c fetch_struct_stat.c \
+	fetch_struct_stat64.c fetch_struct_statfs.c \
+	fetch_struct_xfs_quotastat.c file_handle.c file_ioctl.c \
+	filter.h filter_qualify.c filter_seccomp.c filter_seccomp.h \
+	flock.c flock.h fs_x_ioctl.c fsconfig.c fsmount.c fsopen.c \
+	fspick.c fstatfs.c fstatfs64.c futex.c gcc_compat.h \
 	get_personality.c get_personality.h get_robust_list.c getcpu.c \
-	getcwd.c getrandom.c hdio.c hostname.c inotify.c \
-	inotify_ioctl.c io.c io_uring.c ioctl.c ioperm.c iopl.c \
-	ioprio.c ipc_defs.h ipc_msg.c ipc_msgctl.c ipc_sem.c ipc_shm.c \
-	ipc_shmctl.c kcmp.c kernel_timespec.h kernel_timeval.h \
-	kernel_timex.h kernel_types.h kexec.c keyctl.c \
-	keyctl_kdf_params.h kill_save_errno.h kvm.c \
-	largefile_wrappers.h ldt.c link.c linux/asm_stat.h \
-	linux/x32/asm_stat.h linux/x86_64/asm_stat.h list.h listen.c \
-	lookup_dcookie.c loop.c lseek.c macros.h mem.c membarrier.c \
-	memfd_create.c mknod.c mmap_notify.c mmap_notify.h mmsghdr.c \
-	mount.c move_mount.c mpers_type.h mq.c msghdr.c msghdr.h mtd.c \
-	native_defs.h nbd_ioctl.c negated_errno.h net.c netlink.c \
-	netlink.h netlink_crypto.c netlink_inet_diag.c \
-	netlink_kobject_uevent.c netlink_kobject_uevent.h \
-	netlink_netfilter.c netlink_netlink_diag.c \
-	netlink_packet_diag.c netlink_route.c netlink_route.h \
-	netlink_selinux.c netlink_smc_diag.c netlink_sock_diag.c \
-	netlink_sock_diag.h netlink_unix_diag.c nlattr.c nlattr.h \
-	nsfs.c nsfs.h nsig.h numa.c number_set.c number_set.h \
-	oldstat.c open.c open_tree.c or1k_atomic.c pathtrace.c perf.c \
-	perf_event_struct.h perf_ioctl.c personality.c pidfd_open.c \
-	pkeys.c poll.c prctl.c print_aio_sigset.c print_dev_t.c \
-	print_fields.h print_group_req.c print_ifindex.c \
-	print_instruction_pointer.c print_kernel_version.c print_mac.c \
-	print_mq_attr.c print_msgbuf.c print_sg_req_info.c \
-	print_sigevent.c print_statfs.c print_struct_stat.c \
-	print_time.c print_timespec.c print_timespec.h \
-	print_timespec32.c print_timespec64.c print_timeval.c \
-	print_timeval64.c print_timex.c print_timex.h print_utils.h \
-	printmode.c printrusage.c printsiginfo.c printsiginfo.h \
-	process.c process_vm.c ptp.c ptrace.h ptrace_syscall_info.c \
+	getcwd.c getpagesize.c getpid.c getrandom.c hdio.c hostname.c \
+	inotify.c inotify_ioctl.c io.c io_uring.c ioctl.c ioperm.c \
+	iopl.c ioprio.c ipc.c ipc_defs.h ipc_msg.c ipc_msgctl.c \
+	ipc_sem.c ipc_semctl.c ipc_shm.c ipc_shmctl.c kcmp.c \
+	kernel_dirent.h kernel_rusage.h kernel_timespec.h \
+	kernel_timeval.h kernel_timex.h kernel_types.h \
+	kernel_v4l2_types.h kexec.c keyctl.c keyctl_kdf_params.h \
+	kill_save_errno.h kvm.c largefile_wrappers.h ldt.c link.c \
+	linux/asm_stat.h linux/x32/asm_stat.h linux/x86_64/asm_stat.h \
+	list.h listen.c lookup_dcookie.c loop.c lseek.c macros.h mem.c \
+	membarrier.c memfd_create.c mknod.c mmap_cache.c mmap_cache.h \
+	mmap_notify.c mmap_notify.h mmsghdr.c mount.c move_mount.c \
+	mpers_type.h mq.c msghdr.c msghdr.h mtd.c native_defs.h \
+	nbd_ioctl.c negated_errno.h net.c netlink.c netlink.h \
+	netlink_crypto.c netlink_inet_diag.c netlink_kobject_uevent.c \
+	netlink_kobject_uevent.h netlink_netfilter.c \
+	netlink_netlink_diag.c netlink_packet_diag.c netlink_route.c \
+	netlink_route.h netlink_selinux.c netlink_smc_diag.c \
+	netlink_sock_diag.c netlink_sock_diag.h netlink_unix_diag.c \
+	nlattr.c nlattr.h nsfs.c nsfs.h nsig.h numa.c number_set.c \
+	number_set.h oldstat.c open.c open_tree.c or1k_atomic.c \
+	pathtrace.c perf.c perf_event_struct.h perf_ioctl.c \
+	personality.c pidfd_getfd.c pidfd_open.c pidns.c pkeys.c \
+	poll.c prctl.c print_aio_sigset.c print_dev_t.c print_fields.h \
+	print_group_req.c print_ifindex.c print_instruction_pointer.c \
+	print_kernel_version.c print_mac.c print_mq_attr.c \
+	print_msgbuf.c print_sg_req_info.c print_sigevent.c \
+	print_statfs.c print_struct_stat.c print_syscall_number.c \
+	print_time.c print_timespec.h print_timespec32.c \
+	print_timespec64.c print_timeval.c print_timeval64.c \
+	print_timex.c print_timex.h print_utils.h printmode.c \
+	printrusage.c printsiginfo.c printsiginfo.h process.c \
+	process_vm.c ptp.c ptrace.h ptrace_syscall_info.c \
 	ptrace_syscall_info.h quota.c random_ioctl.c readahead.c \
 	readlink.c reboot.c regs.h renameat.c resource.c retval.c \
 	retval.h riscv.c rt_sigframe.c rt_sigreturn.c rtc.c \
@@ -1711,24 +1893,26 @@ strace_SOURCES = access.c affinity.c aio
 	rtnl_route.c rtnl_rule.c rtnl_tc.c rtnl_tc_action.c s390.c \
 	sched.c sched_attr.h scsi.c seccomp.c sendfile.c sg_io_v3.c \
 	sg_io_v4.c shutdown.c sigaltstack.c sigevent.h signal.c \
-	signalfd.c sock.c sockaddr.c socketutils.c sparc.c \
-	sram_alloc.c stage_output.c stat.c stat.h stat64.c statfs.c \
-	statfs.h static_assert.h statx.c statx.h strace.c \
-	string_to_uint.c string_to_uint.h swapon.c syscall.c sysctl.c \
-	sysent.h sysent_shorthand_defs.h sysent_shorthand_undefs.h \
-	sysinfo.c syslog.c sysmips.c term.c time.c times.c \
-	trace_event.h truncate.c ubi.c ucopy.c uid.c uid16.c umask.c \
-	umount.c uname.c userfaultfd.c ustat.c util.c utime.c utimes.c \
-	v4l2.c wait.c wait.h watchdog_ioctl.c xattr.c xfs_quota_stat.h \
-	xlat.c xlat.h xmalloc.c xmalloc.h xstring.h \
-	$(TYPES_HEADER_FILES) $(strace_SOURCES_check) $(am__append_1) \
-	$(am__append_2) $(am__append_7)
+	signalfd.c sigreturn.c sock.c sockaddr.c socketcall.c \
+	socketutils.c sparc.c sram_alloc.c stage_output.c stat.c \
+	stat.h stat64.c statfs.c statfs.c statfs.h statfs64.c \
+	static_assert.h statx.c statx.h string_to_uint.c \
+	string_to_uint.h swapon.c sync_file_range.c sync_file_range2.c \
+	syscall.c sysctl.c sysent.h sysent_shorthand_defs.h \
+	sysent_shorthand_undefs.h sysinfo.c syslog.c sysmips.c tee.c \
+	term.c time.c times.c trace_event.h trie.c trie.h truncate.c \
+	ubi.c ucopy.c uid.c uid16.c umask.c umount.c uname.c upeek.c \
+	upoke.c userfaultfd.c ustat.c util.c utime.c utimes.c v4l2.c \
+	wait.c wait.h watchdog_ioctl.c xattr.c xfs_quota_stat.h \
+	xgetdents.c xgetdents.h xlat.c xlat.h xmalloc.c xmalloc.h \
+	xstring.h $(TYPES_HEADER_FILES) $(strace_SOURCES_check) \
+	$(am__append_1) $(am__append_2) $(am__append_7)
 strace_SOURCES_check = bpf_attr_check.c $(TYPES_CHECK_FILES)
 CODE_COVERAGE_BRANCH_COVERAGE = 1
 CODE_COVERAGE_GENHTML_OPTIONS = $(CODE_COVERAGE_GENHTML_OPTIONS_DEFAULT) \
 	--prefix $(shell cd $(abs_top_srcdir)/.. && pwd || echo .)
 
-CODE_COVERAGE_IGNORE_PATTERN = '/usr/include/*'
+CODE_COVERAGE_IGNORE_PATTERN = '/usr/include/*' '*/tests/*' '*/tests-m32/*' '*/tests-mx32/*'
 
 # Enable this to get link map generated
 #strace_LDFLAGS += -Wl,-Map=strace.mapfile
@@ -1767,6 +1951,7 @@ EXTRA_DIST = \
 	linux/32/ioctls_inc_align16.h	\
 	linux/32/ioctls_inc_align32.h	\
 	linux/32/ioctls_inc_align64.h	\
+	linux/32/syscallent-time32.h	\
 	linux/32/syscallent.h		\
 	linux/64/ioctls_inc.h		\
 	linux/64/syscallent.h		\
@@ -1881,7 +2066,6 @@ EXTRA_DIST = \
 	linux/hppa/get_error.c		\
 	linux/hppa/get_scno.c		\
 	linux/hppa/get_syscall_args.c	\
-	linux/hppa/get_syscall_result.c	\
 	linux/hppa/ioctls_arch0.h	\
 	linux/hppa/ioctls_inc0.h	\
 	linux/hppa/raw_syscall.h	\
@@ -2123,7 +2307,6 @@ EXTRA_DIST = \
 	linux/sh/get_error.c		\
 	linux/sh/get_scno.c		\
 	linux/sh/get_syscall_args.c	\
-	linux/sh/get_syscall_result.c	\
 	linux/sh/ioctls_arch0.h		\
 	linux/sh/ioctls_inc0.h		\
 	linux/sh/raw_syscall.h		\
@@ -2134,11 +2317,9 @@ EXTRA_DIST = \
 	linux/sh/userent0.h		\
 	linux/sh64/arch_defs_.h		\
 	linux/sh64/arch_regs.c		\
-	linux/sh64/arch_regs.h		\
 	linux/sh64/get_error.c		\
 	linux/sh64/get_scno.c		\
 	linux/sh64/get_syscall_args.c	\
-	linux/sh64/get_syscall_result.c	\
 	linux/sh64/ioctls_arch0.h	\
 	linux/sh64/ioctls_inc0.h	\
 	linux/sh64/raw_syscall.h	\
@@ -2274,7 +2455,6 @@ EXTRA_DIST = \
 	linux/xtensa/get_error.c	\
 	linux/xtensa/get_scno.c		\
 	linux/xtensa/get_syscall_args.c	\
-	linux/xtensa/get_syscall_result.c	\
 	linux/xtensa/ioctls_arch0.h	\
 	linux/xtensa/ioctls_inc0.h	\
 	linux/xtensa/raw_syscall.h	\
@@ -2336,7 +2516,7 @@ al_nums = [[:alnum:]_][[:alnum:]_]*
 SCNO_SED = /TRACE_INDIRECT_SUBCALL/d; s/^\[[[:space:]]*\($(digits)\([[:space:]]*+[[:space:]]*$(digits)\)\?\)\][[:space:]]*=[[:space:]]*{[^,]*,[^,]*,[^,]*,[[:space:]]*"\($(al_nums)\)"[[:space:]]*},.*/\#ifndef __NR_\3\n\# define __NR_\3 (SYSCALL_BIT | (\1))\n\#endif/p
 
 # Generated by ./generate_mpers_am.sh; do not edit.
-mpers_source_files = block.c btrfs.c dirent.c evdev_mpers.c fetch_bpf_fprog.c fetch_struct_flock.c fetch_struct_keyctl_kdf_params.c fetch_struct_mmsghdr.c fetch_struct_msghdr.c fetch_struct_stat.c fetch_struct_stat64.c fetch_struct_statfs.c fetch_struct_xfs_quotastat.c hdio.c ipc_msgctl.c ipc_shmctl.c loop.c mtd.c perf_ioctl.c print_aio_sigset.c print_group_req.c print_mq_attr.c print_msgbuf.c print_sg_req_info.c print_sigevent.c print_time.c print_timespec.c print_timeval.c printrusage.c printsiginfo.c rt_sigreturn.c rtc.c sg_io_v3.c sigaltstack.c sock.c sysinfo.c times.c ustat.c utime.c v4l2.c 
+mpers_source_files = block.c btrfs.c dirent.c evdev_mpers.c fetch_bpf_fprog.c fetch_struct_flock.c fetch_struct_keyctl_kdf_params.c fetch_struct_mmsghdr.c fetch_struct_msghdr.c fetch_struct_stat.c fetch_struct_stat64.c fetch_struct_statfs.c fetch_struct_xfs_quotastat.c hdio.c ipc_msgctl.c ipc_semctl.c ipc_shmctl.c loop.c mtd.c perf_ioctl.c print_aio_sigset.c print_group_req.c print_mq_attr.c print_msgbuf.c print_sg_req_info.c print_sigevent.c print_time.c print_timeval.c printrusage.c printsiginfo.c rt_sigreturn.c rtc.c sg_io_v3.c sigaltstack.c sock.c sysinfo.c times.c ustat.c utime.c v4l2.c 
 
 # defines mpers_source_files
 srcdir_mpers_source_files = $(patsubst %,$(srcdir)/%,$(mpers_source_files))
@@ -2476,31 +2656,41 @@ libmpers-mx32.a: $(libmpers_mx32_a_OBJEC
 	$(AM_V_at)-rm -f libmpers-mx32.a
 	$(AM_V_AR)$(libmpers_mx32_a_AR) libmpers-mx32.a $(libmpers_mx32_a_OBJECTS) $(libmpers_mx32_a_LIBADD)
 	$(AM_V_at)$(RANLIB) libmpers-mx32.a
-
-libstrace.a: $(libstrace_a_OBJECTS) $(libstrace_a_DEPENDENCIES) $(EXTRA_libstrace_a_DEPENDENCIES) 
-	$(AM_V_at)-rm -f libstrace.a
-	$(AM_V_AR)$(libstrace_a_AR) libstrace.a $(libstrace_a_OBJECTS) $(libstrace_a_LIBADD)
-	$(AM_V_at)$(RANLIB) libstrace.a
 types/$(am__dirstamp):
 	@$(MKDIR_P) types
 	@: > types/$(am__dirstamp)
 types/$(DEPDIR)/$(am__dirstamp):
 	@$(MKDIR_P) types/$(DEPDIR)
 	@: > types/$(DEPDIR)/$(am__dirstamp)
-types/strace-check-cryptouser.$(OBJEXT): types/$(am__dirstamp) \
+types/libstrace_a-check-btrfs.$(OBJEXT): types/$(am__dirstamp) \
 	types/$(DEPDIR)/$(am__dirstamp)
-types/strace-check-evdev.$(OBJEXT): types/$(am__dirstamp) \
+types/libstrace_a-check-cryptouser.$(OBJEXT): types/$(am__dirstamp) \
 	types/$(DEPDIR)/$(am__dirstamp)
-types/strace-check-io_uring.$(OBJEXT): types/$(am__dirstamp) \
+types/libstrace_a-check-evdev.$(OBJEXT): types/$(am__dirstamp) \
 	types/$(DEPDIR)/$(am__dirstamp)
-types/strace-check-rtnl_link.$(OBJEXT): types/$(am__dirstamp) \
+types/libstrace_a-check-io_uring.$(OBJEXT): types/$(am__dirstamp) \
 	types/$(DEPDIR)/$(am__dirstamp)
-types/strace-check-rtnl_mdb.$(OBJEXT): types/$(am__dirstamp) \
+types/libstrace_a-check-loop.$(OBJEXT): types/$(am__dirstamp) \
 	types/$(DEPDIR)/$(am__dirstamp)
-types/strace-check-rtnl_neightbl.$(OBJEXT): types/$(am__dirstamp) \
+types/libstrace_a-check-openat2.$(OBJEXT): types/$(am__dirstamp) \
 	types/$(DEPDIR)/$(am__dirstamp)
-types/strace-check-rtnl_route.$(OBJEXT): types/$(am__dirstamp) \
+types/libstrace_a-check-rtnl_link.$(OBJEXT): types/$(am__dirstamp) \
 	types/$(DEPDIR)/$(am__dirstamp)
+types/libstrace_a-check-rtnl_mdb.$(OBJEXT): types/$(am__dirstamp) \
+	types/$(DEPDIR)/$(am__dirstamp)
+types/libstrace_a-check-rtnl_neightbl.$(OBJEXT):  \
+	types/$(am__dirstamp) types/$(DEPDIR)/$(am__dirstamp)
+types/libstrace_a-check-rtnl_route.$(OBJEXT): types/$(am__dirstamp) \
+	types/$(DEPDIR)/$(am__dirstamp)
+types/libstrace_a-check-tee.$(OBJEXT): types/$(am__dirstamp) \
+	types/$(DEPDIR)/$(am__dirstamp)
+types/libstrace_a-check-v4l2.$(OBJEXT): types/$(am__dirstamp) \
+	types/$(DEPDIR)/$(am__dirstamp)
+
+libstrace.a: $(libstrace_a_OBJECTS) $(libstrace_a_DEPENDENCIES) $(EXTRA_libstrace_a_DEPENDENCIES) 
+	$(AM_V_at)-rm -f libstrace.a
+	$(AM_V_AR)$(libstrace_a_AR) libstrace.a $(libstrace_a_OBJECTS) $(libstrace_a_LIBADD)
+	$(AM_V_at)$(RANLIB) libstrace.a
 
 strace$(EXEEXT): $(strace_OBJECTS) $(strace_DEPENDENCIES) $(EXTRA_strace_DEPENDENCIES) 
 	@rm -f strace$(EXEEXT)
@@ -2563,6 +2753,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_m32_a-fetch_struct_xfs_quotastat.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_m32_a-hdio.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_m32_a-ipc_msgctl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_m32_a-ipc_semctl.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_m32_a-ipc_shmctl.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_m32_a-loop.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_m32_a-mtd.Po@am__quote@ # am--include-marker
@@ -2574,7 +2765,6 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_m32_a-print_sg_req_info.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_m32_a-print_sigevent.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_m32_a-print_time.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_m32_a-print_timespec.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_m32_a-print_timeval.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_m32_a-printrusage.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_m32_a-printsiginfo.Po@am__quote@ # am--include-marker
@@ -2603,6 +2793,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_mx32_a-fetch_struct_xfs_quotastat.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_mx32_a-hdio.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_mx32_a-ipc_msgctl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_mx32_a-ipc_semctl.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_mx32_a-ipc_shmctl.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_mx32_a-loop.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_mx32_a-mtd.Po@am__quote@ # am--include-marker
@@ -2614,7 +2805,6 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_mx32_a-print_sg_req_info.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_mx32_a-print_sigevent.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_mx32_a-print_time.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_mx32_a-print_timespec.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_mx32_a-print_timeval.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_mx32_a-printrusage.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_mx32_a-printsiginfo.Po@am__quote@ # am--include-marker
@@ -2628,262 +2818,276 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_mx32_a-ustat.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_mx32_a-utime.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libmpers_mx32_a-v4l2.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-access.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-affinity.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-aio.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-alpha.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-basic_filters.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-bind.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-bjm.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-block.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-bpf.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-bpf_attr_check.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-bpf_filter.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-bpf_seccomp_filter.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-bpf_sock_filter.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-btrfs.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-cacheflush.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-capability.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-chdir.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-chmod.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-clone.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-close_range.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-copy_file_range.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-count.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-delay.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-desc.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-dirent.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-dirent64.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-dirent_types.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-dm.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-dup.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-dyxlat.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-epoll.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-error_prints.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-evdev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-evdev_mpers.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-eventfd.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-execve.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-fadvise.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-fallocate.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-fanotify.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-fchownat.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-fcntl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-fetch_bpf_fprog.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-fetch_indirect_syscall_args.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-fetch_struct_flock.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-fetch_struct_keyctl_kdf_params.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-fetch_struct_mmsghdr.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-fetch_struct_msghdr.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-fetch_struct_stat.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-fetch_struct_stat64.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-fetch_struct_statfs.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-fetch_struct_xfs_quotastat.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-file_handle.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-file_ioctl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-filter_qualify.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-filter_seccomp.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-flock.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-fs_x_ioctl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-fsconfig.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-fsmount.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-fsopen.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-fspick.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-fstatfs.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-fstatfs64.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-futex.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-get_personality.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-get_robust_list.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-getcpu.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-getcwd.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-getpagesize.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-getpid.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-getrandom.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-hdio.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-hostname.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-inotify.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-inotify_ioctl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-io.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-io_uring.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-ioctl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-ioperm.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-iopl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-ioprio.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-ipc.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-ipc_msg.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-ipc_msgctl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-ipc_sem.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-ipc_semctl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-ipc_shm.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-ipc_shmctl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-kcmp.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-kexec.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-keyctl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-kvm.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-ldt.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-link.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-listen.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-lookup_dcookie.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-loop.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-lseek.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-mem.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-membarrier.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-memfd_create.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-mknod.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-mmap_cache.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-mmap_notify.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-mmsghdr.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-mount.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-move_mount.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-mq.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-msghdr.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-mtd.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-nbd_ioctl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-net.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-netlink.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-netlink_crypto.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-netlink_inet_diag.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-netlink_kobject_uevent.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-netlink_netfilter.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-netlink_netlink_diag.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-netlink_packet_diag.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-netlink_route.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-netlink_selinux.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-netlink_smc_diag.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-netlink_sock_diag.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-netlink_unix_diag.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-nlattr.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-nsfs.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-numa.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-number_set.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-oldstat.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-open.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-open_tree.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-or1k_atomic.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-pathtrace.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-perf.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-perf_ioctl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-personality.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-pidfd_getfd.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-pidfd_open.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-pidns.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-pkeys.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-poll.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-prctl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-print_aio_sigset.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-print_dev_t.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-print_group_req.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-print_ifindex.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-print_instruction_pointer.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-print_kernel_version.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-print_mac.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-print_mq_attr.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-print_msgbuf.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-print_sg_req_info.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-print_sigevent.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-print_statfs.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-print_struct_stat.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-print_syscall_number.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-print_time.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-print_timespec32.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-print_timespec64.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-print_timeval.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-print_timeval64.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-print_timex.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-printmode.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-printrusage.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-printsiginfo.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-process.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-process_vm.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-ptp.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-ptrace_syscall_info.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-quota.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-random_ioctl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-readahead.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-readlink.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-reboot.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-renameat.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-resource.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-retval.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-riscv.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-rt_sigframe.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-rt_sigreturn.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-rtc.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-rtnl_addr.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-rtnl_addrlabel.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-rtnl_dcb.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-rtnl_link.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-rtnl_mdb.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-rtnl_neigh.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-rtnl_neightbl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-rtnl_netconf.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-rtnl_nsid.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-rtnl_route.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-rtnl_rule.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-rtnl_tc.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-rtnl_tc_action.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-s390.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-sched.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-scsi.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-seccomp.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-sendfile.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-sg_io_v3.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-sg_io_v4.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-shutdown.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-sigaltstack.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-signal.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-signalfd.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-sigreturn.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-sock.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-sockaddr.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-socketcall.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-socketutils.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-sparc.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-sram_alloc.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-stage_output.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-stat.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-stat64.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-statfs.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-statfs64.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-statx.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-string_to_uint.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-swapon.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-sync_file_range.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-sync_file_range2.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-syscall.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-sysctl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-sysinfo.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-syslog.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-sysmips.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-tee.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-term.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-time.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-times.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-trie.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-truncate.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-ubi.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-ucopy.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-uid.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-uid16.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-umask.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-umount.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-uname.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-unwind-libdw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-unwind-libunwind.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-unwind.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-upeek.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-upoke.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-access.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-affinity.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-aio.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-alpha.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-basic_filters.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-bind.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-bjm.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-block.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-bpf.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-bpf_attr_check.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-bpf_filter.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-bpf_seccomp_filter.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-bpf_sock_filter.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-btrfs.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-cacheflush.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-capability.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-chdir.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-chmod.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-clone.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-copy_file_range.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-count.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-delay.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-desc.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-dirent.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-dirent64.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-dm.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-dyxlat.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-epoll.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-error_prints.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-evdev.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-evdev_mpers.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-eventfd.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-execve.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-fadvise.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-fallocate.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-fanotify.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-fchownat.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-fcntl.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-fetch_bpf_fprog.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-fetch_struct_flock.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-fetch_struct_keyctl_kdf_params.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-fetch_struct_mmsghdr.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-fetch_struct_msghdr.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-fetch_struct_stat.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-fetch_struct_stat64.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-fetch_struct_statfs.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-fetch_struct_xfs_quotastat.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-file_handle.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-file_ioctl.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-filter_qualify.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-filter_seccomp.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-flock.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-fs_x_ioctl.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-fsconfig.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-fsmount.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-fsopen.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-fspick.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-futex.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-get_personality.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-get_robust_list.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-getcpu.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-getcwd.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-getrandom.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-hdio.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-hostname.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-inotify.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-inotify_ioctl.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-io.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-io_uring.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-ioctl.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-ioperm.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-iopl.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-ioprio.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-ipc_msg.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-ipc_msgctl.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-ipc_sem.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-ipc_shm.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-ipc_shmctl.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-kcmp.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-kexec.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-keyctl.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-kvm.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-ldt.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-link.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-listen.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-lookup_dcookie.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-loop.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-lseek.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-mem.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-membarrier.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-memfd_create.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-mknod.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-mmap_notify.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-mmsghdr.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-mount.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-move_mount.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-mq.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-msghdr.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-mtd.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-nbd_ioctl.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-net.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-netlink.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-netlink_crypto.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-netlink_inet_diag.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-netlink_kobject_uevent.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-netlink_netfilter.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-netlink_netlink_diag.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-netlink_packet_diag.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-netlink_route.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-netlink_selinux.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-netlink_smc_diag.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-netlink_sock_diag.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-netlink_unix_diag.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-nlattr.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-nsfs.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-numa.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-number_set.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-oldstat.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-open.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-open_tree.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-or1k_atomic.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-pathtrace.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-perf.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-perf_ioctl.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-personality.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-pidfd_open.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-pkeys.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-poll.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-prctl.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-print_aio_sigset.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-print_dev_t.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-print_group_req.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-print_ifindex.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-print_instruction_pointer.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-print_kernel_version.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-print_mac.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-print_mq_attr.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-print_msgbuf.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-print_sg_req_info.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-print_sigevent.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-print_statfs.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-print_struct_stat.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-print_time.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-print_timespec.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-print_timespec32.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-print_timespec64.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-print_timeval.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-print_timeval64.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-print_timex.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-printmode.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-printrusage.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-printsiginfo.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-process.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-process_vm.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-ptp.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-ptrace_syscall_info.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-quota.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-random_ioctl.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-readahead.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-readlink.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-reboot.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-renameat.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-resource.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-retval.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-riscv.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-rt_sigframe.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-rt_sigreturn.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-rtc.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-rtnl_addr.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-rtnl_addrlabel.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-rtnl_dcb.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-rtnl_link.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-rtnl_mdb.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-rtnl_neigh.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-rtnl_neightbl.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-rtnl_netconf.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-rtnl_nsid.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-rtnl_route.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-rtnl_rule.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-rtnl_tc.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-rtnl_tc_action.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-s390.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-sched.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-scsi.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-seccomp.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-sendfile.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-sg_io_v3.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-sg_io_v4.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-shutdown.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-sigaltstack.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-signal.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-signalfd.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-sock.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-sockaddr.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-socketutils.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-sparc.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-sram_alloc.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-stage_output.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-stat.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-stat64.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-statfs.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-statx.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-userfaultfd.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-ustat.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-util.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-utime.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-utimes.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-v4l2.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-wait.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-watchdog_ioctl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-xattr.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-xgetdents.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-xlat.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libstrace_a-xmalloc.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-strace.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-string_to_uint.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-swapon.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-syscall.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-sysctl.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-sysinfo.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-syslog.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-sysmips.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-term.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-time.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-times.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-truncate.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-ubi.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-ucopy.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-uid.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-uid16.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-umask.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-umount.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-uname.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-unwind-libdw.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-unwind-libunwind.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-unwind.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-userfaultfd.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-ustat.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-util.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-utime.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-utimes.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-v4l2.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-wait.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-watchdog_ioctl.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-xattr.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-xlat.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-xmalloc.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@types/$(DEPDIR)/strace-check-cryptouser.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@types/$(DEPDIR)/strace-check-evdev.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@types/$(DEPDIR)/strace-check-io_uring.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@types/$(DEPDIR)/strace-check-rtnl_link.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@types/$(DEPDIR)/strace-check-rtnl_mdb.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@types/$(DEPDIR)/strace-check-rtnl_neightbl.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@types/$(DEPDIR)/strace-check-rtnl_route.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@types/$(DEPDIR)/libstrace_a-check-btrfs.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@types/$(DEPDIR)/libstrace_a-check-cryptouser.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@types/$(DEPDIR)/libstrace_a-check-evdev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@types/$(DEPDIR)/libstrace_a-check-io_uring.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@types/$(DEPDIR)/libstrace_a-check-loop.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@types/$(DEPDIR)/libstrace_a-check-openat2.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@types/$(DEPDIR)/libstrace_a-check-rtnl_link.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@types/$(DEPDIR)/libstrace_a-check-rtnl_mdb.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@types/$(DEPDIR)/libstrace_a-check-rtnl_neightbl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@types/$(DEPDIR)/libstrace_a-check-rtnl_route.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@types/$(DEPDIR)/libstrace_a-check-tee.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@types/$(DEPDIR)/libstrace_a-check-v4l2.Po@am__quote@ # am--include-marker
 
 $(am__depfiles_remade):
 	@$(MKDIR_P) $(@D)
@@ -3117,6 +3321,20 @@ libmpers_m32_a-ipc_msgctl.obj: ipc_msgct
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
 @am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libmpers_m32_a_CPPFLAGS) $(CPPFLAGS) $(libmpers_m32_a_CFLAGS) $(CFLAGS) -c -o libmpers_m32_a-ipc_msgctl.obj `if test -f 'ipc_msgctl.c'; then $(CYGPATH_W) 'ipc_msgctl.c'; else $(CYGPATH_W) '$(srcdir)/ipc_msgctl.c'; fi`
 
+libmpers_m32_a-ipc_semctl.o: ipc_semctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libmpers_m32_a_CPPFLAGS) $(CPPFLAGS) $(libmpers_m32_a_CFLAGS) $(CFLAGS) -MT libmpers_m32_a-ipc_semctl.o -MD -MP -MF $(DEPDIR)/libmpers_m32_a-ipc_semctl.Tpo -c -o libmpers_m32_a-ipc_semctl.o `test -f 'ipc_semctl.c' || echo '$(srcdir)/'`ipc_semctl.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libmpers_m32_a-ipc_semctl.Tpo $(DEPDIR)/libmpers_m32_a-ipc_semctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc_semctl.c' object='libmpers_m32_a-ipc_semctl.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libmpers_m32_a_CPPFLAGS) $(CPPFLAGS) $(libmpers_m32_a_CFLAGS) $(CFLAGS) -c -o libmpers_m32_a-ipc_semctl.o `test -f 'ipc_semctl.c' || echo '$(srcdir)/'`ipc_semctl.c
+
+libmpers_m32_a-ipc_semctl.obj: ipc_semctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libmpers_m32_a_CPPFLAGS) $(CPPFLAGS) $(libmpers_m32_a_CFLAGS) $(CFLAGS) -MT libmpers_m32_a-ipc_semctl.obj -MD -MP -MF $(DEPDIR)/libmpers_m32_a-ipc_semctl.Tpo -c -o libmpers_m32_a-ipc_semctl.obj `if test -f 'ipc_semctl.c'; then $(CYGPATH_W) 'ipc_semctl.c'; else $(CYGPATH_W) '$(srcdir)/ipc_semctl.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libmpers_m32_a-ipc_semctl.Tpo $(DEPDIR)/libmpers_m32_a-ipc_semctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc_semctl.c' object='libmpers_m32_a-ipc_semctl.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libmpers_m32_a_CPPFLAGS) $(CPPFLAGS) $(libmpers_m32_a_CFLAGS) $(CFLAGS) -c -o libmpers_m32_a-ipc_semctl.obj `if test -f 'ipc_semctl.c'; then $(CYGPATH_W) 'ipc_semctl.c'; else $(CYGPATH_W) '$(srcdir)/ipc_semctl.c'; fi`
+
 libmpers_m32_a-ipc_shmctl.o: ipc_shmctl.c
 @am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libmpers_m32_a_CPPFLAGS) $(CPPFLAGS) $(libmpers_m32_a_CFLAGS) $(CFLAGS) -MT libmpers_m32_a-ipc_shmctl.o -MD -MP -MF $(DEPDIR)/libmpers_m32_a-ipc_shmctl.Tpo -c -o libmpers_m32_a-ipc_shmctl.o `test -f 'ipc_shmctl.c' || echo '$(srcdir)/'`ipc_shmctl.c
 @am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libmpers_m32_a-ipc_shmctl.Tpo $(DEPDIR)/libmpers_m32_a-ipc_shmctl.Po
@@ -3271,20 +3489,6 @@ libmpers_m32_a-print_time.obj: print_tim
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
 @am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libmpers_m32_a_CPPFLAGS) $(CPPFLAGS) $(libmpers_m32_a_CFLAGS) $(CFLAGS) -c -o libmpers_m32_a-print_time.obj `if test -f 'print_time.c'; then $(CYGPATH_W) 'print_time.c'; else $(CYGPATH_W) '$(srcdir)/print_time.c'; fi`
 
-libmpers_m32_a-print_timespec.o: print_timespec.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libmpers_m32_a_CPPFLAGS) $(CPPFLAGS) $(libmpers_m32_a_CFLAGS) $(CFLAGS) -MT libmpers_m32_a-print_timespec.o -MD -MP -MF $(DEPDIR)/libmpers_m32_a-print_timespec.Tpo -c -o libmpers_m32_a-print_timespec.o `test -f 'print_timespec.c' || echo '$(srcdir)/'`print_timespec.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libmpers_m32_a-print_timespec.Tpo $(DEPDIR)/libmpers_m32_a-print_timespec.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_timespec.c' object='libmpers_m32_a-print_timespec.o' libtool=no @AMDEPBACKSLASH@
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libmpers_m32_a_CPPFLAGS) $(CPPFLAGS) $(libmpers_m32_a_CFLAGS) $(CFLAGS) -c -o libmpers_m32_a-print_timespec.o `test -f 'print_timespec.c' || echo '$(srcdir)/'`print_timespec.c
-
-libmpers_m32_a-print_timespec.obj: print_timespec.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libmpers_m32_a_CPPFLAGS) $(CPPFLAGS) $(libmpers_m32_a_CFLAGS) $(CFLAGS) -MT libmpers_m32_a-print_timespec.obj -MD -MP -MF $(DEPDIR)/libmpers_m32_a-print_timespec.Tpo -c -o libmpers_m32_a-print_timespec.obj `if test -f 'print_timespec.c'; then $(CYGPATH_W) 'print_timespec.c'; else $(CYGPATH_W) '$(srcdir)/print_timespec.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libmpers_m32_a-print_timespec.Tpo $(DEPDIR)/libmpers_m32_a-print_timespec.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_timespec.c' object='libmpers_m32_a-print_timespec.obj' libtool=no @AMDEPBACKSLASH@
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libmpers_m32_a_CPPFLAGS) $(CPPFLAGS) $(libmpers_m32_a_CFLAGS) $(CFLAGS) -c -o libmpers_m32_a-print_timespec.obj `if test -f 'print_timespec.c'; then $(CYGPATH_W) 'print_timespec.c'; else $(CYGPATH_W) '$(srcdir)/print_timespec.c'; fi`
-
 libmpers_m32_a-print_timeval.o: print_timeval.c
 @am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libmpers_m32_a_CPPFLAGS) $(CPPFLAGS) $(libmpers_m32_a_CFLAGS) $(CFLAGS) -MT libmpers_m32_a-print_timeval.o -MD -MP -MF $(DEPDIR)/libmpers_m32_a-print_timeval.Tpo -c -o libmpers_m32_a-print_timeval.o `test -f 'print_timeval.c' || echo '$(srcdir)/'`print_timeval.c
 @am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libmpers_m32_a-print_timeval.Tpo $(DEPDIR)/libmpers_m32_a-print_timeval.Po
@@ -3677,6 +3881,20 @@ libmpers_mx32_a-ipc_msgctl.obj: ipc_msgc
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
 @am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libmpers_mx32_a_CPPFLAGS) $(CPPFLAGS) $(libmpers_mx32_a_CFLAGS) $(CFLAGS) -c -o libmpers_mx32_a-ipc_msgctl.obj `if test -f 'ipc_msgctl.c'; then $(CYGPATH_W) 'ipc_msgctl.c'; else $(CYGPATH_W) '$(srcdir)/ipc_msgctl.c'; fi`
 
+libmpers_mx32_a-ipc_semctl.o: ipc_semctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libmpers_mx32_a_CPPFLAGS) $(CPPFLAGS) $(libmpers_mx32_a_CFLAGS) $(CFLAGS) -MT libmpers_mx32_a-ipc_semctl.o -MD -MP -MF $(DEPDIR)/libmpers_mx32_a-ipc_semctl.Tpo -c -o libmpers_mx32_a-ipc_semctl.o `test -f 'ipc_semctl.c' || echo '$(srcdir)/'`ipc_semctl.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libmpers_mx32_a-ipc_semctl.Tpo $(DEPDIR)/libmpers_mx32_a-ipc_semctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc_semctl.c' object='libmpers_mx32_a-ipc_semctl.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libmpers_mx32_a_CPPFLAGS) $(CPPFLAGS) $(libmpers_mx32_a_CFLAGS) $(CFLAGS) -c -o libmpers_mx32_a-ipc_semctl.o `test -f 'ipc_semctl.c' || echo '$(srcdir)/'`ipc_semctl.c
+
+libmpers_mx32_a-ipc_semctl.obj: ipc_semctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libmpers_mx32_a_CPPFLAGS) $(CPPFLAGS) $(libmpers_mx32_a_CFLAGS) $(CFLAGS) -MT libmpers_mx32_a-ipc_semctl.obj -MD -MP -MF $(DEPDIR)/libmpers_mx32_a-ipc_semctl.Tpo -c -o libmpers_mx32_a-ipc_semctl.obj `if test -f 'ipc_semctl.c'; then $(CYGPATH_W) 'ipc_semctl.c'; else $(CYGPATH_W) '$(srcdir)/ipc_semctl.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libmpers_mx32_a-ipc_semctl.Tpo $(DEPDIR)/libmpers_mx32_a-ipc_semctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc_semctl.c' object='libmpers_mx32_a-ipc_semctl.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libmpers_mx32_a_CPPFLAGS) $(CPPFLAGS) $(libmpers_mx32_a_CFLAGS) $(CFLAGS) -c -o libmpers_mx32_a-ipc_semctl.obj `if test -f 'ipc_semctl.c'; then $(CYGPATH_W) 'ipc_semctl.c'; else $(CYGPATH_W) '$(srcdir)/ipc_semctl.c'; fi`
+
 libmpers_mx32_a-ipc_shmctl.o: ipc_shmctl.c
 @am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libmpers_mx32_a_CPPFLAGS) $(CPPFLAGS) $(libmpers_mx32_a_CFLAGS) $(CFLAGS) -MT libmpers_mx32_a-ipc_shmctl.o -MD -MP -MF $(DEPDIR)/libmpers_mx32_a-ipc_shmctl.Tpo -c -o libmpers_mx32_a-ipc_shmctl.o `test -f 'ipc_shmctl.c' || echo '$(srcdir)/'`ipc_shmctl.c
 @am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libmpers_mx32_a-ipc_shmctl.Tpo $(DEPDIR)/libmpers_mx32_a-ipc_shmctl.Po
@@ -3831,20 +4049,6 @@ libmpers_mx32_a-print_time.obj: print_ti
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
 @am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libmpers_mx32_a_CPPFLAGS) $(CPPFLAGS) $(libmpers_mx32_a_CFLAGS) $(CFLAGS) -c -o libmpers_mx32_a-print_time.obj `if test -f 'print_time.c'; then $(CYGPATH_W) 'print_time.c'; else $(CYGPATH_W) '$(srcdir)/print_time.c'; fi`
 
-libmpers_mx32_a-print_timespec.o: print_timespec.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libmpers_mx32_a_CPPFLAGS) $(CPPFLAGS) $(libmpers_mx32_a_CFLAGS) $(CFLAGS) -MT libmpers_mx32_a-print_timespec.o -MD -MP -MF $(DEPDIR)/libmpers_mx32_a-print_timespec.Tpo -c -o libmpers_mx32_a-print_timespec.o `test -f 'print_timespec.c' || echo '$(srcdir)/'`print_timespec.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libmpers_mx32_a-print_timespec.Tpo $(DEPDIR)/libmpers_mx32_a-print_timespec.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_timespec.c' object='libmpers_mx32_a-print_timespec.o' libtool=no @AMDEPBACKSLASH@
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libmpers_mx32_a_CPPFLAGS) $(CPPFLAGS) $(libmpers_mx32_a_CFLAGS) $(CFLAGS) -c -o libmpers_mx32_a-print_timespec.o `test -f 'print_timespec.c' || echo '$(srcdir)/'`print_timespec.c
-
-libmpers_mx32_a-print_timespec.obj: print_timespec.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libmpers_mx32_a_CPPFLAGS) $(CPPFLAGS) $(libmpers_mx32_a_CFLAGS) $(CFLAGS) -MT libmpers_mx32_a-print_timespec.obj -MD -MP -MF $(DEPDIR)/libmpers_mx32_a-print_timespec.Tpo -c -o libmpers_mx32_a-print_timespec.obj `if test -f 'print_timespec.c'; then $(CYGPATH_W) 'print_timespec.c'; else $(CYGPATH_W) '$(srcdir)/print_timespec.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libmpers_mx32_a-print_timespec.Tpo $(DEPDIR)/libmpers_mx32_a-print_timespec.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_timespec.c' object='libmpers_mx32_a-print_timespec.obj' libtool=no @AMDEPBACKSLASH@
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libmpers_mx32_a_CPPFLAGS) $(CPPFLAGS) $(libmpers_mx32_a_CFLAGS) $(CFLAGS) -c -o libmpers_mx32_a-print_timespec.obj `if test -f 'print_timespec.c'; then $(CYGPATH_W) 'print_timespec.c'; else $(CYGPATH_W) '$(srcdir)/print_timespec.c'; fi`
-
 libmpers_mx32_a-print_timeval.o: print_timeval.c
 @am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libmpers_mx32_a_CPPFLAGS) $(CPPFLAGS) $(libmpers_mx32_a_CFLAGS) $(CFLAGS) -MT libmpers_mx32_a-print_timeval.o -MD -MP -MF $(DEPDIR)/libmpers_mx32_a-print_timeval.Tpo -c -o libmpers_mx32_a-print_timeval.o `test -f 'print_timeval.c' || echo '$(srcdir)/'`print_timeval.c
 @am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libmpers_mx32_a-print_timeval.Tpo $(DEPDIR)/libmpers_mx32_a-print_timeval.Po
@@ -4027,3589 +4231,3785 @@ libmpers_mx32_a-v4l2.obj: v4l2.c
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
 @am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libmpers_mx32_a_CPPFLAGS) $(CPPFLAGS) $(libmpers_mx32_a_CFLAGS) $(CFLAGS) -c -o libmpers_mx32_a-v4l2.obj `if test -f 'v4l2.c'; then $(CYGPATH_W) 'v4l2.c'; else $(CYGPATH_W) '$(srcdir)/v4l2.c'; fi`
 
-libstrace_a-fetch_indirect_syscall_args.o: fetch_indirect_syscall_args.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fetch_indirect_syscall_args.o -MD -MP -MF $(DEPDIR)/libstrace_a-fetch_indirect_syscall_args.Tpo -c -o libstrace_a-fetch_indirect_syscall_args.o `test -f 'fetch_indirect_syscall_args.c' || echo '$(srcdir)/'`fetch_indirect_syscall_args.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fetch_indirect_syscall_args.Tpo $(DEPDIR)/libstrace_a-fetch_indirect_syscall_args.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_indirect_syscall_args.c' object='libstrace_a-fetch_indirect_syscall_args.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-access.o: access.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-access.o -MD -MP -MF $(DEPDIR)/libstrace_a-access.Tpo -c -o libstrace_a-access.o `test -f 'access.c' || echo '$(srcdir)/'`access.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-access.Tpo $(DEPDIR)/libstrace_a-access.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='access.c' object='libstrace_a-access.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fetch_indirect_syscall_args.o `test -f 'fetch_indirect_syscall_args.c' || echo '$(srcdir)/'`fetch_indirect_syscall_args.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-access.o `test -f 'access.c' || echo '$(srcdir)/'`access.c
 
-libstrace_a-fetch_indirect_syscall_args.obj: fetch_indirect_syscall_args.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fetch_indirect_syscall_args.obj -MD -MP -MF $(DEPDIR)/libstrace_a-fetch_indirect_syscall_args.Tpo -c -o libstrace_a-fetch_indirect_syscall_args.obj `if test -f 'fetch_indirect_syscall_args.c'; then $(CYGPATH_W) 'fetch_indirect_syscall_args.c'; else $(CYGPATH_W) '$(srcdir)/fetch_indirect_syscall_args.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fetch_indirect_syscall_args.Tpo $(DEPDIR)/libstrace_a-fetch_indirect_syscall_args.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_indirect_syscall_args.c' object='libstrace_a-fetch_indirect_syscall_args.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-access.obj: access.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-access.obj -MD -MP -MF $(DEPDIR)/libstrace_a-access.Tpo -c -o libstrace_a-access.obj `if test -f 'access.c'; then $(CYGPATH_W) 'access.c'; else $(CYGPATH_W) '$(srcdir)/access.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-access.Tpo $(DEPDIR)/libstrace_a-access.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='access.c' object='libstrace_a-access.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fetch_indirect_syscall_args.obj `if test -f 'fetch_indirect_syscall_args.c'; then $(CYGPATH_W) 'fetch_indirect_syscall_args.c'; else $(CYGPATH_W) '$(srcdir)/fetch_indirect_syscall_args.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-access.obj `if test -f 'access.c'; then $(CYGPATH_W) 'access.c'; else $(CYGPATH_W) '$(srcdir)/access.c'; fi`
 
-libstrace_a-fstatfs.o: fstatfs.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fstatfs.o -MD -MP -MF $(DEPDIR)/libstrace_a-fstatfs.Tpo -c -o libstrace_a-fstatfs.o `test -f 'fstatfs.c' || echo '$(srcdir)/'`fstatfs.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fstatfs.Tpo $(DEPDIR)/libstrace_a-fstatfs.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fstatfs.c' object='libstrace_a-fstatfs.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-affinity.o: affinity.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-affinity.o -MD -MP -MF $(DEPDIR)/libstrace_a-affinity.Tpo -c -o libstrace_a-affinity.o `test -f 'affinity.c' || echo '$(srcdir)/'`affinity.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-affinity.Tpo $(DEPDIR)/libstrace_a-affinity.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='affinity.c' object='libstrace_a-affinity.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fstatfs.o `test -f 'fstatfs.c' || echo '$(srcdir)/'`fstatfs.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-affinity.o `test -f 'affinity.c' || echo '$(srcdir)/'`affinity.c
 
-libstrace_a-fstatfs.obj: fstatfs.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fstatfs.obj -MD -MP -MF $(DEPDIR)/libstrace_a-fstatfs.Tpo -c -o libstrace_a-fstatfs.obj `if test -f 'fstatfs.c'; then $(CYGPATH_W) 'fstatfs.c'; else $(CYGPATH_W) '$(srcdir)/fstatfs.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fstatfs.Tpo $(DEPDIR)/libstrace_a-fstatfs.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fstatfs.c' object='libstrace_a-fstatfs.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-affinity.obj: affinity.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-affinity.obj -MD -MP -MF $(DEPDIR)/libstrace_a-affinity.Tpo -c -o libstrace_a-affinity.obj `if test -f 'affinity.c'; then $(CYGPATH_W) 'affinity.c'; else $(CYGPATH_W) '$(srcdir)/affinity.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-affinity.Tpo $(DEPDIR)/libstrace_a-affinity.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='affinity.c' object='libstrace_a-affinity.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fstatfs.obj `if test -f 'fstatfs.c'; then $(CYGPATH_W) 'fstatfs.c'; else $(CYGPATH_W) '$(srcdir)/fstatfs.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-affinity.obj `if test -f 'affinity.c'; then $(CYGPATH_W) 'affinity.c'; else $(CYGPATH_W) '$(srcdir)/affinity.c'; fi`
 
-libstrace_a-fstatfs64.o: fstatfs64.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fstatfs64.o -MD -MP -MF $(DEPDIR)/libstrace_a-fstatfs64.Tpo -c -o libstrace_a-fstatfs64.o `test -f 'fstatfs64.c' || echo '$(srcdir)/'`fstatfs64.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fstatfs64.Tpo $(DEPDIR)/libstrace_a-fstatfs64.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fstatfs64.c' object='libstrace_a-fstatfs64.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-aio.o: aio.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-aio.o -MD -MP -MF $(DEPDIR)/libstrace_a-aio.Tpo -c -o libstrace_a-aio.o `test -f 'aio.c' || echo '$(srcdir)/'`aio.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-aio.Tpo $(DEPDIR)/libstrace_a-aio.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='aio.c' object='libstrace_a-aio.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fstatfs64.o `test -f 'fstatfs64.c' || echo '$(srcdir)/'`fstatfs64.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-aio.o `test -f 'aio.c' || echo '$(srcdir)/'`aio.c
 
-libstrace_a-fstatfs64.obj: fstatfs64.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fstatfs64.obj -MD -MP -MF $(DEPDIR)/libstrace_a-fstatfs64.Tpo -c -o libstrace_a-fstatfs64.obj `if test -f 'fstatfs64.c'; then $(CYGPATH_W) 'fstatfs64.c'; else $(CYGPATH_W) '$(srcdir)/fstatfs64.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fstatfs64.Tpo $(DEPDIR)/libstrace_a-fstatfs64.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fstatfs64.c' object='libstrace_a-fstatfs64.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-aio.obj: aio.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-aio.obj -MD -MP -MF $(DEPDIR)/libstrace_a-aio.Tpo -c -o libstrace_a-aio.obj `if test -f 'aio.c'; then $(CYGPATH_W) 'aio.c'; else $(CYGPATH_W) '$(srcdir)/aio.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-aio.Tpo $(DEPDIR)/libstrace_a-aio.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='aio.c' object='libstrace_a-aio.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fstatfs64.obj `if test -f 'fstatfs64.c'; then $(CYGPATH_W) 'fstatfs64.c'; else $(CYGPATH_W) '$(srcdir)/fstatfs64.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-aio.obj `if test -f 'aio.c'; then $(CYGPATH_W) 'aio.c'; else $(CYGPATH_W) '$(srcdir)/aio.c'; fi`
 
-libstrace_a-getpagesize.o: getpagesize.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-getpagesize.o -MD -MP -MF $(DEPDIR)/libstrace_a-getpagesize.Tpo -c -o libstrace_a-getpagesize.o `test -f 'getpagesize.c' || echo '$(srcdir)/'`getpagesize.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-getpagesize.Tpo $(DEPDIR)/libstrace_a-getpagesize.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='getpagesize.c' object='libstrace_a-getpagesize.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-alpha.o: alpha.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-alpha.o -MD -MP -MF $(DEPDIR)/libstrace_a-alpha.Tpo -c -o libstrace_a-alpha.o `test -f 'alpha.c' || echo '$(srcdir)/'`alpha.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-alpha.Tpo $(DEPDIR)/libstrace_a-alpha.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='alpha.c' object='libstrace_a-alpha.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-getpagesize.o `test -f 'getpagesize.c' || echo '$(srcdir)/'`getpagesize.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-alpha.o `test -f 'alpha.c' || echo '$(srcdir)/'`alpha.c
 
-libstrace_a-getpagesize.obj: getpagesize.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-getpagesize.obj -MD -MP -MF $(DEPDIR)/libstrace_a-getpagesize.Tpo -c -o libstrace_a-getpagesize.obj `if test -f 'getpagesize.c'; then $(CYGPATH_W) 'getpagesize.c'; else $(CYGPATH_W) '$(srcdir)/getpagesize.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-getpagesize.Tpo $(DEPDIR)/libstrace_a-getpagesize.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='getpagesize.c' object='libstrace_a-getpagesize.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-alpha.obj: alpha.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-alpha.obj -MD -MP -MF $(DEPDIR)/libstrace_a-alpha.Tpo -c -o libstrace_a-alpha.obj `if test -f 'alpha.c'; then $(CYGPATH_W) 'alpha.c'; else $(CYGPATH_W) '$(srcdir)/alpha.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-alpha.Tpo $(DEPDIR)/libstrace_a-alpha.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='alpha.c' object='libstrace_a-alpha.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-getpagesize.obj `if test -f 'getpagesize.c'; then $(CYGPATH_W) 'getpagesize.c'; else $(CYGPATH_W) '$(srcdir)/getpagesize.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-alpha.obj `if test -f 'alpha.c'; then $(CYGPATH_W) 'alpha.c'; else $(CYGPATH_W) '$(srcdir)/alpha.c'; fi`
 
-libstrace_a-ipc.o: ipc.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ipc.o -MD -MP -MF $(DEPDIR)/libstrace_a-ipc.Tpo -c -o libstrace_a-ipc.o `test -f 'ipc.c' || echo '$(srcdir)/'`ipc.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ipc.Tpo $(DEPDIR)/libstrace_a-ipc.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc.c' object='libstrace_a-ipc.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-basic_filters.o: basic_filters.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-basic_filters.o -MD -MP -MF $(DEPDIR)/libstrace_a-basic_filters.Tpo -c -o libstrace_a-basic_filters.o `test -f 'basic_filters.c' || echo '$(srcdir)/'`basic_filters.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-basic_filters.Tpo $(DEPDIR)/libstrace_a-basic_filters.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='basic_filters.c' object='libstrace_a-basic_filters.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ipc.o `test -f 'ipc.c' || echo '$(srcdir)/'`ipc.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-basic_filters.o `test -f 'basic_filters.c' || echo '$(srcdir)/'`basic_filters.c
 
-libstrace_a-ipc.obj: ipc.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ipc.obj -MD -MP -MF $(DEPDIR)/libstrace_a-ipc.Tpo -c -o libstrace_a-ipc.obj `if test -f 'ipc.c'; then $(CYGPATH_W) 'ipc.c'; else $(CYGPATH_W) '$(srcdir)/ipc.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ipc.Tpo $(DEPDIR)/libstrace_a-ipc.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc.c' object='libstrace_a-ipc.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-basic_filters.obj: basic_filters.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-basic_filters.obj -MD -MP -MF $(DEPDIR)/libstrace_a-basic_filters.Tpo -c -o libstrace_a-basic_filters.obj `if test -f 'basic_filters.c'; then $(CYGPATH_W) 'basic_filters.c'; else $(CYGPATH_W) '$(srcdir)/basic_filters.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-basic_filters.Tpo $(DEPDIR)/libstrace_a-basic_filters.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='basic_filters.c' object='libstrace_a-basic_filters.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ipc.obj `if test -f 'ipc.c'; then $(CYGPATH_W) 'ipc.c'; else $(CYGPATH_W) '$(srcdir)/ipc.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-basic_filters.obj `if test -f 'basic_filters.c'; then $(CYGPATH_W) 'basic_filters.c'; else $(CYGPATH_W) '$(srcdir)/basic_filters.c'; fi`
 
-libstrace_a-mmap_cache.o: mmap_cache.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-mmap_cache.o -MD -MP -MF $(DEPDIR)/libstrace_a-mmap_cache.Tpo -c -o libstrace_a-mmap_cache.o `test -f 'mmap_cache.c' || echo '$(srcdir)/'`mmap_cache.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-mmap_cache.Tpo $(DEPDIR)/libstrace_a-mmap_cache.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mmap_cache.c' object='libstrace_a-mmap_cache.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-bind.o: bind.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-bind.o -MD -MP -MF $(DEPDIR)/libstrace_a-bind.Tpo -c -o libstrace_a-bind.o `test -f 'bind.c' || echo '$(srcdir)/'`bind.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-bind.Tpo $(DEPDIR)/libstrace_a-bind.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bind.c' object='libstrace_a-bind.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-mmap_cache.o `test -f 'mmap_cache.c' || echo '$(srcdir)/'`mmap_cache.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-bind.o `test -f 'bind.c' || echo '$(srcdir)/'`bind.c
 
-libstrace_a-mmap_cache.obj: mmap_cache.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-mmap_cache.obj -MD -MP -MF $(DEPDIR)/libstrace_a-mmap_cache.Tpo -c -o libstrace_a-mmap_cache.obj `if test -f 'mmap_cache.c'; then $(CYGPATH_W) 'mmap_cache.c'; else $(CYGPATH_W) '$(srcdir)/mmap_cache.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-mmap_cache.Tpo $(DEPDIR)/libstrace_a-mmap_cache.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mmap_cache.c' object='libstrace_a-mmap_cache.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-bind.obj: bind.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-bind.obj -MD -MP -MF $(DEPDIR)/libstrace_a-bind.Tpo -c -o libstrace_a-bind.obj `if test -f 'bind.c'; then $(CYGPATH_W) 'bind.c'; else $(CYGPATH_W) '$(srcdir)/bind.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-bind.Tpo $(DEPDIR)/libstrace_a-bind.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bind.c' object='libstrace_a-bind.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-mmap_cache.obj `if test -f 'mmap_cache.c'; then $(CYGPATH_W) 'mmap_cache.c'; else $(CYGPATH_W) '$(srcdir)/mmap_cache.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-bind.obj `if test -f 'bind.c'; then $(CYGPATH_W) 'bind.c'; else $(CYGPATH_W) '$(srcdir)/bind.c'; fi`
 
-libstrace_a-sigreturn.o: sigreturn.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sigreturn.o -MD -MP -MF $(DEPDIR)/libstrace_a-sigreturn.Tpo -c -o libstrace_a-sigreturn.o `test -f 'sigreturn.c' || echo '$(srcdir)/'`sigreturn.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sigreturn.Tpo $(DEPDIR)/libstrace_a-sigreturn.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sigreturn.c' object='libstrace_a-sigreturn.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-bjm.o: bjm.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-bjm.o -MD -MP -MF $(DEPDIR)/libstrace_a-bjm.Tpo -c -o libstrace_a-bjm.o `test -f 'bjm.c' || echo '$(srcdir)/'`bjm.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-bjm.Tpo $(DEPDIR)/libstrace_a-bjm.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bjm.c' object='libstrace_a-bjm.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sigreturn.o `test -f 'sigreturn.c' || echo '$(srcdir)/'`sigreturn.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-bjm.o `test -f 'bjm.c' || echo '$(srcdir)/'`bjm.c
 
-libstrace_a-sigreturn.obj: sigreturn.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sigreturn.obj -MD -MP -MF $(DEPDIR)/libstrace_a-sigreturn.Tpo -c -o libstrace_a-sigreturn.obj `if test -f 'sigreturn.c'; then $(CYGPATH_W) 'sigreturn.c'; else $(CYGPATH_W) '$(srcdir)/sigreturn.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sigreturn.Tpo $(DEPDIR)/libstrace_a-sigreturn.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sigreturn.c' object='libstrace_a-sigreturn.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-bjm.obj: bjm.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-bjm.obj -MD -MP -MF $(DEPDIR)/libstrace_a-bjm.Tpo -c -o libstrace_a-bjm.obj `if test -f 'bjm.c'; then $(CYGPATH_W) 'bjm.c'; else $(CYGPATH_W) '$(srcdir)/bjm.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-bjm.Tpo $(DEPDIR)/libstrace_a-bjm.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bjm.c' object='libstrace_a-bjm.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sigreturn.obj `if test -f 'sigreturn.c'; then $(CYGPATH_W) 'sigreturn.c'; else $(CYGPATH_W) '$(srcdir)/sigreturn.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-bjm.obj `if test -f 'bjm.c'; then $(CYGPATH_W) 'bjm.c'; else $(CYGPATH_W) '$(srcdir)/bjm.c'; fi`
 
-libstrace_a-socketcall.o: socketcall.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-socketcall.o -MD -MP -MF $(DEPDIR)/libstrace_a-socketcall.Tpo -c -o libstrace_a-socketcall.o `test -f 'socketcall.c' || echo '$(srcdir)/'`socketcall.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-socketcall.Tpo $(DEPDIR)/libstrace_a-socketcall.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='socketcall.c' object='libstrace_a-socketcall.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-block.o: block.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-block.o -MD -MP -MF $(DEPDIR)/libstrace_a-block.Tpo -c -o libstrace_a-block.o `test -f 'block.c' || echo '$(srcdir)/'`block.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-block.Tpo $(DEPDIR)/libstrace_a-block.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='block.c' object='libstrace_a-block.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-socketcall.o `test -f 'socketcall.c' || echo '$(srcdir)/'`socketcall.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-block.o `test -f 'block.c' || echo '$(srcdir)/'`block.c
 
-libstrace_a-socketcall.obj: socketcall.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-socketcall.obj -MD -MP -MF $(DEPDIR)/libstrace_a-socketcall.Tpo -c -o libstrace_a-socketcall.obj `if test -f 'socketcall.c'; then $(CYGPATH_W) 'socketcall.c'; else $(CYGPATH_W) '$(srcdir)/socketcall.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-socketcall.Tpo $(DEPDIR)/libstrace_a-socketcall.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='socketcall.c' object='libstrace_a-socketcall.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-block.obj: block.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-block.obj -MD -MP -MF $(DEPDIR)/libstrace_a-block.Tpo -c -o libstrace_a-block.obj `if test -f 'block.c'; then $(CYGPATH_W) 'block.c'; else $(CYGPATH_W) '$(srcdir)/block.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-block.Tpo $(DEPDIR)/libstrace_a-block.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='block.c' object='libstrace_a-block.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-socketcall.obj `if test -f 'socketcall.c'; then $(CYGPATH_W) 'socketcall.c'; else $(CYGPATH_W) '$(srcdir)/socketcall.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-block.obj `if test -f 'block.c'; then $(CYGPATH_W) 'block.c'; else $(CYGPATH_W) '$(srcdir)/block.c'; fi`
 
-libstrace_a-statfs.o: statfs.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-statfs.o -MD -MP -MF $(DEPDIR)/libstrace_a-statfs.Tpo -c -o libstrace_a-statfs.o `test -f 'statfs.c' || echo '$(srcdir)/'`statfs.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-statfs.Tpo $(DEPDIR)/libstrace_a-statfs.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='statfs.c' object='libstrace_a-statfs.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-bpf.o: bpf.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-bpf.o -MD -MP -MF $(DEPDIR)/libstrace_a-bpf.Tpo -c -o libstrace_a-bpf.o `test -f 'bpf.c' || echo '$(srcdir)/'`bpf.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-bpf.Tpo $(DEPDIR)/libstrace_a-bpf.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bpf.c' object='libstrace_a-bpf.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-statfs.o `test -f 'statfs.c' || echo '$(srcdir)/'`statfs.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-bpf.o `test -f 'bpf.c' || echo '$(srcdir)/'`bpf.c
 
-libstrace_a-statfs.obj: statfs.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-statfs.obj -MD -MP -MF $(DEPDIR)/libstrace_a-statfs.Tpo -c -o libstrace_a-statfs.obj `if test -f 'statfs.c'; then $(CYGPATH_W) 'statfs.c'; else $(CYGPATH_W) '$(srcdir)/statfs.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-statfs.Tpo $(DEPDIR)/libstrace_a-statfs.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='statfs.c' object='libstrace_a-statfs.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-bpf.obj: bpf.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-bpf.obj -MD -MP -MF $(DEPDIR)/libstrace_a-bpf.Tpo -c -o libstrace_a-bpf.obj `if test -f 'bpf.c'; then $(CYGPATH_W) 'bpf.c'; else $(CYGPATH_W) '$(srcdir)/bpf.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-bpf.Tpo $(DEPDIR)/libstrace_a-bpf.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bpf.c' object='libstrace_a-bpf.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-statfs.obj `if test -f 'statfs.c'; then $(CYGPATH_W) 'statfs.c'; else $(CYGPATH_W) '$(srcdir)/statfs.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-bpf.obj `if test -f 'bpf.c'; then $(CYGPATH_W) 'bpf.c'; else $(CYGPATH_W) '$(srcdir)/bpf.c'; fi`
 
-libstrace_a-statfs64.o: statfs64.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-statfs64.o -MD -MP -MF $(DEPDIR)/libstrace_a-statfs64.Tpo -c -o libstrace_a-statfs64.o `test -f 'statfs64.c' || echo '$(srcdir)/'`statfs64.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-statfs64.Tpo $(DEPDIR)/libstrace_a-statfs64.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='statfs64.c' object='libstrace_a-statfs64.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-bpf_filter.o: bpf_filter.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-bpf_filter.o -MD -MP -MF $(DEPDIR)/libstrace_a-bpf_filter.Tpo -c -o libstrace_a-bpf_filter.o `test -f 'bpf_filter.c' || echo '$(srcdir)/'`bpf_filter.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-bpf_filter.Tpo $(DEPDIR)/libstrace_a-bpf_filter.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bpf_filter.c' object='libstrace_a-bpf_filter.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-statfs64.o `test -f 'statfs64.c' || echo '$(srcdir)/'`statfs64.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-bpf_filter.o `test -f 'bpf_filter.c' || echo '$(srcdir)/'`bpf_filter.c
 
-libstrace_a-statfs64.obj: statfs64.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-statfs64.obj -MD -MP -MF $(DEPDIR)/libstrace_a-statfs64.Tpo -c -o libstrace_a-statfs64.obj `if test -f 'statfs64.c'; then $(CYGPATH_W) 'statfs64.c'; else $(CYGPATH_W) '$(srcdir)/statfs64.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-statfs64.Tpo $(DEPDIR)/libstrace_a-statfs64.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='statfs64.c' object='libstrace_a-statfs64.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-bpf_filter.obj: bpf_filter.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-bpf_filter.obj -MD -MP -MF $(DEPDIR)/libstrace_a-bpf_filter.Tpo -c -o libstrace_a-bpf_filter.obj `if test -f 'bpf_filter.c'; then $(CYGPATH_W) 'bpf_filter.c'; else $(CYGPATH_W) '$(srcdir)/bpf_filter.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-bpf_filter.Tpo $(DEPDIR)/libstrace_a-bpf_filter.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bpf_filter.c' object='libstrace_a-bpf_filter.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-statfs64.obj `if test -f 'statfs64.c'; then $(CYGPATH_W) 'statfs64.c'; else $(CYGPATH_W) '$(srcdir)/statfs64.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-bpf_filter.obj `if test -f 'bpf_filter.c'; then $(CYGPATH_W) 'bpf_filter.c'; else $(CYGPATH_W) '$(srcdir)/bpf_filter.c'; fi`
 
-libstrace_a-sync_file_range.o: sync_file_range.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sync_file_range.o -MD -MP -MF $(DEPDIR)/libstrace_a-sync_file_range.Tpo -c -o libstrace_a-sync_file_range.o `test -f 'sync_file_range.c' || echo '$(srcdir)/'`sync_file_range.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sync_file_range.Tpo $(DEPDIR)/libstrace_a-sync_file_range.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sync_file_range.c' object='libstrace_a-sync_file_range.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-bpf_seccomp_filter.o: bpf_seccomp_filter.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-bpf_seccomp_filter.o -MD -MP -MF $(DEPDIR)/libstrace_a-bpf_seccomp_filter.Tpo -c -o libstrace_a-bpf_seccomp_filter.o `test -f 'bpf_seccomp_filter.c' || echo '$(srcdir)/'`bpf_seccomp_filter.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-bpf_seccomp_filter.Tpo $(DEPDIR)/libstrace_a-bpf_seccomp_filter.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bpf_seccomp_filter.c' object='libstrace_a-bpf_seccomp_filter.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sync_file_range.o `test -f 'sync_file_range.c' || echo '$(srcdir)/'`sync_file_range.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-bpf_seccomp_filter.o `test -f 'bpf_seccomp_filter.c' || echo '$(srcdir)/'`bpf_seccomp_filter.c
 
-libstrace_a-sync_file_range.obj: sync_file_range.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sync_file_range.obj -MD -MP -MF $(DEPDIR)/libstrace_a-sync_file_range.Tpo -c -o libstrace_a-sync_file_range.obj `if test -f 'sync_file_range.c'; then $(CYGPATH_W) 'sync_file_range.c'; else $(CYGPATH_W) '$(srcdir)/sync_file_range.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sync_file_range.Tpo $(DEPDIR)/libstrace_a-sync_file_range.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sync_file_range.c' object='libstrace_a-sync_file_range.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-bpf_seccomp_filter.obj: bpf_seccomp_filter.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-bpf_seccomp_filter.obj -MD -MP -MF $(DEPDIR)/libstrace_a-bpf_seccomp_filter.Tpo -c -o libstrace_a-bpf_seccomp_filter.obj `if test -f 'bpf_seccomp_filter.c'; then $(CYGPATH_W) 'bpf_seccomp_filter.c'; else $(CYGPATH_W) '$(srcdir)/bpf_seccomp_filter.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-bpf_seccomp_filter.Tpo $(DEPDIR)/libstrace_a-bpf_seccomp_filter.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bpf_seccomp_filter.c' object='libstrace_a-bpf_seccomp_filter.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sync_file_range.obj `if test -f 'sync_file_range.c'; then $(CYGPATH_W) 'sync_file_range.c'; else $(CYGPATH_W) '$(srcdir)/sync_file_range.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-bpf_seccomp_filter.obj `if test -f 'bpf_seccomp_filter.c'; then $(CYGPATH_W) 'bpf_seccomp_filter.c'; else $(CYGPATH_W) '$(srcdir)/bpf_seccomp_filter.c'; fi`
 
-libstrace_a-sync_file_range2.o: sync_file_range2.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sync_file_range2.o -MD -MP -MF $(DEPDIR)/libstrace_a-sync_file_range2.Tpo -c -o libstrace_a-sync_file_range2.o `test -f 'sync_file_range2.c' || echo '$(srcdir)/'`sync_file_range2.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sync_file_range2.Tpo $(DEPDIR)/libstrace_a-sync_file_range2.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sync_file_range2.c' object='libstrace_a-sync_file_range2.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-bpf_sock_filter.o: bpf_sock_filter.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-bpf_sock_filter.o -MD -MP -MF $(DEPDIR)/libstrace_a-bpf_sock_filter.Tpo -c -o libstrace_a-bpf_sock_filter.o `test -f 'bpf_sock_filter.c' || echo '$(srcdir)/'`bpf_sock_filter.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-bpf_sock_filter.Tpo $(DEPDIR)/libstrace_a-bpf_sock_filter.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bpf_sock_filter.c' object='libstrace_a-bpf_sock_filter.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sync_file_range2.o `test -f 'sync_file_range2.c' || echo '$(srcdir)/'`sync_file_range2.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-bpf_sock_filter.o `test -f 'bpf_sock_filter.c' || echo '$(srcdir)/'`bpf_sock_filter.c
 
-libstrace_a-sync_file_range2.obj: sync_file_range2.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sync_file_range2.obj -MD -MP -MF $(DEPDIR)/libstrace_a-sync_file_range2.Tpo -c -o libstrace_a-sync_file_range2.obj `if test -f 'sync_file_range2.c'; then $(CYGPATH_W) 'sync_file_range2.c'; else $(CYGPATH_W) '$(srcdir)/sync_file_range2.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sync_file_range2.Tpo $(DEPDIR)/libstrace_a-sync_file_range2.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sync_file_range2.c' object='libstrace_a-sync_file_range2.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-bpf_sock_filter.obj: bpf_sock_filter.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-bpf_sock_filter.obj -MD -MP -MF $(DEPDIR)/libstrace_a-bpf_sock_filter.Tpo -c -o libstrace_a-bpf_sock_filter.obj `if test -f 'bpf_sock_filter.c'; then $(CYGPATH_W) 'bpf_sock_filter.c'; else $(CYGPATH_W) '$(srcdir)/bpf_sock_filter.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-bpf_sock_filter.Tpo $(DEPDIR)/libstrace_a-bpf_sock_filter.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bpf_sock_filter.c' object='libstrace_a-bpf_sock_filter.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sync_file_range2.obj `if test -f 'sync_file_range2.c'; then $(CYGPATH_W) 'sync_file_range2.c'; else $(CYGPATH_W) '$(srcdir)/sync_file_range2.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-bpf_sock_filter.obj `if test -f 'bpf_sock_filter.c'; then $(CYGPATH_W) 'bpf_sock_filter.c'; else $(CYGPATH_W) '$(srcdir)/bpf_sock_filter.c'; fi`
 
-libstrace_a-upeek.o: upeek.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-upeek.o -MD -MP -MF $(DEPDIR)/libstrace_a-upeek.Tpo -c -o libstrace_a-upeek.o `test -f 'upeek.c' || echo '$(srcdir)/'`upeek.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-upeek.Tpo $(DEPDIR)/libstrace_a-upeek.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='upeek.c' object='libstrace_a-upeek.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-btrfs.o: btrfs.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-btrfs.o -MD -MP -MF $(DEPDIR)/libstrace_a-btrfs.Tpo -c -o libstrace_a-btrfs.o `test -f 'btrfs.c' || echo '$(srcdir)/'`btrfs.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-btrfs.Tpo $(DEPDIR)/libstrace_a-btrfs.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='btrfs.c' object='libstrace_a-btrfs.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-upeek.o `test -f 'upeek.c' || echo '$(srcdir)/'`upeek.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-btrfs.o `test -f 'btrfs.c' || echo '$(srcdir)/'`btrfs.c
 
-libstrace_a-upeek.obj: upeek.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-upeek.obj -MD -MP -MF $(DEPDIR)/libstrace_a-upeek.Tpo -c -o libstrace_a-upeek.obj `if test -f 'upeek.c'; then $(CYGPATH_W) 'upeek.c'; else $(CYGPATH_W) '$(srcdir)/upeek.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-upeek.Tpo $(DEPDIR)/libstrace_a-upeek.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='upeek.c' object='libstrace_a-upeek.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-btrfs.obj: btrfs.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-btrfs.obj -MD -MP -MF $(DEPDIR)/libstrace_a-btrfs.Tpo -c -o libstrace_a-btrfs.obj `if test -f 'btrfs.c'; then $(CYGPATH_W) 'btrfs.c'; else $(CYGPATH_W) '$(srcdir)/btrfs.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-btrfs.Tpo $(DEPDIR)/libstrace_a-btrfs.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='btrfs.c' object='libstrace_a-btrfs.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-upeek.obj `if test -f 'upeek.c'; then $(CYGPATH_W) 'upeek.c'; else $(CYGPATH_W) '$(srcdir)/upeek.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-btrfs.obj `if test -f 'btrfs.c'; then $(CYGPATH_W) 'btrfs.c'; else $(CYGPATH_W) '$(srcdir)/btrfs.c'; fi`
 
-libstrace_a-upoke.o: upoke.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-upoke.o -MD -MP -MF $(DEPDIR)/libstrace_a-upoke.Tpo -c -o libstrace_a-upoke.o `test -f 'upoke.c' || echo '$(srcdir)/'`upoke.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-upoke.Tpo $(DEPDIR)/libstrace_a-upoke.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='upoke.c' object='libstrace_a-upoke.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-cacheflush.o: cacheflush.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-cacheflush.o -MD -MP -MF $(DEPDIR)/libstrace_a-cacheflush.Tpo -c -o libstrace_a-cacheflush.o `test -f 'cacheflush.c' || echo '$(srcdir)/'`cacheflush.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-cacheflush.Tpo $(DEPDIR)/libstrace_a-cacheflush.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='cacheflush.c' object='libstrace_a-cacheflush.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-upoke.o `test -f 'upoke.c' || echo '$(srcdir)/'`upoke.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-cacheflush.o `test -f 'cacheflush.c' || echo '$(srcdir)/'`cacheflush.c
 
-libstrace_a-upoke.obj: upoke.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-upoke.obj -MD -MP -MF $(DEPDIR)/libstrace_a-upoke.Tpo -c -o libstrace_a-upoke.obj `if test -f 'upoke.c'; then $(CYGPATH_W) 'upoke.c'; else $(CYGPATH_W) '$(srcdir)/upoke.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-upoke.Tpo $(DEPDIR)/libstrace_a-upoke.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='upoke.c' object='libstrace_a-upoke.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-cacheflush.obj: cacheflush.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-cacheflush.obj -MD -MP -MF $(DEPDIR)/libstrace_a-cacheflush.Tpo -c -o libstrace_a-cacheflush.obj `if test -f 'cacheflush.c'; then $(CYGPATH_W) 'cacheflush.c'; else $(CYGPATH_W) '$(srcdir)/cacheflush.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-cacheflush.Tpo $(DEPDIR)/libstrace_a-cacheflush.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='cacheflush.c' object='libstrace_a-cacheflush.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-upoke.obj `if test -f 'upoke.c'; then $(CYGPATH_W) 'upoke.c'; else $(CYGPATH_W) '$(srcdir)/upoke.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-cacheflush.obj `if test -f 'cacheflush.c'; then $(CYGPATH_W) 'cacheflush.c'; else $(CYGPATH_W) '$(srcdir)/cacheflush.c'; fi`
+
+libstrace_a-capability.o: capability.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-capability.o -MD -MP -MF $(DEPDIR)/libstrace_a-capability.Tpo -c -o libstrace_a-capability.o `test -f 'capability.c' || echo '$(srcdir)/'`capability.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-capability.Tpo $(DEPDIR)/libstrace_a-capability.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='capability.c' object='libstrace_a-capability.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-capability.o `test -f 'capability.c' || echo '$(srcdir)/'`capability.c
+
+libstrace_a-capability.obj: capability.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-capability.obj -MD -MP -MF $(DEPDIR)/libstrace_a-capability.Tpo -c -o libstrace_a-capability.obj `if test -f 'capability.c'; then $(CYGPATH_W) 'capability.c'; else $(CYGPATH_W) '$(srcdir)/capability.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-capability.Tpo $(DEPDIR)/libstrace_a-capability.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='capability.c' object='libstrace_a-capability.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-capability.obj `if test -f 'capability.c'; then $(CYGPATH_W) 'capability.c'; else $(CYGPATH_W) '$(srcdir)/capability.c'; fi`
+
+libstrace_a-chdir.o: chdir.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-chdir.o -MD -MP -MF $(DEPDIR)/libstrace_a-chdir.Tpo -c -o libstrace_a-chdir.o `test -f 'chdir.c' || echo '$(srcdir)/'`chdir.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-chdir.Tpo $(DEPDIR)/libstrace_a-chdir.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='chdir.c' object='libstrace_a-chdir.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-chdir.o `test -f 'chdir.c' || echo '$(srcdir)/'`chdir.c
+
+libstrace_a-chdir.obj: chdir.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-chdir.obj -MD -MP -MF $(DEPDIR)/libstrace_a-chdir.Tpo -c -o libstrace_a-chdir.obj `if test -f 'chdir.c'; then $(CYGPATH_W) 'chdir.c'; else $(CYGPATH_W) '$(srcdir)/chdir.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-chdir.Tpo $(DEPDIR)/libstrace_a-chdir.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='chdir.c' object='libstrace_a-chdir.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-chdir.obj `if test -f 'chdir.c'; then $(CYGPATH_W) 'chdir.c'; else $(CYGPATH_W) '$(srcdir)/chdir.c'; fi`
+
+libstrace_a-chmod.o: chmod.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-chmod.o -MD -MP -MF $(DEPDIR)/libstrace_a-chmod.Tpo -c -o libstrace_a-chmod.o `test -f 'chmod.c' || echo '$(srcdir)/'`chmod.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-chmod.Tpo $(DEPDIR)/libstrace_a-chmod.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='chmod.c' object='libstrace_a-chmod.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-chmod.o `test -f 'chmod.c' || echo '$(srcdir)/'`chmod.c
+
+libstrace_a-chmod.obj: chmod.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-chmod.obj -MD -MP -MF $(DEPDIR)/libstrace_a-chmod.Tpo -c -o libstrace_a-chmod.obj `if test -f 'chmod.c'; then $(CYGPATH_W) 'chmod.c'; else $(CYGPATH_W) '$(srcdir)/chmod.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-chmod.Tpo $(DEPDIR)/libstrace_a-chmod.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='chmod.c' object='libstrace_a-chmod.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-chmod.obj `if test -f 'chmod.c'; then $(CYGPATH_W) 'chmod.c'; else $(CYGPATH_W) '$(srcdir)/chmod.c'; fi`
+
+libstrace_a-clone.o: clone.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-clone.o -MD -MP -MF $(DEPDIR)/libstrace_a-clone.Tpo -c -o libstrace_a-clone.o `test -f 'clone.c' || echo '$(srcdir)/'`clone.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-clone.Tpo $(DEPDIR)/libstrace_a-clone.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='clone.c' object='libstrace_a-clone.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-clone.o `test -f 'clone.c' || echo '$(srcdir)/'`clone.c
+
+libstrace_a-clone.obj: clone.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-clone.obj -MD -MP -MF $(DEPDIR)/libstrace_a-clone.Tpo -c -o libstrace_a-clone.obj `if test -f 'clone.c'; then $(CYGPATH_W) 'clone.c'; else $(CYGPATH_W) '$(srcdir)/clone.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-clone.Tpo $(DEPDIR)/libstrace_a-clone.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='clone.c' object='libstrace_a-clone.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-clone.obj `if test -f 'clone.c'; then $(CYGPATH_W) 'clone.c'; else $(CYGPATH_W) '$(srcdir)/clone.c'; fi`
+
+libstrace_a-close_range.o: close_range.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-close_range.o -MD -MP -MF $(DEPDIR)/libstrace_a-close_range.Tpo -c -o libstrace_a-close_range.o `test -f 'close_range.c' || echo '$(srcdir)/'`close_range.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-close_range.Tpo $(DEPDIR)/libstrace_a-close_range.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='close_range.c' object='libstrace_a-close_range.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-close_range.o `test -f 'close_range.c' || echo '$(srcdir)/'`close_range.c
 
-strace-access.o: access.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-access.o -MD -MP -MF $(DEPDIR)/strace-access.Tpo -c -o strace-access.o `test -f 'access.c' || echo '$(srcdir)/'`access.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-access.Tpo $(DEPDIR)/strace-access.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='access.c' object='strace-access.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-close_range.obj: close_range.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-close_range.obj -MD -MP -MF $(DEPDIR)/libstrace_a-close_range.Tpo -c -o libstrace_a-close_range.obj `if test -f 'close_range.c'; then $(CYGPATH_W) 'close_range.c'; else $(CYGPATH_W) '$(srcdir)/close_range.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-close_range.Tpo $(DEPDIR)/libstrace_a-close_range.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='close_range.c' object='libstrace_a-close_range.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-access.o `test -f 'access.c' || echo '$(srcdir)/'`access.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-close_range.obj `if test -f 'close_range.c'; then $(CYGPATH_W) 'close_range.c'; else $(CYGPATH_W) '$(srcdir)/close_range.c'; fi`
 
-strace-access.obj: access.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-access.obj -MD -MP -MF $(DEPDIR)/strace-access.Tpo -c -o strace-access.obj `if test -f 'access.c'; then $(CYGPATH_W) 'access.c'; else $(CYGPATH_W) '$(srcdir)/access.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-access.Tpo $(DEPDIR)/strace-access.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='access.c' object='strace-access.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-copy_file_range.o: copy_file_range.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-copy_file_range.o -MD -MP -MF $(DEPDIR)/libstrace_a-copy_file_range.Tpo -c -o libstrace_a-copy_file_range.o `test -f 'copy_file_range.c' || echo '$(srcdir)/'`copy_file_range.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-copy_file_range.Tpo $(DEPDIR)/libstrace_a-copy_file_range.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='copy_file_range.c' object='libstrace_a-copy_file_range.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-access.obj `if test -f 'access.c'; then $(CYGPATH_W) 'access.c'; else $(CYGPATH_W) '$(srcdir)/access.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-copy_file_range.o `test -f 'copy_file_range.c' || echo '$(srcdir)/'`copy_file_range.c
 
-strace-affinity.o: affinity.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-affinity.o -MD -MP -MF $(DEPDIR)/strace-affinity.Tpo -c -o strace-affinity.o `test -f 'affinity.c' || echo '$(srcdir)/'`affinity.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-affinity.Tpo $(DEPDIR)/strace-affinity.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='affinity.c' object='strace-affinity.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-copy_file_range.obj: copy_file_range.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-copy_file_range.obj -MD -MP -MF $(DEPDIR)/libstrace_a-copy_file_range.Tpo -c -o libstrace_a-copy_file_range.obj `if test -f 'copy_file_range.c'; then $(CYGPATH_W) 'copy_file_range.c'; else $(CYGPATH_W) '$(srcdir)/copy_file_range.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-copy_file_range.Tpo $(DEPDIR)/libstrace_a-copy_file_range.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='copy_file_range.c' object='libstrace_a-copy_file_range.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-affinity.o `test -f 'affinity.c' || echo '$(srcdir)/'`affinity.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-copy_file_range.obj `if test -f 'copy_file_range.c'; then $(CYGPATH_W) 'copy_file_range.c'; else $(CYGPATH_W) '$(srcdir)/copy_file_range.c'; fi`
 
-strace-affinity.obj: affinity.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-affinity.obj -MD -MP -MF $(DEPDIR)/strace-affinity.Tpo -c -o strace-affinity.obj `if test -f 'affinity.c'; then $(CYGPATH_W) 'affinity.c'; else $(CYGPATH_W) '$(srcdir)/affinity.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-affinity.Tpo $(DEPDIR)/strace-affinity.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='affinity.c' object='strace-affinity.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-count.o: count.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-count.o -MD -MP -MF $(DEPDIR)/libstrace_a-count.Tpo -c -o libstrace_a-count.o `test -f 'count.c' || echo '$(srcdir)/'`count.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-count.Tpo $(DEPDIR)/libstrace_a-count.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='count.c' object='libstrace_a-count.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-affinity.obj `if test -f 'affinity.c'; then $(CYGPATH_W) 'affinity.c'; else $(CYGPATH_W) '$(srcdir)/affinity.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-count.o `test -f 'count.c' || echo '$(srcdir)/'`count.c
 
-strace-aio.o: aio.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-aio.o -MD -MP -MF $(DEPDIR)/strace-aio.Tpo -c -o strace-aio.o `test -f 'aio.c' || echo '$(srcdir)/'`aio.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-aio.Tpo $(DEPDIR)/strace-aio.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='aio.c' object='strace-aio.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-count.obj: count.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-count.obj -MD -MP -MF $(DEPDIR)/libstrace_a-count.Tpo -c -o libstrace_a-count.obj `if test -f 'count.c'; then $(CYGPATH_W) 'count.c'; else $(CYGPATH_W) '$(srcdir)/count.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-count.Tpo $(DEPDIR)/libstrace_a-count.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='count.c' object='libstrace_a-count.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-aio.o `test -f 'aio.c' || echo '$(srcdir)/'`aio.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-count.obj `if test -f 'count.c'; then $(CYGPATH_W) 'count.c'; else $(CYGPATH_W) '$(srcdir)/count.c'; fi`
 
-strace-aio.obj: aio.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-aio.obj -MD -MP -MF $(DEPDIR)/strace-aio.Tpo -c -o strace-aio.obj `if test -f 'aio.c'; then $(CYGPATH_W) 'aio.c'; else $(CYGPATH_W) '$(srcdir)/aio.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-aio.Tpo $(DEPDIR)/strace-aio.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='aio.c' object='strace-aio.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-delay.o: delay.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-delay.o -MD -MP -MF $(DEPDIR)/libstrace_a-delay.Tpo -c -o libstrace_a-delay.o `test -f 'delay.c' || echo '$(srcdir)/'`delay.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-delay.Tpo $(DEPDIR)/libstrace_a-delay.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='delay.c' object='libstrace_a-delay.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-aio.obj `if test -f 'aio.c'; then $(CYGPATH_W) 'aio.c'; else $(CYGPATH_W) '$(srcdir)/aio.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-delay.o `test -f 'delay.c' || echo '$(srcdir)/'`delay.c
 
-strace-alpha.o: alpha.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-alpha.o -MD -MP -MF $(DEPDIR)/strace-alpha.Tpo -c -o strace-alpha.o `test -f 'alpha.c' || echo '$(srcdir)/'`alpha.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-alpha.Tpo $(DEPDIR)/strace-alpha.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='alpha.c' object='strace-alpha.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-delay.obj: delay.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-delay.obj -MD -MP -MF $(DEPDIR)/libstrace_a-delay.Tpo -c -o libstrace_a-delay.obj `if test -f 'delay.c'; then $(CYGPATH_W) 'delay.c'; else $(CYGPATH_W) '$(srcdir)/delay.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-delay.Tpo $(DEPDIR)/libstrace_a-delay.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='delay.c' object='libstrace_a-delay.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-alpha.o `test -f 'alpha.c' || echo '$(srcdir)/'`alpha.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-delay.obj `if test -f 'delay.c'; then $(CYGPATH_W) 'delay.c'; else $(CYGPATH_W) '$(srcdir)/delay.c'; fi`
 
-strace-alpha.obj: alpha.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-alpha.obj -MD -MP -MF $(DEPDIR)/strace-alpha.Tpo -c -o strace-alpha.obj `if test -f 'alpha.c'; then $(CYGPATH_W) 'alpha.c'; else $(CYGPATH_W) '$(srcdir)/alpha.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-alpha.Tpo $(DEPDIR)/strace-alpha.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='alpha.c' object='strace-alpha.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-desc.o: desc.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-desc.o -MD -MP -MF $(DEPDIR)/libstrace_a-desc.Tpo -c -o libstrace_a-desc.o `test -f 'desc.c' || echo '$(srcdir)/'`desc.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-desc.Tpo $(DEPDIR)/libstrace_a-desc.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='desc.c' object='libstrace_a-desc.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-alpha.obj `if test -f 'alpha.c'; then $(CYGPATH_W) 'alpha.c'; else $(CYGPATH_W) '$(srcdir)/alpha.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-desc.o `test -f 'desc.c' || echo '$(srcdir)/'`desc.c
 
-strace-basic_filters.o: basic_filters.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-basic_filters.o -MD -MP -MF $(DEPDIR)/strace-basic_filters.Tpo -c -o strace-basic_filters.o `test -f 'basic_filters.c' || echo '$(srcdir)/'`basic_filters.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-basic_filters.Tpo $(DEPDIR)/strace-basic_filters.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='basic_filters.c' object='strace-basic_filters.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-desc.obj: desc.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-desc.obj -MD -MP -MF $(DEPDIR)/libstrace_a-desc.Tpo -c -o libstrace_a-desc.obj `if test -f 'desc.c'; then $(CYGPATH_W) 'desc.c'; else $(CYGPATH_W) '$(srcdir)/desc.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-desc.Tpo $(DEPDIR)/libstrace_a-desc.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='desc.c' object='libstrace_a-desc.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-basic_filters.o `test -f 'basic_filters.c' || echo '$(srcdir)/'`basic_filters.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-desc.obj `if test -f 'desc.c'; then $(CYGPATH_W) 'desc.c'; else $(CYGPATH_W) '$(srcdir)/desc.c'; fi`
 
-strace-basic_filters.obj: basic_filters.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-basic_filters.obj -MD -MP -MF $(DEPDIR)/strace-basic_filters.Tpo -c -o strace-basic_filters.obj `if test -f 'basic_filters.c'; then $(CYGPATH_W) 'basic_filters.c'; else $(CYGPATH_W) '$(srcdir)/basic_filters.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-basic_filters.Tpo $(DEPDIR)/strace-basic_filters.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='basic_filters.c' object='strace-basic_filters.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-dirent.o: dirent.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-dirent.o -MD -MP -MF $(DEPDIR)/libstrace_a-dirent.Tpo -c -o libstrace_a-dirent.o `test -f 'dirent.c' || echo '$(srcdir)/'`dirent.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-dirent.Tpo $(DEPDIR)/libstrace_a-dirent.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='dirent.c' object='libstrace_a-dirent.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-basic_filters.obj `if test -f 'basic_filters.c'; then $(CYGPATH_W) 'basic_filters.c'; else $(CYGPATH_W) '$(srcdir)/basic_filters.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-dirent.o `test -f 'dirent.c' || echo '$(srcdir)/'`dirent.c
 
-strace-bind.o: bind.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-bind.o -MD -MP -MF $(DEPDIR)/strace-bind.Tpo -c -o strace-bind.o `test -f 'bind.c' || echo '$(srcdir)/'`bind.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-bind.Tpo $(DEPDIR)/strace-bind.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bind.c' object='strace-bind.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-dirent.obj: dirent.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-dirent.obj -MD -MP -MF $(DEPDIR)/libstrace_a-dirent.Tpo -c -o libstrace_a-dirent.obj `if test -f 'dirent.c'; then $(CYGPATH_W) 'dirent.c'; else $(CYGPATH_W) '$(srcdir)/dirent.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-dirent.Tpo $(DEPDIR)/libstrace_a-dirent.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='dirent.c' object='libstrace_a-dirent.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-bind.o `test -f 'bind.c' || echo '$(srcdir)/'`bind.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-dirent.obj `if test -f 'dirent.c'; then $(CYGPATH_W) 'dirent.c'; else $(CYGPATH_W) '$(srcdir)/dirent.c'; fi`
 
-strace-bind.obj: bind.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-bind.obj -MD -MP -MF $(DEPDIR)/strace-bind.Tpo -c -o strace-bind.obj `if test -f 'bind.c'; then $(CYGPATH_W) 'bind.c'; else $(CYGPATH_W) '$(srcdir)/bind.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-bind.Tpo $(DEPDIR)/strace-bind.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bind.c' object='strace-bind.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-dirent64.o: dirent64.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-dirent64.o -MD -MP -MF $(DEPDIR)/libstrace_a-dirent64.Tpo -c -o libstrace_a-dirent64.o `test -f 'dirent64.c' || echo '$(srcdir)/'`dirent64.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-dirent64.Tpo $(DEPDIR)/libstrace_a-dirent64.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='dirent64.c' object='libstrace_a-dirent64.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-bind.obj `if test -f 'bind.c'; then $(CYGPATH_W) 'bind.c'; else $(CYGPATH_W) '$(srcdir)/bind.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-dirent64.o `test -f 'dirent64.c' || echo '$(srcdir)/'`dirent64.c
 
-strace-bjm.o: bjm.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-bjm.o -MD -MP -MF $(DEPDIR)/strace-bjm.Tpo -c -o strace-bjm.o `test -f 'bjm.c' || echo '$(srcdir)/'`bjm.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-bjm.Tpo $(DEPDIR)/strace-bjm.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bjm.c' object='strace-bjm.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-dirent64.obj: dirent64.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-dirent64.obj -MD -MP -MF $(DEPDIR)/libstrace_a-dirent64.Tpo -c -o libstrace_a-dirent64.obj `if test -f 'dirent64.c'; then $(CYGPATH_W) 'dirent64.c'; else $(CYGPATH_W) '$(srcdir)/dirent64.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-dirent64.Tpo $(DEPDIR)/libstrace_a-dirent64.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='dirent64.c' object='libstrace_a-dirent64.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-bjm.o `test -f 'bjm.c' || echo '$(srcdir)/'`bjm.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-dirent64.obj `if test -f 'dirent64.c'; then $(CYGPATH_W) 'dirent64.c'; else $(CYGPATH_W) '$(srcdir)/dirent64.c'; fi`
 
-strace-bjm.obj: bjm.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-bjm.obj -MD -MP -MF $(DEPDIR)/strace-bjm.Tpo -c -o strace-bjm.obj `if test -f 'bjm.c'; then $(CYGPATH_W) 'bjm.c'; else $(CYGPATH_W) '$(srcdir)/bjm.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-bjm.Tpo $(DEPDIR)/strace-bjm.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bjm.c' object='strace-bjm.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-dirent_types.o: dirent_types.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-dirent_types.o -MD -MP -MF $(DEPDIR)/libstrace_a-dirent_types.Tpo -c -o libstrace_a-dirent_types.o `test -f 'dirent_types.c' || echo '$(srcdir)/'`dirent_types.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-dirent_types.Tpo $(DEPDIR)/libstrace_a-dirent_types.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='dirent_types.c' object='libstrace_a-dirent_types.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-bjm.obj `if test -f 'bjm.c'; then $(CYGPATH_W) 'bjm.c'; else $(CYGPATH_W) '$(srcdir)/bjm.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-dirent_types.o `test -f 'dirent_types.c' || echo '$(srcdir)/'`dirent_types.c
 
-strace-block.o: block.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-block.o -MD -MP -MF $(DEPDIR)/strace-block.Tpo -c -o strace-block.o `test -f 'block.c' || echo '$(srcdir)/'`block.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-block.Tpo $(DEPDIR)/strace-block.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='block.c' object='strace-block.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-dirent_types.obj: dirent_types.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-dirent_types.obj -MD -MP -MF $(DEPDIR)/libstrace_a-dirent_types.Tpo -c -o libstrace_a-dirent_types.obj `if test -f 'dirent_types.c'; then $(CYGPATH_W) 'dirent_types.c'; else $(CYGPATH_W) '$(srcdir)/dirent_types.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-dirent_types.Tpo $(DEPDIR)/libstrace_a-dirent_types.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='dirent_types.c' object='libstrace_a-dirent_types.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-block.o `test -f 'block.c' || echo '$(srcdir)/'`block.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-dirent_types.obj `if test -f 'dirent_types.c'; then $(CYGPATH_W) 'dirent_types.c'; else $(CYGPATH_W) '$(srcdir)/dirent_types.c'; fi`
 
-strace-block.obj: block.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-block.obj -MD -MP -MF $(DEPDIR)/strace-block.Tpo -c -o strace-block.obj `if test -f 'block.c'; then $(CYGPATH_W) 'block.c'; else $(CYGPATH_W) '$(srcdir)/block.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-block.Tpo $(DEPDIR)/strace-block.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='block.c' object='strace-block.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-dm.o: dm.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-dm.o -MD -MP -MF $(DEPDIR)/libstrace_a-dm.Tpo -c -o libstrace_a-dm.o `test -f 'dm.c' || echo '$(srcdir)/'`dm.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-dm.Tpo $(DEPDIR)/libstrace_a-dm.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='dm.c' object='libstrace_a-dm.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-block.obj `if test -f 'block.c'; then $(CYGPATH_W) 'block.c'; else $(CYGPATH_W) '$(srcdir)/block.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-dm.o `test -f 'dm.c' || echo '$(srcdir)/'`dm.c
 
-strace-bpf.o: bpf.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-bpf.o -MD -MP -MF $(DEPDIR)/strace-bpf.Tpo -c -o strace-bpf.o `test -f 'bpf.c' || echo '$(srcdir)/'`bpf.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-bpf.Tpo $(DEPDIR)/strace-bpf.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bpf.c' object='strace-bpf.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-dm.obj: dm.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-dm.obj -MD -MP -MF $(DEPDIR)/libstrace_a-dm.Tpo -c -o libstrace_a-dm.obj `if test -f 'dm.c'; then $(CYGPATH_W) 'dm.c'; else $(CYGPATH_W) '$(srcdir)/dm.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-dm.Tpo $(DEPDIR)/libstrace_a-dm.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='dm.c' object='libstrace_a-dm.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-bpf.o `test -f 'bpf.c' || echo '$(srcdir)/'`bpf.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-dm.obj `if test -f 'dm.c'; then $(CYGPATH_W) 'dm.c'; else $(CYGPATH_W) '$(srcdir)/dm.c'; fi`
 
-strace-bpf.obj: bpf.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-bpf.obj -MD -MP -MF $(DEPDIR)/strace-bpf.Tpo -c -o strace-bpf.obj `if test -f 'bpf.c'; then $(CYGPATH_W) 'bpf.c'; else $(CYGPATH_W) '$(srcdir)/bpf.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-bpf.Tpo $(DEPDIR)/strace-bpf.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bpf.c' object='strace-bpf.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-dup.o: dup.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-dup.o -MD -MP -MF $(DEPDIR)/libstrace_a-dup.Tpo -c -o libstrace_a-dup.o `test -f 'dup.c' || echo '$(srcdir)/'`dup.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-dup.Tpo $(DEPDIR)/libstrace_a-dup.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='dup.c' object='libstrace_a-dup.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-bpf.obj `if test -f 'bpf.c'; then $(CYGPATH_W) 'bpf.c'; else $(CYGPATH_W) '$(srcdir)/bpf.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-dup.o `test -f 'dup.c' || echo '$(srcdir)/'`dup.c
 
-strace-bpf_filter.o: bpf_filter.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-bpf_filter.o -MD -MP -MF $(DEPDIR)/strace-bpf_filter.Tpo -c -o strace-bpf_filter.o `test -f 'bpf_filter.c' || echo '$(srcdir)/'`bpf_filter.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-bpf_filter.Tpo $(DEPDIR)/strace-bpf_filter.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bpf_filter.c' object='strace-bpf_filter.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-dup.obj: dup.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-dup.obj -MD -MP -MF $(DEPDIR)/libstrace_a-dup.Tpo -c -o libstrace_a-dup.obj `if test -f 'dup.c'; then $(CYGPATH_W) 'dup.c'; else $(CYGPATH_W) '$(srcdir)/dup.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-dup.Tpo $(DEPDIR)/libstrace_a-dup.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='dup.c' object='libstrace_a-dup.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-bpf_filter.o `test -f 'bpf_filter.c' || echo '$(srcdir)/'`bpf_filter.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-dup.obj `if test -f 'dup.c'; then $(CYGPATH_W) 'dup.c'; else $(CYGPATH_W) '$(srcdir)/dup.c'; fi`
 
-strace-bpf_filter.obj: bpf_filter.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-bpf_filter.obj -MD -MP -MF $(DEPDIR)/strace-bpf_filter.Tpo -c -o strace-bpf_filter.obj `if test -f 'bpf_filter.c'; then $(CYGPATH_W) 'bpf_filter.c'; else $(CYGPATH_W) '$(srcdir)/bpf_filter.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-bpf_filter.Tpo $(DEPDIR)/strace-bpf_filter.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bpf_filter.c' object='strace-bpf_filter.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-dyxlat.o: dyxlat.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-dyxlat.o -MD -MP -MF $(DEPDIR)/libstrace_a-dyxlat.Tpo -c -o libstrace_a-dyxlat.o `test -f 'dyxlat.c' || echo '$(srcdir)/'`dyxlat.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-dyxlat.Tpo $(DEPDIR)/libstrace_a-dyxlat.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='dyxlat.c' object='libstrace_a-dyxlat.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-bpf_filter.obj `if test -f 'bpf_filter.c'; then $(CYGPATH_W) 'bpf_filter.c'; else $(CYGPATH_W) '$(srcdir)/bpf_filter.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-dyxlat.o `test -f 'dyxlat.c' || echo '$(srcdir)/'`dyxlat.c
 
-strace-bpf_seccomp_filter.o: bpf_seccomp_filter.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-bpf_seccomp_filter.o -MD -MP -MF $(DEPDIR)/strace-bpf_seccomp_filter.Tpo -c -o strace-bpf_seccomp_filter.o `test -f 'bpf_seccomp_filter.c' || echo '$(srcdir)/'`bpf_seccomp_filter.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-bpf_seccomp_filter.Tpo $(DEPDIR)/strace-bpf_seccomp_filter.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bpf_seccomp_filter.c' object='strace-bpf_seccomp_filter.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-dyxlat.obj: dyxlat.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-dyxlat.obj -MD -MP -MF $(DEPDIR)/libstrace_a-dyxlat.Tpo -c -o libstrace_a-dyxlat.obj `if test -f 'dyxlat.c'; then $(CYGPATH_W) 'dyxlat.c'; else $(CYGPATH_W) '$(srcdir)/dyxlat.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-dyxlat.Tpo $(DEPDIR)/libstrace_a-dyxlat.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='dyxlat.c' object='libstrace_a-dyxlat.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-bpf_seccomp_filter.o `test -f 'bpf_seccomp_filter.c' || echo '$(srcdir)/'`bpf_seccomp_filter.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-dyxlat.obj `if test -f 'dyxlat.c'; then $(CYGPATH_W) 'dyxlat.c'; else $(CYGPATH_W) '$(srcdir)/dyxlat.c'; fi`
 
-strace-bpf_seccomp_filter.obj: bpf_seccomp_filter.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-bpf_seccomp_filter.obj -MD -MP -MF $(DEPDIR)/strace-bpf_seccomp_filter.Tpo -c -o strace-bpf_seccomp_filter.obj `if test -f 'bpf_seccomp_filter.c'; then $(CYGPATH_W) 'bpf_seccomp_filter.c'; else $(CYGPATH_W) '$(srcdir)/bpf_seccomp_filter.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-bpf_seccomp_filter.Tpo $(DEPDIR)/strace-bpf_seccomp_filter.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bpf_seccomp_filter.c' object='strace-bpf_seccomp_filter.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-epoll.o: epoll.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-epoll.o -MD -MP -MF $(DEPDIR)/libstrace_a-epoll.Tpo -c -o libstrace_a-epoll.o `test -f 'epoll.c' || echo '$(srcdir)/'`epoll.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-epoll.Tpo $(DEPDIR)/libstrace_a-epoll.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='epoll.c' object='libstrace_a-epoll.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-bpf_seccomp_filter.obj `if test -f 'bpf_seccomp_filter.c'; then $(CYGPATH_W) 'bpf_seccomp_filter.c'; else $(CYGPATH_W) '$(srcdir)/bpf_seccomp_filter.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-epoll.o `test -f 'epoll.c' || echo '$(srcdir)/'`epoll.c
 
-strace-bpf_sock_filter.o: bpf_sock_filter.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-bpf_sock_filter.o -MD -MP -MF $(DEPDIR)/strace-bpf_sock_filter.Tpo -c -o strace-bpf_sock_filter.o `test -f 'bpf_sock_filter.c' || echo '$(srcdir)/'`bpf_sock_filter.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-bpf_sock_filter.Tpo $(DEPDIR)/strace-bpf_sock_filter.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bpf_sock_filter.c' object='strace-bpf_sock_filter.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-epoll.obj: epoll.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-epoll.obj -MD -MP -MF $(DEPDIR)/libstrace_a-epoll.Tpo -c -o libstrace_a-epoll.obj `if test -f 'epoll.c'; then $(CYGPATH_W) 'epoll.c'; else $(CYGPATH_W) '$(srcdir)/epoll.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-epoll.Tpo $(DEPDIR)/libstrace_a-epoll.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='epoll.c' object='libstrace_a-epoll.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-bpf_sock_filter.o `test -f 'bpf_sock_filter.c' || echo '$(srcdir)/'`bpf_sock_filter.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-epoll.obj `if test -f 'epoll.c'; then $(CYGPATH_W) 'epoll.c'; else $(CYGPATH_W) '$(srcdir)/epoll.c'; fi`
 
-strace-bpf_sock_filter.obj: bpf_sock_filter.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-bpf_sock_filter.obj -MD -MP -MF $(DEPDIR)/strace-bpf_sock_filter.Tpo -c -o strace-bpf_sock_filter.obj `if test -f 'bpf_sock_filter.c'; then $(CYGPATH_W) 'bpf_sock_filter.c'; else $(CYGPATH_W) '$(srcdir)/bpf_sock_filter.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-bpf_sock_filter.Tpo $(DEPDIR)/strace-bpf_sock_filter.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bpf_sock_filter.c' object='strace-bpf_sock_filter.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-error_prints.o: error_prints.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-error_prints.o -MD -MP -MF $(DEPDIR)/libstrace_a-error_prints.Tpo -c -o libstrace_a-error_prints.o `test -f 'error_prints.c' || echo '$(srcdir)/'`error_prints.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-error_prints.Tpo $(DEPDIR)/libstrace_a-error_prints.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='error_prints.c' object='libstrace_a-error_prints.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-bpf_sock_filter.obj `if test -f 'bpf_sock_filter.c'; then $(CYGPATH_W) 'bpf_sock_filter.c'; else $(CYGPATH_W) '$(srcdir)/bpf_sock_filter.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-error_prints.o `test -f 'error_prints.c' || echo '$(srcdir)/'`error_prints.c
 
-strace-btrfs.o: btrfs.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-btrfs.o -MD -MP -MF $(DEPDIR)/strace-btrfs.Tpo -c -o strace-btrfs.o `test -f 'btrfs.c' || echo '$(srcdir)/'`btrfs.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-btrfs.Tpo $(DEPDIR)/strace-btrfs.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='btrfs.c' object='strace-btrfs.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-error_prints.obj: error_prints.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-error_prints.obj -MD -MP -MF $(DEPDIR)/libstrace_a-error_prints.Tpo -c -o libstrace_a-error_prints.obj `if test -f 'error_prints.c'; then $(CYGPATH_W) 'error_prints.c'; else $(CYGPATH_W) '$(srcdir)/error_prints.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-error_prints.Tpo $(DEPDIR)/libstrace_a-error_prints.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='error_prints.c' object='libstrace_a-error_prints.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-btrfs.o `test -f 'btrfs.c' || echo '$(srcdir)/'`btrfs.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-error_prints.obj `if test -f 'error_prints.c'; then $(CYGPATH_W) 'error_prints.c'; else $(CYGPATH_W) '$(srcdir)/error_prints.c'; fi`
 
-strace-btrfs.obj: btrfs.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-btrfs.obj -MD -MP -MF $(DEPDIR)/strace-btrfs.Tpo -c -o strace-btrfs.obj `if test -f 'btrfs.c'; then $(CYGPATH_W) 'btrfs.c'; else $(CYGPATH_W) '$(srcdir)/btrfs.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-btrfs.Tpo $(DEPDIR)/strace-btrfs.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='btrfs.c' object='strace-btrfs.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-evdev.o: evdev.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-evdev.o -MD -MP -MF $(DEPDIR)/libstrace_a-evdev.Tpo -c -o libstrace_a-evdev.o `test -f 'evdev.c' || echo '$(srcdir)/'`evdev.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-evdev.Tpo $(DEPDIR)/libstrace_a-evdev.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='evdev.c' object='libstrace_a-evdev.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-btrfs.obj `if test -f 'btrfs.c'; then $(CYGPATH_W) 'btrfs.c'; else $(CYGPATH_W) '$(srcdir)/btrfs.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-evdev.o `test -f 'evdev.c' || echo '$(srcdir)/'`evdev.c
 
-strace-cacheflush.o: cacheflush.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-cacheflush.o -MD -MP -MF $(DEPDIR)/strace-cacheflush.Tpo -c -o strace-cacheflush.o `test -f 'cacheflush.c' || echo '$(srcdir)/'`cacheflush.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-cacheflush.Tpo $(DEPDIR)/strace-cacheflush.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='cacheflush.c' object='strace-cacheflush.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-evdev.obj: evdev.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-evdev.obj -MD -MP -MF $(DEPDIR)/libstrace_a-evdev.Tpo -c -o libstrace_a-evdev.obj `if test -f 'evdev.c'; then $(CYGPATH_W) 'evdev.c'; else $(CYGPATH_W) '$(srcdir)/evdev.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-evdev.Tpo $(DEPDIR)/libstrace_a-evdev.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='evdev.c' object='libstrace_a-evdev.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-cacheflush.o `test -f 'cacheflush.c' || echo '$(srcdir)/'`cacheflush.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-evdev.obj `if test -f 'evdev.c'; then $(CYGPATH_W) 'evdev.c'; else $(CYGPATH_W) '$(srcdir)/evdev.c'; fi`
 
-strace-cacheflush.obj: cacheflush.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-cacheflush.obj -MD -MP -MF $(DEPDIR)/strace-cacheflush.Tpo -c -o strace-cacheflush.obj `if test -f 'cacheflush.c'; then $(CYGPATH_W) 'cacheflush.c'; else $(CYGPATH_W) '$(srcdir)/cacheflush.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-cacheflush.Tpo $(DEPDIR)/strace-cacheflush.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='cacheflush.c' object='strace-cacheflush.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-evdev_mpers.o: evdev_mpers.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-evdev_mpers.o -MD -MP -MF $(DEPDIR)/libstrace_a-evdev_mpers.Tpo -c -o libstrace_a-evdev_mpers.o `test -f 'evdev_mpers.c' || echo '$(srcdir)/'`evdev_mpers.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-evdev_mpers.Tpo $(DEPDIR)/libstrace_a-evdev_mpers.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='evdev_mpers.c' object='libstrace_a-evdev_mpers.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-cacheflush.obj `if test -f 'cacheflush.c'; then $(CYGPATH_W) 'cacheflush.c'; else $(CYGPATH_W) '$(srcdir)/cacheflush.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-evdev_mpers.o `test -f 'evdev_mpers.c' || echo '$(srcdir)/'`evdev_mpers.c
 
-strace-capability.o: capability.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-capability.o -MD -MP -MF $(DEPDIR)/strace-capability.Tpo -c -o strace-capability.o `test -f 'capability.c' || echo '$(srcdir)/'`capability.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-capability.Tpo $(DEPDIR)/strace-capability.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='capability.c' object='strace-capability.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-evdev_mpers.obj: evdev_mpers.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-evdev_mpers.obj -MD -MP -MF $(DEPDIR)/libstrace_a-evdev_mpers.Tpo -c -o libstrace_a-evdev_mpers.obj `if test -f 'evdev_mpers.c'; then $(CYGPATH_W) 'evdev_mpers.c'; else $(CYGPATH_W) '$(srcdir)/evdev_mpers.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-evdev_mpers.Tpo $(DEPDIR)/libstrace_a-evdev_mpers.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='evdev_mpers.c' object='libstrace_a-evdev_mpers.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-capability.o `test -f 'capability.c' || echo '$(srcdir)/'`capability.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-evdev_mpers.obj `if test -f 'evdev_mpers.c'; then $(CYGPATH_W) 'evdev_mpers.c'; else $(CYGPATH_W) '$(srcdir)/evdev_mpers.c'; fi`
 
-strace-capability.obj: capability.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-capability.obj -MD -MP -MF $(DEPDIR)/strace-capability.Tpo -c -o strace-capability.obj `if test -f 'capability.c'; then $(CYGPATH_W) 'capability.c'; else $(CYGPATH_W) '$(srcdir)/capability.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-capability.Tpo $(DEPDIR)/strace-capability.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='capability.c' object='strace-capability.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-eventfd.o: eventfd.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-eventfd.o -MD -MP -MF $(DEPDIR)/libstrace_a-eventfd.Tpo -c -o libstrace_a-eventfd.o `test -f 'eventfd.c' || echo '$(srcdir)/'`eventfd.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-eventfd.Tpo $(DEPDIR)/libstrace_a-eventfd.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='eventfd.c' object='libstrace_a-eventfd.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-capability.obj `if test -f 'capability.c'; then $(CYGPATH_W) 'capability.c'; else $(CYGPATH_W) '$(srcdir)/capability.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-eventfd.o `test -f 'eventfd.c' || echo '$(srcdir)/'`eventfd.c
 
-strace-chdir.o: chdir.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-chdir.o -MD -MP -MF $(DEPDIR)/strace-chdir.Tpo -c -o strace-chdir.o `test -f 'chdir.c' || echo '$(srcdir)/'`chdir.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-chdir.Tpo $(DEPDIR)/strace-chdir.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='chdir.c' object='strace-chdir.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-eventfd.obj: eventfd.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-eventfd.obj -MD -MP -MF $(DEPDIR)/libstrace_a-eventfd.Tpo -c -o libstrace_a-eventfd.obj `if test -f 'eventfd.c'; then $(CYGPATH_W) 'eventfd.c'; else $(CYGPATH_W) '$(srcdir)/eventfd.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-eventfd.Tpo $(DEPDIR)/libstrace_a-eventfd.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='eventfd.c' object='libstrace_a-eventfd.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-chdir.o `test -f 'chdir.c' || echo '$(srcdir)/'`chdir.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-eventfd.obj `if test -f 'eventfd.c'; then $(CYGPATH_W) 'eventfd.c'; else $(CYGPATH_W) '$(srcdir)/eventfd.c'; fi`
 
-strace-chdir.obj: chdir.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-chdir.obj -MD -MP -MF $(DEPDIR)/strace-chdir.Tpo -c -o strace-chdir.obj `if test -f 'chdir.c'; then $(CYGPATH_W) 'chdir.c'; else $(CYGPATH_W) '$(srcdir)/chdir.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-chdir.Tpo $(DEPDIR)/strace-chdir.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='chdir.c' object='strace-chdir.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-execve.o: execve.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-execve.o -MD -MP -MF $(DEPDIR)/libstrace_a-execve.Tpo -c -o libstrace_a-execve.o `test -f 'execve.c' || echo '$(srcdir)/'`execve.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-execve.Tpo $(DEPDIR)/libstrace_a-execve.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='execve.c' object='libstrace_a-execve.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-chdir.obj `if test -f 'chdir.c'; then $(CYGPATH_W) 'chdir.c'; else $(CYGPATH_W) '$(srcdir)/chdir.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-execve.o `test -f 'execve.c' || echo '$(srcdir)/'`execve.c
 
-strace-chmod.o: chmod.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-chmod.o -MD -MP -MF $(DEPDIR)/strace-chmod.Tpo -c -o strace-chmod.o `test -f 'chmod.c' || echo '$(srcdir)/'`chmod.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-chmod.Tpo $(DEPDIR)/strace-chmod.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='chmod.c' object='strace-chmod.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-execve.obj: execve.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-execve.obj -MD -MP -MF $(DEPDIR)/libstrace_a-execve.Tpo -c -o libstrace_a-execve.obj `if test -f 'execve.c'; then $(CYGPATH_W) 'execve.c'; else $(CYGPATH_W) '$(srcdir)/execve.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-execve.Tpo $(DEPDIR)/libstrace_a-execve.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='execve.c' object='libstrace_a-execve.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-chmod.o `test -f 'chmod.c' || echo '$(srcdir)/'`chmod.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-execve.obj `if test -f 'execve.c'; then $(CYGPATH_W) 'execve.c'; else $(CYGPATH_W) '$(srcdir)/execve.c'; fi`
 
-strace-chmod.obj: chmod.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-chmod.obj -MD -MP -MF $(DEPDIR)/strace-chmod.Tpo -c -o strace-chmod.obj `if test -f 'chmod.c'; then $(CYGPATH_W) 'chmod.c'; else $(CYGPATH_W) '$(srcdir)/chmod.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-chmod.Tpo $(DEPDIR)/strace-chmod.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='chmod.c' object='strace-chmod.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fadvise.o: fadvise.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fadvise.o -MD -MP -MF $(DEPDIR)/libstrace_a-fadvise.Tpo -c -o libstrace_a-fadvise.o `test -f 'fadvise.c' || echo '$(srcdir)/'`fadvise.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fadvise.Tpo $(DEPDIR)/libstrace_a-fadvise.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fadvise.c' object='libstrace_a-fadvise.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-chmod.obj `if test -f 'chmod.c'; then $(CYGPATH_W) 'chmod.c'; else $(CYGPATH_W) '$(srcdir)/chmod.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fadvise.o `test -f 'fadvise.c' || echo '$(srcdir)/'`fadvise.c
 
-strace-clone.o: clone.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-clone.o -MD -MP -MF $(DEPDIR)/strace-clone.Tpo -c -o strace-clone.o `test -f 'clone.c' || echo '$(srcdir)/'`clone.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-clone.Tpo $(DEPDIR)/strace-clone.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='clone.c' object='strace-clone.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fadvise.obj: fadvise.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fadvise.obj -MD -MP -MF $(DEPDIR)/libstrace_a-fadvise.Tpo -c -o libstrace_a-fadvise.obj `if test -f 'fadvise.c'; then $(CYGPATH_W) 'fadvise.c'; else $(CYGPATH_W) '$(srcdir)/fadvise.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fadvise.Tpo $(DEPDIR)/libstrace_a-fadvise.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fadvise.c' object='libstrace_a-fadvise.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-clone.o `test -f 'clone.c' || echo '$(srcdir)/'`clone.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fadvise.obj `if test -f 'fadvise.c'; then $(CYGPATH_W) 'fadvise.c'; else $(CYGPATH_W) '$(srcdir)/fadvise.c'; fi`
 
-strace-clone.obj: clone.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-clone.obj -MD -MP -MF $(DEPDIR)/strace-clone.Tpo -c -o strace-clone.obj `if test -f 'clone.c'; then $(CYGPATH_W) 'clone.c'; else $(CYGPATH_W) '$(srcdir)/clone.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-clone.Tpo $(DEPDIR)/strace-clone.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='clone.c' object='strace-clone.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fallocate.o: fallocate.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fallocate.o -MD -MP -MF $(DEPDIR)/libstrace_a-fallocate.Tpo -c -o libstrace_a-fallocate.o `test -f 'fallocate.c' || echo '$(srcdir)/'`fallocate.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fallocate.Tpo $(DEPDIR)/libstrace_a-fallocate.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fallocate.c' object='libstrace_a-fallocate.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-clone.obj `if test -f 'clone.c'; then $(CYGPATH_W) 'clone.c'; else $(CYGPATH_W) '$(srcdir)/clone.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fallocate.o `test -f 'fallocate.c' || echo '$(srcdir)/'`fallocate.c
 
-strace-copy_file_range.o: copy_file_range.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-copy_file_range.o -MD -MP -MF $(DEPDIR)/strace-copy_file_range.Tpo -c -o strace-copy_file_range.o `test -f 'copy_file_range.c' || echo '$(srcdir)/'`copy_file_range.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-copy_file_range.Tpo $(DEPDIR)/strace-copy_file_range.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='copy_file_range.c' object='strace-copy_file_range.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fallocate.obj: fallocate.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fallocate.obj -MD -MP -MF $(DEPDIR)/libstrace_a-fallocate.Tpo -c -o libstrace_a-fallocate.obj `if test -f 'fallocate.c'; then $(CYGPATH_W) 'fallocate.c'; else $(CYGPATH_W) '$(srcdir)/fallocate.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fallocate.Tpo $(DEPDIR)/libstrace_a-fallocate.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fallocate.c' object='libstrace_a-fallocate.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-copy_file_range.o `test -f 'copy_file_range.c' || echo '$(srcdir)/'`copy_file_range.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fallocate.obj `if test -f 'fallocate.c'; then $(CYGPATH_W) 'fallocate.c'; else $(CYGPATH_W) '$(srcdir)/fallocate.c'; fi`
 
-strace-copy_file_range.obj: copy_file_range.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-copy_file_range.obj -MD -MP -MF $(DEPDIR)/strace-copy_file_range.Tpo -c -o strace-copy_file_range.obj `if test -f 'copy_file_range.c'; then $(CYGPATH_W) 'copy_file_range.c'; else $(CYGPATH_W) '$(srcdir)/copy_file_range.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-copy_file_range.Tpo $(DEPDIR)/strace-copy_file_range.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='copy_file_range.c' object='strace-copy_file_range.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fanotify.o: fanotify.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fanotify.o -MD -MP -MF $(DEPDIR)/libstrace_a-fanotify.Tpo -c -o libstrace_a-fanotify.o `test -f 'fanotify.c' || echo '$(srcdir)/'`fanotify.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fanotify.Tpo $(DEPDIR)/libstrace_a-fanotify.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fanotify.c' object='libstrace_a-fanotify.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-copy_file_range.obj `if test -f 'copy_file_range.c'; then $(CYGPATH_W) 'copy_file_range.c'; else $(CYGPATH_W) '$(srcdir)/copy_file_range.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fanotify.o `test -f 'fanotify.c' || echo '$(srcdir)/'`fanotify.c
 
-strace-count.o: count.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-count.o -MD -MP -MF $(DEPDIR)/strace-count.Tpo -c -o strace-count.o `test -f 'count.c' || echo '$(srcdir)/'`count.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-count.Tpo $(DEPDIR)/strace-count.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='count.c' object='strace-count.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fanotify.obj: fanotify.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fanotify.obj -MD -MP -MF $(DEPDIR)/libstrace_a-fanotify.Tpo -c -o libstrace_a-fanotify.obj `if test -f 'fanotify.c'; then $(CYGPATH_W) 'fanotify.c'; else $(CYGPATH_W) '$(srcdir)/fanotify.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fanotify.Tpo $(DEPDIR)/libstrace_a-fanotify.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fanotify.c' object='libstrace_a-fanotify.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-count.o `test -f 'count.c' || echo '$(srcdir)/'`count.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fanotify.obj `if test -f 'fanotify.c'; then $(CYGPATH_W) 'fanotify.c'; else $(CYGPATH_W) '$(srcdir)/fanotify.c'; fi`
 
-strace-count.obj: count.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-count.obj -MD -MP -MF $(DEPDIR)/strace-count.Tpo -c -o strace-count.obj `if test -f 'count.c'; then $(CYGPATH_W) 'count.c'; else $(CYGPATH_W) '$(srcdir)/count.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-count.Tpo $(DEPDIR)/strace-count.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='count.c' object='strace-count.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fchownat.o: fchownat.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fchownat.o -MD -MP -MF $(DEPDIR)/libstrace_a-fchownat.Tpo -c -o libstrace_a-fchownat.o `test -f 'fchownat.c' || echo '$(srcdir)/'`fchownat.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fchownat.Tpo $(DEPDIR)/libstrace_a-fchownat.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fchownat.c' object='libstrace_a-fchownat.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-count.obj `if test -f 'count.c'; then $(CYGPATH_W) 'count.c'; else $(CYGPATH_W) '$(srcdir)/count.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fchownat.o `test -f 'fchownat.c' || echo '$(srcdir)/'`fchownat.c
 
-strace-delay.o: delay.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-delay.o -MD -MP -MF $(DEPDIR)/strace-delay.Tpo -c -o strace-delay.o `test -f 'delay.c' || echo '$(srcdir)/'`delay.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-delay.Tpo $(DEPDIR)/strace-delay.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='delay.c' object='strace-delay.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fchownat.obj: fchownat.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fchownat.obj -MD -MP -MF $(DEPDIR)/libstrace_a-fchownat.Tpo -c -o libstrace_a-fchownat.obj `if test -f 'fchownat.c'; then $(CYGPATH_W) 'fchownat.c'; else $(CYGPATH_W) '$(srcdir)/fchownat.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fchownat.Tpo $(DEPDIR)/libstrace_a-fchownat.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fchownat.c' object='libstrace_a-fchownat.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-delay.o `test -f 'delay.c' || echo '$(srcdir)/'`delay.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fchownat.obj `if test -f 'fchownat.c'; then $(CYGPATH_W) 'fchownat.c'; else $(CYGPATH_W) '$(srcdir)/fchownat.c'; fi`
 
-strace-delay.obj: delay.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-delay.obj -MD -MP -MF $(DEPDIR)/strace-delay.Tpo -c -o strace-delay.obj `if test -f 'delay.c'; then $(CYGPATH_W) 'delay.c'; else $(CYGPATH_W) '$(srcdir)/delay.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-delay.Tpo $(DEPDIR)/strace-delay.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='delay.c' object='strace-delay.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fcntl.o: fcntl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fcntl.o -MD -MP -MF $(DEPDIR)/libstrace_a-fcntl.Tpo -c -o libstrace_a-fcntl.o `test -f 'fcntl.c' || echo '$(srcdir)/'`fcntl.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fcntl.Tpo $(DEPDIR)/libstrace_a-fcntl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fcntl.c' object='libstrace_a-fcntl.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-delay.obj `if test -f 'delay.c'; then $(CYGPATH_W) 'delay.c'; else $(CYGPATH_W) '$(srcdir)/delay.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fcntl.o `test -f 'fcntl.c' || echo '$(srcdir)/'`fcntl.c
 
-strace-desc.o: desc.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-desc.o -MD -MP -MF $(DEPDIR)/strace-desc.Tpo -c -o strace-desc.o `test -f 'desc.c' || echo '$(srcdir)/'`desc.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-desc.Tpo $(DEPDIR)/strace-desc.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='desc.c' object='strace-desc.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fcntl.obj: fcntl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fcntl.obj -MD -MP -MF $(DEPDIR)/libstrace_a-fcntl.Tpo -c -o libstrace_a-fcntl.obj `if test -f 'fcntl.c'; then $(CYGPATH_W) 'fcntl.c'; else $(CYGPATH_W) '$(srcdir)/fcntl.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fcntl.Tpo $(DEPDIR)/libstrace_a-fcntl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fcntl.c' object='libstrace_a-fcntl.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-desc.o `test -f 'desc.c' || echo '$(srcdir)/'`desc.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fcntl.obj `if test -f 'fcntl.c'; then $(CYGPATH_W) 'fcntl.c'; else $(CYGPATH_W) '$(srcdir)/fcntl.c'; fi`
 
-strace-desc.obj: desc.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-desc.obj -MD -MP -MF $(DEPDIR)/strace-desc.Tpo -c -o strace-desc.obj `if test -f 'desc.c'; then $(CYGPATH_W) 'desc.c'; else $(CYGPATH_W) '$(srcdir)/desc.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-desc.Tpo $(DEPDIR)/strace-desc.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='desc.c' object='strace-desc.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fetch_bpf_fprog.o: fetch_bpf_fprog.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fetch_bpf_fprog.o -MD -MP -MF $(DEPDIR)/libstrace_a-fetch_bpf_fprog.Tpo -c -o libstrace_a-fetch_bpf_fprog.o `test -f 'fetch_bpf_fprog.c' || echo '$(srcdir)/'`fetch_bpf_fprog.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fetch_bpf_fprog.Tpo $(DEPDIR)/libstrace_a-fetch_bpf_fprog.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_bpf_fprog.c' object='libstrace_a-fetch_bpf_fprog.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-desc.obj `if test -f 'desc.c'; then $(CYGPATH_W) 'desc.c'; else $(CYGPATH_W) '$(srcdir)/desc.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fetch_bpf_fprog.o `test -f 'fetch_bpf_fprog.c' || echo '$(srcdir)/'`fetch_bpf_fprog.c
 
-strace-dirent.o: dirent.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-dirent.o -MD -MP -MF $(DEPDIR)/strace-dirent.Tpo -c -o strace-dirent.o `test -f 'dirent.c' || echo '$(srcdir)/'`dirent.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-dirent.Tpo $(DEPDIR)/strace-dirent.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='dirent.c' object='strace-dirent.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fetch_bpf_fprog.obj: fetch_bpf_fprog.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fetch_bpf_fprog.obj -MD -MP -MF $(DEPDIR)/libstrace_a-fetch_bpf_fprog.Tpo -c -o libstrace_a-fetch_bpf_fprog.obj `if test -f 'fetch_bpf_fprog.c'; then $(CYGPATH_W) 'fetch_bpf_fprog.c'; else $(CYGPATH_W) '$(srcdir)/fetch_bpf_fprog.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fetch_bpf_fprog.Tpo $(DEPDIR)/libstrace_a-fetch_bpf_fprog.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_bpf_fprog.c' object='libstrace_a-fetch_bpf_fprog.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-dirent.o `test -f 'dirent.c' || echo '$(srcdir)/'`dirent.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fetch_bpf_fprog.obj `if test -f 'fetch_bpf_fprog.c'; then $(CYGPATH_W) 'fetch_bpf_fprog.c'; else $(CYGPATH_W) '$(srcdir)/fetch_bpf_fprog.c'; fi`
 
-strace-dirent.obj: dirent.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-dirent.obj -MD -MP -MF $(DEPDIR)/strace-dirent.Tpo -c -o strace-dirent.obj `if test -f 'dirent.c'; then $(CYGPATH_W) 'dirent.c'; else $(CYGPATH_W) '$(srcdir)/dirent.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-dirent.Tpo $(DEPDIR)/strace-dirent.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='dirent.c' object='strace-dirent.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fetch_indirect_syscall_args.o: fetch_indirect_syscall_args.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fetch_indirect_syscall_args.o -MD -MP -MF $(DEPDIR)/libstrace_a-fetch_indirect_syscall_args.Tpo -c -o libstrace_a-fetch_indirect_syscall_args.o `test -f 'fetch_indirect_syscall_args.c' || echo '$(srcdir)/'`fetch_indirect_syscall_args.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fetch_indirect_syscall_args.Tpo $(DEPDIR)/libstrace_a-fetch_indirect_syscall_args.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_indirect_syscall_args.c' object='libstrace_a-fetch_indirect_syscall_args.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-dirent.obj `if test -f 'dirent.c'; then $(CYGPATH_W) 'dirent.c'; else $(CYGPATH_W) '$(srcdir)/dirent.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fetch_indirect_syscall_args.o `test -f 'fetch_indirect_syscall_args.c' || echo '$(srcdir)/'`fetch_indirect_syscall_args.c
 
-strace-dirent64.o: dirent64.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-dirent64.o -MD -MP -MF $(DEPDIR)/strace-dirent64.Tpo -c -o strace-dirent64.o `test -f 'dirent64.c' || echo '$(srcdir)/'`dirent64.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-dirent64.Tpo $(DEPDIR)/strace-dirent64.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='dirent64.c' object='strace-dirent64.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fetch_indirect_syscall_args.obj: fetch_indirect_syscall_args.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fetch_indirect_syscall_args.obj -MD -MP -MF $(DEPDIR)/libstrace_a-fetch_indirect_syscall_args.Tpo -c -o libstrace_a-fetch_indirect_syscall_args.obj `if test -f 'fetch_indirect_syscall_args.c'; then $(CYGPATH_W) 'fetch_indirect_syscall_args.c'; else $(CYGPATH_W) '$(srcdir)/fetch_indirect_syscall_args.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fetch_indirect_syscall_args.Tpo $(DEPDIR)/libstrace_a-fetch_indirect_syscall_args.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_indirect_syscall_args.c' object='libstrace_a-fetch_indirect_syscall_args.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-dirent64.o `test -f 'dirent64.c' || echo '$(srcdir)/'`dirent64.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fetch_indirect_syscall_args.obj `if test -f 'fetch_indirect_syscall_args.c'; then $(CYGPATH_W) 'fetch_indirect_syscall_args.c'; else $(CYGPATH_W) '$(srcdir)/fetch_indirect_syscall_args.c'; fi`
 
-strace-dirent64.obj: dirent64.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-dirent64.obj -MD -MP -MF $(DEPDIR)/strace-dirent64.Tpo -c -o strace-dirent64.obj `if test -f 'dirent64.c'; then $(CYGPATH_W) 'dirent64.c'; else $(CYGPATH_W) '$(srcdir)/dirent64.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-dirent64.Tpo $(DEPDIR)/strace-dirent64.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='dirent64.c' object='strace-dirent64.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fetch_struct_flock.o: fetch_struct_flock.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fetch_struct_flock.o -MD -MP -MF $(DEPDIR)/libstrace_a-fetch_struct_flock.Tpo -c -o libstrace_a-fetch_struct_flock.o `test -f 'fetch_struct_flock.c' || echo '$(srcdir)/'`fetch_struct_flock.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fetch_struct_flock.Tpo $(DEPDIR)/libstrace_a-fetch_struct_flock.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_flock.c' object='libstrace_a-fetch_struct_flock.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-dirent64.obj `if test -f 'dirent64.c'; then $(CYGPATH_W) 'dirent64.c'; else $(CYGPATH_W) '$(srcdir)/dirent64.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fetch_struct_flock.o `test -f 'fetch_struct_flock.c' || echo '$(srcdir)/'`fetch_struct_flock.c
 
-strace-dm.o: dm.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-dm.o -MD -MP -MF $(DEPDIR)/strace-dm.Tpo -c -o strace-dm.o `test -f 'dm.c' || echo '$(srcdir)/'`dm.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-dm.Tpo $(DEPDIR)/strace-dm.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='dm.c' object='strace-dm.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fetch_struct_flock.obj: fetch_struct_flock.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fetch_struct_flock.obj -MD -MP -MF $(DEPDIR)/libstrace_a-fetch_struct_flock.Tpo -c -o libstrace_a-fetch_struct_flock.obj `if test -f 'fetch_struct_flock.c'; then $(CYGPATH_W) 'fetch_struct_flock.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_flock.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fetch_struct_flock.Tpo $(DEPDIR)/libstrace_a-fetch_struct_flock.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_flock.c' object='libstrace_a-fetch_struct_flock.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-dm.o `test -f 'dm.c' || echo '$(srcdir)/'`dm.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fetch_struct_flock.obj `if test -f 'fetch_struct_flock.c'; then $(CYGPATH_W) 'fetch_struct_flock.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_flock.c'; fi`
 
-strace-dm.obj: dm.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-dm.obj -MD -MP -MF $(DEPDIR)/strace-dm.Tpo -c -o strace-dm.obj `if test -f 'dm.c'; then $(CYGPATH_W) 'dm.c'; else $(CYGPATH_W) '$(srcdir)/dm.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-dm.Tpo $(DEPDIR)/strace-dm.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='dm.c' object='strace-dm.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fetch_struct_keyctl_kdf_params.o: fetch_struct_keyctl_kdf_params.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fetch_struct_keyctl_kdf_params.o -MD -MP -MF $(DEPDIR)/libstrace_a-fetch_struct_keyctl_kdf_params.Tpo -c -o libstrace_a-fetch_struct_keyctl_kdf_params.o `test -f 'fetch_struct_keyctl_kdf_params.c' || echo '$(srcdir)/'`fetch_struct_keyctl_kdf_params.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fetch_struct_keyctl_kdf_params.Tpo $(DEPDIR)/libstrace_a-fetch_struct_keyctl_kdf_params.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_keyctl_kdf_params.c' object='libstrace_a-fetch_struct_keyctl_kdf_params.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-dm.obj `if test -f 'dm.c'; then $(CYGPATH_W) 'dm.c'; else $(CYGPATH_W) '$(srcdir)/dm.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fetch_struct_keyctl_kdf_params.o `test -f 'fetch_struct_keyctl_kdf_params.c' || echo '$(srcdir)/'`fetch_struct_keyctl_kdf_params.c
 
-strace-dyxlat.o: dyxlat.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-dyxlat.o -MD -MP -MF $(DEPDIR)/strace-dyxlat.Tpo -c -o strace-dyxlat.o `test -f 'dyxlat.c' || echo '$(srcdir)/'`dyxlat.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-dyxlat.Tpo $(DEPDIR)/strace-dyxlat.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='dyxlat.c' object='strace-dyxlat.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fetch_struct_keyctl_kdf_params.obj: fetch_struct_keyctl_kdf_params.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fetch_struct_keyctl_kdf_params.obj -MD -MP -MF $(DEPDIR)/libstrace_a-fetch_struct_keyctl_kdf_params.Tpo -c -o libstrace_a-fetch_struct_keyctl_kdf_params.obj `if test -f 'fetch_struct_keyctl_kdf_params.c'; then $(CYGPATH_W) 'fetch_struct_keyctl_kdf_params.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_keyctl_kdf_params.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fetch_struct_keyctl_kdf_params.Tpo $(DEPDIR)/libstrace_a-fetch_struct_keyctl_kdf_params.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_keyctl_kdf_params.c' object='libstrace_a-fetch_struct_keyctl_kdf_params.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-dyxlat.o `test -f 'dyxlat.c' || echo '$(srcdir)/'`dyxlat.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fetch_struct_keyctl_kdf_params.obj `if test -f 'fetch_struct_keyctl_kdf_params.c'; then $(CYGPATH_W) 'fetch_struct_keyctl_kdf_params.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_keyctl_kdf_params.c'; fi`
 
-strace-dyxlat.obj: dyxlat.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-dyxlat.obj -MD -MP -MF $(DEPDIR)/strace-dyxlat.Tpo -c -o strace-dyxlat.obj `if test -f 'dyxlat.c'; then $(CYGPATH_W) 'dyxlat.c'; else $(CYGPATH_W) '$(srcdir)/dyxlat.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-dyxlat.Tpo $(DEPDIR)/strace-dyxlat.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='dyxlat.c' object='strace-dyxlat.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fetch_struct_mmsghdr.o: fetch_struct_mmsghdr.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fetch_struct_mmsghdr.o -MD -MP -MF $(DEPDIR)/libstrace_a-fetch_struct_mmsghdr.Tpo -c -o libstrace_a-fetch_struct_mmsghdr.o `test -f 'fetch_struct_mmsghdr.c' || echo '$(srcdir)/'`fetch_struct_mmsghdr.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fetch_struct_mmsghdr.Tpo $(DEPDIR)/libstrace_a-fetch_struct_mmsghdr.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_mmsghdr.c' object='libstrace_a-fetch_struct_mmsghdr.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-dyxlat.obj `if test -f 'dyxlat.c'; then $(CYGPATH_W) 'dyxlat.c'; else $(CYGPATH_W) '$(srcdir)/dyxlat.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fetch_struct_mmsghdr.o `test -f 'fetch_struct_mmsghdr.c' || echo '$(srcdir)/'`fetch_struct_mmsghdr.c
 
-strace-epoll.o: epoll.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-epoll.o -MD -MP -MF $(DEPDIR)/strace-epoll.Tpo -c -o strace-epoll.o `test -f 'epoll.c' || echo '$(srcdir)/'`epoll.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-epoll.Tpo $(DEPDIR)/strace-epoll.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='epoll.c' object='strace-epoll.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fetch_struct_mmsghdr.obj: fetch_struct_mmsghdr.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fetch_struct_mmsghdr.obj -MD -MP -MF $(DEPDIR)/libstrace_a-fetch_struct_mmsghdr.Tpo -c -o libstrace_a-fetch_struct_mmsghdr.obj `if test -f 'fetch_struct_mmsghdr.c'; then $(CYGPATH_W) 'fetch_struct_mmsghdr.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_mmsghdr.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fetch_struct_mmsghdr.Tpo $(DEPDIR)/libstrace_a-fetch_struct_mmsghdr.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_mmsghdr.c' object='libstrace_a-fetch_struct_mmsghdr.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-epoll.o `test -f 'epoll.c' || echo '$(srcdir)/'`epoll.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fetch_struct_mmsghdr.obj `if test -f 'fetch_struct_mmsghdr.c'; then $(CYGPATH_W) 'fetch_struct_mmsghdr.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_mmsghdr.c'; fi`
 
-strace-epoll.obj: epoll.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-epoll.obj -MD -MP -MF $(DEPDIR)/strace-epoll.Tpo -c -o strace-epoll.obj `if test -f 'epoll.c'; then $(CYGPATH_W) 'epoll.c'; else $(CYGPATH_W) '$(srcdir)/epoll.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-epoll.Tpo $(DEPDIR)/strace-epoll.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='epoll.c' object='strace-epoll.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fetch_struct_msghdr.o: fetch_struct_msghdr.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fetch_struct_msghdr.o -MD -MP -MF $(DEPDIR)/libstrace_a-fetch_struct_msghdr.Tpo -c -o libstrace_a-fetch_struct_msghdr.o `test -f 'fetch_struct_msghdr.c' || echo '$(srcdir)/'`fetch_struct_msghdr.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fetch_struct_msghdr.Tpo $(DEPDIR)/libstrace_a-fetch_struct_msghdr.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_msghdr.c' object='libstrace_a-fetch_struct_msghdr.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-epoll.obj `if test -f 'epoll.c'; then $(CYGPATH_W) 'epoll.c'; else $(CYGPATH_W) '$(srcdir)/epoll.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fetch_struct_msghdr.o `test -f 'fetch_struct_msghdr.c' || echo '$(srcdir)/'`fetch_struct_msghdr.c
 
-strace-error_prints.o: error_prints.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-error_prints.o -MD -MP -MF $(DEPDIR)/strace-error_prints.Tpo -c -o strace-error_prints.o `test -f 'error_prints.c' || echo '$(srcdir)/'`error_prints.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-error_prints.Tpo $(DEPDIR)/strace-error_prints.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='error_prints.c' object='strace-error_prints.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fetch_struct_msghdr.obj: fetch_struct_msghdr.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fetch_struct_msghdr.obj -MD -MP -MF $(DEPDIR)/libstrace_a-fetch_struct_msghdr.Tpo -c -o libstrace_a-fetch_struct_msghdr.obj `if test -f 'fetch_struct_msghdr.c'; then $(CYGPATH_W) 'fetch_struct_msghdr.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_msghdr.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fetch_struct_msghdr.Tpo $(DEPDIR)/libstrace_a-fetch_struct_msghdr.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_msghdr.c' object='libstrace_a-fetch_struct_msghdr.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-error_prints.o `test -f 'error_prints.c' || echo '$(srcdir)/'`error_prints.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fetch_struct_msghdr.obj `if test -f 'fetch_struct_msghdr.c'; then $(CYGPATH_W) 'fetch_struct_msghdr.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_msghdr.c'; fi`
 
-strace-error_prints.obj: error_prints.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-error_prints.obj -MD -MP -MF $(DEPDIR)/strace-error_prints.Tpo -c -o strace-error_prints.obj `if test -f 'error_prints.c'; then $(CYGPATH_W) 'error_prints.c'; else $(CYGPATH_W) '$(srcdir)/error_prints.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-error_prints.Tpo $(DEPDIR)/strace-error_prints.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='error_prints.c' object='strace-error_prints.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fetch_struct_stat.o: fetch_struct_stat.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fetch_struct_stat.o -MD -MP -MF $(DEPDIR)/libstrace_a-fetch_struct_stat.Tpo -c -o libstrace_a-fetch_struct_stat.o `test -f 'fetch_struct_stat.c' || echo '$(srcdir)/'`fetch_struct_stat.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fetch_struct_stat.Tpo $(DEPDIR)/libstrace_a-fetch_struct_stat.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_stat.c' object='libstrace_a-fetch_struct_stat.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-error_prints.obj `if test -f 'error_prints.c'; then $(CYGPATH_W) 'error_prints.c'; else $(CYGPATH_W) '$(srcdir)/error_prints.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fetch_struct_stat.o `test -f 'fetch_struct_stat.c' || echo '$(srcdir)/'`fetch_struct_stat.c
 
-strace-evdev.o: evdev.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-evdev.o -MD -MP -MF $(DEPDIR)/strace-evdev.Tpo -c -o strace-evdev.o `test -f 'evdev.c' || echo '$(srcdir)/'`evdev.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-evdev.Tpo $(DEPDIR)/strace-evdev.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='evdev.c' object='strace-evdev.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fetch_struct_stat.obj: fetch_struct_stat.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fetch_struct_stat.obj -MD -MP -MF $(DEPDIR)/libstrace_a-fetch_struct_stat.Tpo -c -o libstrace_a-fetch_struct_stat.obj `if test -f 'fetch_struct_stat.c'; then $(CYGPATH_W) 'fetch_struct_stat.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_stat.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fetch_struct_stat.Tpo $(DEPDIR)/libstrace_a-fetch_struct_stat.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_stat.c' object='libstrace_a-fetch_struct_stat.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-evdev.o `test -f 'evdev.c' || echo '$(srcdir)/'`evdev.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fetch_struct_stat.obj `if test -f 'fetch_struct_stat.c'; then $(CYGPATH_W) 'fetch_struct_stat.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_stat.c'; fi`
 
-strace-evdev.obj: evdev.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-evdev.obj -MD -MP -MF $(DEPDIR)/strace-evdev.Tpo -c -o strace-evdev.obj `if test -f 'evdev.c'; then $(CYGPATH_W) 'evdev.c'; else $(CYGPATH_W) '$(srcdir)/evdev.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-evdev.Tpo $(DEPDIR)/strace-evdev.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='evdev.c' object='strace-evdev.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fetch_struct_stat64.o: fetch_struct_stat64.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fetch_struct_stat64.o -MD -MP -MF $(DEPDIR)/libstrace_a-fetch_struct_stat64.Tpo -c -o libstrace_a-fetch_struct_stat64.o `test -f 'fetch_struct_stat64.c' || echo '$(srcdir)/'`fetch_struct_stat64.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fetch_struct_stat64.Tpo $(DEPDIR)/libstrace_a-fetch_struct_stat64.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_stat64.c' object='libstrace_a-fetch_struct_stat64.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-evdev.obj `if test -f 'evdev.c'; then $(CYGPATH_W) 'evdev.c'; else $(CYGPATH_W) '$(srcdir)/evdev.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fetch_struct_stat64.o `test -f 'fetch_struct_stat64.c' || echo '$(srcdir)/'`fetch_struct_stat64.c
 
-strace-evdev_mpers.o: evdev_mpers.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-evdev_mpers.o -MD -MP -MF $(DEPDIR)/strace-evdev_mpers.Tpo -c -o strace-evdev_mpers.o `test -f 'evdev_mpers.c' || echo '$(srcdir)/'`evdev_mpers.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-evdev_mpers.Tpo $(DEPDIR)/strace-evdev_mpers.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='evdev_mpers.c' object='strace-evdev_mpers.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fetch_struct_stat64.obj: fetch_struct_stat64.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fetch_struct_stat64.obj -MD -MP -MF $(DEPDIR)/libstrace_a-fetch_struct_stat64.Tpo -c -o libstrace_a-fetch_struct_stat64.obj `if test -f 'fetch_struct_stat64.c'; then $(CYGPATH_W) 'fetch_struct_stat64.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_stat64.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fetch_struct_stat64.Tpo $(DEPDIR)/libstrace_a-fetch_struct_stat64.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_stat64.c' object='libstrace_a-fetch_struct_stat64.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-evdev_mpers.o `test -f 'evdev_mpers.c' || echo '$(srcdir)/'`evdev_mpers.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fetch_struct_stat64.obj `if test -f 'fetch_struct_stat64.c'; then $(CYGPATH_W) 'fetch_struct_stat64.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_stat64.c'; fi`
 
-strace-evdev_mpers.obj: evdev_mpers.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-evdev_mpers.obj -MD -MP -MF $(DEPDIR)/strace-evdev_mpers.Tpo -c -o strace-evdev_mpers.obj `if test -f 'evdev_mpers.c'; then $(CYGPATH_W) 'evdev_mpers.c'; else $(CYGPATH_W) '$(srcdir)/evdev_mpers.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-evdev_mpers.Tpo $(DEPDIR)/strace-evdev_mpers.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='evdev_mpers.c' object='strace-evdev_mpers.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fetch_struct_statfs.o: fetch_struct_statfs.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fetch_struct_statfs.o -MD -MP -MF $(DEPDIR)/libstrace_a-fetch_struct_statfs.Tpo -c -o libstrace_a-fetch_struct_statfs.o `test -f 'fetch_struct_statfs.c' || echo '$(srcdir)/'`fetch_struct_statfs.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fetch_struct_statfs.Tpo $(DEPDIR)/libstrace_a-fetch_struct_statfs.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_statfs.c' object='libstrace_a-fetch_struct_statfs.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-evdev_mpers.obj `if test -f 'evdev_mpers.c'; then $(CYGPATH_W) 'evdev_mpers.c'; else $(CYGPATH_W) '$(srcdir)/evdev_mpers.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fetch_struct_statfs.o `test -f 'fetch_struct_statfs.c' || echo '$(srcdir)/'`fetch_struct_statfs.c
 
-strace-eventfd.o: eventfd.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-eventfd.o -MD -MP -MF $(DEPDIR)/strace-eventfd.Tpo -c -o strace-eventfd.o `test -f 'eventfd.c' || echo '$(srcdir)/'`eventfd.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-eventfd.Tpo $(DEPDIR)/strace-eventfd.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='eventfd.c' object='strace-eventfd.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fetch_struct_statfs.obj: fetch_struct_statfs.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fetch_struct_statfs.obj -MD -MP -MF $(DEPDIR)/libstrace_a-fetch_struct_statfs.Tpo -c -o libstrace_a-fetch_struct_statfs.obj `if test -f 'fetch_struct_statfs.c'; then $(CYGPATH_W) 'fetch_struct_statfs.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_statfs.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fetch_struct_statfs.Tpo $(DEPDIR)/libstrace_a-fetch_struct_statfs.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_statfs.c' object='libstrace_a-fetch_struct_statfs.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-eventfd.o `test -f 'eventfd.c' || echo '$(srcdir)/'`eventfd.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fetch_struct_statfs.obj `if test -f 'fetch_struct_statfs.c'; then $(CYGPATH_W) 'fetch_struct_statfs.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_statfs.c'; fi`
 
-strace-eventfd.obj: eventfd.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-eventfd.obj -MD -MP -MF $(DEPDIR)/strace-eventfd.Tpo -c -o strace-eventfd.obj `if test -f 'eventfd.c'; then $(CYGPATH_W) 'eventfd.c'; else $(CYGPATH_W) '$(srcdir)/eventfd.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-eventfd.Tpo $(DEPDIR)/strace-eventfd.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='eventfd.c' object='strace-eventfd.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fetch_struct_xfs_quotastat.o: fetch_struct_xfs_quotastat.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fetch_struct_xfs_quotastat.o -MD -MP -MF $(DEPDIR)/libstrace_a-fetch_struct_xfs_quotastat.Tpo -c -o libstrace_a-fetch_struct_xfs_quotastat.o `test -f 'fetch_struct_xfs_quotastat.c' || echo '$(srcdir)/'`fetch_struct_xfs_quotastat.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fetch_struct_xfs_quotastat.Tpo $(DEPDIR)/libstrace_a-fetch_struct_xfs_quotastat.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_xfs_quotastat.c' object='libstrace_a-fetch_struct_xfs_quotastat.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-eventfd.obj `if test -f 'eventfd.c'; then $(CYGPATH_W) 'eventfd.c'; else $(CYGPATH_W) '$(srcdir)/eventfd.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fetch_struct_xfs_quotastat.o `test -f 'fetch_struct_xfs_quotastat.c' || echo '$(srcdir)/'`fetch_struct_xfs_quotastat.c
 
-strace-execve.o: execve.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-execve.o -MD -MP -MF $(DEPDIR)/strace-execve.Tpo -c -o strace-execve.o `test -f 'execve.c' || echo '$(srcdir)/'`execve.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-execve.Tpo $(DEPDIR)/strace-execve.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='execve.c' object='strace-execve.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fetch_struct_xfs_quotastat.obj: fetch_struct_xfs_quotastat.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fetch_struct_xfs_quotastat.obj -MD -MP -MF $(DEPDIR)/libstrace_a-fetch_struct_xfs_quotastat.Tpo -c -o libstrace_a-fetch_struct_xfs_quotastat.obj `if test -f 'fetch_struct_xfs_quotastat.c'; then $(CYGPATH_W) 'fetch_struct_xfs_quotastat.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_xfs_quotastat.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fetch_struct_xfs_quotastat.Tpo $(DEPDIR)/libstrace_a-fetch_struct_xfs_quotastat.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_xfs_quotastat.c' object='libstrace_a-fetch_struct_xfs_quotastat.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-execve.o `test -f 'execve.c' || echo '$(srcdir)/'`execve.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fetch_struct_xfs_quotastat.obj `if test -f 'fetch_struct_xfs_quotastat.c'; then $(CYGPATH_W) 'fetch_struct_xfs_quotastat.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_xfs_quotastat.c'; fi`
 
-strace-execve.obj: execve.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-execve.obj -MD -MP -MF $(DEPDIR)/strace-execve.Tpo -c -o strace-execve.obj `if test -f 'execve.c'; then $(CYGPATH_W) 'execve.c'; else $(CYGPATH_W) '$(srcdir)/execve.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-execve.Tpo $(DEPDIR)/strace-execve.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='execve.c' object='strace-execve.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-file_handle.o: file_handle.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-file_handle.o -MD -MP -MF $(DEPDIR)/libstrace_a-file_handle.Tpo -c -o libstrace_a-file_handle.o `test -f 'file_handle.c' || echo '$(srcdir)/'`file_handle.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-file_handle.Tpo $(DEPDIR)/libstrace_a-file_handle.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='file_handle.c' object='libstrace_a-file_handle.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-execve.obj `if test -f 'execve.c'; then $(CYGPATH_W) 'execve.c'; else $(CYGPATH_W) '$(srcdir)/execve.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-file_handle.o `test -f 'file_handle.c' || echo '$(srcdir)/'`file_handle.c
 
-strace-fadvise.o: fadvise.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fadvise.o -MD -MP -MF $(DEPDIR)/strace-fadvise.Tpo -c -o strace-fadvise.o `test -f 'fadvise.c' || echo '$(srcdir)/'`fadvise.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fadvise.Tpo $(DEPDIR)/strace-fadvise.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fadvise.c' object='strace-fadvise.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-file_handle.obj: file_handle.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-file_handle.obj -MD -MP -MF $(DEPDIR)/libstrace_a-file_handle.Tpo -c -o libstrace_a-file_handle.obj `if test -f 'file_handle.c'; then $(CYGPATH_W) 'file_handle.c'; else $(CYGPATH_W) '$(srcdir)/file_handle.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-file_handle.Tpo $(DEPDIR)/libstrace_a-file_handle.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='file_handle.c' object='libstrace_a-file_handle.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fadvise.o `test -f 'fadvise.c' || echo '$(srcdir)/'`fadvise.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-file_handle.obj `if test -f 'file_handle.c'; then $(CYGPATH_W) 'file_handle.c'; else $(CYGPATH_W) '$(srcdir)/file_handle.c'; fi`
 
-strace-fadvise.obj: fadvise.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fadvise.obj -MD -MP -MF $(DEPDIR)/strace-fadvise.Tpo -c -o strace-fadvise.obj `if test -f 'fadvise.c'; then $(CYGPATH_W) 'fadvise.c'; else $(CYGPATH_W) '$(srcdir)/fadvise.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fadvise.Tpo $(DEPDIR)/strace-fadvise.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fadvise.c' object='strace-fadvise.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-file_ioctl.o: file_ioctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-file_ioctl.o -MD -MP -MF $(DEPDIR)/libstrace_a-file_ioctl.Tpo -c -o libstrace_a-file_ioctl.o `test -f 'file_ioctl.c' || echo '$(srcdir)/'`file_ioctl.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-file_ioctl.Tpo $(DEPDIR)/libstrace_a-file_ioctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='file_ioctl.c' object='libstrace_a-file_ioctl.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fadvise.obj `if test -f 'fadvise.c'; then $(CYGPATH_W) 'fadvise.c'; else $(CYGPATH_W) '$(srcdir)/fadvise.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-file_ioctl.o `test -f 'file_ioctl.c' || echo '$(srcdir)/'`file_ioctl.c
 
-strace-fallocate.o: fallocate.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fallocate.o -MD -MP -MF $(DEPDIR)/strace-fallocate.Tpo -c -o strace-fallocate.o `test -f 'fallocate.c' || echo '$(srcdir)/'`fallocate.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fallocate.Tpo $(DEPDIR)/strace-fallocate.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fallocate.c' object='strace-fallocate.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-file_ioctl.obj: file_ioctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-file_ioctl.obj -MD -MP -MF $(DEPDIR)/libstrace_a-file_ioctl.Tpo -c -o libstrace_a-file_ioctl.obj `if test -f 'file_ioctl.c'; then $(CYGPATH_W) 'file_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/file_ioctl.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-file_ioctl.Tpo $(DEPDIR)/libstrace_a-file_ioctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='file_ioctl.c' object='libstrace_a-file_ioctl.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fallocate.o `test -f 'fallocate.c' || echo '$(srcdir)/'`fallocate.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-file_ioctl.obj `if test -f 'file_ioctl.c'; then $(CYGPATH_W) 'file_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/file_ioctl.c'; fi`
 
-strace-fallocate.obj: fallocate.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fallocate.obj -MD -MP -MF $(DEPDIR)/strace-fallocate.Tpo -c -o strace-fallocate.obj `if test -f 'fallocate.c'; then $(CYGPATH_W) 'fallocate.c'; else $(CYGPATH_W) '$(srcdir)/fallocate.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fallocate.Tpo $(DEPDIR)/strace-fallocate.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fallocate.c' object='strace-fallocate.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-filter_qualify.o: filter_qualify.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-filter_qualify.o -MD -MP -MF $(DEPDIR)/libstrace_a-filter_qualify.Tpo -c -o libstrace_a-filter_qualify.o `test -f 'filter_qualify.c' || echo '$(srcdir)/'`filter_qualify.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-filter_qualify.Tpo $(DEPDIR)/libstrace_a-filter_qualify.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='filter_qualify.c' object='libstrace_a-filter_qualify.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fallocate.obj `if test -f 'fallocate.c'; then $(CYGPATH_W) 'fallocate.c'; else $(CYGPATH_W) '$(srcdir)/fallocate.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-filter_qualify.o `test -f 'filter_qualify.c' || echo '$(srcdir)/'`filter_qualify.c
 
-strace-fanotify.o: fanotify.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fanotify.o -MD -MP -MF $(DEPDIR)/strace-fanotify.Tpo -c -o strace-fanotify.o `test -f 'fanotify.c' || echo '$(srcdir)/'`fanotify.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fanotify.Tpo $(DEPDIR)/strace-fanotify.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fanotify.c' object='strace-fanotify.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-filter_qualify.obj: filter_qualify.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-filter_qualify.obj -MD -MP -MF $(DEPDIR)/libstrace_a-filter_qualify.Tpo -c -o libstrace_a-filter_qualify.obj `if test -f 'filter_qualify.c'; then $(CYGPATH_W) 'filter_qualify.c'; else $(CYGPATH_W) '$(srcdir)/filter_qualify.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-filter_qualify.Tpo $(DEPDIR)/libstrace_a-filter_qualify.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='filter_qualify.c' object='libstrace_a-filter_qualify.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fanotify.o `test -f 'fanotify.c' || echo '$(srcdir)/'`fanotify.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-filter_qualify.obj `if test -f 'filter_qualify.c'; then $(CYGPATH_W) 'filter_qualify.c'; else $(CYGPATH_W) '$(srcdir)/filter_qualify.c'; fi`
 
-strace-fanotify.obj: fanotify.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fanotify.obj -MD -MP -MF $(DEPDIR)/strace-fanotify.Tpo -c -o strace-fanotify.obj `if test -f 'fanotify.c'; then $(CYGPATH_W) 'fanotify.c'; else $(CYGPATH_W) '$(srcdir)/fanotify.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fanotify.Tpo $(DEPDIR)/strace-fanotify.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fanotify.c' object='strace-fanotify.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-filter_seccomp.o: filter_seccomp.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-filter_seccomp.o -MD -MP -MF $(DEPDIR)/libstrace_a-filter_seccomp.Tpo -c -o libstrace_a-filter_seccomp.o `test -f 'filter_seccomp.c' || echo '$(srcdir)/'`filter_seccomp.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-filter_seccomp.Tpo $(DEPDIR)/libstrace_a-filter_seccomp.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='filter_seccomp.c' object='libstrace_a-filter_seccomp.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fanotify.obj `if test -f 'fanotify.c'; then $(CYGPATH_W) 'fanotify.c'; else $(CYGPATH_W) '$(srcdir)/fanotify.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-filter_seccomp.o `test -f 'filter_seccomp.c' || echo '$(srcdir)/'`filter_seccomp.c
 
-strace-fchownat.o: fchownat.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fchownat.o -MD -MP -MF $(DEPDIR)/strace-fchownat.Tpo -c -o strace-fchownat.o `test -f 'fchownat.c' || echo '$(srcdir)/'`fchownat.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fchownat.Tpo $(DEPDIR)/strace-fchownat.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fchownat.c' object='strace-fchownat.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-filter_seccomp.obj: filter_seccomp.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-filter_seccomp.obj -MD -MP -MF $(DEPDIR)/libstrace_a-filter_seccomp.Tpo -c -o libstrace_a-filter_seccomp.obj `if test -f 'filter_seccomp.c'; then $(CYGPATH_W) 'filter_seccomp.c'; else $(CYGPATH_W) '$(srcdir)/filter_seccomp.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-filter_seccomp.Tpo $(DEPDIR)/libstrace_a-filter_seccomp.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='filter_seccomp.c' object='libstrace_a-filter_seccomp.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fchownat.o `test -f 'fchownat.c' || echo '$(srcdir)/'`fchownat.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-filter_seccomp.obj `if test -f 'filter_seccomp.c'; then $(CYGPATH_W) 'filter_seccomp.c'; else $(CYGPATH_W) '$(srcdir)/filter_seccomp.c'; fi`
 
-strace-fchownat.obj: fchownat.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fchownat.obj -MD -MP -MF $(DEPDIR)/strace-fchownat.Tpo -c -o strace-fchownat.obj `if test -f 'fchownat.c'; then $(CYGPATH_W) 'fchownat.c'; else $(CYGPATH_W) '$(srcdir)/fchownat.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fchownat.Tpo $(DEPDIR)/strace-fchownat.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fchownat.c' object='strace-fchownat.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-flock.o: flock.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-flock.o -MD -MP -MF $(DEPDIR)/libstrace_a-flock.Tpo -c -o libstrace_a-flock.o `test -f 'flock.c' || echo '$(srcdir)/'`flock.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-flock.Tpo $(DEPDIR)/libstrace_a-flock.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='flock.c' object='libstrace_a-flock.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fchownat.obj `if test -f 'fchownat.c'; then $(CYGPATH_W) 'fchownat.c'; else $(CYGPATH_W) '$(srcdir)/fchownat.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-flock.o `test -f 'flock.c' || echo '$(srcdir)/'`flock.c
 
-strace-fcntl.o: fcntl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fcntl.o -MD -MP -MF $(DEPDIR)/strace-fcntl.Tpo -c -o strace-fcntl.o `test -f 'fcntl.c' || echo '$(srcdir)/'`fcntl.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fcntl.Tpo $(DEPDIR)/strace-fcntl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fcntl.c' object='strace-fcntl.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-flock.obj: flock.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-flock.obj -MD -MP -MF $(DEPDIR)/libstrace_a-flock.Tpo -c -o libstrace_a-flock.obj `if test -f 'flock.c'; then $(CYGPATH_W) 'flock.c'; else $(CYGPATH_W) '$(srcdir)/flock.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-flock.Tpo $(DEPDIR)/libstrace_a-flock.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='flock.c' object='libstrace_a-flock.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fcntl.o `test -f 'fcntl.c' || echo '$(srcdir)/'`fcntl.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-flock.obj `if test -f 'flock.c'; then $(CYGPATH_W) 'flock.c'; else $(CYGPATH_W) '$(srcdir)/flock.c'; fi`
 
-strace-fcntl.obj: fcntl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fcntl.obj -MD -MP -MF $(DEPDIR)/strace-fcntl.Tpo -c -o strace-fcntl.obj `if test -f 'fcntl.c'; then $(CYGPATH_W) 'fcntl.c'; else $(CYGPATH_W) '$(srcdir)/fcntl.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fcntl.Tpo $(DEPDIR)/strace-fcntl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fcntl.c' object='strace-fcntl.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fs_x_ioctl.o: fs_x_ioctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fs_x_ioctl.o -MD -MP -MF $(DEPDIR)/libstrace_a-fs_x_ioctl.Tpo -c -o libstrace_a-fs_x_ioctl.o `test -f 'fs_x_ioctl.c' || echo '$(srcdir)/'`fs_x_ioctl.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fs_x_ioctl.Tpo $(DEPDIR)/libstrace_a-fs_x_ioctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fs_x_ioctl.c' object='libstrace_a-fs_x_ioctl.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fcntl.obj `if test -f 'fcntl.c'; then $(CYGPATH_W) 'fcntl.c'; else $(CYGPATH_W) '$(srcdir)/fcntl.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fs_x_ioctl.o `test -f 'fs_x_ioctl.c' || echo '$(srcdir)/'`fs_x_ioctl.c
 
-strace-fetch_bpf_fprog.o: fetch_bpf_fprog.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fetch_bpf_fprog.o -MD -MP -MF $(DEPDIR)/strace-fetch_bpf_fprog.Tpo -c -o strace-fetch_bpf_fprog.o `test -f 'fetch_bpf_fprog.c' || echo '$(srcdir)/'`fetch_bpf_fprog.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fetch_bpf_fprog.Tpo $(DEPDIR)/strace-fetch_bpf_fprog.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_bpf_fprog.c' object='strace-fetch_bpf_fprog.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fs_x_ioctl.obj: fs_x_ioctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fs_x_ioctl.obj -MD -MP -MF $(DEPDIR)/libstrace_a-fs_x_ioctl.Tpo -c -o libstrace_a-fs_x_ioctl.obj `if test -f 'fs_x_ioctl.c'; then $(CYGPATH_W) 'fs_x_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/fs_x_ioctl.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fs_x_ioctl.Tpo $(DEPDIR)/libstrace_a-fs_x_ioctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fs_x_ioctl.c' object='libstrace_a-fs_x_ioctl.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fetch_bpf_fprog.o `test -f 'fetch_bpf_fprog.c' || echo '$(srcdir)/'`fetch_bpf_fprog.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fs_x_ioctl.obj `if test -f 'fs_x_ioctl.c'; then $(CYGPATH_W) 'fs_x_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/fs_x_ioctl.c'; fi`
 
-strace-fetch_bpf_fprog.obj: fetch_bpf_fprog.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fetch_bpf_fprog.obj -MD -MP -MF $(DEPDIR)/strace-fetch_bpf_fprog.Tpo -c -o strace-fetch_bpf_fprog.obj `if test -f 'fetch_bpf_fprog.c'; then $(CYGPATH_W) 'fetch_bpf_fprog.c'; else $(CYGPATH_W) '$(srcdir)/fetch_bpf_fprog.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fetch_bpf_fprog.Tpo $(DEPDIR)/strace-fetch_bpf_fprog.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_bpf_fprog.c' object='strace-fetch_bpf_fprog.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fsconfig.o: fsconfig.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fsconfig.o -MD -MP -MF $(DEPDIR)/libstrace_a-fsconfig.Tpo -c -o libstrace_a-fsconfig.o `test -f 'fsconfig.c' || echo '$(srcdir)/'`fsconfig.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fsconfig.Tpo $(DEPDIR)/libstrace_a-fsconfig.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fsconfig.c' object='libstrace_a-fsconfig.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fetch_bpf_fprog.obj `if test -f 'fetch_bpf_fprog.c'; then $(CYGPATH_W) 'fetch_bpf_fprog.c'; else $(CYGPATH_W) '$(srcdir)/fetch_bpf_fprog.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fsconfig.o `test -f 'fsconfig.c' || echo '$(srcdir)/'`fsconfig.c
 
-strace-fetch_struct_flock.o: fetch_struct_flock.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fetch_struct_flock.o -MD -MP -MF $(DEPDIR)/strace-fetch_struct_flock.Tpo -c -o strace-fetch_struct_flock.o `test -f 'fetch_struct_flock.c' || echo '$(srcdir)/'`fetch_struct_flock.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fetch_struct_flock.Tpo $(DEPDIR)/strace-fetch_struct_flock.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_flock.c' object='strace-fetch_struct_flock.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fsconfig.obj: fsconfig.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fsconfig.obj -MD -MP -MF $(DEPDIR)/libstrace_a-fsconfig.Tpo -c -o libstrace_a-fsconfig.obj `if test -f 'fsconfig.c'; then $(CYGPATH_W) 'fsconfig.c'; else $(CYGPATH_W) '$(srcdir)/fsconfig.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fsconfig.Tpo $(DEPDIR)/libstrace_a-fsconfig.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fsconfig.c' object='libstrace_a-fsconfig.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fetch_struct_flock.o `test -f 'fetch_struct_flock.c' || echo '$(srcdir)/'`fetch_struct_flock.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fsconfig.obj `if test -f 'fsconfig.c'; then $(CYGPATH_W) 'fsconfig.c'; else $(CYGPATH_W) '$(srcdir)/fsconfig.c'; fi`
 
-strace-fetch_struct_flock.obj: fetch_struct_flock.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fetch_struct_flock.obj -MD -MP -MF $(DEPDIR)/strace-fetch_struct_flock.Tpo -c -o strace-fetch_struct_flock.obj `if test -f 'fetch_struct_flock.c'; then $(CYGPATH_W) 'fetch_struct_flock.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_flock.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fetch_struct_flock.Tpo $(DEPDIR)/strace-fetch_struct_flock.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_flock.c' object='strace-fetch_struct_flock.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fsmount.o: fsmount.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fsmount.o -MD -MP -MF $(DEPDIR)/libstrace_a-fsmount.Tpo -c -o libstrace_a-fsmount.o `test -f 'fsmount.c' || echo '$(srcdir)/'`fsmount.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fsmount.Tpo $(DEPDIR)/libstrace_a-fsmount.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fsmount.c' object='libstrace_a-fsmount.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fetch_struct_flock.obj `if test -f 'fetch_struct_flock.c'; then $(CYGPATH_W) 'fetch_struct_flock.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_flock.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fsmount.o `test -f 'fsmount.c' || echo '$(srcdir)/'`fsmount.c
 
-strace-fetch_struct_keyctl_kdf_params.o: fetch_struct_keyctl_kdf_params.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fetch_struct_keyctl_kdf_params.o -MD -MP -MF $(DEPDIR)/strace-fetch_struct_keyctl_kdf_params.Tpo -c -o strace-fetch_struct_keyctl_kdf_params.o `test -f 'fetch_struct_keyctl_kdf_params.c' || echo '$(srcdir)/'`fetch_struct_keyctl_kdf_params.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fetch_struct_keyctl_kdf_params.Tpo $(DEPDIR)/strace-fetch_struct_keyctl_kdf_params.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_keyctl_kdf_params.c' object='strace-fetch_struct_keyctl_kdf_params.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fsmount.obj: fsmount.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fsmount.obj -MD -MP -MF $(DEPDIR)/libstrace_a-fsmount.Tpo -c -o libstrace_a-fsmount.obj `if test -f 'fsmount.c'; then $(CYGPATH_W) 'fsmount.c'; else $(CYGPATH_W) '$(srcdir)/fsmount.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fsmount.Tpo $(DEPDIR)/libstrace_a-fsmount.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fsmount.c' object='libstrace_a-fsmount.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fetch_struct_keyctl_kdf_params.o `test -f 'fetch_struct_keyctl_kdf_params.c' || echo '$(srcdir)/'`fetch_struct_keyctl_kdf_params.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fsmount.obj `if test -f 'fsmount.c'; then $(CYGPATH_W) 'fsmount.c'; else $(CYGPATH_W) '$(srcdir)/fsmount.c'; fi`
 
-strace-fetch_struct_keyctl_kdf_params.obj: fetch_struct_keyctl_kdf_params.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fetch_struct_keyctl_kdf_params.obj -MD -MP -MF $(DEPDIR)/strace-fetch_struct_keyctl_kdf_params.Tpo -c -o strace-fetch_struct_keyctl_kdf_params.obj `if test -f 'fetch_struct_keyctl_kdf_params.c'; then $(CYGPATH_W) 'fetch_struct_keyctl_kdf_params.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_keyctl_kdf_params.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fetch_struct_keyctl_kdf_params.Tpo $(DEPDIR)/strace-fetch_struct_keyctl_kdf_params.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_keyctl_kdf_params.c' object='strace-fetch_struct_keyctl_kdf_params.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fsopen.o: fsopen.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fsopen.o -MD -MP -MF $(DEPDIR)/libstrace_a-fsopen.Tpo -c -o libstrace_a-fsopen.o `test -f 'fsopen.c' || echo '$(srcdir)/'`fsopen.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fsopen.Tpo $(DEPDIR)/libstrace_a-fsopen.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fsopen.c' object='libstrace_a-fsopen.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fetch_struct_keyctl_kdf_params.obj `if test -f 'fetch_struct_keyctl_kdf_params.c'; then $(CYGPATH_W) 'fetch_struct_keyctl_kdf_params.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_keyctl_kdf_params.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fsopen.o `test -f 'fsopen.c' || echo '$(srcdir)/'`fsopen.c
 
-strace-fetch_struct_mmsghdr.o: fetch_struct_mmsghdr.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fetch_struct_mmsghdr.o -MD -MP -MF $(DEPDIR)/strace-fetch_struct_mmsghdr.Tpo -c -o strace-fetch_struct_mmsghdr.o `test -f 'fetch_struct_mmsghdr.c' || echo '$(srcdir)/'`fetch_struct_mmsghdr.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fetch_struct_mmsghdr.Tpo $(DEPDIR)/strace-fetch_struct_mmsghdr.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_mmsghdr.c' object='strace-fetch_struct_mmsghdr.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fsopen.obj: fsopen.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fsopen.obj -MD -MP -MF $(DEPDIR)/libstrace_a-fsopen.Tpo -c -o libstrace_a-fsopen.obj `if test -f 'fsopen.c'; then $(CYGPATH_W) 'fsopen.c'; else $(CYGPATH_W) '$(srcdir)/fsopen.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fsopen.Tpo $(DEPDIR)/libstrace_a-fsopen.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fsopen.c' object='libstrace_a-fsopen.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fetch_struct_mmsghdr.o `test -f 'fetch_struct_mmsghdr.c' || echo '$(srcdir)/'`fetch_struct_mmsghdr.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fsopen.obj `if test -f 'fsopen.c'; then $(CYGPATH_W) 'fsopen.c'; else $(CYGPATH_W) '$(srcdir)/fsopen.c'; fi`
 
-strace-fetch_struct_mmsghdr.obj: fetch_struct_mmsghdr.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fetch_struct_mmsghdr.obj -MD -MP -MF $(DEPDIR)/strace-fetch_struct_mmsghdr.Tpo -c -o strace-fetch_struct_mmsghdr.obj `if test -f 'fetch_struct_mmsghdr.c'; then $(CYGPATH_W) 'fetch_struct_mmsghdr.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_mmsghdr.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fetch_struct_mmsghdr.Tpo $(DEPDIR)/strace-fetch_struct_mmsghdr.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_mmsghdr.c' object='strace-fetch_struct_mmsghdr.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fspick.o: fspick.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fspick.o -MD -MP -MF $(DEPDIR)/libstrace_a-fspick.Tpo -c -o libstrace_a-fspick.o `test -f 'fspick.c' || echo '$(srcdir)/'`fspick.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fspick.Tpo $(DEPDIR)/libstrace_a-fspick.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fspick.c' object='libstrace_a-fspick.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fetch_struct_mmsghdr.obj `if test -f 'fetch_struct_mmsghdr.c'; then $(CYGPATH_W) 'fetch_struct_mmsghdr.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_mmsghdr.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fspick.o `test -f 'fspick.c' || echo '$(srcdir)/'`fspick.c
 
-strace-fetch_struct_msghdr.o: fetch_struct_msghdr.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fetch_struct_msghdr.o -MD -MP -MF $(DEPDIR)/strace-fetch_struct_msghdr.Tpo -c -o strace-fetch_struct_msghdr.o `test -f 'fetch_struct_msghdr.c' || echo '$(srcdir)/'`fetch_struct_msghdr.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fetch_struct_msghdr.Tpo $(DEPDIR)/strace-fetch_struct_msghdr.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_msghdr.c' object='strace-fetch_struct_msghdr.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fspick.obj: fspick.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fspick.obj -MD -MP -MF $(DEPDIR)/libstrace_a-fspick.Tpo -c -o libstrace_a-fspick.obj `if test -f 'fspick.c'; then $(CYGPATH_W) 'fspick.c'; else $(CYGPATH_W) '$(srcdir)/fspick.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fspick.Tpo $(DEPDIR)/libstrace_a-fspick.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fspick.c' object='libstrace_a-fspick.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fetch_struct_msghdr.o `test -f 'fetch_struct_msghdr.c' || echo '$(srcdir)/'`fetch_struct_msghdr.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fspick.obj `if test -f 'fspick.c'; then $(CYGPATH_W) 'fspick.c'; else $(CYGPATH_W) '$(srcdir)/fspick.c'; fi`
 
-strace-fetch_struct_msghdr.obj: fetch_struct_msghdr.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fetch_struct_msghdr.obj -MD -MP -MF $(DEPDIR)/strace-fetch_struct_msghdr.Tpo -c -o strace-fetch_struct_msghdr.obj `if test -f 'fetch_struct_msghdr.c'; then $(CYGPATH_W) 'fetch_struct_msghdr.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_msghdr.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fetch_struct_msghdr.Tpo $(DEPDIR)/strace-fetch_struct_msghdr.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_msghdr.c' object='strace-fetch_struct_msghdr.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fstatfs.o: fstatfs.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fstatfs.o -MD -MP -MF $(DEPDIR)/libstrace_a-fstatfs.Tpo -c -o libstrace_a-fstatfs.o `test -f 'fstatfs.c' || echo '$(srcdir)/'`fstatfs.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fstatfs.Tpo $(DEPDIR)/libstrace_a-fstatfs.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fstatfs.c' object='libstrace_a-fstatfs.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fetch_struct_msghdr.obj `if test -f 'fetch_struct_msghdr.c'; then $(CYGPATH_W) 'fetch_struct_msghdr.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_msghdr.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fstatfs.o `test -f 'fstatfs.c' || echo '$(srcdir)/'`fstatfs.c
 
-strace-fetch_struct_stat.o: fetch_struct_stat.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fetch_struct_stat.o -MD -MP -MF $(DEPDIR)/strace-fetch_struct_stat.Tpo -c -o strace-fetch_struct_stat.o `test -f 'fetch_struct_stat.c' || echo '$(srcdir)/'`fetch_struct_stat.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fetch_struct_stat.Tpo $(DEPDIR)/strace-fetch_struct_stat.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_stat.c' object='strace-fetch_struct_stat.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fstatfs.obj: fstatfs.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fstatfs.obj -MD -MP -MF $(DEPDIR)/libstrace_a-fstatfs.Tpo -c -o libstrace_a-fstatfs.obj `if test -f 'fstatfs.c'; then $(CYGPATH_W) 'fstatfs.c'; else $(CYGPATH_W) '$(srcdir)/fstatfs.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fstatfs.Tpo $(DEPDIR)/libstrace_a-fstatfs.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fstatfs.c' object='libstrace_a-fstatfs.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fetch_struct_stat.o `test -f 'fetch_struct_stat.c' || echo '$(srcdir)/'`fetch_struct_stat.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fstatfs.obj `if test -f 'fstatfs.c'; then $(CYGPATH_W) 'fstatfs.c'; else $(CYGPATH_W) '$(srcdir)/fstatfs.c'; fi`
 
-strace-fetch_struct_stat.obj: fetch_struct_stat.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fetch_struct_stat.obj -MD -MP -MF $(DEPDIR)/strace-fetch_struct_stat.Tpo -c -o strace-fetch_struct_stat.obj `if test -f 'fetch_struct_stat.c'; then $(CYGPATH_W) 'fetch_struct_stat.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_stat.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fetch_struct_stat.Tpo $(DEPDIR)/strace-fetch_struct_stat.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_stat.c' object='strace-fetch_struct_stat.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fstatfs64.o: fstatfs64.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fstatfs64.o -MD -MP -MF $(DEPDIR)/libstrace_a-fstatfs64.Tpo -c -o libstrace_a-fstatfs64.o `test -f 'fstatfs64.c' || echo '$(srcdir)/'`fstatfs64.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fstatfs64.Tpo $(DEPDIR)/libstrace_a-fstatfs64.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fstatfs64.c' object='libstrace_a-fstatfs64.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fetch_struct_stat.obj `if test -f 'fetch_struct_stat.c'; then $(CYGPATH_W) 'fetch_struct_stat.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_stat.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fstatfs64.o `test -f 'fstatfs64.c' || echo '$(srcdir)/'`fstatfs64.c
 
-strace-fetch_struct_stat64.o: fetch_struct_stat64.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fetch_struct_stat64.o -MD -MP -MF $(DEPDIR)/strace-fetch_struct_stat64.Tpo -c -o strace-fetch_struct_stat64.o `test -f 'fetch_struct_stat64.c' || echo '$(srcdir)/'`fetch_struct_stat64.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fetch_struct_stat64.Tpo $(DEPDIR)/strace-fetch_struct_stat64.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_stat64.c' object='strace-fetch_struct_stat64.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-fstatfs64.obj: fstatfs64.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-fstatfs64.obj -MD -MP -MF $(DEPDIR)/libstrace_a-fstatfs64.Tpo -c -o libstrace_a-fstatfs64.obj `if test -f 'fstatfs64.c'; then $(CYGPATH_W) 'fstatfs64.c'; else $(CYGPATH_W) '$(srcdir)/fstatfs64.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-fstatfs64.Tpo $(DEPDIR)/libstrace_a-fstatfs64.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fstatfs64.c' object='libstrace_a-fstatfs64.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fetch_struct_stat64.o `test -f 'fetch_struct_stat64.c' || echo '$(srcdir)/'`fetch_struct_stat64.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-fstatfs64.obj `if test -f 'fstatfs64.c'; then $(CYGPATH_W) 'fstatfs64.c'; else $(CYGPATH_W) '$(srcdir)/fstatfs64.c'; fi`
 
-strace-fetch_struct_stat64.obj: fetch_struct_stat64.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fetch_struct_stat64.obj -MD -MP -MF $(DEPDIR)/strace-fetch_struct_stat64.Tpo -c -o strace-fetch_struct_stat64.obj `if test -f 'fetch_struct_stat64.c'; then $(CYGPATH_W) 'fetch_struct_stat64.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_stat64.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fetch_struct_stat64.Tpo $(DEPDIR)/strace-fetch_struct_stat64.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_stat64.c' object='strace-fetch_struct_stat64.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-futex.o: futex.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-futex.o -MD -MP -MF $(DEPDIR)/libstrace_a-futex.Tpo -c -o libstrace_a-futex.o `test -f 'futex.c' || echo '$(srcdir)/'`futex.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-futex.Tpo $(DEPDIR)/libstrace_a-futex.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='futex.c' object='libstrace_a-futex.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fetch_struct_stat64.obj `if test -f 'fetch_struct_stat64.c'; then $(CYGPATH_W) 'fetch_struct_stat64.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_stat64.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-futex.o `test -f 'futex.c' || echo '$(srcdir)/'`futex.c
 
-strace-fetch_struct_statfs.o: fetch_struct_statfs.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fetch_struct_statfs.o -MD -MP -MF $(DEPDIR)/strace-fetch_struct_statfs.Tpo -c -o strace-fetch_struct_statfs.o `test -f 'fetch_struct_statfs.c' || echo '$(srcdir)/'`fetch_struct_statfs.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fetch_struct_statfs.Tpo $(DEPDIR)/strace-fetch_struct_statfs.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_statfs.c' object='strace-fetch_struct_statfs.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-futex.obj: futex.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-futex.obj -MD -MP -MF $(DEPDIR)/libstrace_a-futex.Tpo -c -o libstrace_a-futex.obj `if test -f 'futex.c'; then $(CYGPATH_W) 'futex.c'; else $(CYGPATH_W) '$(srcdir)/futex.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-futex.Tpo $(DEPDIR)/libstrace_a-futex.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='futex.c' object='libstrace_a-futex.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fetch_struct_statfs.o `test -f 'fetch_struct_statfs.c' || echo '$(srcdir)/'`fetch_struct_statfs.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-futex.obj `if test -f 'futex.c'; then $(CYGPATH_W) 'futex.c'; else $(CYGPATH_W) '$(srcdir)/futex.c'; fi`
 
-strace-fetch_struct_statfs.obj: fetch_struct_statfs.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fetch_struct_statfs.obj -MD -MP -MF $(DEPDIR)/strace-fetch_struct_statfs.Tpo -c -o strace-fetch_struct_statfs.obj `if test -f 'fetch_struct_statfs.c'; then $(CYGPATH_W) 'fetch_struct_statfs.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_statfs.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fetch_struct_statfs.Tpo $(DEPDIR)/strace-fetch_struct_statfs.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_statfs.c' object='strace-fetch_struct_statfs.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-get_personality.o: get_personality.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-get_personality.o -MD -MP -MF $(DEPDIR)/libstrace_a-get_personality.Tpo -c -o libstrace_a-get_personality.o `test -f 'get_personality.c' || echo '$(srcdir)/'`get_personality.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-get_personality.Tpo $(DEPDIR)/libstrace_a-get_personality.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='get_personality.c' object='libstrace_a-get_personality.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fetch_struct_statfs.obj `if test -f 'fetch_struct_statfs.c'; then $(CYGPATH_W) 'fetch_struct_statfs.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_statfs.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-get_personality.o `test -f 'get_personality.c' || echo '$(srcdir)/'`get_personality.c
 
-strace-fetch_struct_xfs_quotastat.o: fetch_struct_xfs_quotastat.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fetch_struct_xfs_quotastat.o -MD -MP -MF $(DEPDIR)/strace-fetch_struct_xfs_quotastat.Tpo -c -o strace-fetch_struct_xfs_quotastat.o `test -f 'fetch_struct_xfs_quotastat.c' || echo '$(srcdir)/'`fetch_struct_xfs_quotastat.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fetch_struct_xfs_quotastat.Tpo $(DEPDIR)/strace-fetch_struct_xfs_quotastat.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_xfs_quotastat.c' object='strace-fetch_struct_xfs_quotastat.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-get_personality.obj: get_personality.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-get_personality.obj -MD -MP -MF $(DEPDIR)/libstrace_a-get_personality.Tpo -c -o libstrace_a-get_personality.obj `if test -f 'get_personality.c'; then $(CYGPATH_W) 'get_personality.c'; else $(CYGPATH_W) '$(srcdir)/get_personality.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-get_personality.Tpo $(DEPDIR)/libstrace_a-get_personality.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='get_personality.c' object='libstrace_a-get_personality.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fetch_struct_xfs_quotastat.o `test -f 'fetch_struct_xfs_quotastat.c' || echo '$(srcdir)/'`fetch_struct_xfs_quotastat.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-get_personality.obj `if test -f 'get_personality.c'; then $(CYGPATH_W) 'get_personality.c'; else $(CYGPATH_W) '$(srcdir)/get_personality.c'; fi`
 
-strace-fetch_struct_xfs_quotastat.obj: fetch_struct_xfs_quotastat.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fetch_struct_xfs_quotastat.obj -MD -MP -MF $(DEPDIR)/strace-fetch_struct_xfs_quotastat.Tpo -c -o strace-fetch_struct_xfs_quotastat.obj `if test -f 'fetch_struct_xfs_quotastat.c'; then $(CYGPATH_W) 'fetch_struct_xfs_quotastat.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_xfs_quotastat.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fetch_struct_xfs_quotastat.Tpo $(DEPDIR)/strace-fetch_struct_xfs_quotastat.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fetch_struct_xfs_quotastat.c' object='strace-fetch_struct_xfs_quotastat.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-get_robust_list.o: get_robust_list.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-get_robust_list.o -MD -MP -MF $(DEPDIR)/libstrace_a-get_robust_list.Tpo -c -o libstrace_a-get_robust_list.o `test -f 'get_robust_list.c' || echo '$(srcdir)/'`get_robust_list.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-get_robust_list.Tpo $(DEPDIR)/libstrace_a-get_robust_list.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='get_robust_list.c' object='libstrace_a-get_robust_list.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fetch_struct_xfs_quotastat.obj `if test -f 'fetch_struct_xfs_quotastat.c'; then $(CYGPATH_W) 'fetch_struct_xfs_quotastat.c'; else $(CYGPATH_W) '$(srcdir)/fetch_struct_xfs_quotastat.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-get_robust_list.o `test -f 'get_robust_list.c' || echo '$(srcdir)/'`get_robust_list.c
 
-strace-file_handle.o: file_handle.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-file_handle.o -MD -MP -MF $(DEPDIR)/strace-file_handle.Tpo -c -o strace-file_handle.o `test -f 'file_handle.c' || echo '$(srcdir)/'`file_handle.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-file_handle.Tpo $(DEPDIR)/strace-file_handle.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='file_handle.c' object='strace-file_handle.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-get_robust_list.obj: get_robust_list.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-get_robust_list.obj -MD -MP -MF $(DEPDIR)/libstrace_a-get_robust_list.Tpo -c -o libstrace_a-get_robust_list.obj `if test -f 'get_robust_list.c'; then $(CYGPATH_W) 'get_robust_list.c'; else $(CYGPATH_W) '$(srcdir)/get_robust_list.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-get_robust_list.Tpo $(DEPDIR)/libstrace_a-get_robust_list.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='get_robust_list.c' object='libstrace_a-get_robust_list.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-file_handle.o `test -f 'file_handle.c' || echo '$(srcdir)/'`file_handle.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-get_robust_list.obj `if test -f 'get_robust_list.c'; then $(CYGPATH_W) 'get_robust_list.c'; else $(CYGPATH_W) '$(srcdir)/get_robust_list.c'; fi`
 
-strace-file_handle.obj: file_handle.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-file_handle.obj -MD -MP -MF $(DEPDIR)/strace-file_handle.Tpo -c -o strace-file_handle.obj `if test -f 'file_handle.c'; then $(CYGPATH_W) 'file_handle.c'; else $(CYGPATH_W) '$(srcdir)/file_handle.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-file_handle.Tpo $(DEPDIR)/strace-file_handle.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='file_handle.c' object='strace-file_handle.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-getcpu.o: getcpu.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-getcpu.o -MD -MP -MF $(DEPDIR)/libstrace_a-getcpu.Tpo -c -o libstrace_a-getcpu.o `test -f 'getcpu.c' || echo '$(srcdir)/'`getcpu.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-getcpu.Tpo $(DEPDIR)/libstrace_a-getcpu.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='getcpu.c' object='libstrace_a-getcpu.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-file_handle.obj `if test -f 'file_handle.c'; then $(CYGPATH_W) 'file_handle.c'; else $(CYGPATH_W) '$(srcdir)/file_handle.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-getcpu.o `test -f 'getcpu.c' || echo '$(srcdir)/'`getcpu.c
 
-strace-file_ioctl.o: file_ioctl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-file_ioctl.o -MD -MP -MF $(DEPDIR)/strace-file_ioctl.Tpo -c -o strace-file_ioctl.o `test -f 'file_ioctl.c' || echo '$(srcdir)/'`file_ioctl.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-file_ioctl.Tpo $(DEPDIR)/strace-file_ioctl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='file_ioctl.c' object='strace-file_ioctl.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-getcpu.obj: getcpu.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-getcpu.obj -MD -MP -MF $(DEPDIR)/libstrace_a-getcpu.Tpo -c -o libstrace_a-getcpu.obj `if test -f 'getcpu.c'; then $(CYGPATH_W) 'getcpu.c'; else $(CYGPATH_W) '$(srcdir)/getcpu.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-getcpu.Tpo $(DEPDIR)/libstrace_a-getcpu.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='getcpu.c' object='libstrace_a-getcpu.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-file_ioctl.o `test -f 'file_ioctl.c' || echo '$(srcdir)/'`file_ioctl.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-getcpu.obj `if test -f 'getcpu.c'; then $(CYGPATH_W) 'getcpu.c'; else $(CYGPATH_W) '$(srcdir)/getcpu.c'; fi`
 
-strace-file_ioctl.obj: file_ioctl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-file_ioctl.obj -MD -MP -MF $(DEPDIR)/strace-file_ioctl.Tpo -c -o strace-file_ioctl.obj `if test -f 'file_ioctl.c'; then $(CYGPATH_W) 'file_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/file_ioctl.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-file_ioctl.Tpo $(DEPDIR)/strace-file_ioctl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='file_ioctl.c' object='strace-file_ioctl.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-getcwd.o: getcwd.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-getcwd.o -MD -MP -MF $(DEPDIR)/libstrace_a-getcwd.Tpo -c -o libstrace_a-getcwd.o `test -f 'getcwd.c' || echo '$(srcdir)/'`getcwd.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-getcwd.Tpo $(DEPDIR)/libstrace_a-getcwd.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='getcwd.c' object='libstrace_a-getcwd.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-file_ioctl.obj `if test -f 'file_ioctl.c'; then $(CYGPATH_W) 'file_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/file_ioctl.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-getcwd.o `test -f 'getcwd.c' || echo '$(srcdir)/'`getcwd.c
 
-strace-filter_qualify.o: filter_qualify.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-filter_qualify.o -MD -MP -MF $(DEPDIR)/strace-filter_qualify.Tpo -c -o strace-filter_qualify.o `test -f 'filter_qualify.c' || echo '$(srcdir)/'`filter_qualify.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-filter_qualify.Tpo $(DEPDIR)/strace-filter_qualify.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='filter_qualify.c' object='strace-filter_qualify.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-getcwd.obj: getcwd.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-getcwd.obj -MD -MP -MF $(DEPDIR)/libstrace_a-getcwd.Tpo -c -o libstrace_a-getcwd.obj `if test -f 'getcwd.c'; then $(CYGPATH_W) 'getcwd.c'; else $(CYGPATH_W) '$(srcdir)/getcwd.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-getcwd.Tpo $(DEPDIR)/libstrace_a-getcwd.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='getcwd.c' object='libstrace_a-getcwd.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-filter_qualify.o `test -f 'filter_qualify.c' || echo '$(srcdir)/'`filter_qualify.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-getcwd.obj `if test -f 'getcwd.c'; then $(CYGPATH_W) 'getcwd.c'; else $(CYGPATH_W) '$(srcdir)/getcwd.c'; fi`
 
-strace-filter_qualify.obj: filter_qualify.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-filter_qualify.obj -MD -MP -MF $(DEPDIR)/strace-filter_qualify.Tpo -c -o strace-filter_qualify.obj `if test -f 'filter_qualify.c'; then $(CYGPATH_W) 'filter_qualify.c'; else $(CYGPATH_W) '$(srcdir)/filter_qualify.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-filter_qualify.Tpo $(DEPDIR)/strace-filter_qualify.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='filter_qualify.c' object='strace-filter_qualify.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-getpagesize.o: getpagesize.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-getpagesize.o -MD -MP -MF $(DEPDIR)/libstrace_a-getpagesize.Tpo -c -o libstrace_a-getpagesize.o `test -f 'getpagesize.c' || echo '$(srcdir)/'`getpagesize.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-getpagesize.Tpo $(DEPDIR)/libstrace_a-getpagesize.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='getpagesize.c' object='libstrace_a-getpagesize.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-filter_qualify.obj `if test -f 'filter_qualify.c'; then $(CYGPATH_W) 'filter_qualify.c'; else $(CYGPATH_W) '$(srcdir)/filter_qualify.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-getpagesize.o `test -f 'getpagesize.c' || echo '$(srcdir)/'`getpagesize.c
 
-strace-filter_seccomp.o: filter_seccomp.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-filter_seccomp.o -MD -MP -MF $(DEPDIR)/strace-filter_seccomp.Tpo -c -o strace-filter_seccomp.o `test -f 'filter_seccomp.c' || echo '$(srcdir)/'`filter_seccomp.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-filter_seccomp.Tpo $(DEPDIR)/strace-filter_seccomp.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='filter_seccomp.c' object='strace-filter_seccomp.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-getpagesize.obj: getpagesize.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-getpagesize.obj -MD -MP -MF $(DEPDIR)/libstrace_a-getpagesize.Tpo -c -o libstrace_a-getpagesize.obj `if test -f 'getpagesize.c'; then $(CYGPATH_W) 'getpagesize.c'; else $(CYGPATH_W) '$(srcdir)/getpagesize.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-getpagesize.Tpo $(DEPDIR)/libstrace_a-getpagesize.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='getpagesize.c' object='libstrace_a-getpagesize.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-filter_seccomp.o `test -f 'filter_seccomp.c' || echo '$(srcdir)/'`filter_seccomp.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-getpagesize.obj `if test -f 'getpagesize.c'; then $(CYGPATH_W) 'getpagesize.c'; else $(CYGPATH_W) '$(srcdir)/getpagesize.c'; fi`
 
-strace-filter_seccomp.obj: filter_seccomp.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-filter_seccomp.obj -MD -MP -MF $(DEPDIR)/strace-filter_seccomp.Tpo -c -o strace-filter_seccomp.obj `if test -f 'filter_seccomp.c'; then $(CYGPATH_W) 'filter_seccomp.c'; else $(CYGPATH_W) '$(srcdir)/filter_seccomp.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-filter_seccomp.Tpo $(DEPDIR)/strace-filter_seccomp.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='filter_seccomp.c' object='strace-filter_seccomp.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-getpid.o: getpid.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-getpid.o -MD -MP -MF $(DEPDIR)/libstrace_a-getpid.Tpo -c -o libstrace_a-getpid.o `test -f 'getpid.c' || echo '$(srcdir)/'`getpid.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-getpid.Tpo $(DEPDIR)/libstrace_a-getpid.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='getpid.c' object='libstrace_a-getpid.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-filter_seccomp.obj `if test -f 'filter_seccomp.c'; then $(CYGPATH_W) 'filter_seccomp.c'; else $(CYGPATH_W) '$(srcdir)/filter_seccomp.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-getpid.o `test -f 'getpid.c' || echo '$(srcdir)/'`getpid.c
 
-strace-flock.o: flock.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-flock.o -MD -MP -MF $(DEPDIR)/strace-flock.Tpo -c -o strace-flock.o `test -f 'flock.c' || echo '$(srcdir)/'`flock.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-flock.Tpo $(DEPDIR)/strace-flock.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='flock.c' object='strace-flock.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-getpid.obj: getpid.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-getpid.obj -MD -MP -MF $(DEPDIR)/libstrace_a-getpid.Tpo -c -o libstrace_a-getpid.obj `if test -f 'getpid.c'; then $(CYGPATH_W) 'getpid.c'; else $(CYGPATH_W) '$(srcdir)/getpid.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-getpid.Tpo $(DEPDIR)/libstrace_a-getpid.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='getpid.c' object='libstrace_a-getpid.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-flock.o `test -f 'flock.c' || echo '$(srcdir)/'`flock.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-getpid.obj `if test -f 'getpid.c'; then $(CYGPATH_W) 'getpid.c'; else $(CYGPATH_W) '$(srcdir)/getpid.c'; fi`
 
-strace-flock.obj: flock.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-flock.obj -MD -MP -MF $(DEPDIR)/strace-flock.Tpo -c -o strace-flock.obj `if test -f 'flock.c'; then $(CYGPATH_W) 'flock.c'; else $(CYGPATH_W) '$(srcdir)/flock.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-flock.Tpo $(DEPDIR)/strace-flock.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='flock.c' object='strace-flock.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-getrandom.o: getrandom.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-getrandom.o -MD -MP -MF $(DEPDIR)/libstrace_a-getrandom.Tpo -c -o libstrace_a-getrandom.o `test -f 'getrandom.c' || echo '$(srcdir)/'`getrandom.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-getrandom.Tpo $(DEPDIR)/libstrace_a-getrandom.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='getrandom.c' object='libstrace_a-getrandom.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-flock.obj `if test -f 'flock.c'; then $(CYGPATH_W) 'flock.c'; else $(CYGPATH_W) '$(srcdir)/flock.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-getrandom.o `test -f 'getrandom.c' || echo '$(srcdir)/'`getrandom.c
 
-strace-fs_x_ioctl.o: fs_x_ioctl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fs_x_ioctl.o -MD -MP -MF $(DEPDIR)/strace-fs_x_ioctl.Tpo -c -o strace-fs_x_ioctl.o `test -f 'fs_x_ioctl.c' || echo '$(srcdir)/'`fs_x_ioctl.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fs_x_ioctl.Tpo $(DEPDIR)/strace-fs_x_ioctl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fs_x_ioctl.c' object='strace-fs_x_ioctl.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-getrandom.obj: getrandom.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-getrandom.obj -MD -MP -MF $(DEPDIR)/libstrace_a-getrandom.Tpo -c -o libstrace_a-getrandom.obj `if test -f 'getrandom.c'; then $(CYGPATH_W) 'getrandom.c'; else $(CYGPATH_W) '$(srcdir)/getrandom.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-getrandom.Tpo $(DEPDIR)/libstrace_a-getrandom.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='getrandom.c' object='libstrace_a-getrandom.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fs_x_ioctl.o `test -f 'fs_x_ioctl.c' || echo '$(srcdir)/'`fs_x_ioctl.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-getrandom.obj `if test -f 'getrandom.c'; then $(CYGPATH_W) 'getrandom.c'; else $(CYGPATH_W) '$(srcdir)/getrandom.c'; fi`
 
-strace-fs_x_ioctl.obj: fs_x_ioctl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fs_x_ioctl.obj -MD -MP -MF $(DEPDIR)/strace-fs_x_ioctl.Tpo -c -o strace-fs_x_ioctl.obj `if test -f 'fs_x_ioctl.c'; then $(CYGPATH_W) 'fs_x_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/fs_x_ioctl.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fs_x_ioctl.Tpo $(DEPDIR)/strace-fs_x_ioctl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fs_x_ioctl.c' object='strace-fs_x_ioctl.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-hdio.o: hdio.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-hdio.o -MD -MP -MF $(DEPDIR)/libstrace_a-hdio.Tpo -c -o libstrace_a-hdio.o `test -f 'hdio.c' || echo '$(srcdir)/'`hdio.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-hdio.Tpo $(DEPDIR)/libstrace_a-hdio.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='hdio.c' object='libstrace_a-hdio.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fs_x_ioctl.obj `if test -f 'fs_x_ioctl.c'; then $(CYGPATH_W) 'fs_x_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/fs_x_ioctl.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-hdio.o `test -f 'hdio.c' || echo '$(srcdir)/'`hdio.c
 
-strace-fsconfig.o: fsconfig.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fsconfig.o -MD -MP -MF $(DEPDIR)/strace-fsconfig.Tpo -c -o strace-fsconfig.o `test -f 'fsconfig.c' || echo '$(srcdir)/'`fsconfig.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fsconfig.Tpo $(DEPDIR)/strace-fsconfig.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fsconfig.c' object='strace-fsconfig.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-hdio.obj: hdio.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-hdio.obj -MD -MP -MF $(DEPDIR)/libstrace_a-hdio.Tpo -c -o libstrace_a-hdio.obj `if test -f 'hdio.c'; then $(CYGPATH_W) 'hdio.c'; else $(CYGPATH_W) '$(srcdir)/hdio.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-hdio.Tpo $(DEPDIR)/libstrace_a-hdio.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='hdio.c' object='libstrace_a-hdio.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fsconfig.o `test -f 'fsconfig.c' || echo '$(srcdir)/'`fsconfig.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-hdio.obj `if test -f 'hdio.c'; then $(CYGPATH_W) 'hdio.c'; else $(CYGPATH_W) '$(srcdir)/hdio.c'; fi`
 
-strace-fsconfig.obj: fsconfig.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fsconfig.obj -MD -MP -MF $(DEPDIR)/strace-fsconfig.Tpo -c -o strace-fsconfig.obj `if test -f 'fsconfig.c'; then $(CYGPATH_W) 'fsconfig.c'; else $(CYGPATH_W) '$(srcdir)/fsconfig.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fsconfig.Tpo $(DEPDIR)/strace-fsconfig.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fsconfig.c' object='strace-fsconfig.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-hostname.o: hostname.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-hostname.o -MD -MP -MF $(DEPDIR)/libstrace_a-hostname.Tpo -c -o libstrace_a-hostname.o `test -f 'hostname.c' || echo '$(srcdir)/'`hostname.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-hostname.Tpo $(DEPDIR)/libstrace_a-hostname.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='hostname.c' object='libstrace_a-hostname.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fsconfig.obj `if test -f 'fsconfig.c'; then $(CYGPATH_W) 'fsconfig.c'; else $(CYGPATH_W) '$(srcdir)/fsconfig.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-hostname.o `test -f 'hostname.c' || echo '$(srcdir)/'`hostname.c
 
-strace-fsmount.o: fsmount.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fsmount.o -MD -MP -MF $(DEPDIR)/strace-fsmount.Tpo -c -o strace-fsmount.o `test -f 'fsmount.c' || echo '$(srcdir)/'`fsmount.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fsmount.Tpo $(DEPDIR)/strace-fsmount.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fsmount.c' object='strace-fsmount.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-hostname.obj: hostname.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-hostname.obj -MD -MP -MF $(DEPDIR)/libstrace_a-hostname.Tpo -c -o libstrace_a-hostname.obj `if test -f 'hostname.c'; then $(CYGPATH_W) 'hostname.c'; else $(CYGPATH_W) '$(srcdir)/hostname.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-hostname.Tpo $(DEPDIR)/libstrace_a-hostname.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='hostname.c' object='libstrace_a-hostname.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fsmount.o `test -f 'fsmount.c' || echo '$(srcdir)/'`fsmount.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-hostname.obj `if test -f 'hostname.c'; then $(CYGPATH_W) 'hostname.c'; else $(CYGPATH_W) '$(srcdir)/hostname.c'; fi`
 
-strace-fsmount.obj: fsmount.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fsmount.obj -MD -MP -MF $(DEPDIR)/strace-fsmount.Tpo -c -o strace-fsmount.obj `if test -f 'fsmount.c'; then $(CYGPATH_W) 'fsmount.c'; else $(CYGPATH_W) '$(srcdir)/fsmount.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fsmount.Tpo $(DEPDIR)/strace-fsmount.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fsmount.c' object='strace-fsmount.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-inotify.o: inotify.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-inotify.o -MD -MP -MF $(DEPDIR)/libstrace_a-inotify.Tpo -c -o libstrace_a-inotify.o `test -f 'inotify.c' || echo '$(srcdir)/'`inotify.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-inotify.Tpo $(DEPDIR)/libstrace_a-inotify.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='inotify.c' object='libstrace_a-inotify.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fsmount.obj `if test -f 'fsmount.c'; then $(CYGPATH_W) 'fsmount.c'; else $(CYGPATH_W) '$(srcdir)/fsmount.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-inotify.o `test -f 'inotify.c' || echo '$(srcdir)/'`inotify.c
 
-strace-fsopen.o: fsopen.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fsopen.o -MD -MP -MF $(DEPDIR)/strace-fsopen.Tpo -c -o strace-fsopen.o `test -f 'fsopen.c' || echo '$(srcdir)/'`fsopen.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fsopen.Tpo $(DEPDIR)/strace-fsopen.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fsopen.c' object='strace-fsopen.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-inotify.obj: inotify.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-inotify.obj -MD -MP -MF $(DEPDIR)/libstrace_a-inotify.Tpo -c -o libstrace_a-inotify.obj `if test -f 'inotify.c'; then $(CYGPATH_W) 'inotify.c'; else $(CYGPATH_W) '$(srcdir)/inotify.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-inotify.Tpo $(DEPDIR)/libstrace_a-inotify.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='inotify.c' object='libstrace_a-inotify.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fsopen.o `test -f 'fsopen.c' || echo '$(srcdir)/'`fsopen.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-inotify.obj `if test -f 'inotify.c'; then $(CYGPATH_W) 'inotify.c'; else $(CYGPATH_W) '$(srcdir)/inotify.c'; fi`
 
-strace-fsopen.obj: fsopen.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fsopen.obj -MD -MP -MF $(DEPDIR)/strace-fsopen.Tpo -c -o strace-fsopen.obj `if test -f 'fsopen.c'; then $(CYGPATH_W) 'fsopen.c'; else $(CYGPATH_W) '$(srcdir)/fsopen.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fsopen.Tpo $(DEPDIR)/strace-fsopen.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fsopen.c' object='strace-fsopen.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-inotify_ioctl.o: inotify_ioctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-inotify_ioctl.o -MD -MP -MF $(DEPDIR)/libstrace_a-inotify_ioctl.Tpo -c -o libstrace_a-inotify_ioctl.o `test -f 'inotify_ioctl.c' || echo '$(srcdir)/'`inotify_ioctl.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-inotify_ioctl.Tpo $(DEPDIR)/libstrace_a-inotify_ioctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='inotify_ioctl.c' object='libstrace_a-inotify_ioctl.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fsopen.obj `if test -f 'fsopen.c'; then $(CYGPATH_W) 'fsopen.c'; else $(CYGPATH_W) '$(srcdir)/fsopen.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-inotify_ioctl.o `test -f 'inotify_ioctl.c' || echo '$(srcdir)/'`inotify_ioctl.c
 
-strace-fspick.o: fspick.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fspick.o -MD -MP -MF $(DEPDIR)/strace-fspick.Tpo -c -o strace-fspick.o `test -f 'fspick.c' || echo '$(srcdir)/'`fspick.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fspick.Tpo $(DEPDIR)/strace-fspick.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fspick.c' object='strace-fspick.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-inotify_ioctl.obj: inotify_ioctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-inotify_ioctl.obj -MD -MP -MF $(DEPDIR)/libstrace_a-inotify_ioctl.Tpo -c -o libstrace_a-inotify_ioctl.obj `if test -f 'inotify_ioctl.c'; then $(CYGPATH_W) 'inotify_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/inotify_ioctl.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-inotify_ioctl.Tpo $(DEPDIR)/libstrace_a-inotify_ioctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='inotify_ioctl.c' object='libstrace_a-inotify_ioctl.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fspick.o `test -f 'fspick.c' || echo '$(srcdir)/'`fspick.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-inotify_ioctl.obj `if test -f 'inotify_ioctl.c'; then $(CYGPATH_W) 'inotify_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/inotify_ioctl.c'; fi`
 
-strace-fspick.obj: fspick.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-fspick.obj -MD -MP -MF $(DEPDIR)/strace-fspick.Tpo -c -o strace-fspick.obj `if test -f 'fspick.c'; then $(CYGPATH_W) 'fspick.c'; else $(CYGPATH_W) '$(srcdir)/fspick.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-fspick.Tpo $(DEPDIR)/strace-fspick.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='fspick.c' object='strace-fspick.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-io.o: io.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-io.o -MD -MP -MF $(DEPDIR)/libstrace_a-io.Tpo -c -o libstrace_a-io.o `test -f 'io.c' || echo '$(srcdir)/'`io.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-io.Tpo $(DEPDIR)/libstrace_a-io.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='io.c' object='libstrace_a-io.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-fspick.obj `if test -f 'fspick.c'; then $(CYGPATH_W) 'fspick.c'; else $(CYGPATH_W) '$(srcdir)/fspick.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-io.o `test -f 'io.c' || echo '$(srcdir)/'`io.c
 
-strace-futex.o: futex.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-futex.o -MD -MP -MF $(DEPDIR)/strace-futex.Tpo -c -o strace-futex.o `test -f 'futex.c' || echo '$(srcdir)/'`futex.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-futex.Tpo $(DEPDIR)/strace-futex.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='futex.c' object='strace-futex.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-io.obj: io.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-io.obj -MD -MP -MF $(DEPDIR)/libstrace_a-io.Tpo -c -o libstrace_a-io.obj `if test -f 'io.c'; then $(CYGPATH_W) 'io.c'; else $(CYGPATH_W) '$(srcdir)/io.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-io.Tpo $(DEPDIR)/libstrace_a-io.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='io.c' object='libstrace_a-io.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-futex.o `test -f 'futex.c' || echo '$(srcdir)/'`futex.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-io.obj `if test -f 'io.c'; then $(CYGPATH_W) 'io.c'; else $(CYGPATH_W) '$(srcdir)/io.c'; fi`
 
-strace-futex.obj: futex.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-futex.obj -MD -MP -MF $(DEPDIR)/strace-futex.Tpo -c -o strace-futex.obj `if test -f 'futex.c'; then $(CYGPATH_W) 'futex.c'; else $(CYGPATH_W) '$(srcdir)/futex.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-futex.Tpo $(DEPDIR)/strace-futex.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='futex.c' object='strace-futex.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-io_uring.o: io_uring.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-io_uring.o -MD -MP -MF $(DEPDIR)/libstrace_a-io_uring.Tpo -c -o libstrace_a-io_uring.o `test -f 'io_uring.c' || echo '$(srcdir)/'`io_uring.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-io_uring.Tpo $(DEPDIR)/libstrace_a-io_uring.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='io_uring.c' object='libstrace_a-io_uring.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-futex.obj `if test -f 'futex.c'; then $(CYGPATH_W) 'futex.c'; else $(CYGPATH_W) '$(srcdir)/futex.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-io_uring.o `test -f 'io_uring.c' || echo '$(srcdir)/'`io_uring.c
 
-strace-get_personality.o: get_personality.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-get_personality.o -MD -MP -MF $(DEPDIR)/strace-get_personality.Tpo -c -o strace-get_personality.o `test -f 'get_personality.c' || echo '$(srcdir)/'`get_personality.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-get_personality.Tpo $(DEPDIR)/strace-get_personality.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='get_personality.c' object='strace-get_personality.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-io_uring.obj: io_uring.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-io_uring.obj -MD -MP -MF $(DEPDIR)/libstrace_a-io_uring.Tpo -c -o libstrace_a-io_uring.obj `if test -f 'io_uring.c'; then $(CYGPATH_W) 'io_uring.c'; else $(CYGPATH_W) '$(srcdir)/io_uring.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-io_uring.Tpo $(DEPDIR)/libstrace_a-io_uring.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='io_uring.c' object='libstrace_a-io_uring.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-get_personality.o `test -f 'get_personality.c' || echo '$(srcdir)/'`get_personality.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-io_uring.obj `if test -f 'io_uring.c'; then $(CYGPATH_W) 'io_uring.c'; else $(CYGPATH_W) '$(srcdir)/io_uring.c'; fi`
 
-strace-get_personality.obj: get_personality.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-get_personality.obj -MD -MP -MF $(DEPDIR)/strace-get_personality.Tpo -c -o strace-get_personality.obj `if test -f 'get_personality.c'; then $(CYGPATH_W) 'get_personality.c'; else $(CYGPATH_W) '$(srcdir)/get_personality.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-get_personality.Tpo $(DEPDIR)/strace-get_personality.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='get_personality.c' object='strace-get_personality.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ioctl.o: ioctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ioctl.o -MD -MP -MF $(DEPDIR)/libstrace_a-ioctl.Tpo -c -o libstrace_a-ioctl.o `test -f 'ioctl.c' || echo '$(srcdir)/'`ioctl.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ioctl.Tpo $(DEPDIR)/libstrace_a-ioctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ioctl.c' object='libstrace_a-ioctl.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-get_personality.obj `if test -f 'get_personality.c'; then $(CYGPATH_W) 'get_personality.c'; else $(CYGPATH_W) '$(srcdir)/get_personality.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ioctl.o `test -f 'ioctl.c' || echo '$(srcdir)/'`ioctl.c
 
-strace-get_robust_list.o: get_robust_list.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-get_robust_list.o -MD -MP -MF $(DEPDIR)/strace-get_robust_list.Tpo -c -o strace-get_robust_list.o `test -f 'get_robust_list.c' || echo '$(srcdir)/'`get_robust_list.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-get_robust_list.Tpo $(DEPDIR)/strace-get_robust_list.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='get_robust_list.c' object='strace-get_robust_list.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ioctl.obj: ioctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ioctl.obj -MD -MP -MF $(DEPDIR)/libstrace_a-ioctl.Tpo -c -o libstrace_a-ioctl.obj `if test -f 'ioctl.c'; then $(CYGPATH_W) 'ioctl.c'; else $(CYGPATH_W) '$(srcdir)/ioctl.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ioctl.Tpo $(DEPDIR)/libstrace_a-ioctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ioctl.c' object='libstrace_a-ioctl.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-get_robust_list.o `test -f 'get_robust_list.c' || echo '$(srcdir)/'`get_robust_list.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ioctl.obj `if test -f 'ioctl.c'; then $(CYGPATH_W) 'ioctl.c'; else $(CYGPATH_W) '$(srcdir)/ioctl.c'; fi`
 
-strace-get_robust_list.obj: get_robust_list.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-get_robust_list.obj -MD -MP -MF $(DEPDIR)/strace-get_robust_list.Tpo -c -o strace-get_robust_list.obj `if test -f 'get_robust_list.c'; then $(CYGPATH_W) 'get_robust_list.c'; else $(CYGPATH_W) '$(srcdir)/get_robust_list.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-get_robust_list.Tpo $(DEPDIR)/strace-get_robust_list.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='get_robust_list.c' object='strace-get_robust_list.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ioperm.o: ioperm.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ioperm.o -MD -MP -MF $(DEPDIR)/libstrace_a-ioperm.Tpo -c -o libstrace_a-ioperm.o `test -f 'ioperm.c' || echo '$(srcdir)/'`ioperm.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ioperm.Tpo $(DEPDIR)/libstrace_a-ioperm.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ioperm.c' object='libstrace_a-ioperm.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-get_robust_list.obj `if test -f 'get_robust_list.c'; then $(CYGPATH_W) 'get_robust_list.c'; else $(CYGPATH_W) '$(srcdir)/get_robust_list.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ioperm.o `test -f 'ioperm.c' || echo '$(srcdir)/'`ioperm.c
 
-strace-getcpu.o: getcpu.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-getcpu.o -MD -MP -MF $(DEPDIR)/strace-getcpu.Tpo -c -o strace-getcpu.o `test -f 'getcpu.c' || echo '$(srcdir)/'`getcpu.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-getcpu.Tpo $(DEPDIR)/strace-getcpu.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='getcpu.c' object='strace-getcpu.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ioperm.obj: ioperm.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ioperm.obj -MD -MP -MF $(DEPDIR)/libstrace_a-ioperm.Tpo -c -o libstrace_a-ioperm.obj `if test -f 'ioperm.c'; then $(CYGPATH_W) 'ioperm.c'; else $(CYGPATH_W) '$(srcdir)/ioperm.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ioperm.Tpo $(DEPDIR)/libstrace_a-ioperm.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ioperm.c' object='libstrace_a-ioperm.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-getcpu.o `test -f 'getcpu.c' || echo '$(srcdir)/'`getcpu.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ioperm.obj `if test -f 'ioperm.c'; then $(CYGPATH_W) 'ioperm.c'; else $(CYGPATH_W) '$(srcdir)/ioperm.c'; fi`
 
-strace-getcpu.obj: getcpu.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-getcpu.obj -MD -MP -MF $(DEPDIR)/strace-getcpu.Tpo -c -o strace-getcpu.obj `if test -f 'getcpu.c'; then $(CYGPATH_W) 'getcpu.c'; else $(CYGPATH_W) '$(srcdir)/getcpu.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-getcpu.Tpo $(DEPDIR)/strace-getcpu.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='getcpu.c' object='strace-getcpu.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-iopl.o: iopl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-iopl.o -MD -MP -MF $(DEPDIR)/libstrace_a-iopl.Tpo -c -o libstrace_a-iopl.o `test -f 'iopl.c' || echo '$(srcdir)/'`iopl.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-iopl.Tpo $(DEPDIR)/libstrace_a-iopl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='iopl.c' object='libstrace_a-iopl.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-getcpu.obj `if test -f 'getcpu.c'; then $(CYGPATH_W) 'getcpu.c'; else $(CYGPATH_W) '$(srcdir)/getcpu.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-iopl.o `test -f 'iopl.c' || echo '$(srcdir)/'`iopl.c
 
-strace-getcwd.o: getcwd.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-getcwd.o -MD -MP -MF $(DEPDIR)/strace-getcwd.Tpo -c -o strace-getcwd.o `test -f 'getcwd.c' || echo '$(srcdir)/'`getcwd.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-getcwd.Tpo $(DEPDIR)/strace-getcwd.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='getcwd.c' object='strace-getcwd.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-iopl.obj: iopl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-iopl.obj -MD -MP -MF $(DEPDIR)/libstrace_a-iopl.Tpo -c -o libstrace_a-iopl.obj `if test -f 'iopl.c'; then $(CYGPATH_W) 'iopl.c'; else $(CYGPATH_W) '$(srcdir)/iopl.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-iopl.Tpo $(DEPDIR)/libstrace_a-iopl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='iopl.c' object='libstrace_a-iopl.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-getcwd.o `test -f 'getcwd.c' || echo '$(srcdir)/'`getcwd.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-iopl.obj `if test -f 'iopl.c'; then $(CYGPATH_W) 'iopl.c'; else $(CYGPATH_W) '$(srcdir)/iopl.c'; fi`
 
-strace-getcwd.obj: getcwd.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-getcwd.obj -MD -MP -MF $(DEPDIR)/strace-getcwd.Tpo -c -o strace-getcwd.obj `if test -f 'getcwd.c'; then $(CYGPATH_W) 'getcwd.c'; else $(CYGPATH_W) '$(srcdir)/getcwd.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-getcwd.Tpo $(DEPDIR)/strace-getcwd.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='getcwd.c' object='strace-getcwd.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ioprio.o: ioprio.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ioprio.o -MD -MP -MF $(DEPDIR)/libstrace_a-ioprio.Tpo -c -o libstrace_a-ioprio.o `test -f 'ioprio.c' || echo '$(srcdir)/'`ioprio.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ioprio.Tpo $(DEPDIR)/libstrace_a-ioprio.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ioprio.c' object='libstrace_a-ioprio.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-getcwd.obj `if test -f 'getcwd.c'; then $(CYGPATH_W) 'getcwd.c'; else $(CYGPATH_W) '$(srcdir)/getcwd.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ioprio.o `test -f 'ioprio.c' || echo '$(srcdir)/'`ioprio.c
 
-strace-getrandom.o: getrandom.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-getrandom.o -MD -MP -MF $(DEPDIR)/strace-getrandom.Tpo -c -o strace-getrandom.o `test -f 'getrandom.c' || echo '$(srcdir)/'`getrandom.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-getrandom.Tpo $(DEPDIR)/strace-getrandom.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='getrandom.c' object='strace-getrandom.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ioprio.obj: ioprio.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ioprio.obj -MD -MP -MF $(DEPDIR)/libstrace_a-ioprio.Tpo -c -o libstrace_a-ioprio.obj `if test -f 'ioprio.c'; then $(CYGPATH_W) 'ioprio.c'; else $(CYGPATH_W) '$(srcdir)/ioprio.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ioprio.Tpo $(DEPDIR)/libstrace_a-ioprio.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ioprio.c' object='libstrace_a-ioprio.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-getrandom.o `test -f 'getrandom.c' || echo '$(srcdir)/'`getrandom.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ioprio.obj `if test -f 'ioprio.c'; then $(CYGPATH_W) 'ioprio.c'; else $(CYGPATH_W) '$(srcdir)/ioprio.c'; fi`
 
-strace-getrandom.obj: getrandom.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-getrandom.obj -MD -MP -MF $(DEPDIR)/strace-getrandom.Tpo -c -o strace-getrandom.obj `if test -f 'getrandom.c'; then $(CYGPATH_W) 'getrandom.c'; else $(CYGPATH_W) '$(srcdir)/getrandom.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-getrandom.Tpo $(DEPDIR)/strace-getrandom.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='getrandom.c' object='strace-getrandom.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ipc.o: ipc.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ipc.o -MD -MP -MF $(DEPDIR)/libstrace_a-ipc.Tpo -c -o libstrace_a-ipc.o `test -f 'ipc.c' || echo '$(srcdir)/'`ipc.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ipc.Tpo $(DEPDIR)/libstrace_a-ipc.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc.c' object='libstrace_a-ipc.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-getrandom.obj `if test -f 'getrandom.c'; then $(CYGPATH_W) 'getrandom.c'; else $(CYGPATH_W) '$(srcdir)/getrandom.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ipc.o `test -f 'ipc.c' || echo '$(srcdir)/'`ipc.c
 
-strace-hdio.o: hdio.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-hdio.o -MD -MP -MF $(DEPDIR)/strace-hdio.Tpo -c -o strace-hdio.o `test -f 'hdio.c' || echo '$(srcdir)/'`hdio.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-hdio.Tpo $(DEPDIR)/strace-hdio.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='hdio.c' object='strace-hdio.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ipc.obj: ipc.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ipc.obj -MD -MP -MF $(DEPDIR)/libstrace_a-ipc.Tpo -c -o libstrace_a-ipc.obj `if test -f 'ipc.c'; then $(CYGPATH_W) 'ipc.c'; else $(CYGPATH_W) '$(srcdir)/ipc.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ipc.Tpo $(DEPDIR)/libstrace_a-ipc.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc.c' object='libstrace_a-ipc.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-hdio.o `test -f 'hdio.c' || echo '$(srcdir)/'`hdio.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ipc.obj `if test -f 'ipc.c'; then $(CYGPATH_W) 'ipc.c'; else $(CYGPATH_W) '$(srcdir)/ipc.c'; fi`
 
-strace-hdio.obj: hdio.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-hdio.obj -MD -MP -MF $(DEPDIR)/strace-hdio.Tpo -c -o strace-hdio.obj `if test -f 'hdio.c'; then $(CYGPATH_W) 'hdio.c'; else $(CYGPATH_W) '$(srcdir)/hdio.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-hdio.Tpo $(DEPDIR)/strace-hdio.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='hdio.c' object='strace-hdio.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ipc_msg.o: ipc_msg.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ipc_msg.o -MD -MP -MF $(DEPDIR)/libstrace_a-ipc_msg.Tpo -c -o libstrace_a-ipc_msg.o `test -f 'ipc_msg.c' || echo '$(srcdir)/'`ipc_msg.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ipc_msg.Tpo $(DEPDIR)/libstrace_a-ipc_msg.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc_msg.c' object='libstrace_a-ipc_msg.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-hdio.obj `if test -f 'hdio.c'; then $(CYGPATH_W) 'hdio.c'; else $(CYGPATH_W) '$(srcdir)/hdio.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ipc_msg.o `test -f 'ipc_msg.c' || echo '$(srcdir)/'`ipc_msg.c
 
-strace-hostname.o: hostname.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-hostname.o -MD -MP -MF $(DEPDIR)/strace-hostname.Tpo -c -o strace-hostname.o `test -f 'hostname.c' || echo '$(srcdir)/'`hostname.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-hostname.Tpo $(DEPDIR)/strace-hostname.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='hostname.c' object='strace-hostname.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ipc_msg.obj: ipc_msg.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ipc_msg.obj -MD -MP -MF $(DEPDIR)/libstrace_a-ipc_msg.Tpo -c -o libstrace_a-ipc_msg.obj `if test -f 'ipc_msg.c'; then $(CYGPATH_W) 'ipc_msg.c'; else $(CYGPATH_W) '$(srcdir)/ipc_msg.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ipc_msg.Tpo $(DEPDIR)/libstrace_a-ipc_msg.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc_msg.c' object='libstrace_a-ipc_msg.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-hostname.o `test -f 'hostname.c' || echo '$(srcdir)/'`hostname.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ipc_msg.obj `if test -f 'ipc_msg.c'; then $(CYGPATH_W) 'ipc_msg.c'; else $(CYGPATH_W) '$(srcdir)/ipc_msg.c'; fi`
 
-strace-hostname.obj: hostname.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-hostname.obj -MD -MP -MF $(DEPDIR)/strace-hostname.Tpo -c -o strace-hostname.obj `if test -f 'hostname.c'; then $(CYGPATH_W) 'hostname.c'; else $(CYGPATH_W) '$(srcdir)/hostname.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-hostname.Tpo $(DEPDIR)/strace-hostname.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='hostname.c' object='strace-hostname.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ipc_msgctl.o: ipc_msgctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ipc_msgctl.o -MD -MP -MF $(DEPDIR)/libstrace_a-ipc_msgctl.Tpo -c -o libstrace_a-ipc_msgctl.o `test -f 'ipc_msgctl.c' || echo '$(srcdir)/'`ipc_msgctl.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ipc_msgctl.Tpo $(DEPDIR)/libstrace_a-ipc_msgctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc_msgctl.c' object='libstrace_a-ipc_msgctl.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-hostname.obj `if test -f 'hostname.c'; then $(CYGPATH_W) 'hostname.c'; else $(CYGPATH_W) '$(srcdir)/hostname.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ipc_msgctl.o `test -f 'ipc_msgctl.c' || echo '$(srcdir)/'`ipc_msgctl.c
 
-strace-inotify.o: inotify.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-inotify.o -MD -MP -MF $(DEPDIR)/strace-inotify.Tpo -c -o strace-inotify.o `test -f 'inotify.c' || echo '$(srcdir)/'`inotify.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-inotify.Tpo $(DEPDIR)/strace-inotify.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='inotify.c' object='strace-inotify.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ipc_msgctl.obj: ipc_msgctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ipc_msgctl.obj -MD -MP -MF $(DEPDIR)/libstrace_a-ipc_msgctl.Tpo -c -o libstrace_a-ipc_msgctl.obj `if test -f 'ipc_msgctl.c'; then $(CYGPATH_W) 'ipc_msgctl.c'; else $(CYGPATH_W) '$(srcdir)/ipc_msgctl.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ipc_msgctl.Tpo $(DEPDIR)/libstrace_a-ipc_msgctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc_msgctl.c' object='libstrace_a-ipc_msgctl.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-inotify.o `test -f 'inotify.c' || echo '$(srcdir)/'`inotify.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ipc_msgctl.obj `if test -f 'ipc_msgctl.c'; then $(CYGPATH_W) 'ipc_msgctl.c'; else $(CYGPATH_W) '$(srcdir)/ipc_msgctl.c'; fi`
 
-strace-inotify.obj: inotify.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-inotify.obj -MD -MP -MF $(DEPDIR)/strace-inotify.Tpo -c -o strace-inotify.obj `if test -f 'inotify.c'; then $(CYGPATH_W) 'inotify.c'; else $(CYGPATH_W) '$(srcdir)/inotify.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-inotify.Tpo $(DEPDIR)/strace-inotify.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='inotify.c' object='strace-inotify.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ipc_sem.o: ipc_sem.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ipc_sem.o -MD -MP -MF $(DEPDIR)/libstrace_a-ipc_sem.Tpo -c -o libstrace_a-ipc_sem.o `test -f 'ipc_sem.c' || echo '$(srcdir)/'`ipc_sem.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ipc_sem.Tpo $(DEPDIR)/libstrace_a-ipc_sem.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc_sem.c' object='libstrace_a-ipc_sem.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-inotify.obj `if test -f 'inotify.c'; then $(CYGPATH_W) 'inotify.c'; else $(CYGPATH_W) '$(srcdir)/inotify.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ipc_sem.o `test -f 'ipc_sem.c' || echo '$(srcdir)/'`ipc_sem.c
 
-strace-inotify_ioctl.o: inotify_ioctl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-inotify_ioctl.o -MD -MP -MF $(DEPDIR)/strace-inotify_ioctl.Tpo -c -o strace-inotify_ioctl.o `test -f 'inotify_ioctl.c' || echo '$(srcdir)/'`inotify_ioctl.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-inotify_ioctl.Tpo $(DEPDIR)/strace-inotify_ioctl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='inotify_ioctl.c' object='strace-inotify_ioctl.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ipc_sem.obj: ipc_sem.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ipc_sem.obj -MD -MP -MF $(DEPDIR)/libstrace_a-ipc_sem.Tpo -c -o libstrace_a-ipc_sem.obj `if test -f 'ipc_sem.c'; then $(CYGPATH_W) 'ipc_sem.c'; else $(CYGPATH_W) '$(srcdir)/ipc_sem.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ipc_sem.Tpo $(DEPDIR)/libstrace_a-ipc_sem.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc_sem.c' object='libstrace_a-ipc_sem.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-inotify_ioctl.o `test -f 'inotify_ioctl.c' || echo '$(srcdir)/'`inotify_ioctl.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ipc_sem.obj `if test -f 'ipc_sem.c'; then $(CYGPATH_W) 'ipc_sem.c'; else $(CYGPATH_W) '$(srcdir)/ipc_sem.c'; fi`
 
-strace-inotify_ioctl.obj: inotify_ioctl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-inotify_ioctl.obj -MD -MP -MF $(DEPDIR)/strace-inotify_ioctl.Tpo -c -o strace-inotify_ioctl.obj `if test -f 'inotify_ioctl.c'; then $(CYGPATH_W) 'inotify_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/inotify_ioctl.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-inotify_ioctl.Tpo $(DEPDIR)/strace-inotify_ioctl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='inotify_ioctl.c' object='strace-inotify_ioctl.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ipc_semctl.o: ipc_semctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ipc_semctl.o -MD -MP -MF $(DEPDIR)/libstrace_a-ipc_semctl.Tpo -c -o libstrace_a-ipc_semctl.o `test -f 'ipc_semctl.c' || echo '$(srcdir)/'`ipc_semctl.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ipc_semctl.Tpo $(DEPDIR)/libstrace_a-ipc_semctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc_semctl.c' object='libstrace_a-ipc_semctl.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-inotify_ioctl.obj `if test -f 'inotify_ioctl.c'; then $(CYGPATH_W) 'inotify_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/inotify_ioctl.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ipc_semctl.o `test -f 'ipc_semctl.c' || echo '$(srcdir)/'`ipc_semctl.c
 
-strace-io.o: io.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-io.o -MD -MP -MF $(DEPDIR)/strace-io.Tpo -c -o strace-io.o `test -f 'io.c' || echo '$(srcdir)/'`io.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-io.Tpo $(DEPDIR)/strace-io.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='io.c' object='strace-io.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ipc_semctl.obj: ipc_semctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ipc_semctl.obj -MD -MP -MF $(DEPDIR)/libstrace_a-ipc_semctl.Tpo -c -o libstrace_a-ipc_semctl.obj `if test -f 'ipc_semctl.c'; then $(CYGPATH_W) 'ipc_semctl.c'; else $(CYGPATH_W) '$(srcdir)/ipc_semctl.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ipc_semctl.Tpo $(DEPDIR)/libstrace_a-ipc_semctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc_semctl.c' object='libstrace_a-ipc_semctl.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-io.o `test -f 'io.c' || echo '$(srcdir)/'`io.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ipc_semctl.obj `if test -f 'ipc_semctl.c'; then $(CYGPATH_W) 'ipc_semctl.c'; else $(CYGPATH_W) '$(srcdir)/ipc_semctl.c'; fi`
 
-strace-io.obj: io.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-io.obj -MD -MP -MF $(DEPDIR)/strace-io.Tpo -c -o strace-io.obj `if test -f 'io.c'; then $(CYGPATH_W) 'io.c'; else $(CYGPATH_W) '$(srcdir)/io.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-io.Tpo $(DEPDIR)/strace-io.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='io.c' object='strace-io.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ipc_shm.o: ipc_shm.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ipc_shm.o -MD -MP -MF $(DEPDIR)/libstrace_a-ipc_shm.Tpo -c -o libstrace_a-ipc_shm.o `test -f 'ipc_shm.c' || echo '$(srcdir)/'`ipc_shm.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ipc_shm.Tpo $(DEPDIR)/libstrace_a-ipc_shm.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc_shm.c' object='libstrace_a-ipc_shm.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-io.obj `if test -f 'io.c'; then $(CYGPATH_W) 'io.c'; else $(CYGPATH_W) '$(srcdir)/io.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ipc_shm.o `test -f 'ipc_shm.c' || echo '$(srcdir)/'`ipc_shm.c
 
-strace-io_uring.o: io_uring.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-io_uring.o -MD -MP -MF $(DEPDIR)/strace-io_uring.Tpo -c -o strace-io_uring.o `test -f 'io_uring.c' || echo '$(srcdir)/'`io_uring.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-io_uring.Tpo $(DEPDIR)/strace-io_uring.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='io_uring.c' object='strace-io_uring.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ipc_shm.obj: ipc_shm.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ipc_shm.obj -MD -MP -MF $(DEPDIR)/libstrace_a-ipc_shm.Tpo -c -o libstrace_a-ipc_shm.obj `if test -f 'ipc_shm.c'; then $(CYGPATH_W) 'ipc_shm.c'; else $(CYGPATH_W) '$(srcdir)/ipc_shm.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ipc_shm.Tpo $(DEPDIR)/libstrace_a-ipc_shm.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc_shm.c' object='libstrace_a-ipc_shm.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-io_uring.o `test -f 'io_uring.c' || echo '$(srcdir)/'`io_uring.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ipc_shm.obj `if test -f 'ipc_shm.c'; then $(CYGPATH_W) 'ipc_shm.c'; else $(CYGPATH_W) '$(srcdir)/ipc_shm.c'; fi`
 
-strace-io_uring.obj: io_uring.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-io_uring.obj -MD -MP -MF $(DEPDIR)/strace-io_uring.Tpo -c -o strace-io_uring.obj `if test -f 'io_uring.c'; then $(CYGPATH_W) 'io_uring.c'; else $(CYGPATH_W) '$(srcdir)/io_uring.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-io_uring.Tpo $(DEPDIR)/strace-io_uring.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='io_uring.c' object='strace-io_uring.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ipc_shmctl.o: ipc_shmctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ipc_shmctl.o -MD -MP -MF $(DEPDIR)/libstrace_a-ipc_shmctl.Tpo -c -o libstrace_a-ipc_shmctl.o `test -f 'ipc_shmctl.c' || echo '$(srcdir)/'`ipc_shmctl.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ipc_shmctl.Tpo $(DEPDIR)/libstrace_a-ipc_shmctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc_shmctl.c' object='libstrace_a-ipc_shmctl.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-io_uring.obj `if test -f 'io_uring.c'; then $(CYGPATH_W) 'io_uring.c'; else $(CYGPATH_W) '$(srcdir)/io_uring.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ipc_shmctl.o `test -f 'ipc_shmctl.c' || echo '$(srcdir)/'`ipc_shmctl.c
 
-strace-ioctl.o: ioctl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ioctl.o -MD -MP -MF $(DEPDIR)/strace-ioctl.Tpo -c -o strace-ioctl.o `test -f 'ioctl.c' || echo '$(srcdir)/'`ioctl.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ioctl.Tpo $(DEPDIR)/strace-ioctl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ioctl.c' object='strace-ioctl.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ipc_shmctl.obj: ipc_shmctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ipc_shmctl.obj -MD -MP -MF $(DEPDIR)/libstrace_a-ipc_shmctl.Tpo -c -o libstrace_a-ipc_shmctl.obj `if test -f 'ipc_shmctl.c'; then $(CYGPATH_W) 'ipc_shmctl.c'; else $(CYGPATH_W) '$(srcdir)/ipc_shmctl.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ipc_shmctl.Tpo $(DEPDIR)/libstrace_a-ipc_shmctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc_shmctl.c' object='libstrace_a-ipc_shmctl.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ioctl.o `test -f 'ioctl.c' || echo '$(srcdir)/'`ioctl.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ipc_shmctl.obj `if test -f 'ipc_shmctl.c'; then $(CYGPATH_W) 'ipc_shmctl.c'; else $(CYGPATH_W) '$(srcdir)/ipc_shmctl.c'; fi`
 
-strace-ioctl.obj: ioctl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ioctl.obj -MD -MP -MF $(DEPDIR)/strace-ioctl.Tpo -c -o strace-ioctl.obj `if test -f 'ioctl.c'; then $(CYGPATH_W) 'ioctl.c'; else $(CYGPATH_W) '$(srcdir)/ioctl.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ioctl.Tpo $(DEPDIR)/strace-ioctl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ioctl.c' object='strace-ioctl.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-kcmp.o: kcmp.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-kcmp.o -MD -MP -MF $(DEPDIR)/libstrace_a-kcmp.Tpo -c -o libstrace_a-kcmp.o `test -f 'kcmp.c' || echo '$(srcdir)/'`kcmp.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-kcmp.Tpo $(DEPDIR)/libstrace_a-kcmp.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='kcmp.c' object='libstrace_a-kcmp.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ioctl.obj `if test -f 'ioctl.c'; then $(CYGPATH_W) 'ioctl.c'; else $(CYGPATH_W) '$(srcdir)/ioctl.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-kcmp.o `test -f 'kcmp.c' || echo '$(srcdir)/'`kcmp.c
 
-strace-ioperm.o: ioperm.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ioperm.o -MD -MP -MF $(DEPDIR)/strace-ioperm.Tpo -c -o strace-ioperm.o `test -f 'ioperm.c' || echo '$(srcdir)/'`ioperm.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ioperm.Tpo $(DEPDIR)/strace-ioperm.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ioperm.c' object='strace-ioperm.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-kcmp.obj: kcmp.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-kcmp.obj -MD -MP -MF $(DEPDIR)/libstrace_a-kcmp.Tpo -c -o libstrace_a-kcmp.obj `if test -f 'kcmp.c'; then $(CYGPATH_W) 'kcmp.c'; else $(CYGPATH_W) '$(srcdir)/kcmp.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-kcmp.Tpo $(DEPDIR)/libstrace_a-kcmp.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='kcmp.c' object='libstrace_a-kcmp.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ioperm.o `test -f 'ioperm.c' || echo '$(srcdir)/'`ioperm.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-kcmp.obj `if test -f 'kcmp.c'; then $(CYGPATH_W) 'kcmp.c'; else $(CYGPATH_W) '$(srcdir)/kcmp.c'; fi`
 
-strace-ioperm.obj: ioperm.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ioperm.obj -MD -MP -MF $(DEPDIR)/strace-ioperm.Tpo -c -o strace-ioperm.obj `if test -f 'ioperm.c'; then $(CYGPATH_W) 'ioperm.c'; else $(CYGPATH_W) '$(srcdir)/ioperm.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ioperm.Tpo $(DEPDIR)/strace-ioperm.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ioperm.c' object='strace-ioperm.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-kexec.o: kexec.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-kexec.o -MD -MP -MF $(DEPDIR)/libstrace_a-kexec.Tpo -c -o libstrace_a-kexec.o `test -f 'kexec.c' || echo '$(srcdir)/'`kexec.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-kexec.Tpo $(DEPDIR)/libstrace_a-kexec.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='kexec.c' object='libstrace_a-kexec.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ioperm.obj `if test -f 'ioperm.c'; then $(CYGPATH_W) 'ioperm.c'; else $(CYGPATH_W) '$(srcdir)/ioperm.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-kexec.o `test -f 'kexec.c' || echo '$(srcdir)/'`kexec.c
 
-strace-iopl.o: iopl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-iopl.o -MD -MP -MF $(DEPDIR)/strace-iopl.Tpo -c -o strace-iopl.o `test -f 'iopl.c' || echo '$(srcdir)/'`iopl.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-iopl.Tpo $(DEPDIR)/strace-iopl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='iopl.c' object='strace-iopl.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-kexec.obj: kexec.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-kexec.obj -MD -MP -MF $(DEPDIR)/libstrace_a-kexec.Tpo -c -o libstrace_a-kexec.obj `if test -f 'kexec.c'; then $(CYGPATH_W) 'kexec.c'; else $(CYGPATH_W) '$(srcdir)/kexec.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-kexec.Tpo $(DEPDIR)/libstrace_a-kexec.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='kexec.c' object='libstrace_a-kexec.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-iopl.o `test -f 'iopl.c' || echo '$(srcdir)/'`iopl.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-kexec.obj `if test -f 'kexec.c'; then $(CYGPATH_W) 'kexec.c'; else $(CYGPATH_W) '$(srcdir)/kexec.c'; fi`
 
-strace-iopl.obj: iopl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-iopl.obj -MD -MP -MF $(DEPDIR)/strace-iopl.Tpo -c -o strace-iopl.obj `if test -f 'iopl.c'; then $(CYGPATH_W) 'iopl.c'; else $(CYGPATH_W) '$(srcdir)/iopl.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-iopl.Tpo $(DEPDIR)/strace-iopl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='iopl.c' object='strace-iopl.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-keyctl.o: keyctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-keyctl.o -MD -MP -MF $(DEPDIR)/libstrace_a-keyctl.Tpo -c -o libstrace_a-keyctl.o `test -f 'keyctl.c' || echo '$(srcdir)/'`keyctl.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-keyctl.Tpo $(DEPDIR)/libstrace_a-keyctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='keyctl.c' object='libstrace_a-keyctl.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-iopl.obj `if test -f 'iopl.c'; then $(CYGPATH_W) 'iopl.c'; else $(CYGPATH_W) '$(srcdir)/iopl.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-keyctl.o `test -f 'keyctl.c' || echo '$(srcdir)/'`keyctl.c
 
-strace-ioprio.o: ioprio.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ioprio.o -MD -MP -MF $(DEPDIR)/strace-ioprio.Tpo -c -o strace-ioprio.o `test -f 'ioprio.c' || echo '$(srcdir)/'`ioprio.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ioprio.Tpo $(DEPDIR)/strace-ioprio.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ioprio.c' object='strace-ioprio.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-keyctl.obj: keyctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-keyctl.obj -MD -MP -MF $(DEPDIR)/libstrace_a-keyctl.Tpo -c -o libstrace_a-keyctl.obj `if test -f 'keyctl.c'; then $(CYGPATH_W) 'keyctl.c'; else $(CYGPATH_W) '$(srcdir)/keyctl.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-keyctl.Tpo $(DEPDIR)/libstrace_a-keyctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='keyctl.c' object='libstrace_a-keyctl.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ioprio.o `test -f 'ioprio.c' || echo '$(srcdir)/'`ioprio.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-keyctl.obj `if test -f 'keyctl.c'; then $(CYGPATH_W) 'keyctl.c'; else $(CYGPATH_W) '$(srcdir)/keyctl.c'; fi`
 
-strace-ioprio.obj: ioprio.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ioprio.obj -MD -MP -MF $(DEPDIR)/strace-ioprio.Tpo -c -o strace-ioprio.obj `if test -f 'ioprio.c'; then $(CYGPATH_W) 'ioprio.c'; else $(CYGPATH_W) '$(srcdir)/ioprio.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ioprio.Tpo $(DEPDIR)/strace-ioprio.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ioprio.c' object='strace-ioprio.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-kvm.o: kvm.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-kvm.o -MD -MP -MF $(DEPDIR)/libstrace_a-kvm.Tpo -c -o libstrace_a-kvm.o `test -f 'kvm.c' || echo '$(srcdir)/'`kvm.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-kvm.Tpo $(DEPDIR)/libstrace_a-kvm.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='kvm.c' object='libstrace_a-kvm.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ioprio.obj `if test -f 'ioprio.c'; then $(CYGPATH_W) 'ioprio.c'; else $(CYGPATH_W) '$(srcdir)/ioprio.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-kvm.o `test -f 'kvm.c' || echo '$(srcdir)/'`kvm.c
 
-strace-ipc_msg.o: ipc_msg.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ipc_msg.o -MD -MP -MF $(DEPDIR)/strace-ipc_msg.Tpo -c -o strace-ipc_msg.o `test -f 'ipc_msg.c' || echo '$(srcdir)/'`ipc_msg.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ipc_msg.Tpo $(DEPDIR)/strace-ipc_msg.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc_msg.c' object='strace-ipc_msg.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-kvm.obj: kvm.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-kvm.obj -MD -MP -MF $(DEPDIR)/libstrace_a-kvm.Tpo -c -o libstrace_a-kvm.obj `if test -f 'kvm.c'; then $(CYGPATH_W) 'kvm.c'; else $(CYGPATH_W) '$(srcdir)/kvm.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-kvm.Tpo $(DEPDIR)/libstrace_a-kvm.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='kvm.c' object='libstrace_a-kvm.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ipc_msg.o `test -f 'ipc_msg.c' || echo '$(srcdir)/'`ipc_msg.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-kvm.obj `if test -f 'kvm.c'; then $(CYGPATH_W) 'kvm.c'; else $(CYGPATH_W) '$(srcdir)/kvm.c'; fi`
 
-strace-ipc_msg.obj: ipc_msg.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ipc_msg.obj -MD -MP -MF $(DEPDIR)/strace-ipc_msg.Tpo -c -o strace-ipc_msg.obj `if test -f 'ipc_msg.c'; then $(CYGPATH_W) 'ipc_msg.c'; else $(CYGPATH_W) '$(srcdir)/ipc_msg.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ipc_msg.Tpo $(DEPDIR)/strace-ipc_msg.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc_msg.c' object='strace-ipc_msg.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ldt.o: ldt.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ldt.o -MD -MP -MF $(DEPDIR)/libstrace_a-ldt.Tpo -c -o libstrace_a-ldt.o `test -f 'ldt.c' || echo '$(srcdir)/'`ldt.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ldt.Tpo $(DEPDIR)/libstrace_a-ldt.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ldt.c' object='libstrace_a-ldt.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ipc_msg.obj `if test -f 'ipc_msg.c'; then $(CYGPATH_W) 'ipc_msg.c'; else $(CYGPATH_W) '$(srcdir)/ipc_msg.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ldt.o `test -f 'ldt.c' || echo '$(srcdir)/'`ldt.c
 
-strace-ipc_msgctl.o: ipc_msgctl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ipc_msgctl.o -MD -MP -MF $(DEPDIR)/strace-ipc_msgctl.Tpo -c -o strace-ipc_msgctl.o `test -f 'ipc_msgctl.c' || echo '$(srcdir)/'`ipc_msgctl.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ipc_msgctl.Tpo $(DEPDIR)/strace-ipc_msgctl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc_msgctl.c' object='strace-ipc_msgctl.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ldt.obj: ldt.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ldt.obj -MD -MP -MF $(DEPDIR)/libstrace_a-ldt.Tpo -c -o libstrace_a-ldt.obj `if test -f 'ldt.c'; then $(CYGPATH_W) 'ldt.c'; else $(CYGPATH_W) '$(srcdir)/ldt.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ldt.Tpo $(DEPDIR)/libstrace_a-ldt.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ldt.c' object='libstrace_a-ldt.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ipc_msgctl.o `test -f 'ipc_msgctl.c' || echo '$(srcdir)/'`ipc_msgctl.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ldt.obj `if test -f 'ldt.c'; then $(CYGPATH_W) 'ldt.c'; else $(CYGPATH_W) '$(srcdir)/ldt.c'; fi`
 
-strace-ipc_msgctl.obj: ipc_msgctl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ipc_msgctl.obj -MD -MP -MF $(DEPDIR)/strace-ipc_msgctl.Tpo -c -o strace-ipc_msgctl.obj `if test -f 'ipc_msgctl.c'; then $(CYGPATH_W) 'ipc_msgctl.c'; else $(CYGPATH_W) '$(srcdir)/ipc_msgctl.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ipc_msgctl.Tpo $(DEPDIR)/strace-ipc_msgctl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc_msgctl.c' object='strace-ipc_msgctl.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-link.o: link.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-link.o -MD -MP -MF $(DEPDIR)/libstrace_a-link.Tpo -c -o libstrace_a-link.o `test -f 'link.c' || echo '$(srcdir)/'`link.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-link.Tpo $(DEPDIR)/libstrace_a-link.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='link.c' object='libstrace_a-link.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ipc_msgctl.obj `if test -f 'ipc_msgctl.c'; then $(CYGPATH_W) 'ipc_msgctl.c'; else $(CYGPATH_W) '$(srcdir)/ipc_msgctl.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-link.o `test -f 'link.c' || echo '$(srcdir)/'`link.c
 
-strace-ipc_sem.o: ipc_sem.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ipc_sem.o -MD -MP -MF $(DEPDIR)/strace-ipc_sem.Tpo -c -o strace-ipc_sem.o `test -f 'ipc_sem.c' || echo '$(srcdir)/'`ipc_sem.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ipc_sem.Tpo $(DEPDIR)/strace-ipc_sem.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc_sem.c' object='strace-ipc_sem.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-link.obj: link.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-link.obj -MD -MP -MF $(DEPDIR)/libstrace_a-link.Tpo -c -o libstrace_a-link.obj `if test -f 'link.c'; then $(CYGPATH_W) 'link.c'; else $(CYGPATH_W) '$(srcdir)/link.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-link.Tpo $(DEPDIR)/libstrace_a-link.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='link.c' object='libstrace_a-link.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ipc_sem.o `test -f 'ipc_sem.c' || echo '$(srcdir)/'`ipc_sem.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-link.obj `if test -f 'link.c'; then $(CYGPATH_W) 'link.c'; else $(CYGPATH_W) '$(srcdir)/link.c'; fi`
 
-strace-ipc_sem.obj: ipc_sem.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ipc_sem.obj -MD -MP -MF $(DEPDIR)/strace-ipc_sem.Tpo -c -o strace-ipc_sem.obj `if test -f 'ipc_sem.c'; then $(CYGPATH_W) 'ipc_sem.c'; else $(CYGPATH_W) '$(srcdir)/ipc_sem.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ipc_sem.Tpo $(DEPDIR)/strace-ipc_sem.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc_sem.c' object='strace-ipc_sem.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-listen.o: listen.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-listen.o -MD -MP -MF $(DEPDIR)/libstrace_a-listen.Tpo -c -o libstrace_a-listen.o `test -f 'listen.c' || echo '$(srcdir)/'`listen.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-listen.Tpo $(DEPDIR)/libstrace_a-listen.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='listen.c' object='libstrace_a-listen.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ipc_sem.obj `if test -f 'ipc_sem.c'; then $(CYGPATH_W) 'ipc_sem.c'; else $(CYGPATH_W) '$(srcdir)/ipc_sem.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-listen.o `test -f 'listen.c' || echo '$(srcdir)/'`listen.c
 
-strace-ipc_shm.o: ipc_shm.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ipc_shm.o -MD -MP -MF $(DEPDIR)/strace-ipc_shm.Tpo -c -o strace-ipc_shm.o `test -f 'ipc_shm.c' || echo '$(srcdir)/'`ipc_shm.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ipc_shm.Tpo $(DEPDIR)/strace-ipc_shm.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc_shm.c' object='strace-ipc_shm.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-listen.obj: listen.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-listen.obj -MD -MP -MF $(DEPDIR)/libstrace_a-listen.Tpo -c -o libstrace_a-listen.obj `if test -f 'listen.c'; then $(CYGPATH_W) 'listen.c'; else $(CYGPATH_W) '$(srcdir)/listen.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-listen.Tpo $(DEPDIR)/libstrace_a-listen.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='listen.c' object='libstrace_a-listen.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ipc_shm.o `test -f 'ipc_shm.c' || echo '$(srcdir)/'`ipc_shm.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-listen.obj `if test -f 'listen.c'; then $(CYGPATH_W) 'listen.c'; else $(CYGPATH_W) '$(srcdir)/listen.c'; fi`
 
-strace-ipc_shm.obj: ipc_shm.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ipc_shm.obj -MD -MP -MF $(DEPDIR)/strace-ipc_shm.Tpo -c -o strace-ipc_shm.obj `if test -f 'ipc_shm.c'; then $(CYGPATH_W) 'ipc_shm.c'; else $(CYGPATH_W) '$(srcdir)/ipc_shm.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ipc_shm.Tpo $(DEPDIR)/strace-ipc_shm.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc_shm.c' object='strace-ipc_shm.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-lookup_dcookie.o: lookup_dcookie.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-lookup_dcookie.o -MD -MP -MF $(DEPDIR)/libstrace_a-lookup_dcookie.Tpo -c -o libstrace_a-lookup_dcookie.o `test -f 'lookup_dcookie.c' || echo '$(srcdir)/'`lookup_dcookie.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-lookup_dcookie.Tpo $(DEPDIR)/libstrace_a-lookup_dcookie.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='lookup_dcookie.c' object='libstrace_a-lookup_dcookie.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ipc_shm.obj `if test -f 'ipc_shm.c'; then $(CYGPATH_W) 'ipc_shm.c'; else $(CYGPATH_W) '$(srcdir)/ipc_shm.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-lookup_dcookie.o `test -f 'lookup_dcookie.c' || echo '$(srcdir)/'`lookup_dcookie.c
 
-strace-ipc_shmctl.o: ipc_shmctl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ipc_shmctl.o -MD -MP -MF $(DEPDIR)/strace-ipc_shmctl.Tpo -c -o strace-ipc_shmctl.o `test -f 'ipc_shmctl.c' || echo '$(srcdir)/'`ipc_shmctl.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ipc_shmctl.Tpo $(DEPDIR)/strace-ipc_shmctl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc_shmctl.c' object='strace-ipc_shmctl.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-lookup_dcookie.obj: lookup_dcookie.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-lookup_dcookie.obj -MD -MP -MF $(DEPDIR)/libstrace_a-lookup_dcookie.Tpo -c -o libstrace_a-lookup_dcookie.obj `if test -f 'lookup_dcookie.c'; then $(CYGPATH_W) 'lookup_dcookie.c'; else $(CYGPATH_W) '$(srcdir)/lookup_dcookie.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-lookup_dcookie.Tpo $(DEPDIR)/libstrace_a-lookup_dcookie.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='lookup_dcookie.c' object='libstrace_a-lookup_dcookie.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ipc_shmctl.o `test -f 'ipc_shmctl.c' || echo '$(srcdir)/'`ipc_shmctl.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-lookup_dcookie.obj `if test -f 'lookup_dcookie.c'; then $(CYGPATH_W) 'lookup_dcookie.c'; else $(CYGPATH_W) '$(srcdir)/lookup_dcookie.c'; fi`
 
-strace-ipc_shmctl.obj: ipc_shmctl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ipc_shmctl.obj -MD -MP -MF $(DEPDIR)/strace-ipc_shmctl.Tpo -c -o strace-ipc_shmctl.obj `if test -f 'ipc_shmctl.c'; then $(CYGPATH_W) 'ipc_shmctl.c'; else $(CYGPATH_W) '$(srcdir)/ipc_shmctl.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ipc_shmctl.Tpo $(DEPDIR)/strace-ipc_shmctl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ipc_shmctl.c' object='strace-ipc_shmctl.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-loop.o: loop.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-loop.o -MD -MP -MF $(DEPDIR)/libstrace_a-loop.Tpo -c -o libstrace_a-loop.o `test -f 'loop.c' || echo '$(srcdir)/'`loop.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-loop.Tpo $(DEPDIR)/libstrace_a-loop.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='loop.c' object='libstrace_a-loop.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ipc_shmctl.obj `if test -f 'ipc_shmctl.c'; then $(CYGPATH_W) 'ipc_shmctl.c'; else $(CYGPATH_W) '$(srcdir)/ipc_shmctl.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-loop.o `test -f 'loop.c' || echo '$(srcdir)/'`loop.c
 
-strace-kcmp.o: kcmp.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-kcmp.o -MD -MP -MF $(DEPDIR)/strace-kcmp.Tpo -c -o strace-kcmp.o `test -f 'kcmp.c' || echo '$(srcdir)/'`kcmp.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-kcmp.Tpo $(DEPDIR)/strace-kcmp.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='kcmp.c' object='strace-kcmp.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-loop.obj: loop.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-loop.obj -MD -MP -MF $(DEPDIR)/libstrace_a-loop.Tpo -c -o libstrace_a-loop.obj `if test -f 'loop.c'; then $(CYGPATH_W) 'loop.c'; else $(CYGPATH_W) '$(srcdir)/loop.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-loop.Tpo $(DEPDIR)/libstrace_a-loop.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='loop.c' object='libstrace_a-loop.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-kcmp.o `test -f 'kcmp.c' || echo '$(srcdir)/'`kcmp.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-loop.obj `if test -f 'loop.c'; then $(CYGPATH_W) 'loop.c'; else $(CYGPATH_W) '$(srcdir)/loop.c'; fi`
 
-strace-kcmp.obj: kcmp.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-kcmp.obj -MD -MP -MF $(DEPDIR)/strace-kcmp.Tpo -c -o strace-kcmp.obj `if test -f 'kcmp.c'; then $(CYGPATH_W) 'kcmp.c'; else $(CYGPATH_W) '$(srcdir)/kcmp.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-kcmp.Tpo $(DEPDIR)/strace-kcmp.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='kcmp.c' object='strace-kcmp.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-lseek.o: lseek.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-lseek.o -MD -MP -MF $(DEPDIR)/libstrace_a-lseek.Tpo -c -o libstrace_a-lseek.o `test -f 'lseek.c' || echo '$(srcdir)/'`lseek.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-lseek.Tpo $(DEPDIR)/libstrace_a-lseek.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='lseek.c' object='libstrace_a-lseek.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-kcmp.obj `if test -f 'kcmp.c'; then $(CYGPATH_W) 'kcmp.c'; else $(CYGPATH_W) '$(srcdir)/kcmp.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-lseek.o `test -f 'lseek.c' || echo '$(srcdir)/'`lseek.c
 
-strace-kexec.o: kexec.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-kexec.o -MD -MP -MF $(DEPDIR)/strace-kexec.Tpo -c -o strace-kexec.o `test -f 'kexec.c' || echo '$(srcdir)/'`kexec.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-kexec.Tpo $(DEPDIR)/strace-kexec.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='kexec.c' object='strace-kexec.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-lseek.obj: lseek.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-lseek.obj -MD -MP -MF $(DEPDIR)/libstrace_a-lseek.Tpo -c -o libstrace_a-lseek.obj `if test -f 'lseek.c'; then $(CYGPATH_W) 'lseek.c'; else $(CYGPATH_W) '$(srcdir)/lseek.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-lseek.Tpo $(DEPDIR)/libstrace_a-lseek.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='lseek.c' object='libstrace_a-lseek.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-kexec.o `test -f 'kexec.c' || echo '$(srcdir)/'`kexec.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-lseek.obj `if test -f 'lseek.c'; then $(CYGPATH_W) 'lseek.c'; else $(CYGPATH_W) '$(srcdir)/lseek.c'; fi`
 
-strace-kexec.obj: kexec.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-kexec.obj -MD -MP -MF $(DEPDIR)/strace-kexec.Tpo -c -o strace-kexec.obj `if test -f 'kexec.c'; then $(CYGPATH_W) 'kexec.c'; else $(CYGPATH_W) '$(srcdir)/kexec.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-kexec.Tpo $(DEPDIR)/strace-kexec.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='kexec.c' object='strace-kexec.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-mem.o: mem.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-mem.o -MD -MP -MF $(DEPDIR)/libstrace_a-mem.Tpo -c -o libstrace_a-mem.o `test -f 'mem.c' || echo '$(srcdir)/'`mem.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-mem.Tpo $(DEPDIR)/libstrace_a-mem.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mem.c' object='libstrace_a-mem.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-kexec.obj `if test -f 'kexec.c'; then $(CYGPATH_W) 'kexec.c'; else $(CYGPATH_W) '$(srcdir)/kexec.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-mem.o `test -f 'mem.c' || echo '$(srcdir)/'`mem.c
 
-strace-keyctl.o: keyctl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-keyctl.o -MD -MP -MF $(DEPDIR)/strace-keyctl.Tpo -c -o strace-keyctl.o `test -f 'keyctl.c' || echo '$(srcdir)/'`keyctl.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-keyctl.Tpo $(DEPDIR)/strace-keyctl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='keyctl.c' object='strace-keyctl.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-mem.obj: mem.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-mem.obj -MD -MP -MF $(DEPDIR)/libstrace_a-mem.Tpo -c -o libstrace_a-mem.obj `if test -f 'mem.c'; then $(CYGPATH_W) 'mem.c'; else $(CYGPATH_W) '$(srcdir)/mem.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-mem.Tpo $(DEPDIR)/libstrace_a-mem.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mem.c' object='libstrace_a-mem.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-keyctl.o `test -f 'keyctl.c' || echo '$(srcdir)/'`keyctl.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-mem.obj `if test -f 'mem.c'; then $(CYGPATH_W) 'mem.c'; else $(CYGPATH_W) '$(srcdir)/mem.c'; fi`
 
-strace-keyctl.obj: keyctl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-keyctl.obj -MD -MP -MF $(DEPDIR)/strace-keyctl.Tpo -c -o strace-keyctl.obj `if test -f 'keyctl.c'; then $(CYGPATH_W) 'keyctl.c'; else $(CYGPATH_W) '$(srcdir)/keyctl.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-keyctl.Tpo $(DEPDIR)/strace-keyctl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='keyctl.c' object='strace-keyctl.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-membarrier.o: membarrier.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-membarrier.o -MD -MP -MF $(DEPDIR)/libstrace_a-membarrier.Tpo -c -o libstrace_a-membarrier.o `test -f 'membarrier.c' || echo '$(srcdir)/'`membarrier.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-membarrier.Tpo $(DEPDIR)/libstrace_a-membarrier.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='membarrier.c' object='libstrace_a-membarrier.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-keyctl.obj `if test -f 'keyctl.c'; then $(CYGPATH_W) 'keyctl.c'; else $(CYGPATH_W) '$(srcdir)/keyctl.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-membarrier.o `test -f 'membarrier.c' || echo '$(srcdir)/'`membarrier.c
 
-strace-kvm.o: kvm.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-kvm.o -MD -MP -MF $(DEPDIR)/strace-kvm.Tpo -c -o strace-kvm.o `test -f 'kvm.c' || echo '$(srcdir)/'`kvm.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-kvm.Tpo $(DEPDIR)/strace-kvm.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='kvm.c' object='strace-kvm.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-membarrier.obj: membarrier.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-membarrier.obj -MD -MP -MF $(DEPDIR)/libstrace_a-membarrier.Tpo -c -o libstrace_a-membarrier.obj `if test -f 'membarrier.c'; then $(CYGPATH_W) 'membarrier.c'; else $(CYGPATH_W) '$(srcdir)/membarrier.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-membarrier.Tpo $(DEPDIR)/libstrace_a-membarrier.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='membarrier.c' object='libstrace_a-membarrier.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-kvm.o `test -f 'kvm.c' || echo '$(srcdir)/'`kvm.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-membarrier.obj `if test -f 'membarrier.c'; then $(CYGPATH_W) 'membarrier.c'; else $(CYGPATH_W) '$(srcdir)/membarrier.c'; fi`
 
-strace-kvm.obj: kvm.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-kvm.obj -MD -MP -MF $(DEPDIR)/strace-kvm.Tpo -c -o strace-kvm.obj `if test -f 'kvm.c'; then $(CYGPATH_W) 'kvm.c'; else $(CYGPATH_W) '$(srcdir)/kvm.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-kvm.Tpo $(DEPDIR)/strace-kvm.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='kvm.c' object='strace-kvm.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-memfd_create.o: memfd_create.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-memfd_create.o -MD -MP -MF $(DEPDIR)/libstrace_a-memfd_create.Tpo -c -o libstrace_a-memfd_create.o `test -f 'memfd_create.c' || echo '$(srcdir)/'`memfd_create.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-memfd_create.Tpo $(DEPDIR)/libstrace_a-memfd_create.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='memfd_create.c' object='libstrace_a-memfd_create.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-kvm.obj `if test -f 'kvm.c'; then $(CYGPATH_W) 'kvm.c'; else $(CYGPATH_W) '$(srcdir)/kvm.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-memfd_create.o `test -f 'memfd_create.c' || echo '$(srcdir)/'`memfd_create.c
 
-strace-ldt.o: ldt.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ldt.o -MD -MP -MF $(DEPDIR)/strace-ldt.Tpo -c -o strace-ldt.o `test -f 'ldt.c' || echo '$(srcdir)/'`ldt.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ldt.Tpo $(DEPDIR)/strace-ldt.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ldt.c' object='strace-ldt.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-memfd_create.obj: memfd_create.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-memfd_create.obj -MD -MP -MF $(DEPDIR)/libstrace_a-memfd_create.Tpo -c -o libstrace_a-memfd_create.obj `if test -f 'memfd_create.c'; then $(CYGPATH_W) 'memfd_create.c'; else $(CYGPATH_W) '$(srcdir)/memfd_create.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-memfd_create.Tpo $(DEPDIR)/libstrace_a-memfd_create.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='memfd_create.c' object='libstrace_a-memfd_create.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ldt.o `test -f 'ldt.c' || echo '$(srcdir)/'`ldt.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-memfd_create.obj `if test -f 'memfd_create.c'; then $(CYGPATH_W) 'memfd_create.c'; else $(CYGPATH_W) '$(srcdir)/memfd_create.c'; fi`
 
-strace-ldt.obj: ldt.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ldt.obj -MD -MP -MF $(DEPDIR)/strace-ldt.Tpo -c -o strace-ldt.obj `if test -f 'ldt.c'; then $(CYGPATH_W) 'ldt.c'; else $(CYGPATH_W) '$(srcdir)/ldt.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ldt.Tpo $(DEPDIR)/strace-ldt.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ldt.c' object='strace-ldt.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-mknod.o: mknod.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-mknod.o -MD -MP -MF $(DEPDIR)/libstrace_a-mknod.Tpo -c -o libstrace_a-mknod.o `test -f 'mknod.c' || echo '$(srcdir)/'`mknod.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-mknod.Tpo $(DEPDIR)/libstrace_a-mknod.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mknod.c' object='libstrace_a-mknod.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ldt.obj `if test -f 'ldt.c'; then $(CYGPATH_W) 'ldt.c'; else $(CYGPATH_W) '$(srcdir)/ldt.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-mknod.o `test -f 'mknod.c' || echo '$(srcdir)/'`mknod.c
 
-strace-link.o: link.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-link.o -MD -MP -MF $(DEPDIR)/strace-link.Tpo -c -o strace-link.o `test -f 'link.c' || echo '$(srcdir)/'`link.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-link.Tpo $(DEPDIR)/strace-link.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='link.c' object='strace-link.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-mknod.obj: mknod.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-mknod.obj -MD -MP -MF $(DEPDIR)/libstrace_a-mknod.Tpo -c -o libstrace_a-mknod.obj `if test -f 'mknod.c'; then $(CYGPATH_W) 'mknod.c'; else $(CYGPATH_W) '$(srcdir)/mknod.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-mknod.Tpo $(DEPDIR)/libstrace_a-mknod.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mknod.c' object='libstrace_a-mknod.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-link.o `test -f 'link.c' || echo '$(srcdir)/'`link.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-mknod.obj `if test -f 'mknod.c'; then $(CYGPATH_W) 'mknod.c'; else $(CYGPATH_W) '$(srcdir)/mknod.c'; fi`
 
-strace-link.obj: link.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-link.obj -MD -MP -MF $(DEPDIR)/strace-link.Tpo -c -o strace-link.obj `if test -f 'link.c'; then $(CYGPATH_W) 'link.c'; else $(CYGPATH_W) '$(srcdir)/link.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-link.Tpo $(DEPDIR)/strace-link.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='link.c' object='strace-link.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-mmap_cache.o: mmap_cache.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-mmap_cache.o -MD -MP -MF $(DEPDIR)/libstrace_a-mmap_cache.Tpo -c -o libstrace_a-mmap_cache.o `test -f 'mmap_cache.c' || echo '$(srcdir)/'`mmap_cache.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-mmap_cache.Tpo $(DEPDIR)/libstrace_a-mmap_cache.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mmap_cache.c' object='libstrace_a-mmap_cache.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-link.obj `if test -f 'link.c'; then $(CYGPATH_W) 'link.c'; else $(CYGPATH_W) '$(srcdir)/link.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-mmap_cache.o `test -f 'mmap_cache.c' || echo '$(srcdir)/'`mmap_cache.c
 
-strace-listen.o: listen.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-listen.o -MD -MP -MF $(DEPDIR)/strace-listen.Tpo -c -o strace-listen.o `test -f 'listen.c' || echo '$(srcdir)/'`listen.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-listen.Tpo $(DEPDIR)/strace-listen.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='listen.c' object='strace-listen.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-mmap_cache.obj: mmap_cache.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-mmap_cache.obj -MD -MP -MF $(DEPDIR)/libstrace_a-mmap_cache.Tpo -c -o libstrace_a-mmap_cache.obj `if test -f 'mmap_cache.c'; then $(CYGPATH_W) 'mmap_cache.c'; else $(CYGPATH_W) '$(srcdir)/mmap_cache.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-mmap_cache.Tpo $(DEPDIR)/libstrace_a-mmap_cache.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mmap_cache.c' object='libstrace_a-mmap_cache.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-listen.o `test -f 'listen.c' || echo '$(srcdir)/'`listen.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-mmap_cache.obj `if test -f 'mmap_cache.c'; then $(CYGPATH_W) 'mmap_cache.c'; else $(CYGPATH_W) '$(srcdir)/mmap_cache.c'; fi`
 
-strace-listen.obj: listen.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-listen.obj -MD -MP -MF $(DEPDIR)/strace-listen.Tpo -c -o strace-listen.obj `if test -f 'listen.c'; then $(CYGPATH_W) 'listen.c'; else $(CYGPATH_W) '$(srcdir)/listen.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-listen.Tpo $(DEPDIR)/strace-listen.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='listen.c' object='strace-listen.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-mmap_notify.o: mmap_notify.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-mmap_notify.o -MD -MP -MF $(DEPDIR)/libstrace_a-mmap_notify.Tpo -c -o libstrace_a-mmap_notify.o `test -f 'mmap_notify.c' || echo '$(srcdir)/'`mmap_notify.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-mmap_notify.Tpo $(DEPDIR)/libstrace_a-mmap_notify.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mmap_notify.c' object='libstrace_a-mmap_notify.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-listen.obj `if test -f 'listen.c'; then $(CYGPATH_W) 'listen.c'; else $(CYGPATH_W) '$(srcdir)/listen.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-mmap_notify.o `test -f 'mmap_notify.c' || echo '$(srcdir)/'`mmap_notify.c
 
-strace-lookup_dcookie.o: lookup_dcookie.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-lookup_dcookie.o -MD -MP -MF $(DEPDIR)/strace-lookup_dcookie.Tpo -c -o strace-lookup_dcookie.o `test -f 'lookup_dcookie.c' || echo '$(srcdir)/'`lookup_dcookie.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-lookup_dcookie.Tpo $(DEPDIR)/strace-lookup_dcookie.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='lookup_dcookie.c' object='strace-lookup_dcookie.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-mmap_notify.obj: mmap_notify.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-mmap_notify.obj -MD -MP -MF $(DEPDIR)/libstrace_a-mmap_notify.Tpo -c -o libstrace_a-mmap_notify.obj `if test -f 'mmap_notify.c'; then $(CYGPATH_W) 'mmap_notify.c'; else $(CYGPATH_W) '$(srcdir)/mmap_notify.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-mmap_notify.Tpo $(DEPDIR)/libstrace_a-mmap_notify.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mmap_notify.c' object='libstrace_a-mmap_notify.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-lookup_dcookie.o `test -f 'lookup_dcookie.c' || echo '$(srcdir)/'`lookup_dcookie.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-mmap_notify.obj `if test -f 'mmap_notify.c'; then $(CYGPATH_W) 'mmap_notify.c'; else $(CYGPATH_W) '$(srcdir)/mmap_notify.c'; fi`
 
-strace-lookup_dcookie.obj: lookup_dcookie.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-lookup_dcookie.obj -MD -MP -MF $(DEPDIR)/strace-lookup_dcookie.Tpo -c -o strace-lookup_dcookie.obj `if test -f 'lookup_dcookie.c'; then $(CYGPATH_W) 'lookup_dcookie.c'; else $(CYGPATH_W) '$(srcdir)/lookup_dcookie.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-lookup_dcookie.Tpo $(DEPDIR)/strace-lookup_dcookie.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='lookup_dcookie.c' object='strace-lookup_dcookie.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-mmsghdr.o: mmsghdr.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-mmsghdr.o -MD -MP -MF $(DEPDIR)/libstrace_a-mmsghdr.Tpo -c -o libstrace_a-mmsghdr.o `test -f 'mmsghdr.c' || echo '$(srcdir)/'`mmsghdr.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-mmsghdr.Tpo $(DEPDIR)/libstrace_a-mmsghdr.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mmsghdr.c' object='libstrace_a-mmsghdr.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-lookup_dcookie.obj `if test -f 'lookup_dcookie.c'; then $(CYGPATH_W) 'lookup_dcookie.c'; else $(CYGPATH_W) '$(srcdir)/lookup_dcookie.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-mmsghdr.o `test -f 'mmsghdr.c' || echo '$(srcdir)/'`mmsghdr.c
 
-strace-loop.o: loop.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-loop.o -MD -MP -MF $(DEPDIR)/strace-loop.Tpo -c -o strace-loop.o `test -f 'loop.c' || echo '$(srcdir)/'`loop.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-loop.Tpo $(DEPDIR)/strace-loop.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='loop.c' object='strace-loop.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-mmsghdr.obj: mmsghdr.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-mmsghdr.obj -MD -MP -MF $(DEPDIR)/libstrace_a-mmsghdr.Tpo -c -o libstrace_a-mmsghdr.obj `if test -f 'mmsghdr.c'; then $(CYGPATH_W) 'mmsghdr.c'; else $(CYGPATH_W) '$(srcdir)/mmsghdr.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-mmsghdr.Tpo $(DEPDIR)/libstrace_a-mmsghdr.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mmsghdr.c' object='libstrace_a-mmsghdr.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-loop.o `test -f 'loop.c' || echo '$(srcdir)/'`loop.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-mmsghdr.obj `if test -f 'mmsghdr.c'; then $(CYGPATH_W) 'mmsghdr.c'; else $(CYGPATH_W) '$(srcdir)/mmsghdr.c'; fi`
 
-strace-loop.obj: loop.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-loop.obj -MD -MP -MF $(DEPDIR)/strace-loop.Tpo -c -o strace-loop.obj `if test -f 'loop.c'; then $(CYGPATH_W) 'loop.c'; else $(CYGPATH_W) '$(srcdir)/loop.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-loop.Tpo $(DEPDIR)/strace-loop.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='loop.c' object='strace-loop.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-mount.o: mount.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-mount.o -MD -MP -MF $(DEPDIR)/libstrace_a-mount.Tpo -c -o libstrace_a-mount.o `test -f 'mount.c' || echo '$(srcdir)/'`mount.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-mount.Tpo $(DEPDIR)/libstrace_a-mount.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mount.c' object='libstrace_a-mount.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-loop.obj `if test -f 'loop.c'; then $(CYGPATH_W) 'loop.c'; else $(CYGPATH_W) '$(srcdir)/loop.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-mount.o `test -f 'mount.c' || echo '$(srcdir)/'`mount.c
 
-strace-lseek.o: lseek.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-lseek.o -MD -MP -MF $(DEPDIR)/strace-lseek.Tpo -c -o strace-lseek.o `test -f 'lseek.c' || echo '$(srcdir)/'`lseek.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-lseek.Tpo $(DEPDIR)/strace-lseek.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='lseek.c' object='strace-lseek.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-mount.obj: mount.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-mount.obj -MD -MP -MF $(DEPDIR)/libstrace_a-mount.Tpo -c -o libstrace_a-mount.obj `if test -f 'mount.c'; then $(CYGPATH_W) 'mount.c'; else $(CYGPATH_W) '$(srcdir)/mount.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-mount.Tpo $(DEPDIR)/libstrace_a-mount.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mount.c' object='libstrace_a-mount.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-lseek.o `test -f 'lseek.c' || echo '$(srcdir)/'`lseek.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-mount.obj `if test -f 'mount.c'; then $(CYGPATH_W) 'mount.c'; else $(CYGPATH_W) '$(srcdir)/mount.c'; fi`
 
-strace-lseek.obj: lseek.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-lseek.obj -MD -MP -MF $(DEPDIR)/strace-lseek.Tpo -c -o strace-lseek.obj `if test -f 'lseek.c'; then $(CYGPATH_W) 'lseek.c'; else $(CYGPATH_W) '$(srcdir)/lseek.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-lseek.Tpo $(DEPDIR)/strace-lseek.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='lseek.c' object='strace-lseek.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-move_mount.o: move_mount.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-move_mount.o -MD -MP -MF $(DEPDIR)/libstrace_a-move_mount.Tpo -c -o libstrace_a-move_mount.o `test -f 'move_mount.c' || echo '$(srcdir)/'`move_mount.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-move_mount.Tpo $(DEPDIR)/libstrace_a-move_mount.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='move_mount.c' object='libstrace_a-move_mount.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-lseek.obj `if test -f 'lseek.c'; then $(CYGPATH_W) 'lseek.c'; else $(CYGPATH_W) '$(srcdir)/lseek.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-move_mount.o `test -f 'move_mount.c' || echo '$(srcdir)/'`move_mount.c
 
-strace-mem.o: mem.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-mem.o -MD -MP -MF $(DEPDIR)/strace-mem.Tpo -c -o strace-mem.o `test -f 'mem.c' || echo '$(srcdir)/'`mem.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-mem.Tpo $(DEPDIR)/strace-mem.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mem.c' object='strace-mem.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-move_mount.obj: move_mount.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-move_mount.obj -MD -MP -MF $(DEPDIR)/libstrace_a-move_mount.Tpo -c -o libstrace_a-move_mount.obj `if test -f 'move_mount.c'; then $(CYGPATH_W) 'move_mount.c'; else $(CYGPATH_W) '$(srcdir)/move_mount.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-move_mount.Tpo $(DEPDIR)/libstrace_a-move_mount.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='move_mount.c' object='libstrace_a-move_mount.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-mem.o `test -f 'mem.c' || echo '$(srcdir)/'`mem.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-move_mount.obj `if test -f 'move_mount.c'; then $(CYGPATH_W) 'move_mount.c'; else $(CYGPATH_W) '$(srcdir)/move_mount.c'; fi`
 
-strace-mem.obj: mem.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-mem.obj -MD -MP -MF $(DEPDIR)/strace-mem.Tpo -c -o strace-mem.obj `if test -f 'mem.c'; then $(CYGPATH_W) 'mem.c'; else $(CYGPATH_W) '$(srcdir)/mem.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-mem.Tpo $(DEPDIR)/strace-mem.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mem.c' object='strace-mem.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-mq.o: mq.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-mq.o -MD -MP -MF $(DEPDIR)/libstrace_a-mq.Tpo -c -o libstrace_a-mq.o `test -f 'mq.c' || echo '$(srcdir)/'`mq.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-mq.Tpo $(DEPDIR)/libstrace_a-mq.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mq.c' object='libstrace_a-mq.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-mem.obj `if test -f 'mem.c'; then $(CYGPATH_W) 'mem.c'; else $(CYGPATH_W) '$(srcdir)/mem.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-mq.o `test -f 'mq.c' || echo '$(srcdir)/'`mq.c
 
-strace-membarrier.o: membarrier.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-membarrier.o -MD -MP -MF $(DEPDIR)/strace-membarrier.Tpo -c -o strace-membarrier.o `test -f 'membarrier.c' || echo '$(srcdir)/'`membarrier.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-membarrier.Tpo $(DEPDIR)/strace-membarrier.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='membarrier.c' object='strace-membarrier.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-mq.obj: mq.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-mq.obj -MD -MP -MF $(DEPDIR)/libstrace_a-mq.Tpo -c -o libstrace_a-mq.obj `if test -f 'mq.c'; then $(CYGPATH_W) 'mq.c'; else $(CYGPATH_W) '$(srcdir)/mq.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-mq.Tpo $(DEPDIR)/libstrace_a-mq.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mq.c' object='libstrace_a-mq.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-membarrier.o `test -f 'membarrier.c' || echo '$(srcdir)/'`membarrier.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-mq.obj `if test -f 'mq.c'; then $(CYGPATH_W) 'mq.c'; else $(CYGPATH_W) '$(srcdir)/mq.c'; fi`
 
-strace-membarrier.obj: membarrier.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-membarrier.obj -MD -MP -MF $(DEPDIR)/strace-membarrier.Tpo -c -o strace-membarrier.obj `if test -f 'membarrier.c'; then $(CYGPATH_W) 'membarrier.c'; else $(CYGPATH_W) '$(srcdir)/membarrier.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-membarrier.Tpo $(DEPDIR)/strace-membarrier.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='membarrier.c' object='strace-membarrier.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-msghdr.o: msghdr.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-msghdr.o -MD -MP -MF $(DEPDIR)/libstrace_a-msghdr.Tpo -c -o libstrace_a-msghdr.o `test -f 'msghdr.c' || echo '$(srcdir)/'`msghdr.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-msghdr.Tpo $(DEPDIR)/libstrace_a-msghdr.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='msghdr.c' object='libstrace_a-msghdr.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-membarrier.obj `if test -f 'membarrier.c'; then $(CYGPATH_W) 'membarrier.c'; else $(CYGPATH_W) '$(srcdir)/membarrier.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-msghdr.o `test -f 'msghdr.c' || echo '$(srcdir)/'`msghdr.c
 
-strace-memfd_create.o: memfd_create.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-memfd_create.o -MD -MP -MF $(DEPDIR)/strace-memfd_create.Tpo -c -o strace-memfd_create.o `test -f 'memfd_create.c' || echo '$(srcdir)/'`memfd_create.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-memfd_create.Tpo $(DEPDIR)/strace-memfd_create.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='memfd_create.c' object='strace-memfd_create.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-msghdr.obj: msghdr.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-msghdr.obj -MD -MP -MF $(DEPDIR)/libstrace_a-msghdr.Tpo -c -o libstrace_a-msghdr.obj `if test -f 'msghdr.c'; then $(CYGPATH_W) 'msghdr.c'; else $(CYGPATH_W) '$(srcdir)/msghdr.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-msghdr.Tpo $(DEPDIR)/libstrace_a-msghdr.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='msghdr.c' object='libstrace_a-msghdr.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-memfd_create.o `test -f 'memfd_create.c' || echo '$(srcdir)/'`memfd_create.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-msghdr.obj `if test -f 'msghdr.c'; then $(CYGPATH_W) 'msghdr.c'; else $(CYGPATH_W) '$(srcdir)/msghdr.c'; fi`
 
-strace-memfd_create.obj: memfd_create.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-memfd_create.obj -MD -MP -MF $(DEPDIR)/strace-memfd_create.Tpo -c -o strace-memfd_create.obj `if test -f 'memfd_create.c'; then $(CYGPATH_W) 'memfd_create.c'; else $(CYGPATH_W) '$(srcdir)/memfd_create.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-memfd_create.Tpo $(DEPDIR)/strace-memfd_create.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='memfd_create.c' object='strace-memfd_create.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-mtd.o: mtd.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-mtd.o -MD -MP -MF $(DEPDIR)/libstrace_a-mtd.Tpo -c -o libstrace_a-mtd.o `test -f 'mtd.c' || echo '$(srcdir)/'`mtd.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-mtd.Tpo $(DEPDIR)/libstrace_a-mtd.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mtd.c' object='libstrace_a-mtd.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-memfd_create.obj `if test -f 'memfd_create.c'; then $(CYGPATH_W) 'memfd_create.c'; else $(CYGPATH_W) '$(srcdir)/memfd_create.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-mtd.o `test -f 'mtd.c' || echo '$(srcdir)/'`mtd.c
 
-strace-mknod.o: mknod.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-mknod.o -MD -MP -MF $(DEPDIR)/strace-mknod.Tpo -c -o strace-mknod.o `test -f 'mknod.c' || echo '$(srcdir)/'`mknod.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-mknod.Tpo $(DEPDIR)/strace-mknod.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mknod.c' object='strace-mknod.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-mtd.obj: mtd.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-mtd.obj -MD -MP -MF $(DEPDIR)/libstrace_a-mtd.Tpo -c -o libstrace_a-mtd.obj `if test -f 'mtd.c'; then $(CYGPATH_W) 'mtd.c'; else $(CYGPATH_W) '$(srcdir)/mtd.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-mtd.Tpo $(DEPDIR)/libstrace_a-mtd.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mtd.c' object='libstrace_a-mtd.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-mknod.o `test -f 'mknod.c' || echo '$(srcdir)/'`mknod.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-mtd.obj `if test -f 'mtd.c'; then $(CYGPATH_W) 'mtd.c'; else $(CYGPATH_W) '$(srcdir)/mtd.c'; fi`
 
-strace-mknod.obj: mknod.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-mknod.obj -MD -MP -MF $(DEPDIR)/strace-mknod.Tpo -c -o strace-mknod.obj `if test -f 'mknod.c'; then $(CYGPATH_W) 'mknod.c'; else $(CYGPATH_W) '$(srcdir)/mknod.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-mknod.Tpo $(DEPDIR)/strace-mknod.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mknod.c' object='strace-mknod.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-nbd_ioctl.o: nbd_ioctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-nbd_ioctl.o -MD -MP -MF $(DEPDIR)/libstrace_a-nbd_ioctl.Tpo -c -o libstrace_a-nbd_ioctl.o `test -f 'nbd_ioctl.c' || echo '$(srcdir)/'`nbd_ioctl.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-nbd_ioctl.Tpo $(DEPDIR)/libstrace_a-nbd_ioctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='nbd_ioctl.c' object='libstrace_a-nbd_ioctl.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-mknod.obj `if test -f 'mknod.c'; then $(CYGPATH_W) 'mknod.c'; else $(CYGPATH_W) '$(srcdir)/mknod.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-nbd_ioctl.o `test -f 'nbd_ioctl.c' || echo '$(srcdir)/'`nbd_ioctl.c
 
-strace-mmap_notify.o: mmap_notify.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-mmap_notify.o -MD -MP -MF $(DEPDIR)/strace-mmap_notify.Tpo -c -o strace-mmap_notify.o `test -f 'mmap_notify.c' || echo '$(srcdir)/'`mmap_notify.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-mmap_notify.Tpo $(DEPDIR)/strace-mmap_notify.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mmap_notify.c' object='strace-mmap_notify.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-nbd_ioctl.obj: nbd_ioctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-nbd_ioctl.obj -MD -MP -MF $(DEPDIR)/libstrace_a-nbd_ioctl.Tpo -c -o libstrace_a-nbd_ioctl.obj `if test -f 'nbd_ioctl.c'; then $(CYGPATH_W) 'nbd_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/nbd_ioctl.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-nbd_ioctl.Tpo $(DEPDIR)/libstrace_a-nbd_ioctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='nbd_ioctl.c' object='libstrace_a-nbd_ioctl.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-mmap_notify.o `test -f 'mmap_notify.c' || echo '$(srcdir)/'`mmap_notify.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-nbd_ioctl.obj `if test -f 'nbd_ioctl.c'; then $(CYGPATH_W) 'nbd_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/nbd_ioctl.c'; fi`
 
-strace-mmap_notify.obj: mmap_notify.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-mmap_notify.obj -MD -MP -MF $(DEPDIR)/strace-mmap_notify.Tpo -c -o strace-mmap_notify.obj `if test -f 'mmap_notify.c'; then $(CYGPATH_W) 'mmap_notify.c'; else $(CYGPATH_W) '$(srcdir)/mmap_notify.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-mmap_notify.Tpo $(DEPDIR)/strace-mmap_notify.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mmap_notify.c' object='strace-mmap_notify.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-net.o: net.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-net.o -MD -MP -MF $(DEPDIR)/libstrace_a-net.Tpo -c -o libstrace_a-net.o `test -f 'net.c' || echo '$(srcdir)/'`net.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-net.Tpo $(DEPDIR)/libstrace_a-net.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='net.c' object='libstrace_a-net.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-mmap_notify.obj `if test -f 'mmap_notify.c'; then $(CYGPATH_W) 'mmap_notify.c'; else $(CYGPATH_W) '$(srcdir)/mmap_notify.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-net.o `test -f 'net.c' || echo '$(srcdir)/'`net.c
 
-strace-mmsghdr.o: mmsghdr.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-mmsghdr.o -MD -MP -MF $(DEPDIR)/strace-mmsghdr.Tpo -c -o strace-mmsghdr.o `test -f 'mmsghdr.c' || echo '$(srcdir)/'`mmsghdr.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-mmsghdr.Tpo $(DEPDIR)/strace-mmsghdr.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mmsghdr.c' object='strace-mmsghdr.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-net.obj: net.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-net.obj -MD -MP -MF $(DEPDIR)/libstrace_a-net.Tpo -c -o libstrace_a-net.obj `if test -f 'net.c'; then $(CYGPATH_W) 'net.c'; else $(CYGPATH_W) '$(srcdir)/net.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-net.Tpo $(DEPDIR)/libstrace_a-net.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='net.c' object='libstrace_a-net.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-mmsghdr.o `test -f 'mmsghdr.c' || echo '$(srcdir)/'`mmsghdr.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-net.obj `if test -f 'net.c'; then $(CYGPATH_W) 'net.c'; else $(CYGPATH_W) '$(srcdir)/net.c'; fi`
 
-strace-mmsghdr.obj: mmsghdr.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-mmsghdr.obj -MD -MP -MF $(DEPDIR)/strace-mmsghdr.Tpo -c -o strace-mmsghdr.obj `if test -f 'mmsghdr.c'; then $(CYGPATH_W) 'mmsghdr.c'; else $(CYGPATH_W) '$(srcdir)/mmsghdr.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-mmsghdr.Tpo $(DEPDIR)/strace-mmsghdr.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mmsghdr.c' object='strace-mmsghdr.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-netlink.o: netlink.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-netlink.o -MD -MP -MF $(DEPDIR)/libstrace_a-netlink.Tpo -c -o libstrace_a-netlink.o `test -f 'netlink.c' || echo '$(srcdir)/'`netlink.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-netlink.Tpo $(DEPDIR)/libstrace_a-netlink.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink.c' object='libstrace_a-netlink.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-mmsghdr.obj `if test -f 'mmsghdr.c'; then $(CYGPATH_W) 'mmsghdr.c'; else $(CYGPATH_W) '$(srcdir)/mmsghdr.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-netlink.o `test -f 'netlink.c' || echo '$(srcdir)/'`netlink.c
 
-strace-mount.o: mount.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-mount.o -MD -MP -MF $(DEPDIR)/strace-mount.Tpo -c -o strace-mount.o `test -f 'mount.c' || echo '$(srcdir)/'`mount.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-mount.Tpo $(DEPDIR)/strace-mount.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mount.c' object='strace-mount.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-netlink.obj: netlink.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-netlink.obj -MD -MP -MF $(DEPDIR)/libstrace_a-netlink.Tpo -c -o libstrace_a-netlink.obj `if test -f 'netlink.c'; then $(CYGPATH_W) 'netlink.c'; else $(CYGPATH_W) '$(srcdir)/netlink.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-netlink.Tpo $(DEPDIR)/libstrace_a-netlink.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink.c' object='libstrace_a-netlink.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-mount.o `test -f 'mount.c' || echo '$(srcdir)/'`mount.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-netlink.obj `if test -f 'netlink.c'; then $(CYGPATH_W) 'netlink.c'; else $(CYGPATH_W) '$(srcdir)/netlink.c'; fi`
 
-strace-mount.obj: mount.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-mount.obj -MD -MP -MF $(DEPDIR)/strace-mount.Tpo -c -o strace-mount.obj `if test -f 'mount.c'; then $(CYGPATH_W) 'mount.c'; else $(CYGPATH_W) '$(srcdir)/mount.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-mount.Tpo $(DEPDIR)/strace-mount.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mount.c' object='strace-mount.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-netlink_crypto.o: netlink_crypto.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-netlink_crypto.o -MD -MP -MF $(DEPDIR)/libstrace_a-netlink_crypto.Tpo -c -o libstrace_a-netlink_crypto.o `test -f 'netlink_crypto.c' || echo '$(srcdir)/'`netlink_crypto.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-netlink_crypto.Tpo $(DEPDIR)/libstrace_a-netlink_crypto.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_crypto.c' object='libstrace_a-netlink_crypto.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-mount.obj `if test -f 'mount.c'; then $(CYGPATH_W) 'mount.c'; else $(CYGPATH_W) '$(srcdir)/mount.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-netlink_crypto.o `test -f 'netlink_crypto.c' || echo '$(srcdir)/'`netlink_crypto.c
 
-strace-move_mount.o: move_mount.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-move_mount.o -MD -MP -MF $(DEPDIR)/strace-move_mount.Tpo -c -o strace-move_mount.o `test -f 'move_mount.c' || echo '$(srcdir)/'`move_mount.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-move_mount.Tpo $(DEPDIR)/strace-move_mount.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='move_mount.c' object='strace-move_mount.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-netlink_crypto.obj: netlink_crypto.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-netlink_crypto.obj -MD -MP -MF $(DEPDIR)/libstrace_a-netlink_crypto.Tpo -c -o libstrace_a-netlink_crypto.obj `if test -f 'netlink_crypto.c'; then $(CYGPATH_W) 'netlink_crypto.c'; else $(CYGPATH_W) '$(srcdir)/netlink_crypto.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-netlink_crypto.Tpo $(DEPDIR)/libstrace_a-netlink_crypto.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_crypto.c' object='libstrace_a-netlink_crypto.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-move_mount.o `test -f 'move_mount.c' || echo '$(srcdir)/'`move_mount.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-netlink_crypto.obj `if test -f 'netlink_crypto.c'; then $(CYGPATH_W) 'netlink_crypto.c'; else $(CYGPATH_W) '$(srcdir)/netlink_crypto.c'; fi`
 
-strace-move_mount.obj: move_mount.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-move_mount.obj -MD -MP -MF $(DEPDIR)/strace-move_mount.Tpo -c -o strace-move_mount.obj `if test -f 'move_mount.c'; then $(CYGPATH_W) 'move_mount.c'; else $(CYGPATH_W) '$(srcdir)/move_mount.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-move_mount.Tpo $(DEPDIR)/strace-move_mount.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='move_mount.c' object='strace-move_mount.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-netlink_inet_diag.o: netlink_inet_diag.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-netlink_inet_diag.o -MD -MP -MF $(DEPDIR)/libstrace_a-netlink_inet_diag.Tpo -c -o libstrace_a-netlink_inet_diag.o `test -f 'netlink_inet_diag.c' || echo '$(srcdir)/'`netlink_inet_diag.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-netlink_inet_diag.Tpo $(DEPDIR)/libstrace_a-netlink_inet_diag.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_inet_diag.c' object='libstrace_a-netlink_inet_diag.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-move_mount.obj `if test -f 'move_mount.c'; then $(CYGPATH_W) 'move_mount.c'; else $(CYGPATH_W) '$(srcdir)/move_mount.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-netlink_inet_diag.o `test -f 'netlink_inet_diag.c' || echo '$(srcdir)/'`netlink_inet_diag.c
 
-strace-mq.o: mq.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-mq.o -MD -MP -MF $(DEPDIR)/strace-mq.Tpo -c -o strace-mq.o `test -f 'mq.c' || echo '$(srcdir)/'`mq.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-mq.Tpo $(DEPDIR)/strace-mq.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mq.c' object='strace-mq.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-netlink_inet_diag.obj: netlink_inet_diag.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-netlink_inet_diag.obj -MD -MP -MF $(DEPDIR)/libstrace_a-netlink_inet_diag.Tpo -c -o libstrace_a-netlink_inet_diag.obj `if test -f 'netlink_inet_diag.c'; then $(CYGPATH_W) 'netlink_inet_diag.c'; else $(CYGPATH_W) '$(srcdir)/netlink_inet_diag.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-netlink_inet_diag.Tpo $(DEPDIR)/libstrace_a-netlink_inet_diag.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_inet_diag.c' object='libstrace_a-netlink_inet_diag.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-mq.o `test -f 'mq.c' || echo '$(srcdir)/'`mq.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-netlink_inet_diag.obj `if test -f 'netlink_inet_diag.c'; then $(CYGPATH_W) 'netlink_inet_diag.c'; else $(CYGPATH_W) '$(srcdir)/netlink_inet_diag.c'; fi`
 
-strace-mq.obj: mq.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-mq.obj -MD -MP -MF $(DEPDIR)/strace-mq.Tpo -c -o strace-mq.obj `if test -f 'mq.c'; then $(CYGPATH_W) 'mq.c'; else $(CYGPATH_W) '$(srcdir)/mq.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-mq.Tpo $(DEPDIR)/strace-mq.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mq.c' object='strace-mq.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-netlink_kobject_uevent.o: netlink_kobject_uevent.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-netlink_kobject_uevent.o -MD -MP -MF $(DEPDIR)/libstrace_a-netlink_kobject_uevent.Tpo -c -o libstrace_a-netlink_kobject_uevent.o `test -f 'netlink_kobject_uevent.c' || echo '$(srcdir)/'`netlink_kobject_uevent.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-netlink_kobject_uevent.Tpo $(DEPDIR)/libstrace_a-netlink_kobject_uevent.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_kobject_uevent.c' object='libstrace_a-netlink_kobject_uevent.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-mq.obj `if test -f 'mq.c'; then $(CYGPATH_W) 'mq.c'; else $(CYGPATH_W) '$(srcdir)/mq.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-netlink_kobject_uevent.o `test -f 'netlink_kobject_uevent.c' || echo '$(srcdir)/'`netlink_kobject_uevent.c
 
-strace-msghdr.o: msghdr.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-msghdr.o -MD -MP -MF $(DEPDIR)/strace-msghdr.Tpo -c -o strace-msghdr.o `test -f 'msghdr.c' || echo '$(srcdir)/'`msghdr.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-msghdr.Tpo $(DEPDIR)/strace-msghdr.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='msghdr.c' object='strace-msghdr.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-netlink_kobject_uevent.obj: netlink_kobject_uevent.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-netlink_kobject_uevent.obj -MD -MP -MF $(DEPDIR)/libstrace_a-netlink_kobject_uevent.Tpo -c -o libstrace_a-netlink_kobject_uevent.obj `if test -f 'netlink_kobject_uevent.c'; then $(CYGPATH_W) 'netlink_kobject_uevent.c'; else $(CYGPATH_W) '$(srcdir)/netlink_kobject_uevent.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-netlink_kobject_uevent.Tpo $(DEPDIR)/libstrace_a-netlink_kobject_uevent.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_kobject_uevent.c' object='libstrace_a-netlink_kobject_uevent.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-msghdr.o `test -f 'msghdr.c' || echo '$(srcdir)/'`msghdr.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-netlink_kobject_uevent.obj `if test -f 'netlink_kobject_uevent.c'; then $(CYGPATH_W) 'netlink_kobject_uevent.c'; else $(CYGPATH_W) '$(srcdir)/netlink_kobject_uevent.c'; fi`
 
-strace-msghdr.obj: msghdr.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-msghdr.obj -MD -MP -MF $(DEPDIR)/strace-msghdr.Tpo -c -o strace-msghdr.obj `if test -f 'msghdr.c'; then $(CYGPATH_W) 'msghdr.c'; else $(CYGPATH_W) '$(srcdir)/msghdr.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-msghdr.Tpo $(DEPDIR)/strace-msghdr.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='msghdr.c' object='strace-msghdr.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-netlink_netfilter.o: netlink_netfilter.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-netlink_netfilter.o -MD -MP -MF $(DEPDIR)/libstrace_a-netlink_netfilter.Tpo -c -o libstrace_a-netlink_netfilter.o `test -f 'netlink_netfilter.c' || echo '$(srcdir)/'`netlink_netfilter.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-netlink_netfilter.Tpo $(DEPDIR)/libstrace_a-netlink_netfilter.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_netfilter.c' object='libstrace_a-netlink_netfilter.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-msghdr.obj `if test -f 'msghdr.c'; then $(CYGPATH_W) 'msghdr.c'; else $(CYGPATH_W) '$(srcdir)/msghdr.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-netlink_netfilter.o `test -f 'netlink_netfilter.c' || echo '$(srcdir)/'`netlink_netfilter.c
 
-strace-mtd.o: mtd.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-mtd.o -MD -MP -MF $(DEPDIR)/strace-mtd.Tpo -c -o strace-mtd.o `test -f 'mtd.c' || echo '$(srcdir)/'`mtd.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-mtd.Tpo $(DEPDIR)/strace-mtd.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mtd.c' object='strace-mtd.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-netlink_netfilter.obj: netlink_netfilter.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-netlink_netfilter.obj -MD -MP -MF $(DEPDIR)/libstrace_a-netlink_netfilter.Tpo -c -o libstrace_a-netlink_netfilter.obj `if test -f 'netlink_netfilter.c'; then $(CYGPATH_W) 'netlink_netfilter.c'; else $(CYGPATH_W) '$(srcdir)/netlink_netfilter.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-netlink_netfilter.Tpo $(DEPDIR)/libstrace_a-netlink_netfilter.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_netfilter.c' object='libstrace_a-netlink_netfilter.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-mtd.o `test -f 'mtd.c' || echo '$(srcdir)/'`mtd.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-netlink_netfilter.obj `if test -f 'netlink_netfilter.c'; then $(CYGPATH_W) 'netlink_netfilter.c'; else $(CYGPATH_W) '$(srcdir)/netlink_netfilter.c'; fi`
 
-strace-mtd.obj: mtd.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-mtd.obj -MD -MP -MF $(DEPDIR)/strace-mtd.Tpo -c -o strace-mtd.obj `if test -f 'mtd.c'; then $(CYGPATH_W) 'mtd.c'; else $(CYGPATH_W) '$(srcdir)/mtd.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-mtd.Tpo $(DEPDIR)/strace-mtd.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='mtd.c' object='strace-mtd.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-netlink_netlink_diag.o: netlink_netlink_diag.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-netlink_netlink_diag.o -MD -MP -MF $(DEPDIR)/libstrace_a-netlink_netlink_diag.Tpo -c -o libstrace_a-netlink_netlink_diag.o `test -f 'netlink_netlink_diag.c' || echo '$(srcdir)/'`netlink_netlink_diag.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-netlink_netlink_diag.Tpo $(DEPDIR)/libstrace_a-netlink_netlink_diag.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_netlink_diag.c' object='libstrace_a-netlink_netlink_diag.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-mtd.obj `if test -f 'mtd.c'; then $(CYGPATH_W) 'mtd.c'; else $(CYGPATH_W) '$(srcdir)/mtd.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-netlink_netlink_diag.o `test -f 'netlink_netlink_diag.c' || echo '$(srcdir)/'`netlink_netlink_diag.c
 
-strace-nbd_ioctl.o: nbd_ioctl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-nbd_ioctl.o -MD -MP -MF $(DEPDIR)/strace-nbd_ioctl.Tpo -c -o strace-nbd_ioctl.o `test -f 'nbd_ioctl.c' || echo '$(srcdir)/'`nbd_ioctl.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-nbd_ioctl.Tpo $(DEPDIR)/strace-nbd_ioctl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='nbd_ioctl.c' object='strace-nbd_ioctl.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-netlink_netlink_diag.obj: netlink_netlink_diag.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-netlink_netlink_diag.obj -MD -MP -MF $(DEPDIR)/libstrace_a-netlink_netlink_diag.Tpo -c -o libstrace_a-netlink_netlink_diag.obj `if test -f 'netlink_netlink_diag.c'; then $(CYGPATH_W) 'netlink_netlink_diag.c'; else $(CYGPATH_W) '$(srcdir)/netlink_netlink_diag.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-netlink_netlink_diag.Tpo $(DEPDIR)/libstrace_a-netlink_netlink_diag.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_netlink_diag.c' object='libstrace_a-netlink_netlink_diag.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-nbd_ioctl.o `test -f 'nbd_ioctl.c' || echo '$(srcdir)/'`nbd_ioctl.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-netlink_netlink_diag.obj `if test -f 'netlink_netlink_diag.c'; then $(CYGPATH_W) 'netlink_netlink_diag.c'; else $(CYGPATH_W) '$(srcdir)/netlink_netlink_diag.c'; fi`
 
-strace-nbd_ioctl.obj: nbd_ioctl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-nbd_ioctl.obj -MD -MP -MF $(DEPDIR)/strace-nbd_ioctl.Tpo -c -o strace-nbd_ioctl.obj `if test -f 'nbd_ioctl.c'; then $(CYGPATH_W) 'nbd_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/nbd_ioctl.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-nbd_ioctl.Tpo $(DEPDIR)/strace-nbd_ioctl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='nbd_ioctl.c' object='strace-nbd_ioctl.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-netlink_packet_diag.o: netlink_packet_diag.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-netlink_packet_diag.o -MD -MP -MF $(DEPDIR)/libstrace_a-netlink_packet_diag.Tpo -c -o libstrace_a-netlink_packet_diag.o `test -f 'netlink_packet_diag.c' || echo '$(srcdir)/'`netlink_packet_diag.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-netlink_packet_diag.Tpo $(DEPDIR)/libstrace_a-netlink_packet_diag.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_packet_diag.c' object='libstrace_a-netlink_packet_diag.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-nbd_ioctl.obj `if test -f 'nbd_ioctl.c'; then $(CYGPATH_W) 'nbd_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/nbd_ioctl.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-netlink_packet_diag.o `test -f 'netlink_packet_diag.c' || echo '$(srcdir)/'`netlink_packet_diag.c
 
-strace-net.o: net.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-net.o -MD -MP -MF $(DEPDIR)/strace-net.Tpo -c -o strace-net.o `test -f 'net.c' || echo '$(srcdir)/'`net.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-net.Tpo $(DEPDIR)/strace-net.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='net.c' object='strace-net.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-netlink_packet_diag.obj: netlink_packet_diag.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-netlink_packet_diag.obj -MD -MP -MF $(DEPDIR)/libstrace_a-netlink_packet_diag.Tpo -c -o libstrace_a-netlink_packet_diag.obj `if test -f 'netlink_packet_diag.c'; then $(CYGPATH_W) 'netlink_packet_diag.c'; else $(CYGPATH_W) '$(srcdir)/netlink_packet_diag.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-netlink_packet_diag.Tpo $(DEPDIR)/libstrace_a-netlink_packet_diag.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_packet_diag.c' object='libstrace_a-netlink_packet_diag.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-net.o `test -f 'net.c' || echo '$(srcdir)/'`net.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-netlink_packet_diag.obj `if test -f 'netlink_packet_diag.c'; then $(CYGPATH_W) 'netlink_packet_diag.c'; else $(CYGPATH_W) '$(srcdir)/netlink_packet_diag.c'; fi`
 
-strace-net.obj: net.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-net.obj -MD -MP -MF $(DEPDIR)/strace-net.Tpo -c -o strace-net.obj `if test -f 'net.c'; then $(CYGPATH_W) 'net.c'; else $(CYGPATH_W) '$(srcdir)/net.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-net.Tpo $(DEPDIR)/strace-net.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='net.c' object='strace-net.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-netlink_route.o: netlink_route.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-netlink_route.o -MD -MP -MF $(DEPDIR)/libstrace_a-netlink_route.Tpo -c -o libstrace_a-netlink_route.o `test -f 'netlink_route.c' || echo '$(srcdir)/'`netlink_route.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-netlink_route.Tpo $(DEPDIR)/libstrace_a-netlink_route.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_route.c' object='libstrace_a-netlink_route.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-net.obj `if test -f 'net.c'; then $(CYGPATH_W) 'net.c'; else $(CYGPATH_W) '$(srcdir)/net.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-netlink_route.o `test -f 'netlink_route.c' || echo '$(srcdir)/'`netlink_route.c
 
-strace-netlink.o: netlink.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-netlink.o -MD -MP -MF $(DEPDIR)/strace-netlink.Tpo -c -o strace-netlink.o `test -f 'netlink.c' || echo '$(srcdir)/'`netlink.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-netlink.Tpo $(DEPDIR)/strace-netlink.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink.c' object='strace-netlink.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-netlink_route.obj: netlink_route.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-netlink_route.obj -MD -MP -MF $(DEPDIR)/libstrace_a-netlink_route.Tpo -c -o libstrace_a-netlink_route.obj `if test -f 'netlink_route.c'; then $(CYGPATH_W) 'netlink_route.c'; else $(CYGPATH_W) '$(srcdir)/netlink_route.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-netlink_route.Tpo $(DEPDIR)/libstrace_a-netlink_route.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_route.c' object='libstrace_a-netlink_route.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-netlink.o `test -f 'netlink.c' || echo '$(srcdir)/'`netlink.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-netlink_route.obj `if test -f 'netlink_route.c'; then $(CYGPATH_W) 'netlink_route.c'; else $(CYGPATH_W) '$(srcdir)/netlink_route.c'; fi`
 
-strace-netlink.obj: netlink.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-netlink.obj -MD -MP -MF $(DEPDIR)/strace-netlink.Tpo -c -o strace-netlink.obj `if test -f 'netlink.c'; then $(CYGPATH_W) 'netlink.c'; else $(CYGPATH_W) '$(srcdir)/netlink.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-netlink.Tpo $(DEPDIR)/strace-netlink.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink.c' object='strace-netlink.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-netlink_selinux.o: netlink_selinux.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-netlink_selinux.o -MD -MP -MF $(DEPDIR)/libstrace_a-netlink_selinux.Tpo -c -o libstrace_a-netlink_selinux.o `test -f 'netlink_selinux.c' || echo '$(srcdir)/'`netlink_selinux.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-netlink_selinux.Tpo $(DEPDIR)/libstrace_a-netlink_selinux.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_selinux.c' object='libstrace_a-netlink_selinux.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-netlink.obj `if test -f 'netlink.c'; then $(CYGPATH_W) 'netlink.c'; else $(CYGPATH_W) '$(srcdir)/netlink.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-netlink_selinux.o `test -f 'netlink_selinux.c' || echo '$(srcdir)/'`netlink_selinux.c
 
-strace-netlink_crypto.o: netlink_crypto.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-netlink_crypto.o -MD -MP -MF $(DEPDIR)/strace-netlink_crypto.Tpo -c -o strace-netlink_crypto.o `test -f 'netlink_crypto.c' || echo '$(srcdir)/'`netlink_crypto.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-netlink_crypto.Tpo $(DEPDIR)/strace-netlink_crypto.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_crypto.c' object='strace-netlink_crypto.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-netlink_selinux.obj: netlink_selinux.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-netlink_selinux.obj -MD -MP -MF $(DEPDIR)/libstrace_a-netlink_selinux.Tpo -c -o libstrace_a-netlink_selinux.obj `if test -f 'netlink_selinux.c'; then $(CYGPATH_W) 'netlink_selinux.c'; else $(CYGPATH_W) '$(srcdir)/netlink_selinux.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-netlink_selinux.Tpo $(DEPDIR)/libstrace_a-netlink_selinux.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_selinux.c' object='libstrace_a-netlink_selinux.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-netlink_crypto.o `test -f 'netlink_crypto.c' || echo '$(srcdir)/'`netlink_crypto.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-netlink_selinux.obj `if test -f 'netlink_selinux.c'; then $(CYGPATH_W) 'netlink_selinux.c'; else $(CYGPATH_W) '$(srcdir)/netlink_selinux.c'; fi`
 
-strace-netlink_crypto.obj: netlink_crypto.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-netlink_crypto.obj -MD -MP -MF $(DEPDIR)/strace-netlink_crypto.Tpo -c -o strace-netlink_crypto.obj `if test -f 'netlink_crypto.c'; then $(CYGPATH_W) 'netlink_crypto.c'; else $(CYGPATH_W) '$(srcdir)/netlink_crypto.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-netlink_crypto.Tpo $(DEPDIR)/strace-netlink_crypto.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_crypto.c' object='strace-netlink_crypto.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-netlink_smc_diag.o: netlink_smc_diag.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-netlink_smc_diag.o -MD -MP -MF $(DEPDIR)/libstrace_a-netlink_smc_diag.Tpo -c -o libstrace_a-netlink_smc_diag.o `test -f 'netlink_smc_diag.c' || echo '$(srcdir)/'`netlink_smc_diag.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-netlink_smc_diag.Tpo $(DEPDIR)/libstrace_a-netlink_smc_diag.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_smc_diag.c' object='libstrace_a-netlink_smc_diag.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-netlink_crypto.obj `if test -f 'netlink_crypto.c'; then $(CYGPATH_W) 'netlink_crypto.c'; else $(CYGPATH_W) '$(srcdir)/netlink_crypto.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-netlink_smc_diag.o `test -f 'netlink_smc_diag.c' || echo '$(srcdir)/'`netlink_smc_diag.c
 
-strace-netlink_inet_diag.o: netlink_inet_diag.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-netlink_inet_diag.o -MD -MP -MF $(DEPDIR)/strace-netlink_inet_diag.Tpo -c -o strace-netlink_inet_diag.o `test -f 'netlink_inet_diag.c' || echo '$(srcdir)/'`netlink_inet_diag.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-netlink_inet_diag.Tpo $(DEPDIR)/strace-netlink_inet_diag.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_inet_diag.c' object='strace-netlink_inet_diag.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-netlink_smc_diag.obj: netlink_smc_diag.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-netlink_smc_diag.obj -MD -MP -MF $(DEPDIR)/libstrace_a-netlink_smc_diag.Tpo -c -o libstrace_a-netlink_smc_diag.obj `if test -f 'netlink_smc_diag.c'; then $(CYGPATH_W) 'netlink_smc_diag.c'; else $(CYGPATH_W) '$(srcdir)/netlink_smc_diag.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-netlink_smc_diag.Tpo $(DEPDIR)/libstrace_a-netlink_smc_diag.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_smc_diag.c' object='libstrace_a-netlink_smc_diag.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-netlink_inet_diag.o `test -f 'netlink_inet_diag.c' || echo '$(srcdir)/'`netlink_inet_diag.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-netlink_smc_diag.obj `if test -f 'netlink_smc_diag.c'; then $(CYGPATH_W) 'netlink_smc_diag.c'; else $(CYGPATH_W) '$(srcdir)/netlink_smc_diag.c'; fi`
 
-strace-netlink_inet_diag.obj: netlink_inet_diag.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-netlink_inet_diag.obj -MD -MP -MF $(DEPDIR)/strace-netlink_inet_diag.Tpo -c -o strace-netlink_inet_diag.obj `if test -f 'netlink_inet_diag.c'; then $(CYGPATH_W) 'netlink_inet_diag.c'; else $(CYGPATH_W) '$(srcdir)/netlink_inet_diag.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-netlink_inet_diag.Tpo $(DEPDIR)/strace-netlink_inet_diag.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_inet_diag.c' object='strace-netlink_inet_diag.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-netlink_sock_diag.o: netlink_sock_diag.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-netlink_sock_diag.o -MD -MP -MF $(DEPDIR)/libstrace_a-netlink_sock_diag.Tpo -c -o libstrace_a-netlink_sock_diag.o `test -f 'netlink_sock_diag.c' || echo '$(srcdir)/'`netlink_sock_diag.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-netlink_sock_diag.Tpo $(DEPDIR)/libstrace_a-netlink_sock_diag.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_sock_diag.c' object='libstrace_a-netlink_sock_diag.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-netlink_inet_diag.obj `if test -f 'netlink_inet_diag.c'; then $(CYGPATH_W) 'netlink_inet_diag.c'; else $(CYGPATH_W) '$(srcdir)/netlink_inet_diag.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-netlink_sock_diag.o `test -f 'netlink_sock_diag.c' || echo '$(srcdir)/'`netlink_sock_diag.c
 
-strace-netlink_kobject_uevent.o: netlink_kobject_uevent.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-netlink_kobject_uevent.o -MD -MP -MF $(DEPDIR)/strace-netlink_kobject_uevent.Tpo -c -o strace-netlink_kobject_uevent.o `test -f 'netlink_kobject_uevent.c' || echo '$(srcdir)/'`netlink_kobject_uevent.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-netlink_kobject_uevent.Tpo $(DEPDIR)/strace-netlink_kobject_uevent.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_kobject_uevent.c' object='strace-netlink_kobject_uevent.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-netlink_sock_diag.obj: netlink_sock_diag.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-netlink_sock_diag.obj -MD -MP -MF $(DEPDIR)/libstrace_a-netlink_sock_diag.Tpo -c -o libstrace_a-netlink_sock_diag.obj `if test -f 'netlink_sock_diag.c'; then $(CYGPATH_W) 'netlink_sock_diag.c'; else $(CYGPATH_W) '$(srcdir)/netlink_sock_diag.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-netlink_sock_diag.Tpo $(DEPDIR)/libstrace_a-netlink_sock_diag.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_sock_diag.c' object='libstrace_a-netlink_sock_diag.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-netlink_kobject_uevent.o `test -f 'netlink_kobject_uevent.c' || echo '$(srcdir)/'`netlink_kobject_uevent.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-netlink_sock_diag.obj `if test -f 'netlink_sock_diag.c'; then $(CYGPATH_W) 'netlink_sock_diag.c'; else $(CYGPATH_W) '$(srcdir)/netlink_sock_diag.c'; fi`
 
-strace-netlink_kobject_uevent.obj: netlink_kobject_uevent.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-netlink_kobject_uevent.obj -MD -MP -MF $(DEPDIR)/strace-netlink_kobject_uevent.Tpo -c -o strace-netlink_kobject_uevent.obj `if test -f 'netlink_kobject_uevent.c'; then $(CYGPATH_W) 'netlink_kobject_uevent.c'; else $(CYGPATH_W) '$(srcdir)/netlink_kobject_uevent.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-netlink_kobject_uevent.Tpo $(DEPDIR)/strace-netlink_kobject_uevent.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_kobject_uevent.c' object='strace-netlink_kobject_uevent.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-netlink_unix_diag.o: netlink_unix_diag.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-netlink_unix_diag.o -MD -MP -MF $(DEPDIR)/libstrace_a-netlink_unix_diag.Tpo -c -o libstrace_a-netlink_unix_diag.o `test -f 'netlink_unix_diag.c' || echo '$(srcdir)/'`netlink_unix_diag.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-netlink_unix_diag.Tpo $(DEPDIR)/libstrace_a-netlink_unix_diag.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_unix_diag.c' object='libstrace_a-netlink_unix_diag.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-netlink_kobject_uevent.obj `if test -f 'netlink_kobject_uevent.c'; then $(CYGPATH_W) 'netlink_kobject_uevent.c'; else $(CYGPATH_W) '$(srcdir)/netlink_kobject_uevent.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-netlink_unix_diag.o `test -f 'netlink_unix_diag.c' || echo '$(srcdir)/'`netlink_unix_diag.c
 
-strace-netlink_netfilter.o: netlink_netfilter.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-netlink_netfilter.o -MD -MP -MF $(DEPDIR)/strace-netlink_netfilter.Tpo -c -o strace-netlink_netfilter.o `test -f 'netlink_netfilter.c' || echo '$(srcdir)/'`netlink_netfilter.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-netlink_netfilter.Tpo $(DEPDIR)/strace-netlink_netfilter.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_netfilter.c' object='strace-netlink_netfilter.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-netlink_unix_diag.obj: netlink_unix_diag.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-netlink_unix_diag.obj -MD -MP -MF $(DEPDIR)/libstrace_a-netlink_unix_diag.Tpo -c -o libstrace_a-netlink_unix_diag.obj `if test -f 'netlink_unix_diag.c'; then $(CYGPATH_W) 'netlink_unix_diag.c'; else $(CYGPATH_W) '$(srcdir)/netlink_unix_diag.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-netlink_unix_diag.Tpo $(DEPDIR)/libstrace_a-netlink_unix_diag.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_unix_diag.c' object='libstrace_a-netlink_unix_diag.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-netlink_netfilter.o `test -f 'netlink_netfilter.c' || echo '$(srcdir)/'`netlink_netfilter.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-netlink_unix_diag.obj `if test -f 'netlink_unix_diag.c'; then $(CYGPATH_W) 'netlink_unix_diag.c'; else $(CYGPATH_W) '$(srcdir)/netlink_unix_diag.c'; fi`
 
-strace-netlink_netfilter.obj: netlink_netfilter.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-netlink_netfilter.obj -MD -MP -MF $(DEPDIR)/strace-netlink_netfilter.Tpo -c -o strace-netlink_netfilter.obj `if test -f 'netlink_netfilter.c'; then $(CYGPATH_W) 'netlink_netfilter.c'; else $(CYGPATH_W) '$(srcdir)/netlink_netfilter.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-netlink_netfilter.Tpo $(DEPDIR)/strace-netlink_netfilter.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_netfilter.c' object='strace-netlink_netfilter.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-nlattr.o: nlattr.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-nlattr.o -MD -MP -MF $(DEPDIR)/libstrace_a-nlattr.Tpo -c -o libstrace_a-nlattr.o `test -f 'nlattr.c' || echo '$(srcdir)/'`nlattr.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-nlattr.Tpo $(DEPDIR)/libstrace_a-nlattr.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='nlattr.c' object='libstrace_a-nlattr.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-netlink_netfilter.obj `if test -f 'netlink_netfilter.c'; then $(CYGPATH_W) 'netlink_netfilter.c'; else $(CYGPATH_W) '$(srcdir)/netlink_netfilter.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-nlattr.o `test -f 'nlattr.c' || echo '$(srcdir)/'`nlattr.c
 
-strace-netlink_netlink_diag.o: netlink_netlink_diag.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-netlink_netlink_diag.o -MD -MP -MF $(DEPDIR)/strace-netlink_netlink_diag.Tpo -c -o strace-netlink_netlink_diag.o `test -f 'netlink_netlink_diag.c' || echo '$(srcdir)/'`netlink_netlink_diag.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-netlink_netlink_diag.Tpo $(DEPDIR)/strace-netlink_netlink_diag.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_netlink_diag.c' object='strace-netlink_netlink_diag.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-nlattr.obj: nlattr.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-nlattr.obj -MD -MP -MF $(DEPDIR)/libstrace_a-nlattr.Tpo -c -o libstrace_a-nlattr.obj `if test -f 'nlattr.c'; then $(CYGPATH_W) 'nlattr.c'; else $(CYGPATH_W) '$(srcdir)/nlattr.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-nlattr.Tpo $(DEPDIR)/libstrace_a-nlattr.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='nlattr.c' object='libstrace_a-nlattr.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-netlink_netlink_diag.o `test -f 'netlink_netlink_diag.c' || echo '$(srcdir)/'`netlink_netlink_diag.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-nlattr.obj `if test -f 'nlattr.c'; then $(CYGPATH_W) 'nlattr.c'; else $(CYGPATH_W) '$(srcdir)/nlattr.c'; fi`
 
-strace-netlink_netlink_diag.obj: netlink_netlink_diag.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-netlink_netlink_diag.obj -MD -MP -MF $(DEPDIR)/strace-netlink_netlink_diag.Tpo -c -o strace-netlink_netlink_diag.obj `if test -f 'netlink_netlink_diag.c'; then $(CYGPATH_W) 'netlink_netlink_diag.c'; else $(CYGPATH_W) '$(srcdir)/netlink_netlink_diag.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-netlink_netlink_diag.Tpo $(DEPDIR)/strace-netlink_netlink_diag.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_netlink_diag.c' object='strace-netlink_netlink_diag.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-nsfs.o: nsfs.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-nsfs.o -MD -MP -MF $(DEPDIR)/libstrace_a-nsfs.Tpo -c -o libstrace_a-nsfs.o `test -f 'nsfs.c' || echo '$(srcdir)/'`nsfs.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-nsfs.Tpo $(DEPDIR)/libstrace_a-nsfs.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='nsfs.c' object='libstrace_a-nsfs.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-netlink_netlink_diag.obj `if test -f 'netlink_netlink_diag.c'; then $(CYGPATH_W) 'netlink_netlink_diag.c'; else $(CYGPATH_W) '$(srcdir)/netlink_netlink_diag.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-nsfs.o `test -f 'nsfs.c' || echo '$(srcdir)/'`nsfs.c
 
-strace-netlink_packet_diag.o: netlink_packet_diag.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-netlink_packet_diag.o -MD -MP -MF $(DEPDIR)/strace-netlink_packet_diag.Tpo -c -o strace-netlink_packet_diag.o `test -f 'netlink_packet_diag.c' || echo '$(srcdir)/'`netlink_packet_diag.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-netlink_packet_diag.Tpo $(DEPDIR)/strace-netlink_packet_diag.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_packet_diag.c' object='strace-netlink_packet_diag.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-nsfs.obj: nsfs.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-nsfs.obj -MD -MP -MF $(DEPDIR)/libstrace_a-nsfs.Tpo -c -o libstrace_a-nsfs.obj `if test -f 'nsfs.c'; then $(CYGPATH_W) 'nsfs.c'; else $(CYGPATH_W) '$(srcdir)/nsfs.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-nsfs.Tpo $(DEPDIR)/libstrace_a-nsfs.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='nsfs.c' object='libstrace_a-nsfs.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-netlink_packet_diag.o `test -f 'netlink_packet_diag.c' || echo '$(srcdir)/'`netlink_packet_diag.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-nsfs.obj `if test -f 'nsfs.c'; then $(CYGPATH_W) 'nsfs.c'; else $(CYGPATH_W) '$(srcdir)/nsfs.c'; fi`
 
-strace-netlink_packet_diag.obj: netlink_packet_diag.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-netlink_packet_diag.obj -MD -MP -MF $(DEPDIR)/strace-netlink_packet_diag.Tpo -c -o strace-netlink_packet_diag.obj `if test -f 'netlink_packet_diag.c'; then $(CYGPATH_W) 'netlink_packet_diag.c'; else $(CYGPATH_W) '$(srcdir)/netlink_packet_diag.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-netlink_packet_diag.Tpo $(DEPDIR)/strace-netlink_packet_diag.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_packet_diag.c' object='strace-netlink_packet_diag.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-numa.o: numa.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-numa.o -MD -MP -MF $(DEPDIR)/libstrace_a-numa.Tpo -c -o libstrace_a-numa.o `test -f 'numa.c' || echo '$(srcdir)/'`numa.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-numa.Tpo $(DEPDIR)/libstrace_a-numa.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='numa.c' object='libstrace_a-numa.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-netlink_packet_diag.obj `if test -f 'netlink_packet_diag.c'; then $(CYGPATH_W) 'netlink_packet_diag.c'; else $(CYGPATH_W) '$(srcdir)/netlink_packet_diag.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-numa.o `test -f 'numa.c' || echo '$(srcdir)/'`numa.c
 
-strace-netlink_route.o: netlink_route.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-netlink_route.o -MD -MP -MF $(DEPDIR)/strace-netlink_route.Tpo -c -o strace-netlink_route.o `test -f 'netlink_route.c' || echo '$(srcdir)/'`netlink_route.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-netlink_route.Tpo $(DEPDIR)/strace-netlink_route.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_route.c' object='strace-netlink_route.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-numa.obj: numa.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-numa.obj -MD -MP -MF $(DEPDIR)/libstrace_a-numa.Tpo -c -o libstrace_a-numa.obj `if test -f 'numa.c'; then $(CYGPATH_W) 'numa.c'; else $(CYGPATH_W) '$(srcdir)/numa.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-numa.Tpo $(DEPDIR)/libstrace_a-numa.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='numa.c' object='libstrace_a-numa.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-netlink_route.o `test -f 'netlink_route.c' || echo '$(srcdir)/'`netlink_route.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-numa.obj `if test -f 'numa.c'; then $(CYGPATH_W) 'numa.c'; else $(CYGPATH_W) '$(srcdir)/numa.c'; fi`
 
-strace-netlink_route.obj: netlink_route.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-netlink_route.obj -MD -MP -MF $(DEPDIR)/strace-netlink_route.Tpo -c -o strace-netlink_route.obj `if test -f 'netlink_route.c'; then $(CYGPATH_W) 'netlink_route.c'; else $(CYGPATH_W) '$(srcdir)/netlink_route.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-netlink_route.Tpo $(DEPDIR)/strace-netlink_route.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_route.c' object='strace-netlink_route.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-number_set.o: number_set.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-number_set.o -MD -MP -MF $(DEPDIR)/libstrace_a-number_set.Tpo -c -o libstrace_a-number_set.o `test -f 'number_set.c' || echo '$(srcdir)/'`number_set.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-number_set.Tpo $(DEPDIR)/libstrace_a-number_set.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='number_set.c' object='libstrace_a-number_set.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-netlink_route.obj `if test -f 'netlink_route.c'; then $(CYGPATH_W) 'netlink_route.c'; else $(CYGPATH_W) '$(srcdir)/netlink_route.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-number_set.o `test -f 'number_set.c' || echo '$(srcdir)/'`number_set.c
 
-strace-netlink_selinux.o: netlink_selinux.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-netlink_selinux.o -MD -MP -MF $(DEPDIR)/strace-netlink_selinux.Tpo -c -o strace-netlink_selinux.o `test -f 'netlink_selinux.c' || echo '$(srcdir)/'`netlink_selinux.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-netlink_selinux.Tpo $(DEPDIR)/strace-netlink_selinux.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_selinux.c' object='strace-netlink_selinux.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-number_set.obj: number_set.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-number_set.obj -MD -MP -MF $(DEPDIR)/libstrace_a-number_set.Tpo -c -o libstrace_a-number_set.obj `if test -f 'number_set.c'; then $(CYGPATH_W) 'number_set.c'; else $(CYGPATH_W) '$(srcdir)/number_set.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-number_set.Tpo $(DEPDIR)/libstrace_a-number_set.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='number_set.c' object='libstrace_a-number_set.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-netlink_selinux.o `test -f 'netlink_selinux.c' || echo '$(srcdir)/'`netlink_selinux.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-number_set.obj `if test -f 'number_set.c'; then $(CYGPATH_W) 'number_set.c'; else $(CYGPATH_W) '$(srcdir)/number_set.c'; fi`
 
-strace-netlink_selinux.obj: netlink_selinux.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-netlink_selinux.obj -MD -MP -MF $(DEPDIR)/strace-netlink_selinux.Tpo -c -o strace-netlink_selinux.obj `if test -f 'netlink_selinux.c'; then $(CYGPATH_W) 'netlink_selinux.c'; else $(CYGPATH_W) '$(srcdir)/netlink_selinux.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-netlink_selinux.Tpo $(DEPDIR)/strace-netlink_selinux.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_selinux.c' object='strace-netlink_selinux.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-oldstat.o: oldstat.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-oldstat.o -MD -MP -MF $(DEPDIR)/libstrace_a-oldstat.Tpo -c -o libstrace_a-oldstat.o `test -f 'oldstat.c' || echo '$(srcdir)/'`oldstat.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-oldstat.Tpo $(DEPDIR)/libstrace_a-oldstat.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='oldstat.c' object='libstrace_a-oldstat.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-netlink_selinux.obj `if test -f 'netlink_selinux.c'; then $(CYGPATH_W) 'netlink_selinux.c'; else $(CYGPATH_W) '$(srcdir)/netlink_selinux.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-oldstat.o `test -f 'oldstat.c' || echo '$(srcdir)/'`oldstat.c
 
-strace-netlink_smc_diag.o: netlink_smc_diag.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-netlink_smc_diag.o -MD -MP -MF $(DEPDIR)/strace-netlink_smc_diag.Tpo -c -o strace-netlink_smc_diag.o `test -f 'netlink_smc_diag.c' || echo '$(srcdir)/'`netlink_smc_diag.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-netlink_smc_diag.Tpo $(DEPDIR)/strace-netlink_smc_diag.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_smc_diag.c' object='strace-netlink_smc_diag.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-oldstat.obj: oldstat.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-oldstat.obj -MD -MP -MF $(DEPDIR)/libstrace_a-oldstat.Tpo -c -o libstrace_a-oldstat.obj `if test -f 'oldstat.c'; then $(CYGPATH_W) 'oldstat.c'; else $(CYGPATH_W) '$(srcdir)/oldstat.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-oldstat.Tpo $(DEPDIR)/libstrace_a-oldstat.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='oldstat.c' object='libstrace_a-oldstat.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-netlink_smc_diag.o `test -f 'netlink_smc_diag.c' || echo '$(srcdir)/'`netlink_smc_diag.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-oldstat.obj `if test -f 'oldstat.c'; then $(CYGPATH_W) 'oldstat.c'; else $(CYGPATH_W) '$(srcdir)/oldstat.c'; fi`
 
-strace-netlink_smc_diag.obj: netlink_smc_diag.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-netlink_smc_diag.obj -MD -MP -MF $(DEPDIR)/strace-netlink_smc_diag.Tpo -c -o strace-netlink_smc_diag.obj `if test -f 'netlink_smc_diag.c'; then $(CYGPATH_W) 'netlink_smc_diag.c'; else $(CYGPATH_W) '$(srcdir)/netlink_smc_diag.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-netlink_smc_diag.Tpo $(DEPDIR)/strace-netlink_smc_diag.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_smc_diag.c' object='strace-netlink_smc_diag.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-open.o: open.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-open.o -MD -MP -MF $(DEPDIR)/libstrace_a-open.Tpo -c -o libstrace_a-open.o `test -f 'open.c' || echo '$(srcdir)/'`open.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-open.Tpo $(DEPDIR)/libstrace_a-open.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='open.c' object='libstrace_a-open.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-netlink_smc_diag.obj `if test -f 'netlink_smc_diag.c'; then $(CYGPATH_W) 'netlink_smc_diag.c'; else $(CYGPATH_W) '$(srcdir)/netlink_smc_diag.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-open.o `test -f 'open.c' || echo '$(srcdir)/'`open.c
 
-strace-netlink_sock_diag.o: netlink_sock_diag.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-netlink_sock_diag.o -MD -MP -MF $(DEPDIR)/strace-netlink_sock_diag.Tpo -c -o strace-netlink_sock_diag.o `test -f 'netlink_sock_diag.c' || echo '$(srcdir)/'`netlink_sock_diag.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-netlink_sock_diag.Tpo $(DEPDIR)/strace-netlink_sock_diag.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_sock_diag.c' object='strace-netlink_sock_diag.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-open.obj: open.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-open.obj -MD -MP -MF $(DEPDIR)/libstrace_a-open.Tpo -c -o libstrace_a-open.obj `if test -f 'open.c'; then $(CYGPATH_W) 'open.c'; else $(CYGPATH_W) '$(srcdir)/open.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-open.Tpo $(DEPDIR)/libstrace_a-open.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='open.c' object='libstrace_a-open.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-netlink_sock_diag.o `test -f 'netlink_sock_diag.c' || echo '$(srcdir)/'`netlink_sock_diag.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-open.obj `if test -f 'open.c'; then $(CYGPATH_W) 'open.c'; else $(CYGPATH_W) '$(srcdir)/open.c'; fi`
 
-strace-netlink_sock_diag.obj: netlink_sock_diag.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-netlink_sock_diag.obj -MD -MP -MF $(DEPDIR)/strace-netlink_sock_diag.Tpo -c -o strace-netlink_sock_diag.obj `if test -f 'netlink_sock_diag.c'; then $(CYGPATH_W) 'netlink_sock_diag.c'; else $(CYGPATH_W) '$(srcdir)/netlink_sock_diag.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-netlink_sock_diag.Tpo $(DEPDIR)/strace-netlink_sock_diag.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_sock_diag.c' object='strace-netlink_sock_diag.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-open_tree.o: open_tree.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-open_tree.o -MD -MP -MF $(DEPDIR)/libstrace_a-open_tree.Tpo -c -o libstrace_a-open_tree.o `test -f 'open_tree.c' || echo '$(srcdir)/'`open_tree.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-open_tree.Tpo $(DEPDIR)/libstrace_a-open_tree.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='open_tree.c' object='libstrace_a-open_tree.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-netlink_sock_diag.obj `if test -f 'netlink_sock_diag.c'; then $(CYGPATH_W) 'netlink_sock_diag.c'; else $(CYGPATH_W) '$(srcdir)/netlink_sock_diag.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-open_tree.o `test -f 'open_tree.c' || echo '$(srcdir)/'`open_tree.c
 
-strace-netlink_unix_diag.o: netlink_unix_diag.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-netlink_unix_diag.o -MD -MP -MF $(DEPDIR)/strace-netlink_unix_diag.Tpo -c -o strace-netlink_unix_diag.o `test -f 'netlink_unix_diag.c' || echo '$(srcdir)/'`netlink_unix_diag.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-netlink_unix_diag.Tpo $(DEPDIR)/strace-netlink_unix_diag.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_unix_diag.c' object='strace-netlink_unix_diag.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-open_tree.obj: open_tree.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-open_tree.obj -MD -MP -MF $(DEPDIR)/libstrace_a-open_tree.Tpo -c -o libstrace_a-open_tree.obj `if test -f 'open_tree.c'; then $(CYGPATH_W) 'open_tree.c'; else $(CYGPATH_W) '$(srcdir)/open_tree.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-open_tree.Tpo $(DEPDIR)/libstrace_a-open_tree.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='open_tree.c' object='libstrace_a-open_tree.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-netlink_unix_diag.o `test -f 'netlink_unix_diag.c' || echo '$(srcdir)/'`netlink_unix_diag.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-open_tree.obj `if test -f 'open_tree.c'; then $(CYGPATH_W) 'open_tree.c'; else $(CYGPATH_W) '$(srcdir)/open_tree.c'; fi`
 
-strace-netlink_unix_diag.obj: netlink_unix_diag.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-netlink_unix_diag.obj -MD -MP -MF $(DEPDIR)/strace-netlink_unix_diag.Tpo -c -o strace-netlink_unix_diag.obj `if test -f 'netlink_unix_diag.c'; then $(CYGPATH_W) 'netlink_unix_diag.c'; else $(CYGPATH_W) '$(srcdir)/netlink_unix_diag.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-netlink_unix_diag.Tpo $(DEPDIR)/strace-netlink_unix_diag.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='netlink_unix_diag.c' object='strace-netlink_unix_diag.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-or1k_atomic.o: or1k_atomic.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-or1k_atomic.o -MD -MP -MF $(DEPDIR)/libstrace_a-or1k_atomic.Tpo -c -o libstrace_a-or1k_atomic.o `test -f 'or1k_atomic.c' || echo '$(srcdir)/'`or1k_atomic.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-or1k_atomic.Tpo $(DEPDIR)/libstrace_a-or1k_atomic.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='or1k_atomic.c' object='libstrace_a-or1k_atomic.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-netlink_unix_diag.obj `if test -f 'netlink_unix_diag.c'; then $(CYGPATH_W) 'netlink_unix_diag.c'; else $(CYGPATH_W) '$(srcdir)/netlink_unix_diag.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-or1k_atomic.o `test -f 'or1k_atomic.c' || echo '$(srcdir)/'`or1k_atomic.c
 
-strace-nlattr.o: nlattr.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-nlattr.o -MD -MP -MF $(DEPDIR)/strace-nlattr.Tpo -c -o strace-nlattr.o `test -f 'nlattr.c' || echo '$(srcdir)/'`nlattr.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-nlattr.Tpo $(DEPDIR)/strace-nlattr.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='nlattr.c' object='strace-nlattr.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-or1k_atomic.obj: or1k_atomic.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-or1k_atomic.obj -MD -MP -MF $(DEPDIR)/libstrace_a-or1k_atomic.Tpo -c -o libstrace_a-or1k_atomic.obj `if test -f 'or1k_atomic.c'; then $(CYGPATH_W) 'or1k_atomic.c'; else $(CYGPATH_W) '$(srcdir)/or1k_atomic.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-or1k_atomic.Tpo $(DEPDIR)/libstrace_a-or1k_atomic.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='or1k_atomic.c' object='libstrace_a-or1k_atomic.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-nlattr.o `test -f 'nlattr.c' || echo '$(srcdir)/'`nlattr.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-or1k_atomic.obj `if test -f 'or1k_atomic.c'; then $(CYGPATH_W) 'or1k_atomic.c'; else $(CYGPATH_W) '$(srcdir)/or1k_atomic.c'; fi`
 
-strace-nlattr.obj: nlattr.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-nlattr.obj -MD -MP -MF $(DEPDIR)/strace-nlattr.Tpo -c -o strace-nlattr.obj `if test -f 'nlattr.c'; then $(CYGPATH_W) 'nlattr.c'; else $(CYGPATH_W) '$(srcdir)/nlattr.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-nlattr.Tpo $(DEPDIR)/strace-nlattr.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='nlattr.c' object='strace-nlattr.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-pathtrace.o: pathtrace.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-pathtrace.o -MD -MP -MF $(DEPDIR)/libstrace_a-pathtrace.Tpo -c -o libstrace_a-pathtrace.o `test -f 'pathtrace.c' || echo '$(srcdir)/'`pathtrace.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-pathtrace.Tpo $(DEPDIR)/libstrace_a-pathtrace.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='pathtrace.c' object='libstrace_a-pathtrace.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-nlattr.obj `if test -f 'nlattr.c'; then $(CYGPATH_W) 'nlattr.c'; else $(CYGPATH_W) '$(srcdir)/nlattr.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-pathtrace.o `test -f 'pathtrace.c' || echo '$(srcdir)/'`pathtrace.c
 
-strace-nsfs.o: nsfs.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-nsfs.o -MD -MP -MF $(DEPDIR)/strace-nsfs.Tpo -c -o strace-nsfs.o `test -f 'nsfs.c' || echo '$(srcdir)/'`nsfs.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-nsfs.Tpo $(DEPDIR)/strace-nsfs.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='nsfs.c' object='strace-nsfs.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-pathtrace.obj: pathtrace.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-pathtrace.obj -MD -MP -MF $(DEPDIR)/libstrace_a-pathtrace.Tpo -c -o libstrace_a-pathtrace.obj `if test -f 'pathtrace.c'; then $(CYGPATH_W) 'pathtrace.c'; else $(CYGPATH_W) '$(srcdir)/pathtrace.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-pathtrace.Tpo $(DEPDIR)/libstrace_a-pathtrace.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='pathtrace.c' object='libstrace_a-pathtrace.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-nsfs.o `test -f 'nsfs.c' || echo '$(srcdir)/'`nsfs.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-pathtrace.obj `if test -f 'pathtrace.c'; then $(CYGPATH_W) 'pathtrace.c'; else $(CYGPATH_W) '$(srcdir)/pathtrace.c'; fi`
 
-strace-nsfs.obj: nsfs.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-nsfs.obj -MD -MP -MF $(DEPDIR)/strace-nsfs.Tpo -c -o strace-nsfs.obj `if test -f 'nsfs.c'; then $(CYGPATH_W) 'nsfs.c'; else $(CYGPATH_W) '$(srcdir)/nsfs.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-nsfs.Tpo $(DEPDIR)/strace-nsfs.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='nsfs.c' object='strace-nsfs.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-perf.o: perf.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-perf.o -MD -MP -MF $(DEPDIR)/libstrace_a-perf.Tpo -c -o libstrace_a-perf.o `test -f 'perf.c' || echo '$(srcdir)/'`perf.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-perf.Tpo $(DEPDIR)/libstrace_a-perf.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='perf.c' object='libstrace_a-perf.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-nsfs.obj `if test -f 'nsfs.c'; then $(CYGPATH_W) 'nsfs.c'; else $(CYGPATH_W) '$(srcdir)/nsfs.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-perf.o `test -f 'perf.c' || echo '$(srcdir)/'`perf.c
 
-strace-numa.o: numa.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-numa.o -MD -MP -MF $(DEPDIR)/strace-numa.Tpo -c -o strace-numa.o `test -f 'numa.c' || echo '$(srcdir)/'`numa.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-numa.Tpo $(DEPDIR)/strace-numa.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='numa.c' object='strace-numa.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-perf.obj: perf.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-perf.obj -MD -MP -MF $(DEPDIR)/libstrace_a-perf.Tpo -c -o libstrace_a-perf.obj `if test -f 'perf.c'; then $(CYGPATH_W) 'perf.c'; else $(CYGPATH_W) '$(srcdir)/perf.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-perf.Tpo $(DEPDIR)/libstrace_a-perf.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='perf.c' object='libstrace_a-perf.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-numa.o `test -f 'numa.c' || echo '$(srcdir)/'`numa.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-perf.obj `if test -f 'perf.c'; then $(CYGPATH_W) 'perf.c'; else $(CYGPATH_W) '$(srcdir)/perf.c'; fi`
 
-strace-numa.obj: numa.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-numa.obj -MD -MP -MF $(DEPDIR)/strace-numa.Tpo -c -o strace-numa.obj `if test -f 'numa.c'; then $(CYGPATH_W) 'numa.c'; else $(CYGPATH_W) '$(srcdir)/numa.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-numa.Tpo $(DEPDIR)/strace-numa.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='numa.c' object='strace-numa.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-perf_ioctl.o: perf_ioctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-perf_ioctl.o -MD -MP -MF $(DEPDIR)/libstrace_a-perf_ioctl.Tpo -c -o libstrace_a-perf_ioctl.o `test -f 'perf_ioctl.c' || echo '$(srcdir)/'`perf_ioctl.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-perf_ioctl.Tpo $(DEPDIR)/libstrace_a-perf_ioctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='perf_ioctl.c' object='libstrace_a-perf_ioctl.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-numa.obj `if test -f 'numa.c'; then $(CYGPATH_W) 'numa.c'; else $(CYGPATH_W) '$(srcdir)/numa.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-perf_ioctl.o `test -f 'perf_ioctl.c' || echo '$(srcdir)/'`perf_ioctl.c
 
-strace-number_set.o: number_set.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-number_set.o -MD -MP -MF $(DEPDIR)/strace-number_set.Tpo -c -o strace-number_set.o `test -f 'number_set.c' || echo '$(srcdir)/'`number_set.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-number_set.Tpo $(DEPDIR)/strace-number_set.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='number_set.c' object='strace-number_set.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-perf_ioctl.obj: perf_ioctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-perf_ioctl.obj -MD -MP -MF $(DEPDIR)/libstrace_a-perf_ioctl.Tpo -c -o libstrace_a-perf_ioctl.obj `if test -f 'perf_ioctl.c'; then $(CYGPATH_W) 'perf_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/perf_ioctl.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-perf_ioctl.Tpo $(DEPDIR)/libstrace_a-perf_ioctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='perf_ioctl.c' object='libstrace_a-perf_ioctl.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-number_set.o `test -f 'number_set.c' || echo '$(srcdir)/'`number_set.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-perf_ioctl.obj `if test -f 'perf_ioctl.c'; then $(CYGPATH_W) 'perf_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/perf_ioctl.c'; fi`
 
-strace-number_set.obj: number_set.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-number_set.obj -MD -MP -MF $(DEPDIR)/strace-number_set.Tpo -c -o strace-number_set.obj `if test -f 'number_set.c'; then $(CYGPATH_W) 'number_set.c'; else $(CYGPATH_W) '$(srcdir)/number_set.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-number_set.Tpo $(DEPDIR)/strace-number_set.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='number_set.c' object='strace-number_set.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-personality.o: personality.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-personality.o -MD -MP -MF $(DEPDIR)/libstrace_a-personality.Tpo -c -o libstrace_a-personality.o `test -f 'personality.c' || echo '$(srcdir)/'`personality.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-personality.Tpo $(DEPDIR)/libstrace_a-personality.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='personality.c' object='libstrace_a-personality.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-number_set.obj `if test -f 'number_set.c'; then $(CYGPATH_W) 'number_set.c'; else $(CYGPATH_W) '$(srcdir)/number_set.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-personality.o `test -f 'personality.c' || echo '$(srcdir)/'`personality.c
 
-strace-oldstat.o: oldstat.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-oldstat.o -MD -MP -MF $(DEPDIR)/strace-oldstat.Tpo -c -o strace-oldstat.o `test -f 'oldstat.c' || echo '$(srcdir)/'`oldstat.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-oldstat.Tpo $(DEPDIR)/strace-oldstat.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='oldstat.c' object='strace-oldstat.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-personality.obj: personality.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-personality.obj -MD -MP -MF $(DEPDIR)/libstrace_a-personality.Tpo -c -o libstrace_a-personality.obj `if test -f 'personality.c'; then $(CYGPATH_W) 'personality.c'; else $(CYGPATH_W) '$(srcdir)/personality.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-personality.Tpo $(DEPDIR)/libstrace_a-personality.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='personality.c' object='libstrace_a-personality.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-oldstat.o `test -f 'oldstat.c' || echo '$(srcdir)/'`oldstat.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-personality.obj `if test -f 'personality.c'; then $(CYGPATH_W) 'personality.c'; else $(CYGPATH_W) '$(srcdir)/personality.c'; fi`
 
-strace-oldstat.obj: oldstat.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-oldstat.obj -MD -MP -MF $(DEPDIR)/strace-oldstat.Tpo -c -o strace-oldstat.obj `if test -f 'oldstat.c'; then $(CYGPATH_W) 'oldstat.c'; else $(CYGPATH_W) '$(srcdir)/oldstat.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-oldstat.Tpo $(DEPDIR)/strace-oldstat.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='oldstat.c' object='strace-oldstat.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-pidfd_getfd.o: pidfd_getfd.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-pidfd_getfd.o -MD -MP -MF $(DEPDIR)/libstrace_a-pidfd_getfd.Tpo -c -o libstrace_a-pidfd_getfd.o `test -f 'pidfd_getfd.c' || echo '$(srcdir)/'`pidfd_getfd.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-pidfd_getfd.Tpo $(DEPDIR)/libstrace_a-pidfd_getfd.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='pidfd_getfd.c' object='libstrace_a-pidfd_getfd.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-oldstat.obj `if test -f 'oldstat.c'; then $(CYGPATH_W) 'oldstat.c'; else $(CYGPATH_W) '$(srcdir)/oldstat.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-pidfd_getfd.o `test -f 'pidfd_getfd.c' || echo '$(srcdir)/'`pidfd_getfd.c
 
-strace-open.o: open.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-open.o -MD -MP -MF $(DEPDIR)/strace-open.Tpo -c -o strace-open.o `test -f 'open.c' || echo '$(srcdir)/'`open.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-open.Tpo $(DEPDIR)/strace-open.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='open.c' object='strace-open.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-pidfd_getfd.obj: pidfd_getfd.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-pidfd_getfd.obj -MD -MP -MF $(DEPDIR)/libstrace_a-pidfd_getfd.Tpo -c -o libstrace_a-pidfd_getfd.obj `if test -f 'pidfd_getfd.c'; then $(CYGPATH_W) 'pidfd_getfd.c'; else $(CYGPATH_W) '$(srcdir)/pidfd_getfd.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-pidfd_getfd.Tpo $(DEPDIR)/libstrace_a-pidfd_getfd.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='pidfd_getfd.c' object='libstrace_a-pidfd_getfd.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-open.o `test -f 'open.c' || echo '$(srcdir)/'`open.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-pidfd_getfd.obj `if test -f 'pidfd_getfd.c'; then $(CYGPATH_W) 'pidfd_getfd.c'; else $(CYGPATH_W) '$(srcdir)/pidfd_getfd.c'; fi`
 
-strace-open.obj: open.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-open.obj -MD -MP -MF $(DEPDIR)/strace-open.Tpo -c -o strace-open.obj `if test -f 'open.c'; then $(CYGPATH_W) 'open.c'; else $(CYGPATH_W) '$(srcdir)/open.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-open.Tpo $(DEPDIR)/strace-open.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='open.c' object='strace-open.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-pidfd_open.o: pidfd_open.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-pidfd_open.o -MD -MP -MF $(DEPDIR)/libstrace_a-pidfd_open.Tpo -c -o libstrace_a-pidfd_open.o `test -f 'pidfd_open.c' || echo '$(srcdir)/'`pidfd_open.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-pidfd_open.Tpo $(DEPDIR)/libstrace_a-pidfd_open.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='pidfd_open.c' object='libstrace_a-pidfd_open.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-open.obj `if test -f 'open.c'; then $(CYGPATH_W) 'open.c'; else $(CYGPATH_W) '$(srcdir)/open.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-pidfd_open.o `test -f 'pidfd_open.c' || echo '$(srcdir)/'`pidfd_open.c
 
-strace-open_tree.o: open_tree.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-open_tree.o -MD -MP -MF $(DEPDIR)/strace-open_tree.Tpo -c -o strace-open_tree.o `test -f 'open_tree.c' || echo '$(srcdir)/'`open_tree.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-open_tree.Tpo $(DEPDIR)/strace-open_tree.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='open_tree.c' object='strace-open_tree.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-pidfd_open.obj: pidfd_open.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-pidfd_open.obj -MD -MP -MF $(DEPDIR)/libstrace_a-pidfd_open.Tpo -c -o libstrace_a-pidfd_open.obj `if test -f 'pidfd_open.c'; then $(CYGPATH_W) 'pidfd_open.c'; else $(CYGPATH_W) '$(srcdir)/pidfd_open.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-pidfd_open.Tpo $(DEPDIR)/libstrace_a-pidfd_open.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='pidfd_open.c' object='libstrace_a-pidfd_open.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-open_tree.o `test -f 'open_tree.c' || echo '$(srcdir)/'`open_tree.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-pidfd_open.obj `if test -f 'pidfd_open.c'; then $(CYGPATH_W) 'pidfd_open.c'; else $(CYGPATH_W) '$(srcdir)/pidfd_open.c'; fi`
 
-strace-open_tree.obj: open_tree.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-open_tree.obj -MD -MP -MF $(DEPDIR)/strace-open_tree.Tpo -c -o strace-open_tree.obj `if test -f 'open_tree.c'; then $(CYGPATH_W) 'open_tree.c'; else $(CYGPATH_W) '$(srcdir)/open_tree.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-open_tree.Tpo $(DEPDIR)/strace-open_tree.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='open_tree.c' object='strace-open_tree.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-pidns.o: pidns.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-pidns.o -MD -MP -MF $(DEPDIR)/libstrace_a-pidns.Tpo -c -o libstrace_a-pidns.o `test -f 'pidns.c' || echo '$(srcdir)/'`pidns.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-pidns.Tpo $(DEPDIR)/libstrace_a-pidns.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='pidns.c' object='libstrace_a-pidns.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-open_tree.obj `if test -f 'open_tree.c'; then $(CYGPATH_W) 'open_tree.c'; else $(CYGPATH_W) '$(srcdir)/open_tree.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-pidns.o `test -f 'pidns.c' || echo '$(srcdir)/'`pidns.c
 
-strace-or1k_atomic.o: or1k_atomic.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-or1k_atomic.o -MD -MP -MF $(DEPDIR)/strace-or1k_atomic.Tpo -c -o strace-or1k_atomic.o `test -f 'or1k_atomic.c' || echo '$(srcdir)/'`or1k_atomic.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-or1k_atomic.Tpo $(DEPDIR)/strace-or1k_atomic.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='or1k_atomic.c' object='strace-or1k_atomic.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-pidns.obj: pidns.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-pidns.obj -MD -MP -MF $(DEPDIR)/libstrace_a-pidns.Tpo -c -o libstrace_a-pidns.obj `if test -f 'pidns.c'; then $(CYGPATH_W) 'pidns.c'; else $(CYGPATH_W) '$(srcdir)/pidns.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-pidns.Tpo $(DEPDIR)/libstrace_a-pidns.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='pidns.c' object='libstrace_a-pidns.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-or1k_atomic.o `test -f 'or1k_atomic.c' || echo '$(srcdir)/'`or1k_atomic.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-pidns.obj `if test -f 'pidns.c'; then $(CYGPATH_W) 'pidns.c'; else $(CYGPATH_W) '$(srcdir)/pidns.c'; fi`
 
-strace-or1k_atomic.obj: or1k_atomic.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-or1k_atomic.obj -MD -MP -MF $(DEPDIR)/strace-or1k_atomic.Tpo -c -o strace-or1k_atomic.obj `if test -f 'or1k_atomic.c'; then $(CYGPATH_W) 'or1k_atomic.c'; else $(CYGPATH_W) '$(srcdir)/or1k_atomic.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-or1k_atomic.Tpo $(DEPDIR)/strace-or1k_atomic.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='or1k_atomic.c' object='strace-or1k_atomic.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-pkeys.o: pkeys.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-pkeys.o -MD -MP -MF $(DEPDIR)/libstrace_a-pkeys.Tpo -c -o libstrace_a-pkeys.o `test -f 'pkeys.c' || echo '$(srcdir)/'`pkeys.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-pkeys.Tpo $(DEPDIR)/libstrace_a-pkeys.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='pkeys.c' object='libstrace_a-pkeys.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-or1k_atomic.obj `if test -f 'or1k_atomic.c'; then $(CYGPATH_W) 'or1k_atomic.c'; else $(CYGPATH_W) '$(srcdir)/or1k_atomic.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-pkeys.o `test -f 'pkeys.c' || echo '$(srcdir)/'`pkeys.c
 
-strace-pathtrace.o: pathtrace.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-pathtrace.o -MD -MP -MF $(DEPDIR)/strace-pathtrace.Tpo -c -o strace-pathtrace.o `test -f 'pathtrace.c' || echo '$(srcdir)/'`pathtrace.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-pathtrace.Tpo $(DEPDIR)/strace-pathtrace.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='pathtrace.c' object='strace-pathtrace.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-pkeys.obj: pkeys.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-pkeys.obj -MD -MP -MF $(DEPDIR)/libstrace_a-pkeys.Tpo -c -o libstrace_a-pkeys.obj `if test -f 'pkeys.c'; then $(CYGPATH_W) 'pkeys.c'; else $(CYGPATH_W) '$(srcdir)/pkeys.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-pkeys.Tpo $(DEPDIR)/libstrace_a-pkeys.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='pkeys.c' object='libstrace_a-pkeys.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-pathtrace.o `test -f 'pathtrace.c' || echo '$(srcdir)/'`pathtrace.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-pkeys.obj `if test -f 'pkeys.c'; then $(CYGPATH_W) 'pkeys.c'; else $(CYGPATH_W) '$(srcdir)/pkeys.c'; fi`
 
-strace-pathtrace.obj: pathtrace.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-pathtrace.obj -MD -MP -MF $(DEPDIR)/strace-pathtrace.Tpo -c -o strace-pathtrace.obj `if test -f 'pathtrace.c'; then $(CYGPATH_W) 'pathtrace.c'; else $(CYGPATH_W) '$(srcdir)/pathtrace.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-pathtrace.Tpo $(DEPDIR)/strace-pathtrace.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='pathtrace.c' object='strace-pathtrace.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-poll.o: poll.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-poll.o -MD -MP -MF $(DEPDIR)/libstrace_a-poll.Tpo -c -o libstrace_a-poll.o `test -f 'poll.c' || echo '$(srcdir)/'`poll.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-poll.Tpo $(DEPDIR)/libstrace_a-poll.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='poll.c' object='libstrace_a-poll.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-pathtrace.obj `if test -f 'pathtrace.c'; then $(CYGPATH_W) 'pathtrace.c'; else $(CYGPATH_W) '$(srcdir)/pathtrace.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-poll.o `test -f 'poll.c' || echo '$(srcdir)/'`poll.c
 
-strace-perf.o: perf.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-perf.o -MD -MP -MF $(DEPDIR)/strace-perf.Tpo -c -o strace-perf.o `test -f 'perf.c' || echo '$(srcdir)/'`perf.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-perf.Tpo $(DEPDIR)/strace-perf.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='perf.c' object='strace-perf.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-poll.obj: poll.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-poll.obj -MD -MP -MF $(DEPDIR)/libstrace_a-poll.Tpo -c -o libstrace_a-poll.obj `if test -f 'poll.c'; then $(CYGPATH_W) 'poll.c'; else $(CYGPATH_W) '$(srcdir)/poll.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-poll.Tpo $(DEPDIR)/libstrace_a-poll.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='poll.c' object='libstrace_a-poll.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-perf.o `test -f 'perf.c' || echo '$(srcdir)/'`perf.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-poll.obj `if test -f 'poll.c'; then $(CYGPATH_W) 'poll.c'; else $(CYGPATH_W) '$(srcdir)/poll.c'; fi`
 
-strace-perf.obj: perf.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-perf.obj -MD -MP -MF $(DEPDIR)/strace-perf.Tpo -c -o strace-perf.obj `if test -f 'perf.c'; then $(CYGPATH_W) 'perf.c'; else $(CYGPATH_W) '$(srcdir)/perf.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-perf.Tpo $(DEPDIR)/strace-perf.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='perf.c' object='strace-perf.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-prctl.o: prctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-prctl.o -MD -MP -MF $(DEPDIR)/libstrace_a-prctl.Tpo -c -o libstrace_a-prctl.o `test -f 'prctl.c' || echo '$(srcdir)/'`prctl.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-prctl.Tpo $(DEPDIR)/libstrace_a-prctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='prctl.c' object='libstrace_a-prctl.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-perf.obj `if test -f 'perf.c'; then $(CYGPATH_W) 'perf.c'; else $(CYGPATH_W) '$(srcdir)/perf.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-prctl.o `test -f 'prctl.c' || echo '$(srcdir)/'`prctl.c
 
-strace-perf_ioctl.o: perf_ioctl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-perf_ioctl.o -MD -MP -MF $(DEPDIR)/strace-perf_ioctl.Tpo -c -o strace-perf_ioctl.o `test -f 'perf_ioctl.c' || echo '$(srcdir)/'`perf_ioctl.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-perf_ioctl.Tpo $(DEPDIR)/strace-perf_ioctl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='perf_ioctl.c' object='strace-perf_ioctl.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-prctl.obj: prctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-prctl.obj -MD -MP -MF $(DEPDIR)/libstrace_a-prctl.Tpo -c -o libstrace_a-prctl.obj `if test -f 'prctl.c'; then $(CYGPATH_W) 'prctl.c'; else $(CYGPATH_W) '$(srcdir)/prctl.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-prctl.Tpo $(DEPDIR)/libstrace_a-prctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='prctl.c' object='libstrace_a-prctl.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-perf_ioctl.o `test -f 'perf_ioctl.c' || echo '$(srcdir)/'`perf_ioctl.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-prctl.obj `if test -f 'prctl.c'; then $(CYGPATH_W) 'prctl.c'; else $(CYGPATH_W) '$(srcdir)/prctl.c'; fi`
 
-strace-perf_ioctl.obj: perf_ioctl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-perf_ioctl.obj -MD -MP -MF $(DEPDIR)/strace-perf_ioctl.Tpo -c -o strace-perf_ioctl.obj `if test -f 'perf_ioctl.c'; then $(CYGPATH_W) 'perf_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/perf_ioctl.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-perf_ioctl.Tpo $(DEPDIR)/strace-perf_ioctl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='perf_ioctl.c' object='strace-perf_ioctl.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_aio_sigset.o: print_aio_sigset.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_aio_sigset.o -MD -MP -MF $(DEPDIR)/libstrace_a-print_aio_sigset.Tpo -c -o libstrace_a-print_aio_sigset.o `test -f 'print_aio_sigset.c' || echo '$(srcdir)/'`print_aio_sigset.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_aio_sigset.Tpo $(DEPDIR)/libstrace_a-print_aio_sigset.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_aio_sigset.c' object='libstrace_a-print_aio_sigset.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-perf_ioctl.obj `if test -f 'perf_ioctl.c'; then $(CYGPATH_W) 'perf_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/perf_ioctl.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_aio_sigset.o `test -f 'print_aio_sigset.c' || echo '$(srcdir)/'`print_aio_sigset.c
 
-strace-personality.o: personality.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-personality.o -MD -MP -MF $(DEPDIR)/strace-personality.Tpo -c -o strace-personality.o `test -f 'personality.c' || echo '$(srcdir)/'`personality.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-personality.Tpo $(DEPDIR)/strace-personality.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='personality.c' object='strace-personality.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_aio_sigset.obj: print_aio_sigset.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_aio_sigset.obj -MD -MP -MF $(DEPDIR)/libstrace_a-print_aio_sigset.Tpo -c -o libstrace_a-print_aio_sigset.obj `if test -f 'print_aio_sigset.c'; then $(CYGPATH_W) 'print_aio_sigset.c'; else $(CYGPATH_W) '$(srcdir)/print_aio_sigset.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_aio_sigset.Tpo $(DEPDIR)/libstrace_a-print_aio_sigset.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_aio_sigset.c' object='libstrace_a-print_aio_sigset.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-personality.o `test -f 'personality.c' || echo '$(srcdir)/'`personality.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_aio_sigset.obj `if test -f 'print_aio_sigset.c'; then $(CYGPATH_W) 'print_aio_sigset.c'; else $(CYGPATH_W) '$(srcdir)/print_aio_sigset.c'; fi`
 
-strace-personality.obj: personality.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-personality.obj -MD -MP -MF $(DEPDIR)/strace-personality.Tpo -c -o strace-personality.obj `if test -f 'personality.c'; then $(CYGPATH_W) 'personality.c'; else $(CYGPATH_W) '$(srcdir)/personality.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-personality.Tpo $(DEPDIR)/strace-personality.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='personality.c' object='strace-personality.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_dev_t.o: print_dev_t.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_dev_t.o -MD -MP -MF $(DEPDIR)/libstrace_a-print_dev_t.Tpo -c -o libstrace_a-print_dev_t.o `test -f 'print_dev_t.c' || echo '$(srcdir)/'`print_dev_t.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_dev_t.Tpo $(DEPDIR)/libstrace_a-print_dev_t.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_dev_t.c' object='libstrace_a-print_dev_t.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-personality.obj `if test -f 'personality.c'; then $(CYGPATH_W) 'personality.c'; else $(CYGPATH_W) '$(srcdir)/personality.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_dev_t.o `test -f 'print_dev_t.c' || echo '$(srcdir)/'`print_dev_t.c
 
-strace-pidfd_open.o: pidfd_open.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-pidfd_open.o -MD -MP -MF $(DEPDIR)/strace-pidfd_open.Tpo -c -o strace-pidfd_open.o `test -f 'pidfd_open.c' || echo '$(srcdir)/'`pidfd_open.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-pidfd_open.Tpo $(DEPDIR)/strace-pidfd_open.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='pidfd_open.c' object='strace-pidfd_open.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_dev_t.obj: print_dev_t.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_dev_t.obj -MD -MP -MF $(DEPDIR)/libstrace_a-print_dev_t.Tpo -c -o libstrace_a-print_dev_t.obj `if test -f 'print_dev_t.c'; then $(CYGPATH_W) 'print_dev_t.c'; else $(CYGPATH_W) '$(srcdir)/print_dev_t.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_dev_t.Tpo $(DEPDIR)/libstrace_a-print_dev_t.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_dev_t.c' object='libstrace_a-print_dev_t.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-pidfd_open.o `test -f 'pidfd_open.c' || echo '$(srcdir)/'`pidfd_open.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_dev_t.obj `if test -f 'print_dev_t.c'; then $(CYGPATH_W) 'print_dev_t.c'; else $(CYGPATH_W) '$(srcdir)/print_dev_t.c'; fi`
 
-strace-pidfd_open.obj: pidfd_open.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-pidfd_open.obj -MD -MP -MF $(DEPDIR)/strace-pidfd_open.Tpo -c -o strace-pidfd_open.obj `if test -f 'pidfd_open.c'; then $(CYGPATH_W) 'pidfd_open.c'; else $(CYGPATH_W) '$(srcdir)/pidfd_open.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-pidfd_open.Tpo $(DEPDIR)/strace-pidfd_open.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='pidfd_open.c' object='strace-pidfd_open.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_group_req.o: print_group_req.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_group_req.o -MD -MP -MF $(DEPDIR)/libstrace_a-print_group_req.Tpo -c -o libstrace_a-print_group_req.o `test -f 'print_group_req.c' || echo '$(srcdir)/'`print_group_req.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_group_req.Tpo $(DEPDIR)/libstrace_a-print_group_req.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_group_req.c' object='libstrace_a-print_group_req.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-pidfd_open.obj `if test -f 'pidfd_open.c'; then $(CYGPATH_W) 'pidfd_open.c'; else $(CYGPATH_W) '$(srcdir)/pidfd_open.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_group_req.o `test -f 'print_group_req.c' || echo '$(srcdir)/'`print_group_req.c
 
-strace-pkeys.o: pkeys.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-pkeys.o -MD -MP -MF $(DEPDIR)/strace-pkeys.Tpo -c -o strace-pkeys.o `test -f 'pkeys.c' || echo '$(srcdir)/'`pkeys.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-pkeys.Tpo $(DEPDIR)/strace-pkeys.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='pkeys.c' object='strace-pkeys.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_group_req.obj: print_group_req.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_group_req.obj -MD -MP -MF $(DEPDIR)/libstrace_a-print_group_req.Tpo -c -o libstrace_a-print_group_req.obj `if test -f 'print_group_req.c'; then $(CYGPATH_W) 'print_group_req.c'; else $(CYGPATH_W) '$(srcdir)/print_group_req.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_group_req.Tpo $(DEPDIR)/libstrace_a-print_group_req.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_group_req.c' object='libstrace_a-print_group_req.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-pkeys.o `test -f 'pkeys.c' || echo '$(srcdir)/'`pkeys.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_group_req.obj `if test -f 'print_group_req.c'; then $(CYGPATH_W) 'print_group_req.c'; else $(CYGPATH_W) '$(srcdir)/print_group_req.c'; fi`
 
-strace-pkeys.obj: pkeys.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-pkeys.obj -MD -MP -MF $(DEPDIR)/strace-pkeys.Tpo -c -o strace-pkeys.obj `if test -f 'pkeys.c'; then $(CYGPATH_W) 'pkeys.c'; else $(CYGPATH_W) '$(srcdir)/pkeys.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-pkeys.Tpo $(DEPDIR)/strace-pkeys.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='pkeys.c' object='strace-pkeys.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_ifindex.o: print_ifindex.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_ifindex.o -MD -MP -MF $(DEPDIR)/libstrace_a-print_ifindex.Tpo -c -o libstrace_a-print_ifindex.o `test -f 'print_ifindex.c' || echo '$(srcdir)/'`print_ifindex.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_ifindex.Tpo $(DEPDIR)/libstrace_a-print_ifindex.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_ifindex.c' object='libstrace_a-print_ifindex.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-pkeys.obj `if test -f 'pkeys.c'; then $(CYGPATH_W) 'pkeys.c'; else $(CYGPATH_W) '$(srcdir)/pkeys.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_ifindex.o `test -f 'print_ifindex.c' || echo '$(srcdir)/'`print_ifindex.c
 
-strace-poll.o: poll.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-poll.o -MD -MP -MF $(DEPDIR)/strace-poll.Tpo -c -o strace-poll.o `test -f 'poll.c' || echo '$(srcdir)/'`poll.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-poll.Tpo $(DEPDIR)/strace-poll.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='poll.c' object='strace-poll.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_ifindex.obj: print_ifindex.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_ifindex.obj -MD -MP -MF $(DEPDIR)/libstrace_a-print_ifindex.Tpo -c -o libstrace_a-print_ifindex.obj `if test -f 'print_ifindex.c'; then $(CYGPATH_W) 'print_ifindex.c'; else $(CYGPATH_W) '$(srcdir)/print_ifindex.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_ifindex.Tpo $(DEPDIR)/libstrace_a-print_ifindex.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_ifindex.c' object='libstrace_a-print_ifindex.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-poll.o `test -f 'poll.c' || echo '$(srcdir)/'`poll.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_ifindex.obj `if test -f 'print_ifindex.c'; then $(CYGPATH_W) 'print_ifindex.c'; else $(CYGPATH_W) '$(srcdir)/print_ifindex.c'; fi`
 
-strace-poll.obj: poll.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-poll.obj -MD -MP -MF $(DEPDIR)/strace-poll.Tpo -c -o strace-poll.obj `if test -f 'poll.c'; then $(CYGPATH_W) 'poll.c'; else $(CYGPATH_W) '$(srcdir)/poll.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-poll.Tpo $(DEPDIR)/strace-poll.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='poll.c' object='strace-poll.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_instruction_pointer.o: print_instruction_pointer.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_instruction_pointer.o -MD -MP -MF $(DEPDIR)/libstrace_a-print_instruction_pointer.Tpo -c -o libstrace_a-print_instruction_pointer.o `test -f 'print_instruction_pointer.c' || echo '$(srcdir)/'`print_instruction_pointer.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_instruction_pointer.Tpo $(DEPDIR)/libstrace_a-print_instruction_pointer.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_instruction_pointer.c' object='libstrace_a-print_instruction_pointer.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-poll.obj `if test -f 'poll.c'; then $(CYGPATH_W) 'poll.c'; else $(CYGPATH_W) '$(srcdir)/poll.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_instruction_pointer.o `test -f 'print_instruction_pointer.c' || echo '$(srcdir)/'`print_instruction_pointer.c
 
-strace-prctl.o: prctl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-prctl.o -MD -MP -MF $(DEPDIR)/strace-prctl.Tpo -c -o strace-prctl.o `test -f 'prctl.c' || echo '$(srcdir)/'`prctl.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-prctl.Tpo $(DEPDIR)/strace-prctl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='prctl.c' object='strace-prctl.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_instruction_pointer.obj: print_instruction_pointer.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_instruction_pointer.obj -MD -MP -MF $(DEPDIR)/libstrace_a-print_instruction_pointer.Tpo -c -o libstrace_a-print_instruction_pointer.obj `if test -f 'print_instruction_pointer.c'; then $(CYGPATH_W) 'print_instruction_pointer.c'; else $(CYGPATH_W) '$(srcdir)/print_instruction_pointer.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_instruction_pointer.Tpo $(DEPDIR)/libstrace_a-print_instruction_pointer.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_instruction_pointer.c' object='libstrace_a-print_instruction_pointer.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-prctl.o `test -f 'prctl.c' || echo '$(srcdir)/'`prctl.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_instruction_pointer.obj `if test -f 'print_instruction_pointer.c'; then $(CYGPATH_W) 'print_instruction_pointer.c'; else $(CYGPATH_W) '$(srcdir)/print_instruction_pointer.c'; fi`
 
-strace-prctl.obj: prctl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-prctl.obj -MD -MP -MF $(DEPDIR)/strace-prctl.Tpo -c -o strace-prctl.obj `if test -f 'prctl.c'; then $(CYGPATH_W) 'prctl.c'; else $(CYGPATH_W) '$(srcdir)/prctl.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-prctl.Tpo $(DEPDIR)/strace-prctl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='prctl.c' object='strace-prctl.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_kernel_version.o: print_kernel_version.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_kernel_version.o -MD -MP -MF $(DEPDIR)/libstrace_a-print_kernel_version.Tpo -c -o libstrace_a-print_kernel_version.o `test -f 'print_kernel_version.c' || echo '$(srcdir)/'`print_kernel_version.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_kernel_version.Tpo $(DEPDIR)/libstrace_a-print_kernel_version.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_kernel_version.c' object='libstrace_a-print_kernel_version.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-prctl.obj `if test -f 'prctl.c'; then $(CYGPATH_W) 'prctl.c'; else $(CYGPATH_W) '$(srcdir)/prctl.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_kernel_version.o `test -f 'print_kernel_version.c' || echo '$(srcdir)/'`print_kernel_version.c
 
-strace-print_aio_sigset.o: print_aio_sigset.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_aio_sigset.o -MD -MP -MF $(DEPDIR)/strace-print_aio_sigset.Tpo -c -o strace-print_aio_sigset.o `test -f 'print_aio_sigset.c' || echo '$(srcdir)/'`print_aio_sigset.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_aio_sigset.Tpo $(DEPDIR)/strace-print_aio_sigset.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_aio_sigset.c' object='strace-print_aio_sigset.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_kernel_version.obj: print_kernel_version.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_kernel_version.obj -MD -MP -MF $(DEPDIR)/libstrace_a-print_kernel_version.Tpo -c -o libstrace_a-print_kernel_version.obj `if test -f 'print_kernel_version.c'; then $(CYGPATH_W) 'print_kernel_version.c'; else $(CYGPATH_W) '$(srcdir)/print_kernel_version.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_kernel_version.Tpo $(DEPDIR)/libstrace_a-print_kernel_version.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_kernel_version.c' object='libstrace_a-print_kernel_version.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_aio_sigset.o `test -f 'print_aio_sigset.c' || echo '$(srcdir)/'`print_aio_sigset.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_kernel_version.obj `if test -f 'print_kernel_version.c'; then $(CYGPATH_W) 'print_kernel_version.c'; else $(CYGPATH_W) '$(srcdir)/print_kernel_version.c'; fi`
 
-strace-print_aio_sigset.obj: print_aio_sigset.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_aio_sigset.obj -MD -MP -MF $(DEPDIR)/strace-print_aio_sigset.Tpo -c -o strace-print_aio_sigset.obj `if test -f 'print_aio_sigset.c'; then $(CYGPATH_W) 'print_aio_sigset.c'; else $(CYGPATH_W) '$(srcdir)/print_aio_sigset.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_aio_sigset.Tpo $(DEPDIR)/strace-print_aio_sigset.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_aio_sigset.c' object='strace-print_aio_sigset.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_mac.o: print_mac.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_mac.o -MD -MP -MF $(DEPDIR)/libstrace_a-print_mac.Tpo -c -o libstrace_a-print_mac.o `test -f 'print_mac.c' || echo '$(srcdir)/'`print_mac.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_mac.Tpo $(DEPDIR)/libstrace_a-print_mac.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_mac.c' object='libstrace_a-print_mac.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_aio_sigset.obj `if test -f 'print_aio_sigset.c'; then $(CYGPATH_W) 'print_aio_sigset.c'; else $(CYGPATH_W) '$(srcdir)/print_aio_sigset.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_mac.o `test -f 'print_mac.c' || echo '$(srcdir)/'`print_mac.c
 
-strace-print_dev_t.o: print_dev_t.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_dev_t.o -MD -MP -MF $(DEPDIR)/strace-print_dev_t.Tpo -c -o strace-print_dev_t.o `test -f 'print_dev_t.c' || echo '$(srcdir)/'`print_dev_t.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_dev_t.Tpo $(DEPDIR)/strace-print_dev_t.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_dev_t.c' object='strace-print_dev_t.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_mac.obj: print_mac.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_mac.obj -MD -MP -MF $(DEPDIR)/libstrace_a-print_mac.Tpo -c -o libstrace_a-print_mac.obj `if test -f 'print_mac.c'; then $(CYGPATH_W) 'print_mac.c'; else $(CYGPATH_W) '$(srcdir)/print_mac.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_mac.Tpo $(DEPDIR)/libstrace_a-print_mac.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_mac.c' object='libstrace_a-print_mac.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_dev_t.o `test -f 'print_dev_t.c' || echo '$(srcdir)/'`print_dev_t.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_mac.obj `if test -f 'print_mac.c'; then $(CYGPATH_W) 'print_mac.c'; else $(CYGPATH_W) '$(srcdir)/print_mac.c'; fi`
 
-strace-print_dev_t.obj: print_dev_t.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_dev_t.obj -MD -MP -MF $(DEPDIR)/strace-print_dev_t.Tpo -c -o strace-print_dev_t.obj `if test -f 'print_dev_t.c'; then $(CYGPATH_W) 'print_dev_t.c'; else $(CYGPATH_W) '$(srcdir)/print_dev_t.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_dev_t.Tpo $(DEPDIR)/strace-print_dev_t.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_dev_t.c' object='strace-print_dev_t.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_mq_attr.o: print_mq_attr.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_mq_attr.o -MD -MP -MF $(DEPDIR)/libstrace_a-print_mq_attr.Tpo -c -o libstrace_a-print_mq_attr.o `test -f 'print_mq_attr.c' || echo '$(srcdir)/'`print_mq_attr.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_mq_attr.Tpo $(DEPDIR)/libstrace_a-print_mq_attr.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_mq_attr.c' object='libstrace_a-print_mq_attr.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_dev_t.obj `if test -f 'print_dev_t.c'; then $(CYGPATH_W) 'print_dev_t.c'; else $(CYGPATH_W) '$(srcdir)/print_dev_t.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_mq_attr.o `test -f 'print_mq_attr.c' || echo '$(srcdir)/'`print_mq_attr.c
 
-strace-print_group_req.o: print_group_req.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_group_req.o -MD -MP -MF $(DEPDIR)/strace-print_group_req.Tpo -c -o strace-print_group_req.o `test -f 'print_group_req.c' || echo '$(srcdir)/'`print_group_req.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_group_req.Tpo $(DEPDIR)/strace-print_group_req.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_group_req.c' object='strace-print_group_req.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_mq_attr.obj: print_mq_attr.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_mq_attr.obj -MD -MP -MF $(DEPDIR)/libstrace_a-print_mq_attr.Tpo -c -o libstrace_a-print_mq_attr.obj `if test -f 'print_mq_attr.c'; then $(CYGPATH_W) 'print_mq_attr.c'; else $(CYGPATH_W) '$(srcdir)/print_mq_attr.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_mq_attr.Tpo $(DEPDIR)/libstrace_a-print_mq_attr.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_mq_attr.c' object='libstrace_a-print_mq_attr.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_group_req.o `test -f 'print_group_req.c' || echo '$(srcdir)/'`print_group_req.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_mq_attr.obj `if test -f 'print_mq_attr.c'; then $(CYGPATH_W) 'print_mq_attr.c'; else $(CYGPATH_W) '$(srcdir)/print_mq_attr.c'; fi`
 
-strace-print_group_req.obj: print_group_req.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_group_req.obj -MD -MP -MF $(DEPDIR)/strace-print_group_req.Tpo -c -o strace-print_group_req.obj `if test -f 'print_group_req.c'; then $(CYGPATH_W) 'print_group_req.c'; else $(CYGPATH_W) '$(srcdir)/print_group_req.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_group_req.Tpo $(DEPDIR)/strace-print_group_req.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_group_req.c' object='strace-print_group_req.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_msgbuf.o: print_msgbuf.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_msgbuf.o -MD -MP -MF $(DEPDIR)/libstrace_a-print_msgbuf.Tpo -c -o libstrace_a-print_msgbuf.o `test -f 'print_msgbuf.c' || echo '$(srcdir)/'`print_msgbuf.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_msgbuf.Tpo $(DEPDIR)/libstrace_a-print_msgbuf.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_msgbuf.c' object='libstrace_a-print_msgbuf.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_group_req.obj `if test -f 'print_group_req.c'; then $(CYGPATH_W) 'print_group_req.c'; else $(CYGPATH_W) '$(srcdir)/print_group_req.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_msgbuf.o `test -f 'print_msgbuf.c' || echo '$(srcdir)/'`print_msgbuf.c
 
-strace-print_ifindex.o: print_ifindex.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_ifindex.o -MD -MP -MF $(DEPDIR)/strace-print_ifindex.Tpo -c -o strace-print_ifindex.o `test -f 'print_ifindex.c' || echo '$(srcdir)/'`print_ifindex.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_ifindex.Tpo $(DEPDIR)/strace-print_ifindex.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_ifindex.c' object='strace-print_ifindex.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_msgbuf.obj: print_msgbuf.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_msgbuf.obj -MD -MP -MF $(DEPDIR)/libstrace_a-print_msgbuf.Tpo -c -o libstrace_a-print_msgbuf.obj `if test -f 'print_msgbuf.c'; then $(CYGPATH_W) 'print_msgbuf.c'; else $(CYGPATH_W) '$(srcdir)/print_msgbuf.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_msgbuf.Tpo $(DEPDIR)/libstrace_a-print_msgbuf.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_msgbuf.c' object='libstrace_a-print_msgbuf.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_ifindex.o `test -f 'print_ifindex.c' || echo '$(srcdir)/'`print_ifindex.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_msgbuf.obj `if test -f 'print_msgbuf.c'; then $(CYGPATH_W) 'print_msgbuf.c'; else $(CYGPATH_W) '$(srcdir)/print_msgbuf.c'; fi`
 
-strace-print_ifindex.obj: print_ifindex.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_ifindex.obj -MD -MP -MF $(DEPDIR)/strace-print_ifindex.Tpo -c -o strace-print_ifindex.obj `if test -f 'print_ifindex.c'; then $(CYGPATH_W) 'print_ifindex.c'; else $(CYGPATH_W) '$(srcdir)/print_ifindex.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_ifindex.Tpo $(DEPDIR)/strace-print_ifindex.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_ifindex.c' object='strace-print_ifindex.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_sg_req_info.o: print_sg_req_info.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_sg_req_info.o -MD -MP -MF $(DEPDIR)/libstrace_a-print_sg_req_info.Tpo -c -o libstrace_a-print_sg_req_info.o `test -f 'print_sg_req_info.c' || echo '$(srcdir)/'`print_sg_req_info.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_sg_req_info.Tpo $(DEPDIR)/libstrace_a-print_sg_req_info.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_sg_req_info.c' object='libstrace_a-print_sg_req_info.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_ifindex.obj `if test -f 'print_ifindex.c'; then $(CYGPATH_W) 'print_ifindex.c'; else $(CYGPATH_W) '$(srcdir)/print_ifindex.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_sg_req_info.o `test -f 'print_sg_req_info.c' || echo '$(srcdir)/'`print_sg_req_info.c
 
-strace-print_instruction_pointer.o: print_instruction_pointer.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_instruction_pointer.o -MD -MP -MF $(DEPDIR)/strace-print_instruction_pointer.Tpo -c -o strace-print_instruction_pointer.o `test -f 'print_instruction_pointer.c' || echo '$(srcdir)/'`print_instruction_pointer.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_instruction_pointer.Tpo $(DEPDIR)/strace-print_instruction_pointer.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_instruction_pointer.c' object='strace-print_instruction_pointer.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_sg_req_info.obj: print_sg_req_info.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_sg_req_info.obj -MD -MP -MF $(DEPDIR)/libstrace_a-print_sg_req_info.Tpo -c -o libstrace_a-print_sg_req_info.obj `if test -f 'print_sg_req_info.c'; then $(CYGPATH_W) 'print_sg_req_info.c'; else $(CYGPATH_W) '$(srcdir)/print_sg_req_info.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_sg_req_info.Tpo $(DEPDIR)/libstrace_a-print_sg_req_info.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_sg_req_info.c' object='libstrace_a-print_sg_req_info.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_instruction_pointer.o `test -f 'print_instruction_pointer.c' || echo '$(srcdir)/'`print_instruction_pointer.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_sg_req_info.obj `if test -f 'print_sg_req_info.c'; then $(CYGPATH_W) 'print_sg_req_info.c'; else $(CYGPATH_W) '$(srcdir)/print_sg_req_info.c'; fi`
 
-strace-print_instruction_pointer.obj: print_instruction_pointer.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_instruction_pointer.obj -MD -MP -MF $(DEPDIR)/strace-print_instruction_pointer.Tpo -c -o strace-print_instruction_pointer.obj `if test -f 'print_instruction_pointer.c'; then $(CYGPATH_W) 'print_instruction_pointer.c'; else $(CYGPATH_W) '$(srcdir)/print_instruction_pointer.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_instruction_pointer.Tpo $(DEPDIR)/strace-print_instruction_pointer.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_instruction_pointer.c' object='strace-print_instruction_pointer.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_sigevent.o: print_sigevent.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_sigevent.o -MD -MP -MF $(DEPDIR)/libstrace_a-print_sigevent.Tpo -c -o libstrace_a-print_sigevent.o `test -f 'print_sigevent.c' || echo '$(srcdir)/'`print_sigevent.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_sigevent.Tpo $(DEPDIR)/libstrace_a-print_sigevent.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_sigevent.c' object='libstrace_a-print_sigevent.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_instruction_pointer.obj `if test -f 'print_instruction_pointer.c'; then $(CYGPATH_W) 'print_instruction_pointer.c'; else $(CYGPATH_W) '$(srcdir)/print_instruction_pointer.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_sigevent.o `test -f 'print_sigevent.c' || echo '$(srcdir)/'`print_sigevent.c
 
-strace-print_kernel_version.o: print_kernel_version.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_kernel_version.o -MD -MP -MF $(DEPDIR)/strace-print_kernel_version.Tpo -c -o strace-print_kernel_version.o `test -f 'print_kernel_version.c' || echo '$(srcdir)/'`print_kernel_version.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_kernel_version.Tpo $(DEPDIR)/strace-print_kernel_version.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_kernel_version.c' object='strace-print_kernel_version.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_sigevent.obj: print_sigevent.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_sigevent.obj -MD -MP -MF $(DEPDIR)/libstrace_a-print_sigevent.Tpo -c -o libstrace_a-print_sigevent.obj `if test -f 'print_sigevent.c'; then $(CYGPATH_W) 'print_sigevent.c'; else $(CYGPATH_W) '$(srcdir)/print_sigevent.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_sigevent.Tpo $(DEPDIR)/libstrace_a-print_sigevent.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_sigevent.c' object='libstrace_a-print_sigevent.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_kernel_version.o `test -f 'print_kernel_version.c' || echo '$(srcdir)/'`print_kernel_version.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_sigevent.obj `if test -f 'print_sigevent.c'; then $(CYGPATH_W) 'print_sigevent.c'; else $(CYGPATH_W) '$(srcdir)/print_sigevent.c'; fi`
 
-strace-print_kernel_version.obj: print_kernel_version.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_kernel_version.obj -MD -MP -MF $(DEPDIR)/strace-print_kernel_version.Tpo -c -o strace-print_kernel_version.obj `if test -f 'print_kernel_version.c'; then $(CYGPATH_W) 'print_kernel_version.c'; else $(CYGPATH_W) '$(srcdir)/print_kernel_version.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_kernel_version.Tpo $(DEPDIR)/strace-print_kernel_version.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_kernel_version.c' object='strace-print_kernel_version.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_statfs.o: print_statfs.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_statfs.o -MD -MP -MF $(DEPDIR)/libstrace_a-print_statfs.Tpo -c -o libstrace_a-print_statfs.o `test -f 'print_statfs.c' || echo '$(srcdir)/'`print_statfs.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_statfs.Tpo $(DEPDIR)/libstrace_a-print_statfs.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_statfs.c' object='libstrace_a-print_statfs.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_kernel_version.obj `if test -f 'print_kernel_version.c'; then $(CYGPATH_W) 'print_kernel_version.c'; else $(CYGPATH_W) '$(srcdir)/print_kernel_version.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_statfs.o `test -f 'print_statfs.c' || echo '$(srcdir)/'`print_statfs.c
 
-strace-print_mac.o: print_mac.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_mac.o -MD -MP -MF $(DEPDIR)/strace-print_mac.Tpo -c -o strace-print_mac.o `test -f 'print_mac.c' || echo '$(srcdir)/'`print_mac.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_mac.Tpo $(DEPDIR)/strace-print_mac.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_mac.c' object='strace-print_mac.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_statfs.obj: print_statfs.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_statfs.obj -MD -MP -MF $(DEPDIR)/libstrace_a-print_statfs.Tpo -c -o libstrace_a-print_statfs.obj `if test -f 'print_statfs.c'; then $(CYGPATH_W) 'print_statfs.c'; else $(CYGPATH_W) '$(srcdir)/print_statfs.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_statfs.Tpo $(DEPDIR)/libstrace_a-print_statfs.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_statfs.c' object='libstrace_a-print_statfs.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_mac.o `test -f 'print_mac.c' || echo '$(srcdir)/'`print_mac.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_statfs.obj `if test -f 'print_statfs.c'; then $(CYGPATH_W) 'print_statfs.c'; else $(CYGPATH_W) '$(srcdir)/print_statfs.c'; fi`
 
-strace-print_mac.obj: print_mac.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_mac.obj -MD -MP -MF $(DEPDIR)/strace-print_mac.Tpo -c -o strace-print_mac.obj `if test -f 'print_mac.c'; then $(CYGPATH_W) 'print_mac.c'; else $(CYGPATH_W) '$(srcdir)/print_mac.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_mac.Tpo $(DEPDIR)/strace-print_mac.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_mac.c' object='strace-print_mac.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_struct_stat.o: print_struct_stat.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_struct_stat.o -MD -MP -MF $(DEPDIR)/libstrace_a-print_struct_stat.Tpo -c -o libstrace_a-print_struct_stat.o `test -f 'print_struct_stat.c' || echo '$(srcdir)/'`print_struct_stat.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_struct_stat.Tpo $(DEPDIR)/libstrace_a-print_struct_stat.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_struct_stat.c' object='libstrace_a-print_struct_stat.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_mac.obj `if test -f 'print_mac.c'; then $(CYGPATH_W) 'print_mac.c'; else $(CYGPATH_W) '$(srcdir)/print_mac.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_struct_stat.o `test -f 'print_struct_stat.c' || echo '$(srcdir)/'`print_struct_stat.c
 
-strace-print_mq_attr.o: print_mq_attr.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_mq_attr.o -MD -MP -MF $(DEPDIR)/strace-print_mq_attr.Tpo -c -o strace-print_mq_attr.o `test -f 'print_mq_attr.c' || echo '$(srcdir)/'`print_mq_attr.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_mq_attr.Tpo $(DEPDIR)/strace-print_mq_attr.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_mq_attr.c' object='strace-print_mq_attr.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_struct_stat.obj: print_struct_stat.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_struct_stat.obj -MD -MP -MF $(DEPDIR)/libstrace_a-print_struct_stat.Tpo -c -o libstrace_a-print_struct_stat.obj `if test -f 'print_struct_stat.c'; then $(CYGPATH_W) 'print_struct_stat.c'; else $(CYGPATH_W) '$(srcdir)/print_struct_stat.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_struct_stat.Tpo $(DEPDIR)/libstrace_a-print_struct_stat.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_struct_stat.c' object='libstrace_a-print_struct_stat.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_mq_attr.o `test -f 'print_mq_attr.c' || echo '$(srcdir)/'`print_mq_attr.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_struct_stat.obj `if test -f 'print_struct_stat.c'; then $(CYGPATH_W) 'print_struct_stat.c'; else $(CYGPATH_W) '$(srcdir)/print_struct_stat.c'; fi`
 
-strace-print_mq_attr.obj: print_mq_attr.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_mq_attr.obj -MD -MP -MF $(DEPDIR)/strace-print_mq_attr.Tpo -c -o strace-print_mq_attr.obj `if test -f 'print_mq_attr.c'; then $(CYGPATH_W) 'print_mq_attr.c'; else $(CYGPATH_W) '$(srcdir)/print_mq_attr.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_mq_attr.Tpo $(DEPDIR)/strace-print_mq_attr.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_mq_attr.c' object='strace-print_mq_attr.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_syscall_number.o: print_syscall_number.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_syscall_number.o -MD -MP -MF $(DEPDIR)/libstrace_a-print_syscall_number.Tpo -c -o libstrace_a-print_syscall_number.o `test -f 'print_syscall_number.c' || echo '$(srcdir)/'`print_syscall_number.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_syscall_number.Tpo $(DEPDIR)/libstrace_a-print_syscall_number.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_syscall_number.c' object='libstrace_a-print_syscall_number.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_mq_attr.obj `if test -f 'print_mq_attr.c'; then $(CYGPATH_W) 'print_mq_attr.c'; else $(CYGPATH_W) '$(srcdir)/print_mq_attr.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_syscall_number.o `test -f 'print_syscall_number.c' || echo '$(srcdir)/'`print_syscall_number.c
 
-strace-print_msgbuf.o: print_msgbuf.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_msgbuf.o -MD -MP -MF $(DEPDIR)/strace-print_msgbuf.Tpo -c -o strace-print_msgbuf.o `test -f 'print_msgbuf.c' || echo '$(srcdir)/'`print_msgbuf.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_msgbuf.Tpo $(DEPDIR)/strace-print_msgbuf.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_msgbuf.c' object='strace-print_msgbuf.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_syscall_number.obj: print_syscall_number.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_syscall_number.obj -MD -MP -MF $(DEPDIR)/libstrace_a-print_syscall_number.Tpo -c -o libstrace_a-print_syscall_number.obj `if test -f 'print_syscall_number.c'; then $(CYGPATH_W) 'print_syscall_number.c'; else $(CYGPATH_W) '$(srcdir)/print_syscall_number.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_syscall_number.Tpo $(DEPDIR)/libstrace_a-print_syscall_number.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_syscall_number.c' object='libstrace_a-print_syscall_number.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_msgbuf.o `test -f 'print_msgbuf.c' || echo '$(srcdir)/'`print_msgbuf.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_syscall_number.obj `if test -f 'print_syscall_number.c'; then $(CYGPATH_W) 'print_syscall_number.c'; else $(CYGPATH_W) '$(srcdir)/print_syscall_number.c'; fi`
 
-strace-print_msgbuf.obj: print_msgbuf.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_msgbuf.obj -MD -MP -MF $(DEPDIR)/strace-print_msgbuf.Tpo -c -o strace-print_msgbuf.obj `if test -f 'print_msgbuf.c'; then $(CYGPATH_W) 'print_msgbuf.c'; else $(CYGPATH_W) '$(srcdir)/print_msgbuf.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_msgbuf.Tpo $(DEPDIR)/strace-print_msgbuf.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_msgbuf.c' object='strace-print_msgbuf.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_time.o: print_time.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_time.o -MD -MP -MF $(DEPDIR)/libstrace_a-print_time.Tpo -c -o libstrace_a-print_time.o `test -f 'print_time.c' || echo '$(srcdir)/'`print_time.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_time.Tpo $(DEPDIR)/libstrace_a-print_time.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_time.c' object='libstrace_a-print_time.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_msgbuf.obj `if test -f 'print_msgbuf.c'; then $(CYGPATH_W) 'print_msgbuf.c'; else $(CYGPATH_W) '$(srcdir)/print_msgbuf.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_time.o `test -f 'print_time.c' || echo '$(srcdir)/'`print_time.c
 
-strace-print_sg_req_info.o: print_sg_req_info.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_sg_req_info.o -MD -MP -MF $(DEPDIR)/strace-print_sg_req_info.Tpo -c -o strace-print_sg_req_info.o `test -f 'print_sg_req_info.c' || echo '$(srcdir)/'`print_sg_req_info.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_sg_req_info.Tpo $(DEPDIR)/strace-print_sg_req_info.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_sg_req_info.c' object='strace-print_sg_req_info.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_time.obj: print_time.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_time.obj -MD -MP -MF $(DEPDIR)/libstrace_a-print_time.Tpo -c -o libstrace_a-print_time.obj `if test -f 'print_time.c'; then $(CYGPATH_W) 'print_time.c'; else $(CYGPATH_W) '$(srcdir)/print_time.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_time.Tpo $(DEPDIR)/libstrace_a-print_time.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_time.c' object='libstrace_a-print_time.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_sg_req_info.o `test -f 'print_sg_req_info.c' || echo '$(srcdir)/'`print_sg_req_info.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_time.obj `if test -f 'print_time.c'; then $(CYGPATH_W) 'print_time.c'; else $(CYGPATH_W) '$(srcdir)/print_time.c'; fi`
 
-strace-print_sg_req_info.obj: print_sg_req_info.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_sg_req_info.obj -MD -MP -MF $(DEPDIR)/strace-print_sg_req_info.Tpo -c -o strace-print_sg_req_info.obj `if test -f 'print_sg_req_info.c'; then $(CYGPATH_W) 'print_sg_req_info.c'; else $(CYGPATH_W) '$(srcdir)/print_sg_req_info.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_sg_req_info.Tpo $(DEPDIR)/strace-print_sg_req_info.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_sg_req_info.c' object='strace-print_sg_req_info.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_timespec32.o: print_timespec32.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_timespec32.o -MD -MP -MF $(DEPDIR)/libstrace_a-print_timespec32.Tpo -c -o libstrace_a-print_timespec32.o `test -f 'print_timespec32.c' || echo '$(srcdir)/'`print_timespec32.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_timespec32.Tpo $(DEPDIR)/libstrace_a-print_timespec32.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_timespec32.c' object='libstrace_a-print_timespec32.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_sg_req_info.obj `if test -f 'print_sg_req_info.c'; then $(CYGPATH_W) 'print_sg_req_info.c'; else $(CYGPATH_W) '$(srcdir)/print_sg_req_info.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_timespec32.o `test -f 'print_timespec32.c' || echo '$(srcdir)/'`print_timespec32.c
 
-strace-print_sigevent.o: print_sigevent.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_sigevent.o -MD -MP -MF $(DEPDIR)/strace-print_sigevent.Tpo -c -o strace-print_sigevent.o `test -f 'print_sigevent.c' || echo '$(srcdir)/'`print_sigevent.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_sigevent.Tpo $(DEPDIR)/strace-print_sigevent.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_sigevent.c' object='strace-print_sigevent.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_timespec32.obj: print_timespec32.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_timespec32.obj -MD -MP -MF $(DEPDIR)/libstrace_a-print_timespec32.Tpo -c -o libstrace_a-print_timespec32.obj `if test -f 'print_timespec32.c'; then $(CYGPATH_W) 'print_timespec32.c'; else $(CYGPATH_W) '$(srcdir)/print_timespec32.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_timespec32.Tpo $(DEPDIR)/libstrace_a-print_timespec32.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_timespec32.c' object='libstrace_a-print_timespec32.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_sigevent.o `test -f 'print_sigevent.c' || echo '$(srcdir)/'`print_sigevent.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_timespec32.obj `if test -f 'print_timespec32.c'; then $(CYGPATH_W) 'print_timespec32.c'; else $(CYGPATH_W) '$(srcdir)/print_timespec32.c'; fi`
 
-strace-print_sigevent.obj: print_sigevent.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_sigevent.obj -MD -MP -MF $(DEPDIR)/strace-print_sigevent.Tpo -c -o strace-print_sigevent.obj `if test -f 'print_sigevent.c'; then $(CYGPATH_W) 'print_sigevent.c'; else $(CYGPATH_W) '$(srcdir)/print_sigevent.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_sigevent.Tpo $(DEPDIR)/strace-print_sigevent.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_sigevent.c' object='strace-print_sigevent.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_timespec64.o: print_timespec64.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_timespec64.o -MD -MP -MF $(DEPDIR)/libstrace_a-print_timespec64.Tpo -c -o libstrace_a-print_timespec64.o `test -f 'print_timespec64.c' || echo '$(srcdir)/'`print_timespec64.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_timespec64.Tpo $(DEPDIR)/libstrace_a-print_timespec64.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_timespec64.c' object='libstrace_a-print_timespec64.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_sigevent.obj `if test -f 'print_sigevent.c'; then $(CYGPATH_W) 'print_sigevent.c'; else $(CYGPATH_W) '$(srcdir)/print_sigevent.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_timespec64.o `test -f 'print_timespec64.c' || echo '$(srcdir)/'`print_timespec64.c
 
-strace-print_statfs.o: print_statfs.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_statfs.o -MD -MP -MF $(DEPDIR)/strace-print_statfs.Tpo -c -o strace-print_statfs.o `test -f 'print_statfs.c' || echo '$(srcdir)/'`print_statfs.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_statfs.Tpo $(DEPDIR)/strace-print_statfs.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_statfs.c' object='strace-print_statfs.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_timespec64.obj: print_timespec64.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_timespec64.obj -MD -MP -MF $(DEPDIR)/libstrace_a-print_timespec64.Tpo -c -o libstrace_a-print_timespec64.obj `if test -f 'print_timespec64.c'; then $(CYGPATH_W) 'print_timespec64.c'; else $(CYGPATH_W) '$(srcdir)/print_timespec64.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_timespec64.Tpo $(DEPDIR)/libstrace_a-print_timespec64.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_timespec64.c' object='libstrace_a-print_timespec64.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_statfs.o `test -f 'print_statfs.c' || echo '$(srcdir)/'`print_statfs.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_timespec64.obj `if test -f 'print_timespec64.c'; then $(CYGPATH_W) 'print_timespec64.c'; else $(CYGPATH_W) '$(srcdir)/print_timespec64.c'; fi`
 
-strace-print_statfs.obj: print_statfs.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_statfs.obj -MD -MP -MF $(DEPDIR)/strace-print_statfs.Tpo -c -o strace-print_statfs.obj `if test -f 'print_statfs.c'; then $(CYGPATH_W) 'print_statfs.c'; else $(CYGPATH_W) '$(srcdir)/print_statfs.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_statfs.Tpo $(DEPDIR)/strace-print_statfs.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_statfs.c' object='strace-print_statfs.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_timeval.o: print_timeval.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_timeval.o -MD -MP -MF $(DEPDIR)/libstrace_a-print_timeval.Tpo -c -o libstrace_a-print_timeval.o `test -f 'print_timeval.c' || echo '$(srcdir)/'`print_timeval.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_timeval.Tpo $(DEPDIR)/libstrace_a-print_timeval.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_timeval.c' object='libstrace_a-print_timeval.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_statfs.obj `if test -f 'print_statfs.c'; then $(CYGPATH_W) 'print_statfs.c'; else $(CYGPATH_W) '$(srcdir)/print_statfs.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_timeval.o `test -f 'print_timeval.c' || echo '$(srcdir)/'`print_timeval.c
 
-strace-print_struct_stat.o: print_struct_stat.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_struct_stat.o -MD -MP -MF $(DEPDIR)/strace-print_struct_stat.Tpo -c -o strace-print_struct_stat.o `test -f 'print_struct_stat.c' || echo '$(srcdir)/'`print_struct_stat.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_struct_stat.Tpo $(DEPDIR)/strace-print_struct_stat.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_struct_stat.c' object='strace-print_struct_stat.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_timeval.obj: print_timeval.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_timeval.obj -MD -MP -MF $(DEPDIR)/libstrace_a-print_timeval.Tpo -c -o libstrace_a-print_timeval.obj `if test -f 'print_timeval.c'; then $(CYGPATH_W) 'print_timeval.c'; else $(CYGPATH_W) '$(srcdir)/print_timeval.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_timeval.Tpo $(DEPDIR)/libstrace_a-print_timeval.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_timeval.c' object='libstrace_a-print_timeval.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_struct_stat.o `test -f 'print_struct_stat.c' || echo '$(srcdir)/'`print_struct_stat.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_timeval.obj `if test -f 'print_timeval.c'; then $(CYGPATH_W) 'print_timeval.c'; else $(CYGPATH_W) '$(srcdir)/print_timeval.c'; fi`
 
-strace-print_struct_stat.obj: print_struct_stat.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_struct_stat.obj -MD -MP -MF $(DEPDIR)/strace-print_struct_stat.Tpo -c -o strace-print_struct_stat.obj `if test -f 'print_struct_stat.c'; then $(CYGPATH_W) 'print_struct_stat.c'; else $(CYGPATH_W) '$(srcdir)/print_struct_stat.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_struct_stat.Tpo $(DEPDIR)/strace-print_struct_stat.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_struct_stat.c' object='strace-print_struct_stat.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_timeval64.o: print_timeval64.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_timeval64.o -MD -MP -MF $(DEPDIR)/libstrace_a-print_timeval64.Tpo -c -o libstrace_a-print_timeval64.o `test -f 'print_timeval64.c' || echo '$(srcdir)/'`print_timeval64.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_timeval64.Tpo $(DEPDIR)/libstrace_a-print_timeval64.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_timeval64.c' object='libstrace_a-print_timeval64.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_struct_stat.obj `if test -f 'print_struct_stat.c'; then $(CYGPATH_W) 'print_struct_stat.c'; else $(CYGPATH_W) '$(srcdir)/print_struct_stat.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_timeval64.o `test -f 'print_timeval64.c' || echo '$(srcdir)/'`print_timeval64.c
 
-strace-print_time.o: print_time.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_time.o -MD -MP -MF $(DEPDIR)/strace-print_time.Tpo -c -o strace-print_time.o `test -f 'print_time.c' || echo '$(srcdir)/'`print_time.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_time.Tpo $(DEPDIR)/strace-print_time.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_time.c' object='strace-print_time.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_timeval64.obj: print_timeval64.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_timeval64.obj -MD -MP -MF $(DEPDIR)/libstrace_a-print_timeval64.Tpo -c -o libstrace_a-print_timeval64.obj `if test -f 'print_timeval64.c'; then $(CYGPATH_W) 'print_timeval64.c'; else $(CYGPATH_W) '$(srcdir)/print_timeval64.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_timeval64.Tpo $(DEPDIR)/libstrace_a-print_timeval64.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_timeval64.c' object='libstrace_a-print_timeval64.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_time.o `test -f 'print_time.c' || echo '$(srcdir)/'`print_time.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_timeval64.obj `if test -f 'print_timeval64.c'; then $(CYGPATH_W) 'print_timeval64.c'; else $(CYGPATH_W) '$(srcdir)/print_timeval64.c'; fi`
 
-strace-print_time.obj: print_time.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_time.obj -MD -MP -MF $(DEPDIR)/strace-print_time.Tpo -c -o strace-print_time.obj `if test -f 'print_time.c'; then $(CYGPATH_W) 'print_time.c'; else $(CYGPATH_W) '$(srcdir)/print_time.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_time.Tpo $(DEPDIR)/strace-print_time.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_time.c' object='strace-print_time.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_timex.o: print_timex.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_timex.o -MD -MP -MF $(DEPDIR)/libstrace_a-print_timex.Tpo -c -o libstrace_a-print_timex.o `test -f 'print_timex.c' || echo '$(srcdir)/'`print_timex.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_timex.Tpo $(DEPDIR)/libstrace_a-print_timex.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_timex.c' object='libstrace_a-print_timex.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_time.obj `if test -f 'print_time.c'; then $(CYGPATH_W) 'print_time.c'; else $(CYGPATH_W) '$(srcdir)/print_time.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_timex.o `test -f 'print_timex.c' || echo '$(srcdir)/'`print_timex.c
 
-strace-print_timespec.o: print_timespec.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_timespec.o -MD -MP -MF $(DEPDIR)/strace-print_timespec.Tpo -c -o strace-print_timespec.o `test -f 'print_timespec.c' || echo '$(srcdir)/'`print_timespec.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_timespec.Tpo $(DEPDIR)/strace-print_timespec.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_timespec.c' object='strace-print_timespec.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-print_timex.obj: print_timex.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-print_timex.obj -MD -MP -MF $(DEPDIR)/libstrace_a-print_timex.Tpo -c -o libstrace_a-print_timex.obj `if test -f 'print_timex.c'; then $(CYGPATH_W) 'print_timex.c'; else $(CYGPATH_W) '$(srcdir)/print_timex.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-print_timex.Tpo $(DEPDIR)/libstrace_a-print_timex.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_timex.c' object='libstrace_a-print_timex.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_timespec.o `test -f 'print_timespec.c' || echo '$(srcdir)/'`print_timespec.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-print_timex.obj `if test -f 'print_timex.c'; then $(CYGPATH_W) 'print_timex.c'; else $(CYGPATH_W) '$(srcdir)/print_timex.c'; fi`
 
-strace-print_timespec.obj: print_timespec.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_timespec.obj -MD -MP -MF $(DEPDIR)/strace-print_timespec.Tpo -c -o strace-print_timespec.obj `if test -f 'print_timespec.c'; then $(CYGPATH_W) 'print_timespec.c'; else $(CYGPATH_W) '$(srcdir)/print_timespec.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_timespec.Tpo $(DEPDIR)/strace-print_timespec.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_timespec.c' object='strace-print_timespec.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-printmode.o: printmode.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-printmode.o -MD -MP -MF $(DEPDIR)/libstrace_a-printmode.Tpo -c -o libstrace_a-printmode.o `test -f 'printmode.c' || echo '$(srcdir)/'`printmode.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-printmode.Tpo $(DEPDIR)/libstrace_a-printmode.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='printmode.c' object='libstrace_a-printmode.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_timespec.obj `if test -f 'print_timespec.c'; then $(CYGPATH_W) 'print_timespec.c'; else $(CYGPATH_W) '$(srcdir)/print_timespec.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-printmode.o `test -f 'printmode.c' || echo '$(srcdir)/'`printmode.c
 
-strace-print_timespec32.o: print_timespec32.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_timespec32.o -MD -MP -MF $(DEPDIR)/strace-print_timespec32.Tpo -c -o strace-print_timespec32.o `test -f 'print_timespec32.c' || echo '$(srcdir)/'`print_timespec32.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_timespec32.Tpo $(DEPDIR)/strace-print_timespec32.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_timespec32.c' object='strace-print_timespec32.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-printmode.obj: printmode.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-printmode.obj -MD -MP -MF $(DEPDIR)/libstrace_a-printmode.Tpo -c -o libstrace_a-printmode.obj `if test -f 'printmode.c'; then $(CYGPATH_W) 'printmode.c'; else $(CYGPATH_W) '$(srcdir)/printmode.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-printmode.Tpo $(DEPDIR)/libstrace_a-printmode.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='printmode.c' object='libstrace_a-printmode.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_timespec32.o `test -f 'print_timespec32.c' || echo '$(srcdir)/'`print_timespec32.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-printmode.obj `if test -f 'printmode.c'; then $(CYGPATH_W) 'printmode.c'; else $(CYGPATH_W) '$(srcdir)/printmode.c'; fi`
 
-strace-print_timespec32.obj: print_timespec32.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_timespec32.obj -MD -MP -MF $(DEPDIR)/strace-print_timespec32.Tpo -c -o strace-print_timespec32.obj `if test -f 'print_timespec32.c'; then $(CYGPATH_W) 'print_timespec32.c'; else $(CYGPATH_W) '$(srcdir)/print_timespec32.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_timespec32.Tpo $(DEPDIR)/strace-print_timespec32.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_timespec32.c' object='strace-print_timespec32.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-printrusage.o: printrusage.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-printrusage.o -MD -MP -MF $(DEPDIR)/libstrace_a-printrusage.Tpo -c -o libstrace_a-printrusage.o `test -f 'printrusage.c' || echo '$(srcdir)/'`printrusage.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-printrusage.Tpo $(DEPDIR)/libstrace_a-printrusage.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='printrusage.c' object='libstrace_a-printrusage.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_timespec32.obj `if test -f 'print_timespec32.c'; then $(CYGPATH_W) 'print_timespec32.c'; else $(CYGPATH_W) '$(srcdir)/print_timespec32.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-printrusage.o `test -f 'printrusage.c' || echo '$(srcdir)/'`printrusage.c
 
-strace-print_timespec64.o: print_timespec64.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_timespec64.o -MD -MP -MF $(DEPDIR)/strace-print_timespec64.Tpo -c -o strace-print_timespec64.o `test -f 'print_timespec64.c' || echo '$(srcdir)/'`print_timespec64.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_timespec64.Tpo $(DEPDIR)/strace-print_timespec64.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_timespec64.c' object='strace-print_timespec64.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-printrusage.obj: printrusage.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-printrusage.obj -MD -MP -MF $(DEPDIR)/libstrace_a-printrusage.Tpo -c -o libstrace_a-printrusage.obj `if test -f 'printrusage.c'; then $(CYGPATH_W) 'printrusage.c'; else $(CYGPATH_W) '$(srcdir)/printrusage.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-printrusage.Tpo $(DEPDIR)/libstrace_a-printrusage.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='printrusage.c' object='libstrace_a-printrusage.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_timespec64.o `test -f 'print_timespec64.c' || echo '$(srcdir)/'`print_timespec64.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-printrusage.obj `if test -f 'printrusage.c'; then $(CYGPATH_W) 'printrusage.c'; else $(CYGPATH_W) '$(srcdir)/printrusage.c'; fi`
 
-strace-print_timespec64.obj: print_timespec64.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_timespec64.obj -MD -MP -MF $(DEPDIR)/strace-print_timespec64.Tpo -c -o strace-print_timespec64.obj `if test -f 'print_timespec64.c'; then $(CYGPATH_W) 'print_timespec64.c'; else $(CYGPATH_W) '$(srcdir)/print_timespec64.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_timespec64.Tpo $(DEPDIR)/strace-print_timespec64.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_timespec64.c' object='strace-print_timespec64.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-printsiginfo.o: printsiginfo.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-printsiginfo.o -MD -MP -MF $(DEPDIR)/libstrace_a-printsiginfo.Tpo -c -o libstrace_a-printsiginfo.o `test -f 'printsiginfo.c' || echo '$(srcdir)/'`printsiginfo.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-printsiginfo.Tpo $(DEPDIR)/libstrace_a-printsiginfo.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='printsiginfo.c' object='libstrace_a-printsiginfo.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_timespec64.obj `if test -f 'print_timespec64.c'; then $(CYGPATH_W) 'print_timespec64.c'; else $(CYGPATH_W) '$(srcdir)/print_timespec64.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-printsiginfo.o `test -f 'printsiginfo.c' || echo '$(srcdir)/'`printsiginfo.c
 
-strace-print_timeval.o: print_timeval.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_timeval.o -MD -MP -MF $(DEPDIR)/strace-print_timeval.Tpo -c -o strace-print_timeval.o `test -f 'print_timeval.c' || echo '$(srcdir)/'`print_timeval.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_timeval.Tpo $(DEPDIR)/strace-print_timeval.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_timeval.c' object='strace-print_timeval.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-printsiginfo.obj: printsiginfo.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-printsiginfo.obj -MD -MP -MF $(DEPDIR)/libstrace_a-printsiginfo.Tpo -c -o libstrace_a-printsiginfo.obj `if test -f 'printsiginfo.c'; then $(CYGPATH_W) 'printsiginfo.c'; else $(CYGPATH_W) '$(srcdir)/printsiginfo.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-printsiginfo.Tpo $(DEPDIR)/libstrace_a-printsiginfo.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='printsiginfo.c' object='libstrace_a-printsiginfo.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_timeval.o `test -f 'print_timeval.c' || echo '$(srcdir)/'`print_timeval.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-printsiginfo.obj `if test -f 'printsiginfo.c'; then $(CYGPATH_W) 'printsiginfo.c'; else $(CYGPATH_W) '$(srcdir)/printsiginfo.c'; fi`
 
-strace-print_timeval.obj: print_timeval.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_timeval.obj -MD -MP -MF $(DEPDIR)/strace-print_timeval.Tpo -c -o strace-print_timeval.obj `if test -f 'print_timeval.c'; then $(CYGPATH_W) 'print_timeval.c'; else $(CYGPATH_W) '$(srcdir)/print_timeval.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_timeval.Tpo $(DEPDIR)/strace-print_timeval.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_timeval.c' object='strace-print_timeval.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-process.o: process.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-process.o -MD -MP -MF $(DEPDIR)/libstrace_a-process.Tpo -c -o libstrace_a-process.o `test -f 'process.c' || echo '$(srcdir)/'`process.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-process.Tpo $(DEPDIR)/libstrace_a-process.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='process.c' object='libstrace_a-process.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_timeval.obj `if test -f 'print_timeval.c'; then $(CYGPATH_W) 'print_timeval.c'; else $(CYGPATH_W) '$(srcdir)/print_timeval.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-process.o `test -f 'process.c' || echo '$(srcdir)/'`process.c
 
-strace-print_timeval64.o: print_timeval64.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_timeval64.o -MD -MP -MF $(DEPDIR)/strace-print_timeval64.Tpo -c -o strace-print_timeval64.o `test -f 'print_timeval64.c' || echo '$(srcdir)/'`print_timeval64.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_timeval64.Tpo $(DEPDIR)/strace-print_timeval64.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_timeval64.c' object='strace-print_timeval64.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-process.obj: process.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-process.obj -MD -MP -MF $(DEPDIR)/libstrace_a-process.Tpo -c -o libstrace_a-process.obj `if test -f 'process.c'; then $(CYGPATH_W) 'process.c'; else $(CYGPATH_W) '$(srcdir)/process.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-process.Tpo $(DEPDIR)/libstrace_a-process.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='process.c' object='libstrace_a-process.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_timeval64.o `test -f 'print_timeval64.c' || echo '$(srcdir)/'`print_timeval64.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-process.obj `if test -f 'process.c'; then $(CYGPATH_W) 'process.c'; else $(CYGPATH_W) '$(srcdir)/process.c'; fi`
 
-strace-print_timeval64.obj: print_timeval64.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_timeval64.obj -MD -MP -MF $(DEPDIR)/strace-print_timeval64.Tpo -c -o strace-print_timeval64.obj `if test -f 'print_timeval64.c'; then $(CYGPATH_W) 'print_timeval64.c'; else $(CYGPATH_W) '$(srcdir)/print_timeval64.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_timeval64.Tpo $(DEPDIR)/strace-print_timeval64.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_timeval64.c' object='strace-print_timeval64.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-process_vm.o: process_vm.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-process_vm.o -MD -MP -MF $(DEPDIR)/libstrace_a-process_vm.Tpo -c -o libstrace_a-process_vm.o `test -f 'process_vm.c' || echo '$(srcdir)/'`process_vm.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-process_vm.Tpo $(DEPDIR)/libstrace_a-process_vm.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='process_vm.c' object='libstrace_a-process_vm.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_timeval64.obj `if test -f 'print_timeval64.c'; then $(CYGPATH_W) 'print_timeval64.c'; else $(CYGPATH_W) '$(srcdir)/print_timeval64.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-process_vm.o `test -f 'process_vm.c' || echo '$(srcdir)/'`process_vm.c
 
-strace-print_timex.o: print_timex.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_timex.o -MD -MP -MF $(DEPDIR)/strace-print_timex.Tpo -c -o strace-print_timex.o `test -f 'print_timex.c' || echo '$(srcdir)/'`print_timex.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_timex.Tpo $(DEPDIR)/strace-print_timex.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_timex.c' object='strace-print_timex.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-process_vm.obj: process_vm.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-process_vm.obj -MD -MP -MF $(DEPDIR)/libstrace_a-process_vm.Tpo -c -o libstrace_a-process_vm.obj `if test -f 'process_vm.c'; then $(CYGPATH_W) 'process_vm.c'; else $(CYGPATH_W) '$(srcdir)/process_vm.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-process_vm.Tpo $(DEPDIR)/libstrace_a-process_vm.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='process_vm.c' object='libstrace_a-process_vm.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_timex.o `test -f 'print_timex.c' || echo '$(srcdir)/'`print_timex.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-process_vm.obj `if test -f 'process_vm.c'; then $(CYGPATH_W) 'process_vm.c'; else $(CYGPATH_W) '$(srcdir)/process_vm.c'; fi`
 
-strace-print_timex.obj: print_timex.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-print_timex.obj -MD -MP -MF $(DEPDIR)/strace-print_timex.Tpo -c -o strace-print_timex.obj `if test -f 'print_timex.c'; then $(CYGPATH_W) 'print_timex.c'; else $(CYGPATH_W) '$(srcdir)/print_timex.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-print_timex.Tpo $(DEPDIR)/strace-print_timex.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='print_timex.c' object='strace-print_timex.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ptp.o: ptp.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ptp.o -MD -MP -MF $(DEPDIR)/libstrace_a-ptp.Tpo -c -o libstrace_a-ptp.o `test -f 'ptp.c' || echo '$(srcdir)/'`ptp.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ptp.Tpo $(DEPDIR)/libstrace_a-ptp.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ptp.c' object='libstrace_a-ptp.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-print_timex.obj `if test -f 'print_timex.c'; then $(CYGPATH_W) 'print_timex.c'; else $(CYGPATH_W) '$(srcdir)/print_timex.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ptp.o `test -f 'ptp.c' || echo '$(srcdir)/'`ptp.c
 
-strace-printmode.o: printmode.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-printmode.o -MD -MP -MF $(DEPDIR)/strace-printmode.Tpo -c -o strace-printmode.o `test -f 'printmode.c' || echo '$(srcdir)/'`printmode.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-printmode.Tpo $(DEPDIR)/strace-printmode.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='printmode.c' object='strace-printmode.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ptp.obj: ptp.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ptp.obj -MD -MP -MF $(DEPDIR)/libstrace_a-ptp.Tpo -c -o libstrace_a-ptp.obj `if test -f 'ptp.c'; then $(CYGPATH_W) 'ptp.c'; else $(CYGPATH_W) '$(srcdir)/ptp.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ptp.Tpo $(DEPDIR)/libstrace_a-ptp.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ptp.c' object='libstrace_a-ptp.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-printmode.o `test -f 'printmode.c' || echo '$(srcdir)/'`printmode.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ptp.obj `if test -f 'ptp.c'; then $(CYGPATH_W) 'ptp.c'; else $(CYGPATH_W) '$(srcdir)/ptp.c'; fi`
 
-strace-printmode.obj: printmode.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-printmode.obj -MD -MP -MF $(DEPDIR)/strace-printmode.Tpo -c -o strace-printmode.obj `if test -f 'printmode.c'; then $(CYGPATH_W) 'printmode.c'; else $(CYGPATH_W) '$(srcdir)/printmode.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-printmode.Tpo $(DEPDIR)/strace-printmode.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='printmode.c' object='strace-printmode.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ptrace_syscall_info.o: ptrace_syscall_info.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ptrace_syscall_info.o -MD -MP -MF $(DEPDIR)/libstrace_a-ptrace_syscall_info.Tpo -c -o libstrace_a-ptrace_syscall_info.o `test -f 'ptrace_syscall_info.c' || echo '$(srcdir)/'`ptrace_syscall_info.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ptrace_syscall_info.Tpo $(DEPDIR)/libstrace_a-ptrace_syscall_info.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ptrace_syscall_info.c' object='libstrace_a-ptrace_syscall_info.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-printmode.obj `if test -f 'printmode.c'; then $(CYGPATH_W) 'printmode.c'; else $(CYGPATH_W) '$(srcdir)/printmode.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ptrace_syscall_info.o `test -f 'ptrace_syscall_info.c' || echo '$(srcdir)/'`ptrace_syscall_info.c
 
-strace-printrusage.o: printrusage.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-printrusage.o -MD -MP -MF $(DEPDIR)/strace-printrusage.Tpo -c -o strace-printrusage.o `test -f 'printrusage.c' || echo '$(srcdir)/'`printrusage.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-printrusage.Tpo $(DEPDIR)/strace-printrusage.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='printrusage.c' object='strace-printrusage.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ptrace_syscall_info.obj: ptrace_syscall_info.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ptrace_syscall_info.obj -MD -MP -MF $(DEPDIR)/libstrace_a-ptrace_syscall_info.Tpo -c -o libstrace_a-ptrace_syscall_info.obj `if test -f 'ptrace_syscall_info.c'; then $(CYGPATH_W) 'ptrace_syscall_info.c'; else $(CYGPATH_W) '$(srcdir)/ptrace_syscall_info.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ptrace_syscall_info.Tpo $(DEPDIR)/libstrace_a-ptrace_syscall_info.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ptrace_syscall_info.c' object='libstrace_a-ptrace_syscall_info.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-printrusage.o `test -f 'printrusage.c' || echo '$(srcdir)/'`printrusage.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ptrace_syscall_info.obj `if test -f 'ptrace_syscall_info.c'; then $(CYGPATH_W) 'ptrace_syscall_info.c'; else $(CYGPATH_W) '$(srcdir)/ptrace_syscall_info.c'; fi`
 
-strace-printrusage.obj: printrusage.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-printrusage.obj -MD -MP -MF $(DEPDIR)/strace-printrusage.Tpo -c -o strace-printrusage.obj `if test -f 'printrusage.c'; then $(CYGPATH_W) 'printrusage.c'; else $(CYGPATH_W) '$(srcdir)/printrusage.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-printrusage.Tpo $(DEPDIR)/strace-printrusage.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='printrusage.c' object='strace-printrusage.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-quota.o: quota.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-quota.o -MD -MP -MF $(DEPDIR)/libstrace_a-quota.Tpo -c -o libstrace_a-quota.o `test -f 'quota.c' || echo '$(srcdir)/'`quota.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-quota.Tpo $(DEPDIR)/libstrace_a-quota.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='quota.c' object='libstrace_a-quota.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-printrusage.obj `if test -f 'printrusage.c'; then $(CYGPATH_W) 'printrusage.c'; else $(CYGPATH_W) '$(srcdir)/printrusage.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-quota.o `test -f 'quota.c' || echo '$(srcdir)/'`quota.c
 
-strace-printsiginfo.o: printsiginfo.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-printsiginfo.o -MD -MP -MF $(DEPDIR)/strace-printsiginfo.Tpo -c -o strace-printsiginfo.o `test -f 'printsiginfo.c' || echo '$(srcdir)/'`printsiginfo.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-printsiginfo.Tpo $(DEPDIR)/strace-printsiginfo.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='printsiginfo.c' object='strace-printsiginfo.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-quota.obj: quota.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-quota.obj -MD -MP -MF $(DEPDIR)/libstrace_a-quota.Tpo -c -o libstrace_a-quota.obj `if test -f 'quota.c'; then $(CYGPATH_W) 'quota.c'; else $(CYGPATH_W) '$(srcdir)/quota.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-quota.Tpo $(DEPDIR)/libstrace_a-quota.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='quota.c' object='libstrace_a-quota.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-printsiginfo.o `test -f 'printsiginfo.c' || echo '$(srcdir)/'`printsiginfo.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-quota.obj `if test -f 'quota.c'; then $(CYGPATH_W) 'quota.c'; else $(CYGPATH_W) '$(srcdir)/quota.c'; fi`
 
-strace-printsiginfo.obj: printsiginfo.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-printsiginfo.obj -MD -MP -MF $(DEPDIR)/strace-printsiginfo.Tpo -c -o strace-printsiginfo.obj `if test -f 'printsiginfo.c'; then $(CYGPATH_W) 'printsiginfo.c'; else $(CYGPATH_W) '$(srcdir)/printsiginfo.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-printsiginfo.Tpo $(DEPDIR)/strace-printsiginfo.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='printsiginfo.c' object='strace-printsiginfo.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-random_ioctl.o: random_ioctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-random_ioctl.o -MD -MP -MF $(DEPDIR)/libstrace_a-random_ioctl.Tpo -c -o libstrace_a-random_ioctl.o `test -f 'random_ioctl.c' || echo '$(srcdir)/'`random_ioctl.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-random_ioctl.Tpo $(DEPDIR)/libstrace_a-random_ioctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='random_ioctl.c' object='libstrace_a-random_ioctl.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-printsiginfo.obj `if test -f 'printsiginfo.c'; then $(CYGPATH_W) 'printsiginfo.c'; else $(CYGPATH_W) '$(srcdir)/printsiginfo.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-random_ioctl.o `test -f 'random_ioctl.c' || echo '$(srcdir)/'`random_ioctl.c
 
-strace-process.o: process.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-process.o -MD -MP -MF $(DEPDIR)/strace-process.Tpo -c -o strace-process.o `test -f 'process.c' || echo '$(srcdir)/'`process.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-process.Tpo $(DEPDIR)/strace-process.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='process.c' object='strace-process.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-random_ioctl.obj: random_ioctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-random_ioctl.obj -MD -MP -MF $(DEPDIR)/libstrace_a-random_ioctl.Tpo -c -o libstrace_a-random_ioctl.obj `if test -f 'random_ioctl.c'; then $(CYGPATH_W) 'random_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/random_ioctl.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-random_ioctl.Tpo $(DEPDIR)/libstrace_a-random_ioctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='random_ioctl.c' object='libstrace_a-random_ioctl.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-process.o `test -f 'process.c' || echo '$(srcdir)/'`process.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-random_ioctl.obj `if test -f 'random_ioctl.c'; then $(CYGPATH_W) 'random_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/random_ioctl.c'; fi`
 
-strace-process.obj: process.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-process.obj -MD -MP -MF $(DEPDIR)/strace-process.Tpo -c -o strace-process.obj `if test -f 'process.c'; then $(CYGPATH_W) 'process.c'; else $(CYGPATH_W) '$(srcdir)/process.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-process.Tpo $(DEPDIR)/strace-process.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='process.c' object='strace-process.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-readahead.o: readahead.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-readahead.o -MD -MP -MF $(DEPDIR)/libstrace_a-readahead.Tpo -c -o libstrace_a-readahead.o `test -f 'readahead.c' || echo '$(srcdir)/'`readahead.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-readahead.Tpo $(DEPDIR)/libstrace_a-readahead.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='readahead.c' object='libstrace_a-readahead.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-process.obj `if test -f 'process.c'; then $(CYGPATH_W) 'process.c'; else $(CYGPATH_W) '$(srcdir)/process.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-readahead.o `test -f 'readahead.c' || echo '$(srcdir)/'`readahead.c
 
-strace-process_vm.o: process_vm.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-process_vm.o -MD -MP -MF $(DEPDIR)/strace-process_vm.Tpo -c -o strace-process_vm.o `test -f 'process_vm.c' || echo '$(srcdir)/'`process_vm.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-process_vm.Tpo $(DEPDIR)/strace-process_vm.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='process_vm.c' object='strace-process_vm.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-readahead.obj: readahead.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-readahead.obj -MD -MP -MF $(DEPDIR)/libstrace_a-readahead.Tpo -c -o libstrace_a-readahead.obj `if test -f 'readahead.c'; then $(CYGPATH_W) 'readahead.c'; else $(CYGPATH_W) '$(srcdir)/readahead.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-readahead.Tpo $(DEPDIR)/libstrace_a-readahead.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='readahead.c' object='libstrace_a-readahead.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-process_vm.o `test -f 'process_vm.c' || echo '$(srcdir)/'`process_vm.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-readahead.obj `if test -f 'readahead.c'; then $(CYGPATH_W) 'readahead.c'; else $(CYGPATH_W) '$(srcdir)/readahead.c'; fi`
 
-strace-process_vm.obj: process_vm.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-process_vm.obj -MD -MP -MF $(DEPDIR)/strace-process_vm.Tpo -c -o strace-process_vm.obj `if test -f 'process_vm.c'; then $(CYGPATH_W) 'process_vm.c'; else $(CYGPATH_W) '$(srcdir)/process_vm.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-process_vm.Tpo $(DEPDIR)/strace-process_vm.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='process_vm.c' object='strace-process_vm.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-readlink.o: readlink.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-readlink.o -MD -MP -MF $(DEPDIR)/libstrace_a-readlink.Tpo -c -o libstrace_a-readlink.o `test -f 'readlink.c' || echo '$(srcdir)/'`readlink.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-readlink.Tpo $(DEPDIR)/libstrace_a-readlink.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='readlink.c' object='libstrace_a-readlink.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-process_vm.obj `if test -f 'process_vm.c'; then $(CYGPATH_W) 'process_vm.c'; else $(CYGPATH_W) '$(srcdir)/process_vm.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-readlink.o `test -f 'readlink.c' || echo '$(srcdir)/'`readlink.c
 
-strace-ptp.o: ptp.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ptp.o -MD -MP -MF $(DEPDIR)/strace-ptp.Tpo -c -o strace-ptp.o `test -f 'ptp.c' || echo '$(srcdir)/'`ptp.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ptp.Tpo $(DEPDIR)/strace-ptp.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ptp.c' object='strace-ptp.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-readlink.obj: readlink.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-readlink.obj -MD -MP -MF $(DEPDIR)/libstrace_a-readlink.Tpo -c -o libstrace_a-readlink.obj `if test -f 'readlink.c'; then $(CYGPATH_W) 'readlink.c'; else $(CYGPATH_W) '$(srcdir)/readlink.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-readlink.Tpo $(DEPDIR)/libstrace_a-readlink.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='readlink.c' object='libstrace_a-readlink.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ptp.o `test -f 'ptp.c' || echo '$(srcdir)/'`ptp.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-readlink.obj `if test -f 'readlink.c'; then $(CYGPATH_W) 'readlink.c'; else $(CYGPATH_W) '$(srcdir)/readlink.c'; fi`
 
-strace-ptp.obj: ptp.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ptp.obj -MD -MP -MF $(DEPDIR)/strace-ptp.Tpo -c -o strace-ptp.obj `if test -f 'ptp.c'; then $(CYGPATH_W) 'ptp.c'; else $(CYGPATH_W) '$(srcdir)/ptp.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ptp.Tpo $(DEPDIR)/strace-ptp.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ptp.c' object='strace-ptp.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-reboot.o: reboot.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-reboot.o -MD -MP -MF $(DEPDIR)/libstrace_a-reboot.Tpo -c -o libstrace_a-reboot.o `test -f 'reboot.c' || echo '$(srcdir)/'`reboot.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-reboot.Tpo $(DEPDIR)/libstrace_a-reboot.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='reboot.c' object='libstrace_a-reboot.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ptp.obj `if test -f 'ptp.c'; then $(CYGPATH_W) 'ptp.c'; else $(CYGPATH_W) '$(srcdir)/ptp.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-reboot.o `test -f 'reboot.c' || echo '$(srcdir)/'`reboot.c
 
-strace-ptrace_syscall_info.o: ptrace_syscall_info.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ptrace_syscall_info.o -MD -MP -MF $(DEPDIR)/strace-ptrace_syscall_info.Tpo -c -o strace-ptrace_syscall_info.o `test -f 'ptrace_syscall_info.c' || echo '$(srcdir)/'`ptrace_syscall_info.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ptrace_syscall_info.Tpo $(DEPDIR)/strace-ptrace_syscall_info.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ptrace_syscall_info.c' object='strace-ptrace_syscall_info.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-reboot.obj: reboot.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-reboot.obj -MD -MP -MF $(DEPDIR)/libstrace_a-reboot.Tpo -c -o libstrace_a-reboot.obj `if test -f 'reboot.c'; then $(CYGPATH_W) 'reboot.c'; else $(CYGPATH_W) '$(srcdir)/reboot.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-reboot.Tpo $(DEPDIR)/libstrace_a-reboot.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='reboot.c' object='libstrace_a-reboot.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ptrace_syscall_info.o `test -f 'ptrace_syscall_info.c' || echo '$(srcdir)/'`ptrace_syscall_info.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-reboot.obj `if test -f 'reboot.c'; then $(CYGPATH_W) 'reboot.c'; else $(CYGPATH_W) '$(srcdir)/reboot.c'; fi`
 
-strace-ptrace_syscall_info.obj: ptrace_syscall_info.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ptrace_syscall_info.obj -MD -MP -MF $(DEPDIR)/strace-ptrace_syscall_info.Tpo -c -o strace-ptrace_syscall_info.obj `if test -f 'ptrace_syscall_info.c'; then $(CYGPATH_W) 'ptrace_syscall_info.c'; else $(CYGPATH_W) '$(srcdir)/ptrace_syscall_info.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ptrace_syscall_info.Tpo $(DEPDIR)/strace-ptrace_syscall_info.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ptrace_syscall_info.c' object='strace-ptrace_syscall_info.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-renameat.o: renameat.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-renameat.o -MD -MP -MF $(DEPDIR)/libstrace_a-renameat.Tpo -c -o libstrace_a-renameat.o `test -f 'renameat.c' || echo '$(srcdir)/'`renameat.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-renameat.Tpo $(DEPDIR)/libstrace_a-renameat.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='renameat.c' object='libstrace_a-renameat.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ptrace_syscall_info.obj `if test -f 'ptrace_syscall_info.c'; then $(CYGPATH_W) 'ptrace_syscall_info.c'; else $(CYGPATH_W) '$(srcdir)/ptrace_syscall_info.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-renameat.o `test -f 'renameat.c' || echo '$(srcdir)/'`renameat.c
 
-strace-quota.o: quota.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-quota.o -MD -MP -MF $(DEPDIR)/strace-quota.Tpo -c -o strace-quota.o `test -f 'quota.c' || echo '$(srcdir)/'`quota.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-quota.Tpo $(DEPDIR)/strace-quota.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='quota.c' object='strace-quota.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-renameat.obj: renameat.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-renameat.obj -MD -MP -MF $(DEPDIR)/libstrace_a-renameat.Tpo -c -o libstrace_a-renameat.obj `if test -f 'renameat.c'; then $(CYGPATH_W) 'renameat.c'; else $(CYGPATH_W) '$(srcdir)/renameat.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-renameat.Tpo $(DEPDIR)/libstrace_a-renameat.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='renameat.c' object='libstrace_a-renameat.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-quota.o `test -f 'quota.c' || echo '$(srcdir)/'`quota.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-renameat.obj `if test -f 'renameat.c'; then $(CYGPATH_W) 'renameat.c'; else $(CYGPATH_W) '$(srcdir)/renameat.c'; fi`
 
-strace-quota.obj: quota.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-quota.obj -MD -MP -MF $(DEPDIR)/strace-quota.Tpo -c -o strace-quota.obj `if test -f 'quota.c'; then $(CYGPATH_W) 'quota.c'; else $(CYGPATH_W) '$(srcdir)/quota.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-quota.Tpo $(DEPDIR)/strace-quota.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='quota.c' object='strace-quota.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-resource.o: resource.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-resource.o -MD -MP -MF $(DEPDIR)/libstrace_a-resource.Tpo -c -o libstrace_a-resource.o `test -f 'resource.c' || echo '$(srcdir)/'`resource.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-resource.Tpo $(DEPDIR)/libstrace_a-resource.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='resource.c' object='libstrace_a-resource.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-quota.obj `if test -f 'quota.c'; then $(CYGPATH_W) 'quota.c'; else $(CYGPATH_W) '$(srcdir)/quota.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-resource.o `test -f 'resource.c' || echo '$(srcdir)/'`resource.c
 
-strace-random_ioctl.o: random_ioctl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-random_ioctl.o -MD -MP -MF $(DEPDIR)/strace-random_ioctl.Tpo -c -o strace-random_ioctl.o `test -f 'random_ioctl.c' || echo '$(srcdir)/'`random_ioctl.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-random_ioctl.Tpo $(DEPDIR)/strace-random_ioctl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='random_ioctl.c' object='strace-random_ioctl.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-resource.obj: resource.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-resource.obj -MD -MP -MF $(DEPDIR)/libstrace_a-resource.Tpo -c -o libstrace_a-resource.obj `if test -f 'resource.c'; then $(CYGPATH_W) 'resource.c'; else $(CYGPATH_W) '$(srcdir)/resource.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-resource.Tpo $(DEPDIR)/libstrace_a-resource.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='resource.c' object='libstrace_a-resource.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-random_ioctl.o `test -f 'random_ioctl.c' || echo '$(srcdir)/'`random_ioctl.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-resource.obj `if test -f 'resource.c'; then $(CYGPATH_W) 'resource.c'; else $(CYGPATH_W) '$(srcdir)/resource.c'; fi`
 
-strace-random_ioctl.obj: random_ioctl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-random_ioctl.obj -MD -MP -MF $(DEPDIR)/strace-random_ioctl.Tpo -c -o strace-random_ioctl.obj `if test -f 'random_ioctl.c'; then $(CYGPATH_W) 'random_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/random_ioctl.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-random_ioctl.Tpo $(DEPDIR)/strace-random_ioctl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='random_ioctl.c' object='strace-random_ioctl.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-retval.o: retval.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-retval.o -MD -MP -MF $(DEPDIR)/libstrace_a-retval.Tpo -c -o libstrace_a-retval.o `test -f 'retval.c' || echo '$(srcdir)/'`retval.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-retval.Tpo $(DEPDIR)/libstrace_a-retval.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='retval.c' object='libstrace_a-retval.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-random_ioctl.obj `if test -f 'random_ioctl.c'; then $(CYGPATH_W) 'random_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/random_ioctl.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-retval.o `test -f 'retval.c' || echo '$(srcdir)/'`retval.c
 
-strace-readahead.o: readahead.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-readahead.o -MD -MP -MF $(DEPDIR)/strace-readahead.Tpo -c -o strace-readahead.o `test -f 'readahead.c' || echo '$(srcdir)/'`readahead.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-readahead.Tpo $(DEPDIR)/strace-readahead.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='readahead.c' object='strace-readahead.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-retval.obj: retval.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-retval.obj -MD -MP -MF $(DEPDIR)/libstrace_a-retval.Tpo -c -o libstrace_a-retval.obj `if test -f 'retval.c'; then $(CYGPATH_W) 'retval.c'; else $(CYGPATH_W) '$(srcdir)/retval.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-retval.Tpo $(DEPDIR)/libstrace_a-retval.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='retval.c' object='libstrace_a-retval.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-readahead.o `test -f 'readahead.c' || echo '$(srcdir)/'`readahead.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-retval.obj `if test -f 'retval.c'; then $(CYGPATH_W) 'retval.c'; else $(CYGPATH_W) '$(srcdir)/retval.c'; fi`
 
-strace-readahead.obj: readahead.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-readahead.obj -MD -MP -MF $(DEPDIR)/strace-readahead.Tpo -c -o strace-readahead.obj `if test -f 'readahead.c'; then $(CYGPATH_W) 'readahead.c'; else $(CYGPATH_W) '$(srcdir)/readahead.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-readahead.Tpo $(DEPDIR)/strace-readahead.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='readahead.c' object='strace-readahead.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-riscv.o: riscv.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-riscv.o -MD -MP -MF $(DEPDIR)/libstrace_a-riscv.Tpo -c -o libstrace_a-riscv.o `test -f 'riscv.c' || echo '$(srcdir)/'`riscv.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-riscv.Tpo $(DEPDIR)/libstrace_a-riscv.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='riscv.c' object='libstrace_a-riscv.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-readahead.obj `if test -f 'readahead.c'; then $(CYGPATH_W) 'readahead.c'; else $(CYGPATH_W) '$(srcdir)/readahead.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-riscv.o `test -f 'riscv.c' || echo '$(srcdir)/'`riscv.c
 
-strace-readlink.o: readlink.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-readlink.o -MD -MP -MF $(DEPDIR)/strace-readlink.Tpo -c -o strace-readlink.o `test -f 'readlink.c' || echo '$(srcdir)/'`readlink.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-readlink.Tpo $(DEPDIR)/strace-readlink.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='readlink.c' object='strace-readlink.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-riscv.obj: riscv.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-riscv.obj -MD -MP -MF $(DEPDIR)/libstrace_a-riscv.Tpo -c -o libstrace_a-riscv.obj `if test -f 'riscv.c'; then $(CYGPATH_W) 'riscv.c'; else $(CYGPATH_W) '$(srcdir)/riscv.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-riscv.Tpo $(DEPDIR)/libstrace_a-riscv.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='riscv.c' object='libstrace_a-riscv.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-readlink.o `test -f 'readlink.c' || echo '$(srcdir)/'`readlink.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-riscv.obj `if test -f 'riscv.c'; then $(CYGPATH_W) 'riscv.c'; else $(CYGPATH_W) '$(srcdir)/riscv.c'; fi`
 
-strace-readlink.obj: readlink.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-readlink.obj -MD -MP -MF $(DEPDIR)/strace-readlink.Tpo -c -o strace-readlink.obj `if test -f 'readlink.c'; then $(CYGPATH_W) 'readlink.c'; else $(CYGPATH_W) '$(srcdir)/readlink.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-readlink.Tpo $(DEPDIR)/strace-readlink.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='readlink.c' object='strace-readlink.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rt_sigframe.o: rt_sigframe.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rt_sigframe.o -MD -MP -MF $(DEPDIR)/libstrace_a-rt_sigframe.Tpo -c -o libstrace_a-rt_sigframe.o `test -f 'rt_sigframe.c' || echo '$(srcdir)/'`rt_sigframe.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rt_sigframe.Tpo $(DEPDIR)/libstrace_a-rt_sigframe.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rt_sigframe.c' object='libstrace_a-rt_sigframe.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-readlink.obj `if test -f 'readlink.c'; then $(CYGPATH_W) 'readlink.c'; else $(CYGPATH_W) '$(srcdir)/readlink.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rt_sigframe.o `test -f 'rt_sigframe.c' || echo '$(srcdir)/'`rt_sigframe.c
 
-strace-reboot.o: reboot.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-reboot.o -MD -MP -MF $(DEPDIR)/strace-reboot.Tpo -c -o strace-reboot.o `test -f 'reboot.c' || echo '$(srcdir)/'`reboot.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-reboot.Tpo $(DEPDIR)/strace-reboot.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='reboot.c' object='strace-reboot.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rt_sigframe.obj: rt_sigframe.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rt_sigframe.obj -MD -MP -MF $(DEPDIR)/libstrace_a-rt_sigframe.Tpo -c -o libstrace_a-rt_sigframe.obj `if test -f 'rt_sigframe.c'; then $(CYGPATH_W) 'rt_sigframe.c'; else $(CYGPATH_W) '$(srcdir)/rt_sigframe.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rt_sigframe.Tpo $(DEPDIR)/libstrace_a-rt_sigframe.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rt_sigframe.c' object='libstrace_a-rt_sigframe.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-reboot.o `test -f 'reboot.c' || echo '$(srcdir)/'`reboot.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rt_sigframe.obj `if test -f 'rt_sigframe.c'; then $(CYGPATH_W) 'rt_sigframe.c'; else $(CYGPATH_W) '$(srcdir)/rt_sigframe.c'; fi`
 
-strace-reboot.obj: reboot.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-reboot.obj -MD -MP -MF $(DEPDIR)/strace-reboot.Tpo -c -o strace-reboot.obj `if test -f 'reboot.c'; then $(CYGPATH_W) 'reboot.c'; else $(CYGPATH_W) '$(srcdir)/reboot.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-reboot.Tpo $(DEPDIR)/strace-reboot.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='reboot.c' object='strace-reboot.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rt_sigreturn.o: rt_sigreturn.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rt_sigreturn.o -MD -MP -MF $(DEPDIR)/libstrace_a-rt_sigreturn.Tpo -c -o libstrace_a-rt_sigreturn.o `test -f 'rt_sigreturn.c' || echo '$(srcdir)/'`rt_sigreturn.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rt_sigreturn.Tpo $(DEPDIR)/libstrace_a-rt_sigreturn.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rt_sigreturn.c' object='libstrace_a-rt_sigreturn.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-reboot.obj `if test -f 'reboot.c'; then $(CYGPATH_W) 'reboot.c'; else $(CYGPATH_W) '$(srcdir)/reboot.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rt_sigreturn.o `test -f 'rt_sigreturn.c' || echo '$(srcdir)/'`rt_sigreturn.c
 
-strace-renameat.o: renameat.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-renameat.o -MD -MP -MF $(DEPDIR)/strace-renameat.Tpo -c -o strace-renameat.o `test -f 'renameat.c' || echo '$(srcdir)/'`renameat.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-renameat.Tpo $(DEPDIR)/strace-renameat.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='renameat.c' object='strace-renameat.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rt_sigreturn.obj: rt_sigreturn.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rt_sigreturn.obj -MD -MP -MF $(DEPDIR)/libstrace_a-rt_sigreturn.Tpo -c -o libstrace_a-rt_sigreturn.obj `if test -f 'rt_sigreturn.c'; then $(CYGPATH_W) 'rt_sigreturn.c'; else $(CYGPATH_W) '$(srcdir)/rt_sigreturn.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rt_sigreturn.Tpo $(DEPDIR)/libstrace_a-rt_sigreturn.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rt_sigreturn.c' object='libstrace_a-rt_sigreturn.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-renameat.o `test -f 'renameat.c' || echo '$(srcdir)/'`renameat.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rt_sigreturn.obj `if test -f 'rt_sigreturn.c'; then $(CYGPATH_W) 'rt_sigreturn.c'; else $(CYGPATH_W) '$(srcdir)/rt_sigreturn.c'; fi`
 
-strace-renameat.obj: renameat.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-renameat.obj -MD -MP -MF $(DEPDIR)/strace-renameat.Tpo -c -o strace-renameat.obj `if test -f 'renameat.c'; then $(CYGPATH_W) 'renameat.c'; else $(CYGPATH_W) '$(srcdir)/renameat.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-renameat.Tpo $(DEPDIR)/strace-renameat.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='renameat.c' object='strace-renameat.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtc.o: rtc.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtc.o -MD -MP -MF $(DEPDIR)/libstrace_a-rtc.Tpo -c -o libstrace_a-rtc.o `test -f 'rtc.c' || echo '$(srcdir)/'`rtc.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtc.Tpo $(DEPDIR)/libstrace_a-rtc.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtc.c' object='libstrace_a-rtc.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-renameat.obj `if test -f 'renameat.c'; then $(CYGPATH_W) 'renameat.c'; else $(CYGPATH_W) '$(srcdir)/renameat.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtc.o `test -f 'rtc.c' || echo '$(srcdir)/'`rtc.c
 
-strace-resource.o: resource.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-resource.o -MD -MP -MF $(DEPDIR)/strace-resource.Tpo -c -o strace-resource.o `test -f 'resource.c' || echo '$(srcdir)/'`resource.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-resource.Tpo $(DEPDIR)/strace-resource.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='resource.c' object='strace-resource.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtc.obj: rtc.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtc.obj -MD -MP -MF $(DEPDIR)/libstrace_a-rtc.Tpo -c -o libstrace_a-rtc.obj `if test -f 'rtc.c'; then $(CYGPATH_W) 'rtc.c'; else $(CYGPATH_W) '$(srcdir)/rtc.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtc.Tpo $(DEPDIR)/libstrace_a-rtc.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtc.c' object='libstrace_a-rtc.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-resource.o `test -f 'resource.c' || echo '$(srcdir)/'`resource.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtc.obj `if test -f 'rtc.c'; then $(CYGPATH_W) 'rtc.c'; else $(CYGPATH_W) '$(srcdir)/rtc.c'; fi`
 
-strace-resource.obj: resource.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-resource.obj -MD -MP -MF $(DEPDIR)/strace-resource.Tpo -c -o strace-resource.obj `if test -f 'resource.c'; then $(CYGPATH_W) 'resource.c'; else $(CYGPATH_W) '$(srcdir)/resource.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-resource.Tpo $(DEPDIR)/strace-resource.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='resource.c' object='strace-resource.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtnl_addr.o: rtnl_addr.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtnl_addr.o -MD -MP -MF $(DEPDIR)/libstrace_a-rtnl_addr.Tpo -c -o libstrace_a-rtnl_addr.o `test -f 'rtnl_addr.c' || echo '$(srcdir)/'`rtnl_addr.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtnl_addr.Tpo $(DEPDIR)/libstrace_a-rtnl_addr.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_addr.c' object='libstrace_a-rtnl_addr.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-resource.obj `if test -f 'resource.c'; then $(CYGPATH_W) 'resource.c'; else $(CYGPATH_W) '$(srcdir)/resource.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtnl_addr.o `test -f 'rtnl_addr.c' || echo '$(srcdir)/'`rtnl_addr.c
 
-strace-retval.o: retval.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-retval.o -MD -MP -MF $(DEPDIR)/strace-retval.Tpo -c -o strace-retval.o `test -f 'retval.c' || echo '$(srcdir)/'`retval.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-retval.Tpo $(DEPDIR)/strace-retval.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='retval.c' object='strace-retval.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtnl_addr.obj: rtnl_addr.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtnl_addr.obj -MD -MP -MF $(DEPDIR)/libstrace_a-rtnl_addr.Tpo -c -o libstrace_a-rtnl_addr.obj `if test -f 'rtnl_addr.c'; then $(CYGPATH_W) 'rtnl_addr.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_addr.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtnl_addr.Tpo $(DEPDIR)/libstrace_a-rtnl_addr.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_addr.c' object='libstrace_a-rtnl_addr.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-retval.o `test -f 'retval.c' || echo '$(srcdir)/'`retval.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtnl_addr.obj `if test -f 'rtnl_addr.c'; then $(CYGPATH_W) 'rtnl_addr.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_addr.c'; fi`
 
-strace-retval.obj: retval.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-retval.obj -MD -MP -MF $(DEPDIR)/strace-retval.Tpo -c -o strace-retval.obj `if test -f 'retval.c'; then $(CYGPATH_W) 'retval.c'; else $(CYGPATH_W) '$(srcdir)/retval.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-retval.Tpo $(DEPDIR)/strace-retval.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='retval.c' object='strace-retval.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtnl_addrlabel.o: rtnl_addrlabel.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtnl_addrlabel.o -MD -MP -MF $(DEPDIR)/libstrace_a-rtnl_addrlabel.Tpo -c -o libstrace_a-rtnl_addrlabel.o `test -f 'rtnl_addrlabel.c' || echo '$(srcdir)/'`rtnl_addrlabel.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtnl_addrlabel.Tpo $(DEPDIR)/libstrace_a-rtnl_addrlabel.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_addrlabel.c' object='libstrace_a-rtnl_addrlabel.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-retval.obj `if test -f 'retval.c'; then $(CYGPATH_W) 'retval.c'; else $(CYGPATH_W) '$(srcdir)/retval.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtnl_addrlabel.o `test -f 'rtnl_addrlabel.c' || echo '$(srcdir)/'`rtnl_addrlabel.c
 
-strace-riscv.o: riscv.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-riscv.o -MD -MP -MF $(DEPDIR)/strace-riscv.Tpo -c -o strace-riscv.o `test -f 'riscv.c' || echo '$(srcdir)/'`riscv.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-riscv.Tpo $(DEPDIR)/strace-riscv.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='riscv.c' object='strace-riscv.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtnl_addrlabel.obj: rtnl_addrlabel.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtnl_addrlabel.obj -MD -MP -MF $(DEPDIR)/libstrace_a-rtnl_addrlabel.Tpo -c -o libstrace_a-rtnl_addrlabel.obj `if test -f 'rtnl_addrlabel.c'; then $(CYGPATH_W) 'rtnl_addrlabel.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_addrlabel.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtnl_addrlabel.Tpo $(DEPDIR)/libstrace_a-rtnl_addrlabel.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_addrlabel.c' object='libstrace_a-rtnl_addrlabel.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-riscv.o `test -f 'riscv.c' || echo '$(srcdir)/'`riscv.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtnl_addrlabel.obj `if test -f 'rtnl_addrlabel.c'; then $(CYGPATH_W) 'rtnl_addrlabel.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_addrlabel.c'; fi`
 
-strace-riscv.obj: riscv.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-riscv.obj -MD -MP -MF $(DEPDIR)/strace-riscv.Tpo -c -o strace-riscv.obj `if test -f 'riscv.c'; then $(CYGPATH_W) 'riscv.c'; else $(CYGPATH_W) '$(srcdir)/riscv.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-riscv.Tpo $(DEPDIR)/strace-riscv.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='riscv.c' object='strace-riscv.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtnl_dcb.o: rtnl_dcb.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtnl_dcb.o -MD -MP -MF $(DEPDIR)/libstrace_a-rtnl_dcb.Tpo -c -o libstrace_a-rtnl_dcb.o `test -f 'rtnl_dcb.c' || echo '$(srcdir)/'`rtnl_dcb.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtnl_dcb.Tpo $(DEPDIR)/libstrace_a-rtnl_dcb.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_dcb.c' object='libstrace_a-rtnl_dcb.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-riscv.obj `if test -f 'riscv.c'; then $(CYGPATH_W) 'riscv.c'; else $(CYGPATH_W) '$(srcdir)/riscv.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtnl_dcb.o `test -f 'rtnl_dcb.c' || echo '$(srcdir)/'`rtnl_dcb.c
 
-strace-rt_sigframe.o: rt_sigframe.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rt_sigframe.o -MD -MP -MF $(DEPDIR)/strace-rt_sigframe.Tpo -c -o strace-rt_sigframe.o `test -f 'rt_sigframe.c' || echo '$(srcdir)/'`rt_sigframe.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rt_sigframe.Tpo $(DEPDIR)/strace-rt_sigframe.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rt_sigframe.c' object='strace-rt_sigframe.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtnl_dcb.obj: rtnl_dcb.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtnl_dcb.obj -MD -MP -MF $(DEPDIR)/libstrace_a-rtnl_dcb.Tpo -c -o libstrace_a-rtnl_dcb.obj `if test -f 'rtnl_dcb.c'; then $(CYGPATH_W) 'rtnl_dcb.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_dcb.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtnl_dcb.Tpo $(DEPDIR)/libstrace_a-rtnl_dcb.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_dcb.c' object='libstrace_a-rtnl_dcb.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rt_sigframe.o `test -f 'rt_sigframe.c' || echo '$(srcdir)/'`rt_sigframe.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtnl_dcb.obj `if test -f 'rtnl_dcb.c'; then $(CYGPATH_W) 'rtnl_dcb.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_dcb.c'; fi`
 
-strace-rt_sigframe.obj: rt_sigframe.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rt_sigframe.obj -MD -MP -MF $(DEPDIR)/strace-rt_sigframe.Tpo -c -o strace-rt_sigframe.obj `if test -f 'rt_sigframe.c'; then $(CYGPATH_W) 'rt_sigframe.c'; else $(CYGPATH_W) '$(srcdir)/rt_sigframe.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rt_sigframe.Tpo $(DEPDIR)/strace-rt_sigframe.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rt_sigframe.c' object='strace-rt_sigframe.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtnl_link.o: rtnl_link.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtnl_link.o -MD -MP -MF $(DEPDIR)/libstrace_a-rtnl_link.Tpo -c -o libstrace_a-rtnl_link.o `test -f 'rtnl_link.c' || echo '$(srcdir)/'`rtnl_link.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtnl_link.Tpo $(DEPDIR)/libstrace_a-rtnl_link.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_link.c' object='libstrace_a-rtnl_link.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rt_sigframe.obj `if test -f 'rt_sigframe.c'; then $(CYGPATH_W) 'rt_sigframe.c'; else $(CYGPATH_W) '$(srcdir)/rt_sigframe.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtnl_link.o `test -f 'rtnl_link.c' || echo '$(srcdir)/'`rtnl_link.c
 
-strace-rt_sigreturn.o: rt_sigreturn.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rt_sigreturn.o -MD -MP -MF $(DEPDIR)/strace-rt_sigreturn.Tpo -c -o strace-rt_sigreturn.o `test -f 'rt_sigreturn.c' || echo '$(srcdir)/'`rt_sigreturn.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rt_sigreturn.Tpo $(DEPDIR)/strace-rt_sigreturn.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rt_sigreturn.c' object='strace-rt_sigreturn.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtnl_link.obj: rtnl_link.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtnl_link.obj -MD -MP -MF $(DEPDIR)/libstrace_a-rtnl_link.Tpo -c -o libstrace_a-rtnl_link.obj `if test -f 'rtnl_link.c'; then $(CYGPATH_W) 'rtnl_link.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_link.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtnl_link.Tpo $(DEPDIR)/libstrace_a-rtnl_link.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_link.c' object='libstrace_a-rtnl_link.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rt_sigreturn.o `test -f 'rt_sigreturn.c' || echo '$(srcdir)/'`rt_sigreturn.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtnl_link.obj `if test -f 'rtnl_link.c'; then $(CYGPATH_W) 'rtnl_link.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_link.c'; fi`
 
-strace-rt_sigreturn.obj: rt_sigreturn.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rt_sigreturn.obj -MD -MP -MF $(DEPDIR)/strace-rt_sigreturn.Tpo -c -o strace-rt_sigreturn.obj `if test -f 'rt_sigreturn.c'; then $(CYGPATH_W) 'rt_sigreturn.c'; else $(CYGPATH_W) '$(srcdir)/rt_sigreturn.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rt_sigreturn.Tpo $(DEPDIR)/strace-rt_sigreturn.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rt_sigreturn.c' object='strace-rt_sigreturn.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtnl_mdb.o: rtnl_mdb.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtnl_mdb.o -MD -MP -MF $(DEPDIR)/libstrace_a-rtnl_mdb.Tpo -c -o libstrace_a-rtnl_mdb.o `test -f 'rtnl_mdb.c' || echo '$(srcdir)/'`rtnl_mdb.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtnl_mdb.Tpo $(DEPDIR)/libstrace_a-rtnl_mdb.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_mdb.c' object='libstrace_a-rtnl_mdb.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rt_sigreturn.obj `if test -f 'rt_sigreturn.c'; then $(CYGPATH_W) 'rt_sigreturn.c'; else $(CYGPATH_W) '$(srcdir)/rt_sigreturn.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtnl_mdb.o `test -f 'rtnl_mdb.c' || echo '$(srcdir)/'`rtnl_mdb.c
 
-strace-rtc.o: rtc.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtc.o -MD -MP -MF $(DEPDIR)/strace-rtc.Tpo -c -o strace-rtc.o `test -f 'rtc.c' || echo '$(srcdir)/'`rtc.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtc.Tpo $(DEPDIR)/strace-rtc.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtc.c' object='strace-rtc.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtnl_mdb.obj: rtnl_mdb.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtnl_mdb.obj -MD -MP -MF $(DEPDIR)/libstrace_a-rtnl_mdb.Tpo -c -o libstrace_a-rtnl_mdb.obj `if test -f 'rtnl_mdb.c'; then $(CYGPATH_W) 'rtnl_mdb.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_mdb.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtnl_mdb.Tpo $(DEPDIR)/libstrace_a-rtnl_mdb.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_mdb.c' object='libstrace_a-rtnl_mdb.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtc.o `test -f 'rtc.c' || echo '$(srcdir)/'`rtc.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtnl_mdb.obj `if test -f 'rtnl_mdb.c'; then $(CYGPATH_W) 'rtnl_mdb.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_mdb.c'; fi`
 
-strace-rtc.obj: rtc.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtc.obj -MD -MP -MF $(DEPDIR)/strace-rtc.Tpo -c -o strace-rtc.obj `if test -f 'rtc.c'; then $(CYGPATH_W) 'rtc.c'; else $(CYGPATH_W) '$(srcdir)/rtc.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtc.Tpo $(DEPDIR)/strace-rtc.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtc.c' object='strace-rtc.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtnl_neigh.o: rtnl_neigh.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtnl_neigh.o -MD -MP -MF $(DEPDIR)/libstrace_a-rtnl_neigh.Tpo -c -o libstrace_a-rtnl_neigh.o `test -f 'rtnl_neigh.c' || echo '$(srcdir)/'`rtnl_neigh.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtnl_neigh.Tpo $(DEPDIR)/libstrace_a-rtnl_neigh.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_neigh.c' object='libstrace_a-rtnl_neigh.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtc.obj `if test -f 'rtc.c'; then $(CYGPATH_W) 'rtc.c'; else $(CYGPATH_W) '$(srcdir)/rtc.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtnl_neigh.o `test -f 'rtnl_neigh.c' || echo '$(srcdir)/'`rtnl_neigh.c
 
-strace-rtnl_addr.o: rtnl_addr.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtnl_addr.o -MD -MP -MF $(DEPDIR)/strace-rtnl_addr.Tpo -c -o strace-rtnl_addr.o `test -f 'rtnl_addr.c' || echo '$(srcdir)/'`rtnl_addr.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtnl_addr.Tpo $(DEPDIR)/strace-rtnl_addr.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_addr.c' object='strace-rtnl_addr.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtnl_neigh.obj: rtnl_neigh.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtnl_neigh.obj -MD -MP -MF $(DEPDIR)/libstrace_a-rtnl_neigh.Tpo -c -o libstrace_a-rtnl_neigh.obj `if test -f 'rtnl_neigh.c'; then $(CYGPATH_W) 'rtnl_neigh.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_neigh.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtnl_neigh.Tpo $(DEPDIR)/libstrace_a-rtnl_neigh.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_neigh.c' object='libstrace_a-rtnl_neigh.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtnl_addr.o `test -f 'rtnl_addr.c' || echo '$(srcdir)/'`rtnl_addr.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtnl_neigh.obj `if test -f 'rtnl_neigh.c'; then $(CYGPATH_W) 'rtnl_neigh.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_neigh.c'; fi`
 
-strace-rtnl_addr.obj: rtnl_addr.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtnl_addr.obj -MD -MP -MF $(DEPDIR)/strace-rtnl_addr.Tpo -c -o strace-rtnl_addr.obj `if test -f 'rtnl_addr.c'; then $(CYGPATH_W) 'rtnl_addr.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_addr.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtnl_addr.Tpo $(DEPDIR)/strace-rtnl_addr.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_addr.c' object='strace-rtnl_addr.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtnl_neightbl.o: rtnl_neightbl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtnl_neightbl.o -MD -MP -MF $(DEPDIR)/libstrace_a-rtnl_neightbl.Tpo -c -o libstrace_a-rtnl_neightbl.o `test -f 'rtnl_neightbl.c' || echo '$(srcdir)/'`rtnl_neightbl.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtnl_neightbl.Tpo $(DEPDIR)/libstrace_a-rtnl_neightbl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_neightbl.c' object='libstrace_a-rtnl_neightbl.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtnl_addr.obj `if test -f 'rtnl_addr.c'; then $(CYGPATH_W) 'rtnl_addr.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_addr.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtnl_neightbl.o `test -f 'rtnl_neightbl.c' || echo '$(srcdir)/'`rtnl_neightbl.c
 
-strace-rtnl_addrlabel.o: rtnl_addrlabel.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtnl_addrlabel.o -MD -MP -MF $(DEPDIR)/strace-rtnl_addrlabel.Tpo -c -o strace-rtnl_addrlabel.o `test -f 'rtnl_addrlabel.c' || echo '$(srcdir)/'`rtnl_addrlabel.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtnl_addrlabel.Tpo $(DEPDIR)/strace-rtnl_addrlabel.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_addrlabel.c' object='strace-rtnl_addrlabel.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtnl_neightbl.obj: rtnl_neightbl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtnl_neightbl.obj -MD -MP -MF $(DEPDIR)/libstrace_a-rtnl_neightbl.Tpo -c -o libstrace_a-rtnl_neightbl.obj `if test -f 'rtnl_neightbl.c'; then $(CYGPATH_W) 'rtnl_neightbl.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_neightbl.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtnl_neightbl.Tpo $(DEPDIR)/libstrace_a-rtnl_neightbl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_neightbl.c' object='libstrace_a-rtnl_neightbl.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtnl_addrlabel.o `test -f 'rtnl_addrlabel.c' || echo '$(srcdir)/'`rtnl_addrlabel.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtnl_neightbl.obj `if test -f 'rtnl_neightbl.c'; then $(CYGPATH_W) 'rtnl_neightbl.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_neightbl.c'; fi`
 
-strace-rtnl_addrlabel.obj: rtnl_addrlabel.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtnl_addrlabel.obj -MD -MP -MF $(DEPDIR)/strace-rtnl_addrlabel.Tpo -c -o strace-rtnl_addrlabel.obj `if test -f 'rtnl_addrlabel.c'; then $(CYGPATH_W) 'rtnl_addrlabel.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_addrlabel.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtnl_addrlabel.Tpo $(DEPDIR)/strace-rtnl_addrlabel.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_addrlabel.c' object='strace-rtnl_addrlabel.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtnl_netconf.o: rtnl_netconf.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtnl_netconf.o -MD -MP -MF $(DEPDIR)/libstrace_a-rtnl_netconf.Tpo -c -o libstrace_a-rtnl_netconf.o `test -f 'rtnl_netconf.c' || echo '$(srcdir)/'`rtnl_netconf.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtnl_netconf.Tpo $(DEPDIR)/libstrace_a-rtnl_netconf.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_netconf.c' object='libstrace_a-rtnl_netconf.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtnl_addrlabel.obj `if test -f 'rtnl_addrlabel.c'; then $(CYGPATH_W) 'rtnl_addrlabel.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_addrlabel.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtnl_netconf.o `test -f 'rtnl_netconf.c' || echo '$(srcdir)/'`rtnl_netconf.c
 
-strace-rtnl_dcb.o: rtnl_dcb.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtnl_dcb.o -MD -MP -MF $(DEPDIR)/strace-rtnl_dcb.Tpo -c -o strace-rtnl_dcb.o `test -f 'rtnl_dcb.c' || echo '$(srcdir)/'`rtnl_dcb.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtnl_dcb.Tpo $(DEPDIR)/strace-rtnl_dcb.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_dcb.c' object='strace-rtnl_dcb.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtnl_netconf.obj: rtnl_netconf.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtnl_netconf.obj -MD -MP -MF $(DEPDIR)/libstrace_a-rtnl_netconf.Tpo -c -o libstrace_a-rtnl_netconf.obj `if test -f 'rtnl_netconf.c'; then $(CYGPATH_W) 'rtnl_netconf.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_netconf.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtnl_netconf.Tpo $(DEPDIR)/libstrace_a-rtnl_netconf.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_netconf.c' object='libstrace_a-rtnl_netconf.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtnl_dcb.o `test -f 'rtnl_dcb.c' || echo '$(srcdir)/'`rtnl_dcb.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtnl_netconf.obj `if test -f 'rtnl_netconf.c'; then $(CYGPATH_W) 'rtnl_netconf.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_netconf.c'; fi`
 
-strace-rtnl_dcb.obj: rtnl_dcb.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtnl_dcb.obj -MD -MP -MF $(DEPDIR)/strace-rtnl_dcb.Tpo -c -o strace-rtnl_dcb.obj `if test -f 'rtnl_dcb.c'; then $(CYGPATH_W) 'rtnl_dcb.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_dcb.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtnl_dcb.Tpo $(DEPDIR)/strace-rtnl_dcb.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_dcb.c' object='strace-rtnl_dcb.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtnl_nsid.o: rtnl_nsid.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtnl_nsid.o -MD -MP -MF $(DEPDIR)/libstrace_a-rtnl_nsid.Tpo -c -o libstrace_a-rtnl_nsid.o `test -f 'rtnl_nsid.c' || echo '$(srcdir)/'`rtnl_nsid.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtnl_nsid.Tpo $(DEPDIR)/libstrace_a-rtnl_nsid.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_nsid.c' object='libstrace_a-rtnl_nsid.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtnl_dcb.obj `if test -f 'rtnl_dcb.c'; then $(CYGPATH_W) 'rtnl_dcb.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_dcb.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtnl_nsid.o `test -f 'rtnl_nsid.c' || echo '$(srcdir)/'`rtnl_nsid.c
 
-strace-rtnl_link.o: rtnl_link.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtnl_link.o -MD -MP -MF $(DEPDIR)/strace-rtnl_link.Tpo -c -o strace-rtnl_link.o `test -f 'rtnl_link.c' || echo '$(srcdir)/'`rtnl_link.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtnl_link.Tpo $(DEPDIR)/strace-rtnl_link.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_link.c' object='strace-rtnl_link.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtnl_nsid.obj: rtnl_nsid.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtnl_nsid.obj -MD -MP -MF $(DEPDIR)/libstrace_a-rtnl_nsid.Tpo -c -o libstrace_a-rtnl_nsid.obj `if test -f 'rtnl_nsid.c'; then $(CYGPATH_W) 'rtnl_nsid.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_nsid.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtnl_nsid.Tpo $(DEPDIR)/libstrace_a-rtnl_nsid.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_nsid.c' object='libstrace_a-rtnl_nsid.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtnl_link.o `test -f 'rtnl_link.c' || echo '$(srcdir)/'`rtnl_link.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtnl_nsid.obj `if test -f 'rtnl_nsid.c'; then $(CYGPATH_W) 'rtnl_nsid.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_nsid.c'; fi`
 
-strace-rtnl_link.obj: rtnl_link.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtnl_link.obj -MD -MP -MF $(DEPDIR)/strace-rtnl_link.Tpo -c -o strace-rtnl_link.obj `if test -f 'rtnl_link.c'; then $(CYGPATH_W) 'rtnl_link.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_link.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtnl_link.Tpo $(DEPDIR)/strace-rtnl_link.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_link.c' object='strace-rtnl_link.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtnl_route.o: rtnl_route.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtnl_route.o -MD -MP -MF $(DEPDIR)/libstrace_a-rtnl_route.Tpo -c -o libstrace_a-rtnl_route.o `test -f 'rtnl_route.c' || echo '$(srcdir)/'`rtnl_route.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtnl_route.Tpo $(DEPDIR)/libstrace_a-rtnl_route.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_route.c' object='libstrace_a-rtnl_route.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtnl_link.obj `if test -f 'rtnl_link.c'; then $(CYGPATH_W) 'rtnl_link.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_link.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtnl_route.o `test -f 'rtnl_route.c' || echo '$(srcdir)/'`rtnl_route.c
 
-strace-rtnl_mdb.o: rtnl_mdb.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtnl_mdb.o -MD -MP -MF $(DEPDIR)/strace-rtnl_mdb.Tpo -c -o strace-rtnl_mdb.o `test -f 'rtnl_mdb.c' || echo '$(srcdir)/'`rtnl_mdb.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtnl_mdb.Tpo $(DEPDIR)/strace-rtnl_mdb.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_mdb.c' object='strace-rtnl_mdb.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtnl_route.obj: rtnl_route.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtnl_route.obj -MD -MP -MF $(DEPDIR)/libstrace_a-rtnl_route.Tpo -c -o libstrace_a-rtnl_route.obj `if test -f 'rtnl_route.c'; then $(CYGPATH_W) 'rtnl_route.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_route.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtnl_route.Tpo $(DEPDIR)/libstrace_a-rtnl_route.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_route.c' object='libstrace_a-rtnl_route.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtnl_mdb.o `test -f 'rtnl_mdb.c' || echo '$(srcdir)/'`rtnl_mdb.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtnl_route.obj `if test -f 'rtnl_route.c'; then $(CYGPATH_W) 'rtnl_route.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_route.c'; fi`
 
-strace-rtnl_mdb.obj: rtnl_mdb.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtnl_mdb.obj -MD -MP -MF $(DEPDIR)/strace-rtnl_mdb.Tpo -c -o strace-rtnl_mdb.obj `if test -f 'rtnl_mdb.c'; then $(CYGPATH_W) 'rtnl_mdb.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_mdb.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtnl_mdb.Tpo $(DEPDIR)/strace-rtnl_mdb.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_mdb.c' object='strace-rtnl_mdb.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtnl_rule.o: rtnl_rule.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtnl_rule.o -MD -MP -MF $(DEPDIR)/libstrace_a-rtnl_rule.Tpo -c -o libstrace_a-rtnl_rule.o `test -f 'rtnl_rule.c' || echo '$(srcdir)/'`rtnl_rule.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtnl_rule.Tpo $(DEPDIR)/libstrace_a-rtnl_rule.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_rule.c' object='libstrace_a-rtnl_rule.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtnl_mdb.obj `if test -f 'rtnl_mdb.c'; then $(CYGPATH_W) 'rtnl_mdb.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_mdb.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtnl_rule.o `test -f 'rtnl_rule.c' || echo '$(srcdir)/'`rtnl_rule.c
 
-strace-rtnl_neigh.o: rtnl_neigh.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtnl_neigh.o -MD -MP -MF $(DEPDIR)/strace-rtnl_neigh.Tpo -c -o strace-rtnl_neigh.o `test -f 'rtnl_neigh.c' || echo '$(srcdir)/'`rtnl_neigh.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtnl_neigh.Tpo $(DEPDIR)/strace-rtnl_neigh.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_neigh.c' object='strace-rtnl_neigh.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtnl_rule.obj: rtnl_rule.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtnl_rule.obj -MD -MP -MF $(DEPDIR)/libstrace_a-rtnl_rule.Tpo -c -o libstrace_a-rtnl_rule.obj `if test -f 'rtnl_rule.c'; then $(CYGPATH_W) 'rtnl_rule.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_rule.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtnl_rule.Tpo $(DEPDIR)/libstrace_a-rtnl_rule.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_rule.c' object='libstrace_a-rtnl_rule.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtnl_neigh.o `test -f 'rtnl_neigh.c' || echo '$(srcdir)/'`rtnl_neigh.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtnl_rule.obj `if test -f 'rtnl_rule.c'; then $(CYGPATH_W) 'rtnl_rule.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_rule.c'; fi`
 
-strace-rtnl_neigh.obj: rtnl_neigh.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtnl_neigh.obj -MD -MP -MF $(DEPDIR)/strace-rtnl_neigh.Tpo -c -o strace-rtnl_neigh.obj `if test -f 'rtnl_neigh.c'; then $(CYGPATH_W) 'rtnl_neigh.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_neigh.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtnl_neigh.Tpo $(DEPDIR)/strace-rtnl_neigh.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_neigh.c' object='strace-rtnl_neigh.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtnl_tc.o: rtnl_tc.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtnl_tc.o -MD -MP -MF $(DEPDIR)/libstrace_a-rtnl_tc.Tpo -c -o libstrace_a-rtnl_tc.o `test -f 'rtnl_tc.c' || echo '$(srcdir)/'`rtnl_tc.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtnl_tc.Tpo $(DEPDIR)/libstrace_a-rtnl_tc.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_tc.c' object='libstrace_a-rtnl_tc.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtnl_neigh.obj `if test -f 'rtnl_neigh.c'; then $(CYGPATH_W) 'rtnl_neigh.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_neigh.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtnl_tc.o `test -f 'rtnl_tc.c' || echo '$(srcdir)/'`rtnl_tc.c
 
-strace-rtnl_neightbl.o: rtnl_neightbl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtnl_neightbl.o -MD -MP -MF $(DEPDIR)/strace-rtnl_neightbl.Tpo -c -o strace-rtnl_neightbl.o `test -f 'rtnl_neightbl.c' || echo '$(srcdir)/'`rtnl_neightbl.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtnl_neightbl.Tpo $(DEPDIR)/strace-rtnl_neightbl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_neightbl.c' object='strace-rtnl_neightbl.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtnl_tc.obj: rtnl_tc.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtnl_tc.obj -MD -MP -MF $(DEPDIR)/libstrace_a-rtnl_tc.Tpo -c -o libstrace_a-rtnl_tc.obj `if test -f 'rtnl_tc.c'; then $(CYGPATH_W) 'rtnl_tc.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_tc.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtnl_tc.Tpo $(DEPDIR)/libstrace_a-rtnl_tc.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_tc.c' object='libstrace_a-rtnl_tc.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtnl_neightbl.o `test -f 'rtnl_neightbl.c' || echo '$(srcdir)/'`rtnl_neightbl.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtnl_tc.obj `if test -f 'rtnl_tc.c'; then $(CYGPATH_W) 'rtnl_tc.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_tc.c'; fi`
 
-strace-rtnl_neightbl.obj: rtnl_neightbl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtnl_neightbl.obj -MD -MP -MF $(DEPDIR)/strace-rtnl_neightbl.Tpo -c -o strace-rtnl_neightbl.obj `if test -f 'rtnl_neightbl.c'; then $(CYGPATH_W) 'rtnl_neightbl.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_neightbl.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtnl_neightbl.Tpo $(DEPDIR)/strace-rtnl_neightbl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_neightbl.c' object='strace-rtnl_neightbl.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtnl_tc_action.o: rtnl_tc_action.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtnl_tc_action.o -MD -MP -MF $(DEPDIR)/libstrace_a-rtnl_tc_action.Tpo -c -o libstrace_a-rtnl_tc_action.o `test -f 'rtnl_tc_action.c' || echo '$(srcdir)/'`rtnl_tc_action.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtnl_tc_action.Tpo $(DEPDIR)/libstrace_a-rtnl_tc_action.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_tc_action.c' object='libstrace_a-rtnl_tc_action.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtnl_neightbl.obj `if test -f 'rtnl_neightbl.c'; then $(CYGPATH_W) 'rtnl_neightbl.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_neightbl.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtnl_tc_action.o `test -f 'rtnl_tc_action.c' || echo '$(srcdir)/'`rtnl_tc_action.c
 
-strace-rtnl_netconf.o: rtnl_netconf.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtnl_netconf.o -MD -MP -MF $(DEPDIR)/strace-rtnl_netconf.Tpo -c -o strace-rtnl_netconf.o `test -f 'rtnl_netconf.c' || echo '$(srcdir)/'`rtnl_netconf.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtnl_netconf.Tpo $(DEPDIR)/strace-rtnl_netconf.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_netconf.c' object='strace-rtnl_netconf.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-rtnl_tc_action.obj: rtnl_tc_action.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-rtnl_tc_action.obj -MD -MP -MF $(DEPDIR)/libstrace_a-rtnl_tc_action.Tpo -c -o libstrace_a-rtnl_tc_action.obj `if test -f 'rtnl_tc_action.c'; then $(CYGPATH_W) 'rtnl_tc_action.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_tc_action.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-rtnl_tc_action.Tpo $(DEPDIR)/libstrace_a-rtnl_tc_action.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_tc_action.c' object='libstrace_a-rtnl_tc_action.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtnl_netconf.o `test -f 'rtnl_netconf.c' || echo '$(srcdir)/'`rtnl_netconf.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-rtnl_tc_action.obj `if test -f 'rtnl_tc_action.c'; then $(CYGPATH_W) 'rtnl_tc_action.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_tc_action.c'; fi`
 
-strace-rtnl_netconf.obj: rtnl_netconf.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtnl_netconf.obj -MD -MP -MF $(DEPDIR)/strace-rtnl_netconf.Tpo -c -o strace-rtnl_netconf.obj `if test -f 'rtnl_netconf.c'; then $(CYGPATH_W) 'rtnl_netconf.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_netconf.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtnl_netconf.Tpo $(DEPDIR)/strace-rtnl_netconf.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_netconf.c' object='strace-rtnl_netconf.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-s390.o: s390.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-s390.o -MD -MP -MF $(DEPDIR)/libstrace_a-s390.Tpo -c -o libstrace_a-s390.o `test -f 's390.c' || echo '$(srcdir)/'`s390.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-s390.Tpo $(DEPDIR)/libstrace_a-s390.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='s390.c' object='libstrace_a-s390.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtnl_netconf.obj `if test -f 'rtnl_netconf.c'; then $(CYGPATH_W) 'rtnl_netconf.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_netconf.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-s390.o `test -f 's390.c' || echo '$(srcdir)/'`s390.c
 
-strace-rtnl_nsid.o: rtnl_nsid.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtnl_nsid.o -MD -MP -MF $(DEPDIR)/strace-rtnl_nsid.Tpo -c -o strace-rtnl_nsid.o `test -f 'rtnl_nsid.c' || echo '$(srcdir)/'`rtnl_nsid.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtnl_nsid.Tpo $(DEPDIR)/strace-rtnl_nsid.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_nsid.c' object='strace-rtnl_nsid.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-s390.obj: s390.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-s390.obj -MD -MP -MF $(DEPDIR)/libstrace_a-s390.Tpo -c -o libstrace_a-s390.obj `if test -f 's390.c'; then $(CYGPATH_W) 's390.c'; else $(CYGPATH_W) '$(srcdir)/s390.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-s390.Tpo $(DEPDIR)/libstrace_a-s390.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='s390.c' object='libstrace_a-s390.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtnl_nsid.o `test -f 'rtnl_nsid.c' || echo '$(srcdir)/'`rtnl_nsid.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-s390.obj `if test -f 's390.c'; then $(CYGPATH_W) 's390.c'; else $(CYGPATH_W) '$(srcdir)/s390.c'; fi`
 
-strace-rtnl_nsid.obj: rtnl_nsid.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtnl_nsid.obj -MD -MP -MF $(DEPDIR)/strace-rtnl_nsid.Tpo -c -o strace-rtnl_nsid.obj `if test -f 'rtnl_nsid.c'; then $(CYGPATH_W) 'rtnl_nsid.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_nsid.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtnl_nsid.Tpo $(DEPDIR)/strace-rtnl_nsid.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_nsid.c' object='strace-rtnl_nsid.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-sched.o: sched.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sched.o -MD -MP -MF $(DEPDIR)/libstrace_a-sched.Tpo -c -o libstrace_a-sched.o `test -f 'sched.c' || echo '$(srcdir)/'`sched.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sched.Tpo $(DEPDIR)/libstrace_a-sched.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sched.c' object='libstrace_a-sched.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtnl_nsid.obj `if test -f 'rtnl_nsid.c'; then $(CYGPATH_W) 'rtnl_nsid.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_nsid.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sched.o `test -f 'sched.c' || echo '$(srcdir)/'`sched.c
 
-strace-rtnl_route.o: rtnl_route.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtnl_route.o -MD -MP -MF $(DEPDIR)/strace-rtnl_route.Tpo -c -o strace-rtnl_route.o `test -f 'rtnl_route.c' || echo '$(srcdir)/'`rtnl_route.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtnl_route.Tpo $(DEPDIR)/strace-rtnl_route.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_route.c' object='strace-rtnl_route.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-sched.obj: sched.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sched.obj -MD -MP -MF $(DEPDIR)/libstrace_a-sched.Tpo -c -o libstrace_a-sched.obj `if test -f 'sched.c'; then $(CYGPATH_W) 'sched.c'; else $(CYGPATH_W) '$(srcdir)/sched.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sched.Tpo $(DEPDIR)/libstrace_a-sched.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sched.c' object='libstrace_a-sched.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtnl_route.o `test -f 'rtnl_route.c' || echo '$(srcdir)/'`rtnl_route.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sched.obj `if test -f 'sched.c'; then $(CYGPATH_W) 'sched.c'; else $(CYGPATH_W) '$(srcdir)/sched.c'; fi`
 
-strace-rtnl_route.obj: rtnl_route.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtnl_route.obj -MD -MP -MF $(DEPDIR)/strace-rtnl_route.Tpo -c -o strace-rtnl_route.obj `if test -f 'rtnl_route.c'; then $(CYGPATH_W) 'rtnl_route.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_route.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtnl_route.Tpo $(DEPDIR)/strace-rtnl_route.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_route.c' object='strace-rtnl_route.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-scsi.o: scsi.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-scsi.o -MD -MP -MF $(DEPDIR)/libstrace_a-scsi.Tpo -c -o libstrace_a-scsi.o `test -f 'scsi.c' || echo '$(srcdir)/'`scsi.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-scsi.Tpo $(DEPDIR)/libstrace_a-scsi.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='scsi.c' object='libstrace_a-scsi.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtnl_route.obj `if test -f 'rtnl_route.c'; then $(CYGPATH_W) 'rtnl_route.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_route.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-scsi.o `test -f 'scsi.c' || echo '$(srcdir)/'`scsi.c
 
-strace-rtnl_rule.o: rtnl_rule.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtnl_rule.o -MD -MP -MF $(DEPDIR)/strace-rtnl_rule.Tpo -c -o strace-rtnl_rule.o `test -f 'rtnl_rule.c' || echo '$(srcdir)/'`rtnl_rule.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtnl_rule.Tpo $(DEPDIR)/strace-rtnl_rule.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_rule.c' object='strace-rtnl_rule.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-scsi.obj: scsi.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-scsi.obj -MD -MP -MF $(DEPDIR)/libstrace_a-scsi.Tpo -c -o libstrace_a-scsi.obj `if test -f 'scsi.c'; then $(CYGPATH_W) 'scsi.c'; else $(CYGPATH_W) '$(srcdir)/scsi.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-scsi.Tpo $(DEPDIR)/libstrace_a-scsi.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='scsi.c' object='libstrace_a-scsi.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtnl_rule.o `test -f 'rtnl_rule.c' || echo '$(srcdir)/'`rtnl_rule.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-scsi.obj `if test -f 'scsi.c'; then $(CYGPATH_W) 'scsi.c'; else $(CYGPATH_W) '$(srcdir)/scsi.c'; fi`
 
-strace-rtnl_rule.obj: rtnl_rule.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtnl_rule.obj -MD -MP -MF $(DEPDIR)/strace-rtnl_rule.Tpo -c -o strace-rtnl_rule.obj `if test -f 'rtnl_rule.c'; then $(CYGPATH_W) 'rtnl_rule.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_rule.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtnl_rule.Tpo $(DEPDIR)/strace-rtnl_rule.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_rule.c' object='strace-rtnl_rule.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-seccomp.o: seccomp.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-seccomp.o -MD -MP -MF $(DEPDIR)/libstrace_a-seccomp.Tpo -c -o libstrace_a-seccomp.o `test -f 'seccomp.c' || echo '$(srcdir)/'`seccomp.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-seccomp.Tpo $(DEPDIR)/libstrace_a-seccomp.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='seccomp.c' object='libstrace_a-seccomp.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtnl_rule.obj `if test -f 'rtnl_rule.c'; then $(CYGPATH_W) 'rtnl_rule.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_rule.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-seccomp.o `test -f 'seccomp.c' || echo '$(srcdir)/'`seccomp.c
 
-strace-rtnl_tc.o: rtnl_tc.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtnl_tc.o -MD -MP -MF $(DEPDIR)/strace-rtnl_tc.Tpo -c -o strace-rtnl_tc.o `test -f 'rtnl_tc.c' || echo '$(srcdir)/'`rtnl_tc.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtnl_tc.Tpo $(DEPDIR)/strace-rtnl_tc.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_tc.c' object='strace-rtnl_tc.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-seccomp.obj: seccomp.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-seccomp.obj -MD -MP -MF $(DEPDIR)/libstrace_a-seccomp.Tpo -c -o libstrace_a-seccomp.obj `if test -f 'seccomp.c'; then $(CYGPATH_W) 'seccomp.c'; else $(CYGPATH_W) '$(srcdir)/seccomp.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-seccomp.Tpo $(DEPDIR)/libstrace_a-seccomp.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='seccomp.c' object='libstrace_a-seccomp.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtnl_tc.o `test -f 'rtnl_tc.c' || echo '$(srcdir)/'`rtnl_tc.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-seccomp.obj `if test -f 'seccomp.c'; then $(CYGPATH_W) 'seccomp.c'; else $(CYGPATH_W) '$(srcdir)/seccomp.c'; fi`
 
-strace-rtnl_tc.obj: rtnl_tc.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtnl_tc.obj -MD -MP -MF $(DEPDIR)/strace-rtnl_tc.Tpo -c -o strace-rtnl_tc.obj `if test -f 'rtnl_tc.c'; then $(CYGPATH_W) 'rtnl_tc.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_tc.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtnl_tc.Tpo $(DEPDIR)/strace-rtnl_tc.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_tc.c' object='strace-rtnl_tc.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-sendfile.o: sendfile.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sendfile.o -MD -MP -MF $(DEPDIR)/libstrace_a-sendfile.Tpo -c -o libstrace_a-sendfile.o `test -f 'sendfile.c' || echo '$(srcdir)/'`sendfile.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sendfile.Tpo $(DEPDIR)/libstrace_a-sendfile.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sendfile.c' object='libstrace_a-sendfile.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtnl_tc.obj `if test -f 'rtnl_tc.c'; then $(CYGPATH_W) 'rtnl_tc.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_tc.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sendfile.o `test -f 'sendfile.c' || echo '$(srcdir)/'`sendfile.c
 
-strace-rtnl_tc_action.o: rtnl_tc_action.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtnl_tc_action.o -MD -MP -MF $(DEPDIR)/strace-rtnl_tc_action.Tpo -c -o strace-rtnl_tc_action.o `test -f 'rtnl_tc_action.c' || echo '$(srcdir)/'`rtnl_tc_action.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtnl_tc_action.Tpo $(DEPDIR)/strace-rtnl_tc_action.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_tc_action.c' object='strace-rtnl_tc_action.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-sendfile.obj: sendfile.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sendfile.obj -MD -MP -MF $(DEPDIR)/libstrace_a-sendfile.Tpo -c -o libstrace_a-sendfile.obj `if test -f 'sendfile.c'; then $(CYGPATH_W) 'sendfile.c'; else $(CYGPATH_W) '$(srcdir)/sendfile.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sendfile.Tpo $(DEPDIR)/libstrace_a-sendfile.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sendfile.c' object='libstrace_a-sendfile.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtnl_tc_action.o `test -f 'rtnl_tc_action.c' || echo '$(srcdir)/'`rtnl_tc_action.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sendfile.obj `if test -f 'sendfile.c'; then $(CYGPATH_W) 'sendfile.c'; else $(CYGPATH_W) '$(srcdir)/sendfile.c'; fi`
 
-strace-rtnl_tc_action.obj: rtnl_tc_action.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-rtnl_tc_action.obj -MD -MP -MF $(DEPDIR)/strace-rtnl_tc_action.Tpo -c -o strace-rtnl_tc_action.obj `if test -f 'rtnl_tc_action.c'; then $(CYGPATH_W) 'rtnl_tc_action.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_tc_action.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-rtnl_tc_action.Tpo $(DEPDIR)/strace-rtnl_tc_action.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='rtnl_tc_action.c' object='strace-rtnl_tc_action.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-sg_io_v3.o: sg_io_v3.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sg_io_v3.o -MD -MP -MF $(DEPDIR)/libstrace_a-sg_io_v3.Tpo -c -o libstrace_a-sg_io_v3.o `test -f 'sg_io_v3.c' || echo '$(srcdir)/'`sg_io_v3.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sg_io_v3.Tpo $(DEPDIR)/libstrace_a-sg_io_v3.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sg_io_v3.c' object='libstrace_a-sg_io_v3.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-rtnl_tc_action.obj `if test -f 'rtnl_tc_action.c'; then $(CYGPATH_W) 'rtnl_tc_action.c'; else $(CYGPATH_W) '$(srcdir)/rtnl_tc_action.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sg_io_v3.o `test -f 'sg_io_v3.c' || echo '$(srcdir)/'`sg_io_v3.c
 
-strace-s390.o: s390.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-s390.o -MD -MP -MF $(DEPDIR)/strace-s390.Tpo -c -o strace-s390.o `test -f 's390.c' || echo '$(srcdir)/'`s390.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-s390.Tpo $(DEPDIR)/strace-s390.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='s390.c' object='strace-s390.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-sg_io_v3.obj: sg_io_v3.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sg_io_v3.obj -MD -MP -MF $(DEPDIR)/libstrace_a-sg_io_v3.Tpo -c -o libstrace_a-sg_io_v3.obj `if test -f 'sg_io_v3.c'; then $(CYGPATH_W) 'sg_io_v3.c'; else $(CYGPATH_W) '$(srcdir)/sg_io_v3.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sg_io_v3.Tpo $(DEPDIR)/libstrace_a-sg_io_v3.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sg_io_v3.c' object='libstrace_a-sg_io_v3.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-s390.o `test -f 's390.c' || echo '$(srcdir)/'`s390.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sg_io_v3.obj `if test -f 'sg_io_v3.c'; then $(CYGPATH_W) 'sg_io_v3.c'; else $(CYGPATH_W) '$(srcdir)/sg_io_v3.c'; fi`
 
-strace-s390.obj: s390.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-s390.obj -MD -MP -MF $(DEPDIR)/strace-s390.Tpo -c -o strace-s390.obj `if test -f 's390.c'; then $(CYGPATH_W) 's390.c'; else $(CYGPATH_W) '$(srcdir)/s390.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-s390.Tpo $(DEPDIR)/strace-s390.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='s390.c' object='strace-s390.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-sg_io_v4.o: sg_io_v4.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sg_io_v4.o -MD -MP -MF $(DEPDIR)/libstrace_a-sg_io_v4.Tpo -c -o libstrace_a-sg_io_v4.o `test -f 'sg_io_v4.c' || echo '$(srcdir)/'`sg_io_v4.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sg_io_v4.Tpo $(DEPDIR)/libstrace_a-sg_io_v4.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sg_io_v4.c' object='libstrace_a-sg_io_v4.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-s390.obj `if test -f 's390.c'; then $(CYGPATH_W) 's390.c'; else $(CYGPATH_W) '$(srcdir)/s390.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sg_io_v4.o `test -f 'sg_io_v4.c' || echo '$(srcdir)/'`sg_io_v4.c
 
-strace-sched.o: sched.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-sched.o -MD -MP -MF $(DEPDIR)/strace-sched.Tpo -c -o strace-sched.o `test -f 'sched.c' || echo '$(srcdir)/'`sched.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-sched.Tpo $(DEPDIR)/strace-sched.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sched.c' object='strace-sched.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-sg_io_v4.obj: sg_io_v4.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sg_io_v4.obj -MD -MP -MF $(DEPDIR)/libstrace_a-sg_io_v4.Tpo -c -o libstrace_a-sg_io_v4.obj `if test -f 'sg_io_v4.c'; then $(CYGPATH_W) 'sg_io_v4.c'; else $(CYGPATH_W) '$(srcdir)/sg_io_v4.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sg_io_v4.Tpo $(DEPDIR)/libstrace_a-sg_io_v4.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sg_io_v4.c' object='libstrace_a-sg_io_v4.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-sched.o `test -f 'sched.c' || echo '$(srcdir)/'`sched.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sg_io_v4.obj `if test -f 'sg_io_v4.c'; then $(CYGPATH_W) 'sg_io_v4.c'; else $(CYGPATH_W) '$(srcdir)/sg_io_v4.c'; fi`
 
-strace-sched.obj: sched.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-sched.obj -MD -MP -MF $(DEPDIR)/strace-sched.Tpo -c -o strace-sched.obj `if test -f 'sched.c'; then $(CYGPATH_W) 'sched.c'; else $(CYGPATH_W) '$(srcdir)/sched.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-sched.Tpo $(DEPDIR)/strace-sched.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sched.c' object='strace-sched.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-shutdown.o: shutdown.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-shutdown.o -MD -MP -MF $(DEPDIR)/libstrace_a-shutdown.Tpo -c -o libstrace_a-shutdown.o `test -f 'shutdown.c' || echo '$(srcdir)/'`shutdown.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-shutdown.Tpo $(DEPDIR)/libstrace_a-shutdown.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='shutdown.c' object='libstrace_a-shutdown.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-sched.obj `if test -f 'sched.c'; then $(CYGPATH_W) 'sched.c'; else $(CYGPATH_W) '$(srcdir)/sched.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-shutdown.o `test -f 'shutdown.c' || echo '$(srcdir)/'`shutdown.c
 
-strace-scsi.o: scsi.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-scsi.o -MD -MP -MF $(DEPDIR)/strace-scsi.Tpo -c -o strace-scsi.o `test -f 'scsi.c' || echo '$(srcdir)/'`scsi.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-scsi.Tpo $(DEPDIR)/strace-scsi.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='scsi.c' object='strace-scsi.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-shutdown.obj: shutdown.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-shutdown.obj -MD -MP -MF $(DEPDIR)/libstrace_a-shutdown.Tpo -c -o libstrace_a-shutdown.obj `if test -f 'shutdown.c'; then $(CYGPATH_W) 'shutdown.c'; else $(CYGPATH_W) '$(srcdir)/shutdown.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-shutdown.Tpo $(DEPDIR)/libstrace_a-shutdown.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='shutdown.c' object='libstrace_a-shutdown.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-scsi.o `test -f 'scsi.c' || echo '$(srcdir)/'`scsi.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-shutdown.obj `if test -f 'shutdown.c'; then $(CYGPATH_W) 'shutdown.c'; else $(CYGPATH_W) '$(srcdir)/shutdown.c'; fi`
 
-strace-scsi.obj: scsi.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-scsi.obj -MD -MP -MF $(DEPDIR)/strace-scsi.Tpo -c -o strace-scsi.obj `if test -f 'scsi.c'; then $(CYGPATH_W) 'scsi.c'; else $(CYGPATH_W) '$(srcdir)/scsi.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-scsi.Tpo $(DEPDIR)/strace-scsi.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='scsi.c' object='strace-scsi.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-sigaltstack.o: sigaltstack.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sigaltstack.o -MD -MP -MF $(DEPDIR)/libstrace_a-sigaltstack.Tpo -c -o libstrace_a-sigaltstack.o `test -f 'sigaltstack.c' || echo '$(srcdir)/'`sigaltstack.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sigaltstack.Tpo $(DEPDIR)/libstrace_a-sigaltstack.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sigaltstack.c' object='libstrace_a-sigaltstack.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-scsi.obj `if test -f 'scsi.c'; then $(CYGPATH_W) 'scsi.c'; else $(CYGPATH_W) '$(srcdir)/scsi.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sigaltstack.o `test -f 'sigaltstack.c' || echo '$(srcdir)/'`sigaltstack.c
 
-strace-seccomp.o: seccomp.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-seccomp.o -MD -MP -MF $(DEPDIR)/strace-seccomp.Tpo -c -o strace-seccomp.o `test -f 'seccomp.c' || echo '$(srcdir)/'`seccomp.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-seccomp.Tpo $(DEPDIR)/strace-seccomp.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='seccomp.c' object='strace-seccomp.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-sigaltstack.obj: sigaltstack.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sigaltstack.obj -MD -MP -MF $(DEPDIR)/libstrace_a-sigaltstack.Tpo -c -o libstrace_a-sigaltstack.obj `if test -f 'sigaltstack.c'; then $(CYGPATH_W) 'sigaltstack.c'; else $(CYGPATH_W) '$(srcdir)/sigaltstack.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sigaltstack.Tpo $(DEPDIR)/libstrace_a-sigaltstack.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sigaltstack.c' object='libstrace_a-sigaltstack.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-seccomp.o `test -f 'seccomp.c' || echo '$(srcdir)/'`seccomp.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sigaltstack.obj `if test -f 'sigaltstack.c'; then $(CYGPATH_W) 'sigaltstack.c'; else $(CYGPATH_W) '$(srcdir)/sigaltstack.c'; fi`
 
-strace-seccomp.obj: seccomp.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-seccomp.obj -MD -MP -MF $(DEPDIR)/strace-seccomp.Tpo -c -o strace-seccomp.obj `if test -f 'seccomp.c'; then $(CYGPATH_W) 'seccomp.c'; else $(CYGPATH_W) '$(srcdir)/seccomp.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-seccomp.Tpo $(DEPDIR)/strace-seccomp.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='seccomp.c' object='strace-seccomp.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-signal.o: signal.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-signal.o -MD -MP -MF $(DEPDIR)/libstrace_a-signal.Tpo -c -o libstrace_a-signal.o `test -f 'signal.c' || echo '$(srcdir)/'`signal.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-signal.Tpo $(DEPDIR)/libstrace_a-signal.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='signal.c' object='libstrace_a-signal.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-seccomp.obj `if test -f 'seccomp.c'; then $(CYGPATH_W) 'seccomp.c'; else $(CYGPATH_W) '$(srcdir)/seccomp.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-signal.o `test -f 'signal.c' || echo '$(srcdir)/'`signal.c
 
-strace-sendfile.o: sendfile.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-sendfile.o -MD -MP -MF $(DEPDIR)/strace-sendfile.Tpo -c -o strace-sendfile.o `test -f 'sendfile.c' || echo '$(srcdir)/'`sendfile.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-sendfile.Tpo $(DEPDIR)/strace-sendfile.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sendfile.c' object='strace-sendfile.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-signal.obj: signal.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-signal.obj -MD -MP -MF $(DEPDIR)/libstrace_a-signal.Tpo -c -o libstrace_a-signal.obj `if test -f 'signal.c'; then $(CYGPATH_W) 'signal.c'; else $(CYGPATH_W) '$(srcdir)/signal.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-signal.Tpo $(DEPDIR)/libstrace_a-signal.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='signal.c' object='libstrace_a-signal.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-sendfile.o `test -f 'sendfile.c' || echo '$(srcdir)/'`sendfile.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-signal.obj `if test -f 'signal.c'; then $(CYGPATH_W) 'signal.c'; else $(CYGPATH_W) '$(srcdir)/signal.c'; fi`
 
-strace-sendfile.obj: sendfile.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-sendfile.obj -MD -MP -MF $(DEPDIR)/strace-sendfile.Tpo -c -o strace-sendfile.obj `if test -f 'sendfile.c'; then $(CYGPATH_W) 'sendfile.c'; else $(CYGPATH_W) '$(srcdir)/sendfile.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-sendfile.Tpo $(DEPDIR)/strace-sendfile.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sendfile.c' object='strace-sendfile.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-signalfd.o: signalfd.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-signalfd.o -MD -MP -MF $(DEPDIR)/libstrace_a-signalfd.Tpo -c -o libstrace_a-signalfd.o `test -f 'signalfd.c' || echo '$(srcdir)/'`signalfd.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-signalfd.Tpo $(DEPDIR)/libstrace_a-signalfd.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='signalfd.c' object='libstrace_a-signalfd.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-sendfile.obj `if test -f 'sendfile.c'; then $(CYGPATH_W) 'sendfile.c'; else $(CYGPATH_W) '$(srcdir)/sendfile.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-signalfd.o `test -f 'signalfd.c' || echo '$(srcdir)/'`signalfd.c
 
-strace-sg_io_v3.o: sg_io_v3.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-sg_io_v3.o -MD -MP -MF $(DEPDIR)/strace-sg_io_v3.Tpo -c -o strace-sg_io_v3.o `test -f 'sg_io_v3.c' || echo '$(srcdir)/'`sg_io_v3.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-sg_io_v3.Tpo $(DEPDIR)/strace-sg_io_v3.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sg_io_v3.c' object='strace-sg_io_v3.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-signalfd.obj: signalfd.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-signalfd.obj -MD -MP -MF $(DEPDIR)/libstrace_a-signalfd.Tpo -c -o libstrace_a-signalfd.obj `if test -f 'signalfd.c'; then $(CYGPATH_W) 'signalfd.c'; else $(CYGPATH_W) '$(srcdir)/signalfd.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-signalfd.Tpo $(DEPDIR)/libstrace_a-signalfd.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='signalfd.c' object='libstrace_a-signalfd.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-sg_io_v3.o `test -f 'sg_io_v3.c' || echo '$(srcdir)/'`sg_io_v3.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-signalfd.obj `if test -f 'signalfd.c'; then $(CYGPATH_W) 'signalfd.c'; else $(CYGPATH_W) '$(srcdir)/signalfd.c'; fi`
 
-strace-sg_io_v3.obj: sg_io_v3.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-sg_io_v3.obj -MD -MP -MF $(DEPDIR)/strace-sg_io_v3.Tpo -c -o strace-sg_io_v3.obj `if test -f 'sg_io_v3.c'; then $(CYGPATH_W) 'sg_io_v3.c'; else $(CYGPATH_W) '$(srcdir)/sg_io_v3.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-sg_io_v3.Tpo $(DEPDIR)/strace-sg_io_v3.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sg_io_v3.c' object='strace-sg_io_v3.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-sigreturn.o: sigreturn.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sigreturn.o -MD -MP -MF $(DEPDIR)/libstrace_a-sigreturn.Tpo -c -o libstrace_a-sigreturn.o `test -f 'sigreturn.c' || echo '$(srcdir)/'`sigreturn.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sigreturn.Tpo $(DEPDIR)/libstrace_a-sigreturn.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sigreturn.c' object='libstrace_a-sigreturn.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-sg_io_v3.obj `if test -f 'sg_io_v3.c'; then $(CYGPATH_W) 'sg_io_v3.c'; else $(CYGPATH_W) '$(srcdir)/sg_io_v3.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sigreturn.o `test -f 'sigreturn.c' || echo '$(srcdir)/'`sigreturn.c
 
-strace-sg_io_v4.o: sg_io_v4.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-sg_io_v4.o -MD -MP -MF $(DEPDIR)/strace-sg_io_v4.Tpo -c -o strace-sg_io_v4.o `test -f 'sg_io_v4.c' || echo '$(srcdir)/'`sg_io_v4.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-sg_io_v4.Tpo $(DEPDIR)/strace-sg_io_v4.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sg_io_v4.c' object='strace-sg_io_v4.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-sigreturn.obj: sigreturn.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sigreturn.obj -MD -MP -MF $(DEPDIR)/libstrace_a-sigreturn.Tpo -c -o libstrace_a-sigreturn.obj `if test -f 'sigreturn.c'; then $(CYGPATH_W) 'sigreturn.c'; else $(CYGPATH_W) '$(srcdir)/sigreturn.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sigreturn.Tpo $(DEPDIR)/libstrace_a-sigreturn.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sigreturn.c' object='libstrace_a-sigreturn.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-sg_io_v4.o `test -f 'sg_io_v4.c' || echo '$(srcdir)/'`sg_io_v4.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sigreturn.obj `if test -f 'sigreturn.c'; then $(CYGPATH_W) 'sigreturn.c'; else $(CYGPATH_W) '$(srcdir)/sigreturn.c'; fi`
 
-strace-sg_io_v4.obj: sg_io_v4.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-sg_io_v4.obj -MD -MP -MF $(DEPDIR)/strace-sg_io_v4.Tpo -c -o strace-sg_io_v4.obj `if test -f 'sg_io_v4.c'; then $(CYGPATH_W) 'sg_io_v4.c'; else $(CYGPATH_W) '$(srcdir)/sg_io_v4.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-sg_io_v4.Tpo $(DEPDIR)/strace-sg_io_v4.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sg_io_v4.c' object='strace-sg_io_v4.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-sock.o: sock.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sock.o -MD -MP -MF $(DEPDIR)/libstrace_a-sock.Tpo -c -o libstrace_a-sock.o `test -f 'sock.c' || echo '$(srcdir)/'`sock.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sock.Tpo $(DEPDIR)/libstrace_a-sock.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sock.c' object='libstrace_a-sock.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-sg_io_v4.obj `if test -f 'sg_io_v4.c'; then $(CYGPATH_W) 'sg_io_v4.c'; else $(CYGPATH_W) '$(srcdir)/sg_io_v4.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sock.o `test -f 'sock.c' || echo '$(srcdir)/'`sock.c
 
-strace-shutdown.o: shutdown.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-shutdown.o -MD -MP -MF $(DEPDIR)/strace-shutdown.Tpo -c -o strace-shutdown.o `test -f 'shutdown.c' || echo '$(srcdir)/'`shutdown.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-shutdown.Tpo $(DEPDIR)/strace-shutdown.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='shutdown.c' object='strace-shutdown.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-sock.obj: sock.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sock.obj -MD -MP -MF $(DEPDIR)/libstrace_a-sock.Tpo -c -o libstrace_a-sock.obj `if test -f 'sock.c'; then $(CYGPATH_W) 'sock.c'; else $(CYGPATH_W) '$(srcdir)/sock.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sock.Tpo $(DEPDIR)/libstrace_a-sock.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sock.c' object='libstrace_a-sock.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-shutdown.o `test -f 'shutdown.c' || echo '$(srcdir)/'`shutdown.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sock.obj `if test -f 'sock.c'; then $(CYGPATH_W) 'sock.c'; else $(CYGPATH_W) '$(srcdir)/sock.c'; fi`
 
-strace-shutdown.obj: shutdown.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-shutdown.obj -MD -MP -MF $(DEPDIR)/strace-shutdown.Tpo -c -o strace-shutdown.obj `if test -f 'shutdown.c'; then $(CYGPATH_W) 'shutdown.c'; else $(CYGPATH_W) '$(srcdir)/shutdown.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-shutdown.Tpo $(DEPDIR)/strace-shutdown.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='shutdown.c' object='strace-shutdown.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-sockaddr.o: sockaddr.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sockaddr.o -MD -MP -MF $(DEPDIR)/libstrace_a-sockaddr.Tpo -c -o libstrace_a-sockaddr.o `test -f 'sockaddr.c' || echo '$(srcdir)/'`sockaddr.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sockaddr.Tpo $(DEPDIR)/libstrace_a-sockaddr.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sockaddr.c' object='libstrace_a-sockaddr.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-shutdown.obj `if test -f 'shutdown.c'; then $(CYGPATH_W) 'shutdown.c'; else $(CYGPATH_W) '$(srcdir)/shutdown.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sockaddr.o `test -f 'sockaddr.c' || echo '$(srcdir)/'`sockaddr.c
 
-strace-sigaltstack.o: sigaltstack.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-sigaltstack.o -MD -MP -MF $(DEPDIR)/strace-sigaltstack.Tpo -c -o strace-sigaltstack.o `test -f 'sigaltstack.c' || echo '$(srcdir)/'`sigaltstack.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-sigaltstack.Tpo $(DEPDIR)/strace-sigaltstack.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sigaltstack.c' object='strace-sigaltstack.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-sockaddr.obj: sockaddr.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sockaddr.obj -MD -MP -MF $(DEPDIR)/libstrace_a-sockaddr.Tpo -c -o libstrace_a-sockaddr.obj `if test -f 'sockaddr.c'; then $(CYGPATH_W) 'sockaddr.c'; else $(CYGPATH_W) '$(srcdir)/sockaddr.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sockaddr.Tpo $(DEPDIR)/libstrace_a-sockaddr.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sockaddr.c' object='libstrace_a-sockaddr.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-sigaltstack.o `test -f 'sigaltstack.c' || echo '$(srcdir)/'`sigaltstack.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sockaddr.obj `if test -f 'sockaddr.c'; then $(CYGPATH_W) 'sockaddr.c'; else $(CYGPATH_W) '$(srcdir)/sockaddr.c'; fi`
 
-strace-sigaltstack.obj: sigaltstack.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-sigaltstack.obj -MD -MP -MF $(DEPDIR)/strace-sigaltstack.Tpo -c -o strace-sigaltstack.obj `if test -f 'sigaltstack.c'; then $(CYGPATH_W) 'sigaltstack.c'; else $(CYGPATH_W) '$(srcdir)/sigaltstack.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-sigaltstack.Tpo $(DEPDIR)/strace-sigaltstack.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sigaltstack.c' object='strace-sigaltstack.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-socketcall.o: socketcall.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-socketcall.o -MD -MP -MF $(DEPDIR)/libstrace_a-socketcall.Tpo -c -o libstrace_a-socketcall.o `test -f 'socketcall.c' || echo '$(srcdir)/'`socketcall.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-socketcall.Tpo $(DEPDIR)/libstrace_a-socketcall.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='socketcall.c' object='libstrace_a-socketcall.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-sigaltstack.obj `if test -f 'sigaltstack.c'; then $(CYGPATH_W) 'sigaltstack.c'; else $(CYGPATH_W) '$(srcdir)/sigaltstack.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-socketcall.o `test -f 'socketcall.c' || echo '$(srcdir)/'`socketcall.c
 
-strace-signal.o: signal.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-signal.o -MD -MP -MF $(DEPDIR)/strace-signal.Tpo -c -o strace-signal.o `test -f 'signal.c' || echo '$(srcdir)/'`signal.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-signal.Tpo $(DEPDIR)/strace-signal.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='signal.c' object='strace-signal.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-socketcall.obj: socketcall.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-socketcall.obj -MD -MP -MF $(DEPDIR)/libstrace_a-socketcall.Tpo -c -o libstrace_a-socketcall.obj `if test -f 'socketcall.c'; then $(CYGPATH_W) 'socketcall.c'; else $(CYGPATH_W) '$(srcdir)/socketcall.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-socketcall.Tpo $(DEPDIR)/libstrace_a-socketcall.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='socketcall.c' object='libstrace_a-socketcall.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-signal.o `test -f 'signal.c' || echo '$(srcdir)/'`signal.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-socketcall.obj `if test -f 'socketcall.c'; then $(CYGPATH_W) 'socketcall.c'; else $(CYGPATH_W) '$(srcdir)/socketcall.c'; fi`
 
-strace-signal.obj: signal.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-signal.obj -MD -MP -MF $(DEPDIR)/strace-signal.Tpo -c -o strace-signal.obj `if test -f 'signal.c'; then $(CYGPATH_W) 'signal.c'; else $(CYGPATH_W) '$(srcdir)/signal.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-signal.Tpo $(DEPDIR)/strace-signal.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='signal.c' object='strace-signal.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-socketutils.o: socketutils.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-socketutils.o -MD -MP -MF $(DEPDIR)/libstrace_a-socketutils.Tpo -c -o libstrace_a-socketutils.o `test -f 'socketutils.c' || echo '$(srcdir)/'`socketutils.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-socketutils.Tpo $(DEPDIR)/libstrace_a-socketutils.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='socketutils.c' object='libstrace_a-socketutils.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-signal.obj `if test -f 'signal.c'; then $(CYGPATH_W) 'signal.c'; else $(CYGPATH_W) '$(srcdir)/signal.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-socketutils.o `test -f 'socketutils.c' || echo '$(srcdir)/'`socketutils.c
 
-strace-signalfd.o: signalfd.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-signalfd.o -MD -MP -MF $(DEPDIR)/strace-signalfd.Tpo -c -o strace-signalfd.o `test -f 'signalfd.c' || echo '$(srcdir)/'`signalfd.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-signalfd.Tpo $(DEPDIR)/strace-signalfd.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='signalfd.c' object='strace-signalfd.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-socketutils.obj: socketutils.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-socketutils.obj -MD -MP -MF $(DEPDIR)/libstrace_a-socketutils.Tpo -c -o libstrace_a-socketutils.obj `if test -f 'socketutils.c'; then $(CYGPATH_W) 'socketutils.c'; else $(CYGPATH_W) '$(srcdir)/socketutils.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-socketutils.Tpo $(DEPDIR)/libstrace_a-socketutils.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='socketutils.c' object='libstrace_a-socketutils.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-signalfd.o `test -f 'signalfd.c' || echo '$(srcdir)/'`signalfd.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-socketutils.obj `if test -f 'socketutils.c'; then $(CYGPATH_W) 'socketutils.c'; else $(CYGPATH_W) '$(srcdir)/socketutils.c'; fi`
 
-strace-signalfd.obj: signalfd.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-signalfd.obj -MD -MP -MF $(DEPDIR)/strace-signalfd.Tpo -c -o strace-signalfd.obj `if test -f 'signalfd.c'; then $(CYGPATH_W) 'signalfd.c'; else $(CYGPATH_W) '$(srcdir)/signalfd.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-signalfd.Tpo $(DEPDIR)/strace-signalfd.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='signalfd.c' object='strace-signalfd.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-sparc.o: sparc.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sparc.o -MD -MP -MF $(DEPDIR)/libstrace_a-sparc.Tpo -c -o libstrace_a-sparc.o `test -f 'sparc.c' || echo '$(srcdir)/'`sparc.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sparc.Tpo $(DEPDIR)/libstrace_a-sparc.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sparc.c' object='libstrace_a-sparc.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-signalfd.obj `if test -f 'signalfd.c'; then $(CYGPATH_W) 'signalfd.c'; else $(CYGPATH_W) '$(srcdir)/signalfd.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sparc.o `test -f 'sparc.c' || echo '$(srcdir)/'`sparc.c
 
-strace-sock.o: sock.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-sock.o -MD -MP -MF $(DEPDIR)/strace-sock.Tpo -c -o strace-sock.o `test -f 'sock.c' || echo '$(srcdir)/'`sock.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-sock.Tpo $(DEPDIR)/strace-sock.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sock.c' object='strace-sock.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-sparc.obj: sparc.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sparc.obj -MD -MP -MF $(DEPDIR)/libstrace_a-sparc.Tpo -c -o libstrace_a-sparc.obj `if test -f 'sparc.c'; then $(CYGPATH_W) 'sparc.c'; else $(CYGPATH_W) '$(srcdir)/sparc.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sparc.Tpo $(DEPDIR)/libstrace_a-sparc.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sparc.c' object='libstrace_a-sparc.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-sock.o `test -f 'sock.c' || echo '$(srcdir)/'`sock.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sparc.obj `if test -f 'sparc.c'; then $(CYGPATH_W) 'sparc.c'; else $(CYGPATH_W) '$(srcdir)/sparc.c'; fi`
 
-strace-sock.obj: sock.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-sock.obj -MD -MP -MF $(DEPDIR)/strace-sock.Tpo -c -o strace-sock.obj `if test -f 'sock.c'; then $(CYGPATH_W) 'sock.c'; else $(CYGPATH_W) '$(srcdir)/sock.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-sock.Tpo $(DEPDIR)/strace-sock.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sock.c' object='strace-sock.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-sram_alloc.o: sram_alloc.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sram_alloc.o -MD -MP -MF $(DEPDIR)/libstrace_a-sram_alloc.Tpo -c -o libstrace_a-sram_alloc.o `test -f 'sram_alloc.c' || echo '$(srcdir)/'`sram_alloc.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sram_alloc.Tpo $(DEPDIR)/libstrace_a-sram_alloc.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sram_alloc.c' object='libstrace_a-sram_alloc.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-sock.obj `if test -f 'sock.c'; then $(CYGPATH_W) 'sock.c'; else $(CYGPATH_W) '$(srcdir)/sock.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sram_alloc.o `test -f 'sram_alloc.c' || echo '$(srcdir)/'`sram_alloc.c
 
-strace-sockaddr.o: sockaddr.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-sockaddr.o -MD -MP -MF $(DEPDIR)/strace-sockaddr.Tpo -c -o strace-sockaddr.o `test -f 'sockaddr.c' || echo '$(srcdir)/'`sockaddr.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-sockaddr.Tpo $(DEPDIR)/strace-sockaddr.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sockaddr.c' object='strace-sockaddr.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-sram_alloc.obj: sram_alloc.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sram_alloc.obj -MD -MP -MF $(DEPDIR)/libstrace_a-sram_alloc.Tpo -c -o libstrace_a-sram_alloc.obj `if test -f 'sram_alloc.c'; then $(CYGPATH_W) 'sram_alloc.c'; else $(CYGPATH_W) '$(srcdir)/sram_alloc.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sram_alloc.Tpo $(DEPDIR)/libstrace_a-sram_alloc.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sram_alloc.c' object='libstrace_a-sram_alloc.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-sockaddr.o `test -f 'sockaddr.c' || echo '$(srcdir)/'`sockaddr.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sram_alloc.obj `if test -f 'sram_alloc.c'; then $(CYGPATH_W) 'sram_alloc.c'; else $(CYGPATH_W) '$(srcdir)/sram_alloc.c'; fi`
 
-strace-sockaddr.obj: sockaddr.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-sockaddr.obj -MD -MP -MF $(DEPDIR)/strace-sockaddr.Tpo -c -o strace-sockaddr.obj `if test -f 'sockaddr.c'; then $(CYGPATH_W) 'sockaddr.c'; else $(CYGPATH_W) '$(srcdir)/sockaddr.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-sockaddr.Tpo $(DEPDIR)/strace-sockaddr.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sockaddr.c' object='strace-sockaddr.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-stage_output.o: stage_output.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-stage_output.o -MD -MP -MF $(DEPDIR)/libstrace_a-stage_output.Tpo -c -o libstrace_a-stage_output.o `test -f 'stage_output.c' || echo '$(srcdir)/'`stage_output.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-stage_output.Tpo $(DEPDIR)/libstrace_a-stage_output.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='stage_output.c' object='libstrace_a-stage_output.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-sockaddr.obj `if test -f 'sockaddr.c'; then $(CYGPATH_W) 'sockaddr.c'; else $(CYGPATH_W) '$(srcdir)/sockaddr.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-stage_output.o `test -f 'stage_output.c' || echo '$(srcdir)/'`stage_output.c
 
-strace-socketutils.o: socketutils.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-socketutils.o -MD -MP -MF $(DEPDIR)/strace-socketutils.Tpo -c -o strace-socketutils.o `test -f 'socketutils.c' || echo '$(srcdir)/'`socketutils.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-socketutils.Tpo $(DEPDIR)/strace-socketutils.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='socketutils.c' object='strace-socketutils.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-stage_output.obj: stage_output.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-stage_output.obj -MD -MP -MF $(DEPDIR)/libstrace_a-stage_output.Tpo -c -o libstrace_a-stage_output.obj `if test -f 'stage_output.c'; then $(CYGPATH_W) 'stage_output.c'; else $(CYGPATH_W) '$(srcdir)/stage_output.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-stage_output.Tpo $(DEPDIR)/libstrace_a-stage_output.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='stage_output.c' object='libstrace_a-stage_output.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-socketutils.o `test -f 'socketutils.c' || echo '$(srcdir)/'`socketutils.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-stage_output.obj `if test -f 'stage_output.c'; then $(CYGPATH_W) 'stage_output.c'; else $(CYGPATH_W) '$(srcdir)/stage_output.c'; fi`
 
-strace-socketutils.obj: socketutils.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-socketutils.obj -MD -MP -MF $(DEPDIR)/strace-socketutils.Tpo -c -o strace-socketutils.obj `if test -f 'socketutils.c'; then $(CYGPATH_W) 'socketutils.c'; else $(CYGPATH_W) '$(srcdir)/socketutils.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-socketutils.Tpo $(DEPDIR)/strace-socketutils.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='socketutils.c' object='strace-socketutils.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-stat.o: stat.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-stat.o -MD -MP -MF $(DEPDIR)/libstrace_a-stat.Tpo -c -o libstrace_a-stat.o `test -f 'stat.c' || echo '$(srcdir)/'`stat.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-stat.Tpo $(DEPDIR)/libstrace_a-stat.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='stat.c' object='libstrace_a-stat.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-socketutils.obj `if test -f 'socketutils.c'; then $(CYGPATH_W) 'socketutils.c'; else $(CYGPATH_W) '$(srcdir)/socketutils.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-stat.o `test -f 'stat.c' || echo '$(srcdir)/'`stat.c
 
-strace-sparc.o: sparc.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-sparc.o -MD -MP -MF $(DEPDIR)/strace-sparc.Tpo -c -o strace-sparc.o `test -f 'sparc.c' || echo '$(srcdir)/'`sparc.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-sparc.Tpo $(DEPDIR)/strace-sparc.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sparc.c' object='strace-sparc.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-stat.obj: stat.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-stat.obj -MD -MP -MF $(DEPDIR)/libstrace_a-stat.Tpo -c -o libstrace_a-stat.obj `if test -f 'stat.c'; then $(CYGPATH_W) 'stat.c'; else $(CYGPATH_W) '$(srcdir)/stat.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-stat.Tpo $(DEPDIR)/libstrace_a-stat.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='stat.c' object='libstrace_a-stat.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-sparc.o `test -f 'sparc.c' || echo '$(srcdir)/'`sparc.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-stat.obj `if test -f 'stat.c'; then $(CYGPATH_W) 'stat.c'; else $(CYGPATH_W) '$(srcdir)/stat.c'; fi`
 
-strace-sparc.obj: sparc.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-sparc.obj -MD -MP -MF $(DEPDIR)/strace-sparc.Tpo -c -o strace-sparc.obj `if test -f 'sparc.c'; then $(CYGPATH_W) 'sparc.c'; else $(CYGPATH_W) '$(srcdir)/sparc.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-sparc.Tpo $(DEPDIR)/strace-sparc.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sparc.c' object='strace-sparc.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-stat64.o: stat64.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-stat64.o -MD -MP -MF $(DEPDIR)/libstrace_a-stat64.Tpo -c -o libstrace_a-stat64.o `test -f 'stat64.c' || echo '$(srcdir)/'`stat64.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-stat64.Tpo $(DEPDIR)/libstrace_a-stat64.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='stat64.c' object='libstrace_a-stat64.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-sparc.obj `if test -f 'sparc.c'; then $(CYGPATH_W) 'sparc.c'; else $(CYGPATH_W) '$(srcdir)/sparc.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-stat64.o `test -f 'stat64.c' || echo '$(srcdir)/'`stat64.c
 
-strace-sram_alloc.o: sram_alloc.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-sram_alloc.o -MD -MP -MF $(DEPDIR)/strace-sram_alloc.Tpo -c -o strace-sram_alloc.o `test -f 'sram_alloc.c' || echo '$(srcdir)/'`sram_alloc.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-sram_alloc.Tpo $(DEPDIR)/strace-sram_alloc.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sram_alloc.c' object='strace-sram_alloc.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-stat64.obj: stat64.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-stat64.obj -MD -MP -MF $(DEPDIR)/libstrace_a-stat64.Tpo -c -o libstrace_a-stat64.obj `if test -f 'stat64.c'; then $(CYGPATH_W) 'stat64.c'; else $(CYGPATH_W) '$(srcdir)/stat64.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-stat64.Tpo $(DEPDIR)/libstrace_a-stat64.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='stat64.c' object='libstrace_a-stat64.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-sram_alloc.o `test -f 'sram_alloc.c' || echo '$(srcdir)/'`sram_alloc.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-stat64.obj `if test -f 'stat64.c'; then $(CYGPATH_W) 'stat64.c'; else $(CYGPATH_W) '$(srcdir)/stat64.c'; fi`
 
-strace-sram_alloc.obj: sram_alloc.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-sram_alloc.obj -MD -MP -MF $(DEPDIR)/strace-sram_alloc.Tpo -c -o strace-sram_alloc.obj `if test -f 'sram_alloc.c'; then $(CYGPATH_W) 'sram_alloc.c'; else $(CYGPATH_W) '$(srcdir)/sram_alloc.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-sram_alloc.Tpo $(DEPDIR)/strace-sram_alloc.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sram_alloc.c' object='strace-sram_alloc.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-statfs.o: statfs.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-statfs.o -MD -MP -MF $(DEPDIR)/libstrace_a-statfs.Tpo -c -o libstrace_a-statfs.o `test -f 'statfs.c' || echo '$(srcdir)/'`statfs.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-statfs.Tpo $(DEPDIR)/libstrace_a-statfs.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='statfs.c' object='libstrace_a-statfs.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-sram_alloc.obj `if test -f 'sram_alloc.c'; then $(CYGPATH_W) 'sram_alloc.c'; else $(CYGPATH_W) '$(srcdir)/sram_alloc.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-statfs.o `test -f 'statfs.c' || echo '$(srcdir)/'`statfs.c
 
-strace-stage_output.o: stage_output.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-stage_output.o -MD -MP -MF $(DEPDIR)/strace-stage_output.Tpo -c -o strace-stage_output.o `test -f 'stage_output.c' || echo '$(srcdir)/'`stage_output.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-stage_output.Tpo $(DEPDIR)/strace-stage_output.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='stage_output.c' object='strace-stage_output.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-statfs.obj: statfs.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-statfs.obj -MD -MP -MF $(DEPDIR)/libstrace_a-statfs.Tpo -c -o libstrace_a-statfs.obj `if test -f 'statfs.c'; then $(CYGPATH_W) 'statfs.c'; else $(CYGPATH_W) '$(srcdir)/statfs.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-statfs.Tpo $(DEPDIR)/libstrace_a-statfs.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='statfs.c' object='libstrace_a-statfs.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-stage_output.o `test -f 'stage_output.c' || echo '$(srcdir)/'`stage_output.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-statfs.obj `if test -f 'statfs.c'; then $(CYGPATH_W) 'statfs.c'; else $(CYGPATH_W) '$(srcdir)/statfs.c'; fi`
 
-strace-stage_output.obj: stage_output.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-stage_output.obj -MD -MP -MF $(DEPDIR)/strace-stage_output.Tpo -c -o strace-stage_output.obj `if test -f 'stage_output.c'; then $(CYGPATH_W) 'stage_output.c'; else $(CYGPATH_W) '$(srcdir)/stage_output.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-stage_output.Tpo $(DEPDIR)/strace-stage_output.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='stage_output.c' object='strace-stage_output.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-statfs64.o: statfs64.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-statfs64.o -MD -MP -MF $(DEPDIR)/libstrace_a-statfs64.Tpo -c -o libstrace_a-statfs64.o `test -f 'statfs64.c' || echo '$(srcdir)/'`statfs64.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-statfs64.Tpo $(DEPDIR)/libstrace_a-statfs64.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='statfs64.c' object='libstrace_a-statfs64.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-stage_output.obj `if test -f 'stage_output.c'; then $(CYGPATH_W) 'stage_output.c'; else $(CYGPATH_W) '$(srcdir)/stage_output.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-statfs64.o `test -f 'statfs64.c' || echo '$(srcdir)/'`statfs64.c
 
-strace-stat.o: stat.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-stat.o -MD -MP -MF $(DEPDIR)/strace-stat.Tpo -c -o strace-stat.o `test -f 'stat.c' || echo '$(srcdir)/'`stat.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-stat.Tpo $(DEPDIR)/strace-stat.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='stat.c' object='strace-stat.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-statfs64.obj: statfs64.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-statfs64.obj -MD -MP -MF $(DEPDIR)/libstrace_a-statfs64.Tpo -c -o libstrace_a-statfs64.obj `if test -f 'statfs64.c'; then $(CYGPATH_W) 'statfs64.c'; else $(CYGPATH_W) '$(srcdir)/statfs64.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-statfs64.Tpo $(DEPDIR)/libstrace_a-statfs64.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='statfs64.c' object='libstrace_a-statfs64.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-stat.o `test -f 'stat.c' || echo '$(srcdir)/'`stat.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-statfs64.obj `if test -f 'statfs64.c'; then $(CYGPATH_W) 'statfs64.c'; else $(CYGPATH_W) '$(srcdir)/statfs64.c'; fi`
 
-strace-stat.obj: stat.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-stat.obj -MD -MP -MF $(DEPDIR)/strace-stat.Tpo -c -o strace-stat.obj `if test -f 'stat.c'; then $(CYGPATH_W) 'stat.c'; else $(CYGPATH_W) '$(srcdir)/stat.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-stat.Tpo $(DEPDIR)/strace-stat.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='stat.c' object='strace-stat.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-statx.o: statx.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-statx.o -MD -MP -MF $(DEPDIR)/libstrace_a-statx.Tpo -c -o libstrace_a-statx.o `test -f 'statx.c' || echo '$(srcdir)/'`statx.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-statx.Tpo $(DEPDIR)/libstrace_a-statx.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='statx.c' object='libstrace_a-statx.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-stat.obj `if test -f 'stat.c'; then $(CYGPATH_W) 'stat.c'; else $(CYGPATH_W) '$(srcdir)/stat.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-statx.o `test -f 'statx.c' || echo '$(srcdir)/'`statx.c
 
-strace-stat64.o: stat64.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-stat64.o -MD -MP -MF $(DEPDIR)/strace-stat64.Tpo -c -o strace-stat64.o `test -f 'stat64.c' || echo '$(srcdir)/'`stat64.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-stat64.Tpo $(DEPDIR)/strace-stat64.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='stat64.c' object='strace-stat64.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-statx.obj: statx.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-statx.obj -MD -MP -MF $(DEPDIR)/libstrace_a-statx.Tpo -c -o libstrace_a-statx.obj `if test -f 'statx.c'; then $(CYGPATH_W) 'statx.c'; else $(CYGPATH_W) '$(srcdir)/statx.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-statx.Tpo $(DEPDIR)/libstrace_a-statx.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='statx.c' object='libstrace_a-statx.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-stat64.o `test -f 'stat64.c' || echo '$(srcdir)/'`stat64.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-statx.obj `if test -f 'statx.c'; then $(CYGPATH_W) 'statx.c'; else $(CYGPATH_W) '$(srcdir)/statx.c'; fi`
 
-strace-stat64.obj: stat64.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-stat64.obj -MD -MP -MF $(DEPDIR)/strace-stat64.Tpo -c -o strace-stat64.obj `if test -f 'stat64.c'; then $(CYGPATH_W) 'stat64.c'; else $(CYGPATH_W) '$(srcdir)/stat64.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-stat64.Tpo $(DEPDIR)/strace-stat64.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='stat64.c' object='strace-stat64.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-string_to_uint.o: string_to_uint.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-string_to_uint.o -MD -MP -MF $(DEPDIR)/libstrace_a-string_to_uint.Tpo -c -o libstrace_a-string_to_uint.o `test -f 'string_to_uint.c' || echo '$(srcdir)/'`string_to_uint.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-string_to_uint.Tpo $(DEPDIR)/libstrace_a-string_to_uint.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='string_to_uint.c' object='libstrace_a-string_to_uint.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-stat64.obj `if test -f 'stat64.c'; then $(CYGPATH_W) 'stat64.c'; else $(CYGPATH_W) '$(srcdir)/stat64.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-string_to_uint.o `test -f 'string_to_uint.c' || echo '$(srcdir)/'`string_to_uint.c
 
-strace-statfs.o: statfs.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-statfs.o -MD -MP -MF $(DEPDIR)/strace-statfs.Tpo -c -o strace-statfs.o `test -f 'statfs.c' || echo '$(srcdir)/'`statfs.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-statfs.Tpo $(DEPDIR)/strace-statfs.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='statfs.c' object='strace-statfs.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-string_to_uint.obj: string_to_uint.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-string_to_uint.obj -MD -MP -MF $(DEPDIR)/libstrace_a-string_to_uint.Tpo -c -o libstrace_a-string_to_uint.obj `if test -f 'string_to_uint.c'; then $(CYGPATH_W) 'string_to_uint.c'; else $(CYGPATH_W) '$(srcdir)/string_to_uint.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-string_to_uint.Tpo $(DEPDIR)/libstrace_a-string_to_uint.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='string_to_uint.c' object='libstrace_a-string_to_uint.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-statfs.o `test -f 'statfs.c' || echo '$(srcdir)/'`statfs.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-string_to_uint.obj `if test -f 'string_to_uint.c'; then $(CYGPATH_W) 'string_to_uint.c'; else $(CYGPATH_W) '$(srcdir)/string_to_uint.c'; fi`
 
-strace-statfs.obj: statfs.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-statfs.obj -MD -MP -MF $(DEPDIR)/strace-statfs.Tpo -c -o strace-statfs.obj `if test -f 'statfs.c'; then $(CYGPATH_W) 'statfs.c'; else $(CYGPATH_W) '$(srcdir)/statfs.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-statfs.Tpo $(DEPDIR)/strace-statfs.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='statfs.c' object='strace-statfs.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-swapon.o: swapon.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-swapon.o -MD -MP -MF $(DEPDIR)/libstrace_a-swapon.Tpo -c -o libstrace_a-swapon.o `test -f 'swapon.c' || echo '$(srcdir)/'`swapon.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-swapon.Tpo $(DEPDIR)/libstrace_a-swapon.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='swapon.c' object='libstrace_a-swapon.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-statfs.obj `if test -f 'statfs.c'; then $(CYGPATH_W) 'statfs.c'; else $(CYGPATH_W) '$(srcdir)/statfs.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-swapon.o `test -f 'swapon.c' || echo '$(srcdir)/'`swapon.c
 
-strace-statx.o: statx.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-statx.o -MD -MP -MF $(DEPDIR)/strace-statx.Tpo -c -o strace-statx.o `test -f 'statx.c' || echo '$(srcdir)/'`statx.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-statx.Tpo $(DEPDIR)/strace-statx.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='statx.c' object='strace-statx.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-swapon.obj: swapon.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-swapon.obj -MD -MP -MF $(DEPDIR)/libstrace_a-swapon.Tpo -c -o libstrace_a-swapon.obj `if test -f 'swapon.c'; then $(CYGPATH_W) 'swapon.c'; else $(CYGPATH_W) '$(srcdir)/swapon.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-swapon.Tpo $(DEPDIR)/libstrace_a-swapon.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='swapon.c' object='libstrace_a-swapon.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-statx.o `test -f 'statx.c' || echo '$(srcdir)/'`statx.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-swapon.obj `if test -f 'swapon.c'; then $(CYGPATH_W) 'swapon.c'; else $(CYGPATH_W) '$(srcdir)/swapon.c'; fi`
 
-strace-statx.obj: statx.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-statx.obj -MD -MP -MF $(DEPDIR)/strace-statx.Tpo -c -o strace-statx.obj `if test -f 'statx.c'; then $(CYGPATH_W) 'statx.c'; else $(CYGPATH_W) '$(srcdir)/statx.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-statx.Tpo $(DEPDIR)/strace-statx.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='statx.c' object='strace-statx.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-sync_file_range.o: sync_file_range.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sync_file_range.o -MD -MP -MF $(DEPDIR)/libstrace_a-sync_file_range.Tpo -c -o libstrace_a-sync_file_range.o `test -f 'sync_file_range.c' || echo '$(srcdir)/'`sync_file_range.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sync_file_range.Tpo $(DEPDIR)/libstrace_a-sync_file_range.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sync_file_range.c' object='libstrace_a-sync_file_range.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-statx.obj `if test -f 'statx.c'; then $(CYGPATH_W) 'statx.c'; else $(CYGPATH_W) '$(srcdir)/statx.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sync_file_range.o `test -f 'sync_file_range.c' || echo '$(srcdir)/'`sync_file_range.c
 
-strace-strace.o: strace.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-strace.o -MD -MP -MF $(DEPDIR)/strace-strace.Tpo -c -o strace-strace.o `test -f 'strace.c' || echo '$(srcdir)/'`strace.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-strace.Tpo $(DEPDIR)/strace-strace.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='strace.c' object='strace-strace.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-sync_file_range.obj: sync_file_range.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sync_file_range.obj -MD -MP -MF $(DEPDIR)/libstrace_a-sync_file_range.Tpo -c -o libstrace_a-sync_file_range.obj `if test -f 'sync_file_range.c'; then $(CYGPATH_W) 'sync_file_range.c'; else $(CYGPATH_W) '$(srcdir)/sync_file_range.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sync_file_range.Tpo $(DEPDIR)/libstrace_a-sync_file_range.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sync_file_range.c' object='libstrace_a-sync_file_range.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-strace.o `test -f 'strace.c' || echo '$(srcdir)/'`strace.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sync_file_range.obj `if test -f 'sync_file_range.c'; then $(CYGPATH_W) 'sync_file_range.c'; else $(CYGPATH_W) '$(srcdir)/sync_file_range.c'; fi`
 
-strace-strace.obj: strace.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-strace.obj -MD -MP -MF $(DEPDIR)/strace-strace.Tpo -c -o strace-strace.obj `if test -f 'strace.c'; then $(CYGPATH_W) 'strace.c'; else $(CYGPATH_W) '$(srcdir)/strace.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-strace.Tpo $(DEPDIR)/strace-strace.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='strace.c' object='strace-strace.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-sync_file_range2.o: sync_file_range2.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sync_file_range2.o -MD -MP -MF $(DEPDIR)/libstrace_a-sync_file_range2.Tpo -c -o libstrace_a-sync_file_range2.o `test -f 'sync_file_range2.c' || echo '$(srcdir)/'`sync_file_range2.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sync_file_range2.Tpo $(DEPDIR)/libstrace_a-sync_file_range2.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sync_file_range2.c' object='libstrace_a-sync_file_range2.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-strace.obj `if test -f 'strace.c'; then $(CYGPATH_W) 'strace.c'; else $(CYGPATH_W) '$(srcdir)/strace.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sync_file_range2.o `test -f 'sync_file_range2.c' || echo '$(srcdir)/'`sync_file_range2.c
+
+libstrace_a-sync_file_range2.obj: sync_file_range2.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sync_file_range2.obj -MD -MP -MF $(DEPDIR)/libstrace_a-sync_file_range2.Tpo -c -o libstrace_a-sync_file_range2.obj `if test -f 'sync_file_range2.c'; then $(CYGPATH_W) 'sync_file_range2.c'; else $(CYGPATH_W) '$(srcdir)/sync_file_range2.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sync_file_range2.Tpo $(DEPDIR)/libstrace_a-sync_file_range2.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sync_file_range2.c' object='libstrace_a-sync_file_range2.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sync_file_range2.obj `if test -f 'sync_file_range2.c'; then $(CYGPATH_W) 'sync_file_range2.c'; else $(CYGPATH_W) '$(srcdir)/sync_file_range2.c'; fi`
+
+libstrace_a-syscall.o: syscall.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-syscall.o -MD -MP -MF $(DEPDIR)/libstrace_a-syscall.Tpo -c -o libstrace_a-syscall.o `test -f 'syscall.c' || echo '$(srcdir)/'`syscall.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-syscall.Tpo $(DEPDIR)/libstrace_a-syscall.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='syscall.c' object='libstrace_a-syscall.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-syscall.o `test -f 'syscall.c' || echo '$(srcdir)/'`syscall.c
+
+libstrace_a-syscall.obj: syscall.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-syscall.obj -MD -MP -MF $(DEPDIR)/libstrace_a-syscall.Tpo -c -o libstrace_a-syscall.obj `if test -f 'syscall.c'; then $(CYGPATH_W) 'syscall.c'; else $(CYGPATH_W) '$(srcdir)/syscall.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-syscall.Tpo $(DEPDIR)/libstrace_a-syscall.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='syscall.c' object='libstrace_a-syscall.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-syscall.obj `if test -f 'syscall.c'; then $(CYGPATH_W) 'syscall.c'; else $(CYGPATH_W) '$(srcdir)/syscall.c'; fi`
+
+libstrace_a-sysctl.o: sysctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sysctl.o -MD -MP -MF $(DEPDIR)/libstrace_a-sysctl.Tpo -c -o libstrace_a-sysctl.o `test -f 'sysctl.c' || echo '$(srcdir)/'`sysctl.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sysctl.Tpo $(DEPDIR)/libstrace_a-sysctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sysctl.c' object='libstrace_a-sysctl.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sysctl.o `test -f 'sysctl.c' || echo '$(srcdir)/'`sysctl.c
+
+libstrace_a-sysctl.obj: sysctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sysctl.obj -MD -MP -MF $(DEPDIR)/libstrace_a-sysctl.Tpo -c -o libstrace_a-sysctl.obj `if test -f 'sysctl.c'; then $(CYGPATH_W) 'sysctl.c'; else $(CYGPATH_W) '$(srcdir)/sysctl.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sysctl.Tpo $(DEPDIR)/libstrace_a-sysctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sysctl.c' object='libstrace_a-sysctl.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sysctl.obj `if test -f 'sysctl.c'; then $(CYGPATH_W) 'sysctl.c'; else $(CYGPATH_W) '$(srcdir)/sysctl.c'; fi`
+
+libstrace_a-sysinfo.o: sysinfo.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sysinfo.o -MD -MP -MF $(DEPDIR)/libstrace_a-sysinfo.Tpo -c -o libstrace_a-sysinfo.o `test -f 'sysinfo.c' || echo '$(srcdir)/'`sysinfo.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sysinfo.Tpo $(DEPDIR)/libstrace_a-sysinfo.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sysinfo.c' object='libstrace_a-sysinfo.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sysinfo.o `test -f 'sysinfo.c' || echo '$(srcdir)/'`sysinfo.c
+
+libstrace_a-sysinfo.obj: sysinfo.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sysinfo.obj -MD -MP -MF $(DEPDIR)/libstrace_a-sysinfo.Tpo -c -o libstrace_a-sysinfo.obj `if test -f 'sysinfo.c'; then $(CYGPATH_W) 'sysinfo.c'; else $(CYGPATH_W) '$(srcdir)/sysinfo.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sysinfo.Tpo $(DEPDIR)/libstrace_a-sysinfo.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sysinfo.c' object='libstrace_a-sysinfo.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sysinfo.obj `if test -f 'sysinfo.c'; then $(CYGPATH_W) 'sysinfo.c'; else $(CYGPATH_W) '$(srcdir)/sysinfo.c'; fi`
+
+libstrace_a-syslog.o: syslog.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-syslog.o -MD -MP -MF $(DEPDIR)/libstrace_a-syslog.Tpo -c -o libstrace_a-syslog.o `test -f 'syslog.c' || echo '$(srcdir)/'`syslog.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-syslog.Tpo $(DEPDIR)/libstrace_a-syslog.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='syslog.c' object='libstrace_a-syslog.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-syslog.o `test -f 'syslog.c' || echo '$(srcdir)/'`syslog.c
+
+libstrace_a-syslog.obj: syslog.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-syslog.obj -MD -MP -MF $(DEPDIR)/libstrace_a-syslog.Tpo -c -o libstrace_a-syslog.obj `if test -f 'syslog.c'; then $(CYGPATH_W) 'syslog.c'; else $(CYGPATH_W) '$(srcdir)/syslog.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-syslog.Tpo $(DEPDIR)/libstrace_a-syslog.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='syslog.c' object='libstrace_a-syslog.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-syslog.obj `if test -f 'syslog.c'; then $(CYGPATH_W) 'syslog.c'; else $(CYGPATH_W) '$(srcdir)/syslog.c'; fi`
+
+libstrace_a-sysmips.o: sysmips.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sysmips.o -MD -MP -MF $(DEPDIR)/libstrace_a-sysmips.Tpo -c -o libstrace_a-sysmips.o `test -f 'sysmips.c' || echo '$(srcdir)/'`sysmips.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sysmips.Tpo $(DEPDIR)/libstrace_a-sysmips.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sysmips.c' object='libstrace_a-sysmips.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sysmips.o `test -f 'sysmips.c' || echo '$(srcdir)/'`sysmips.c
+
+libstrace_a-sysmips.obj: sysmips.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-sysmips.obj -MD -MP -MF $(DEPDIR)/libstrace_a-sysmips.Tpo -c -o libstrace_a-sysmips.obj `if test -f 'sysmips.c'; then $(CYGPATH_W) 'sysmips.c'; else $(CYGPATH_W) '$(srcdir)/sysmips.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-sysmips.Tpo $(DEPDIR)/libstrace_a-sysmips.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sysmips.c' object='libstrace_a-sysmips.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-sysmips.obj `if test -f 'sysmips.c'; then $(CYGPATH_W) 'sysmips.c'; else $(CYGPATH_W) '$(srcdir)/sysmips.c'; fi`
+
+libstrace_a-tee.o: tee.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-tee.o -MD -MP -MF $(DEPDIR)/libstrace_a-tee.Tpo -c -o libstrace_a-tee.o `test -f 'tee.c' || echo '$(srcdir)/'`tee.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-tee.Tpo $(DEPDIR)/libstrace_a-tee.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='tee.c' object='libstrace_a-tee.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-tee.o `test -f 'tee.c' || echo '$(srcdir)/'`tee.c
+
+libstrace_a-tee.obj: tee.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-tee.obj -MD -MP -MF $(DEPDIR)/libstrace_a-tee.Tpo -c -o libstrace_a-tee.obj `if test -f 'tee.c'; then $(CYGPATH_W) 'tee.c'; else $(CYGPATH_W) '$(srcdir)/tee.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-tee.Tpo $(DEPDIR)/libstrace_a-tee.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='tee.c' object='libstrace_a-tee.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-tee.obj `if test -f 'tee.c'; then $(CYGPATH_W) 'tee.c'; else $(CYGPATH_W) '$(srcdir)/tee.c'; fi`
+
+libstrace_a-term.o: term.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-term.o -MD -MP -MF $(DEPDIR)/libstrace_a-term.Tpo -c -o libstrace_a-term.o `test -f 'term.c' || echo '$(srcdir)/'`term.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-term.Tpo $(DEPDIR)/libstrace_a-term.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='term.c' object='libstrace_a-term.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-term.o `test -f 'term.c' || echo '$(srcdir)/'`term.c
+
+libstrace_a-term.obj: term.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-term.obj -MD -MP -MF $(DEPDIR)/libstrace_a-term.Tpo -c -o libstrace_a-term.obj `if test -f 'term.c'; then $(CYGPATH_W) 'term.c'; else $(CYGPATH_W) '$(srcdir)/term.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-term.Tpo $(DEPDIR)/libstrace_a-term.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='term.c' object='libstrace_a-term.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-term.obj `if test -f 'term.c'; then $(CYGPATH_W) 'term.c'; else $(CYGPATH_W) '$(srcdir)/term.c'; fi`
+
+libstrace_a-time.o: time.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-time.o -MD -MP -MF $(DEPDIR)/libstrace_a-time.Tpo -c -o libstrace_a-time.o `test -f 'time.c' || echo '$(srcdir)/'`time.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-time.Tpo $(DEPDIR)/libstrace_a-time.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='time.c' object='libstrace_a-time.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-time.o `test -f 'time.c' || echo '$(srcdir)/'`time.c
+
+libstrace_a-time.obj: time.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-time.obj -MD -MP -MF $(DEPDIR)/libstrace_a-time.Tpo -c -o libstrace_a-time.obj `if test -f 'time.c'; then $(CYGPATH_W) 'time.c'; else $(CYGPATH_W) '$(srcdir)/time.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-time.Tpo $(DEPDIR)/libstrace_a-time.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='time.c' object='libstrace_a-time.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-time.obj `if test -f 'time.c'; then $(CYGPATH_W) 'time.c'; else $(CYGPATH_W) '$(srcdir)/time.c'; fi`
+
+libstrace_a-times.o: times.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-times.o -MD -MP -MF $(DEPDIR)/libstrace_a-times.Tpo -c -o libstrace_a-times.o `test -f 'times.c' || echo '$(srcdir)/'`times.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-times.Tpo $(DEPDIR)/libstrace_a-times.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='times.c' object='libstrace_a-times.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-times.o `test -f 'times.c' || echo '$(srcdir)/'`times.c
+
+libstrace_a-times.obj: times.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-times.obj -MD -MP -MF $(DEPDIR)/libstrace_a-times.Tpo -c -o libstrace_a-times.obj `if test -f 'times.c'; then $(CYGPATH_W) 'times.c'; else $(CYGPATH_W) '$(srcdir)/times.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-times.Tpo $(DEPDIR)/libstrace_a-times.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='times.c' object='libstrace_a-times.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-times.obj `if test -f 'times.c'; then $(CYGPATH_W) 'times.c'; else $(CYGPATH_W) '$(srcdir)/times.c'; fi`
 
-strace-string_to_uint.o: string_to_uint.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-string_to_uint.o -MD -MP -MF $(DEPDIR)/strace-string_to_uint.Tpo -c -o strace-string_to_uint.o `test -f 'string_to_uint.c' || echo '$(srcdir)/'`string_to_uint.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-string_to_uint.Tpo $(DEPDIR)/strace-string_to_uint.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='string_to_uint.c' object='strace-string_to_uint.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-trie.o: trie.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-trie.o -MD -MP -MF $(DEPDIR)/libstrace_a-trie.Tpo -c -o libstrace_a-trie.o `test -f 'trie.c' || echo '$(srcdir)/'`trie.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-trie.Tpo $(DEPDIR)/libstrace_a-trie.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='trie.c' object='libstrace_a-trie.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-string_to_uint.o `test -f 'string_to_uint.c' || echo '$(srcdir)/'`string_to_uint.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-trie.o `test -f 'trie.c' || echo '$(srcdir)/'`trie.c
 
-strace-string_to_uint.obj: string_to_uint.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-string_to_uint.obj -MD -MP -MF $(DEPDIR)/strace-string_to_uint.Tpo -c -o strace-string_to_uint.obj `if test -f 'string_to_uint.c'; then $(CYGPATH_W) 'string_to_uint.c'; else $(CYGPATH_W) '$(srcdir)/string_to_uint.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-string_to_uint.Tpo $(DEPDIR)/strace-string_to_uint.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='string_to_uint.c' object='strace-string_to_uint.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-trie.obj: trie.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-trie.obj -MD -MP -MF $(DEPDIR)/libstrace_a-trie.Tpo -c -o libstrace_a-trie.obj `if test -f 'trie.c'; then $(CYGPATH_W) 'trie.c'; else $(CYGPATH_W) '$(srcdir)/trie.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-trie.Tpo $(DEPDIR)/libstrace_a-trie.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='trie.c' object='libstrace_a-trie.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-string_to_uint.obj `if test -f 'string_to_uint.c'; then $(CYGPATH_W) 'string_to_uint.c'; else $(CYGPATH_W) '$(srcdir)/string_to_uint.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-trie.obj `if test -f 'trie.c'; then $(CYGPATH_W) 'trie.c'; else $(CYGPATH_W) '$(srcdir)/trie.c'; fi`
 
-strace-swapon.o: swapon.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-swapon.o -MD -MP -MF $(DEPDIR)/strace-swapon.Tpo -c -o strace-swapon.o `test -f 'swapon.c' || echo '$(srcdir)/'`swapon.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-swapon.Tpo $(DEPDIR)/strace-swapon.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='swapon.c' object='strace-swapon.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-truncate.o: truncate.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-truncate.o -MD -MP -MF $(DEPDIR)/libstrace_a-truncate.Tpo -c -o libstrace_a-truncate.o `test -f 'truncate.c' || echo '$(srcdir)/'`truncate.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-truncate.Tpo $(DEPDIR)/libstrace_a-truncate.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='truncate.c' object='libstrace_a-truncate.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-swapon.o `test -f 'swapon.c' || echo '$(srcdir)/'`swapon.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-truncate.o `test -f 'truncate.c' || echo '$(srcdir)/'`truncate.c
 
-strace-swapon.obj: swapon.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-swapon.obj -MD -MP -MF $(DEPDIR)/strace-swapon.Tpo -c -o strace-swapon.obj `if test -f 'swapon.c'; then $(CYGPATH_W) 'swapon.c'; else $(CYGPATH_W) '$(srcdir)/swapon.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-swapon.Tpo $(DEPDIR)/strace-swapon.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='swapon.c' object='strace-swapon.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-truncate.obj: truncate.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-truncate.obj -MD -MP -MF $(DEPDIR)/libstrace_a-truncate.Tpo -c -o libstrace_a-truncate.obj `if test -f 'truncate.c'; then $(CYGPATH_W) 'truncate.c'; else $(CYGPATH_W) '$(srcdir)/truncate.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-truncate.Tpo $(DEPDIR)/libstrace_a-truncate.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='truncate.c' object='libstrace_a-truncate.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-swapon.obj `if test -f 'swapon.c'; then $(CYGPATH_W) 'swapon.c'; else $(CYGPATH_W) '$(srcdir)/swapon.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-truncate.obj `if test -f 'truncate.c'; then $(CYGPATH_W) 'truncate.c'; else $(CYGPATH_W) '$(srcdir)/truncate.c'; fi`
 
-strace-syscall.o: syscall.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-syscall.o -MD -MP -MF $(DEPDIR)/strace-syscall.Tpo -c -o strace-syscall.o `test -f 'syscall.c' || echo '$(srcdir)/'`syscall.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-syscall.Tpo $(DEPDIR)/strace-syscall.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='syscall.c' object='strace-syscall.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ubi.o: ubi.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ubi.o -MD -MP -MF $(DEPDIR)/libstrace_a-ubi.Tpo -c -o libstrace_a-ubi.o `test -f 'ubi.c' || echo '$(srcdir)/'`ubi.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ubi.Tpo $(DEPDIR)/libstrace_a-ubi.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ubi.c' object='libstrace_a-ubi.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-syscall.o `test -f 'syscall.c' || echo '$(srcdir)/'`syscall.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ubi.o `test -f 'ubi.c' || echo '$(srcdir)/'`ubi.c
 
-strace-syscall.obj: syscall.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-syscall.obj -MD -MP -MF $(DEPDIR)/strace-syscall.Tpo -c -o strace-syscall.obj `if test -f 'syscall.c'; then $(CYGPATH_W) 'syscall.c'; else $(CYGPATH_W) '$(srcdir)/syscall.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-syscall.Tpo $(DEPDIR)/strace-syscall.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='syscall.c' object='strace-syscall.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ubi.obj: ubi.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ubi.obj -MD -MP -MF $(DEPDIR)/libstrace_a-ubi.Tpo -c -o libstrace_a-ubi.obj `if test -f 'ubi.c'; then $(CYGPATH_W) 'ubi.c'; else $(CYGPATH_W) '$(srcdir)/ubi.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ubi.Tpo $(DEPDIR)/libstrace_a-ubi.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ubi.c' object='libstrace_a-ubi.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-syscall.obj `if test -f 'syscall.c'; then $(CYGPATH_W) 'syscall.c'; else $(CYGPATH_W) '$(srcdir)/syscall.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ubi.obj `if test -f 'ubi.c'; then $(CYGPATH_W) 'ubi.c'; else $(CYGPATH_W) '$(srcdir)/ubi.c'; fi`
 
-strace-sysctl.o: sysctl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-sysctl.o -MD -MP -MF $(DEPDIR)/strace-sysctl.Tpo -c -o strace-sysctl.o `test -f 'sysctl.c' || echo '$(srcdir)/'`sysctl.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-sysctl.Tpo $(DEPDIR)/strace-sysctl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sysctl.c' object='strace-sysctl.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ucopy.o: ucopy.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ucopy.o -MD -MP -MF $(DEPDIR)/libstrace_a-ucopy.Tpo -c -o libstrace_a-ucopy.o `test -f 'ucopy.c' || echo '$(srcdir)/'`ucopy.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ucopy.Tpo $(DEPDIR)/libstrace_a-ucopy.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ucopy.c' object='libstrace_a-ucopy.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-sysctl.o `test -f 'sysctl.c' || echo '$(srcdir)/'`sysctl.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ucopy.o `test -f 'ucopy.c' || echo '$(srcdir)/'`ucopy.c
 
-strace-sysctl.obj: sysctl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-sysctl.obj -MD -MP -MF $(DEPDIR)/strace-sysctl.Tpo -c -o strace-sysctl.obj `if test -f 'sysctl.c'; then $(CYGPATH_W) 'sysctl.c'; else $(CYGPATH_W) '$(srcdir)/sysctl.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-sysctl.Tpo $(DEPDIR)/strace-sysctl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sysctl.c' object='strace-sysctl.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ucopy.obj: ucopy.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ucopy.obj -MD -MP -MF $(DEPDIR)/libstrace_a-ucopy.Tpo -c -o libstrace_a-ucopy.obj `if test -f 'ucopy.c'; then $(CYGPATH_W) 'ucopy.c'; else $(CYGPATH_W) '$(srcdir)/ucopy.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ucopy.Tpo $(DEPDIR)/libstrace_a-ucopy.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ucopy.c' object='libstrace_a-ucopy.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-sysctl.obj `if test -f 'sysctl.c'; then $(CYGPATH_W) 'sysctl.c'; else $(CYGPATH_W) '$(srcdir)/sysctl.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ucopy.obj `if test -f 'ucopy.c'; then $(CYGPATH_W) 'ucopy.c'; else $(CYGPATH_W) '$(srcdir)/ucopy.c'; fi`
 
-strace-sysinfo.o: sysinfo.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-sysinfo.o -MD -MP -MF $(DEPDIR)/strace-sysinfo.Tpo -c -o strace-sysinfo.o `test -f 'sysinfo.c' || echo '$(srcdir)/'`sysinfo.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-sysinfo.Tpo $(DEPDIR)/strace-sysinfo.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sysinfo.c' object='strace-sysinfo.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-uid.o: uid.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-uid.o -MD -MP -MF $(DEPDIR)/libstrace_a-uid.Tpo -c -o libstrace_a-uid.o `test -f 'uid.c' || echo '$(srcdir)/'`uid.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-uid.Tpo $(DEPDIR)/libstrace_a-uid.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='uid.c' object='libstrace_a-uid.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-sysinfo.o `test -f 'sysinfo.c' || echo '$(srcdir)/'`sysinfo.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-uid.o `test -f 'uid.c' || echo '$(srcdir)/'`uid.c
 
-strace-sysinfo.obj: sysinfo.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-sysinfo.obj -MD -MP -MF $(DEPDIR)/strace-sysinfo.Tpo -c -o strace-sysinfo.obj `if test -f 'sysinfo.c'; then $(CYGPATH_W) 'sysinfo.c'; else $(CYGPATH_W) '$(srcdir)/sysinfo.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-sysinfo.Tpo $(DEPDIR)/strace-sysinfo.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sysinfo.c' object='strace-sysinfo.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-uid.obj: uid.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-uid.obj -MD -MP -MF $(DEPDIR)/libstrace_a-uid.Tpo -c -o libstrace_a-uid.obj `if test -f 'uid.c'; then $(CYGPATH_W) 'uid.c'; else $(CYGPATH_W) '$(srcdir)/uid.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-uid.Tpo $(DEPDIR)/libstrace_a-uid.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='uid.c' object='libstrace_a-uid.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-sysinfo.obj `if test -f 'sysinfo.c'; then $(CYGPATH_W) 'sysinfo.c'; else $(CYGPATH_W) '$(srcdir)/sysinfo.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-uid.obj `if test -f 'uid.c'; then $(CYGPATH_W) 'uid.c'; else $(CYGPATH_W) '$(srcdir)/uid.c'; fi`
 
-strace-syslog.o: syslog.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-syslog.o -MD -MP -MF $(DEPDIR)/strace-syslog.Tpo -c -o strace-syslog.o `test -f 'syslog.c' || echo '$(srcdir)/'`syslog.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-syslog.Tpo $(DEPDIR)/strace-syslog.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='syslog.c' object='strace-syslog.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-uid16.o: uid16.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-uid16.o -MD -MP -MF $(DEPDIR)/libstrace_a-uid16.Tpo -c -o libstrace_a-uid16.o `test -f 'uid16.c' || echo '$(srcdir)/'`uid16.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-uid16.Tpo $(DEPDIR)/libstrace_a-uid16.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='uid16.c' object='libstrace_a-uid16.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-syslog.o `test -f 'syslog.c' || echo '$(srcdir)/'`syslog.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-uid16.o `test -f 'uid16.c' || echo '$(srcdir)/'`uid16.c
 
-strace-syslog.obj: syslog.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-syslog.obj -MD -MP -MF $(DEPDIR)/strace-syslog.Tpo -c -o strace-syslog.obj `if test -f 'syslog.c'; then $(CYGPATH_W) 'syslog.c'; else $(CYGPATH_W) '$(srcdir)/syslog.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-syslog.Tpo $(DEPDIR)/strace-syslog.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='syslog.c' object='strace-syslog.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-uid16.obj: uid16.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-uid16.obj -MD -MP -MF $(DEPDIR)/libstrace_a-uid16.Tpo -c -o libstrace_a-uid16.obj `if test -f 'uid16.c'; then $(CYGPATH_W) 'uid16.c'; else $(CYGPATH_W) '$(srcdir)/uid16.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-uid16.Tpo $(DEPDIR)/libstrace_a-uid16.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='uid16.c' object='libstrace_a-uid16.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-syslog.obj `if test -f 'syslog.c'; then $(CYGPATH_W) 'syslog.c'; else $(CYGPATH_W) '$(srcdir)/syslog.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-uid16.obj `if test -f 'uid16.c'; then $(CYGPATH_W) 'uid16.c'; else $(CYGPATH_W) '$(srcdir)/uid16.c'; fi`
 
-strace-sysmips.o: sysmips.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-sysmips.o -MD -MP -MF $(DEPDIR)/strace-sysmips.Tpo -c -o strace-sysmips.o `test -f 'sysmips.c' || echo '$(srcdir)/'`sysmips.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-sysmips.Tpo $(DEPDIR)/strace-sysmips.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sysmips.c' object='strace-sysmips.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-umask.o: umask.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-umask.o -MD -MP -MF $(DEPDIR)/libstrace_a-umask.Tpo -c -o libstrace_a-umask.o `test -f 'umask.c' || echo '$(srcdir)/'`umask.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-umask.Tpo $(DEPDIR)/libstrace_a-umask.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='umask.c' object='libstrace_a-umask.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-sysmips.o `test -f 'sysmips.c' || echo '$(srcdir)/'`sysmips.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-umask.o `test -f 'umask.c' || echo '$(srcdir)/'`umask.c
 
-strace-sysmips.obj: sysmips.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-sysmips.obj -MD -MP -MF $(DEPDIR)/strace-sysmips.Tpo -c -o strace-sysmips.obj `if test -f 'sysmips.c'; then $(CYGPATH_W) 'sysmips.c'; else $(CYGPATH_W) '$(srcdir)/sysmips.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-sysmips.Tpo $(DEPDIR)/strace-sysmips.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='sysmips.c' object='strace-sysmips.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-umask.obj: umask.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-umask.obj -MD -MP -MF $(DEPDIR)/libstrace_a-umask.Tpo -c -o libstrace_a-umask.obj `if test -f 'umask.c'; then $(CYGPATH_W) 'umask.c'; else $(CYGPATH_W) '$(srcdir)/umask.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-umask.Tpo $(DEPDIR)/libstrace_a-umask.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='umask.c' object='libstrace_a-umask.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-sysmips.obj `if test -f 'sysmips.c'; then $(CYGPATH_W) 'sysmips.c'; else $(CYGPATH_W) '$(srcdir)/sysmips.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-umask.obj `if test -f 'umask.c'; then $(CYGPATH_W) 'umask.c'; else $(CYGPATH_W) '$(srcdir)/umask.c'; fi`
 
-strace-term.o: term.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-term.o -MD -MP -MF $(DEPDIR)/strace-term.Tpo -c -o strace-term.o `test -f 'term.c' || echo '$(srcdir)/'`term.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-term.Tpo $(DEPDIR)/strace-term.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='term.c' object='strace-term.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-umount.o: umount.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-umount.o -MD -MP -MF $(DEPDIR)/libstrace_a-umount.Tpo -c -o libstrace_a-umount.o `test -f 'umount.c' || echo '$(srcdir)/'`umount.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-umount.Tpo $(DEPDIR)/libstrace_a-umount.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='umount.c' object='libstrace_a-umount.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-term.o `test -f 'term.c' || echo '$(srcdir)/'`term.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-umount.o `test -f 'umount.c' || echo '$(srcdir)/'`umount.c
 
-strace-term.obj: term.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-term.obj -MD -MP -MF $(DEPDIR)/strace-term.Tpo -c -o strace-term.obj `if test -f 'term.c'; then $(CYGPATH_W) 'term.c'; else $(CYGPATH_W) '$(srcdir)/term.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-term.Tpo $(DEPDIR)/strace-term.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='term.c' object='strace-term.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-umount.obj: umount.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-umount.obj -MD -MP -MF $(DEPDIR)/libstrace_a-umount.Tpo -c -o libstrace_a-umount.obj `if test -f 'umount.c'; then $(CYGPATH_W) 'umount.c'; else $(CYGPATH_W) '$(srcdir)/umount.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-umount.Tpo $(DEPDIR)/libstrace_a-umount.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='umount.c' object='libstrace_a-umount.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-term.obj `if test -f 'term.c'; then $(CYGPATH_W) 'term.c'; else $(CYGPATH_W) '$(srcdir)/term.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-umount.obj `if test -f 'umount.c'; then $(CYGPATH_W) 'umount.c'; else $(CYGPATH_W) '$(srcdir)/umount.c'; fi`
 
-strace-time.o: time.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-time.o -MD -MP -MF $(DEPDIR)/strace-time.Tpo -c -o strace-time.o `test -f 'time.c' || echo '$(srcdir)/'`time.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-time.Tpo $(DEPDIR)/strace-time.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='time.c' object='strace-time.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-uname.o: uname.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-uname.o -MD -MP -MF $(DEPDIR)/libstrace_a-uname.Tpo -c -o libstrace_a-uname.o `test -f 'uname.c' || echo '$(srcdir)/'`uname.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-uname.Tpo $(DEPDIR)/libstrace_a-uname.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='uname.c' object='libstrace_a-uname.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-time.o `test -f 'time.c' || echo '$(srcdir)/'`time.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-uname.o `test -f 'uname.c' || echo '$(srcdir)/'`uname.c
 
-strace-time.obj: time.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-time.obj -MD -MP -MF $(DEPDIR)/strace-time.Tpo -c -o strace-time.obj `if test -f 'time.c'; then $(CYGPATH_W) 'time.c'; else $(CYGPATH_W) '$(srcdir)/time.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-time.Tpo $(DEPDIR)/strace-time.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='time.c' object='strace-time.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-uname.obj: uname.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-uname.obj -MD -MP -MF $(DEPDIR)/libstrace_a-uname.Tpo -c -o libstrace_a-uname.obj `if test -f 'uname.c'; then $(CYGPATH_W) 'uname.c'; else $(CYGPATH_W) '$(srcdir)/uname.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-uname.Tpo $(DEPDIR)/libstrace_a-uname.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='uname.c' object='libstrace_a-uname.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-time.obj `if test -f 'time.c'; then $(CYGPATH_W) 'time.c'; else $(CYGPATH_W) '$(srcdir)/time.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-uname.obj `if test -f 'uname.c'; then $(CYGPATH_W) 'uname.c'; else $(CYGPATH_W) '$(srcdir)/uname.c'; fi`
 
-strace-times.o: times.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-times.o -MD -MP -MF $(DEPDIR)/strace-times.Tpo -c -o strace-times.o `test -f 'times.c' || echo '$(srcdir)/'`times.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-times.Tpo $(DEPDIR)/strace-times.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='times.c' object='strace-times.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-upeek.o: upeek.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-upeek.o -MD -MP -MF $(DEPDIR)/libstrace_a-upeek.Tpo -c -o libstrace_a-upeek.o `test -f 'upeek.c' || echo '$(srcdir)/'`upeek.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-upeek.Tpo $(DEPDIR)/libstrace_a-upeek.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='upeek.c' object='libstrace_a-upeek.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-times.o `test -f 'times.c' || echo '$(srcdir)/'`times.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-upeek.o `test -f 'upeek.c' || echo '$(srcdir)/'`upeek.c
 
-strace-times.obj: times.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-times.obj -MD -MP -MF $(DEPDIR)/strace-times.Tpo -c -o strace-times.obj `if test -f 'times.c'; then $(CYGPATH_W) 'times.c'; else $(CYGPATH_W) '$(srcdir)/times.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-times.Tpo $(DEPDIR)/strace-times.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='times.c' object='strace-times.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-upeek.obj: upeek.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-upeek.obj -MD -MP -MF $(DEPDIR)/libstrace_a-upeek.Tpo -c -o libstrace_a-upeek.obj `if test -f 'upeek.c'; then $(CYGPATH_W) 'upeek.c'; else $(CYGPATH_W) '$(srcdir)/upeek.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-upeek.Tpo $(DEPDIR)/libstrace_a-upeek.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='upeek.c' object='libstrace_a-upeek.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-times.obj `if test -f 'times.c'; then $(CYGPATH_W) 'times.c'; else $(CYGPATH_W) '$(srcdir)/times.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-upeek.obj `if test -f 'upeek.c'; then $(CYGPATH_W) 'upeek.c'; else $(CYGPATH_W) '$(srcdir)/upeek.c'; fi`
 
-strace-truncate.o: truncate.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-truncate.o -MD -MP -MF $(DEPDIR)/strace-truncate.Tpo -c -o strace-truncate.o `test -f 'truncate.c' || echo '$(srcdir)/'`truncate.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-truncate.Tpo $(DEPDIR)/strace-truncate.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='truncate.c' object='strace-truncate.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-upoke.o: upoke.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-upoke.o -MD -MP -MF $(DEPDIR)/libstrace_a-upoke.Tpo -c -o libstrace_a-upoke.o `test -f 'upoke.c' || echo '$(srcdir)/'`upoke.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-upoke.Tpo $(DEPDIR)/libstrace_a-upoke.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='upoke.c' object='libstrace_a-upoke.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-truncate.o `test -f 'truncate.c' || echo '$(srcdir)/'`truncate.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-upoke.o `test -f 'upoke.c' || echo '$(srcdir)/'`upoke.c
 
-strace-truncate.obj: truncate.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-truncate.obj -MD -MP -MF $(DEPDIR)/strace-truncate.Tpo -c -o strace-truncate.obj `if test -f 'truncate.c'; then $(CYGPATH_W) 'truncate.c'; else $(CYGPATH_W) '$(srcdir)/truncate.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-truncate.Tpo $(DEPDIR)/strace-truncate.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='truncate.c' object='strace-truncate.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-upoke.obj: upoke.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-upoke.obj -MD -MP -MF $(DEPDIR)/libstrace_a-upoke.Tpo -c -o libstrace_a-upoke.obj `if test -f 'upoke.c'; then $(CYGPATH_W) 'upoke.c'; else $(CYGPATH_W) '$(srcdir)/upoke.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-upoke.Tpo $(DEPDIR)/libstrace_a-upoke.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='upoke.c' object='libstrace_a-upoke.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-truncate.obj `if test -f 'truncate.c'; then $(CYGPATH_W) 'truncate.c'; else $(CYGPATH_W) '$(srcdir)/truncate.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-upoke.obj `if test -f 'upoke.c'; then $(CYGPATH_W) 'upoke.c'; else $(CYGPATH_W) '$(srcdir)/upoke.c'; fi`
 
-strace-ubi.o: ubi.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ubi.o -MD -MP -MF $(DEPDIR)/strace-ubi.Tpo -c -o strace-ubi.o `test -f 'ubi.c' || echo '$(srcdir)/'`ubi.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ubi.Tpo $(DEPDIR)/strace-ubi.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ubi.c' object='strace-ubi.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-userfaultfd.o: userfaultfd.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-userfaultfd.o -MD -MP -MF $(DEPDIR)/libstrace_a-userfaultfd.Tpo -c -o libstrace_a-userfaultfd.o `test -f 'userfaultfd.c' || echo '$(srcdir)/'`userfaultfd.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-userfaultfd.Tpo $(DEPDIR)/libstrace_a-userfaultfd.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='userfaultfd.c' object='libstrace_a-userfaultfd.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ubi.o `test -f 'ubi.c' || echo '$(srcdir)/'`ubi.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-userfaultfd.o `test -f 'userfaultfd.c' || echo '$(srcdir)/'`userfaultfd.c
 
-strace-ubi.obj: ubi.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ubi.obj -MD -MP -MF $(DEPDIR)/strace-ubi.Tpo -c -o strace-ubi.obj `if test -f 'ubi.c'; then $(CYGPATH_W) 'ubi.c'; else $(CYGPATH_W) '$(srcdir)/ubi.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ubi.Tpo $(DEPDIR)/strace-ubi.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ubi.c' object='strace-ubi.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-userfaultfd.obj: userfaultfd.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-userfaultfd.obj -MD -MP -MF $(DEPDIR)/libstrace_a-userfaultfd.Tpo -c -o libstrace_a-userfaultfd.obj `if test -f 'userfaultfd.c'; then $(CYGPATH_W) 'userfaultfd.c'; else $(CYGPATH_W) '$(srcdir)/userfaultfd.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-userfaultfd.Tpo $(DEPDIR)/libstrace_a-userfaultfd.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='userfaultfd.c' object='libstrace_a-userfaultfd.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ubi.obj `if test -f 'ubi.c'; then $(CYGPATH_W) 'ubi.c'; else $(CYGPATH_W) '$(srcdir)/ubi.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-userfaultfd.obj `if test -f 'userfaultfd.c'; then $(CYGPATH_W) 'userfaultfd.c'; else $(CYGPATH_W) '$(srcdir)/userfaultfd.c'; fi`
 
-strace-ucopy.o: ucopy.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ucopy.o -MD -MP -MF $(DEPDIR)/strace-ucopy.Tpo -c -o strace-ucopy.o `test -f 'ucopy.c' || echo '$(srcdir)/'`ucopy.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ucopy.Tpo $(DEPDIR)/strace-ucopy.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ucopy.c' object='strace-ucopy.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ustat.o: ustat.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ustat.o -MD -MP -MF $(DEPDIR)/libstrace_a-ustat.Tpo -c -o libstrace_a-ustat.o `test -f 'ustat.c' || echo '$(srcdir)/'`ustat.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ustat.Tpo $(DEPDIR)/libstrace_a-ustat.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ustat.c' object='libstrace_a-ustat.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ucopy.o `test -f 'ucopy.c' || echo '$(srcdir)/'`ucopy.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ustat.o `test -f 'ustat.c' || echo '$(srcdir)/'`ustat.c
 
-strace-ucopy.obj: ucopy.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ucopy.obj -MD -MP -MF $(DEPDIR)/strace-ucopy.Tpo -c -o strace-ucopy.obj `if test -f 'ucopy.c'; then $(CYGPATH_W) 'ucopy.c'; else $(CYGPATH_W) '$(srcdir)/ucopy.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ucopy.Tpo $(DEPDIR)/strace-ucopy.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ucopy.c' object='strace-ucopy.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-ustat.obj: ustat.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-ustat.obj -MD -MP -MF $(DEPDIR)/libstrace_a-ustat.Tpo -c -o libstrace_a-ustat.obj `if test -f 'ustat.c'; then $(CYGPATH_W) 'ustat.c'; else $(CYGPATH_W) '$(srcdir)/ustat.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-ustat.Tpo $(DEPDIR)/libstrace_a-ustat.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ustat.c' object='libstrace_a-ustat.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ucopy.obj `if test -f 'ucopy.c'; then $(CYGPATH_W) 'ucopy.c'; else $(CYGPATH_W) '$(srcdir)/ucopy.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-ustat.obj `if test -f 'ustat.c'; then $(CYGPATH_W) 'ustat.c'; else $(CYGPATH_W) '$(srcdir)/ustat.c'; fi`
 
-strace-uid.o: uid.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-uid.o -MD -MP -MF $(DEPDIR)/strace-uid.Tpo -c -o strace-uid.o `test -f 'uid.c' || echo '$(srcdir)/'`uid.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-uid.Tpo $(DEPDIR)/strace-uid.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='uid.c' object='strace-uid.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-util.o: util.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-util.o -MD -MP -MF $(DEPDIR)/libstrace_a-util.Tpo -c -o libstrace_a-util.o `test -f 'util.c' || echo '$(srcdir)/'`util.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-util.Tpo $(DEPDIR)/libstrace_a-util.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='util.c' object='libstrace_a-util.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-uid.o `test -f 'uid.c' || echo '$(srcdir)/'`uid.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-util.o `test -f 'util.c' || echo '$(srcdir)/'`util.c
 
-strace-uid.obj: uid.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-uid.obj -MD -MP -MF $(DEPDIR)/strace-uid.Tpo -c -o strace-uid.obj `if test -f 'uid.c'; then $(CYGPATH_W) 'uid.c'; else $(CYGPATH_W) '$(srcdir)/uid.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-uid.Tpo $(DEPDIR)/strace-uid.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='uid.c' object='strace-uid.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-util.obj: util.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-util.obj -MD -MP -MF $(DEPDIR)/libstrace_a-util.Tpo -c -o libstrace_a-util.obj `if test -f 'util.c'; then $(CYGPATH_W) 'util.c'; else $(CYGPATH_W) '$(srcdir)/util.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-util.Tpo $(DEPDIR)/libstrace_a-util.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='util.c' object='libstrace_a-util.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-uid.obj `if test -f 'uid.c'; then $(CYGPATH_W) 'uid.c'; else $(CYGPATH_W) '$(srcdir)/uid.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-util.obj `if test -f 'util.c'; then $(CYGPATH_W) 'util.c'; else $(CYGPATH_W) '$(srcdir)/util.c'; fi`
 
-strace-uid16.o: uid16.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-uid16.o -MD -MP -MF $(DEPDIR)/strace-uid16.Tpo -c -o strace-uid16.o `test -f 'uid16.c' || echo '$(srcdir)/'`uid16.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-uid16.Tpo $(DEPDIR)/strace-uid16.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='uid16.c' object='strace-uid16.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-utime.o: utime.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-utime.o -MD -MP -MF $(DEPDIR)/libstrace_a-utime.Tpo -c -o libstrace_a-utime.o `test -f 'utime.c' || echo '$(srcdir)/'`utime.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-utime.Tpo $(DEPDIR)/libstrace_a-utime.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='utime.c' object='libstrace_a-utime.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-uid16.o `test -f 'uid16.c' || echo '$(srcdir)/'`uid16.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-utime.o `test -f 'utime.c' || echo '$(srcdir)/'`utime.c
 
-strace-uid16.obj: uid16.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-uid16.obj -MD -MP -MF $(DEPDIR)/strace-uid16.Tpo -c -o strace-uid16.obj `if test -f 'uid16.c'; then $(CYGPATH_W) 'uid16.c'; else $(CYGPATH_W) '$(srcdir)/uid16.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-uid16.Tpo $(DEPDIR)/strace-uid16.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='uid16.c' object='strace-uid16.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-utime.obj: utime.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-utime.obj -MD -MP -MF $(DEPDIR)/libstrace_a-utime.Tpo -c -o libstrace_a-utime.obj `if test -f 'utime.c'; then $(CYGPATH_W) 'utime.c'; else $(CYGPATH_W) '$(srcdir)/utime.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-utime.Tpo $(DEPDIR)/libstrace_a-utime.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='utime.c' object='libstrace_a-utime.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-uid16.obj `if test -f 'uid16.c'; then $(CYGPATH_W) 'uid16.c'; else $(CYGPATH_W) '$(srcdir)/uid16.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-utime.obj `if test -f 'utime.c'; then $(CYGPATH_W) 'utime.c'; else $(CYGPATH_W) '$(srcdir)/utime.c'; fi`
 
-strace-umask.o: umask.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-umask.o -MD -MP -MF $(DEPDIR)/strace-umask.Tpo -c -o strace-umask.o `test -f 'umask.c' || echo '$(srcdir)/'`umask.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-umask.Tpo $(DEPDIR)/strace-umask.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='umask.c' object='strace-umask.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-utimes.o: utimes.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-utimes.o -MD -MP -MF $(DEPDIR)/libstrace_a-utimes.Tpo -c -o libstrace_a-utimes.o `test -f 'utimes.c' || echo '$(srcdir)/'`utimes.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-utimes.Tpo $(DEPDIR)/libstrace_a-utimes.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='utimes.c' object='libstrace_a-utimes.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-umask.o `test -f 'umask.c' || echo '$(srcdir)/'`umask.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-utimes.o `test -f 'utimes.c' || echo '$(srcdir)/'`utimes.c
 
-strace-umask.obj: umask.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-umask.obj -MD -MP -MF $(DEPDIR)/strace-umask.Tpo -c -o strace-umask.obj `if test -f 'umask.c'; then $(CYGPATH_W) 'umask.c'; else $(CYGPATH_W) '$(srcdir)/umask.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-umask.Tpo $(DEPDIR)/strace-umask.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='umask.c' object='strace-umask.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-utimes.obj: utimes.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-utimes.obj -MD -MP -MF $(DEPDIR)/libstrace_a-utimes.Tpo -c -o libstrace_a-utimes.obj `if test -f 'utimes.c'; then $(CYGPATH_W) 'utimes.c'; else $(CYGPATH_W) '$(srcdir)/utimes.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-utimes.Tpo $(DEPDIR)/libstrace_a-utimes.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='utimes.c' object='libstrace_a-utimes.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-umask.obj `if test -f 'umask.c'; then $(CYGPATH_W) 'umask.c'; else $(CYGPATH_W) '$(srcdir)/umask.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-utimes.obj `if test -f 'utimes.c'; then $(CYGPATH_W) 'utimes.c'; else $(CYGPATH_W) '$(srcdir)/utimes.c'; fi`
 
-strace-umount.o: umount.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-umount.o -MD -MP -MF $(DEPDIR)/strace-umount.Tpo -c -o strace-umount.o `test -f 'umount.c' || echo '$(srcdir)/'`umount.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-umount.Tpo $(DEPDIR)/strace-umount.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='umount.c' object='strace-umount.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-v4l2.o: v4l2.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-v4l2.o -MD -MP -MF $(DEPDIR)/libstrace_a-v4l2.Tpo -c -o libstrace_a-v4l2.o `test -f 'v4l2.c' || echo '$(srcdir)/'`v4l2.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-v4l2.Tpo $(DEPDIR)/libstrace_a-v4l2.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='v4l2.c' object='libstrace_a-v4l2.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-umount.o `test -f 'umount.c' || echo '$(srcdir)/'`umount.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-v4l2.o `test -f 'v4l2.c' || echo '$(srcdir)/'`v4l2.c
 
-strace-umount.obj: umount.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-umount.obj -MD -MP -MF $(DEPDIR)/strace-umount.Tpo -c -o strace-umount.obj `if test -f 'umount.c'; then $(CYGPATH_W) 'umount.c'; else $(CYGPATH_W) '$(srcdir)/umount.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-umount.Tpo $(DEPDIR)/strace-umount.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='umount.c' object='strace-umount.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-v4l2.obj: v4l2.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-v4l2.obj -MD -MP -MF $(DEPDIR)/libstrace_a-v4l2.Tpo -c -o libstrace_a-v4l2.obj `if test -f 'v4l2.c'; then $(CYGPATH_W) 'v4l2.c'; else $(CYGPATH_W) '$(srcdir)/v4l2.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-v4l2.Tpo $(DEPDIR)/libstrace_a-v4l2.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='v4l2.c' object='libstrace_a-v4l2.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-umount.obj `if test -f 'umount.c'; then $(CYGPATH_W) 'umount.c'; else $(CYGPATH_W) '$(srcdir)/umount.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-v4l2.obj `if test -f 'v4l2.c'; then $(CYGPATH_W) 'v4l2.c'; else $(CYGPATH_W) '$(srcdir)/v4l2.c'; fi`
 
-strace-uname.o: uname.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-uname.o -MD -MP -MF $(DEPDIR)/strace-uname.Tpo -c -o strace-uname.o `test -f 'uname.c' || echo '$(srcdir)/'`uname.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-uname.Tpo $(DEPDIR)/strace-uname.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='uname.c' object='strace-uname.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-wait.o: wait.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-wait.o -MD -MP -MF $(DEPDIR)/libstrace_a-wait.Tpo -c -o libstrace_a-wait.o `test -f 'wait.c' || echo '$(srcdir)/'`wait.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-wait.Tpo $(DEPDIR)/libstrace_a-wait.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='wait.c' object='libstrace_a-wait.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-uname.o `test -f 'uname.c' || echo '$(srcdir)/'`uname.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-wait.o `test -f 'wait.c' || echo '$(srcdir)/'`wait.c
 
-strace-uname.obj: uname.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-uname.obj -MD -MP -MF $(DEPDIR)/strace-uname.Tpo -c -o strace-uname.obj `if test -f 'uname.c'; then $(CYGPATH_W) 'uname.c'; else $(CYGPATH_W) '$(srcdir)/uname.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-uname.Tpo $(DEPDIR)/strace-uname.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='uname.c' object='strace-uname.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-wait.obj: wait.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-wait.obj -MD -MP -MF $(DEPDIR)/libstrace_a-wait.Tpo -c -o libstrace_a-wait.obj `if test -f 'wait.c'; then $(CYGPATH_W) 'wait.c'; else $(CYGPATH_W) '$(srcdir)/wait.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-wait.Tpo $(DEPDIR)/libstrace_a-wait.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='wait.c' object='libstrace_a-wait.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-uname.obj `if test -f 'uname.c'; then $(CYGPATH_W) 'uname.c'; else $(CYGPATH_W) '$(srcdir)/uname.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-wait.obj `if test -f 'wait.c'; then $(CYGPATH_W) 'wait.c'; else $(CYGPATH_W) '$(srcdir)/wait.c'; fi`
 
-strace-userfaultfd.o: userfaultfd.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-userfaultfd.o -MD -MP -MF $(DEPDIR)/strace-userfaultfd.Tpo -c -o strace-userfaultfd.o `test -f 'userfaultfd.c' || echo '$(srcdir)/'`userfaultfd.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-userfaultfd.Tpo $(DEPDIR)/strace-userfaultfd.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='userfaultfd.c' object='strace-userfaultfd.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-watchdog_ioctl.o: watchdog_ioctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-watchdog_ioctl.o -MD -MP -MF $(DEPDIR)/libstrace_a-watchdog_ioctl.Tpo -c -o libstrace_a-watchdog_ioctl.o `test -f 'watchdog_ioctl.c' || echo '$(srcdir)/'`watchdog_ioctl.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-watchdog_ioctl.Tpo $(DEPDIR)/libstrace_a-watchdog_ioctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='watchdog_ioctl.c' object='libstrace_a-watchdog_ioctl.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-userfaultfd.o `test -f 'userfaultfd.c' || echo '$(srcdir)/'`userfaultfd.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-watchdog_ioctl.o `test -f 'watchdog_ioctl.c' || echo '$(srcdir)/'`watchdog_ioctl.c
 
-strace-userfaultfd.obj: userfaultfd.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-userfaultfd.obj -MD -MP -MF $(DEPDIR)/strace-userfaultfd.Tpo -c -o strace-userfaultfd.obj `if test -f 'userfaultfd.c'; then $(CYGPATH_W) 'userfaultfd.c'; else $(CYGPATH_W) '$(srcdir)/userfaultfd.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-userfaultfd.Tpo $(DEPDIR)/strace-userfaultfd.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='userfaultfd.c' object='strace-userfaultfd.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-watchdog_ioctl.obj: watchdog_ioctl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-watchdog_ioctl.obj -MD -MP -MF $(DEPDIR)/libstrace_a-watchdog_ioctl.Tpo -c -o libstrace_a-watchdog_ioctl.obj `if test -f 'watchdog_ioctl.c'; then $(CYGPATH_W) 'watchdog_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/watchdog_ioctl.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-watchdog_ioctl.Tpo $(DEPDIR)/libstrace_a-watchdog_ioctl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='watchdog_ioctl.c' object='libstrace_a-watchdog_ioctl.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-userfaultfd.obj `if test -f 'userfaultfd.c'; then $(CYGPATH_W) 'userfaultfd.c'; else $(CYGPATH_W) '$(srcdir)/userfaultfd.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-watchdog_ioctl.obj `if test -f 'watchdog_ioctl.c'; then $(CYGPATH_W) 'watchdog_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/watchdog_ioctl.c'; fi`
 
-strace-ustat.o: ustat.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ustat.o -MD -MP -MF $(DEPDIR)/strace-ustat.Tpo -c -o strace-ustat.o `test -f 'ustat.c' || echo '$(srcdir)/'`ustat.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ustat.Tpo $(DEPDIR)/strace-ustat.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ustat.c' object='strace-ustat.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-xattr.o: xattr.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-xattr.o -MD -MP -MF $(DEPDIR)/libstrace_a-xattr.Tpo -c -o libstrace_a-xattr.o `test -f 'xattr.c' || echo '$(srcdir)/'`xattr.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-xattr.Tpo $(DEPDIR)/libstrace_a-xattr.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='xattr.c' object='libstrace_a-xattr.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ustat.o `test -f 'ustat.c' || echo '$(srcdir)/'`ustat.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-xattr.o `test -f 'xattr.c' || echo '$(srcdir)/'`xattr.c
 
-strace-ustat.obj: ustat.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-ustat.obj -MD -MP -MF $(DEPDIR)/strace-ustat.Tpo -c -o strace-ustat.obj `if test -f 'ustat.c'; then $(CYGPATH_W) 'ustat.c'; else $(CYGPATH_W) '$(srcdir)/ustat.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-ustat.Tpo $(DEPDIR)/strace-ustat.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='ustat.c' object='strace-ustat.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-xattr.obj: xattr.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-xattr.obj -MD -MP -MF $(DEPDIR)/libstrace_a-xattr.Tpo -c -o libstrace_a-xattr.obj `if test -f 'xattr.c'; then $(CYGPATH_W) 'xattr.c'; else $(CYGPATH_W) '$(srcdir)/xattr.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-xattr.Tpo $(DEPDIR)/libstrace_a-xattr.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='xattr.c' object='libstrace_a-xattr.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-ustat.obj `if test -f 'ustat.c'; then $(CYGPATH_W) 'ustat.c'; else $(CYGPATH_W) '$(srcdir)/ustat.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-xattr.obj `if test -f 'xattr.c'; then $(CYGPATH_W) 'xattr.c'; else $(CYGPATH_W) '$(srcdir)/xattr.c'; fi`
 
-strace-util.o: util.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-util.o -MD -MP -MF $(DEPDIR)/strace-util.Tpo -c -o strace-util.o `test -f 'util.c' || echo '$(srcdir)/'`util.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-util.Tpo $(DEPDIR)/strace-util.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='util.c' object='strace-util.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-xgetdents.o: xgetdents.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-xgetdents.o -MD -MP -MF $(DEPDIR)/libstrace_a-xgetdents.Tpo -c -o libstrace_a-xgetdents.o `test -f 'xgetdents.c' || echo '$(srcdir)/'`xgetdents.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-xgetdents.Tpo $(DEPDIR)/libstrace_a-xgetdents.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='xgetdents.c' object='libstrace_a-xgetdents.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-util.o `test -f 'util.c' || echo '$(srcdir)/'`util.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-xgetdents.o `test -f 'xgetdents.c' || echo '$(srcdir)/'`xgetdents.c
 
-strace-util.obj: util.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-util.obj -MD -MP -MF $(DEPDIR)/strace-util.Tpo -c -o strace-util.obj `if test -f 'util.c'; then $(CYGPATH_W) 'util.c'; else $(CYGPATH_W) '$(srcdir)/util.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-util.Tpo $(DEPDIR)/strace-util.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='util.c' object='strace-util.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-xgetdents.obj: xgetdents.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-xgetdents.obj -MD -MP -MF $(DEPDIR)/libstrace_a-xgetdents.Tpo -c -o libstrace_a-xgetdents.obj `if test -f 'xgetdents.c'; then $(CYGPATH_W) 'xgetdents.c'; else $(CYGPATH_W) '$(srcdir)/xgetdents.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-xgetdents.Tpo $(DEPDIR)/libstrace_a-xgetdents.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='xgetdents.c' object='libstrace_a-xgetdents.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-util.obj `if test -f 'util.c'; then $(CYGPATH_W) 'util.c'; else $(CYGPATH_W) '$(srcdir)/util.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-xgetdents.obj `if test -f 'xgetdents.c'; then $(CYGPATH_W) 'xgetdents.c'; else $(CYGPATH_W) '$(srcdir)/xgetdents.c'; fi`
 
-strace-utime.o: utime.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-utime.o -MD -MP -MF $(DEPDIR)/strace-utime.Tpo -c -o strace-utime.o `test -f 'utime.c' || echo '$(srcdir)/'`utime.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-utime.Tpo $(DEPDIR)/strace-utime.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='utime.c' object='strace-utime.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-xlat.o: xlat.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-xlat.o -MD -MP -MF $(DEPDIR)/libstrace_a-xlat.Tpo -c -o libstrace_a-xlat.o `test -f 'xlat.c' || echo '$(srcdir)/'`xlat.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-xlat.Tpo $(DEPDIR)/libstrace_a-xlat.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='xlat.c' object='libstrace_a-xlat.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-utime.o `test -f 'utime.c' || echo '$(srcdir)/'`utime.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-xlat.o `test -f 'xlat.c' || echo '$(srcdir)/'`xlat.c
 
-strace-utime.obj: utime.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-utime.obj -MD -MP -MF $(DEPDIR)/strace-utime.Tpo -c -o strace-utime.obj `if test -f 'utime.c'; then $(CYGPATH_W) 'utime.c'; else $(CYGPATH_W) '$(srcdir)/utime.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-utime.Tpo $(DEPDIR)/strace-utime.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='utime.c' object='strace-utime.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-xlat.obj: xlat.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-xlat.obj -MD -MP -MF $(DEPDIR)/libstrace_a-xlat.Tpo -c -o libstrace_a-xlat.obj `if test -f 'xlat.c'; then $(CYGPATH_W) 'xlat.c'; else $(CYGPATH_W) '$(srcdir)/xlat.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-xlat.Tpo $(DEPDIR)/libstrace_a-xlat.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='xlat.c' object='libstrace_a-xlat.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-utime.obj `if test -f 'utime.c'; then $(CYGPATH_W) 'utime.c'; else $(CYGPATH_W) '$(srcdir)/utime.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-xlat.obj `if test -f 'xlat.c'; then $(CYGPATH_W) 'xlat.c'; else $(CYGPATH_W) '$(srcdir)/xlat.c'; fi`
 
-strace-utimes.o: utimes.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-utimes.o -MD -MP -MF $(DEPDIR)/strace-utimes.Tpo -c -o strace-utimes.o `test -f 'utimes.c' || echo '$(srcdir)/'`utimes.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-utimes.Tpo $(DEPDIR)/strace-utimes.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='utimes.c' object='strace-utimes.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-xmalloc.o: xmalloc.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-xmalloc.o -MD -MP -MF $(DEPDIR)/libstrace_a-xmalloc.Tpo -c -o libstrace_a-xmalloc.o `test -f 'xmalloc.c' || echo '$(srcdir)/'`xmalloc.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-xmalloc.Tpo $(DEPDIR)/libstrace_a-xmalloc.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='xmalloc.c' object='libstrace_a-xmalloc.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-utimes.o `test -f 'utimes.c' || echo '$(srcdir)/'`utimes.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-xmalloc.o `test -f 'xmalloc.c' || echo '$(srcdir)/'`xmalloc.c
 
-strace-utimes.obj: utimes.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-utimes.obj -MD -MP -MF $(DEPDIR)/strace-utimes.Tpo -c -o strace-utimes.obj `if test -f 'utimes.c'; then $(CYGPATH_W) 'utimes.c'; else $(CYGPATH_W) '$(srcdir)/utimes.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-utimes.Tpo $(DEPDIR)/strace-utimes.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='utimes.c' object='strace-utimes.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-xmalloc.obj: xmalloc.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-xmalloc.obj -MD -MP -MF $(DEPDIR)/libstrace_a-xmalloc.Tpo -c -o libstrace_a-xmalloc.obj `if test -f 'xmalloc.c'; then $(CYGPATH_W) 'xmalloc.c'; else $(CYGPATH_W) '$(srcdir)/xmalloc.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-xmalloc.Tpo $(DEPDIR)/libstrace_a-xmalloc.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='xmalloc.c' object='libstrace_a-xmalloc.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-utimes.obj `if test -f 'utimes.c'; then $(CYGPATH_W) 'utimes.c'; else $(CYGPATH_W) '$(srcdir)/utimes.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-xmalloc.obj `if test -f 'xmalloc.c'; then $(CYGPATH_W) 'xmalloc.c'; else $(CYGPATH_W) '$(srcdir)/xmalloc.c'; fi`
 
-strace-v4l2.o: v4l2.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-v4l2.o -MD -MP -MF $(DEPDIR)/strace-v4l2.Tpo -c -o strace-v4l2.o `test -f 'v4l2.c' || echo '$(srcdir)/'`v4l2.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-v4l2.Tpo $(DEPDIR)/strace-v4l2.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='v4l2.c' object='strace-v4l2.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-bpf_attr_check.o: bpf_attr_check.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-bpf_attr_check.o -MD -MP -MF $(DEPDIR)/libstrace_a-bpf_attr_check.Tpo -c -o libstrace_a-bpf_attr_check.o `test -f 'bpf_attr_check.c' || echo '$(srcdir)/'`bpf_attr_check.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-bpf_attr_check.Tpo $(DEPDIR)/libstrace_a-bpf_attr_check.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bpf_attr_check.c' object='libstrace_a-bpf_attr_check.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-v4l2.o `test -f 'v4l2.c' || echo '$(srcdir)/'`v4l2.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-bpf_attr_check.o `test -f 'bpf_attr_check.c' || echo '$(srcdir)/'`bpf_attr_check.c
 
-strace-v4l2.obj: v4l2.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-v4l2.obj -MD -MP -MF $(DEPDIR)/strace-v4l2.Tpo -c -o strace-v4l2.obj `if test -f 'v4l2.c'; then $(CYGPATH_W) 'v4l2.c'; else $(CYGPATH_W) '$(srcdir)/v4l2.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-v4l2.Tpo $(DEPDIR)/strace-v4l2.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='v4l2.c' object='strace-v4l2.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-bpf_attr_check.obj: bpf_attr_check.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-bpf_attr_check.obj -MD -MP -MF $(DEPDIR)/libstrace_a-bpf_attr_check.Tpo -c -o libstrace_a-bpf_attr_check.obj `if test -f 'bpf_attr_check.c'; then $(CYGPATH_W) 'bpf_attr_check.c'; else $(CYGPATH_W) '$(srcdir)/bpf_attr_check.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-bpf_attr_check.Tpo $(DEPDIR)/libstrace_a-bpf_attr_check.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bpf_attr_check.c' object='libstrace_a-bpf_attr_check.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-v4l2.obj `if test -f 'v4l2.c'; then $(CYGPATH_W) 'v4l2.c'; else $(CYGPATH_W) '$(srcdir)/v4l2.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-bpf_attr_check.obj `if test -f 'bpf_attr_check.c'; then $(CYGPATH_W) 'bpf_attr_check.c'; else $(CYGPATH_W) '$(srcdir)/bpf_attr_check.c'; fi`
 
-strace-wait.o: wait.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-wait.o -MD -MP -MF $(DEPDIR)/strace-wait.Tpo -c -o strace-wait.o `test -f 'wait.c' || echo '$(srcdir)/'`wait.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-wait.Tpo $(DEPDIR)/strace-wait.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='wait.c' object='strace-wait.o' libtool=no @AMDEPBACKSLASH@
+types/libstrace_a-check-btrfs.o: types/check-btrfs.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT types/libstrace_a-check-btrfs.o -MD -MP -MF types/$(DEPDIR)/libstrace_a-check-btrfs.Tpo -c -o types/libstrace_a-check-btrfs.o `test -f 'types/check-btrfs.c' || echo '$(srcdir)/'`types/check-btrfs.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/libstrace_a-check-btrfs.Tpo types/$(DEPDIR)/libstrace_a-check-btrfs.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-btrfs.c' object='types/libstrace_a-check-btrfs.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-wait.o `test -f 'wait.c' || echo '$(srcdir)/'`wait.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o types/libstrace_a-check-btrfs.o `test -f 'types/check-btrfs.c' || echo '$(srcdir)/'`types/check-btrfs.c
 
-strace-wait.obj: wait.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-wait.obj -MD -MP -MF $(DEPDIR)/strace-wait.Tpo -c -o strace-wait.obj `if test -f 'wait.c'; then $(CYGPATH_W) 'wait.c'; else $(CYGPATH_W) '$(srcdir)/wait.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-wait.Tpo $(DEPDIR)/strace-wait.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='wait.c' object='strace-wait.obj' libtool=no @AMDEPBACKSLASH@
+types/libstrace_a-check-btrfs.obj: types/check-btrfs.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT types/libstrace_a-check-btrfs.obj -MD -MP -MF types/$(DEPDIR)/libstrace_a-check-btrfs.Tpo -c -o types/libstrace_a-check-btrfs.obj `if test -f 'types/check-btrfs.c'; then $(CYGPATH_W) 'types/check-btrfs.c'; else $(CYGPATH_W) '$(srcdir)/types/check-btrfs.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/libstrace_a-check-btrfs.Tpo types/$(DEPDIR)/libstrace_a-check-btrfs.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-btrfs.c' object='types/libstrace_a-check-btrfs.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-wait.obj `if test -f 'wait.c'; then $(CYGPATH_W) 'wait.c'; else $(CYGPATH_W) '$(srcdir)/wait.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o types/libstrace_a-check-btrfs.obj `if test -f 'types/check-btrfs.c'; then $(CYGPATH_W) 'types/check-btrfs.c'; else $(CYGPATH_W) '$(srcdir)/types/check-btrfs.c'; fi`
 
-strace-watchdog_ioctl.o: watchdog_ioctl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-watchdog_ioctl.o -MD -MP -MF $(DEPDIR)/strace-watchdog_ioctl.Tpo -c -o strace-watchdog_ioctl.o `test -f 'watchdog_ioctl.c' || echo '$(srcdir)/'`watchdog_ioctl.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-watchdog_ioctl.Tpo $(DEPDIR)/strace-watchdog_ioctl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='watchdog_ioctl.c' object='strace-watchdog_ioctl.o' libtool=no @AMDEPBACKSLASH@
+types/libstrace_a-check-cryptouser.o: types/check-cryptouser.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT types/libstrace_a-check-cryptouser.o -MD -MP -MF types/$(DEPDIR)/libstrace_a-check-cryptouser.Tpo -c -o types/libstrace_a-check-cryptouser.o `test -f 'types/check-cryptouser.c' || echo '$(srcdir)/'`types/check-cryptouser.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/libstrace_a-check-cryptouser.Tpo types/$(DEPDIR)/libstrace_a-check-cryptouser.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-cryptouser.c' object='types/libstrace_a-check-cryptouser.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-watchdog_ioctl.o `test -f 'watchdog_ioctl.c' || echo '$(srcdir)/'`watchdog_ioctl.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o types/libstrace_a-check-cryptouser.o `test -f 'types/check-cryptouser.c' || echo '$(srcdir)/'`types/check-cryptouser.c
 
-strace-watchdog_ioctl.obj: watchdog_ioctl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-watchdog_ioctl.obj -MD -MP -MF $(DEPDIR)/strace-watchdog_ioctl.Tpo -c -o strace-watchdog_ioctl.obj `if test -f 'watchdog_ioctl.c'; then $(CYGPATH_W) 'watchdog_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/watchdog_ioctl.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-watchdog_ioctl.Tpo $(DEPDIR)/strace-watchdog_ioctl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='watchdog_ioctl.c' object='strace-watchdog_ioctl.obj' libtool=no @AMDEPBACKSLASH@
+types/libstrace_a-check-cryptouser.obj: types/check-cryptouser.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT types/libstrace_a-check-cryptouser.obj -MD -MP -MF types/$(DEPDIR)/libstrace_a-check-cryptouser.Tpo -c -o types/libstrace_a-check-cryptouser.obj `if test -f 'types/check-cryptouser.c'; then $(CYGPATH_W) 'types/check-cryptouser.c'; else $(CYGPATH_W) '$(srcdir)/types/check-cryptouser.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/libstrace_a-check-cryptouser.Tpo types/$(DEPDIR)/libstrace_a-check-cryptouser.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-cryptouser.c' object='types/libstrace_a-check-cryptouser.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-watchdog_ioctl.obj `if test -f 'watchdog_ioctl.c'; then $(CYGPATH_W) 'watchdog_ioctl.c'; else $(CYGPATH_W) '$(srcdir)/watchdog_ioctl.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o types/libstrace_a-check-cryptouser.obj `if test -f 'types/check-cryptouser.c'; then $(CYGPATH_W) 'types/check-cryptouser.c'; else $(CYGPATH_W) '$(srcdir)/types/check-cryptouser.c'; fi`
 
-strace-xattr.o: xattr.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-xattr.o -MD -MP -MF $(DEPDIR)/strace-xattr.Tpo -c -o strace-xattr.o `test -f 'xattr.c' || echo '$(srcdir)/'`xattr.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-xattr.Tpo $(DEPDIR)/strace-xattr.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='xattr.c' object='strace-xattr.o' libtool=no @AMDEPBACKSLASH@
+types/libstrace_a-check-evdev.o: types/check-evdev.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT types/libstrace_a-check-evdev.o -MD -MP -MF types/$(DEPDIR)/libstrace_a-check-evdev.Tpo -c -o types/libstrace_a-check-evdev.o `test -f 'types/check-evdev.c' || echo '$(srcdir)/'`types/check-evdev.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/libstrace_a-check-evdev.Tpo types/$(DEPDIR)/libstrace_a-check-evdev.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-evdev.c' object='types/libstrace_a-check-evdev.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-xattr.o `test -f 'xattr.c' || echo '$(srcdir)/'`xattr.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o types/libstrace_a-check-evdev.o `test -f 'types/check-evdev.c' || echo '$(srcdir)/'`types/check-evdev.c
 
-strace-xattr.obj: xattr.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-xattr.obj -MD -MP -MF $(DEPDIR)/strace-xattr.Tpo -c -o strace-xattr.obj `if test -f 'xattr.c'; then $(CYGPATH_W) 'xattr.c'; else $(CYGPATH_W) '$(srcdir)/xattr.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-xattr.Tpo $(DEPDIR)/strace-xattr.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='xattr.c' object='strace-xattr.obj' libtool=no @AMDEPBACKSLASH@
+types/libstrace_a-check-evdev.obj: types/check-evdev.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT types/libstrace_a-check-evdev.obj -MD -MP -MF types/$(DEPDIR)/libstrace_a-check-evdev.Tpo -c -o types/libstrace_a-check-evdev.obj `if test -f 'types/check-evdev.c'; then $(CYGPATH_W) 'types/check-evdev.c'; else $(CYGPATH_W) '$(srcdir)/types/check-evdev.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/libstrace_a-check-evdev.Tpo types/$(DEPDIR)/libstrace_a-check-evdev.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-evdev.c' object='types/libstrace_a-check-evdev.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-xattr.obj `if test -f 'xattr.c'; then $(CYGPATH_W) 'xattr.c'; else $(CYGPATH_W) '$(srcdir)/xattr.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o types/libstrace_a-check-evdev.obj `if test -f 'types/check-evdev.c'; then $(CYGPATH_W) 'types/check-evdev.c'; else $(CYGPATH_W) '$(srcdir)/types/check-evdev.c'; fi`
 
-strace-xlat.o: xlat.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-xlat.o -MD -MP -MF $(DEPDIR)/strace-xlat.Tpo -c -o strace-xlat.o `test -f 'xlat.c' || echo '$(srcdir)/'`xlat.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-xlat.Tpo $(DEPDIR)/strace-xlat.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='xlat.c' object='strace-xlat.o' libtool=no @AMDEPBACKSLASH@
+types/libstrace_a-check-io_uring.o: types/check-io_uring.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT types/libstrace_a-check-io_uring.o -MD -MP -MF types/$(DEPDIR)/libstrace_a-check-io_uring.Tpo -c -o types/libstrace_a-check-io_uring.o `test -f 'types/check-io_uring.c' || echo '$(srcdir)/'`types/check-io_uring.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/libstrace_a-check-io_uring.Tpo types/$(DEPDIR)/libstrace_a-check-io_uring.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-io_uring.c' object='types/libstrace_a-check-io_uring.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-xlat.o `test -f 'xlat.c' || echo '$(srcdir)/'`xlat.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o types/libstrace_a-check-io_uring.o `test -f 'types/check-io_uring.c' || echo '$(srcdir)/'`types/check-io_uring.c
 
-strace-xlat.obj: xlat.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-xlat.obj -MD -MP -MF $(DEPDIR)/strace-xlat.Tpo -c -o strace-xlat.obj `if test -f 'xlat.c'; then $(CYGPATH_W) 'xlat.c'; else $(CYGPATH_W) '$(srcdir)/xlat.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-xlat.Tpo $(DEPDIR)/strace-xlat.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='xlat.c' object='strace-xlat.obj' libtool=no @AMDEPBACKSLASH@
+types/libstrace_a-check-io_uring.obj: types/check-io_uring.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT types/libstrace_a-check-io_uring.obj -MD -MP -MF types/$(DEPDIR)/libstrace_a-check-io_uring.Tpo -c -o types/libstrace_a-check-io_uring.obj `if test -f 'types/check-io_uring.c'; then $(CYGPATH_W) 'types/check-io_uring.c'; else $(CYGPATH_W) '$(srcdir)/types/check-io_uring.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/libstrace_a-check-io_uring.Tpo types/$(DEPDIR)/libstrace_a-check-io_uring.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-io_uring.c' object='types/libstrace_a-check-io_uring.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-xlat.obj `if test -f 'xlat.c'; then $(CYGPATH_W) 'xlat.c'; else $(CYGPATH_W) '$(srcdir)/xlat.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o types/libstrace_a-check-io_uring.obj `if test -f 'types/check-io_uring.c'; then $(CYGPATH_W) 'types/check-io_uring.c'; else $(CYGPATH_W) '$(srcdir)/types/check-io_uring.c'; fi`
 
-strace-xmalloc.o: xmalloc.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-xmalloc.o -MD -MP -MF $(DEPDIR)/strace-xmalloc.Tpo -c -o strace-xmalloc.o `test -f 'xmalloc.c' || echo '$(srcdir)/'`xmalloc.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-xmalloc.Tpo $(DEPDIR)/strace-xmalloc.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='xmalloc.c' object='strace-xmalloc.o' libtool=no @AMDEPBACKSLASH@
+types/libstrace_a-check-loop.o: types/check-loop.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT types/libstrace_a-check-loop.o -MD -MP -MF types/$(DEPDIR)/libstrace_a-check-loop.Tpo -c -o types/libstrace_a-check-loop.o `test -f 'types/check-loop.c' || echo '$(srcdir)/'`types/check-loop.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/libstrace_a-check-loop.Tpo types/$(DEPDIR)/libstrace_a-check-loop.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-loop.c' object='types/libstrace_a-check-loop.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-xmalloc.o `test -f 'xmalloc.c' || echo '$(srcdir)/'`xmalloc.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o types/libstrace_a-check-loop.o `test -f 'types/check-loop.c' || echo '$(srcdir)/'`types/check-loop.c
 
-strace-xmalloc.obj: xmalloc.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-xmalloc.obj -MD -MP -MF $(DEPDIR)/strace-xmalloc.Tpo -c -o strace-xmalloc.obj `if test -f 'xmalloc.c'; then $(CYGPATH_W) 'xmalloc.c'; else $(CYGPATH_W) '$(srcdir)/xmalloc.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-xmalloc.Tpo $(DEPDIR)/strace-xmalloc.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='xmalloc.c' object='strace-xmalloc.obj' libtool=no @AMDEPBACKSLASH@
+types/libstrace_a-check-loop.obj: types/check-loop.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT types/libstrace_a-check-loop.obj -MD -MP -MF types/$(DEPDIR)/libstrace_a-check-loop.Tpo -c -o types/libstrace_a-check-loop.obj `if test -f 'types/check-loop.c'; then $(CYGPATH_W) 'types/check-loop.c'; else $(CYGPATH_W) '$(srcdir)/types/check-loop.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/libstrace_a-check-loop.Tpo types/$(DEPDIR)/libstrace_a-check-loop.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-loop.c' object='types/libstrace_a-check-loop.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-xmalloc.obj `if test -f 'xmalloc.c'; then $(CYGPATH_W) 'xmalloc.c'; else $(CYGPATH_W) '$(srcdir)/xmalloc.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o types/libstrace_a-check-loop.obj `if test -f 'types/check-loop.c'; then $(CYGPATH_W) 'types/check-loop.c'; else $(CYGPATH_W) '$(srcdir)/types/check-loop.c'; fi`
 
-strace-bpf_attr_check.o: bpf_attr_check.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-bpf_attr_check.o -MD -MP -MF $(DEPDIR)/strace-bpf_attr_check.Tpo -c -o strace-bpf_attr_check.o `test -f 'bpf_attr_check.c' || echo '$(srcdir)/'`bpf_attr_check.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-bpf_attr_check.Tpo $(DEPDIR)/strace-bpf_attr_check.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bpf_attr_check.c' object='strace-bpf_attr_check.o' libtool=no @AMDEPBACKSLASH@
+types/libstrace_a-check-openat2.o: types/check-openat2.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT types/libstrace_a-check-openat2.o -MD -MP -MF types/$(DEPDIR)/libstrace_a-check-openat2.Tpo -c -o types/libstrace_a-check-openat2.o `test -f 'types/check-openat2.c' || echo '$(srcdir)/'`types/check-openat2.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/libstrace_a-check-openat2.Tpo types/$(DEPDIR)/libstrace_a-check-openat2.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-openat2.c' object='types/libstrace_a-check-openat2.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-bpf_attr_check.o `test -f 'bpf_attr_check.c' || echo '$(srcdir)/'`bpf_attr_check.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o types/libstrace_a-check-openat2.o `test -f 'types/check-openat2.c' || echo '$(srcdir)/'`types/check-openat2.c
 
-strace-bpf_attr_check.obj: bpf_attr_check.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-bpf_attr_check.obj -MD -MP -MF $(DEPDIR)/strace-bpf_attr_check.Tpo -c -o strace-bpf_attr_check.obj `if test -f 'bpf_attr_check.c'; then $(CYGPATH_W) 'bpf_attr_check.c'; else $(CYGPATH_W) '$(srcdir)/bpf_attr_check.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-bpf_attr_check.Tpo $(DEPDIR)/strace-bpf_attr_check.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='bpf_attr_check.c' object='strace-bpf_attr_check.obj' libtool=no @AMDEPBACKSLASH@
+types/libstrace_a-check-openat2.obj: types/check-openat2.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT types/libstrace_a-check-openat2.obj -MD -MP -MF types/$(DEPDIR)/libstrace_a-check-openat2.Tpo -c -o types/libstrace_a-check-openat2.obj `if test -f 'types/check-openat2.c'; then $(CYGPATH_W) 'types/check-openat2.c'; else $(CYGPATH_W) '$(srcdir)/types/check-openat2.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/libstrace_a-check-openat2.Tpo types/$(DEPDIR)/libstrace_a-check-openat2.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-openat2.c' object='types/libstrace_a-check-openat2.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-bpf_attr_check.obj `if test -f 'bpf_attr_check.c'; then $(CYGPATH_W) 'bpf_attr_check.c'; else $(CYGPATH_W) '$(srcdir)/bpf_attr_check.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o types/libstrace_a-check-openat2.obj `if test -f 'types/check-openat2.c'; then $(CYGPATH_W) 'types/check-openat2.c'; else $(CYGPATH_W) '$(srcdir)/types/check-openat2.c'; fi`
 
-types/strace-check-cryptouser.o: types/check-cryptouser.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT types/strace-check-cryptouser.o -MD -MP -MF types/$(DEPDIR)/strace-check-cryptouser.Tpo -c -o types/strace-check-cryptouser.o `test -f 'types/check-cryptouser.c' || echo '$(srcdir)/'`types/check-cryptouser.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/strace-check-cryptouser.Tpo types/$(DEPDIR)/strace-check-cryptouser.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-cryptouser.c' object='types/strace-check-cryptouser.o' libtool=no @AMDEPBACKSLASH@
+types/libstrace_a-check-rtnl_link.o: types/check-rtnl_link.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT types/libstrace_a-check-rtnl_link.o -MD -MP -MF types/$(DEPDIR)/libstrace_a-check-rtnl_link.Tpo -c -o types/libstrace_a-check-rtnl_link.o `test -f 'types/check-rtnl_link.c' || echo '$(srcdir)/'`types/check-rtnl_link.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/libstrace_a-check-rtnl_link.Tpo types/$(DEPDIR)/libstrace_a-check-rtnl_link.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-rtnl_link.c' object='types/libstrace_a-check-rtnl_link.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o types/strace-check-cryptouser.o `test -f 'types/check-cryptouser.c' || echo '$(srcdir)/'`types/check-cryptouser.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o types/libstrace_a-check-rtnl_link.o `test -f 'types/check-rtnl_link.c' || echo '$(srcdir)/'`types/check-rtnl_link.c
 
-types/strace-check-cryptouser.obj: types/check-cryptouser.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT types/strace-check-cryptouser.obj -MD -MP -MF types/$(DEPDIR)/strace-check-cryptouser.Tpo -c -o types/strace-check-cryptouser.obj `if test -f 'types/check-cryptouser.c'; then $(CYGPATH_W) 'types/check-cryptouser.c'; else $(CYGPATH_W) '$(srcdir)/types/check-cryptouser.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/strace-check-cryptouser.Tpo types/$(DEPDIR)/strace-check-cryptouser.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-cryptouser.c' object='types/strace-check-cryptouser.obj' libtool=no @AMDEPBACKSLASH@
+types/libstrace_a-check-rtnl_link.obj: types/check-rtnl_link.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT types/libstrace_a-check-rtnl_link.obj -MD -MP -MF types/$(DEPDIR)/libstrace_a-check-rtnl_link.Tpo -c -o types/libstrace_a-check-rtnl_link.obj `if test -f 'types/check-rtnl_link.c'; then $(CYGPATH_W) 'types/check-rtnl_link.c'; else $(CYGPATH_W) '$(srcdir)/types/check-rtnl_link.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/libstrace_a-check-rtnl_link.Tpo types/$(DEPDIR)/libstrace_a-check-rtnl_link.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-rtnl_link.c' object='types/libstrace_a-check-rtnl_link.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o types/strace-check-cryptouser.obj `if test -f 'types/check-cryptouser.c'; then $(CYGPATH_W) 'types/check-cryptouser.c'; else $(CYGPATH_W) '$(srcdir)/types/check-cryptouser.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o types/libstrace_a-check-rtnl_link.obj `if test -f 'types/check-rtnl_link.c'; then $(CYGPATH_W) 'types/check-rtnl_link.c'; else $(CYGPATH_W) '$(srcdir)/types/check-rtnl_link.c'; fi`
 
-types/strace-check-evdev.o: types/check-evdev.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT types/strace-check-evdev.o -MD -MP -MF types/$(DEPDIR)/strace-check-evdev.Tpo -c -o types/strace-check-evdev.o `test -f 'types/check-evdev.c' || echo '$(srcdir)/'`types/check-evdev.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/strace-check-evdev.Tpo types/$(DEPDIR)/strace-check-evdev.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-evdev.c' object='types/strace-check-evdev.o' libtool=no @AMDEPBACKSLASH@
+types/libstrace_a-check-rtnl_mdb.o: types/check-rtnl_mdb.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT types/libstrace_a-check-rtnl_mdb.o -MD -MP -MF types/$(DEPDIR)/libstrace_a-check-rtnl_mdb.Tpo -c -o types/libstrace_a-check-rtnl_mdb.o `test -f 'types/check-rtnl_mdb.c' || echo '$(srcdir)/'`types/check-rtnl_mdb.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/libstrace_a-check-rtnl_mdb.Tpo types/$(DEPDIR)/libstrace_a-check-rtnl_mdb.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-rtnl_mdb.c' object='types/libstrace_a-check-rtnl_mdb.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o types/strace-check-evdev.o `test -f 'types/check-evdev.c' || echo '$(srcdir)/'`types/check-evdev.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o types/libstrace_a-check-rtnl_mdb.o `test -f 'types/check-rtnl_mdb.c' || echo '$(srcdir)/'`types/check-rtnl_mdb.c
 
-types/strace-check-evdev.obj: types/check-evdev.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT types/strace-check-evdev.obj -MD -MP -MF types/$(DEPDIR)/strace-check-evdev.Tpo -c -o types/strace-check-evdev.obj `if test -f 'types/check-evdev.c'; then $(CYGPATH_W) 'types/check-evdev.c'; else $(CYGPATH_W) '$(srcdir)/types/check-evdev.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/strace-check-evdev.Tpo types/$(DEPDIR)/strace-check-evdev.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-evdev.c' object='types/strace-check-evdev.obj' libtool=no @AMDEPBACKSLASH@
+types/libstrace_a-check-rtnl_mdb.obj: types/check-rtnl_mdb.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT types/libstrace_a-check-rtnl_mdb.obj -MD -MP -MF types/$(DEPDIR)/libstrace_a-check-rtnl_mdb.Tpo -c -o types/libstrace_a-check-rtnl_mdb.obj `if test -f 'types/check-rtnl_mdb.c'; then $(CYGPATH_W) 'types/check-rtnl_mdb.c'; else $(CYGPATH_W) '$(srcdir)/types/check-rtnl_mdb.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/libstrace_a-check-rtnl_mdb.Tpo types/$(DEPDIR)/libstrace_a-check-rtnl_mdb.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-rtnl_mdb.c' object='types/libstrace_a-check-rtnl_mdb.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o types/strace-check-evdev.obj `if test -f 'types/check-evdev.c'; then $(CYGPATH_W) 'types/check-evdev.c'; else $(CYGPATH_W) '$(srcdir)/types/check-evdev.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o types/libstrace_a-check-rtnl_mdb.obj `if test -f 'types/check-rtnl_mdb.c'; then $(CYGPATH_W) 'types/check-rtnl_mdb.c'; else $(CYGPATH_W) '$(srcdir)/types/check-rtnl_mdb.c'; fi`
 
-types/strace-check-io_uring.o: types/check-io_uring.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT types/strace-check-io_uring.o -MD -MP -MF types/$(DEPDIR)/strace-check-io_uring.Tpo -c -o types/strace-check-io_uring.o `test -f 'types/check-io_uring.c' || echo '$(srcdir)/'`types/check-io_uring.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/strace-check-io_uring.Tpo types/$(DEPDIR)/strace-check-io_uring.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-io_uring.c' object='types/strace-check-io_uring.o' libtool=no @AMDEPBACKSLASH@
+types/libstrace_a-check-rtnl_neightbl.o: types/check-rtnl_neightbl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT types/libstrace_a-check-rtnl_neightbl.o -MD -MP -MF types/$(DEPDIR)/libstrace_a-check-rtnl_neightbl.Tpo -c -o types/libstrace_a-check-rtnl_neightbl.o `test -f 'types/check-rtnl_neightbl.c' || echo '$(srcdir)/'`types/check-rtnl_neightbl.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/libstrace_a-check-rtnl_neightbl.Tpo types/$(DEPDIR)/libstrace_a-check-rtnl_neightbl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-rtnl_neightbl.c' object='types/libstrace_a-check-rtnl_neightbl.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o types/strace-check-io_uring.o `test -f 'types/check-io_uring.c' || echo '$(srcdir)/'`types/check-io_uring.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o types/libstrace_a-check-rtnl_neightbl.o `test -f 'types/check-rtnl_neightbl.c' || echo '$(srcdir)/'`types/check-rtnl_neightbl.c
 
-types/strace-check-io_uring.obj: types/check-io_uring.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT types/strace-check-io_uring.obj -MD -MP -MF types/$(DEPDIR)/strace-check-io_uring.Tpo -c -o types/strace-check-io_uring.obj `if test -f 'types/check-io_uring.c'; then $(CYGPATH_W) 'types/check-io_uring.c'; else $(CYGPATH_W) '$(srcdir)/types/check-io_uring.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/strace-check-io_uring.Tpo types/$(DEPDIR)/strace-check-io_uring.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-io_uring.c' object='types/strace-check-io_uring.obj' libtool=no @AMDEPBACKSLASH@
+types/libstrace_a-check-rtnl_neightbl.obj: types/check-rtnl_neightbl.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT types/libstrace_a-check-rtnl_neightbl.obj -MD -MP -MF types/$(DEPDIR)/libstrace_a-check-rtnl_neightbl.Tpo -c -o types/libstrace_a-check-rtnl_neightbl.obj `if test -f 'types/check-rtnl_neightbl.c'; then $(CYGPATH_W) 'types/check-rtnl_neightbl.c'; else $(CYGPATH_W) '$(srcdir)/types/check-rtnl_neightbl.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/libstrace_a-check-rtnl_neightbl.Tpo types/$(DEPDIR)/libstrace_a-check-rtnl_neightbl.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-rtnl_neightbl.c' object='types/libstrace_a-check-rtnl_neightbl.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o types/strace-check-io_uring.obj `if test -f 'types/check-io_uring.c'; then $(CYGPATH_W) 'types/check-io_uring.c'; else $(CYGPATH_W) '$(srcdir)/types/check-io_uring.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o types/libstrace_a-check-rtnl_neightbl.obj `if test -f 'types/check-rtnl_neightbl.c'; then $(CYGPATH_W) 'types/check-rtnl_neightbl.c'; else $(CYGPATH_W) '$(srcdir)/types/check-rtnl_neightbl.c'; fi`
 
-types/strace-check-rtnl_link.o: types/check-rtnl_link.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT types/strace-check-rtnl_link.o -MD -MP -MF types/$(DEPDIR)/strace-check-rtnl_link.Tpo -c -o types/strace-check-rtnl_link.o `test -f 'types/check-rtnl_link.c' || echo '$(srcdir)/'`types/check-rtnl_link.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/strace-check-rtnl_link.Tpo types/$(DEPDIR)/strace-check-rtnl_link.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-rtnl_link.c' object='types/strace-check-rtnl_link.o' libtool=no @AMDEPBACKSLASH@
+types/libstrace_a-check-rtnl_route.o: types/check-rtnl_route.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT types/libstrace_a-check-rtnl_route.o -MD -MP -MF types/$(DEPDIR)/libstrace_a-check-rtnl_route.Tpo -c -o types/libstrace_a-check-rtnl_route.o `test -f 'types/check-rtnl_route.c' || echo '$(srcdir)/'`types/check-rtnl_route.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/libstrace_a-check-rtnl_route.Tpo types/$(DEPDIR)/libstrace_a-check-rtnl_route.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-rtnl_route.c' object='types/libstrace_a-check-rtnl_route.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o types/strace-check-rtnl_link.o `test -f 'types/check-rtnl_link.c' || echo '$(srcdir)/'`types/check-rtnl_link.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o types/libstrace_a-check-rtnl_route.o `test -f 'types/check-rtnl_route.c' || echo '$(srcdir)/'`types/check-rtnl_route.c
 
-types/strace-check-rtnl_link.obj: types/check-rtnl_link.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT types/strace-check-rtnl_link.obj -MD -MP -MF types/$(DEPDIR)/strace-check-rtnl_link.Tpo -c -o types/strace-check-rtnl_link.obj `if test -f 'types/check-rtnl_link.c'; then $(CYGPATH_W) 'types/check-rtnl_link.c'; else $(CYGPATH_W) '$(srcdir)/types/check-rtnl_link.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/strace-check-rtnl_link.Tpo types/$(DEPDIR)/strace-check-rtnl_link.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-rtnl_link.c' object='types/strace-check-rtnl_link.obj' libtool=no @AMDEPBACKSLASH@
+types/libstrace_a-check-rtnl_route.obj: types/check-rtnl_route.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT types/libstrace_a-check-rtnl_route.obj -MD -MP -MF types/$(DEPDIR)/libstrace_a-check-rtnl_route.Tpo -c -o types/libstrace_a-check-rtnl_route.obj `if test -f 'types/check-rtnl_route.c'; then $(CYGPATH_W) 'types/check-rtnl_route.c'; else $(CYGPATH_W) '$(srcdir)/types/check-rtnl_route.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/libstrace_a-check-rtnl_route.Tpo types/$(DEPDIR)/libstrace_a-check-rtnl_route.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-rtnl_route.c' object='types/libstrace_a-check-rtnl_route.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o types/strace-check-rtnl_link.obj `if test -f 'types/check-rtnl_link.c'; then $(CYGPATH_W) 'types/check-rtnl_link.c'; else $(CYGPATH_W) '$(srcdir)/types/check-rtnl_link.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o types/libstrace_a-check-rtnl_route.obj `if test -f 'types/check-rtnl_route.c'; then $(CYGPATH_W) 'types/check-rtnl_route.c'; else $(CYGPATH_W) '$(srcdir)/types/check-rtnl_route.c'; fi`
 
-types/strace-check-rtnl_mdb.o: types/check-rtnl_mdb.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT types/strace-check-rtnl_mdb.o -MD -MP -MF types/$(DEPDIR)/strace-check-rtnl_mdb.Tpo -c -o types/strace-check-rtnl_mdb.o `test -f 'types/check-rtnl_mdb.c' || echo '$(srcdir)/'`types/check-rtnl_mdb.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/strace-check-rtnl_mdb.Tpo types/$(DEPDIR)/strace-check-rtnl_mdb.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-rtnl_mdb.c' object='types/strace-check-rtnl_mdb.o' libtool=no @AMDEPBACKSLASH@
+types/libstrace_a-check-tee.o: types/check-tee.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT types/libstrace_a-check-tee.o -MD -MP -MF types/$(DEPDIR)/libstrace_a-check-tee.Tpo -c -o types/libstrace_a-check-tee.o `test -f 'types/check-tee.c' || echo '$(srcdir)/'`types/check-tee.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/libstrace_a-check-tee.Tpo types/$(DEPDIR)/libstrace_a-check-tee.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-tee.c' object='types/libstrace_a-check-tee.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o types/strace-check-rtnl_mdb.o `test -f 'types/check-rtnl_mdb.c' || echo '$(srcdir)/'`types/check-rtnl_mdb.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o types/libstrace_a-check-tee.o `test -f 'types/check-tee.c' || echo '$(srcdir)/'`types/check-tee.c
 
-types/strace-check-rtnl_mdb.obj: types/check-rtnl_mdb.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT types/strace-check-rtnl_mdb.obj -MD -MP -MF types/$(DEPDIR)/strace-check-rtnl_mdb.Tpo -c -o types/strace-check-rtnl_mdb.obj `if test -f 'types/check-rtnl_mdb.c'; then $(CYGPATH_W) 'types/check-rtnl_mdb.c'; else $(CYGPATH_W) '$(srcdir)/types/check-rtnl_mdb.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/strace-check-rtnl_mdb.Tpo types/$(DEPDIR)/strace-check-rtnl_mdb.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-rtnl_mdb.c' object='types/strace-check-rtnl_mdb.obj' libtool=no @AMDEPBACKSLASH@
+types/libstrace_a-check-tee.obj: types/check-tee.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT types/libstrace_a-check-tee.obj -MD -MP -MF types/$(DEPDIR)/libstrace_a-check-tee.Tpo -c -o types/libstrace_a-check-tee.obj `if test -f 'types/check-tee.c'; then $(CYGPATH_W) 'types/check-tee.c'; else $(CYGPATH_W) '$(srcdir)/types/check-tee.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/libstrace_a-check-tee.Tpo types/$(DEPDIR)/libstrace_a-check-tee.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-tee.c' object='types/libstrace_a-check-tee.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o types/strace-check-rtnl_mdb.obj `if test -f 'types/check-rtnl_mdb.c'; then $(CYGPATH_W) 'types/check-rtnl_mdb.c'; else $(CYGPATH_W) '$(srcdir)/types/check-rtnl_mdb.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o types/libstrace_a-check-tee.obj `if test -f 'types/check-tee.c'; then $(CYGPATH_W) 'types/check-tee.c'; else $(CYGPATH_W) '$(srcdir)/types/check-tee.c'; fi`
 
-types/strace-check-rtnl_neightbl.o: types/check-rtnl_neightbl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT types/strace-check-rtnl_neightbl.o -MD -MP -MF types/$(DEPDIR)/strace-check-rtnl_neightbl.Tpo -c -o types/strace-check-rtnl_neightbl.o `test -f 'types/check-rtnl_neightbl.c' || echo '$(srcdir)/'`types/check-rtnl_neightbl.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/strace-check-rtnl_neightbl.Tpo types/$(DEPDIR)/strace-check-rtnl_neightbl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-rtnl_neightbl.c' object='types/strace-check-rtnl_neightbl.o' libtool=no @AMDEPBACKSLASH@
+types/libstrace_a-check-v4l2.o: types/check-v4l2.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT types/libstrace_a-check-v4l2.o -MD -MP -MF types/$(DEPDIR)/libstrace_a-check-v4l2.Tpo -c -o types/libstrace_a-check-v4l2.o `test -f 'types/check-v4l2.c' || echo '$(srcdir)/'`types/check-v4l2.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/libstrace_a-check-v4l2.Tpo types/$(DEPDIR)/libstrace_a-check-v4l2.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-v4l2.c' object='types/libstrace_a-check-v4l2.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o types/strace-check-rtnl_neightbl.o `test -f 'types/check-rtnl_neightbl.c' || echo '$(srcdir)/'`types/check-rtnl_neightbl.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o types/libstrace_a-check-v4l2.o `test -f 'types/check-v4l2.c' || echo '$(srcdir)/'`types/check-v4l2.c
 
-types/strace-check-rtnl_neightbl.obj: types/check-rtnl_neightbl.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT types/strace-check-rtnl_neightbl.obj -MD -MP -MF types/$(DEPDIR)/strace-check-rtnl_neightbl.Tpo -c -o types/strace-check-rtnl_neightbl.obj `if test -f 'types/check-rtnl_neightbl.c'; then $(CYGPATH_W) 'types/check-rtnl_neightbl.c'; else $(CYGPATH_W) '$(srcdir)/types/check-rtnl_neightbl.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/strace-check-rtnl_neightbl.Tpo types/$(DEPDIR)/strace-check-rtnl_neightbl.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-rtnl_neightbl.c' object='types/strace-check-rtnl_neightbl.obj' libtool=no @AMDEPBACKSLASH@
+types/libstrace_a-check-v4l2.obj: types/check-v4l2.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT types/libstrace_a-check-v4l2.obj -MD -MP -MF types/$(DEPDIR)/libstrace_a-check-v4l2.Tpo -c -o types/libstrace_a-check-v4l2.obj `if test -f 'types/check-v4l2.c'; then $(CYGPATH_W) 'types/check-v4l2.c'; else $(CYGPATH_W) '$(srcdir)/types/check-v4l2.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/libstrace_a-check-v4l2.Tpo types/$(DEPDIR)/libstrace_a-check-v4l2.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-v4l2.c' object='types/libstrace_a-check-v4l2.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o types/strace-check-rtnl_neightbl.obj `if test -f 'types/check-rtnl_neightbl.c'; then $(CYGPATH_W) 'types/check-rtnl_neightbl.c'; else $(CYGPATH_W) '$(srcdir)/types/check-rtnl_neightbl.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o types/libstrace_a-check-v4l2.obj `if test -f 'types/check-v4l2.c'; then $(CYGPATH_W) 'types/check-v4l2.c'; else $(CYGPATH_W) '$(srcdir)/types/check-v4l2.c'; fi`
 
-types/strace-check-rtnl_route.o: types/check-rtnl_route.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT types/strace-check-rtnl_route.o -MD -MP -MF types/$(DEPDIR)/strace-check-rtnl_route.Tpo -c -o types/strace-check-rtnl_route.o `test -f 'types/check-rtnl_route.c' || echo '$(srcdir)/'`types/check-rtnl_route.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/strace-check-rtnl_route.Tpo types/$(DEPDIR)/strace-check-rtnl_route.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-rtnl_route.c' object='types/strace-check-rtnl_route.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-unwind.o: unwind.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-unwind.o -MD -MP -MF $(DEPDIR)/libstrace_a-unwind.Tpo -c -o libstrace_a-unwind.o `test -f 'unwind.c' || echo '$(srcdir)/'`unwind.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-unwind.Tpo $(DEPDIR)/libstrace_a-unwind.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='unwind.c' object='libstrace_a-unwind.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o types/strace-check-rtnl_route.o `test -f 'types/check-rtnl_route.c' || echo '$(srcdir)/'`types/check-rtnl_route.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-unwind.o `test -f 'unwind.c' || echo '$(srcdir)/'`unwind.c
 
-types/strace-check-rtnl_route.obj: types/check-rtnl_route.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT types/strace-check-rtnl_route.obj -MD -MP -MF types/$(DEPDIR)/strace-check-rtnl_route.Tpo -c -o types/strace-check-rtnl_route.obj `if test -f 'types/check-rtnl_route.c'; then $(CYGPATH_W) 'types/check-rtnl_route.c'; else $(CYGPATH_W) '$(srcdir)/types/check-rtnl_route.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) types/$(DEPDIR)/strace-check-rtnl_route.Tpo types/$(DEPDIR)/strace-check-rtnl_route.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='types/check-rtnl_route.c' object='types/strace-check-rtnl_route.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-unwind.obj: unwind.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-unwind.obj -MD -MP -MF $(DEPDIR)/libstrace_a-unwind.Tpo -c -o libstrace_a-unwind.obj `if test -f 'unwind.c'; then $(CYGPATH_W) 'unwind.c'; else $(CYGPATH_W) '$(srcdir)/unwind.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-unwind.Tpo $(DEPDIR)/libstrace_a-unwind.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='unwind.c' object='libstrace_a-unwind.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o types/strace-check-rtnl_route.obj `if test -f 'types/check-rtnl_route.c'; then $(CYGPATH_W) 'types/check-rtnl_route.c'; else $(CYGPATH_W) '$(srcdir)/types/check-rtnl_route.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-unwind.obj `if test -f 'unwind.c'; then $(CYGPATH_W) 'unwind.c'; else $(CYGPATH_W) '$(srcdir)/unwind.c'; fi`
 
-strace-unwind.o: unwind.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-unwind.o -MD -MP -MF $(DEPDIR)/strace-unwind.Tpo -c -o strace-unwind.o `test -f 'unwind.c' || echo '$(srcdir)/'`unwind.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-unwind.Tpo $(DEPDIR)/strace-unwind.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='unwind.c' object='strace-unwind.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-unwind-libdw.o: unwind-libdw.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-unwind-libdw.o -MD -MP -MF $(DEPDIR)/libstrace_a-unwind-libdw.Tpo -c -o libstrace_a-unwind-libdw.o `test -f 'unwind-libdw.c' || echo '$(srcdir)/'`unwind-libdw.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-unwind-libdw.Tpo $(DEPDIR)/libstrace_a-unwind-libdw.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='unwind-libdw.c' object='libstrace_a-unwind-libdw.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-unwind.o `test -f 'unwind.c' || echo '$(srcdir)/'`unwind.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-unwind-libdw.o `test -f 'unwind-libdw.c' || echo '$(srcdir)/'`unwind-libdw.c
 
-strace-unwind.obj: unwind.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-unwind.obj -MD -MP -MF $(DEPDIR)/strace-unwind.Tpo -c -o strace-unwind.obj `if test -f 'unwind.c'; then $(CYGPATH_W) 'unwind.c'; else $(CYGPATH_W) '$(srcdir)/unwind.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-unwind.Tpo $(DEPDIR)/strace-unwind.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='unwind.c' object='strace-unwind.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-unwind-libdw.obj: unwind-libdw.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-unwind-libdw.obj -MD -MP -MF $(DEPDIR)/libstrace_a-unwind-libdw.Tpo -c -o libstrace_a-unwind-libdw.obj `if test -f 'unwind-libdw.c'; then $(CYGPATH_W) 'unwind-libdw.c'; else $(CYGPATH_W) '$(srcdir)/unwind-libdw.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-unwind-libdw.Tpo $(DEPDIR)/libstrace_a-unwind-libdw.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='unwind-libdw.c' object='libstrace_a-unwind-libdw.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-unwind.obj `if test -f 'unwind.c'; then $(CYGPATH_W) 'unwind.c'; else $(CYGPATH_W) '$(srcdir)/unwind.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-unwind-libdw.obj `if test -f 'unwind-libdw.c'; then $(CYGPATH_W) 'unwind-libdw.c'; else $(CYGPATH_W) '$(srcdir)/unwind-libdw.c'; fi`
 
-strace-unwind-libdw.o: unwind-libdw.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-unwind-libdw.o -MD -MP -MF $(DEPDIR)/strace-unwind-libdw.Tpo -c -o strace-unwind-libdw.o `test -f 'unwind-libdw.c' || echo '$(srcdir)/'`unwind-libdw.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-unwind-libdw.Tpo $(DEPDIR)/strace-unwind-libdw.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='unwind-libdw.c' object='strace-unwind-libdw.o' libtool=no @AMDEPBACKSLASH@
+libstrace_a-unwind-libunwind.o: unwind-libunwind.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-unwind-libunwind.o -MD -MP -MF $(DEPDIR)/libstrace_a-unwind-libunwind.Tpo -c -o libstrace_a-unwind-libunwind.o `test -f 'unwind-libunwind.c' || echo '$(srcdir)/'`unwind-libunwind.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-unwind-libunwind.Tpo $(DEPDIR)/libstrace_a-unwind-libunwind.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='unwind-libunwind.c' object='libstrace_a-unwind-libunwind.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-unwind-libdw.o `test -f 'unwind-libdw.c' || echo '$(srcdir)/'`unwind-libdw.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-unwind-libunwind.o `test -f 'unwind-libunwind.c' || echo '$(srcdir)/'`unwind-libunwind.c
 
-strace-unwind-libdw.obj: unwind-libdw.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-unwind-libdw.obj -MD -MP -MF $(DEPDIR)/strace-unwind-libdw.Tpo -c -o strace-unwind-libdw.obj `if test -f 'unwind-libdw.c'; then $(CYGPATH_W) 'unwind-libdw.c'; else $(CYGPATH_W) '$(srcdir)/unwind-libdw.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-unwind-libdw.Tpo $(DEPDIR)/strace-unwind-libdw.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='unwind-libdw.c' object='strace-unwind-libdw.obj' libtool=no @AMDEPBACKSLASH@
+libstrace_a-unwind-libunwind.obj: unwind-libunwind.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -MT libstrace_a-unwind-libunwind.obj -MD -MP -MF $(DEPDIR)/libstrace_a-unwind-libunwind.Tpo -c -o libstrace_a-unwind-libunwind.obj `if test -f 'unwind-libunwind.c'; then $(CYGPATH_W) 'unwind-libunwind.c'; else $(CYGPATH_W) '$(srcdir)/unwind-libunwind.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libstrace_a-unwind-libunwind.Tpo $(DEPDIR)/libstrace_a-unwind-libunwind.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='unwind-libunwind.c' object='libstrace_a-unwind-libunwind.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-unwind-libdw.obj `if test -f 'unwind-libdw.c'; then $(CYGPATH_W) 'unwind-libdw.c'; else $(CYGPATH_W) '$(srcdir)/unwind-libdw.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libstrace_a_CPPFLAGS) $(CPPFLAGS) $(libstrace_a_CFLAGS) $(CFLAGS) -c -o libstrace_a-unwind-libunwind.obj `if test -f 'unwind-libunwind.c'; then $(CYGPATH_W) 'unwind-libunwind.c'; else $(CYGPATH_W) '$(srcdir)/unwind-libunwind.c'; fi`
 
-strace-unwind-libunwind.o: unwind-libunwind.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-unwind-libunwind.o -MD -MP -MF $(DEPDIR)/strace-unwind-libunwind.Tpo -c -o strace-unwind-libunwind.o `test -f 'unwind-libunwind.c' || echo '$(srcdir)/'`unwind-libunwind.c
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-unwind-libunwind.Tpo $(DEPDIR)/strace-unwind-libunwind.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='unwind-libunwind.c' object='strace-unwind-libunwind.o' libtool=no @AMDEPBACKSLASH@
+strace-strace.o: strace.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-strace.o -MD -MP -MF $(DEPDIR)/strace-strace.Tpo -c -o strace-strace.o `test -f 'strace.c' || echo '$(srcdir)/'`strace.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-strace.Tpo $(DEPDIR)/strace-strace.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='strace.c' object='strace-strace.o' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-unwind-libunwind.o `test -f 'unwind-libunwind.c' || echo '$(srcdir)/'`unwind-libunwind.c
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-strace.o `test -f 'strace.c' || echo '$(srcdir)/'`strace.c
 
-strace-unwind-libunwind.obj: unwind-libunwind.c
-@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-unwind-libunwind.obj -MD -MP -MF $(DEPDIR)/strace-unwind-libunwind.Tpo -c -o strace-unwind-libunwind.obj `if test -f 'unwind-libunwind.c'; then $(CYGPATH_W) 'unwind-libunwind.c'; else $(CYGPATH_W) '$(srcdir)/unwind-libunwind.c'; fi`
-@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-unwind-libunwind.Tpo $(DEPDIR)/strace-unwind-libunwind.Po
-@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='unwind-libunwind.c' object='strace-unwind-libunwind.obj' libtool=no @AMDEPBACKSLASH@
+strace-strace.obj: strace.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -MT strace-strace.obj -MD -MP -MF $(DEPDIR)/strace-strace.Tpo -c -o strace-strace.obj `if test -f 'strace.c'; then $(CYGPATH_W) 'strace.c'; else $(CYGPATH_W) '$(srcdir)/strace.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/strace-strace.Tpo $(DEPDIR)/strace-strace.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='strace.c' object='strace-strace.obj' libtool=no @AMDEPBACKSLASH@
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-unwind-libunwind.obj `if test -f 'unwind-libunwind.c'; then $(CYGPATH_W) 'unwind-libunwind.c'; else $(CYGPATH_W) '$(srcdir)/unwind-libunwind.c'; fi`
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(strace_CPPFLAGS) $(CPPFLAGS) $(strace_CFLAGS) $(CFLAGS) -c -o strace-strace.obj `if test -f 'strace.c'; then $(CYGPATH_W) 'strace.c'; else $(CYGPATH_W) '$(srcdir)/strace.c'; fi`
 install-man1: $(man_MANS)
 	@$(NORMAL_INSTALL)
 	@list1=''; \
@@ -7850,6 +8250,10 @@ dist-xz: distdir
 	tardir=$(distdir) && $(am__tar) | XZ_OPT=$${XZ_OPT--e} xz -c >$(distdir).tar.xz
 	$(am__post_remove_distdir)
 
+dist-zstd: distdir
+	tardir=$(distdir) && $(am__tar) | zstd -c $${ZSTD_CLEVEL-$${ZSTD_OPT--19}} >$(distdir).tar.zst
+	$(am__post_remove_distdir)
+
 dist-tarZ: distdir
 	@echo WARNING: "Support for distribution archives compressed with" \
 		       "legacy program 'compress' is deprecated." >&2
@@ -7892,6 +8296,8 @@ distcheck: dist
 	  eval GZIP= gzip $(GZIP_ENV) -dc $(distdir).shar.gz | unshar ;;\
 	*.zip*) \
 	  unzip $(distdir).zip ;;\
+	*.tar.zst*) \
+	  zstd -dc $(distdir).tar.zst | $(am__untar) ;;\
 	esac
 	chmod -R a-w $(distdir)
 	chmod u+w $(distdir)
@@ -7907,7 +8313,7 @@ distcheck: dist
 	    $(DISTCHECK_CONFIGURE_FLAGS) \
 	    --srcdir=../.. --prefix="$$dc_install_base" \
 	  && $(MAKE) $(AM_MAKEFLAGS) \
-	  && $(MAKE) $(AM_MAKEFLAGS) dvi \
+	  && $(MAKE) $(AM_MAKEFLAGS) $(AM_DISTCHECK_DVI_TARGET) \
 	  && $(MAKE) $(AM_MAKEFLAGS) check \
 	  && $(MAKE) $(AM_MAKEFLAGS) install \
 	  && $(MAKE) $(AM_MAKEFLAGS) installcheck \
@@ -8045,6 +8451,7 @@ distclean: distclean-recursive
 	-rm -f ./$(DEPDIR)/libmpers_m32_a-fetch_struct_xfs_quotastat.Po
 	-rm -f ./$(DEPDIR)/libmpers_m32_a-hdio.Po
 	-rm -f ./$(DEPDIR)/libmpers_m32_a-ipc_msgctl.Po
+	-rm -f ./$(DEPDIR)/libmpers_m32_a-ipc_semctl.Po
 	-rm -f ./$(DEPDIR)/libmpers_m32_a-ipc_shmctl.Po
 	-rm -f ./$(DEPDIR)/libmpers_m32_a-loop.Po
 	-rm -f ./$(DEPDIR)/libmpers_m32_a-mtd.Po
@@ -8056,7 +8463,6 @@ distclean: distclean-recursive
 	-rm -f ./$(DEPDIR)/libmpers_m32_a-print_sg_req_info.Po
 	-rm -f ./$(DEPDIR)/libmpers_m32_a-print_sigevent.Po
 	-rm -f ./$(DEPDIR)/libmpers_m32_a-print_time.Po
-	-rm -f ./$(DEPDIR)/libmpers_m32_a-print_timespec.Po
 	-rm -f ./$(DEPDIR)/libmpers_m32_a-print_timeval.Po
 	-rm -f ./$(DEPDIR)/libmpers_m32_a-printrusage.Po
 	-rm -f ./$(DEPDIR)/libmpers_m32_a-printsiginfo.Po
@@ -8085,6 +8491,7 @@ distclean: distclean-recursive
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-fetch_struct_xfs_quotastat.Po
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-hdio.Po
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-ipc_msgctl.Po
+	-rm -f ./$(DEPDIR)/libmpers_mx32_a-ipc_semctl.Po
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-ipc_shmctl.Po
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-loop.Po
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-mtd.Po
@@ -8096,7 +8503,6 @@ distclean: distclean-recursive
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-print_sg_req_info.Po
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-print_sigevent.Po
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-print_time.Po
-	-rm -f ./$(DEPDIR)/libmpers_mx32_a-print_timespec.Po
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-print_timeval.Po
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-printrusage.Po
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-printsiginfo.Po
@@ -8110,262 +8516,276 @@ distclean: distclean-recursive
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-ustat.Po
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-utime.Po
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-v4l2.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-access.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-affinity.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-aio.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-alpha.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-basic_filters.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-bind.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-bjm.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-block.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-bpf.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-bpf_attr_check.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-bpf_filter.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-bpf_seccomp_filter.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-bpf_sock_filter.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-btrfs.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-cacheflush.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-capability.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-chdir.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-chmod.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-clone.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-close_range.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-copy_file_range.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-count.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-delay.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-desc.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-dirent.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-dirent64.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-dirent_types.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-dm.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-dup.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-dyxlat.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-epoll.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-error_prints.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-evdev.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-evdev_mpers.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-eventfd.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-execve.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fadvise.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fallocate.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fanotify.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fchownat.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fcntl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fetch_bpf_fprog.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-fetch_indirect_syscall_args.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fetch_struct_flock.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fetch_struct_keyctl_kdf_params.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fetch_struct_mmsghdr.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fetch_struct_msghdr.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fetch_struct_stat.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fetch_struct_stat64.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fetch_struct_statfs.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fetch_struct_xfs_quotastat.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-file_handle.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-file_ioctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-filter_qualify.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-filter_seccomp.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-flock.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fs_x_ioctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fsconfig.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fsmount.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fsopen.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fspick.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-fstatfs.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-fstatfs64.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-futex.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-get_personality.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-get_robust_list.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-getcpu.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-getcwd.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-getpagesize.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-getpid.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-getrandom.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-hdio.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-hostname.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-inotify.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-inotify_ioctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-io.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-io_uring.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ioctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ioperm.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-iopl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ioprio.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-ipc.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ipc_msg.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ipc_msgctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ipc_sem.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ipc_semctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ipc_shm.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ipc_shmctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-kcmp.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-kexec.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-keyctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-kvm.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ldt.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-link.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-listen.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-lookup_dcookie.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-loop.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-lseek.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-mem.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-membarrier.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-memfd_create.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-mknod.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-mmap_cache.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-mmap_notify.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-mmsghdr.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-mount.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-move_mount.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-mq.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-msghdr.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-mtd.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-nbd_ioctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-net.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-netlink.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-netlink_crypto.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-netlink_inet_diag.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-netlink_kobject_uevent.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-netlink_netfilter.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-netlink_netlink_diag.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-netlink_packet_diag.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-netlink_route.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-netlink_selinux.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-netlink_smc_diag.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-netlink_sock_diag.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-netlink_unix_diag.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-nlattr.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-nsfs.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-numa.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-number_set.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-oldstat.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-open.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-open_tree.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-or1k_atomic.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-pathtrace.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-perf.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-perf_ioctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-personality.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-pidfd_getfd.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-pidfd_open.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-pidns.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-pkeys.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-poll.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-prctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_aio_sigset.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_dev_t.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_group_req.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_ifindex.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_instruction_pointer.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_kernel_version.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_mac.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_mq_attr.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_msgbuf.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_sg_req_info.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_sigevent.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_statfs.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_struct_stat.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_syscall_number.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_time.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_timespec32.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_timespec64.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_timeval.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_timeval64.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_timex.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-printmode.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-printrusage.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-printsiginfo.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-process.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-process_vm.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ptp.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ptrace_syscall_info.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-quota.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-random_ioctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-readahead.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-readlink.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-reboot.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-renameat.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-resource.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-retval.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-riscv.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rt_sigframe.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rt_sigreturn.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtc.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtnl_addr.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtnl_addrlabel.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtnl_dcb.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtnl_link.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtnl_mdb.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtnl_neigh.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtnl_neightbl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtnl_netconf.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtnl_nsid.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtnl_route.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtnl_rule.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtnl_tc.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtnl_tc_action.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-s390.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-sched.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-scsi.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-seccomp.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-sendfile.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-sg_io_v3.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-sg_io_v4.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-shutdown.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-sigaltstack.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-signal.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-signalfd.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-sigreturn.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-sock.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-sockaddr.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-socketcall.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-socketutils.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-sparc.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-sram_alloc.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-stage_output.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-stat.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-stat64.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-statfs.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-statfs64.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-statx.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-string_to_uint.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-swapon.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-sync_file_range.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-sync_file_range2.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-syscall.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-sysctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-sysinfo.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-syslog.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-sysmips.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-tee.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-term.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-time.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-times.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-trie.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-truncate.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ubi.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ucopy.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-uid.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-uid16.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-umask.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-umount.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-uname.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-unwind-libdw.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-unwind-libunwind.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-unwind.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-upeek.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-upoke.Po
-	-rm -f ./$(DEPDIR)/strace-access.Po
-	-rm -f ./$(DEPDIR)/strace-affinity.Po
-	-rm -f ./$(DEPDIR)/strace-aio.Po
-	-rm -f ./$(DEPDIR)/strace-alpha.Po
-	-rm -f ./$(DEPDIR)/strace-basic_filters.Po
-	-rm -f ./$(DEPDIR)/strace-bind.Po
-	-rm -f ./$(DEPDIR)/strace-bjm.Po
-	-rm -f ./$(DEPDIR)/strace-block.Po
-	-rm -f ./$(DEPDIR)/strace-bpf.Po
-	-rm -f ./$(DEPDIR)/strace-bpf_attr_check.Po
-	-rm -f ./$(DEPDIR)/strace-bpf_filter.Po
-	-rm -f ./$(DEPDIR)/strace-bpf_seccomp_filter.Po
-	-rm -f ./$(DEPDIR)/strace-bpf_sock_filter.Po
-	-rm -f ./$(DEPDIR)/strace-btrfs.Po
-	-rm -f ./$(DEPDIR)/strace-cacheflush.Po
-	-rm -f ./$(DEPDIR)/strace-capability.Po
-	-rm -f ./$(DEPDIR)/strace-chdir.Po
-	-rm -f ./$(DEPDIR)/strace-chmod.Po
-	-rm -f ./$(DEPDIR)/strace-clone.Po
-	-rm -f ./$(DEPDIR)/strace-copy_file_range.Po
-	-rm -f ./$(DEPDIR)/strace-count.Po
-	-rm -f ./$(DEPDIR)/strace-delay.Po
-	-rm -f ./$(DEPDIR)/strace-desc.Po
-	-rm -f ./$(DEPDIR)/strace-dirent.Po
-	-rm -f ./$(DEPDIR)/strace-dirent64.Po
-	-rm -f ./$(DEPDIR)/strace-dm.Po
-	-rm -f ./$(DEPDIR)/strace-dyxlat.Po
-	-rm -f ./$(DEPDIR)/strace-epoll.Po
-	-rm -f ./$(DEPDIR)/strace-error_prints.Po
-	-rm -f ./$(DEPDIR)/strace-evdev.Po
-	-rm -f ./$(DEPDIR)/strace-evdev_mpers.Po
-	-rm -f ./$(DEPDIR)/strace-eventfd.Po
-	-rm -f ./$(DEPDIR)/strace-execve.Po
-	-rm -f ./$(DEPDIR)/strace-fadvise.Po
-	-rm -f ./$(DEPDIR)/strace-fallocate.Po
-	-rm -f ./$(DEPDIR)/strace-fanotify.Po
-	-rm -f ./$(DEPDIR)/strace-fchownat.Po
-	-rm -f ./$(DEPDIR)/strace-fcntl.Po
-	-rm -f ./$(DEPDIR)/strace-fetch_bpf_fprog.Po
-	-rm -f ./$(DEPDIR)/strace-fetch_struct_flock.Po
-	-rm -f ./$(DEPDIR)/strace-fetch_struct_keyctl_kdf_params.Po
-	-rm -f ./$(DEPDIR)/strace-fetch_struct_mmsghdr.Po
-	-rm -f ./$(DEPDIR)/strace-fetch_struct_msghdr.Po
-	-rm -f ./$(DEPDIR)/strace-fetch_struct_stat.Po
-	-rm -f ./$(DEPDIR)/strace-fetch_struct_stat64.Po
-	-rm -f ./$(DEPDIR)/strace-fetch_struct_statfs.Po
-	-rm -f ./$(DEPDIR)/strace-fetch_struct_xfs_quotastat.Po
-	-rm -f ./$(DEPDIR)/strace-file_handle.Po
-	-rm -f ./$(DEPDIR)/strace-file_ioctl.Po
-	-rm -f ./$(DEPDIR)/strace-filter_qualify.Po
-	-rm -f ./$(DEPDIR)/strace-filter_seccomp.Po
-	-rm -f ./$(DEPDIR)/strace-flock.Po
-	-rm -f ./$(DEPDIR)/strace-fs_x_ioctl.Po
-	-rm -f ./$(DEPDIR)/strace-fsconfig.Po
-	-rm -f ./$(DEPDIR)/strace-fsmount.Po
-	-rm -f ./$(DEPDIR)/strace-fsopen.Po
-	-rm -f ./$(DEPDIR)/strace-fspick.Po
-	-rm -f ./$(DEPDIR)/strace-futex.Po
-	-rm -f ./$(DEPDIR)/strace-get_personality.Po
-	-rm -f ./$(DEPDIR)/strace-get_robust_list.Po
-	-rm -f ./$(DEPDIR)/strace-getcpu.Po
-	-rm -f ./$(DEPDIR)/strace-getcwd.Po
-	-rm -f ./$(DEPDIR)/strace-getrandom.Po
-	-rm -f ./$(DEPDIR)/strace-hdio.Po
-	-rm -f ./$(DEPDIR)/strace-hostname.Po
-	-rm -f ./$(DEPDIR)/strace-inotify.Po
-	-rm -f ./$(DEPDIR)/strace-inotify_ioctl.Po
-	-rm -f ./$(DEPDIR)/strace-io.Po
-	-rm -f ./$(DEPDIR)/strace-io_uring.Po
-	-rm -f ./$(DEPDIR)/strace-ioctl.Po
-	-rm -f ./$(DEPDIR)/strace-ioperm.Po
-	-rm -f ./$(DEPDIR)/strace-iopl.Po
-	-rm -f ./$(DEPDIR)/strace-ioprio.Po
-	-rm -f ./$(DEPDIR)/strace-ipc_msg.Po
-	-rm -f ./$(DEPDIR)/strace-ipc_msgctl.Po
-	-rm -f ./$(DEPDIR)/strace-ipc_sem.Po
-	-rm -f ./$(DEPDIR)/strace-ipc_shm.Po
-	-rm -f ./$(DEPDIR)/strace-ipc_shmctl.Po
-	-rm -f ./$(DEPDIR)/strace-kcmp.Po
-	-rm -f ./$(DEPDIR)/strace-kexec.Po
-	-rm -f ./$(DEPDIR)/strace-keyctl.Po
-	-rm -f ./$(DEPDIR)/strace-kvm.Po
-	-rm -f ./$(DEPDIR)/strace-ldt.Po
-	-rm -f ./$(DEPDIR)/strace-link.Po
-	-rm -f ./$(DEPDIR)/strace-listen.Po
-	-rm -f ./$(DEPDIR)/strace-lookup_dcookie.Po
-	-rm -f ./$(DEPDIR)/strace-loop.Po
-	-rm -f ./$(DEPDIR)/strace-lseek.Po
-	-rm -f ./$(DEPDIR)/strace-mem.Po
-	-rm -f ./$(DEPDIR)/strace-membarrier.Po
-	-rm -f ./$(DEPDIR)/strace-memfd_create.Po
-	-rm -f ./$(DEPDIR)/strace-mknod.Po
-	-rm -f ./$(DEPDIR)/strace-mmap_notify.Po
-	-rm -f ./$(DEPDIR)/strace-mmsghdr.Po
-	-rm -f ./$(DEPDIR)/strace-mount.Po
-	-rm -f ./$(DEPDIR)/strace-move_mount.Po
-	-rm -f ./$(DEPDIR)/strace-mq.Po
-	-rm -f ./$(DEPDIR)/strace-msghdr.Po
-	-rm -f ./$(DEPDIR)/strace-mtd.Po
-	-rm -f ./$(DEPDIR)/strace-nbd_ioctl.Po
-	-rm -f ./$(DEPDIR)/strace-net.Po
-	-rm -f ./$(DEPDIR)/strace-netlink.Po
-	-rm -f ./$(DEPDIR)/strace-netlink_crypto.Po
-	-rm -f ./$(DEPDIR)/strace-netlink_inet_diag.Po
-	-rm -f ./$(DEPDIR)/strace-netlink_kobject_uevent.Po
-	-rm -f ./$(DEPDIR)/strace-netlink_netfilter.Po
-	-rm -f ./$(DEPDIR)/strace-netlink_netlink_diag.Po
-	-rm -f ./$(DEPDIR)/strace-netlink_packet_diag.Po
-	-rm -f ./$(DEPDIR)/strace-netlink_route.Po
-	-rm -f ./$(DEPDIR)/strace-netlink_selinux.Po
-	-rm -f ./$(DEPDIR)/strace-netlink_smc_diag.Po
-	-rm -f ./$(DEPDIR)/strace-netlink_sock_diag.Po
-	-rm -f ./$(DEPDIR)/strace-netlink_unix_diag.Po
-	-rm -f ./$(DEPDIR)/strace-nlattr.Po
-	-rm -f ./$(DEPDIR)/strace-nsfs.Po
-	-rm -f ./$(DEPDIR)/strace-numa.Po
-	-rm -f ./$(DEPDIR)/strace-number_set.Po
-	-rm -f ./$(DEPDIR)/strace-oldstat.Po
-	-rm -f ./$(DEPDIR)/strace-open.Po
-	-rm -f ./$(DEPDIR)/strace-open_tree.Po
-	-rm -f ./$(DEPDIR)/strace-or1k_atomic.Po
-	-rm -f ./$(DEPDIR)/strace-pathtrace.Po
-	-rm -f ./$(DEPDIR)/strace-perf.Po
-	-rm -f ./$(DEPDIR)/strace-perf_ioctl.Po
-	-rm -f ./$(DEPDIR)/strace-personality.Po
-	-rm -f ./$(DEPDIR)/strace-pidfd_open.Po
-	-rm -f ./$(DEPDIR)/strace-pkeys.Po
-	-rm -f ./$(DEPDIR)/strace-poll.Po
-	-rm -f ./$(DEPDIR)/strace-prctl.Po
-	-rm -f ./$(DEPDIR)/strace-print_aio_sigset.Po
-	-rm -f ./$(DEPDIR)/strace-print_dev_t.Po
-	-rm -f ./$(DEPDIR)/strace-print_group_req.Po
-	-rm -f ./$(DEPDIR)/strace-print_ifindex.Po
-	-rm -f ./$(DEPDIR)/strace-print_instruction_pointer.Po
-	-rm -f ./$(DEPDIR)/strace-print_kernel_version.Po
-	-rm -f ./$(DEPDIR)/strace-print_mac.Po
-	-rm -f ./$(DEPDIR)/strace-print_mq_attr.Po
-	-rm -f ./$(DEPDIR)/strace-print_msgbuf.Po
-	-rm -f ./$(DEPDIR)/strace-print_sg_req_info.Po
-	-rm -f ./$(DEPDIR)/strace-print_sigevent.Po
-	-rm -f ./$(DEPDIR)/strace-print_statfs.Po
-	-rm -f ./$(DEPDIR)/strace-print_struct_stat.Po
-	-rm -f ./$(DEPDIR)/strace-print_time.Po
-	-rm -f ./$(DEPDIR)/strace-print_timespec.Po
-	-rm -f ./$(DEPDIR)/strace-print_timespec32.Po
-	-rm -f ./$(DEPDIR)/strace-print_timespec64.Po
-	-rm -f ./$(DEPDIR)/strace-print_timeval.Po
-	-rm -f ./$(DEPDIR)/strace-print_timeval64.Po
-	-rm -f ./$(DEPDIR)/strace-print_timex.Po
-	-rm -f ./$(DEPDIR)/strace-printmode.Po
-	-rm -f ./$(DEPDIR)/strace-printrusage.Po
-	-rm -f ./$(DEPDIR)/strace-printsiginfo.Po
-	-rm -f ./$(DEPDIR)/strace-process.Po
-	-rm -f ./$(DEPDIR)/strace-process_vm.Po
-	-rm -f ./$(DEPDIR)/strace-ptp.Po
-	-rm -f ./$(DEPDIR)/strace-ptrace_syscall_info.Po
-	-rm -f ./$(DEPDIR)/strace-quota.Po
-	-rm -f ./$(DEPDIR)/strace-random_ioctl.Po
-	-rm -f ./$(DEPDIR)/strace-readahead.Po
-	-rm -f ./$(DEPDIR)/strace-readlink.Po
-	-rm -f ./$(DEPDIR)/strace-reboot.Po
-	-rm -f ./$(DEPDIR)/strace-renameat.Po
-	-rm -f ./$(DEPDIR)/strace-resource.Po
-	-rm -f ./$(DEPDIR)/strace-retval.Po
-	-rm -f ./$(DEPDIR)/strace-riscv.Po
-	-rm -f ./$(DEPDIR)/strace-rt_sigframe.Po
-	-rm -f ./$(DEPDIR)/strace-rt_sigreturn.Po
-	-rm -f ./$(DEPDIR)/strace-rtc.Po
-	-rm -f ./$(DEPDIR)/strace-rtnl_addr.Po
-	-rm -f ./$(DEPDIR)/strace-rtnl_addrlabel.Po
-	-rm -f ./$(DEPDIR)/strace-rtnl_dcb.Po
-	-rm -f ./$(DEPDIR)/strace-rtnl_link.Po
-	-rm -f ./$(DEPDIR)/strace-rtnl_mdb.Po
-	-rm -f ./$(DEPDIR)/strace-rtnl_neigh.Po
-	-rm -f ./$(DEPDIR)/strace-rtnl_neightbl.Po
-	-rm -f ./$(DEPDIR)/strace-rtnl_netconf.Po
-	-rm -f ./$(DEPDIR)/strace-rtnl_nsid.Po
-	-rm -f ./$(DEPDIR)/strace-rtnl_route.Po
-	-rm -f ./$(DEPDIR)/strace-rtnl_rule.Po
-	-rm -f ./$(DEPDIR)/strace-rtnl_tc.Po
-	-rm -f ./$(DEPDIR)/strace-rtnl_tc_action.Po
-	-rm -f ./$(DEPDIR)/strace-s390.Po
-	-rm -f ./$(DEPDIR)/strace-sched.Po
-	-rm -f ./$(DEPDIR)/strace-scsi.Po
-	-rm -f ./$(DEPDIR)/strace-seccomp.Po
-	-rm -f ./$(DEPDIR)/strace-sendfile.Po
-	-rm -f ./$(DEPDIR)/strace-sg_io_v3.Po
-	-rm -f ./$(DEPDIR)/strace-sg_io_v4.Po
-	-rm -f ./$(DEPDIR)/strace-shutdown.Po
-	-rm -f ./$(DEPDIR)/strace-sigaltstack.Po
-	-rm -f ./$(DEPDIR)/strace-signal.Po
-	-rm -f ./$(DEPDIR)/strace-signalfd.Po
-	-rm -f ./$(DEPDIR)/strace-sock.Po
-	-rm -f ./$(DEPDIR)/strace-sockaddr.Po
-	-rm -f ./$(DEPDIR)/strace-socketutils.Po
-	-rm -f ./$(DEPDIR)/strace-sparc.Po
-	-rm -f ./$(DEPDIR)/strace-sram_alloc.Po
-	-rm -f ./$(DEPDIR)/strace-stage_output.Po
-	-rm -f ./$(DEPDIR)/strace-stat.Po
-	-rm -f ./$(DEPDIR)/strace-stat64.Po
-	-rm -f ./$(DEPDIR)/strace-statfs.Po
-	-rm -f ./$(DEPDIR)/strace-statx.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-userfaultfd.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ustat.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-util.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-utime.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-utimes.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-v4l2.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-wait.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-watchdog_ioctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-xattr.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-xgetdents.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-xlat.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-xmalloc.Po
 	-rm -f ./$(DEPDIR)/strace-strace.Po
-	-rm -f ./$(DEPDIR)/strace-string_to_uint.Po
-	-rm -f ./$(DEPDIR)/strace-swapon.Po
-	-rm -f ./$(DEPDIR)/strace-syscall.Po
-	-rm -f ./$(DEPDIR)/strace-sysctl.Po
-	-rm -f ./$(DEPDIR)/strace-sysinfo.Po
-	-rm -f ./$(DEPDIR)/strace-syslog.Po
-	-rm -f ./$(DEPDIR)/strace-sysmips.Po
-	-rm -f ./$(DEPDIR)/strace-term.Po
-	-rm -f ./$(DEPDIR)/strace-time.Po
-	-rm -f ./$(DEPDIR)/strace-times.Po
-	-rm -f ./$(DEPDIR)/strace-truncate.Po
-	-rm -f ./$(DEPDIR)/strace-ubi.Po
-	-rm -f ./$(DEPDIR)/strace-ucopy.Po
-	-rm -f ./$(DEPDIR)/strace-uid.Po
-	-rm -f ./$(DEPDIR)/strace-uid16.Po
-	-rm -f ./$(DEPDIR)/strace-umask.Po
-	-rm -f ./$(DEPDIR)/strace-umount.Po
-	-rm -f ./$(DEPDIR)/strace-uname.Po
-	-rm -f ./$(DEPDIR)/strace-unwind-libdw.Po
-	-rm -f ./$(DEPDIR)/strace-unwind-libunwind.Po
-	-rm -f ./$(DEPDIR)/strace-unwind.Po
-	-rm -f ./$(DEPDIR)/strace-userfaultfd.Po
-	-rm -f ./$(DEPDIR)/strace-ustat.Po
-	-rm -f ./$(DEPDIR)/strace-util.Po
-	-rm -f ./$(DEPDIR)/strace-utime.Po
-	-rm -f ./$(DEPDIR)/strace-utimes.Po
-	-rm -f ./$(DEPDIR)/strace-v4l2.Po
-	-rm -f ./$(DEPDIR)/strace-wait.Po
-	-rm -f ./$(DEPDIR)/strace-watchdog_ioctl.Po
-	-rm -f ./$(DEPDIR)/strace-xattr.Po
-	-rm -f ./$(DEPDIR)/strace-xlat.Po
-	-rm -f ./$(DEPDIR)/strace-xmalloc.Po
-	-rm -f types/$(DEPDIR)/strace-check-cryptouser.Po
-	-rm -f types/$(DEPDIR)/strace-check-evdev.Po
-	-rm -f types/$(DEPDIR)/strace-check-io_uring.Po
-	-rm -f types/$(DEPDIR)/strace-check-rtnl_link.Po
-	-rm -f types/$(DEPDIR)/strace-check-rtnl_mdb.Po
-	-rm -f types/$(DEPDIR)/strace-check-rtnl_neightbl.Po
-	-rm -f types/$(DEPDIR)/strace-check-rtnl_route.Po
+	-rm -f types/$(DEPDIR)/libstrace_a-check-btrfs.Po
+	-rm -f types/$(DEPDIR)/libstrace_a-check-cryptouser.Po
+	-rm -f types/$(DEPDIR)/libstrace_a-check-evdev.Po
+	-rm -f types/$(DEPDIR)/libstrace_a-check-io_uring.Po
+	-rm -f types/$(DEPDIR)/libstrace_a-check-loop.Po
+	-rm -f types/$(DEPDIR)/libstrace_a-check-openat2.Po
+	-rm -f types/$(DEPDIR)/libstrace_a-check-rtnl_link.Po
+	-rm -f types/$(DEPDIR)/libstrace_a-check-rtnl_mdb.Po
+	-rm -f types/$(DEPDIR)/libstrace_a-check-rtnl_neightbl.Po
+	-rm -f types/$(DEPDIR)/libstrace_a-check-rtnl_route.Po
+	-rm -f types/$(DEPDIR)/libstrace_a-check-tee.Po
+	-rm -f types/$(DEPDIR)/libstrace_a-check-v4l2.Po
 	-rm -f Makefile
 distclean-am: clean-am distclean-compile distclean-generic \
 	distclean-hdr distclean-tags
@@ -8428,6 +8848,7 @@ maintainer-clean: maintainer-clean-recur
 	-rm -f ./$(DEPDIR)/libmpers_m32_a-fetch_struct_xfs_quotastat.Po
 	-rm -f ./$(DEPDIR)/libmpers_m32_a-hdio.Po
 	-rm -f ./$(DEPDIR)/libmpers_m32_a-ipc_msgctl.Po
+	-rm -f ./$(DEPDIR)/libmpers_m32_a-ipc_semctl.Po
 	-rm -f ./$(DEPDIR)/libmpers_m32_a-ipc_shmctl.Po
 	-rm -f ./$(DEPDIR)/libmpers_m32_a-loop.Po
 	-rm -f ./$(DEPDIR)/libmpers_m32_a-mtd.Po
@@ -8439,7 +8860,6 @@ maintainer-clean: maintainer-clean-recur
 	-rm -f ./$(DEPDIR)/libmpers_m32_a-print_sg_req_info.Po
 	-rm -f ./$(DEPDIR)/libmpers_m32_a-print_sigevent.Po
 	-rm -f ./$(DEPDIR)/libmpers_m32_a-print_time.Po
-	-rm -f ./$(DEPDIR)/libmpers_m32_a-print_timespec.Po
 	-rm -f ./$(DEPDIR)/libmpers_m32_a-print_timeval.Po
 	-rm -f ./$(DEPDIR)/libmpers_m32_a-printrusage.Po
 	-rm -f ./$(DEPDIR)/libmpers_m32_a-printsiginfo.Po
@@ -8468,6 +8888,7 @@ maintainer-clean: maintainer-clean-recur
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-fetch_struct_xfs_quotastat.Po
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-hdio.Po
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-ipc_msgctl.Po
+	-rm -f ./$(DEPDIR)/libmpers_mx32_a-ipc_semctl.Po
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-ipc_shmctl.Po
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-loop.Po
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-mtd.Po
@@ -8479,7 +8900,6 @@ maintainer-clean: maintainer-clean-recur
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-print_sg_req_info.Po
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-print_sigevent.Po
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-print_time.Po
-	-rm -f ./$(DEPDIR)/libmpers_mx32_a-print_timespec.Po
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-print_timeval.Po
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-printrusage.Po
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-printsiginfo.Po
@@ -8493,262 +8913,276 @@ maintainer-clean: maintainer-clean-recur
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-ustat.Po
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-utime.Po
 	-rm -f ./$(DEPDIR)/libmpers_mx32_a-v4l2.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-access.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-affinity.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-aio.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-alpha.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-basic_filters.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-bind.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-bjm.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-block.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-bpf.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-bpf_attr_check.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-bpf_filter.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-bpf_seccomp_filter.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-bpf_sock_filter.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-btrfs.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-cacheflush.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-capability.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-chdir.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-chmod.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-clone.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-close_range.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-copy_file_range.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-count.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-delay.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-desc.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-dirent.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-dirent64.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-dirent_types.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-dm.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-dup.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-dyxlat.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-epoll.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-error_prints.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-evdev.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-evdev_mpers.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-eventfd.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-execve.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fadvise.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fallocate.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fanotify.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fchownat.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fcntl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fetch_bpf_fprog.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-fetch_indirect_syscall_args.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fetch_struct_flock.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fetch_struct_keyctl_kdf_params.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fetch_struct_mmsghdr.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fetch_struct_msghdr.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fetch_struct_stat.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fetch_struct_stat64.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fetch_struct_statfs.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fetch_struct_xfs_quotastat.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-file_handle.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-file_ioctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-filter_qualify.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-filter_seccomp.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-flock.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fs_x_ioctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fsconfig.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fsmount.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fsopen.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-fspick.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-fstatfs.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-fstatfs64.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-futex.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-get_personality.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-get_robust_list.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-getcpu.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-getcwd.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-getpagesize.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-getpid.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-getrandom.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-hdio.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-hostname.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-inotify.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-inotify_ioctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-io.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-io_uring.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ioctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ioperm.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-iopl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ioprio.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-ipc.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ipc_msg.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ipc_msgctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ipc_sem.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ipc_semctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ipc_shm.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ipc_shmctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-kcmp.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-kexec.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-keyctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-kvm.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ldt.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-link.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-listen.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-lookup_dcookie.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-loop.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-lseek.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-mem.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-membarrier.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-memfd_create.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-mknod.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-mmap_cache.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-mmap_notify.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-mmsghdr.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-mount.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-move_mount.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-mq.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-msghdr.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-mtd.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-nbd_ioctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-net.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-netlink.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-netlink_crypto.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-netlink_inet_diag.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-netlink_kobject_uevent.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-netlink_netfilter.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-netlink_netlink_diag.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-netlink_packet_diag.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-netlink_route.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-netlink_selinux.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-netlink_smc_diag.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-netlink_sock_diag.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-netlink_unix_diag.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-nlattr.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-nsfs.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-numa.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-number_set.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-oldstat.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-open.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-open_tree.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-or1k_atomic.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-pathtrace.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-perf.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-perf_ioctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-personality.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-pidfd_getfd.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-pidfd_open.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-pidns.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-pkeys.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-poll.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-prctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_aio_sigset.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_dev_t.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_group_req.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_ifindex.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_instruction_pointer.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_kernel_version.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_mac.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_mq_attr.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_msgbuf.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_sg_req_info.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_sigevent.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_statfs.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_struct_stat.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_syscall_number.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_time.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_timespec32.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_timespec64.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_timeval.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_timeval64.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-print_timex.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-printmode.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-printrusage.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-printsiginfo.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-process.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-process_vm.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ptp.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ptrace_syscall_info.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-quota.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-random_ioctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-readahead.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-readlink.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-reboot.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-renameat.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-resource.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-retval.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-riscv.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rt_sigframe.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rt_sigreturn.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtc.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtnl_addr.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtnl_addrlabel.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtnl_dcb.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtnl_link.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtnl_mdb.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtnl_neigh.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtnl_neightbl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtnl_netconf.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtnl_nsid.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtnl_route.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtnl_rule.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtnl_tc.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-rtnl_tc_action.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-s390.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-sched.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-scsi.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-seccomp.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-sendfile.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-sg_io_v3.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-sg_io_v4.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-shutdown.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-sigaltstack.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-signal.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-signalfd.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-sigreturn.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-sock.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-sockaddr.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-socketcall.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-socketutils.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-sparc.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-sram_alloc.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-stage_output.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-stat.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-stat64.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-statfs.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-statfs64.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-statx.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-string_to_uint.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-swapon.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-sync_file_range.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-sync_file_range2.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-syscall.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-sysctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-sysinfo.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-syslog.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-sysmips.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-tee.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-term.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-time.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-times.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-trie.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-truncate.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ubi.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ucopy.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-uid.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-uid16.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-umask.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-umount.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-uname.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-unwind-libdw.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-unwind-libunwind.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-unwind.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-upeek.Po
 	-rm -f ./$(DEPDIR)/libstrace_a-upoke.Po
-	-rm -f ./$(DEPDIR)/strace-access.Po
-	-rm -f ./$(DEPDIR)/strace-affinity.Po
-	-rm -f ./$(DEPDIR)/strace-aio.Po
-	-rm -f ./$(DEPDIR)/strace-alpha.Po
-	-rm -f ./$(DEPDIR)/strace-basic_filters.Po
-	-rm -f ./$(DEPDIR)/strace-bind.Po
-	-rm -f ./$(DEPDIR)/strace-bjm.Po
-	-rm -f ./$(DEPDIR)/strace-block.Po
-	-rm -f ./$(DEPDIR)/strace-bpf.Po
-	-rm -f ./$(DEPDIR)/strace-bpf_attr_check.Po
-	-rm -f ./$(DEPDIR)/strace-bpf_filter.Po
-	-rm -f ./$(DEPDIR)/strace-bpf_seccomp_filter.Po
-	-rm -f ./$(DEPDIR)/strace-bpf_sock_filter.Po
-	-rm -f ./$(DEPDIR)/strace-btrfs.Po
-	-rm -f ./$(DEPDIR)/strace-cacheflush.Po
-	-rm -f ./$(DEPDIR)/strace-capability.Po
-	-rm -f ./$(DEPDIR)/strace-chdir.Po
-	-rm -f ./$(DEPDIR)/strace-chmod.Po
-	-rm -f ./$(DEPDIR)/strace-clone.Po
-	-rm -f ./$(DEPDIR)/strace-copy_file_range.Po
-	-rm -f ./$(DEPDIR)/strace-count.Po
-	-rm -f ./$(DEPDIR)/strace-delay.Po
-	-rm -f ./$(DEPDIR)/strace-desc.Po
-	-rm -f ./$(DEPDIR)/strace-dirent.Po
-	-rm -f ./$(DEPDIR)/strace-dirent64.Po
-	-rm -f ./$(DEPDIR)/strace-dm.Po
-	-rm -f ./$(DEPDIR)/strace-dyxlat.Po
-	-rm -f ./$(DEPDIR)/strace-epoll.Po
-	-rm -f ./$(DEPDIR)/strace-error_prints.Po
-	-rm -f ./$(DEPDIR)/strace-evdev.Po
-	-rm -f ./$(DEPDIR)/strace-evdev_mpers.Po
-	-rm -f ./$(DEPDIR)/strace-eventfd.Po
-	-rm -f ./$(DEPDIR)/strace-execve.Po
-	-rm -f ./$(DEPDIR)/strace-fadvise.Po
-	-rm -f ./$(DEPDIR)/strace-fallocate.Po
-	-rm -f ./$(DEPDIR)/strace-fanotify.Po
-	-rm -f ./$(DEPDIR)/strace-fchownat.Po
-	-rm -f ./$(DEPDIR)/strace-fcntl.Po
-	-rm -f ./$(DEPDIR)/strace-fetch_bpf_fprog.Po
-	-rm -f ./$(DEPDIR)/strace-fetch_struct_flock.Po
-	-rm -f ./$(DEPDIR)/strace-fetch_struct_keyctl_kdf_params.Po
-	-rm -f ./$(DEPDIR)/strace-fetch_struct_mmsghdr.Po
-	-rm -f ./$(DEPDIR)/strace-fetch_struct_msghdr.Po
-	-rm -f ./$(DEPDIR)/strace-fetch_struct_stat.Po
-	-rm -f ./$(DEPDIR)/strace-fetch_struct_stat64.Po
-	-rm -f ./$(DEPDIR)/strace-fetch_struct_statfs.Po
-	-rm -f ./$(DEPDIR)/strace-fetch_struct_xfs_quotastat.Po
-	-rm -f ./$(DEPDIR)/strace-file_handle.Po
-	-rm -f ./$(DEPDIR)/strace-file_ioctl.Po
-	-rm -f ./$(DEPDIR)/strace-filter_qualify.Po
-	-rm -f ./$(DEPDIR)/strace-filter_seccomp.Po
-	-rm -f ./$(DEPDIR)/strace-flock.Po
-	-rm -f ./$(DEPDIR)/strace-fs_x_ioctl.Po
-	-rm -f ./$(DEPDIR)/strace-fsconfig.Po
-	-rm -f ./$(DEPDIR)/strace-fsmount.Po
-	-rm -f ./$(DEPDIR)/strace-fsopen.Po
-	-rm -f ./$(DEPDIR)/strace-fspick.Po
-	-rm -f ./$(DEPDIR)/strace-futex.Po
-	-rm -f ./$(DEPDIR)/strace-get_personality.Po
-	-rm -f ./$(DEPDIR)/strace-get_robust_list.Po
-	-rm -f ./$(DEPDIR)/strace-getcpu.Po
-	-rm -f ./$(DEPDIR)/strace-getcwd.Po
-	-rm -f ./$(DEPDIR)/strace-getrandom.Po
-	-rm -f ./$(DEPDIR)/strace-hdio.Po
-	-rm -f ./$(DEPDIR)/strace-hostname.Po
-	-rm -f ./$(DEPDIR)/strace-inotify.Po
-	-rm -f ./$(DEPDIR)/strace-inotify_ioctl.Po
-	-rm -f ./$(DEPDIR)/strace-io.Po
-	-rm -f ./$(DEPDIR)/strace-io_uring.Po
-	-rm -f ./$(DEPDIR)/strace-ioctl.Po
-	-rm -f ./$(DEPDIR)/strace-ioperm.Po
-	-rm -f ./$(DEPDIR)/strace-iopl.Po
-	-rm -f ./$(DEPDIR)/strace-ioprio.Po
-	-rm -f ./$(DEPDIR)/strace-ipc_msg.Po
-	-rm -f ./$(DEPDIR)/strace-ipc_msgctl.Po
-	-rm -f ./$(DEPDIR)/strace-ipc_sem.Po
-	-rm -f ./$(DEPDIR)/strace-ipc_shm.Po
-	-rm -f ./$(DEPDIR)/strace-ipc_shmctl.Po
-	-rm -f ./$(DEPDIR)/strace-kcmp.Po
-	-rm -f ./$(DEPDIR)/strace-kexec.Po
-	-rm -f ./$(DEPDIR)/strace-keyctl.Po
-	-rm -f ./$(DEPDIR)/strace-kvm.Po
-	-rm -f ./$(DEPDIR)/strace-ldt.Po
-	-rm -f ./$(DEPDIR)/strace-link.Po
-	-rm -f ./$(DEPDIR)/strace-listen.Po
-	-rm -f ./$(DEPDIR)/strace-lookup_dcookie.Po
-	-rm -f ./$(DEPDIR)/strace-loop.Po
-	-rm -f ./$(DEPDIR)/strace-lseek.Po
-	-rm -f ./$(DEPDIR)/strace-mem.Po
-	-rm -f ./$(DEPDIR)/strace-membarrier.Po
-	-rm -f ./$(DEPDIR)/strace-memfd_create.Po
-	-rm -f ./$(DEPDIR)/strace-mknod.Po
-	-rm -f ./$(DEPDIR)/strace-mmap_notify.Po
-	-rm -f ./$(DEPDIR)/strace-mmsghdr.Po
-	-rm -f ./$(DEPDIR)/strace-mount.Po
-	-rm -f ./$(DEPDIR)/strace-move_mount.Po
-	-rm -f ./$(DEPDIR)/strace-mq.Po
-	-rm -f ./$(DEPDIR)/strace-msghdr.Po
-	-rm -f ./$(DEPDIR)/strace-mtd.Po
-	-rm -f ./$(DEPDIR)/strace-nbd_ioctl.Po
-	-rm -f ./$(DEPDIR)/strace-net.Po
-	-rm -f ./$(DEPDIR)/strace-netlink.Po
-	-rm -f ./$(DEPDIR)/strace-netlink_crypto.Po
-	-rm -f ./$(DEPDIR)/strace-netlink_inet_diag.Po
-	-rm -f ./$(DEPDIR)/strace-netlink_kobject_uevent.Po
-	-rm -f ./$(DEPDIR)/strace-netlink_netfilter.Po
-	-rm -f ./$(DEPDIR)/strace-netlink_netlink_diag.Po
-	-rm -f ./$(DEPDIR)/strace-netlink_packet_diag.Po
-	-rm -f ./$(DEPDIR)/strace-netlink_route.Po
-	-rm -f ./$(DEPDIR)/strace-netlink_selinux.Po
-	-rm -f ./$(DEPDIR)/strace-netlink_smc_diag.Po
-	-rm -f ./$(DEPDIR)/strace-netlink_sock_diag.Po
-	-rm -f ./$(DEPDIR)/strace-netlink_unix_diag.Po
-	-rm -f ./$(DEPDIR)/strace-nlattr.Po
-	-rm -f ./$(DEPDIR)/strace-nsfs.Po
-	-rm -f ./$(DEPDIR)/strace-numa.Po
-	-rm -f ./$(DEPDIR)/strace-number_set.Po
-	-rm -f ./$(DEPDIR)/strace-oldstat.Po
-	-rm -f ./$(DEPDIR)/strace-open.Po
-	-rm -f ./$(DEPDIR)/strace-open_tree.Po
-	-rm -f ./$(DEPDIR)/strace-or1k_atomic.Po
-	-rm -f ./$(DEPDIR)/strace-pathtrace.Po
-	-rm -f ./$(DEPDIR)/strace-perf.Po
-	-rm -f ./$(DEPDIR)/strace-perf_ioctl.Po
-	-rm -f ./$(DEPDIR)/strace-personality.Po
-	-rm -f ./$(DEPDIR)/strace-pidfd_open.Po
-	-rm -f ./$(DEPDIR)/strace-pkeys.Po
-	-rm -f ./$(DEPDIR)/strace-poll.Po
-	-rm -f ./$(DEPDIR)/strace-prctl.Po
-	-rm -f ./$(DEPDIR)/strace-print_aio_sigset.Po
-	-rm -f ./$(DEPDIR)/strace-print_dev_t.Po
-	-rm -f ./$(DEPDIR)/strace-print_group_req.Po
-	-rm -f ./$(DEPDIR)/strace-print_ifindex.Po
-	-rm -f ./$(DEPDIR)/strace-print_instruction_pointer.Po
-	-rm -f ./$(DEPDIR)/strace-print_kernel_version.Po
-	-rm -f ./$(DEPDIR)/strace-print_mac.Po
-	-rm -f ./$(DEPDIR)/strace-print_mq_attr.Po
-	-rm -f ./$(DEPDIR)/strace-print_msgbuf.Po
-	-rm -f ./$(DEPDIR)/strace-print_sg_req_info.Po
-	-rm -f ./$(DEPDIR)/strace-print_sigevent.Po
-	-rm -f ./$(DEPDIR)/strace-print_statfs.Po
-	-rm -f ./$(DEPDIR)/strace-print_struct_stat.Po
-	-rm -f ./$(DEPDIR)/strace-print_time.Po
-	-rm -f ./$(DEPDIR)/strace-print_timespec.Po
-	-rm -f ./$(DEPDIR)/strace-print_timespec32.Po
-	-rm -f ./$(DEPDIR)/strace-print_timespec64.Po
-	-rm -f ./$(DEPDIR)/strace-print_timeval.Po
-	-rm -f ./$(DEPDIR)/strace-print_timeval64.Po
-	-rm -f ./$(DEPDIR)/strace-print_timex.Po
-	-rm -f ./$(DEPDIR)/strace-printmode.Po
-	-rm -f ./$(DEPDIR)/strace-printrusage.Po
-	-rm -f ./$(DEPDIR)/strace-printsiginfo.Po
-	-rm -f ./$(DEPDIR)/strace-process.Po
-	-rm -f ./$(DEPDIR)/strace-process_vm.Po
-	-rm -f ./$(DEPDIR)/strace-ptp.Po
-	-rm -f ./$(DEPDIR)/strace-ptrace_syscall_info.Po
-	-rm -f ./$(DEPDIR)/strace-quota.Po
-	-rm -f ./$(DEPDIR)/strace-random_ioctl.Po
-	-rm -f ./$(DEPDIR)/strace-readahead.Po
-	-rm -f ./$(DEPDIR)/strace-readlink.Po
-	-rm -f ./$(DEPDIR)/strace-reboot.Po
-	-rm -f ./$(DEPDIR)/strace-renameat.Po
-	-rm -f ./$(DEPDIR)/strace-resource.Po
-	-rm -f ./$(DEPDIR)/strace-retval.Po
-	-rm -f ./$(DEPDIR)/strace-riscv.Po
-	-rm -f ./$(DEPDIR)/strace-rt_sigframe.Po
-	-rm -f ./$(DEPDIR)/strace-rt_sigreturn.Po
-	-rm -f ./$(DEPDIR)/strace-rtc.Po
-	-rm -f ./$(DEPDIR)/strace-rtnl_addr.Po
-	-rm -f ./$(DEPDIR)/strace-rtnl_addrlabel.Po
-	-rm -f ./$(DEPDIR)/strace-rtnl_dcb.Po
-	-rm -f ./$(DEPDIR)/strace-rtnl_link.Po
-	-rm -f ./$(DEPDIR)/strace-rtnl_mdb.Po
-	-rm -f ./$(DEPDIR)/strace-rtnl_neigh.Po
-	-rm -f ./$(DEPDIR)/strace-rtnl_neightbl.Po
-	-rm -f ./$(DEPDIR)/strace-rtnl_netconf.Po
-	-rm -f ./$(DEPDIR)/strace-rtnl_nsid.Po
-	-rm -f ./$(DEPDIR)/strace-rtnl_route.Po
-	-rm -f ./$(DEPDIR)/strace-rtnl_rule.Po
-	-rm -f ./$(DEPDIR)/strace-rtnl_tc.Po
-	-rm -f ./$(DEPDIR)/strace-rtnl_tc_action.Po
-	-rm -f ./$(DEPDIR)/strace-s390.Po
-	-rm -f ./$(DEPDIR)/strace-sched.Po
-	-rm -f ./$(DEPDIR)/strace-scsi.Po
-	-rm -f ./$(DEPDIR)/strace-seccomp.Po
-	-rm -f ./$(DEPDIR)/strace-sendfile.Po
-	-rm -f ./$(DEPDIR)/strace-sg_io_v3.Po
-	-rm -f ./$(DEPDIR)/strace-sg_io_v4.Po
-	-rm -f ./$(DEPDIR)/strace-shutdown.Po
-	-rm -f ./$(DEPDIR)/strace-sigaltstack.Po
-	-rm -f ./$(DEPDIR)/strace-signal.Po
-	-rm -f ./$(DEPDIR)/strace-signalfd.Po
-	-rm -f ./$(DEPDIR)/strace-sock.Po
-	-rm -f ./$(DEPDIR)/strace-sockaddr.Po
-	-rm -f ./$(DEPDIR)/strace-socketutils.Po
-	-rm -f ./$(DEPDIR)/strace-sparc.Po
-	-rm -f ./$(DEPDIR)/strace-sram_alloc.Po
-	-rm -f ./$(DEPDIR)/strace-stage_output.Po
-	-rm -f ./$(DEPDIR)/strace-stat.Po
-	-rm -f ./$(DEPDIR)/strace-stat64.Po
-	-rm -f ./$(DEPDIR)/strace-statfs.Po
-	-rm -f ./$(DEPDIR)/strace-statx.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-userfaultfd.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-ustat.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-util.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-utime.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-utimes.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-v4l2.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-wait.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-watchdog_ioctl.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-xattr.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-xgetdents.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-xlat.Po
+	-rm -f ./$(DEPDIR)/libstrace_a-xmalloc.Po
 	-rm -f ./$(DEPDIR)/strace-strace.Po
-	-rm -f ./$(DEPDIR)/strace-string_to_uint.Po
-	-rm -f ./$(DEPDIR)/strace-swapon.Po
-	-rm -f ./$(DEPDIR)/strace-syscall.Po
-	-rm -f ./$(DEPDIR)/strace-sysctl.Po
-	-rm -f ./$(DEPDIR)/strace-sysinfo.Po
-	-rm -f ./$(DEPDIR)/strace-syslog.Po
-	-rm -f ./$(DEPDIR)/strace-sysmips.Po
-	-rm -f ./$(DEPDIR)/strace-term.Po
-	-rm -f ./$(DEPDIR)/strace-time.Po
-	-rm -f ./$(DEPDIR)/strace-times.Po
-	-rm -f ./$(DEPDIR)/strace-truncate.Po
-	-rm -f ./$(DEPDIR)/strace-ubi.Po
-	-rm -f ./$(DEPDIR)/strace-ucopy.Po
-	-rm -f ./$(DEPDIR)/strace-uid.Po
-	-rm -f ./$(DEPDIR)/strace-uid16.Po
-	-rm -f ./$(DEPDIR)/strace-umask.Po
-	-rm -f ./$(DEPDIR)/strace-umount.Po
-	-rm -f ./$(DEPDIR)/strace-uname.Po
-	-rm -f ./$(DEPDIR)/strace-unwind-libdw.Po
-	-rm -f ./$(DEPDIR)/strace-unwind-libunwind.Po
-	-rm -f ./$(DEPDIR)/strace-unwind.Po
-	-rm -f ./$(DEPDIR)/strace-userfaultfd.Po
-	-rm -f ./$(DEPDIR)/strace-ustat.Po
-	-rm -f ./$(DEPDIR)/strace-util.Po
-	-rm -f ./$(DEPDIR)/strace-utime.Po
-	-rm -f ./$(DEPDIR)/strace-utimes.Po
-	-rm -f ./$(DEPDIR)/strace-v4l2.Po
-	-rm -f ./$(DEPDIR)/strace-wait.Po
-	-rm -f ./$(DEPDIR)/strace-watchdog_ioctl.Po
-	-rm -f ./$(DEPDIR)/strace-xattr.Po
-	-rm -f ./$(DEPDIR)/strace-xlat.Po
-	-rm -f ./$(DEPDIR)/strace-xmalloc.Po
-	-rm -f types/$(DEPDIR)/strace-check-cryptouser.Po
-	-rm -f types/$(DEPDIR)/strace-check-evdev.Po
-	-rm -f types/$(DEPDIR)/strace-check-io_uring.Po
-	-rm -f types/$(DEPDIR)/strace-check-rtnl_link.Po
-	-rm -f types/$(DEPDIR)/strace-check-rtnl_mdb.Po
-	-rm -f types/$(DEPDIR)/strace-check-rtnl_neightbl.Po
-	-rm -f types/$(DEPDIR)/strace-check-rtnl_route.Po
+	-rm -f types/$(DEPDIR)/libstrace_a-check-btrfs.Po
+	-rm -f types/$(DEPDIR)/libstrace_a-check-cryptouser.Po
+	-rm -f types/$(DEPDIR)/libstrace_a-check-evdev.Po
+	-rm -f types/$(DEPDIR)/libstrace_a-check-io_uring.Po
+	-rm -f types/$(DEPDIR)/libstrace_a-check-loop.Po
+	-rm -f types/$(DEPDIR)/libstrace_a-check-openat2.Po
+	-rm -f types/$(DEPDIR)/libstrace_a-check-rtnl_link.Po
+	-rm -f types/$(DEPDIR)/libstrace_a-check-rtnl_mdb.Po
+	-rm -f types/$(DEPDIR)/libstrace_a-check-rtnl_neightbl.Po
+	-rm -f types/$(DEPDIR)/libstrace_a-check-rtnl_route.Po
+	-rm -f types/$(DEPDIR)/libstrace_a-check-tee.Po
+	-rm -f types/$(DEPDIR)/libstrace_a-check-v4l2.Po
 	-rm -f Makefile
 maintainer-clean-am: distclean-am maintainer-clean-generic
 
@@ -8781,7 +9215,7 @@ uninstall-man: uninstall-man1
 	clean-cscope clean-generic clean-local clean-noinstLIBRARIES \
 	cscope cscopelist-am ctags ctags-am dist dist-all dist-bzip2 \
 	dist-gzip dist-hook dist-lzip dist-shar dist-tarZ dist-xz \
-	dist-zip distcheck distclean distclean-compile \
+	dist-zip dist-zstd distcheck distclean distclean-compile \
 	distclean-generic distclean-hdr distclean-tags distcleancheck \
 	distdir distuninstallcheck dvi dvi-am html html-am info \
 	info-am install install-am install-binPROGRAMS \
@@ -8798,7 +9232,7 @@ uninstall-man: uninstall-man1
 
 .PRECIOUS: Makefile
 
-$(top_srcdir)/xlat/access_flags.h: $(top_srcdir)/xlat/access_flags.in $(top_srcdir)/xlat/gen.sh
+$(top_srcdir)/xlat/access_modes.h: $(top_srcdir)/xlat/access_modes.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/addrfams.h: $(top_srcdir)/xlat/addrfams.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
@@ -8974,6 +9408,8 @@ $(top_srcdir)/xlat/clone3_flags.h: $(top
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/clone_flags.h: $(top_srcdir)/xlat/clone_flags.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/close_range_flags.h: $(top_srcdir)/xlat/close_range_flags.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/cpuclocknames.h: $(top_srcdir)/xlat/cpuclocknames.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/crypto_msgs.h: $(top_srcdir)/xlat/crypto_msgs.in $(top_srcdir)/xlat/gen.sh
@@ -9044,6 +9480,8 @@ $(top_srcdir)/xlat/f_owner_types.h: $(to
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/f_seals.h: $(top_srcdir)/xlat/f_seals.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/faccessat_flags.h: $(top_srcdir)/xlat/faccessat_flags.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/falloc_flags.h: $(top_srcdir)/xlat/falloc_flags.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/fan_classes.h: $(top_srcdir)/xlat/fan_classes.in $(top_srcdir)/xlat/gen.sh
@@ -9098,6 +9536,8 @@ $(top_srcdir)/xlat/getsock_options.h: $(
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/hci_channels.h: $(top_srcdir)/xlat/hci_channels.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/hdio_drive_cmds.h: $(top_srcdir)/xlat/hdio_drive_cmds.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/hw_breakpoint_len.h: $(top_srcdir)/xlat/hw_breakpoint_len.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/hw_breakpoint_type.h: $(top_srcdir)/xlat/hw_breakpoint_type.in $(top_srcdir)/xlat/gen.sh
@@ -9352,6 +9792,8 @@ $(top_srcdir)/xlat/open_access_modes.h:
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/open_mode_flags.h: $(top_srcdir)/xlat/open_mode_flags.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/open_resolve_flags.h: $(top_srcdir)/xlat/open_resolve_flags.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/open_tree_flags.h: $(top_srcdir)/xlat/open_tree_flags.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/packet_diag_attrs.h: $(top_srcdir)/xlat/packet_diag_attrs.in $(top_srcdir)/xlat/gen.sh
@@ -9468,6 +9910,10 @@ $(top_srcdir)/xlat/routing_table_ids.h:
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/routing_types.h: $(top_srcdir)/xlat/routing_types.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/rtc_ioctl_cmds.h: $(top_srcdir)/xlat/rtc_ioctl_cmds.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/rtc_vl_flags.h: $(top_srcdir)/xlat/rtc_vl_flags.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/rtnl_addr_attrs.h: $(top_srcdir)/xlat/rtnl_addr_attrs.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/rtnl_addrlabel_attrs.h: $(top_srcdir)/xlat/rtnl_addrlabel_attrs.in $(top_srcdir)/xlat/gen.sh
@@ -9532,6 +9978,8 @@ $(top_srcdir)/xlat/rtnl_tc_attrs.h: $(to
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/rtnl_tca_act_flags.h: $(top_srcdir)/xlat/rtnl_tca_act_flags.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/rtnl_tca_act_hw_stats.h: $(top_srcdir)/xlat/rtnl_tca_act_hw_stats.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/rtnl_tca_stab_attrs.h: $(top_srcdir)/xlat/rtnl_tca_stab_attrs.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/rtnl_tca_stats_attrs.h: $(top_srcdir)/xlat/rtnl_tca_stats_attrs.in $(top_srcdir)/xlat/gen.sh
@@ -9762,6 +10210,24 @@ $(top_srcdir)/xlat/tcp_states.h: $(top_s
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/tcxonc_options.h: $(top_srcdir)/xlat/tcxonc_options.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/tee_ioctl_cmds.h: $(top_srcdir)/xlat/tee_ioctl_cmds.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/tee_ioctl_gen_caps.h: $(top_srcdir)/xlat/tee_ioctl_gen_caps.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/tee_ioctl_impl_ids.h: $(top_srcdir)/xlat/tee_ioctl_impl_ids.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/tee_ioctl_login_types.h: $(top_srcdir)/xlat/tee_ioctl_login_types.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/tee_ioctl_max_arg_size.h: $(top_srcdir)/xlat/tee_ioctl_max_arg_size.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/tee_ioctl_optee_caps.h: $(top_srcdir)/xlat/tee_ioctl_optee_caps.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/tee_ioctl_origins.h: $(top_srcdir)/xlat/tee_ioctl_origins.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/tee_ioctl_param_attr_types.h: $(top_srcdir)/xlat/tee_ioctl_param_attr_types.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/tee_ioctl_shm_flags.h: $(top_srcdir)/xlat/tee_ioctl_shm_flags.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/timerfdflags.h: $(top_srcdir)/xlat/timerfdflags.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/tun_device_types.h: $(top_srcdir)/xlat/tun_device_types.in $(top_srcdir)/xlat/gen.sh
@@ -9792,8 +10258,14 @@ $(top_srcdir)/xlat/unix_diag_show.h: $(t
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/unshare_flags.h: $(top_srcdir)/xlat/unshare_flags.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/uring_cqring_flags.h: $(top_srcdir)/xlat/uring_cqring_flags.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/uring_enter_flags.h: $(top_srcdir)/xlat/uring_enter_flags.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/uring_op_flags.h: $(top_srcdir)/xlat/uring_op_flags.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/uring_ops.h: $(top_srcdir)/xlat/uring_ops.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/uring_register_opcodes.h: $(top_srcdir)/xlat/uring_register_opcodes.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/uring_setup_features.h: $(top_srcdir)/xlat/uring_setup_features.in $(top_srcdir)/xlat/gen.sh
@@ -9804,6 +10276,12 @@ $(top_srcdir)/xlat/usagewho.h: $(top_src
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/v4l2_buf_flags.h: $(top_srcdir)/xlat/v4l2_buf_flags.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/v4l2_buf_flags_masks.h: $(top_srcdir)/xlat/v4l2_buf_flags_masks.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/v4l2_buf_flags_ts_src.h: $(top_srcdir)/xlat/v4l2_buf_flags_ts_src.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/v4l2_buf_flags_ts_type.h: $(top_srcdir)/xlat/v4l2_buf_flags_ts_type.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/v4l2_buf_types.h: $(top_srcdir)/xlat/v4l2_buf_types.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/v4l2_capture_modes.h: $(top_srcdir)/xlat/v4l2_capture_modes.in $(top_srcdir)/xlat/gen.sh
@@ -9818,6 +10296,8 @@ $(top_srcdir)/xlat/v4l2_control_id_bases
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/v4l2_control_ids.h: $(top_srcdir)/xlat/v4l2_control_ids.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/v4l2_control_query_flags.h: $(top_srcdir)/xlat/v4l2_control_query_flags.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/v4l2_control_types.h: $(top_srcdir)/xlat/v4l2_control_types.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/v4l2_device_capabilities_flags.h: $(top_srcdir)/xlat/v4l2_device_capabilities_flags.in $(top_srcdir)/xlat/gen.sh
@@ -9832,6 +10312,8 @@ $(top_srcdir)/xlat/v4l2_framesize_types.
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/v4l2_input_types.h: $(top_srcdir)/xlat/v4l2_input_types.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/v4l2_ioctl_cmds.h: $(top_srcdir)/xlat/v4l2_ioctl_cmds.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/v4l2_memories.h: $(top_srcdir)/xlat/v4l2_memories.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/v4l2_pix_fmts.h: $(top_srcdir)/xlat/v4l2_pix_fmts.in $(top_srcdir)/xlat/gen.sh
diff -pruN 5.5-3/missing 5.9-0ubuntu2/missing
--- 5.5-3/missing	2020-02-06 16:23:34.000000000 +0000
+++ 5.9-0ubuntu2/missing	2020-09-24 09:18:59.000000000 +0000
@@ -3,7 +3,7 @@
 
 scriptversion=2018-03-07.03; # UTC
 
-# Copyright (C) 1996-2018 Free Software Foundation, Inc.
+# Copyright (C) 1996-2020 Free Software Foundation, Inc.
 # Originally written by Fran,cois Pinard <pinard@iro.umontreal.ca>, 1996.
 
 # This program is free software; you can redistribute it and/or modify
diff -pruN 5.5-3/mmap_cache.c 5.9-0ubuntu2/mmap_cache.c
--- 5.5-3/mmap_cache.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/mmap_cache.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2013 Luca Clementi <luca.clementi@gmail.com>
- * Copyright (c) 2013-2018 The strace developers.
+ * Copyright (c) 2013-2020 The strace developers.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  */
@@ -84,7 +84,7 @@ mmap_cache_rebuild_if_invalid(struct tcb
 		return MMAP_CACHE_REBUILD_READY;
 
 	char filename[sizeof("/proc/4294967296/maps")];
-	xsprintf(filename, "/proc/%u/maps", tcp->pid);
+	xsprintf(filename, "/proc/%u/maps", get_proc_pid(tcp));
 
 	FILE *fp = fopen_stream(filename, "r");
 	if (!fp) {
diff -pruN 5.5-3/mpers.am 5.9-0ubuntu2/mpers.am
--- 5.5-3/mpers.am	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/mpers.am	2020-09-24 09:18:43.000000000 +0000
@@ -1,2 +1,2 @@
 # Generated by ./generate_mpers_am.sh; do not edit.
-mpers_source_files = block.c btrfs.c dirent.c evdev_mpers.c fetch_bpf_fprog.c fetch_struct_flock.c fetch_struct_keyctl_kdf_params.c fetch_struct_mmsghdr.c fetch_struct_msghdr.c fetch_struct_stat.c fetch_struct_stat64.c fetch_struct_statfs.c fetch_struct_xfs_quotastat.c hdio.c ipc_msgctl.c ipc_shmctl.c loop.c mtd.c perf_ioctl.c print_aio_sigset.c print_group_req.c print_mq_attr.c print_msgbuf.c print_sg_req_info.c print_sigevent.c print_time.c print_timespec.c print_timeval.c printrusage.c printsiginfo.c rt_sigreturn.c rtc.c sg_io_v3.c sigaltstack.c sock.c sysinfo.c times.c ustat.c utime.c v4l2.c 
+mpers_source_files = block.c btrfs.c dirent.c evdev_mpers.c fetch_bpf_fprog.c fetch_struct_flock.c fetch_struct_keyctl_kdf_params.c fetch_struct_mmsghdr.c fetch_struct_msghdr.c fetch_struct_stat.c fetch_struct_stat64.c fetch_struct_statfs.c fetch_struct_xfs_quotastat.c hdio.c ipc_msgctl.c ipc_semctl.c ipc_shmctl.c loop.c mtd.c perf_ioctl.c print_aio_sigset.c print_group_req.c print_mq_attr.c print_msgbuf.c print_sg_req_info.c print_sigevent.c print_time.c print_timeval.c printrusage.c printsiginfo.c rt_sigreturn.c rtc.c sg_io_v3.c sigaltstack.c sock.c sysinfo.c times.c ustat.c utime.c v4l2.c 
diff -pruN 5.5-3/mpers_test.sh 5.9-0ubuntu2/mpers_test.sh
--- 5.5-3/mpers_test.sh	2019-03-18 02:40:16.000000000 +0000
+++ 5.9-0ubuntu2/mpers_test.sh	2020-09-23 16:29:35.000000000 +0000
@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2015 Elvira Khabirova <lineprinter0@gmail.com>
 # Copyright (c) 2015 Dmitry V. Levin <ldv@altlinux.org>
-# Copyright (c) 2015-2019 The strace developers.
+# Copyright (c) 2015-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: LGPL-2.1-or-later
@@ -22,6 +22,7 @@ mkdir -p "$mpers_dir"
 
 sample="$mpers_dir/sample.c"
 cat > "$sample" <<EOF
+#include <stdint.h>
 #include "mpers_type.h"
 #include DEF_MPERS_TYPE(sample_struct)
 typedef struct {
@@ -56,6 +57,14 @@ typedef struct {
 		unsigned short us[4];
 		char sc;
 		unsigned char uc;
+		int8_t i8;
+		int16_t i16;
+		int32_t i32;
+		int64_t i64;
+		uint8_t u8;
+		uint16_t u16;
+		uint32_t u32;
+		uint64_t u64;
 	} u[3][2];
 	short f[0];
 } sample_struct;
@@ -103,6 +112,14 @@ int16_t ss[7][9];
 uint16_t us[4];
 char sc;
 unsigned char uc;
+signed char i8;
+int16_t i16;
+int32_t i32;
+int64_t i64;
+unsigned char u8;
+uint16_t u16;
+uint32_t u32;
+uint64_t u64;
 } u[3][2];
 int16_t f[0];
 } ATTRIBUTE_PACKED ${mpers_name}_sample_struct;
diff -pruN 5.5-3/mpers_xlat.h 5.9-0ubuntu2/mpers_xlat.h
--- 5.5-3/mpers_xlat.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/mpers_xlat.h	2020-09-24 09:18:43.000000000 +0000
@@ -26,7 +26,9 @@ extern const struct xlat btrfs_send_flag
 extern const struct xlat btrfs_snap_flags_v2[];
 extern const struct xlat btrfs_space_info_flags[];
 extern const struct xlat btrfs_tree_objectids[];
+extern const struct xlat hdio_drive_cmds[];
 extern const struct xlat msgctl_flags[];
+extern const struct xlat semctl_flags[];
 extern const struct xlat shmctl_flags[];
 extern const struct xlat loop_cmds[];
 extern const struct xlat loop_flags_options[];
@@ -54,6 +56,8 @@ extern const struct xlat sigsegv_codes[]
 extern const struct xlat sigsys_codes[];
 extern const struct xlat sigtrap_codes[];
 extern const struct xlat sigemt_codes[];
+extern const struct xlat rtc_vl_flags[];
+extern const struct xlat rtc_ioctl_cmds[];
 extern const struct xlat sg_io_info[];
 extern const struct xlat sg_io_dxfer_direction[];
 extern const struct xlat sg_io_flags[];
@@ -62,6 +66,7 @@ extern const struct xlat iffflags[];
 extern const struct xlat arp_hardware_types[];
 extern const struct xlat v4l2_pix_fmts[];
 extern const struct xlat v4l2_sdr_fmts[];
+extern const struct xlat v4l2_ioctl_cmds[];
 extern const struct xlat v4l2_device_capabilities_flags[];
 extern const struct xlat v4l2_buf_types[];
 extern const struct xlat v4l2_format_description_flags[];
@@ -71,12 +76,16 @@ extern const struct xlat v4l2_vbi_flags[
 extern const struct xlat v4l2_sliced_flags[];
 extern const struct xlat v4l2_memories[];
 extern const struct xlat v4l2_buf_flags[];
+extern const struct xlat v4l2_buf_flags_ts_type[];
+extern const struct xlat v4l2_buf_flags_ts_src[];
+extern const struct xlat v4l2_buf_flags_masks[];
 extern const struct xlat v4l2_streaming_capabilities[];
 extern const struct xlat v4l2_capture_modes[];
 extern const struct xlat v4l2_input_types[];
 extern const struct xlat v4l2_control_classes[];
 extern const struct xlat v4l2_control_id_bases[];
 extern const struct xlat v4l2_control_ids[];
+extern const struct xlat v4l2_control_query_flags[];
 extern const struct xlat v4l2_tuner_types[];
 extern const struct xlat v4l2_tuner_capabilities[];
 extern const struct xlat v4l2_tuner_rxsubchanses[];
diff -pruN 5.5-3/msghdr.c 5.9-0ubuntu2/msghdr.c
--- 5.5-3/msghdr.c	2019-05-17 16:16:29.000000000 +0000
+++ 5.9-0ubuntu2/msghdr.c	2020-08-25 14:29:30.000000000 +0000
@@ -4,7 +4,7 @@
  * Copyright (c) 1993, 1994, 1995, 1996 Rick Sladkey <jrs@world.std.com>
  * Copyright (c) 1996-2000 Wichert Akkerman <wichert@cistron.nl>
  * Copyright (c) 2005-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -69,7 +69,7 @@ print_scm_creds(struct tcb *tcp, const v
 {
 	const struct ucred *uc = cmsg_data;
 
-	PRINT_FIELD_U("{", *uc, pid);
+	PRINT_FIELD_TGID("{", *uc, pid, tcp);
 	PRINT_FIELD_UID(", ", *uc, uid);
 	PRINT_FIELD_UID(", ", *uc, gid);
 	tprints("}");
@@ -89,18 +89,37 @@ print_scm_timestamp_old(struct tcb *tcp,
 	print_struct_timeval_data_size(cmsg_data, data_len);
 }
 
+#ifdef current_klongsize
+# if current_klongsize == 4
+#  define PRINT_TIMESPEC_DATA_SIZE print_timespec32_data_size
+#  define PRINT_TIMESPEC_ARRAY_DATA_SIZE print_timespec32_array_data_size
+# else
+#  define PRINT_TIMESPEC_DATA_SIZE print_timespec64_data_size
+#  define PRINT_TIMESPEC_ARRAY_DATA_SIZE print_timespec64_array_data_size
+# endif
+#else
+# define PRINT_TIMESPEC_DATA_SIZE			\
+	((current_klongsize == 4) ?			\
+		print_timespec32_data_size :		\
+		print_timespec64_data_size)
+# define PRINT_TIMESPEC_ARRAY_DATA_SIZE			\
+	((current_klongsize == 4) ?			\
+		print_timespec32_array_data_size :	\
+		print_timespec64_array_data_size)
+#endif
+
 static void
 print_scm_timestampns_old(struct tcb *tcp, const void *cmsg_data,
 			  const unsigned int data_len)
 {
-	print_struct_timespec_data_size(cmsg_data, data_len);
+	PRINT_TIMESPEC_DATA_SIZE(cmsg_data, data_len);
 }
 
 static void
 print_scm_timestamping_old(struct tcb *tcp, const void *cmsg_data,
 			   const unsigned int data_len)
 {
-	print_struct_timespec_array_data_size(cmsg_data, 3, data_len);
+	PRINT_TIMESPEC_ARRAY_DATA_SIZE(cmsg_data, 3, data_len);
 }
 
 static void
@@ -197,7 +216,7 @@ print_cmsg_ip_recverr(struct tcb *tcp, c
 	PRINT_FIELD_U(", ", *err, ee_code);
 	PRINT_FIELD_U(", ", *err, ee_info);
 	PRINT_FIELD_U(", ", *err, ee_data);
-	PRINT_FIELD_SOCKADDR(", ", *err, offender);
+	PRINT_FIELD_SOCKADDR(", ", *err, offender, tcp);
 	tprints("}");
 }
 
@@ -209,7 +228,7 @@ print_cmsg_ip_origdstaddr(struct tcb *tc
 		data_len > sizeof(struct sockaddr_storage)
 		? sizeof(struct sockaddr_storage) : data_len;
 
-	print_sockaddr(cmsg_data, addr_len);
+	print_sockaddr(tcp, cmsg_data, addr_len);
 }
 
 typedef void (* const cmsg_printer)(struct tcb *, const void *, unsigned int);
@@ -274,7 +293,7 @@ get_optmem_max(struct tcb *tcp)
 	static int optmem_max;
 
 	if (!optmem_max) {
-		if (read_int_from_file(tcp, "/proc/sys/net/core/optmem_max",
+		if (read_int_from_file("/proc/sys/net/core/optmem_max",
 				       &optmem_max) || optmem_max <= 0) {
 			optmem_max = sizeof(long long) * (2 * IOV_MAX + 512);
 		} else {
diff -pruN 5.5-3/net.c 5.9-0ubuntu2/net.c
--- 5.5-3/net.c	2019-08-14 11:22:32.000000000 +0000
+++ 5.9-0ubuntu2/net.c	2020-08-25 14:29:30.000000000 +0000
@@ -3,7 +3,7 @@
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995, 1996 Rick Sladkey <jrs@world.std.com>
  * Copyright (c) 1996-2000 Wichert Akkerman <wichert@cistron.nl>
- * Copyright (c) 1999-2019 The strace developers.
+ * Copyright (c) 1999-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -579,24 +579,8 @@ print_get_linger(struct tcb *const tcp,
 	if (umoven_or_printaddr(tcp, addr, len, &linger))
 		return;
 
-	if (len < sizeof(linger.l_onoff)) {
-		tprints("{l_onoff=");
-		print_quoted_string((void *) &linger.l_onoff,
-				    len, QUOTE_FORCE_HEX);
-	} else {
-		PRINT_FIELD_D("{", linger, l_onoff);
-
-		if (len > offsetof(struct linger, l_linger)) {
-			len -= offsetof(struct linger, l_linger);
-			if (len < sizeof(linger.l_linger)) {
-				tprints(", l_linger=");
-				print_quoted_string((void *) &linger.l_linger,
-						    len, QUOTE_FORCE_HEX);
-			} else {
-				PRINT_FIELD_D(", ", linger, l_linger);
-			}
-		}
-	}
+	PRINT_FIELD_LEN("{", linger, l_onoff, len, PRINT_FIELD_D);
+	PRINT_FIELD_LEN(", ", linger, l_linger, len, PRINT_FIELD_D);
 	tprints("}");
 }
 
@@ -617,38 +601,9 @@ print_get_ucred(struct tcb *const tcp, c
 	if (umoven_or_printaddr(tcp, addr, len, &uc))
 		return;
 
-	if (len < sizeof(uc.pid)) {
-		tprints("{pid=");
-		print_quoted_string((void *) &uc.pid,
-				    len, QUOTE_FORCE_HEX);
-	} else {
-		PRINT_FIELD_D("{", uc, pid);
-
-		if (len > offsetof(struct ucred, uid)) {
-			len -= offsetof(struct ucred, uid);
-			if (len < sizeof(uc.uid)) {
-				tprints(", uid=");
-				print_quoted_string((void *) &uc.uid,
-						    len, QUOTE_FORCE_HEX);
-			} else {
-				PRINT_FIELD_UID(", ", uc, uid);
-
-				if (len > offsetof(struct ucred, gid) -
-					  offsetof(struct ucred, uid)) {
-					len -= offsetof(struct ucred, gid) -
-					       offsetof(struct ucred, uid);
-					if (len < sizeof(uc.gid)) {
-						tprints(", gid=");
-						print_quoted_string((void *) &uc.gid,
-								    len,
-								    QUOTE_FORCE_HEX);
-					} else {
-						PRINT_FIELD_UID(", ", uc, gid);
-					}
-				}
-			}
-		}
-	}
+	PRINT_FIELD_LEN("{", uc, pid, len, PRINT_FIELD_TGID, tcp);
+	PRINT_FIELD_LEN(", ", uc, uid, len, PRINT_FIELD_UID);
+	PRINT_FIELD_LEN(", ", uc, gid, len, PRINT_FIELD_UID);
 	tprints("}");
 }
 
@@ -688,38 +643,9 @@ print_tpacket_stats(struct tcb *const tc
 	if (umoven_or_printaddr(tcp, addr, len, &stats))
 		return;
 
-	if (len < sizeof(stats.tp_packets)) {
-		tprints("{tp_packets=");
-		print_quoted_string((void *) &stats.tp_packets,
-				    len, QUOTE_FORCE_HEX);
-	} else {
-		PRINT_FIELD_U("{", stats, tp_packets);
-
-		if (len > offsetof(struct tp_stats, tp_drops)) {
-			len -= offsetof(struct tp_stats, tp_drops);
-			if (len < sizeof(stats.tp_drops)) {
-				tprints(", tp_drops=");
-				print_quoted_string((void *) &stats.tp_drops,
-						    len, QUOTE_FORCE_HEX);
-			} else {
-				PRINT_FIELD_U(", ", stats, tp_drops);
-
-				if (len > offsetof(struct tp_stats, tp_freeze_q_cnt) -
-					  offsetof(struct tp_stats, tp_drops)) {
-					len -= offsetof(struct tp_stats, tp_freeze_q_cnt) -
-					       offsetof(struct tp_stats, tp_drops);
-					if (len < sizeof(stats.tp_freeze_q_cnt)) {
-						tprints(", tp_freeze_q_cnt=");
-						print_quoted_string((void *) &stats.tp_freeze_q_cnt,
-								    len,
-								    QUOTE_FORCE_HEX);
-					} else {
-						PRINT_FIELD_U(", ", stats, tp_freeze_q_cnt);
-					}
-				}
-			}
-		}
-	}
+	PRINT_FIELD_LEN("{", stats, tp_packets, len, PRINT_FIELD_U);
+	PRINT_FIELD_LEN(", ", stats, tp_drops, len, PRINT_FIELD_U);
+	PRINT_FIELD_LEN(", ", stats, tp_freeze_q_cnt, len, PRINT_FIELD_U);
 	tprints("}");
 }
 #endif /* PACKET_STATISTICS */
diff -pruN 5.5-3/netlink.c 5.9-0ubuntu2/netlink.c
--- 5.5-3/netlink.c	2019-11-28 19:30:05.000000000 +0000
+++ 5.9-0ubuntu2/netlink.c	2020-08-25 14:29:30.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2016 Fabien Siron <fabien.siron@epita.fr>
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -40,9 +40,9 @@
 #include "xlat/nl_xfrm_types.h"
 #include "xlat/nlmsgerr_attrs.h"
 
-# define XLAT_MACROS_ONLY
-#  include "xlat/crypto_msgs.h"
-# undef XLAT_MACROS_ONLY
+#define XLAT_MACROS_ONLY
+# include "xlat/crypto_msgs.h"
+#undef XLAT_MACROS_ONLY
 
 /*
  * Fetch a struct nlmsghdr from the given address.
@@ -446,8 +446,9 @@ print_nlmsghdr(struct tcb *tcp,
 	decode_nlmsg_flags(nlmsghdr->nlmsg_flags,
 			   nlmsghdr->nlmsg_type, family);
 
-	tprintf(", seq=%u, pid=%u}", nlmsghdr->nlmsg_seq,
-		nlmsghdr->nlmsg_pid);
+	tprintf(", seq=%u, pid=", nlmsghdr->nlmsg_seq);
+	printpid(tcp, nlmsghdr->nlmsg_pid, PT_TGID);
+	tprints("}");
 }
 
 static bool
diff -pruN 5.5-3/NEWS 5.9-0ubuntu2/NEWS
--- 5.5-3/NEWS	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/NEWS	2020-09-24 08:00:00.000000000 +0000
@@ -1,3 +1,132 @@
+Noteworthy changes in release 5.9 (2020-09-24)
+==============================================
+
+* Improvements
+  * Added -n/--syscall-number option for printing syscall numbers.
+  * Added --pidns-translation option for PID namespace translation (addresses
+    Fedora bug #1035433).
+  * Implemented decoding of close_range syscall.
+  * Implemented decoding of TEE_* ioctl commands.
+  * Implemented decoding of struct msginfo argument of IPC_INFO
+    and MSG_INFO msgctl syscall commands.
+  * Implemented decoding of struct msqid_ds argument of MSG_STAT
+    and MSG_STAT_ANY msgctl syscall commands.
+  * Implemented decoding of struct seminfo argument of IPC_INFO
+    and SEM_INFO semctl syscall commands.
+  * Implemented decoding of struct semid_ds argument of IPC_SET,
+    IPC_STAT, SEM_STAT, and SEM_STAT_ANY semctl syscall commands.
+  * Implemented decoding of struct shminfo argument of IPC_INFO
+    shmctl syscall command.
+  * Implemented decoding of struct shm_info argument of SHM_INFO
+    shmctl syscall command.
+  * Implemented decoding of struct shmid_ds argument of SHM_STAT
+    and SHM_STAT_ANY shmctl syscall commands.
+  * Updated lists of BPF_*, CAP_*, FAN_*, IFLA_*, INET_DIAG_REQ_*,
+    IORING_FEAT_*, IP_*, IPV6_*, KVM_*, NDA_*, PTP_PEROUT_*, RTPROT_*,
+    and V4L2_FMT_FLAG_* constants.
+  * Updated lists of ioctl commands from Linux 5.9.
+
+Noteworthy changes in release 5.8 (2020-08-06)
+==============================================
+
+* Changes in behaviour
+  * Modified %process class to contain system calls associated with
+    process lifecycle (creation, exec, termination):
+    kill, tkill, tgkill, pidfd_send_signal and rt_sigqueueinfo are added,
+    arch_prctl and unshare are removed.
+
+* Improvements
+  * Implemented decoding of faccessat2 syscall.
+  * Implemented decoding of LOOP_CONFIGURE ioctl command.
+  * Updated decoding of io_uring_setup syscall to match Linux 5.8.
+  * Updated lists of AUDIT_*, BPF_*, CAP_*, ETH_*, INET_DIAG_*, IORING_*,
+    KEYCTL_*, KVM_*, LOOP_*, NDA_*, RTC_*, TCA_*, STATX_*, and *_MAGIC
+    constants.
+  * Updated lists of ioctl commands from Linux 5.8.
+
+* Bug fixes
+  * Added statx syscall to %fstat trace class.
+
+Noteworthy changes in release 5.7 (2020-06-01)
+==============================================
+
+* Improvements
+  * Implemented interval specification in "when=" subexpression of syscall
+    tampering expressions.
+  * Added -e trace=%clock option for tracing syscalls reading of modifying
+    system clocks.
+  * Implemented decoding of BPF_LINK_CREATE and BPF_LINK_UPDATE bpf
+    syscall commands.
+  * Updated decoding of clone3 syscall to match Linux 5.7.
+  * Updated lists of BPF_*, BTRFS_*, CLONE_*, FAN_*, IORING_*, KVM_*,
+    LWTUNNEL_*, MREMAP_*, PERF_*, SECCOMP_*, UFFDIO_*, V4L2_*, and XDP_*
+    constants.
+  * Updated lists of ioctl commands from Linux 5.7.
+
+* Bug fixes
+  * Fixed decoding of getdents and getdents64 syscalls when they return
+    a lot of directory entries.
+  * Fixed pathtrace matching of openat2 syscall.
+  * Fixed build on systems without fork.
+
+Noteworthy changes in release 5.6 (2020-04-07)
+==============================================
+
+* Changes in behaviour
+  * Messages about unknown tracees are now subject to the strace's quietness
+    setting (-q/--quiet).
+  * If -A option is provided without -o, or -S option without -c/-C, a warning
+    about its uselessness is printed now.
+  * The usage of --seccomp-bpf without -f has no effect now.
+
+* Improvements
+  * Every short option now has a long option alias, which also has enabled
+    the following improvements:
+    * Ability to use human-readable settings for -I/--interruptible,
+      -D/--daemonize options.
+    * Ability to silence specific messages using -e quiet/--quiet qualifier
+      (an alias for the -q option), including those that couldn't be silenced
+      previously (path resolution messages and "superseded by execve").
+    * Ability to specify selected fd decoding features using
+      -e decode-fds/--decode-fds qualifier (an alias for the -y option).
+    * Ability to set precision for the absolute timestamp, relative timestamp,
+      and syscall time output (using --absolute-timestamps,
+      --relative-timestamps, and --syscall-times options, respectively).
+  * Implemented ability to select the set of displayed columns in the call
+    summary output (-U/--summary-columns option).
+  * Implemented ability to sort on any summary column.
+  * Implemented ability to show information about minimum and maximum call
+    duration in the call summary output (addresses Debian bug #240945).
+  * Implemented printing of PIDs associated with pidfds in -yy mode.
+  * Implemented PTRACE_GETREGS API support on hppa, sh, sh64, and xtensa.
+  * Improved performance of libdw-based stack traces printing by implementing
+    a symbol-to-address cache.
+  * Implemented decoding of openat2 and pidfd_getfd syscalls.
+  * Enhanced io_uring_register, prctl, sched_getattr, and sched_setattr syscall
+    decoding.
+  * Implemented decoding of BPF_MAP_LOOKUP_BATCH,
+    BPF_MAP_LOOKUP_AND_DELETE_BATCH, BPF_MAP_UPDATE_BATCH, and
+    BPF_MAP_DELETE_BATCH bpf syscall commands.
+  * Enhanced decoding of BPF_MAP_CREATE and BPF_PROG_ATTACH bpf syscall
+    commands.
+  * Enhanced decoding of RTC_VL_READ ioctl command.
+  * Enhanced decoding of IFLA_* netlink attributes.
+  * Implemented HIDIOCGRAWUNIQ() ioctl command number printing.
+  * Wired up kexec_file_load syscall on hppa.
+  * Updated lists of AUDIT_*, BPF_*, CLONE_*, GRND_*, IFLA_*, IORING_*,
+    IPPROTO_*, KEY_*, KVM_*, RTM_F_*, SCHED_*, and *_MAGIC constants.
+  * Updated lists of ioctl commands from Linux 5.6.
+
+* Bug fixes
+  * Fixed build on csky abiv1 architecture.
+  * Various minor fixes in VIDIOC_* ioctl output formatting.
+  * Fix printing of the size field for _IOC_NONE ioctl command numbers on sparc.
+
+* Portability
+  * On hppa, linux kernel >= 4.7 is required.
+    On sh and sh64, linux kernel >= 2.6.28 is required.
+    Older versions without a decent PTRACE_GETREGS support will not work.
+
 Noteworthy changes in release 5.5 (2020-02-06)
 ==============================================
 
@@ -65,7 +194,7 @@ Noteworthy changes in release 5.3 (2019-
   * Enhanced decoding of NETLINK_ROUTE protocol.
   * Implemented decoding of UNIX_DIAG_UID netlink attribute.
   * Implemented decoding of WDIOC_* ioctl commands.
-  * Enchanced syscall count statistics: overhead is now applied per-call,
+  * Enhanced syscall count statistics: overhead is now applied per-call,
     added ability for sorting on errors field.
   * Syscall delay injection and overhead values can now be supplied with
     time measure unit suffix and provided in IEEE 754 floating point format.
diff -pruN 5.5-3/nlattr.c 5.9-0ubuntu2/nlattr.c
--- 5.5-3/nlattr.c	2019-07-24 17:12:18.000000000 +0000
+++ 5.9-0ubuntu2/nlattr.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2016 Fabien Siron <fabien.siron@epita.fr>
  * Copyright (c) 2017 JingPiao Chen <chenjingpiao@gmail.com>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -165,7 +165,8 @@ decode_nla_str(struct tcb *const tcp,
 	       const unsigned int len,
 	       const void *const opaque_data)
 {
-	printstr_ex(tcp, addr, len, QUOTE_0_TERMINATED);
+	printstr_ex(tcp, addr, len,
+		    QUOTE_OMIT_TRAILING_0 | QUOTE_EXPECT_TRAILING_0);
 
 	return true;
 }
@@ -332,6 +333,26 @@ decode_nla_ip_proto(struct tcb *const tc
 }
 
 bool
+decode_nla_hwaddr(struct tcb *const tcp,
+		const kernel_ulong_t addr,
+		const unsigned int len,
+		const void *const opaque_data)
+{
+	if (len > MAX_ADDR_LEN)
+		return false;
+
+	uint8_t buf[len];
+	const uintptr_t arphrd = (uintptr_t) opaque_data;
+
+	if (!umoven_or_printaddr(tcp, addr, len, buf)) {
+		print_hwaddr("", buf, len, arphrd & NLA_HWADDR_FAMILY_OFFSET
+				? arphrd & ~NLA_HWADDR_FAMILY_OFFSET : -1U);
+	}
+
+	return true;
+}
+
+bool
 decode_nla_in_addr(struct tcb *const tcp,
 		   const kernel_ulong_t addr,
 		   const unsigned int len,
diff -pruN 5.5-3/nlattr.h 5.9-0ubuntu2/nlattr.h
--- 5.5-3/nlattr.h	2019-07-24 17:12:18.000000000 +0000
+++ 5.9-0ubuntu2/nlattr.h	2020-04-03 22:58:26.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2016 Fabien Siron <fabien.siron@epita.fr>
  * Copyright (c) 2017 JingPiao Chen <chenjingpiao@gmail.com>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -87,4 +87,34 @@ DECL_NLA(rt_class);
 DECL_NLA(rt_proto);
 DECL_NLA(tc_stats);
 
+# define NLA_HWADDR_FAMILY_OFFSET 1024
+
+/**
+ * Print hardware (low-level, L2) address.
+ * @param opaque_data Interpreted as integer value, not pointer
+ */
+DECL_NLA(hwaddr);
+
+/** Non-standard decoder that accepts ARPHRD_* value as an argument */
+static inline bool
+decode_nla_hwaddr_family(struct tcb *const tcp,
+		const kernel_ulong_t addr,
+		const unsigned int len,
+		const unsigned int arphrd)
+{
+	return decode_nla_hwaddr(tcp, addr, len, (void *) (uintptr_t) (
+				 arphrd > NLA_HWADDR_FAMILY_OFFSET ? 0
+					: NLA_HWADDR_FAMILY_OFFSET | arphrd));
+}
+
+/** decode_nla_hwaddr wrapper that ignores opaque_data */
+static inline bool
+decode_nla_hwaddr_nofamily(struct tcb *const tcp,
+		const kernel_ulong_t addr,
+		const unsigned int len,
+		const void *const opaque_data)
+{
+	return decode_nla_hwaddr(tcp, addr, len, NULL);
+}
+
 #endif /* !STRACE_NLATTR_H */
diff -pruN 5.5-3/numa.c 5.9-0ubuntu2/numa.c
--- 5.5-3/numa.c	2019-08-14 11:22:32.000000000 +0000
+++ 5.9-0ubuntu2/numa.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2003-2007 Ulrich Drepper <drepper@redhat.com>
  * Copyright (c) 2005-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -44,7 +44,8 @@ print_nodemask(struct tcb *const tcp, co
 
 SYS_FUNC(migrate_pages)
 {
-	tprintf("%d, %" PRI_klu ", ", (int) tcp->u_arg[0], tcp->u_arg[1]);
+	printpid(tcp, tcp->u_arg[0], PT_TGID);
+	tprintf(", %" PRI_klu ", ", tcp->u_arg[1]);
 	print_nodemask(tcp, tcp->u_arg[2], tcp->u_arg[1]);
 	tprints(", ");
 	print_nodemask(tcp, tcp->u_arg[3], tcp->u_arg[1]);
@@ -170,7 +171,8 @@ SYS_FUNC(move_pages)
 	kernel_ulong_t buf;
 
 	if (entering(tcp)) {
-		tprintf("%d, %" PRI_klu ", ", (int) tcp->u_arg[0], npages);
+		printpid(tcp, tcp->u_arg[0], PT_TGID);
+		tprintf(", %" PRI_klu ", ", npages);
 		print_array(tcp, tcp->u_arg[2], npages, &buf, current_wordsize,
 			    tfetch_mem, print_addr, 0);
 		tprints(", ");
diff -pruN 5.5-3/number_set.h 5.9-0ubuntu2/number_set.h
--- 5.5-3/number_set.h	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/number_set.h	2020-04-05 13:28:30.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -56,10 +56,39 @@ enum status_t {
 	NUMBER_OF_STATUSES
 };
 
+enum quiet_bits {
+	/** Do not print messages on tracee attach/detach. */
+	QUIET_ATTACH,
+	/** Do not print messages on tracee exits. */
+	QUIET_EXIT,
+	/** Do not print messages about path tracing path resolution. */
+	QUIET_PATH_RESOLVE,
+	/** Do not print messages on personality change. */
+	QUIET_PERSONALITY,
+	/** Do not print messages on superseding execve. */
+	QUIET_THREAD_EXECVE,
+
+	NUM_QUIET_BITS
+};
+
+enum decode_fd_bits {
+	DECODE_FD_PATH,
+	DECODE_FD_SOCKET,
+	DECODE_FD_DEV,
+	DECODE_FD_PIDFD,
+
+	NUM_DECODE_FD_BITS
+};
+
+extern bool quiet_set_updated;
+extern bool decode_fd_set_updated;
+
 extern struct number_set *read_set;
 extern struct number_set *write_set;
 extern struct number_set *signal_set;
 extern struct number_set *status_set;
+extern struct number_set *quiet_set;
+extern struct number_set *decode_fd_set;
 extern struct number_set *trace_set;
 
 #endif /* !STRACE_NUMBER_SET_H */
diff -pruN 5.5-3/open.c 5.9-0ubuntu2/open.c
--- 5.5-3/open.c	2019-07-18 13:58:07.000000000 +0000
+++ 5.9-0ubuntu2/open.c	2020-07-18 08:00:00.000000000 +0000
@@ -7,7 +7,7 @@
  * Copyright (c) 2006-2007 Ulrich Drepper <drepper@redhat.com>
  * Copyright (c) 2009-2013 Denys Vlasenko <dvlasenk@redhat.com>
  * Copyright (c) 2005-2015 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2014-2019 The strace developers.
+ * Copyright (c) 2014-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -18,6 +18,10 @@
 
 #include <asm/fcntl.h>
 
+#include "print_fields.h"
+
+#include "types/openat2.h"
+
 /* some libcs are guilty of messing up with O_ACCMODE */
 #undef O_ACCMODE
 #define O_ACCMODE 03
@@ -30,6 +34,7 @@
 
 #include "xlat/open_access_modes.h"
 #include "xlat/open_mode_flags.h"
+#include "xlat/open_resolve_flags.h"
 
 #ifndef AT_FDCWD
 # define AT_FDCWD	-100
@@ -51,8 +56,8 @@ print_dirfd(struct tcb *tcp, int fd)
  * low bits of the open(2) flags define access mode,
  * other bits are real flags.
  */
-const char *
-sprint_open_modes(unsigned int flags)
+static const char *
+sprint_open_modes64(uint64_t flags)
 {
 	static char outstr[sizeof("flags O_ACCMODE")];
 	char *p;
@@ -76,11 +81,22 @@ sprint_open_modes(unsigned int flags)
 			      XLAT_STYLE_ABBREV) ?: outstr;
 }
 
+const char *
+sprint_open_modes(unsigned int flags)
+{
+	return sprint_open_modes64(flags);
+}
+
+static void
+tprint_open_modes64(uint64_t flags)
+{
+	print_xlat_ex(flags, sprint_open_modes64(flags) + sizeof("flags"),
+		      XLAT_STYLE_DEFAULT);
+}
 void
 tprint_open_modes(unsigned int flags)
 {
-	print_xlat_ex(flags, sprint_open_modes(flags) + sizeof("flags"),
-		      XLAT_STYLE_DEFAULT);
+	tprint_open_modes64(flags);
 }
 
 static int
@@ -104,6 +120,35 @@ SYS_FUNC(open)
 	return decode_open(tcp, 0);
 }
 
+static void
+print_open_how(struct tcb *tcp, kernel_ulong_t addr, kernel_ulong_t size)
+{
+	enum { OPEN_HOW_MIN_SIZE = 24 };
+
+	struct_open_how how;
+
+	if (size < OPEN_HOW_MIN_SIZE) {
+		printaddr(addr);
+		return;
+	}
+	if (umoven_or_printaddr(tcp, addr, MIN(size, sizeof(how)), &how))
+		return;
+
+	tprints("{flags=");
+	tprint_open_modes64(how.flags);
+	if ((how.flags & (O_CREAT| __O_TMPFILE)) || how.mode)
+		PRINT_FIELD_NUMERIC_UMODE_T(", ", how, mode);
+	PRINT_FIELD_FLAGS(", ", how, resolve, open_resolve_flags,
+			  "RESOLVE_???");
+
+	if (size > sizeof(how)) {
+		print_nonzero_bytes(tcp, ", ", addr, sizeof(how),
+				    MIN(size, get_pagesize()), QUOTE_FORCE_HEX);
+	}
+
+	tprints("}");
+}
+
 SYS_FUNC(openat)
 {
 	print_dirfd(tcp, tcp->u_arg[0]);
@@ -111,6 +156,18 @@ SYS_FUNC(openat)
 	return decode_open(tcp, 1);
 }
 
+SYS_FUNC(openat2)
+{
+	print_dirfd(tcp, tcp->u_arg[0]);
+	tprints(", ");
+	printpath(tcp, tcp->u_arg[1]);
+	tprints(", ");
+	print_open_how(tcp, tcp->u_arg[2], tcp->u_arg[3]);
+	tprintf(", %" PRI_klu, tcp->u_arg[3]);
+
+	return RVAL_DECODED | RVAL_FD;
+}
+
 SYS_FUNC(creat)
 {
 	printpath(tcp, tcp->u_arg[0]);
diff -pruN 5.5-3/pathtrace.c 5.9-0ubuntu2/pathtrace.c
--- 5.5-3/pathtrace.c	2019-08-15 11:54:22.000000000 +0000
+++ 5.9-0ubuntu2/pathtrace.c	2020-09-06 08:00:00.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2011 Comtrol Corp.
- * Copyright (c) 2011-2019 The strace developers.
+ * Copyright (c) 2011-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -11,6 +11,7 @@
 #include <limits.h>
 #include <poll.h>
 
+#include "number_set.h"
 #include "syscall.h"
 #include "xstring.h"
 
@@ -75,10 +76,10 @@ storepath(const char *path, struct path_
 }
 
 /*
- * Get path associated with fd.
+ * Get path associated with fd of a process with pid.
  */
 int
-getfdpath(struct tcb *tcp, int fd, char *buf, unsigned bufsize)
+getfdpath_pid(pid_t pid, int fd, char *buf, unsigned bufsize)
 {
 	char linkpath[sizeof("/proc/%u/fd/%u") + 2 * sizeof(int)*3];
 	ssize_t n;
@@ -86,7 +87,12 @@ getfdpath(struct tcb *tcp, int fd, char
 	if (fd < 0)
 		return -1;
 
-	xsprintf(linkpath, "/proc/%u/fd/%u", tcp->pid, fd);
+	int proc_pid = 0;
+	translate_pid(NULL, pid, PT_TID, &proc_pid);
+	if (!proc_pid)
+		return -1;
+
+	xsprintf(linkpath, "/proc/%u/fd/%u", proc_pid, fd);
 	n = readlink(linkpath, buf, bufsize - 1);
 	/*
 	 * NB: if buf is too small, readlink doesn't fail,
@@ -119,7 +125,21 @@ pathtrace_select_set(const char *path, s
 		return;
 	}
 
-	error_msg("Requested path '%s' resolved into '%s'", path, rpath);
+	if (!is_number_in_set(QUIET_PATH_RESOLVE, quiet_set)) {
+		char *path_quoted = xmalloc(strlen(path) * 4 + 4);
+		char *rpath_quoted = xmalloc(strlen(rpath) * 4 + 4);
+
+		string_quote(path, path_quoted, strlen(path) + 1,
+			     QUOTE_0_TERMINATED, NULL);
+		string_quote(rpath, rpath_quoted, strlen(rpath) + 1,
+			     QUOTE_0_TERMINATED, NULL);
+
+		error_msg("Requested path %s resolved into %s",
+			  path_quoted, rpath_quoted);
+
+		free(path_quoted);
+		free(rpath_quoted);
+	}
 	storepath(rpath, set);
 }
 
@@ -178,6 +198,7 @@ pathtrace_match_set(struct tcb *tcp, str
 	 */
 
 	switch (s->sen) {
+	case SEN_close_range:
 	case SEN_dup2:
 	case SEN_dup3:
 	case SEN_kexec_file_load:
@@ -190,6 +211,7 @@ pathtrace_match_set(struct tcb *tcp, str
 
 	case SEN_execveat:
 	case SEN_faccessat:
+	case SEN_faccessat2:
 	case SEN_fchmodat:
 	case SEN_fchownat:
 	case SEN_fspick:
@@ -202,6 +224,7 @@ pathtrace_match_set(struct tcb *tcp, str
 	case SEN_newfstatat:
 	case SEN_open_tree:
 	case SEN_openat:
+	case SEN_openat2:
 	case SEN_readlinkat:
 	case SEN_statx:
 	case SEN_unlinkat:
diff -pruN 5.5-3/perf_ioctl.c 5.9-0ubuntu2/perf_ioctl.c
--- 5.5-3/perf_ioctl.c	2018-12-30 15:35:21.000000000 +0000
+++ 5.9-0ubuntu2/perf_ioctl.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -90,7 +90,7 @@ MPERS_PRINTER_DECL(int, perf_ioctl,
 
 	case PERF_EVENT_IOC_SET_OUTPUT:
 	case PERF_EVENT_IOC_SET_BPF:
-		tprintf(", ");
+		tprints(", ");
 		printfd(tcp, (int) arg);
 
 		return RVAL_IOCTL_DECODED;
diff -pruN 5.5-3/pidfd_getfd.c 5.9-0ubuntu2/pidfd_getfd.c
--- 5.5-3/pidfd_getfd.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/pidfd_getfd.c	2020-05-30 08:00:00.000000000 +0000
@@ -0,0 +1,31 @@
+/*
+ * pidfd_getfd() syscall decoder.
+ *
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
+#include "defs.h"
+#include "number_set.h"
+
+SYS_FUNC(pidfd_getfd)
+{
+	int pidfd = (int) tcp->u_arg[0];
+	int targetfd = (int) tcp->u_arg[1];
+	unsigned int flags = (unsigned int) tcp->u_arg[2];
+
+	printfd(tcp, pidfd);
+	tprints(", ");
+
+	pid_t target_pid = pidfd_get_pid(tcp->pid, pidfd);
+	if (target_pid > 0)
+		printfd_pid(tcp, target_pid, targetfd);
+	else
+		tprintf("%d", targetfd);
+
+	tprintf(", %#x", flags);
+
+	return RVAL_DECODED | RVAL_FD;
+}
diff -pruN 5.5-3/pidfd_open.c 5.9-0ubuntu2/pidfd_open.c
--- 5.5-3/pidfd_open.c	2019-08-15 11:54:22.000000000 +0000
+++ 5.9-0ubuntu2/pidfd_open.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,5 +1,6 @@
 /*
  * Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2019-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -10,7 +11,7 @@
 SYS_FUNC(pidfd_open)
 {
 	/* pid_t pid */
-	tprintf("%d", (int) tcp->u_arg[0]);
+	printpid(tcp, tcp->u_arg[0], PT_TGID);
 
 	/* unsigned int flags */
 	tprintf(", %#x", (unsigned int) tcp->u_arg[1]);
diff -pruN 5.5-3/pidns.c 5.9-0ubuntu2/pidns.c
--- 5.5-3/pidns.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/pidns.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,608 @@
+/*
+ * Copyright (c) 2020 Ákos Uzonyi <uzonyi.akos@gmail.com>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
+#include "defs.h"
+
+
+#include <dirent.h>
+#include <fcntl.h>
+#include <stdint.h>
+#include <string.h>
+#include <unistd.h>
+
+#include <asm/unistd.h>
+
+#include <sys/ioctl.h>
+#include <sys/param.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+
+#include "largefile_wrappers.h"
+#include "trie.h"
+#include "nsfs.h"
+#include "xmalloc.h"
+#include "xstring.h"
+
+/**
+ * Key:   PID NS ID
+ * Value: a btree:
+ *           Key:   a process PID in NS
+ *           Value: the process's PID as present in /proc
+ */
+static struct trie *ns_pid_to_proc_pid[PT_COUNT];
+
+/**
+ * Key:   Proc PID
+ * Value: struct proc_data
+ */
+static struct trie *proc_data_cache;
+
+static bool ns_get_parent_enotty = false;
+
+static const char tid_str[]  = "NSpid:\t";
+static const char tgid_str[] = "NStgid:\t";
+static const char pgid_str[] = "NSpgid:\t";
+static const char sid_str[]  = "NSsid:\t";
+
+static const struct {
+	const char *str;
+	size_t size;
+} id_strs[PT_COUNT] = {
+	[PT_TID] =  { tid_str,  sizeof(tid_str)  - 1 },
+	[PT_TGID] = { tgid_str, sizeof(tgid_str) - 1 },
+	[PT_PGID] = { pgid_str, sizeof(pgid_str) - 1 },
+	[PT_SID] =  { sid_str,  sizeof(sid_str)  - 1 },
+};
+
+
+/**
+ * Limit on PID NS hierarchy depth, imposed since Linux 3.7. NS traversal
+ * is not possible before Linux 4.9, so we consider this limit pretty universal.
+ */
+#define MAX_NS_DEPTH 32
+
+static const size_t ns_id_size = sizeof(unsigned int) * 8;
+static const uint8_t ptr_sz_lg = (sizeof(void *) == 8 ? 6 : 5);
+
+static int pid_max;
+static uint8_t pid_max_size, pid_max_size_lg;
+
+struct proc_data {
+	int proc_pid;
+	int ns_count;
+	unsigned int ns_hierarchy[MAX_NS_DEPTH];
+	int id_count[PT_COUNT];
+	int id_hierarchy[PT_COUNT][MAX_NS_DEPTH];
+};
+
+/**
+ * Helper function for creating a trie.
+ *
+ * For node_key_bits and data_block_key_bits 4 is used (so trie height is 32 / 4
+ * = 8, and node sizes are 8 byte * 2^4 = 128 bytes), which seems to be a good
+ * tradeoff between memory usage and lookup time. It should not be too large,
+ * since there can be large holes between PIDs, and it would be just a waste of
+ * memory having large nodes with lot of NULL pointers in them.
+ */
+static struct trie *
+create_trie_4(uint8_t key_size, uint8_t item_size_lg, uint64_t empty_value)
+{
+	struct trie *t = trie_create(key_size, item_size_lg, 4, 4, empty_value);
+	if (!t)
+		error_msg_and_die("creating trie failed");
+
+	return t;
+}
+
+void
+pidns_init(void)
+{
+	if (proc_data_cache)
+		return;
+
+	pid_max = INT_MAX;
+	if (read_int_from_file("/proc/sys/kernel/pid_max", &pid_max) < 0)
+		debug_func_perror_msg("reading /proc/sys/kernel/pid_max");
+	pid_max_size = ilog2_32(pid_max - 1) + 1;
+	pid_max_size_lg = ilog2_32(pid_max_size - 1) + 1;
+
+	for (int i = 0; i < PT_COUNT; i++)
+		ns_pid_to_proc_pid[i] = create_trie_4(ns_id_size, ptr_sz_lg, 0);
+
+	proc_data_cache = create_trie_4(pid_max_size, ptr_sz_lg, 0);
+}
+
+static void
+put_proc_pid(unsigned int ns, int ns_pid, enum pid_type type, int proc_pid)
+{
+	struct trie *b = (struct trie *) (uintptr_t) trie_get(ns_pid_to_proc_pid[type], ns);
+	if (!b) {
+		b = create_trie_4(pid_max_size, pid_max_size_lg, 0);
+		trie_set(ns_pid_to_proc_pid[type], ns, (uint64_t) (uintptr_t) b);
+	}
+	trie_set(b, ns_pid, proc_pid);
+}
+
+static int
+get_cached_proc_pid(unsigned int ns, int ns_pid, enum pid_type type)
+{
+	struct trie *b = (struct trie *) (uintptr_t)
+		trie_get(ns_pid_to_proc_pid[type], ns);
+	if (!b)
+		return 0;
+
+	return trie_get(b, ns_pid);
+}
+
+/**
+ * Helper function, converts pid to string, or to "self" for pid == 0.
+ * Uses static buffer for operation.
+ */
+static const char *
+pid_to_str(pid_t pid)
+{
+	if (!pid)
+		return "self";
+
+	static char buf[sizeof("-2147483648")];
+	xsprintf(buf, "%d", pid);
+	return buf;
+}
+
+/**
+ * Returns a list of PID NS IDs for the specified PID.
+ *
+ * @param proc_pid PID (as present in /proc) to get information for.
+ * @param ns_buf   Pointer to buffer that is able to contain at least
+ *                 ns_buf_size items.
+ * @return         Amount of NS in list. 0 indicates error.
+ */
+static size_t
+get_ns_hierarchy(int proc_pid, unsigned int *ns_buf, size_t ns_buf_size)
+{
+	char path[PATH_MAX + 1];
+	xsprintf(path, "/proc/%s/ns/pid", pid_to_str(proc_pid));
+
+	int fd = open_file(path, O_RDONLY);
+	if (fd < 0)
+		return 0;
+
+	size_t n = 0;
+	while (n < ns_buf_size) {
+		strace_stat_t st;
+		if (fstat_fd(fd, &st))
+			break;
+
+		ns_buf[n++] = st.st_ino;
+		if (n >= ns_buf_size)
+			break;
+
+		if (ns_get_parent_enotty)
+			break;
+
+		int parent_fd = ioctl(fd, NS_GET_PARENT);
+		if (parent_fd < 0) {
+			switch (errno) {
+			case EPERM:
+				break;
+
+			case ENOTTY:
+				ns_get_parent_enotty = true;
+				error_msg("NS_* ioctl commands are not "
+					  "supported by the kernel");
+				break;
+
+			default:
+				perror_func_msg("ioctl(NS_GET_PARENT)");
+				break;
+			}
+
+			break;
+		}
+
+		close(fd);
+		fd = parent_fd;
+	}
+
+	close(fd);
+
+	return n;
+}
+
+/**
+ * Get list of IDs present in NS* proc status record. IDs are placed as they are
+ * stored in /proc (from top to bottom of NS hierarchy).
+ *
+ * @param proc_pid    PID (as present in /proc) to get information for.
+ * @param id_buf      Pointer to buffer that is able to contain at least
+ *                    MAX_NS_DEPTH items. Can be NULL.
+ * @param type        Type of ID requested.
+ * @return            Number of items stored in id_list. 0 indicates error.
+ */
+static size_t
+get_id_list(int proc_pid, int *id_buf, enum pid_type type)
+{
+	const char *ns_str = id_strs[type].str;
+	size_t ns_str_size = id_strs[type].size;
+
+	size_t n = 0;
+
+	char status_path[PATH_MAX + 1];
+	xsprintf(status_path, "/proc/%s/status", pid_to_str(proc_pid));
+	FILE *f = fopen_stream(status_path, "r");
+	if (!f)
+		return 0;
+
+	char *line = NULL;
+	size_t linesize = 0;
+	char *p = NULL;
+
+	while (getline(&line, &linesize, f) > 0) {
+		if (strncmp(line, ns_str, ns_str_size) == 0) {
+			p = line + ns_str_size;
+			break;
+		}
+	}
+
+	while (p) {
+		errno = 0;
+		long id = strtol(p, NULL, 10);
+
+		if (id < 0 || id > INT_MAX || errno) {
+			perror_func_msg("converting pid (%ld) to int", id);
+			break;
+		}
+
+		if (id_buf)
+			id_buf[n] = (int) id;
+
+		n++;
+		strsep(&p, "\t");
+	}
+
+	free(line);
+	fclose(f);
+
+	return n;
+}
+
+/**
+ * Returns whether the /proc filesystem's PID namespace is the same as strace's.
+ */
+static bool
+is_proc_ours(void)
+{
+	static int cached_val = -1;
+
+	if (cached_val < 0)
+		cached_val = get_id_list(0, NULL, PT_TID) <= 1;
+
+	return cached_val;
+}
+
+/**
+ * Returns the PID namespace of the tracee
+ */
+static unsigned int
+get_ns(struct tcb *tcp)
+{
+	if (!tcp->pid_ns) {
+		int proc_pid = 0;
+		translate_pid(NULL, tcp->pid, PT_TID, &proc_pid);
+
+		if (proc_pid)
+			get_ns_hierarchy(proc_pid, &tcp->pid_ns, 1);
+	}
+
+	return tcp->pid_ns;
+}
+
+/**
+ * Returns the PID namespace of strace
+ */
+static unsigned int
+get_our_ns(void)
+{
+	static unsigned int our_ns = 0;
+	static bool our_ns_initialised = false;
+
+	if (!our_ns_initialised) {
+		get_ns_hierarchy(0, &our_ns, 1);
+		our_ns_initialised = true;
+	}
+
+	return our_ns;
+}
+
+/**
+ * Returns the cached proc_data struct associated with proc_pid.
+ * If none found, allocates a new proc_data.
+ */
+static struct proc_data *
+get_or_create_proc_data(int proc_pid)
+{
+	struct proc_data *pd = (struct proc_data *) (uintptr_t)
+		trie_get(proc_data_cache, proc_pid);
+
+	if (!pd) {
+		pd = calloc(1, sizeof(*pd));
+		if (!pd)
+			return NULL;
+
+		pd->proc_pid = proc_pid;
+		trie_set(proc_data_cache, proc_pid, (uint64_t) (uintptr_t) pd);
+	}
+
+	return pd;
+}
+
+/**
+ * Updates the proc_data from /proc
+ * If the process does not exists, returns false, and frees the proc_data
+ */
+static bool
+update_proc_data(struct proc_data *pd, enum pid_type type)
+{
+	pd->ns_count = get_ns_hierarchy(pd->proc_pid,
+		pd->ns_hierarchy, MAX_NS_DEPTH);
+	if (!pd->ns_count)
+		goto fail;
+
+	pd->id_count[type] = get_id_list(pd->proc_pid,
+		pd->id_hierarchy[type], type);
+	if (!pd->id_count[type])
+		goto fail;
+
+	return true;
+
+fail:
+	trie_set(proc_data_cache, pd->proc_pid, (uint64_t) (uintptr_t) NULL);
+	free(pd);
+	return false;
+}
+
+/**
+ * Paramters for id translation
+ */
+struct translate_id_params {
+	/* The result (output) */
+	int result_id;
+	/* The proc data of the process (output) */
+	struct proc_data *pd;
+
+	/* The namespace to be translated from */
+	unsigned int from_ns;
+	/* The id to be translated */
+	int from_id;
+	/* The type of the id */
+	enum pid_type type;
+};
+
+/**
+ * Translates an id to our namespace, given the proc_pid of the process,
+ * by reading files in /proc.
+ *
+ * @param tip      The parameters
+ * @param proc_pid The proc pid of the process.
+ *                 If 0, use the cached values in tip->pd.
+ */
+static void
+translate_id_proc_pid(struct translate_id_params *tip, int proc_pid)
+{
+	struct proc_data *pd = proc_pid ?
+		get_or_create_proc_data(proc_pid) :
+		tip->pd;
+
+	tip->result_id = 0;
+	tip->pd = NULL;
+
+	if (!pd)
+		return;
+
+	if (proc_pid && !update_proc_data(pd, tip->type))
+		return;
+
+	if (!pd->ns_count || pd->id_count[tip->type] < pd->ns_count)
+		return;
+
+	int *id_hierarchy = pd->id_hierarchy[tip->type];
+	int id_count = pd->id_count[tip->type];
+
+	for (int i = 0; i < pd->ns_count; i++) {
+		unsigned int ns = pd->ns_hierarchy[i];
+		int ns_id = id_hierarchy[id_count - i - 1];
+		int our_id = id_hierarchy[id_count - pd->ns_count];
+
+		if (ns != tip->from_ns)
+			continue;
+
+		if (ns_id != tip->from_id)
+			return;
+
+		tip->result_id = our_id;
+		tip->pd = pd;
+		return;
+	}
+}
+
+/**
+ * Translates an id to our namespace by reading all proc entries in a directory.
+ * The directory is either /proc or /proc/<pid>/task.
+ *
+ *
+ * @param tip            The parameters
+ * @param path           The path of the directory to be read.
+ * @param read_task_dir  Whether recurse to "task" subdirectory.
+ */
+static void
+translate_id_dir(struct translate_id_params *tip, const char *path,
+                 bool read_task_dir)
+{
+	DIR *dir = opendir(path);
+	if (!dir) {
+		debug_func_perror_msg("opening dir: %s", path);
+		return;
+	}
+
+	while (!tip->result_id) {
+		errno = 0;
+		struct_dirent *entry = read_dir(dir);
+		if (!entry) {
+			if (errno)
+				perror_func_msg("readdir");
+
+			break;
+		}
+
+		if (entry->d_type != DT_DIR)
+			continue;
+
+		errno = 0;
+		long proc_pid = strtol(entry->d_name, NULL, 10);
+		if (proc_pid < 1 || proc_pid > INT_MAX || errno)
+			continue;
+
+		if (read_task_dir) {
+			char task_dir_path[PATH_MAX + 1];
+			xsprintf(task_dir_path, "/proc/%ld/task", proc_pid);
+			translate_id_dir(tip, task_dir_path, false);
+		}
+
+		if (tip->result_id)
+			break;
+
+		translate_id_proc_pid(tip, proc_pid);
+	}
+
+	closedir(dir);
+}
+
+/**
+ * Iterator function of the proc_data_cache for id translation.
+ * If the cache contains the id we are looking for, reads the corresponding
+ * directory in /proc, and if cache is valid, saves the result.
+ */
+static void
+proc_data_cache_iterator_fn(void* fn_data, uint64_t key, uint64_t val)
+{
+	struct translate_id_params *tip = (struct translate_id_params *)fn_data;
+	struct proc_data *pd = (struct proc_data *) (uintptr_t) val;
+
+	if (!pd)
+		return;
+
+	/* Result already found in an earlier iteration */
+	if (tip->result_id)
+		return;
+
+	/* Translate from cache */
+	tip->pd = pd;
+	translate_id_proc_pid(tip, 0);
+	if (!tip->result_id)
+		return;
+
+	/* Now translate from actual data in /proc, to check cache validity */
+	translate_id_proc_pid(tip, pd->proc_pid);
+}
+
+int
+translate_pid(struct tcb *tcp, int from_id, enum pid_type type,
+              int *proc_pid_ptr)
+{
+	if (from_id <= 0 || type < 0 || type >= PT_COUNT)
+		return 0;
+
+	/* If translation is trivial */
+	if ((!tcp || get_ns(tcp) == get_our_ns()) &&
+	    (!proc_pid_ptr || is_proc_ours())) {
+		if (proc_pid_ptr)
+			*proc_pid_ptr = from_id;
+
+		return from_id;
+	}
+
+	struct translate_id_params tip = {
+		.result_id = 0,
+		.pd = NULL,
+		.from_ns = tcp ? get_ns(tcp) : get_our_ns(),
+		.from_id = from_id,
+		.type = type,
+	};
+
+	if (!tip.from_ns)
+		return 0;
+
+	if (ns_get_parent_enotty)
+		return 0;
+
+	/* Look for a cached proc_pid for this (from_ns, from_id) pair */
+	int cached_proc_pid = get_cached_proc_pid(tip.from_ns, tip.from_id,
+		tip.type);
+	if (cached_proc_pid) {
+		translate_id_proc_pid(&tip, cached_proc_pid);
+		if (tip.result_id)
+			goto exit;
+	}
+
+	/* Iterate through the cache, find potential proc_data */
+	trie_iterate_keys(proc_data_cache, 0, pid_max - 1,
+		proc_data_cache_iterator_fn, &tip);
+	/* (proc_data_cache_iterator_fn takes care about updating proc_data) */
+	if (tip.result_id)
+		goto exit;
+
+	/* No cache helped, read all entries in /proc */
+	translate_id_dir(&tip, "/proc", true);
+
+exit:
+	if (tip.pd) {
+		if (tip.pd->proc_pid)
+			put_proc_pid(tip.from_ns, tip.from_id, tip.type,
+				tip.pd->proc_pid);
+
+		if (proc_pid_ptr)
+			*proc_pid_ptr = tip.pd->proc_pid;
+	}
+
+	return tip.result_id;
+}
+
+int
+get_proc_pid(struct tcb *tcp)
+{
+	int proc_pid = 0;
+	translate_pid(NULL, tcp->pid, PT_TID, &proc_pid);
+	return proc_pid;
+}
+
+static void
+printpid_translation(struct tcb *tcp, int pid, enum pid_type type)
+{
+	if (!pidns_translation)
+		return;
+
+	int strace_pid = translate_pid(tcp, pid, type, NULL);
+	if (strace_pid && strace_pid != pid)
+		tprintf_comment("%d in strace's PID NS", strace_pid);
+}
+
+void
+printpid(struct tcb *tcp, int pid, enum pid_type type)
+{
+	tprintf("%d", pid);
+	printpid_translation(tcp, pid, type);
+}
+
+void
+printpid_tgid_pgid(struct tcb *tcp, int pid)
+{
+	tprintf("%d", pid);
+	if (pid > 0)
+		printpid_translation(tcp,  pid, PT_TGID);
+	else if (pid < -1)
+		printpid_translation(tcp, -pid, PT_PGID);
+}
diff -pruN 5.5-3/prctl.c 5.9-0ubuntu2/prctl.c
--- 5.5-3/prctl.c	2020-01-07 23:31:49.000000000 +0000
+++ 5.9-0ubuntu2/prctl.c	2020-04-03 22:58:26.000000000 +0000
@@ -3,7 +3,7 @@
  * Copyright (c) 1996-2000 Wichert Akkerman <wichert@cistron.nl>
  * Copyright (c) 2005-2007 Roland McGrath <roland@redhat.com>
  * Copyright (c) 2008-2015 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2014-2019 The strace developers.
+ * Copyright (c) 2014-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -369,6 +369,7 @@ SYS_FUNC(prctl)
 
 	case PR_SET_NO_NEW_PRIVS:
 	case PR_SET_THP_DISABLE:
+	case PR_SET_IO_FLUSHER:
 		tprintf(", %" PRI_klu, arg2);
 		print_prctl_args(tcp, 2);
 		return RVAL_DECODED;
@@ -411,6 +412,7 @@ SYS_FUNC(prctl)
 	case PR_GET_THP_DISABLE:
 	case PR_MPX_DISABLE_MANAGEMENT:
 	case PR_MPX_ENABLE_MANAGEMENT:
+	case PR_GET_IO_FLUSHER:
 	default:
 		print_prctl_args(tcp, 1);
 		return RVAL_DECODED;
diff -pruN 5.5-3/print_fields.h 5.9-0ubuntu2/print_fields.h
--- 5.5-3/print_fields.h	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/print_fields.h	2020-08-25 14:29:30.000000000 +0000
@@ -9,6 +9,8 @@
 #ifndef STRACE_PRINT_FIELDS_H
 # define STRACE_PRINT_FIELDS_H
 
+# include "static_assert.h"
+
 /*
  * The printf-like function to use in header files
  * shared between strace and its tests.
@@ -50,10 +52,28 @@
 		      (int) sizeof((where_).field_) * 2,		\
 		      zero_extend_signed_to_ull((where_).field_))
 
+# define PRINT_FIELD_UINT_ARRAY(prefix_, where_, field_, fmt_)			\
+	do {									\
+		STRACE_PRINTF("%s%s=", (prefix_), #field_);			\
+		for (size_t i_ = 0; i_ < ARRAY_SIZE((where_).field_); ++i_)	\
+			STRACE_PRINTF("%s" fmt_, (i_ ? ", " : "["),		\
+				zero_extend_signed_to_ull((where_).field_[i_]));\
+		STRACE_PRINTF("]");						\
+	} while (0)
+
+# define PRINT_FIELD_U_ARRAY(prefix_, where_, field_)			\
+	PRINT_FIELD_UINT_ARRAY((prefix_), (where_), field_, "%llu")
+
+# define PRINT_FIELD_X_ARRAY(prefix_, where_, field_)			\
+	PRINT_FIELD_UINT_ARRAY((prefix_), (where_), field_, "%#llx")
+
+
 # define PRINT_FIELD_COOKIE(prefix_, where_, field_)			\
-	STRACE_PRINTF("%s%s=[%llu, %llu]", (prefix_), #field_,		\
-		      zero_extend_signed_to_ull((where_).field_[0]),	\
-		      zero_extend_signed_to_ull((where_).field_[1]))
+	do {								\
+		static_assert(ARRAY_SIZE((where_).field_) == 2,		\
+			      "unexpected array size");			\
+		PRINT_FIELD_U_ARRAY((prefix_), (where_), field_);	\
+	} while (0)
 
 # define PRINT_FIELD_FLAGS(prefix_, where_, field_, xlat_, dflt_)	\
 	do {								\
@@ -211,10 +231,10 @@
 		print_ifindex((where_).field_);				\
 	} while (0)
 
-# define PRINT_FIELD_SOCKADDR(prefix_, where_, field_)			\
+# define PRINT_FIELD_SOCKADDR(prefix_, where_, field_, tcp_)			\
 	do {								\
 		STRACE_PRINTF("%s%s=", (prefix_), #field_);		\
-		print_sockaddr(&(where_).field_,			\
+		print_sockaddr(tcp_, &(where_).field_,			\
 			       sizeof((where_).field_));		\
 	} while (0)
 
@@ -224,6 +244,13 @@
 		print_dev_t((where_).field_);				\
 	} while (0)
 
+# define PRINT_FIELD_NUMERIC_UMODE_T(prefix_, where_, field_)		\
+	do {								\
+		STRACE_PRINTF("%s%s=", (prefix_), #field_);		\
+		print_numeric_ll_umode_t(				\
+			zero_extend_signed_to_ull((where_).field_));	\
+	} while (0)
+
 # define PRINT_FIELD_PTR(prefix_, where_, field_)			\
 	do {								\
 		STRACE_PRINTF("%s%s=", (prefix_), #field_);		\
@@ -236,6 +263,30 @@
 		printfd((tcp_), (where_).field_);			\
 	} while (0)
 
+# define PRINT_FIELD_TID(prefix_, where_, field_, tcp_)			\
+	do {								\
+		STRACE_PRINTF("%s%s=", (prefix_), #field_);		\
+		printpid((tcp_), (where_).field_, PT_TID);			\
+	} while (0)
+
+# define PRINT_FIELD_TGID(prefix_, where_, field_, tcp_)			\
+	do {								\
+		STRACE_PRINTF("%s%s=", (prefix_), #field_);		\
+		printpid((tcp_), (where_).field_, PT_TGID);			\
+	} while (0)
+
+# define PRINT_FIELD_PGID(prefix_, where_, field_, tcp_)			\
+	do {								\
+		STRACE_PRINTF("%s%s=", (prefix_), #field_);		\
+		printpid((tcp_), (where_).field_, PT_PGID);			\
+	} while (0)
+
+# define PRINT_FIELD_SID(prefix_, where_, field_, tcp_)			\
+	do {								\
+		STRACE_PRINTF("%s%s=", (prefix_), #field_);		\
+		printpid((tcp_), (where_).field_, PT_SID);			\
+	} while (0)
+
 # define PRINT_FIELD_STRN(prefix_, where_, field_, len_, tcp_)		\
 	do {								\
 		STRACE_PRINTF("%s%s=", (prefix_), #field_);		\
@@ -277,4 +328,19 @@
 			       (size_), (hwtype_));			\
 	} while (0)
 
+# define PRINT_FIELD_LEN(prefix_, where_, field_, 			\
+			len_, print_func_, ...)				\
+	do {								\
+		unsigned int start = offsetof(typeof(where_), field_);	\
+		unsigned int end = start + sizeof(where_.field_);	\
+		if (len_ >= end) {					\
+			print_func_(prefix_, where_, field_,		\
+					##__VA_ARGS__);			\
+		} else if (len_ > start) {				\
+			tprintf("%s%s=", prefix_, #field_);		\
+			print_quoted_string((void *)&where_.field_,	\
+					len_ - start, QUOTE_FORCE_HEX);	\
+		}							\
+	} while (0)
+
 #endif /* !STRACE_PRINT_FIELDS_H */
diff -pruN 5.5-3/print_group_req.c 5.9-0ubuntu2/print_group_req.c
--- 5.5-3/print_group_req.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/print_group_req.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -30,7 +30,7 @@ MPERS_PRINTER_DECL(void, print_group_req
 		printaddr(addr);
 	} else if (!umove_or_printaddr(tcp, addr, &greq)) {
 		PRINT_FIELD_IFINDEX("{", greq, gr_interface);
-		PRINT_FIELD_SOCKADDR(", ", greq, gr_group);
+		PRINT_FIELD_SOCKADDR(", ", greq, gr_group, tcp);
 		tprints("}");
 	}
 }
diff -pruN 5.5-3/print_mac.c 5.9-0ubuntu2/print_mac.c
--- 5.5-3/print_mac.c	2019-07-18 13:58:07.000000000 +0000
+++ 5.9-0ubuntu2/print_mac.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -17,7 +17,7 @@
 DIAG_PUSH_IGNORE_OVERRIDE_INIT
 
 static uint8_t hwaddr_sizes[] = {
-	[0 ... ARPHRD_IEEE802_TR] = 255,
+	[0 ... ARPHRD_VSOCKMON] = 255,
 
 	[ARPHRD_NETROM]     =  7 /* AX25_ADDR_LEN */,
 	[ARPHRD_ETHER]      =  6 /* ETH_ALEN */,
@@ -114,10 +114,12 @@ void
 print_mac_addr(const char *prefix, const uint8_t addr[], size_t size)
 {
 	tprints(prefix);
-	if (xlat_verbose(xlat_verbosity) != XLAT_STYLE_ABBREV)
+	if (xlat_verbose(xlat_verbosity) != XLAT_STYLE_ABBREV
+	    || size > MAX_ADDR_LEN)
 		print_quoted_string((const char *) addr, size,
 				    QUOTE_FORCE_HEX);
-	if (xlat_verbose(xlat_verbosity) == XLAT_STYLE_RAW)
+	if (xlat_verbose(xlat_verbosity) == XLAT_STYLE_RAW
+	    || size > MAX_ADDR_LEN)
 		return;
 	(xlat_verbose(xlat_verbosity) == XLAT_STYLE_VERBOSE
 		? tprints_comment : tprints)(sprint_mac_addr(addr, size));
@@ -137,10 +139,12 @@ print_hwaddr(const char *prefix, const u
 	     uint32_t devtype)
 {
 	tprints(prefix);
-	if (xlat_verbose(xlat_verbosity) != XLAT_STYLE_ABBREV)
+	if (xlat_verbose(xlat_verbosity) != XLAT_STYLE_ABBREV
+	    || size > MAX_ADDR_LEN)
 		print_quoted_string((const char *) addr, size,
 				    QUOTE_FORCE_HEX);
-	if (xlat_verbose(xlat_verbosity) == XLAT_STYLE_RAW)
+	if (xlat_verbose(xlat_verbosity) == XLAT_STYLE_RAW
+	    || size > MAX_ADDR_LEN)
 		return;
 	(xlat_verbose(xlat_verbosity) == XLAT_STYLE_VERBOSE
 		? tprints_comment : tprints)(sprint_hwaddr(addr, size,
diff -pruN 5.5-3/printmode.c 5.9-0ubuntu2/printmode.c
--- 5.5-3/printmode.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/printmode.c	2020-07-18 08:00:00.000000000 +0000
@@ -4,7 +4,7 @@
  * Copyright (c) 1993-1996 Rick Sladkey <jrs@world.std.com>
  * Copyright (c) 1996-1999 Wichert Akkerman <wichert@cistron.nl>
  * Copyright (c) 2012 Denys Vlasenko <vda.linux@googlemail.com>
- * Copyright (c) 2012-2018 The strace developers.
+ * Copyright (c) 2012-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -47,7 +47,7 @@ print_numeric_umode_t(const unsigned sho
 }
 
 void
-print_numeric_long_umask(const unsigned long mode)
+print_numeric_ll_umode_t(const unsigned long long mode)
 {
-	tprintf("%#03lo", mode);
+	tprintf("%#03llo", mode);
 }
diff -pruN 5.5-3/printrusage.c 5.9-0ubuntu2/printrusage.c
--- 5.5-3/printrusage.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/printrusage.c	2020-04-19 01:22:29.000000000 +0000
@@ -10,20 +10,20 @@
  */
 
 #include "defs.h"
-#include <sys/resource.h>
-
-#include "print_fields.h"
 
-#include DEF_MPERS_TYPE(rusage_t)
+#include DEF_MPERS_TYPE(kernel_rusage_t)
 
-typedef struct rusage rusage_t;
+#include "kernel_rusage.h"
 
 #include MPERS_DEFS
 
+#include <sys/resource.h>
+#include "print_fields.h"
+
 MPERS_PRINTER_DECL(void, printrusage,
 		   struct tcb *const tcp, const kernel_ulong_t addr)
 {
-	rusage_t ru;
+	kernel_rusage_t ru;
 
 	if (umove_or_printaddr(tcp, addr, &ru))
 		return;
diff -pruN 5.5-3/printsiginfo.c 5.9-0ubuntu2/printsiginfo.c
--- 5.5-3/printsiginfo.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/printsiginfo.c	2020-08-25 14:29:30.000000000 +0000
@@ -7,7 +7,7 @@
  * Copyright (c) 2013 Denys Vlasenko <vda.linux@googlemail.com>
  * Copyright (c) 2011-2015 Dmitry V. Levin <ldv@altlinux.org>
  * Copyright (c) 2015 Elvira Khabirova <lineprinter0@gmail.com>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -56,11 +56,10 @@
 #endif
 
 static void
-printsigsource(const siginfo_t *sip)
+printsigsource(struct tcb *tcp, const siginfo_t *sip)
 {
-	tprintf(", si_pid=%u, si_uid=%u",
-		(unsigned int) sip->si_pid,
-		(unsigned int) sip->si_uid);
+	PRINT_FIELD_TGID(", ", *sip, si_pid, tcp);
+	PRINT_FIELD_UID(", ", *sip, si_uid);
 }
 
 static void
@@ -117,7 +116,7 @@ print_si_code(int si_signo, unsigned int
 }
 
 static void
-print_si_info(const siginfo_t *sip)
+print_si_info(struct tcb *tcp, const siginfo_t *sip)
 {
 	if (sip->si_errno)
 		PRINT_FIELD_ERR_U(", ", *sip, si_errno);
@@ -125,10 +124,10 @@ print_si_info(const siginfo_t *sip)
 	if (SI_FROMUSER(sip)) {
 		switch (sip->si_code) {
 		case SI_USER:
-			printsigsource(sip);
+			printsigsource(tcp, sip);
 			break;
 		case SI_TKILL:
-			printsigsource(sip);
+			printsigsource(tcp, sip);
 			break;
 #if defined HAVE_SIGINFO_T_SI_TIMERID && defined HAVE_SIGINFO_T_SI_OVERRUN
 		case SI_TIMER:
@@ -138,7 +137,7 @@ print_si_info(const siginfo_t *sip)
 			break;
 #endif
 		default:
-			printsigsource(sip);
+			printsigsource(tcp, sip);
 			if (sip->si_ptr)
 				printsigval(sip);
 			break;
@@ -146,7 +145,7 @@ print_si_info(const siginfo_t *sip)
 	} else {
 		switch (sip->si_signo) {
 		case SIGCHLD:
-			printsigsource(sip);
+			printsigsource(tcp, sip);
 			tprints(", si_status=");
 			if (sip->si_code == CLD_EXITED)
 				tprintf("%d", sip->si_status);
@@ -205,7 +204,7 @@ print_si_info(const siginfo_t *sip)
 #endif
 		default:
 			if (sip->si_pid || sip->si_uid)
-				printsigsource(sip);
+				printsigsource(tcp, sip);
 			if (sip->si_ptr)
 				printsigval(sip);
 		}
@@ -216,7 +215,7 @@ print_si_info(const siginfo_t *sip)
 static
 #endif
 void
-printsiginfo(const siginfo_t *sip)
+printsiginfo(struct tcb *tcp, const siginfo_t *sip)
 {
 	if (sip->si_signo == 0) {
 		tprints("{}");
@@ -231,7 +230,7 @@ printsiginfo(const siginfo_t *sip)
 #ifdef SI_NOINFO
 	if (sip->si_code != SI_NOINFO)
 #endif
-		print_si_info(sip);
+		print_si_info(tcp, sip);
 
 	tprints("}");
 }
@@ -242,13 +241,13 @@ MPERS_PRINTER_DECL(void, printsiginfo_at
 	siginfo_t si;
 
 	if (!umove_or_printaddr(tcp, addr, &si))
-		printsiginfo(&si);
+		printsiginfo(tcp, &si);
 }
 
 static bool
 print_siginfo_t(struct tcb *tcp, void *elem_buf, size_t elem_size, void *data)
 {
-	printsiginfo((const siginfo_t *) elem_buf);
+	printsiginfo(tcp, (const siginfo_t *) elem_buf);
 	return true;
 }
 
diff -pruN 5.5-3/printsiginfo.h 5.9-0ubuntu2/printsiginfo.h
--- 5.5-3/printsiginfo.h	2018-12-30 15:35:21.000000000 +0000
+++ 5.9-0ubuntu2/printsiginfo.h	2020-08-03 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -8,6 +8,6 @@
 #ifndef STRACE_PRINTSIGINFO_H
 # define STRACE_PRINTSIGINFO_H
 
-extern void printsiginfo(const siginfo_t *);
+extern void printsiginfo(struct tcb *, const siginfo_t *);
 
 #endif /* !STRACE_PRINTSIGINFO_H */
diff -pruN 5.5-3/print_syscall_number.c 5.9-0ubuntu2/print_syscall_number.c
--- 5.5-3/print_syscall_number.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/print_syscall_number.c	2020-08-21 16:39:24.000000000 +0000
@@ -0,0 +1,18 @@
+/*
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
+#include "defs.h"
+
+void
+print_syscall_number(struct tcb *tcp)
+{
+	if (tcp->true_scno != (kernel_ulong_t) -1) {
+		tprintf("[%4" PRI_klu "] ", tcp->true_scno);
+	} else {
+		tprintf("[????] ");
+	}
+}
diff -pruN 5.5-3/print_timespec32.c 5.9-0ubuntu2/print_timespec32.c
--- 5.5-3/print_timespec32.c	2019-05-09 22:03:30.000000000 +0000
+++ 5.9-0ubuntu2/print_timespec32.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2019-2020 Dmitry V. Levin <ldv@altlinux.org>
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -7,17 +7,19 @@
 
 #include "defs.h"
 
-#if HAVE_ARCH_TIME32_SYSCALLS
+#if HAVE_ARCH_TIME32_SYSCALLS || HAVE_ARCH_TIMESPEC32
 
 # define TIMESPEC_T kernel_timespec32_t
 # define PRINT_TIMESPEC_DATA_SIZE print_timespec32_data_size
 # define PRINT_TIMESPEC_ARRAY_DATA_SIZE print_timespec32_array_data_size
-# define PRINT_TIMESPEC print_timespec32
-# define SPRINT_TIMESPEC sprint_timespec32
-# define PRINT_TIMESPEC_UTIME_PAIR print_timespec32_utime_pair
-# define PRINT_ITIMERSPEC print_itimerspec32
+# if HAVE_ARCH_TIME32_SYSCALLS
+#  define PRINT_TIMESPEC print_timespec32
+#  define SPRINT_TIMESPEC sprint_timespec32
+#  define PRINT_TIMESPEC_UTIME_PAIR print_timespec32_utime_pair
+#  define PRINT_ITIMERSPEC print_itimerspec32
+# endif /* HAVE_ARCH_TIME32_SYSCALLS */
 
 # include "kernel_timespec.h"
 # include "print_timespec.h"
 
-#endif /* HAVE_ARCH_TIME32_SYSCALLS */
+#endif /* HAVE_ARCH_TIME32_SYSCALLS || HAVE_ARCH_TIMESPEC32 */
diff -pruN 5.5-3/print_timespec.c 5.9-0ubuntu2/print_timespec.c
--- 5.5-3/print_timespec.c	2019-05-22 11:05:13.000000000 +0000
+++ 5.9-0ubuntu2/print_timespec.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,48 +0,0 @@
-/*
- * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
- * All rights reserved.
- *
- * SPDX-License-Identifier: LGPL-2.1-or-later
- */
-
-#include "defs.h"
-
-#include DEF_MPERS_TYPE(timespec_t)
-
-#include "kernel_timespec.h"
-
-#if defined MPERS_IS_mx32
-# define TIMESPEC_IS_32BIT 0
-#elif defined MPERS_IS_m32
-# define TIMESPEC_IS_32BIT 1
-#elif ARCH_TIMESIZE == 4
-# define TIMESPEC_IS_32BIT 1
-#else
-# define TIMESPEC_IS_32BIT 0
-#endif
-
-#if TIMESPEC_IS_32BIT
-typedef kernel_timespec32_t timespec_t;
-# define PRINT_TIMESPEC_DATA_SIZE print_timespec32_data_size
-# define PRINT_TIMESPEC_ARRAY_DATA_SIZE print_timespec32_array_data_size
-#else
-typedef kernel_timespec64_t timespec_t;
-# define PRINT_TIMESPEC_DATA_SIZE print_timespec64_data_size
-# define PRINT_TIMESPEC_ARRAY_DATA_SIZE print_timespec64_array_data_size
-#endif
-
-#include MPERS_DEFS
-
-MPERS_PRINTER_DECL(bool, print_struct_timespec_data_size,
-		   const void *arg, const size_t size)
-{
-	return PRINT_TIMESPEC_DATA_SIZE(arg, size);
-}
-
-MPERS_PRINTER_DECL(bool, print_struct_timespec_array_data_size,
-		   const void *arg, const unsigned int nmemb,
-		   const size_t size)
-{
-	return PRINT_TIMESPEC_ARRAY_DATA_SIZE(arg, nmemb, size);
-}
diff -pruN 5.5-3/print_timeval.c 5.9-0ubuntu2/print_timeval.c
--- 5.5-3/print_timeval.c	2019-05-22 11:05:13.000000000 +0000
+++ 5.9-0ubuntu2/print_timeval.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2017 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -10,7 +10,9 @@
 
 #include DEF_MPERS_TYPE(timeval_t)
 
-typedef struct timeval timeval_t;
+#include "kernel_timeval.h"
+
+typedef kernel_old_timeval_t timeval_t;
 
 #include MPERS_DEFS
 
diff -pruN 5.5-3/process.c 5.9-0ubuntu2/process.c
--- 5.5-3/process.c	2019-11-28 19:30:05.000000000 +0000
+++ 5.9-0ubuntu2/process.c	2020-09-23 16:29:35.000000000 +0000
@@ -8,7 +8,7 @@
  *                    <barrow_dj@mail.yahoo.com,djbarrow@de.ibm.com>
  * Copyright (c) 2000 PocketPenguins Inc.  Linux for Hitachi SuperH
  *                    port by Greg Banks <gbanks@pocketpenguins.com>
- * Copyright (c) 1999-2019 The strace developers.
+ * Copyright (c) 1999-2020 The strace developers.
  *
  * All rights reserved.
  *
@@ -92,7 +92,8 @@ SYS_FUNC(ptrace)
 		}
 
 		/* pid */
-		tprintf(", %d", pid);
+		tprints(", ");
+		printpid(tcp, pid, PT_TGID);
 
 		/* addr */
 		switch (request) {
diff -pruN 5.5-3/process_vm.c 5.9-0ubuntu2/process_vm.c
--- 5.5-3/process_vm.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/process_vm.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2012 Denys Vlasenko <vda.linux@googlemail.com>
  * Copyright (c) 2012-2015 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2014-2018 The strace developers.
+ * Copyright (c) 2014-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -13,7 +13,8 @@ SYS_FUNC(process_vm_readv)
 {
 	if (entering(tcp)) {
 		/* arg 1: pid */
-		tprintf("%d, ", (int) tcp->u_arg[0]);
+		printpid(tcp, tcp->u_arg[0], PT_TGID);
+		tprints(", ");
 	} else {
 		kernel_ulong_t local_iovcnt = tcp->u_arg[2];
 		kernel_ulong_t remote_iovcnt = tcp->u_arg[4];
@@ -42,7 +43,8 @@ SYS_FUNC(process_vm_writev)
 	kernel_ulong_t flags = tcp->u_arg[5];
 
 	/* arg 1: pid */
-	tprintf("%d, ", (int) tcp->u_arg[0]);
+	printpid(tcp, tcp->u_arg[0], PT_TGID);
+	tprints(", ");
 	/* arg 2: local iov */
 	tprint_iov(tcp, local_iovcnt, tcp->u_arg[1], IOV_DECODE_STR);
 	/* arg 3: local iovcnt */
diff -pruN 5.5-3/ptrace_syscall_info.c 5.9-0ubuntu2/ptrace_syscall_info.c
--- 5.5-3/ptrace_syscall_info.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/ptrace_syscall_info.c	2020-05-27 08:00:00.000000000 +0000
@@ -20,18 +20,20 @@
 
 bool ptrace_get_syscall_info_supported;
 
+#define FAIL	do { ptrace_stop = -1U; goto done; } while (0)
+
+#ifdef HAVE_FORK
 static int
 kill_tracee(pid_t pid)
 {
 	return kill_save_errno(pid, SIGKILL);
 }
 
-#define FAIL	do { ptrace_stop = -1U; goto done; } while (0)
-
 static const unsigned int expected_none_size =
 	offsetof(struct_ptrace_syscall_info, entry);
 static const unsigned int expected_entry_size =
 	offsetofend(struct_ptrace_syscall_info, entry.args);
+#endif /* HAVE_FORK */
 static const unsigned int expected_exit_size =
 	offsetofend(struct_ptrace_syscall_info, exit.is_error);
 static const unsigned int expected_seccomp_size =
@@ -81,6 +83,12 @@ test_ptrace_get_syscall_info(void)
 	};
 	const unsigned long *exp_args;
 
+# if SIZEOF_KERNEL_LONG_T > SIZEOF_LONG
+#  define CAST (unsigned long)
+# else
+#  define CAST
+# endif
+
 	int pid = fork();
 	if (pid < 0)
 		perror_func_msg_and_die("fork");
@@ -196,12 +204,12 @@ test_ptrace_get_syscall_info(void)
 				    || !info.instruction_pointer
 				    || !info.stack_pointer
 				    || (info.entry.nr != exp_args[0])
-				    || (info.entry.args[0] != exp_args[1])
-				    || (info.entry.args[1] != exp_args[2])
-				    || (info.entry.args[2] != exp_args[3])
-				    || (info.entry.args[3] != exp_args[4])
-				    || (info.entry.args[4] != exp_args[5])
-				    || (info.entry.args[5] != exp_args[6])) {
+				    || (CAST info.entry.args[0] != exp_args[1])
+				    || (CAST info.entry.args[1] != exp_args[2])
+				    || (CAST info.entry.args[2] != exp_args[3])
+				    || (CAST info.entry.args[3] != exp_args[4])
+				    || (CAST info.entry.args[4] != exp_args[5])
+				    || (CAST info.entry.args[5] != exp_args[6])) {
 					debug_func_msg("#%d: entry stop"
 						       " mismatch",
 						       ptrace_stop);
diff -pruN 5.5-3/resource.c 5.9-0ubuntu2/resource.c
--- 5.5-3/resource.c	2019-03-18 02:40:16.000000000 +0000
+++ 5.9-0ubuntu2/resource.c	2020-09-23 16:29:35.000000000 +0000
@@ -3,7 +3,7 @@
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995, 1996 Rick Sladkey <jrs@world.std.com>
  * Copyright (c) 1996-1999 Wichert Akkerman <wichert@cistron.nl>
- * Copyright (c) 1999-2019 The strace developers.
+ * Copyright (c) 1999-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -142,7 +142,8 @@ SYS_FUNC(setrlimit)
 SYS_FUNC(prlimit64)
 {
 	if (entering(tcp)) {
-		tprintf("%d, ", (int) tcp->u_arg[0]);
+		printpid(tcp, tcp->u_arg[0], PT_TGID);
+		tprints(", ");
 		printxval(resources, tcp->u_arg[1], "RLIMIT_???");
 		tprints(", ");
 		print_rlimit64(tcp, tcp->u_arg[2]);
@@ -179,10 +180,28 @@ SYS_FUNC(osf_getrusage)
 
 #include "xlat/priorities.h"
 
+static void
+priority_print_who(struct tcb *tcp, int which, int who)
+{
+	switch (which)
+	{
+	case PRIO_PROCESS:
+		printpid(tcp, who, PT_TGID);
+		break;
+	case PRIO_PGRP:
+		printpid(tcp, who, PT_PGID);
+		break;
+	default:
+		tprintf("%d", who);
+		break;
+	}
+}
+
 SYS_FUNC(getpriority)
 {
 	printxval(priorities, tcp->u_arg[0], "PRIO_???");
-	tprintf(", %d", (int) tcp->u_arg[1]);
+	tprints(", ");
+	priority_print_who(tcp, tcp->u_arg[0], tcp->u_arg[1]);
 
 	return RVAL_DECODED;
 }
@@ -190,7 +209,9 @@ SYS_FUNC(getpriority)
 SYS_FUNC(setpriority)
 {
 	printxval(priorities, tcp->u_arg[0], "PRIO_???");
-	tprintf(", %d, %d", (int) tcp->u_arg[1], (int) tcp->u_arg[2]);
+	tprints(", ");
+	priority_print_who(tcp, tcp->u_arg[0], tcp->u_arg[1]);
+	tprintf(", %d", (int) tcp->u_arg[2]);
 
 	return RVAL_DECODED;
 }
diff -pruN 5.5-3/rtc.c 5.9-0ubuntu2/rtc.c
--- 5.5-3/rtc.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/rtc.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2004 Ulrich Drepper <drepper@redhat.com>
  * Copyright (c) 2004-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -18,6 +18,12 @@ typedef struct rtc_pll_info struct_rtc_p
 
 #include MPERS_DEFS
 
+#include "xlat/rtc_vl_flags.h"
+
+#define XLAT_MACROS_ONLY
+# include "xlat/rtc_ioctl_cmds.h"
+#undef XLAT_MACROS_ONLY
+
 static void
 print_rtc_time(struct tcb *tcp, const struct rtc_time *rt)
 {
@@ -65,6 +71,19 @@ decode_rtc_pll_info(struct tcb *const tc
 			pll.pll_posmult, pll.pll_negmult, (long) pll.pll_clock);
 }
 
+static void
+decode_rtc_vl(struct tcb *const tcp, const kernel_ulong_t addr)
+{
+	unsigned int val;
+
+	if (umove_or_printaddr(tcp, addr, &val))
+		return;
+
+	tprints("[");
+	printflags(rtc_vl_flags, val, "RTC_VL_???");
+	tprints("]");
+}
+
 MPERS_PRINTER_DECL(int, rtc_ioctl, struct tcb *const tcp,
 		   const unsigned int code, const kernel_ulong_t arg)
 {
@@ -106,14 +125,12 @@ MPERS_PRINTER_DECL(int, rtc_ioctl, struc
 		tprints(", ");
 		decode_rtc_pll_info(tcp, arg);
 		break;
-#ifdef RTC_VL_READ
 	case RTC_VL_READ:
 		if (entering(tcp))
 			return 0;
 		tprints(", ");
-		printnum_int(tcp, arg, "%d");
+		decode_rtc_vl(tcp, arg);
 		break;
-#endif
 	case RTC_AIE_ON:
 	case RTC_AIE_OFF:
 	case RTC_UIE_ON:
@@ -122,9 +139,7 @@ MPERS_PRINTER_DECL(int, rtc_ioctl, struc
 	case RTC_PIE_OFF:
 	case RTC_WIE_ON:
 	case RTC_WIE_OFF:
-#ifdef RTC_VL_CLR
 	case RTC_VL_CLR:
-#endif
 		/* no args */
 		break;
 	default:
diff -pruN 5.5-3/rtnl_addr.c 5.9-0ubuntu2/rtnl_addr.c
--- 5.5-3/rtnl_addr.c	2019-07-08 21:04:00.000000000 +0000
+++ 5.9-0ubuntu2/rtnl_addr.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2016 Fabien Siron <fabien.siron@epita.fr>
  * Copyright (c) 2017 JingPiao Chen <chenjingpiao@gmail.com>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -50,7 +50,7 @@ decode_ifa_cacheinfo(struct tcb *const t
 		PRINT_FIELD_U(", ", ci, ifa_valid);
 		PRINT_FIELD_U(", ", ci, cstamp);
 		PRINT_FIELD_U(", ", ci, tstamp);
-		tprintf("}");
+		tprints("}");
 	}
 
 	return true;
diff -pruN 5.5-3/rtnl_link.c 5.9-0ubuntu2/rtnl_link.c
--- 5.5-3/rtnl_link.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/rtnl_link.c	2020-05-30 08:00:00.000000000 +0000
@@ -42,6 +42,17 @@
 #include "xlat/xdp_flags.h"
 
 static bool
+decode_ifla_hwaddr(struct tcb *const tcp,
+		   const kernel_ulong_t addr,
+		   const unsigned int len,
+		   const void *const opaque_data)
+{
+	const struct ifinfomsg *ifinfo = (const struct ifinfomsg *) opaque_data;
+
+	return decode_nla_hwaddr_family(tcp, addr, len, ifinfo->ifi_family);
+}
+
+static bool
 decode_rtnl_link_stats(struct tcb *const tcp,
 		       const kernel_ulong_t addr,
 		       const unsigned int len,
@@ -287,7 +298,7 @@ static const nla_decoder_t ifla_info_dat
 	[IFLA_BR_TCN_TIMER]			= decode_nla_u64,
 	[IFLA_BR_TOPOLOGY_CHANGE_TIMER]		= decode_nla_u64,
 	[IFLA_BR_GC_TIMER]			= decode_nla_u64,
-	[IFLA_BR_GROUP_ADDR]			= NULL, /* MAC address */
+	[IFLA_BR_GROUP_ADDR]			= decode_nla_hwaddr_nofamily,
 	[IFLA_BR_FDB_FLUSH]			= NULL, /* unspecified */
 	[IFLA_BR_MCAST_ROUTER]			= decode_nla_u8,
 	[IFLA_BR_MCAST_SNOOPING]		= decode_nla_u8,
@@ -572,6 +583,7 @@ static const nla_decoder_t ifla_xdp_nla_
 	[IFLA_XDP_DRV_PROG_ID]  = decode_nla_u32,
 	[IFLA_XDP_SKB_PROG_ID]  = decode_nla_u32,
 	[IFLA_XDP_HW_PROG_ID]   = decode_nla_u32,
+	[IFLA_XDP_EXPECTED_FD]	= decode_nla_fd,
 };
 
 static bool
@@ -803,9 +815,48 @@ decode_ifla_af_spec(struct tcb *const tc
 	return true;
 }
 
+static bool
+decode_ifla_prop_list_attr(struct tcb *const tcp,
+			   const kernel_ulong_t addr,
+			   const unsigned int len,
+			   const void *const opaque_data)
+{
+	const uintptr_t type = (uintptr_t) opaque_data;
+
+	switch (type) {
+	case IFLA_ALT_IFNAME:
+		return decode_nla_str(tcp, addr, len, NULL);
+	default:
+		return false;
+	}
+
+	return true;
+}
+
+static bool
+decode_ifla_prop_list(struct tcb *const tcp,
+		      const kernel_ulong_t addr,
+		      const unsigned int len,
+		      const void *const opaque_data)
+{
+	nla_decoder_t ifla_prop_list_decoder = &decode_ifla_prop_list_attr;
+
+	/*
+	 * We're using the zero-size decoder list in order to avoid large table,
+	 * as IFLA_ALT_IFNAME is the only attribute type we need to decode
+	 * inside the IFLA_PROP_LIST attribute so far, and it has rather large
+	 * value of 53.
+	 */
+	decode_nlattr(tcp, addr, len, rtnl_link_attrs, "IFLA_???",
+		      &ifla_prop_list_decoder, 0, NULL);
+
+	return true;
+}
+
+
 static const nla_decoder_t ifinfomsg_nla_decoders[] = {
-	[IFLA_ADDRESS]		= NULL, /* unimplemented */
-	[IFLA_BROADCAST]	= NULL, /* unimplemented */
+	[IFLA_ADDRESS]		= decode_ifla_hwaddr,
+	[IFLA_BROADCAST]	= decode_ifla_hwaddr,
 	[IFLA_IFNAME]		= decode_nla_str,
 	[IFLA_MTU]		= decode_nla_u32,
 	[IFLA_LINK]		= decode_nla_u32,
@@ -855,6 +906,9 @@ static const nla_decoder_t ifinfomsg_nla
 	[IFLA_NEW_IFINDEX]	= decode_nla_ifindex,
 	[IFLA_MIN_MTU]		= decode_nla_u32,
 	[IFLA_MAX_MTU]		= decode_nla_u32,
+	[IFLA_PROP_LIST]	= decode_ifla_prop_list,
+	[IFLA_ALT_IFNAME]	= decode_nla_str,
+	[IFLA_PERM_ADDRESS]	= decode_ifla_hwaddr,
 };
 
 DECL_NETLINK_ROUTE_DECODER(decode_ifinfomsg)
@@ -887,6 +941,6 @@ DECL_NETLINK_ROUTE_DECODER(decode_ifinfo
 		tprints(", ");
 		decode_nlattr(tcp, addr + offset, len - offset,
 			      rtnl_link_attrs, "IFLA_???",
-			      ARRSZ_PAIR(ifinfomsg_nla_decoders), NULL);
+			      ARRSZ_PAIR(ifinfomsg_nla_decoders), &ifinfo);
 	}
 }
diff -pruN 5.5-3/rtnl_neigh.c 5.9-0ubuntu2/rtnl_neigh.c
--- 5.5-3/rtnl_neigh.c	2019-12-03 23:53:51.000000000 +0000
+++ 5.9-0ubuntu2/rtnl_neigh.c	2020-06-28 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2016 Fabien Siron <fabien.siron@epita.fr>
  * Copyright (c) 2017 JingPiao Chen <chenjingpiao@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -36,22 +36,6 @@ decode_neigh_addr(struct tcb *const tcp,
 }
 
 static bool
-decode_neigh_lladdr(struct tcb *const tcp,
-		    const kernel_ulong_t addr,
-		    const unsigned int len,
-		    const void *const opaque_data)
-{
-	uint8_t maddr[6];
-
-	if (len < sizeof(maddr))
-		return false;
-	else if (!umove_or_printaddr(tcp, addr, &maddr))
-		print_mac_addr("", maddr, sizeof(maddr));
-
-	return true;
-}
-
-static bool
 decode_nda_cacheinfo(struct tcb *const tcp,
 		     const kernel_ulong_t addr,
 		     const unsigned int len,
@@ -74,7 +58,7 @@ decode_nda_cacheinfo(struct tcb *const t
 
 static const nla_decoder_t ndmsg_nla_decoders[] = {
 	[NDA_DST]		= decode_neigh_addr,
-	[NDA_LLADDR]		= decode_neigh_lladdr,
+	[NDA_LLADDR]		= decode_nla_hwaddr_nofamily,
 	[NDA_CACHEINFO]		= decode_nda_cacheinfo,
 	[NDA_PROBES]		= decode_nla_u32,
 	[NDA_VLAN]		= decode_nla_u16,
@@ -85,6 +69,7 @@ static const nla_decoder_t ndmsg_nla_dec
 	[NDA_LINK_NETNSID]	= decode_nla_u32,
 	[NDA_SRC_VNI]		= NULL,
 	[NDA_PROTOCOL]		= decode_nla_u8,
+	[NDA_NH_ID]		= decode_nla_u32,
 };
 
 DECL_NETLINK_ROUTE_DECODER(decode_ndmsg)
diff -pruN 5.5-3/rtnl_tc_action.c 5.9-0ubuntu2/rtnl_tc_action.c
--- 5.5-3/rtnl_tc_action.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/rtnl_tc_action.c	2020-05-30 08:00:00.000000000 +0000
@@ -18,6 +18,7 @@
 
 #include "xlat/rtnl_tc_action_attrs.h"
 #include "xlat/rtnl_tca_act_flags.h"
+#include "xlat/rtnl_tca_act_hw_stats.h"
 
 
 static bool
@@ -34,6 +35,20 @@ decode_tca_act_flags(struct tcb *const t
 	return decode_nla_flags(tcp, addr, len, &opts);
 }
 
+static bool
+decode_tca_act_hw_stats(struct tcb *const tcp,
+		        const kernel_ulong_t addr,
+		        const unsigned int len,
+		        const void *const opaque_data)
+{
+	static const struct decode_nla_xlat_opts opts = {
+		rtnl_tca_act_hw_stats, "TCA_ACT_HW_STATS_???",
+		.size = 4,
+	};
+
+	return decode_nla_flags(tcp, addr, len, &opts);
+}
+
 static const nla_decoder_t tcamsg_nla_decoders[] = {
 	[TCA_ACT_KIND]		= decode_nla_str,
 	[TCA_ACT_OPTIONS]	= NULL, /* unimplemented */
@@ -42,6 +57,8 @@ static const nla_decoder_t tcamsg_nla_de
 	[TCA_ACT_PAD]		= NULL,
 	[TCA_ACT_COOKIE]	= NULL, /* default parser */
 	[TCA_ACT_FLAGS]		= decode_tca_act_flags,
+	[TCA_ACT_HW_STATS]	= decode_tca_act_hw_stats,
+	[TCA_ACT_USED_HW_STATS]	= decode_tca_act_hw_stats,
 };
 
 DECL_NETLINK_ROUTE_DECODER(decode_tcamsg)
diff -pruN 5.5-3/rtnl_tc.c 5.9-0ubuntu2/rtnl_tc.c
--- 5.5-3/rtnl_tc.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/rtnl_tc.c	2020-06-29 08:00:00.000000000 +0000
@@ -279,6 +279,7 @@ static const nla_decoder_t tcmsg_nla_dec
 	[TCA_HW_OFFLOAD]	= decode_nla_u8,
 	[TCA_INGRESS_BLOCK]	= decode_nla_u32,
 	[TCA_EGRESS_BLOCK]	= decode_nla_u32,
+	[TCA_DUMP_FLAGS]	= decode_nla_u32,
 };
 
 DECL_NETLINK_ROUTE_DECODER(decode_tcmsg)
diff -pruN 5.5-3/s390.c 5.9-0ubuntu2/s390.c
--- 5.5-3/s390.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/s390.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * s390-specific syscalls decoders.
  *
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -592,7 +592,7 @@ static void
 print_sthyi_partition(struct tcb *tcp, struct sthyi_partition *hdr,
 		      uint16_t size, bool *mt)
 {
-	size_t last_decoded = offsetofend(typeof(*hdr), infplgif);
+	size_t last_decoded = offsetofend(typeof(*hdr), infpabif);
 	int cnt_val, wcap_val, acap_val, id_val, lpar_val;
 
 	*mt = false;
@@ -662,18 +662,20 @@ print_sthyi_partition(struct tcb *tcp, s
 		if (acap_val || hdr->infpabif)
 			PRINT_FIELD_WEIGHT(", ", *hdr, infpabif);
 
-		if (!IS_ARRAY_ZERO(hdr->infplgnm)) {
-			PRINT_FIELD_EBCDIC(", ", *hdr, infplgnm);
-
-			PRINT_FIELD_WEIGHT(", ", *hdr, infplgcp);
-			PRINT_FIELD_WEIGHT(", ", *hdr, infplgif);
-		} else {
-			if (lpar_val)
-				PRINT_FIELD_HEX_ARRAY(", ", *hdr, infplgnm);
-			if (hdr->infplgcp)
-				PRINT_FIELD_X(", ", *hdr, infplgcp);
-			if (hdr->infplgif)
-				PRINT_FIELD_X(", ", *hdr, infplgif);
+		if (size >= offsetofend(struct sthyi_partition, infplgif)) {
+			if (!IS_ARRAY_ZERO(hdr->infplgnm)) {
+				PRINT_FIELD_EBCDIC(", ", *hdr, infplgnm);
+
+				PRINT_FIELD_WEIGHT(", ", *hdr, infplgcp);
+				PRINT_FIELD_WEIGHT(", ", *hdr, infplgif);
+			} else {
+				if (lpar_val)
+					PRINT_FIELD_HEX_ARRAY(", ", *hdr, infplgnm);
+				if (hdr->infplgcp)
+					PRINT_FIELD_X(", ", *hdr, infplgcp);
+				if (hdr->infplgif)
+					PRINT_FIELD_X(", ", *hdr, infplgif);
+			}
 		}
 
 		if (size >= offsetofend(struct sthyi_partition, infpplnm)) {
diff -pruN 5.5-3/sched_attr.h 5.9-0ubuntu2/sched_attr.h
--- 5.5-3/sched_attr.h	2018-12-30 15:35:21.000000000 +0000
+++ 5.9-0ubuntu2/sched_attr.h	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,6 @@
 /*
  * Copyright (c) 2017-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -19,8 +20,14 @@ struct sched_attr {
 	uint64_t sched_runtime;
 	uint64_t sched_deadline;
 	uint64_t sched_period;
+	/* ver. 1 fields below */
+	uint32_t sched_util_min;
+	uint32_t sched_util_max;
 };
 
 # define SCHED_ATTR_MIN_SIZE	48
+# ifndef SCHED_ATTR_SIZE_VER1
+#  define SCHED_ATTR_SIZE_VER1  56
+# endif
 
 #endif /* !STRACE_SCHED_ATTR_H */
diff -pruN 5.5-3/sched.c 5.9-0ubuntu2/sched.c
--- 5.5-3/sched.c	2019-05-22 11:05:13.000000000 +0000
+++ 5.9-0ubuntu2/sched.c	2020-08-25 14:29:30.000000000 +0000
@@ -2,7 +2,7 @@
  * Copyright (c) 2004 Ulrich Drepper <drepper@redhat.com>
  * Copyright (c) 2005 Roland McGrath <roland@redhat.com>
  * Copyright (c) 2012-2015 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2014-2019 The strace developers.
+ * Copyright (c) 2014-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -13,13 +13,15 @@
 #include <sched.h>
 #include "sched_attr.h"
 
+#include "print_fields.h"
+
 #include "xlat/schedulers.h"
 #include "xlat/sched_flags.h"
 
 SYS_FUNC(sched_getscheduler)
 {
 	if (entering(tcp)) {
-		tprintf("%d", (int) tcp->u_arg[0]);
+		printpid(tcp, tcp->u_arg[0], PT_TGID);
 	} else if (!syserror(tcp)) {
 		tcp->auxstr = xlookup(schedulers, (kernel_ulong_t) tcp->u_rval);
 		return RVAL_STR;
@@ -29,7 +31,8 @@ SYS_FUNC(sched_getscheduler)
 
 SYS_FUNC(sched_setscheduler)
 {
-	tprintf("%d, ", (int) tcp->u_arg[0]);
+	printpid(tcp, tcp->u_arg[0], PT_TGID);
+	tprints(", ");
 	printxval(schedulers, tcp->u_arg[1], "SCHED_???");
 	tprints(", ");
 	printnum_int(tcp, tcp->u_arg[2], "%d");
@@ -39,16 +42,19 @@ SYS_FUNC(sched_setscheduler)
 
 SYS_FUNC(sched_getparam)
 {
-	if (entering(tcp))
-		tprintf("%d, ", (int) tcp->u_arg[0]);
-	else
+	if (entering(tcp)) {
+		printpid(tcp, tcp->u_arg[0], PT_TGID);
+		tprints(", ");
+	} else {
 		printnum_int(tcp, tcp->u_arg[1], "%d");
+	}
 	return 0;
 }
 
 SYS_FUNC(sched_setparam)
 {
-	tprintf("%d, ", (int) tcp->u_arg[0]);
+	printpid(tcp, tcp->u_arg[0], PT_TGID);
+	tprints(", ");
 	printnum_int(tcp, tcp->u_arg[1], "%d");
 
 	return RVAL_DECODED;
@@ -66,7 +72,8 @@ do_sched_rr_get_interval(struct tcb *con
 			 const print_obj_by_addr_fn print_ts)
 {
 	if (entering(tcp)) {
-		tprintf("%d, ", (int) tcp->u_arg[0]);
+		printpid(tcp, tcp->u_arg[0], PT_TGID);
+		tprints(", ");
 	} else {
 		if (syserror(tcp))
 			printaddr(tcp->u_arg[1]);
@@ -94,6 +101,7 @@ print_sched_attr(struct tcb *const tcp,
 {
 	struct sched_attr attr = {};
 	unsigned int size;
+	bool is_set = false;
 
 	if (usize) {
 		/* called from sched_getattr */
@@ -104,6 +112,8 @@ print_sched_attr(struct tcb *const tcp,
 		size = attr.size;
 	} else {
 		/* called from sched_setattr */
+		is_set = true;
+
 		if (umove_or_printaddr(tcp, addr, &attr.size))
 			return;
 		usize = attr.size;
@@ -116,34 +126,47 @@ print_sched_attr(struct tcb *const tcp,
 		}
 	}
 
-	tprintf("{size=%u", attr.size);
+	PRINT_FIELD_U("{", attr, size);
 
-	if (size >= SCHED_ATTR_MIN_SIZE) {
-		tprints(", sched_policy=");
-		printxval(schedulers, attr.sched_policy, "SCHED_???");
-		tprints(", sched_flags=");
-		printflags64(sched_flags, attr.sched_flags, "SCHED_FLAG_???");
-
-#define PRINT_SCHED_FIELD(field, fmt)			\
-		tprintf(", " #field "=%" fmt, attr.field)
-
-		PRINT_SCHED_FIELD(sched_nice, "d");
-		PRINT_SCHED_FIELD(sched_priority, "u");
-		PRINT_SCHED_FIELD(sched_runtime, PRIu64);
-		PRINT_SCHED_FIELD(sched_deadline, PRIu64);
-		PRINT_SCHED_FIELD(sched_period, PRIu64);
+	if (size < SCHED_ATTR_MIN_SIZE)
+		goto end;
 
-		if (usize > size)
-			tprints(", ...");
+	if (!is_set
+	    || (int) attr.sched_policy < 0
+	    || !(attr.sched_flags & (SCHED_FLAG_KEEP_POLICY
+				     | SCHED_FLAG_KEEP_PARAMS)))
+		PRINT_FIELD_XVAL(", ", attr, sched_policy, schedulers,
+				 "SCHED_???");
+	PRINT_FIELD_FLAGS(", ", attr, sched_flags, sched_flags,
+			  "SCHED_FLAG_???");
+
+
+	if (!is_set || !(attr.sched_flags & SCHED_FLAG_KEEP_PARAMS)) {
+		PRINT_FIELD_D(", ", attr, sched_nice);
+		PRINT_FIELD_U(", ", attr, sched_priority);
+		PRINT_FIELD_U(", ", attr, sched_runtime);
+		PRINT_FIELD_U(", ", attr, sched_deadline);
+		PRINT_FIELD_U(", ", attr, sched_period);
 	}
 
+	if (size < SCHED_ATTR_SIZE_VER1)
+		goto end;
+
+	PRINT_FIELD_U(", ", attr, sched_util_min);
+	PRINT_FIELD_U(", ", attr, sched_util_max);
+
+end:
+	if ((is_set ? usize : attr.size) > size)
+		tprints(", ...");
+
 	tprints("}");
 }
 
 SYS_FUNC(sched_setattr)
 {
 	if (entering(tcp)) {
-		tprintf("%d, ", (int) tcp->u_arg[0]);
+		printpid(tcp, tcp->u_arg[0], PT_TGID);
+		tprints(", ");
 		print_sched_attr(tcp, tcp->u_arg[1], 0);
 	} else {
 		struct sched_attr attr;
@@ -162,7 +185,8 @@ SYS_FUNC(sched_setattr)
 SYS_FUNC(sched_getattr)
 {
 	if (entering(tcp)) {
-		tprintf("%d, ", (int) tcp->u_arg[0]);
+		printpid(tcp, tcp->u_arg[0], PT_TGID);
+		tprints(", ");
 	} else {
 		const unsigned int size = tcp->u_arg[2];
 
diff -pruN 5.5-3/signal.c 5.9-0ubuntu2/signal.c
--- 5.5-3/signal.c	2019-07-10 16:12:44.000000000 +0000
+++ 5.9-0ubuntu2/signal.c	2020-08-25 14:29:30.000000000 +0000
@@ -6,7 +6,7 @@
  * Copyright (c) 1999 IBM Deutschland Entwicklung GmbH, IBM Corporation
  *                     Linux for s390 port by D.J. Barrow
  *                    <barrow_dj@mail.yahoo.com,djbarrow@de.ibm.com>
- * Copyright (c) 2001-2019 The strace developers.
+ * Copyright (c) 1999-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -439,17 +439,31 @@ SYS_FUNC(sigprocmask)
 SYS_FUNC(kill)
 {
 	/* pid */
-	tprintf("%d, ", (int) tcp->u_arg[0]);
+	printpid_tgid_pgid(tcp, tcp->u_arg[0]);
+	tprints(", ");
 	/* signal */
 	printsignal(tcp->u_arg[1]);
 
 	return RVAL_DECODED;
 }
 
+SYS_FUNC(tkill)
+{
+	printpid(tcp, tcp->u_arg[0], PT_TID);
+	tprints(", ");
+	printsignal(tcp->u_arg[1]);
+
+	return RVAL_DECODED;
+}
+
 SYS_FUNC(tgkill)
 {
-	/* tgid, tid */
-	tprintf("%d, %d, ", (int) tcp->u_arg[0], (int) tcp->u_arg[1]);
+	/* tgid */
+	printpid(tcp, tcp->u_arg[0], PT_TGID);
+	tprints(", ");
+	/* tid */
+	printpid(tcp, tcp->u_arg[1], PT_TID);
+	tprints(", ");
 	/* signal */
 	printsignal(tcp->u_arg[2]);
 
@@ -615,7 +629,8 @@ print_sigqueueinfo(struct tcb *const tcp
 
 SYS_FUNC(rt_sigqueueinfo)
 {
-	tprintf("%d, ", (int) tcp->u_arg[0]);
+	printpid(tcp, tcp->u_arg[0], PT_TGID);
+	tprints(", ");
 	print_sigqueueinfo(tcp, tcp->u_arg[1], tcp->u_arg[2]);
 
 	return RVAL_DECODED;
@@ -623,7 +638,10 @@ SYS_FUNC(rt_sigqueueinfo)
 
 SYS_FUNC(rt_tgsigqueueinfo)
 {
-	tprintf("%d, %d, ", (int) tcp->u_arg[0], (int) tcp->u_arg[1]);
+	printpid(tcp, tcp->u_arg[0], PT_TGID);
+	tprints(", ");
+	printpid(tcp, tcp->u_arg[1], PT_TID);
+	tprints(", ");
 	print_sigqueueinfo(tcp, tcp->u_arg[2], tcp->u_arg[3]);
 
 	return RVAL_DECODED;
diff -pruN 5.5-3/sockaddr.c 5.9-0ubuntu2/sockaddr.c
--- 5.5-3/sockaddr.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/sockaddr.c	2020-08-25 14:29:30.000000000 +0000
@@ -47,7 +47,7 @@ const size_t arp_hardware_types_size = A
 const size_t ethernet_protocols_size = ARRAY_SIZE(ethernet_protocols) - 1;
 
 static void
-print_sockaddr_data_un(const void *const buf, const int addrlen)
+print_sockaddr_data_un(struct tcb *tcp, const void *const buf, const int addrlen)
 {
 	const struct sockaddr_un *const sa_un = buf;
 	const int un_len = addrlen > (int) sizeof(*sa_un)
@@ -172,7 +172,8 @@ decode_inet_addr(struct tcb *const tcp,
 }
 
 static void
-print_sockaddr_data_in(const void *const buf, const int addrlen)
+print_sockaddr_data_in(struct tcb *tcp, const void *const buf,
+		       const int addrlen)
 {
 	const struct sockaddr_in *const sa_in = buf;
 
@@ -183,7 +184,8 @@ print_sockaddr_data_in(const void *const
 #define SIN6_MIN_LEN offsetof(struct sockaddr_in6, sin6_scope_id)
 
 static void
-print_sockaddr_data_in6(const void *const buf, const int addrlen)
+print_sockaddr_data_in6(struct tcb *tcp, const void *const buf,
+			const int addrlen)
 {
 	const struct sockaddr_in6 *const sa_in6 = buf;
 
@@ -322,7 +324,8 @@ print_ax25_addr(const void /* ax25_addre
 }
 
 static void
-print_sockaddr_data_ax25(const void *const buf, const int addrlen)
+print_sockaddr_data_ax25(struct tcb *tcp, const void *const buf,
+			 const int addrlen)
 {
 	const struct full_sockaddr_ax25 *const sax25 = buf;
 	size_t addrlen_us = MAX(addrlen, 0);
@@ -372,7 +375,8 @@ digis_end:
 }
 
 static void
-print_sockaddr_data_ipx(const void *const buf, const int addrlen)
+print_sockaddr_data_ipx(struct tcb *tcp, const void *const buf,
+			const int addrlen)
 {
 	const struct sockaddr_ipx *const sa_ipx = buf;
 	unsigned int i;
@@ -399,7 +403,8 @@ print_x25_addr(const void /* struct x25_
 }
 
 static void
-print_sockaddr_data_x25(const void *const buf, const int addrlen)
+print_sockaddr_data_x25(struct tcb *tcp, const void *const buf,
+			const int addrlen)
 {
 	const struct sockaddr_x25 *const sa_x25 = buf;
 
@@ -407,11 +412,11 @@ print_sockaddr_data_x25(const void *cons
 }
 
 static void
-print_sockaddr_data_nl(const void *const buf, const int addrlen)
+print_sockaddr_data_nl(struct tcb *tcp, const void *const buf, const int addrlen)
 {
 	const struct sockaddr_nl *const sa_nl = buf;
 
-	PRINT_FIELD_D("", *sa_nl, nl_pid);
+	PRINT_FIELD_TGID("", *sa_nl, nl_pid, tcp);
 	PRINT_FIELD_0X(", ", *sa_nl, nl_groups);
 }
 
@@ -442,7 +447,8 @@ print_sll_protocol(const struct sockaddr
 }
 
 static void
-print_sockaddr_data_ll(const void *const buf, const int addrlen)
+print_sockaddr_data_ll(struct tcb *tcp, const void *const buf,
+		       const int addrlen)
 {
 	const struct sockaddr_ll *const sa_ll = buf;
 
@@ -567,7 +573,8 @@ print_bluetooth_l2_cid_end:
 }
 
 static void
-print_sockaddr_data_bt(const void *const buf, const int addrlen)
+print_sockaddr_data_bt(struct tcb *tcp, const void *const buf,
+		       const int addrlen)
 {
 	struct sockaddr_hci {
 		/* sa_family_t */ uint16_t	hci_family;
@@ -651,7 +658,7 @@ print_sockaddr_data_bt(const void *const
 	}
 }
 
-typedef void (* const sockaddr_printer)(const void *const, const int);
+typedef void (* const sockaddr_printer)(struct tcb *tcp, const void *const, const int);
 
 static const struct {
 	const sockaddr_printer printer;
@@ -669,7 +676,7 @@ static const struct {
 };
 
 void
-print_sockaddr(const void *const buf, const int addrlen)
+print_sockaddr(struct tcb *tcp, const void *const buf, const int addrlen)
 {
 	const struct sockaddr *const sa = buf;
 
@@ -682,7 +689,7 @@ print_sockaddr(const void *const buf, co
 		if (sa->sa_family < ARRAY_SIZE(sa_printers)
 		    && sa_printers[sa->sa_family].printer
 		    && addrlen >= sa_printers[sa->sa_family].min_len) {
-			sa_printers[sa->sa_family].printer(buf, addrlen);
+			sa_printers[sa->sa_family].printer(tcp, buf, addrlen);
 		} else {
 			print_sockaddr_data_raw(buf, addrlen);
 		}
@@ -713,7 +720,7 @@ decode_sockaddr(struct tcb *const tcp, c
 
 	memset(&addrbuf.pad[addrlen], 0, sizeof(addrbuf.pad) - addrlen);
 
-	print_sockaddr(&addrbuf, addrlen);
+	print_sockaddr(tcp, &addrbuf, addrlen);
 
 	return addrbuf.sa.sa_family;
 }
diff -pruN 5.5-3/sock.c 5.9-0ubuntu2/sock.c
--- 5.5-3/sock.c	2019-07-24 17:12:18.000000000 +0000
+++ 5.9-0ubuntu2/sock.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 1993, 1994, 1995, 1996 Rick Sladkey <jrs@world.std.com>
- * Copyright (c) 1996-2018 The strace developers.
+ * Copyright (c) 1996-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -44,19 +44,19 @@ print_ifreq(struct tcb *const tcp, const
 	switch (code) {
 	case SIOCSIFADDR:
 	case SIOCGIFADDR:
-		PRINT_FIELD_SOCKADDR("", *ifr, ifr_addr);
+		PRINT_FIELD_SOCKADDR("", *ifr, ifr_addr, tcp);
 		break;
 	case SIOCSIFDSTADDR:
 	case SIOCGIFDSTADDR:
-		PRINT_FIELD_SOCKADDR("", *ifr, ifr_dstaddr);
+		PRINT_FIELD_SOCKADDR("", *ifr, ifr_dstaddr, tcp);
 		break;
 	case SIOCSIFBRDADDR:
 	case SIOCGIFBRDADDR:
-		PRINT_FIELD_SOCKADDR("", *ifr, ifr_broadaddr);
+		PRINT_FIELD_SOCKADDR("", *ifr, ifr_broadaddr, tcp);
 		break;
 	case SIOCSIFNETMASK:
 	case SIOCGIFNETMASK:
-		PRINT_FIELD_SOCKADDR("", *ifr, ifr_netmask);
+		PRINT_FIELD_SOCKADDR("", *ifr, ifr_netmask, tcp);
 		break;
 	case SIOCSIFHWADDR:
 	case SIOCGIFHWADDR: {
@@ -126,7 +126,7 @@ print_ifconf_ifreq(struct tcb *tcp, void
 
 	tprints("{ifr_name=");
 	print_ifname(ifr->ifr_name);
-	PRINT_FIELD_SOCKADDR(", ", *ifr, ifr_addr);
+	PRINT_FIELD_SOCKADDR(", ", *ifr, ifr_addr, tcp);
 	tprints("}");
 
 	return true;
diff -pruN 5.5-3/statx.c 5.9-0ubuntu2/statx.c
--- 5.5-3/statx.c	2019-07-11 17:51:22.000000000 +0000
+++ 5.9-0ubuntu2/statx.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -49,19 +49,19 @@ SYS_FUNC(statx)
 		if (umove_or_printaddr(tcp, tcp->u_arg[4], &stx))
 			return 0;
 
-		tprints("{stx_mask=");
-		printflags(statx_masks, stx.stx_mask, "STATX_???");
+		PRINT_FIELD_FLAGS("{", stx, stx_mask, statx_masks,
+				  "STATX_???");
 
 		if (!abbrev(tcp))
 			PRINT_FIELD_U(", ", stx, stx_blksize);
 
-		tprints(", stx_attributes=");
-		printflags(statx_attrs, stx.stx_attributes, "STATX_ATTR_???");
+		PRINT_FIELD_FLAGS(", ", stx, stx_attributes, statx_attrs,
+				  "STATX_ATTR_???");
 
 		if (!abbrev(tcp)) {
 			PRINT_FIELD_U(", ", stx, stx_nlink);
-			printuid(", stx_uid=", stx.stx_uid);
-			printuid(", stx_gid=", stx.stx_gid);
+			PRINT_FIELD_UID(", ", stx, stx_uid);
+			PRINT_FIELD_UID(", ", stx, stx_gid);
 		}
 
 		tprints(", stx_mode=");
@@ -74,11 +74,8 @@ SYS_FUNC(statx)
 
 		if (!abbrev(tcp)) {
 			PRINT_FIELD_U(", ", stx, stx_blocks);
-
-			tprints(", stx_attributes_mask=");
-			printflags(statx_attrs, stx.stx_attributes_mask,
-				   "STATX_ATTR_???");
-
+			PRINT_FIELD_FLAGS(", ", stx, stx_attributes_mask,
+					  statx_attrs, "STATX_ATTR_???");
 			PRINT_FIELD_TIME(stx_atime);
 			PRINT_FIELD_TIME(stx_btime);
 			PRINT_FIELD_TIME(stx_ctime);
diff -pruN 5.5-3/strace.1 5.9-0ubuntu2/strace.1
--- 5.5-3/strace.1	2020-02-06 16:23:56.000000000 +0000
+++ 5.9-0ubuntu2/strace.1	2020-09-24 09:19:37.000000000 +0000
@@ -33,16 +33,19 @@
 .  el \
 .    BR "\\$1"
 ..
-.TH STRACE 1 "2020-02-04" "strace 5.5"
+.TH STRACE 1 "2020-09-23" "strace 5.9"
 .SH NAME
 strace \- trace system calls and signals
 .SH SYNOPSIS
 .SY strace
-.if '#'#' .OP \-ACdffhikqqrtttTvVwxxyyzZ
-.if ''#' .OP \-ACdffhiqqrtttTvVwxxyyzZ
+.if ''#' .OP \-ACdffhikqqrtttTvVwxxyyzZ
+.if '#'#' .OP \-ACdffhiqqrtttTvVwxxyyzZ
 .OP \-I n
 .OP \-b execve
 .OM \-e expr
+.OP \-O overhead
+.OP \-S sortby
+.OP \-U columns
 .OP \-a column
 .OP \-o file
 .OP \-s strsize
@@ -67,6 +70,7 @@ strace \- trace system calls and signals
 .OM \-e expr
 .OP \-O overhead
 .OP \-S sortby
+.OP \-U columns
 .OM \-P path
 .OM \-p pid
 .OP \-\-seccomp\-bpf
@@ -153,9 +157,9 @@ This example shows the shell performing
 .CW
 open("xyzzy", O_WRONLY|O_APPEND|O_CREAT, 0666) = 3
 .CE
-Here, the third argument of
+Here, the second and the third argument of
 .BR open (2)
-is decoded by breaking down the
+are decoded by breaking down the
 flag argument into its three bitwise-OR constituents and printing the
 mode value in octal by tradition.  Where the traditional or native
 usage differs from ANSI or POSIX, the latter forms are preferred.
@@ -243,16 +247,18 @@ or how to trace them.  The format of the
 where
 .I qualifier
 is one of
-.BR trace ,
-.BR abbrev ,
-.BR verbose ,
-.BR raw ,
-.BR signal ,
-.BR read ,
-.BR write ,
+.BR trace " (or " t ),
+.BR abbrev " (or " a ),
+.BR verbose " (or " v ),
+.BR raw " (or " x ),
+.BR signal " (or " signals " or " s ),
+.BR read " (or " reads " or " r ),
+.BR write " (or " writes " or " w ),
 .BR fault ,
 .BR inject ,
 .BR status ,
+.BR quiet " (or " silent " or " silence " or " q ),
+.BR decode\-fds " (or " decode\-fd ),
 or
 .BR kvm ,
 and
@@ -343,12 +349,20 @@ multi-threaded process and therefore req
 but don't want to trace its (potentially very complex) children.
 .TP
 .B \-D
+.TQ
+.B \-\-daemonize
+.TQ
+.BR \-\-daemonize = grandchild
 Run tracer process as a grandchild, not as the parent of the
 tracee.  This reduces the visible effect of
 .B strace
 by keeping the tracee a direct child of the calling process.
 .TP
 .B \-DD
+.TQ
+.BR \-\-daemonize = pgroup
+.TQ
+.BR \-\-daemonize = pgrp
 Run tracer process as tracee's grandchild in a separate process group.
 In addition to reduction of the visible effect of
 .BR strace ,
@@ -359,6 +373,8 @@ with
 issued to the whole process group.
 .TP
 .B \-DDD
+.TQ
+.BR \-\-daemonize = session
 Run tracer process as tracee's grandchild in a separate session
 ("true daemonisation").
 In addition to reduction of the visible effect of
@@ -368,6 +384,8 @@ it also avoids killing of
 upon session termination.
 .TP
 .B \-f
+.TQ
+.BR \-\-follow\-forks
 Trace child processes as they are created by currently traced
 processes as a result of the
 .BR fork (2),
@@ -383,15 +401,23 @@ will attach all threads of process
 if it is multi-threaded, not only thread with
 .IR thread_id " = " PID .
 .TP
-.B \-ff
+.B \-\-output\-separately
 If the
-.B \-o
-.I filename
+.BR \-\-output = \fIfilename\fR
 option is in effect, each processes trace is written to
 .IR filename . pid
 where
 .I pid
 is the numeric process id of each process.
+.TP
+.B \-ff
+.TQ
+.B \-\-follow\-forks \-\-output\-separately
+Combine the effects of
+.B \-\-follow\-forks
+and
+.B \-\-output\-separately
+options.
 This is incompatible with
 .BR \-c ,
 since no per-process counts are kept.
@@ -401,23 +427,25 @@ One might want to consider using
 to obtain a combined strace log view.
 .TP
 .BI "\-I " interruptible
+.TQ
+.BR "\-\-interruptible" = \fIinterruptible\fR
 When
 .B strace
 can be interrupted by signals (such as pressing
 .BR CTRL\-C ).
 .RS
-.TP 4
-.B 1
+.TP 15
+.BR 1 ", " anywhere
 no signals are blocked;
 .TQ
-.B 2
+.BR 2 ", " waiting
 fatal signals are blocked while decoding syscall (default);
 .TQ
-.B 3
+.BR 3 ", " never
 fatal signals are always blocked (default if
 .BR -o " " \fIFILE\fR " " \fIPROG\fR );
 .TQ
-.B 4
+.BR 4 ", " never_tstp
 fatal signals and
 .BR SIGTSTP " (" CTRL\-Z )
 are always blocked (useful to make
@@ -490,8 +518,8 @@ is deprecated.
 .B %process
 .TQ
 .B process
-Trace all system calls which involve process management.  This
-is useful for watching the fork, wait, and exec steps of a process.
+Trace system calls associated with process lifecycle
+(creation, exec, termination).
 The syntax without a preceding percent sign
 .RB (\[dq] "-e trace" = process \[dq])
 is deprecated.
@@ -548,7 +576,7 @@ Trace stat syscall variants.
 Trace lstat syscall variants.
 .TP
 .BR %fstat
-Trace fstat and fstatat syscall variants.
+Trace fstat, fstatat, and statx syscall variants.
 .TP
 .BR %%stat
 Trace syscalls used for requesting file status (stat, lstat, fstat, fstatat,
@@ -572,6 +600,9 @@ and ustat).  The same effect can be achi
 .BR "\-e\ trace" = /statv?fs|fsstat|ustat
 regular expression.
 .TP
+.BR %clock
+Trace system calls that read or modify system clocks.
+.TP
 .BR %pure
 Trace syscalls that always succeed and have no arguments.
 Currently, this list includes
@@ -675,9 +706,13 @@ Multiple
 options can be used to specify several paths.
 .TP
 .B \-z
+.TQ
+.B \-\-successful\-only
 Print only syscalls that returned without an error code.
 .TP
 .B \-Z
+.TQ
+.B \-\-failed\-only
 Print only syscalls that returned with an error code.
 .SS Output format
 .TP 12
@@ -763,6 +798,69 @@ Note that this is independent from the n
 system call which is controlled by the option
 .BR -e "\ " trace = write .
 .TP
+\fB\-e\ quiet\fR=\,\fIset\fR
+.TQ
+\fB\-\-quiet\fR=\,\fIset\fR
+.TQ
+\fB\-\-silent\fR=\,\fIset\fR
+.TQ
+\fB\-\-silence\fR=\,\fIset\fR
+Suppress various information messages.  The default is
+.BR quiet = none .
+.I set
+can include the following elements:
+.RS
+.TP 17
+.B attach
+Suppress messages about attaching and detaching
+.RB (\[dq] "[ Process NNNN attached ]" "\[dq],"
+.RB "\[dq]" "[ Process NNNN detached ]" "\[dq])."
+.TQ
+.B exit
+Suppress messages about process exits
+.RB (\[dq] "+++ exited with SSS +++" \[dq]).
+.TQ
+.B path-resolution
+Suppress messages about resolution of paths provided via the
+.B \-P
+option
+.RB (\[dq] "Requested path \[dq]...\[dq] resolved into \[dq]...\[dq]" \[dq]).
+.TQ
+.B personality
+Suppress messages about process personality changes
+.RB (\[dq] "[ Process PID=NNNN runs in PPP mode. ]" \[dq]).
+.TQ
+.B thread-execve
+.TQ
+.B superseded
+Suppress messages about process being superseded by
+.BR execve (2)
+in another thread
+.RB (\[dq] "+++ superseded by execve in pid NNNN +++" \[dq]).
+.RE
+.TP
+\fB\-e\ decode\-fds\fR=\,\fIset\fR
+.TQ
+\fB\-\-decode\-fds\fR=\,\fIset\fR
+Decode various information associated with file descriptors.  The default is
+.BR decode\-fds = none .
+.I set
+can include the following elements:
+.RS
+.TP 8
+.B path
+Print file paths.
+.TQ
+.B socket
+Print socket protocol-specific information,
+.TQ
+.B dev
+Print character/block device numbers.
+.TQ
+.B pidfd
+Print PIDs associated with pidfd file descriptors.
+.RE
+.TP
 .BR "\-e\ kvm" = vcpu
 .TQ
 .BR "\-\-kvm" = vcpu
@@ -773,12 +871,17 @@ or higher.
 .TQ
 .B \-\-instruction\-pointer
 Print the instruction pointer at the time of the system call.
-.if '#'#' .TP
-.if '#'#' .B \-k
-.if '#'#' .TQ
-.if '#'#' .B \-\-stack\-traces
-.if '#'#' Print the execution stack trace of the traced
-.if '#'#' processes after each system call.
+.TP
+.B \-n
+.TQ
+.B \-\-syscall\-number
+Print the syscall number.
+.if ''#' .TP
+.if ''#' .B \-k
+.if ''#' .TQ
+.if ''#' .B \-\-stack\-traces
+.if ''#' Print the execution stack trace of the traced
+.if ''#' processes after each system call.
 .TP
 .BI "\-o " filename
 .TQ
@@ -806,17 +909,40 @@ Open the file provided in the
 option in append mode.
 .TP
 .B \-q
-Suppress messages about attaching, detaching etc.  This happens
-automatically when output is redirected to a file and the command
-is run directly instead of attaching.
+.TQ
+.B \-\-quiet
+.TQ
+.BR \-\-quiet = attach , personality
+Suppress messages about attaching, detaching, and personality changes.
+This happens automatically when output is redirected to a file
+and the command is run directly instead of attaching.
 .TP
 .B \-qq
-If given twice, suppress messages about process exit status.
+.TQ
+.BR \-\-quiet = attach , personality , exit
+Suppress messages attaching, detaching, personality changes,
+and about process exit status.
+.TP
+.B \-qqq
+.TQ
+.BR \-\-quiet = all
+Suppress all suppressible messages (please refer to the
+.B -e quiet
+option description for the full list of suppressible messages).
 .TP
 .B \-r
+.TQ
+.BR \-\-relative\-timestamps [= \fIprecision\fR ]
 Print a relative timestamp upon entry to each system call.  This
 records the time difference between the beginning of successive
 system calls.
+.I precision
+can be one of
+.BR s " (for seconds), " ms " (milliseconds), " us " (microseconds), or " ns
+(nanoseconds), and allows setting the precision of time value being printed.
+Default is
+.B us
+(microseconds).
 Note that since
 .B \-r
 option uses the monotonic clock time for measuring time difference and not the
@@ -832,20 +958,70 @@ Specify the maximum string size to print
 that filenames are not considered strings and are always printed in
 full.
 .TP
+.BR \-\-absolute\-timestamps [=[[ format: ] \fIformat\fR ],[[ precision: ] \fIprecision ]]
+.TQ
+.BR \-\-timestamps [=[[ format: ] \fIformat\fR ],[[ precision: ] \fIprecision ]]
+Prefix each line of the trace with the wall clock time in the specified
+.I format
+with the specified
+.IR precision .
+.I format
+can be one of the following:
+.RS
+.TP 14
+.B none
+No time stamp is printed.
+Can be used to override the previous setting.
+.TQ
+.B time
+Wall clock time
+.RB ( strftime (3)
+format string is
+.BR %T ).
+.TQ
+.B unix
+Number of seconds since the epoch
+.RB ( strftime (3)
+format string is
+.BR %s ).
+.RE
+.IP
+.I precision
+can be one of
+.BR s " (for seconds), " ms " (milliseconds), " us " (microseconds), or " ns
+(nanoseconds).
+Default arguments for the option are
+.BR format:time , precision:s .
+.TP
 .B \-t
+.TQ
+.B \-\-absolute\-timestamps
 Prefix each line of the trace with the wall clock time.
 .TP
 .B \-tt
+.TQ
+.BR \-\-absolute\-timestamps = precision:us
 If given twice, the time printed will include the microseconds.
 .TP
 .B \-ttt
+.TQ
+.BR \-\-absolute\-timestamps = format:unix , precision:us
 If given thrice, the time printed will include the microseconds
 and the leading portion will be printed as the number
 of seconds since the epoch.
 .TP
 .B \-T
+.TQ
+.BR \-\-syscall\-times [= \fIprecision\fR ]
 Show the time spent in system calls.  This records the time
 difference between the beginning and the end of each system call.
+.I precision
+can be one of
+.BR s " (for seconds), " ms " (milliseconds), " us " (microseconds), or " ns
+(nanoseconds), and allows setting the precision of time value being printed.
+Default is
+.B us
+(microseconds).
 .TP
 .B \-v
 .TQ
@@ -856,9 +1032,15 @@ behavior displays a reasonable subset of
 this option to get all of the gory details.
 .TP
 .B \-x
+.TQ
+.BR \-\-strings\-in\-hex = \fInon\-ascii\fR
 Print all non-ASCII strings in hexadecimal string format.
 .TP
 .B \-xx
+.TQ
+.B \-\-strings\-in\-hex
+.TQ
+.BR \-\-strings\-in\-hex = \fIall\fR
 Print all strings in hexadecimal string format.
 .TP
 .BI "\-X " format
@@ -885,11 +1067,23 @@ Output both the raw value and the decode
 .RE
 .TP
 .B \-y
+.TQ
+.B \-\-decode\-fds
+.TQ
+.BR \-\-decode\-fds = path
 Print paths associated with file descriptor arguments.
 .TP
 .B \-yy
-Print protocol specific information associated with socket file descriptors,
-and block/character device number associated with device file descriptors.
+.TQ
+.BR \-\-decode\-fds = all
+Print all available information associated with file descritors:
+protocol-specific information associated with socket file descriptors,
+block/character device number associated with device file descriptors,
+and PIDs asociated with pidfd file descriptors.
+.TP
+.B \-\-pidns\-translation
+If strace and tracee are in different PID namespaces, print PIDs in
+strace's namespace, too.
 .SS Statistics
 .TP 12
 .B \-c
@@ -912,6 +1106,8 @@ Like
 but also print regular output while processes are running.
 .TP
 .BI "\-O " overhead
+.TQ
+.BR "\-\-summary\-syscall\-overhead " = \fIoverhead\fR
 Set the overhead for tracing system calls to
 .IR overhead .
 This is useful for overriding the default heuristic for guessing
@@ -936,15 +1132,60 @@ specification is described in section
 Sort the output of the histogram printed by the
 .B \-c
 option by the specified criterion.  Legal values are
-.BR time " (or " time_total " or " total_time ),
+.BR time " (or " time\-percent " or " time\-total " or " total\-time ),
+.BR min\-time " (or " shortest " or " time\-min ),
+.BR max\-time " (or " longest " or " time\-max ),
+.BR avg\-time " (or " time\-avg ),
 .BR calls " (or " count ),
 .BR errors " (or " error ),
-.BR name " (or " syscall " or " syscall_name ),
+.BR name " (or " syscall " or " syscall\-name ),
 and
 .BR nothing " (or " none );
 default is
 .BR time .
 .TP
+.BI "\-U " columns
+.TQ
+.BR "\-\-summary\-columns" = \fIcolumns\fR
+Configure a set (and order) of columns being shown in the call summary.
+The
+.I columns
+argument is a comma-separated list with items being one of the following:
+.RS
+.TP 36
+.BR time\-percent " (or " time )
+Percentage of cumulative time consumed by a specific system call.
+.TQ
+.BR total\-time " (or " time\-total )
+Total system (or wall clock, if
+.B \-w
+option is provided) time consumed by a specific system call.
+.TQ
+.BR min\-time " (or " shortest " or " time\-min )
+Minimum observed call duration.
+.TQ
+.BR max\-time " (or " longest " or " time\-max )
+Maximum observed call duration.
+.TQ
+.BR avg\-time " (or " time\-avg )
+Average call duration.
+.TQ
+.BR calls " (or " count )
+Call count.
+.TQ
+.BR errors " (or " error )
+Error count.
+.TQ
+.BR name " (or " syscall " or " syscall\-name )
+Syscall name.
+.RE
+.IP
+The default value is
+.BR time\-percent , total\-time , avg\-time , calls , errors , name .
+If the
+.B name
+field is not supplied explicitly, it is added as the last column.
+.TP
 .B \-w
 .TQ
 .B \-\-summary\-wall\-clock
@@ -1033,9 +1274,22 @@ Unless a :\fBwhen\fR=\,\fIexpr\fR subexp
 an injection is being made into every invocation of each syscall from the
 .IR set .
 .IP
-The format of the subexpression is one of the following:
+The format of the subexpression is:
+.RS 15
+.IP
+\fIfirst\/\fR[\fB..\fR\,\fIlast\/\fR][\fB+\fR[\,\fIstep\/\fR]]
+.RE
+.IP
+Number
+.I first
+stands for the first invocation number in the range, number
+.I last
+stands for the last invocation number in the range, and
+.I step
+stands for the step between two consecutive invocations.
+The following combinations are useful:
 .RS
-.TP 12
+.TP 18
 .I first
 For every syscall from the
 .IR set ,
@@ -1043,6 +1297,15 @@ perform an injection for the syscall inv
 .I first
 only.
 .TQ
+\fIfirst\/\fB..\fR\,\fIlast\fR
+For every syscall from the
+.IR set ,
+perform an injection for the syscall invocation number
+.I first
+and all subsequent invocations until the invocation number
+.I last
+(inclusive).
+.TQ
 \fIfirst\/\fB+\fR
 For every syscall from the
 .IR set ,
@@ -1050,7 +1313,16 @@ perform injections for the syscall invoc
 .I first
 and all subsequent invocations.
 .TQ
-\fIfirst\/\fB+\fIstep\fR
+\fIfirst\/\fB..\fR\,\fIlast\/\fB+\fR
+For every syscall from the
+.IR set ,
+perform injections for the syscall invocation number
+.I first
+and all subsequent invocations until the invocation number
+.I last
+(inclusive).
+.TQ
+\fIfirst\/\fB+\fR\,\fIstep\fR
 For every syscall from the
 .IR set ,
 perform injections for syscall invocations number
@@ -1058,6 +1330,11 @@ perform injections for syscall invocatio
 .IR first + step ,
 .IR first + step + step ,
 and so on.
+.TQ
+\fIfirst\/\fB..\fR\,\fIlast\fB+\fR\,\fIstep\fR
+Same as the previous, but consider only syscall invocations with numbers up to
+.I last
+(inclusive).
 .RE
 .IP
 For example, to fail each third and subsequent chdir syscalls with
@@ -1069,7 +1346,9 @@ The valid range for numbers
 .I first
 and
 .I step
-is 1..65535.
+is 1..65535, and for number
+.I last
+is 1..65534.
 .IP
 An injection expression can contain only one
 .BR error =
@@ -1124,22 +1403,22 @@ option.
 Print the help summary.
 .TP
 .B \-\-seccomp\-bpf
-Enable (experimental) usage of seccomp-bpf (see
+Try to enable use of seccomp-bpf (see
 .BR seccomp (2))
 to have
 .BR ptrace (2)-stops
 only when system calls that are being traced occur in the traced processes.
-Implies the
-.B \-f
-option.
-An attempt to rely on seccomp-bpf to filter system calls may fail for various
-reasons, e.g. there are too many system calls to filter, the seccomp API is not
-available, or
+This option has no effect unless
+.BR \-f / \-\-follow\-forks
+is also specified.
+.B \-\-seccomp\-bpf
+is also not applicable to processes attached using
+.BR \-p / \-\-attach
+option.  An attempt to enable system calls filtering using seccomp-bpf may
+fail for various reasons, e.g. there are too many system calls to filter,
+the seccomp API is not available, or
 .B strace
 itself is being traced.
-.B \-\-seccomp\-bpf
-is also ineffective on processes attached using
-.BR \-p .
 In cases when seccomp-bpf filter setup failed,
 .B strace
 proceeds as usual and stops traced processes on every system call.
@@ -1378,7 +1657,9 @@ effective user
 .SM ID
 privileges while being traced.
 .LP
-A traced process runs slowly.
+A traced process runs slowly (but check out the
+.B \-\-seccomp\-bpf
+option).
 .LP
 Traced processes which are descended from
 .I command
@@ -1440,7 +1721,7 @@ Since 2009,
 .B strace
 is actively maintained by Dmitry Levin.
 .B strace
-gained support for AArch64, ARC, AVR32, Blackfin, Meta, Nios II, OpenSISC 1000,
+gained support for AArch64, ARC, AVR32, Blackfin, Meta, Nios II, OpenRISC 1000,
 RISC-V, Tile/TileGx, Xtensa architectures since that time.
 In 2012, unmaintained and apparently broken support for non-Linux operating
 systems was removed.
diff -pruN 5.5-3/strace.1.in 5.9-0ubuntu2/strace.1.in
--- 5.5-3/strace.1.in	2020-02-04 18:46:22.000000000 +0000
+++ 5.9-0ubuntu2/strace.1.in	2020-09-23 16:29:35.000000000 +0000
@@ -43,6 +43,9 @@ strace \- trace system calls and signals
 .OP \-I n
 .OP \-b execve
 .OM \-e expr
+.OP \-O overhead
+.OP \-S sortby
+.OP \-U columns
 .OP \-a column
 .OP \-o file
 .OP \-s strsize
@@ -67,6 +70,7 @@ strace \- trace system calls and signals
 .OM \-e expr
 .OP \-O overhead
 .OP \-S sortby
+.OP \-U columns
 .OM \-P path
 .OM \-p pid
 .OP \-\-seccomp\-bpf
@@ -153,9 +157,9 @@ This example shows the shell performing
 .CW
 open("xyzzy", O_WRONLY|O_APPEND|O_CREAT, 0666) = 3
 .CE
-Here, the third argument of
+Here, the second and the third argument of
 .BR open (2)
-is decoded by breaking down the
+are decoded by breaking down the
 flag argument into its three bitwise-OR constituents and printing the
 mode value in octal by tradition.  Where the traditional or native
 usage differs from ANSI or POSIX, the latter forms are preferred.
@@ -243,16 +247,18 @@ or how to trace them.  The format of the
 where
 .I qualifier
 is one of
-.BR trace ,
-.BR abbrev ,
-.BR verbose ,
-.BR raw ,
-.BR signal ,
-.BR read ,
-.BR write ,
+.BR trace " (or " t ),
+.BR abbrev " (or " a ),
+.BR verbose " (or " v ),
+.BR raw " (or " x ),
+.BR signal " (or " signals " or " s ),
+.BR read " (or " reads " or " r ),
+.BR write " (or " writes " or " w ),
 .BR fault ,
 .BR inject ,
 .BR status ,
+.BR quiet " (or " silent " or " silence " or " q ),
+.BR decode\-fds " (or " decode\-fd ),
 or
 .BR kvm ,
 and
@@ -343,12 +349,20 @@ multi-threaded process and therefore req
 but don't want to trace its (potentially very complex) children.
 .TP
 .B \-D
+.TQ
+.B \-\-daemonize
+.TQ
+.BR \-\-daemonize = grandchild
 Run tracer process as a grandchild, not as the parent of the
 tracee.  This reduces the visible effect of
 .B strace
 by keeping the tracee a direct child of the calling process.
 .TP
 .B \-DD
+.TQ
+.BR \-\-daemonize = pgroup
+.TQ
+.BR \-\-daemonize = pgrp
 Run tracer process as tracee's grandchild in a separate process group.
 In addition to reduction of the visible effect of
 .BR strace ,
@@ -359,6 +373,8 @@ with
 issued to the whole process group.
 .TP
 .B \-DDD
+.TQ
+.BR \-\-daemonize = session
 Run tracer process as tracee's grandchild in a separate session
 ("true daemonisation").
 In addition to reduction of the visible effect of
@@ -368,6 +384,8 @@ it also avoids killing of
 upon session termination.
 .TP
 .B \-f
+.TQ
+.BR \-\-follow\-forks
 Trace child processes as they are created by currently traced
 processes as a result of the
 .BR fork (2),
@@ -383,15 +401,23 @@ will attach all threads of process
 if it is multi-threaded, not only thread with
 .IR thread_id " = " PID .
 .TP
-.B \-ff
+.B \-\-output\-separately
 If the
-.B \-o
-.I filename
+.BR \-\-output = \fIfilename\fR
 option is in effect, each processes trace is written to
 .IR filename . pid
 where
 .I pid
 is the numeric process id of each process.
+.TP
+.B \-ff
+.TQ
+.B \-\-follow\-forks \-\-output\-separately
+Combine the effects of
+.B \-\-follow\-forks
+and
+.B \-\-output\-separately
+options.
 This is incompatible with
 .BR \-c ,
 since no per-process counts are kept.
@@ -401,23 +427,25 @@ One might want to consider using
 to obtain a combined strace log view.
 .TP
 .BI "\-I " interruptible
+.TQ
+.BR "\-\-interruptible" = \fIinterruptible\fR
 When
 .B strace
 can be interrupted by signals (such as pressing
 .BR CTRL\-C ).
 .RS
-.TP 4
-.B 1
+.TP 15
+.BR 1 ", " anywhere
 no signals are blocked;
 .TQ
-.B 2
+.BR 2 ", " waiting
 fatal signals are blocked while decoding syscall (default);
 .TQ
-.B 3
+.BR 3 ", " never
 fatal signals are always blocked (default if
 .BR -o " " \fIFILE\fR " " \fIPROG\fR );
 .TQ
-.B 4
+.BR 4 ", " never_tstp
 fatal signals and
 .BR SIGTSTP " (" CTRL\-Z )
 are always blocked (useful to make
@@ -490,8 +518,8 @@ is deprecated.
 .B %process
 .TQ
 .B process
-Trace all system calls which involve process management.  This
-is useful for watching the fork, wait, and exec steps of a process.
+Trace system calls associated with process lifecycle
+(creation, exec, termination).
 The syntax without a preceding percent sign
 .RB (\[dq] "-e trace" = process \[dq])
 is deprecated.
@@ -548,7 +576,7 @@ Trace stat syscall variants.
 Trace lstat syscall variants.
 .TP
 .BR %fstat
-Trace fstat and fstatat syscall variants.
+Trace fstat, fstatat, and statx syscall variants.
 .TP
 .BR %%stat
 Trace syscalls used for requesting file status (stat, lstat, fstat, fstatat,
@@ -572,6 +600,9 @@ and ustat).  The same effect can be achi
 .BR "\-e\ trace" = /statv?fs|fsstat|ustat
 regular expression.
 .TP
+.BR %clock
+Trace system calls that read or modify system clocks.
+.TP
 .BR %pure
 Trace syscalls that always succeed and have no arguments.
 Currently, this list includes
@@ -675,9 +706,13 @@ Multiple
 options can be used to specify several paths.
 .TP
 .B \-z
+.TQ
+.B \-\-successful\-only
 Print only syscalls that returned without an error code.
 .TP
 .B \-Z
+.TQ
+.B \-\-failed\-only
 Print only syscalls that returned with an error code.
 .SS Output format
 .TP 12
@@ -763,6 +798,69 @@ Note that this is independent from the n
 system call which is controlled by the option
 .BR -e "\ " trace = write .
 .TP
+\fB\-e\ quiet\fR=\,\fIset\fR
+.TQ
+\fB\-\-quiet\fR=\,\fIset\fR
+.TQ
+\fB\-\-silent\fR=\,\fIset\fR
+.TQ
+\fB\-\-silence\fR=\,\fIset\fR
+Suppress various information messages.  The default is
+.BR quiet = none .
+.I set
+can include the following elements:
+.RS
+.TP 17
+.B attach
+Suppress messages about attaching and detaching
+.RB (\[dq] "[ Process NNNN attached ]" "\[dq],"
+.RB "\[dq]" "[ Process NNNN detached ]" "\[dq])."
+.TQ
+.B exit
+Suppress messages about process exits
+.RB (\[dq] "+++ exited with SSS +++" \[dq]).
+.TQ
+.B path-resolution
+Suppress messages about resolution of paths provided via the
+.B \-P
+option
+.RB (\[dq] "Requested path \[dq]...\[dq] resolved into \[dq]...\[dq]" \[dq]).
+.TQ
+.B personality
+Suppress messages about process personality changes
+.RB (\[dq] "[ Process PID=NNNN runs in PPP mode. ]" \[dq]).
+.TQ
+.B thread-execve
+.TQ
+.B superseded
+Suppress messages about process being superseded by
+.BR execve (2)
+in another thread
+.RB (\[dq] "+++ superseded by execve in pid NNNN +++" \[dq]).
+.RE
+.TP
+\fB\-e\ decode\-fds\fR=\,\fIset\fR
+.TQ
+\fB\-\-decode\-fds\fR=\,\fIset\fR
+Decode various information associated with file descriptors.  The default is
+.BR decode\-fds = none .
+.I set
+can include the following elements:
+.RS
+.TP 8
+.B path
+Print file paths.
+.TQ
+.B socket
+Print socket protocol-specific information,
+.TQ
+.B dev
+Print character/block device numbers.
+.TQ
+.B pidfd
+Print PIDs associated with pidfd file descriptors.
+.RE
+.TP
 .BR "\-e\ kvm" = vcpu
 .TQ
 .BR "\-\-kvm" = vcpu
@@ -773,6 +871,11 @@ or higher.
 .TQ
 .B \-\-instruction\-pointer
 Print the instruction pointer at the time of the system call.
+.TP
+.B \-n
+.TQ
+.B \-\-syscall\-number
+Print the syscall number.
 .if '@ENABLE_STACKTRACE_FALSE@'#' .TP
 .if '@ENABLE_STACKTRACE_FALSE@'#' .B \-k
 .if '@ENABLE_STACKTRACE_FALSE@'#' .TQ
@@ -806,17 +909,40 @@ Open the file provided in the
 option in append mode.
 .TP
 .B \-q
-Suppress messages about attaching, detaching etc.  This happens
-automatically when output is redirected to a file and the command
-is run directly instead of attaching.
+.TQ
+.B \-\-quiet
+.TQ
+.BR \-\-quiet = attach , personality
+Suppress messages about attaching, detaching, and personality changes.
+This happens automatically when output is redirected to a file
+and the command is run directly instead of attaching.
 .TP
 .B \-qq
-If given twice, suppress messages about process exit status.
+.TQ
+.BR \-\-quiet = attach , personality , exit
+Suppress messages attaching, detaching, personality changes,
+and about process exit status.
+.TP
+.B \-qqq
+.TQ
+.BR \-\-quiet = all
+Suppress all suppressible messages (please refer to the
+.B -e quiet
+option description for the full list of suppressible messages).
 .TP
 .B \-r
+.TQ
+.BR \-\-relative\-timestamps [= \fIprecision\fR ]
 Print a relative timestamp upon entry to each system call.  This
 records the time difference between the beginning of successive
 system calls.
+.I precision
+can be one of
+.BR s " (for seconds), " ms " (milliseconds), " us " (microseconds), or " ns
+(nanoseconds), and allows setting the precision of time value being printed.
+Default is
+.B us
+(microseconds).
 Note that since
 .B \-r
 option uses the monotonic clock time for measuring time difference and not the
@@ -832,20 +958,70 @@ Specify the maximum string size to print
 that filenames are not considered strings and are always printed in
 full.
 .TP
+.BR \-\-absolute\-timestamps [=[[ format: ] \fIformat\fR ],[[ precision: ] \fIprecision ]]
+.TQ
+.BR \-\-timestamps [=[[ format: ] \fIformat\fR ],[[ precision: ] \fIprecision ]]
+Prefix each line of the trace with the wall clock time in the specified
+.I format
+with the specified
+.IR precision .
+.I format
+can be one of the following:
+.RS
+.TP 14
+.B none
+No time stamp is printed.
+Can be used to override the previous setting.
+.TQ
+.B time
+Wall clock time
+.RB ( strftime (3)
+format string is
+.BR %T ).
+.TQ
+.B unix
+Number of seconds since the epoch
+.RB ( strftime (3)
+format string is
+.BR %s ).
+.RE
+.IP
+.I precision
+can be one of
+.BR s " (for seconds), " ms " (milliseconds), " us " (microseconds), or " ns
+(nanoseconds).
+Default arguments for the option are
+.BR format:time , precision:s .
+.TP
 .B \-t
+.TQ
+.B \-\-absolute\-timestamps
 Prefix each line of the trace with the wall clock time.
 .TP
 .B \-tt
+.TQ
+.BR \-\-absolute\-timestamps = precision:us
 If given twice, the time printed will include the microseconds.
 .TP
 .B \-ttt
+.TQ
+.BR \-\-absolute\-timestamps = format:unix , precision:us
 If given thrice, the time printed will include the microseconds
 and the leading portion will be printed as the number
 of seconds since the epoch.
 .TP
 .B \-T
+.TQ
+.BR \-\-syscall\-times [= \fIprecision\fR ]
 Show the time spent in system calls.  This records the time
 difference between the beginning and the end of each system call.
+.I precision
+can be one of
+.BR s " (for seconds), " ms " (milliseconds), " us " (microseconds), or " ns
+(nanoseconds), and allows setting the precision of time value being printed.
+Default is
+.B us
+(microseconds).
 .TP
 .B \-v
 .TQ
@@ -856,9 +1032,15 @@ behavior displays a reasonable subset of
 this option to get all of the gory details.
 .TP
 .B \-x
+.TQ
+.BR \-\-strings\-in\-hex = \fInon\-ascii\fR
 Print all non-ASCII strings in hexadecimal string format.
 .TP
 .B \-xx
+.TQ
+.B \-\-strings\-in\-hex
+.TQ
+.BR \-\-strings\-in\-hex = \fIall\fR
 Print all strings in hexadecimal string format.
 .TP
 .BI "\-X " format
@@ -885,11 +1067,23 @@ Output both the raw value and the decode
 .RE
 .TP
 .B \-y
+.TQ
+.B \-\-decode\-fds
+.TQ
+.BR \-\-decode\-fds = path
 Print paths associated with file descriptor arguments.
 .TP
 .B \-yy
-Print protocol specific information associated with socket file descriptors,
-and block/character device number associated with device file descriptors.
+.TQ
+.BR \-\-decode\-fds = all
+Print all available information associated with file descritors:
+protocol-specific information associated with socket file descriptors,
+block/character device number associated with device file descriptors,
+and PIDs asociated with pidfd file descriptors.
+.TP
+.B \-\-pidns\-translation
+If strace and tracee are in different PID namespaces, print PIDs in
+strace's namespace, too.
 .SS Statistics
 .TP 12
 .B \-c
@@ -912,6 +1106,8 @@ Like
 but also print regular output while processes are running.
 .TP
 .BI "\-O " overhead
+.TQ
+.BR "\-\-summary\-syscall\-overhead " = \fIoverhead\fR
 Set the overhead for tracing system calls to
 .IR overhead .
 This is useful for overriding the default heuristic for guessing
@@ -936,15 +1132,60 @@ specification is described in section
 Sort the output of the histogram printed by the
 .B \-c
 option by the specified criterion.  Legal values are
-.BR time " (or " time_total " or " total_time ),
+.BR time " (or " time\-percent " or " time\-total " or " total\-time ),
+.BR min\-time " (or " shortest " or " time\-min ),
+.BR max\-time " (or " longest " or " time\-max ),
+.BR avg\-time " (or " time\-avg ),
 .BR calls " (or " count ),
 .BR errors " (or " error ),
-.BR name " (or " syscall " or " syscall_name ),
+.BR name " (or " syscall " or " syscall\-name ),
 and
 .BR nothing " (or " none );
 default is
 .BR time .
 .TP
+.BI "\-U " columns
+.TQ
+.BR "\-\-summary\-columns" = \fIcolumns\fR
+Configure a set (and order) of columns being shown in the call summary.
+The
+.I columns
+argument is a comma-separated list with items being one of the following:
+.RS
+.TP 36
+.BR time\-percent " (or " time )
+Percentage of cumulative time consumed by a specific system call.
+.TQ
+.BR total\-time " (or " time\-total )
+Total system (or wall clock, if
+.B \-w
+option is provided) time consumed by a specific system call.
+.TQ
+.BR min\-time " (or " shortest " or " time\-min )
+Minimum observed call duration.
+.TQ
+.BR max\-time " (or " longest " or " time\-max )
+Maximum observed call duration.
+.TQ
+.BR avg\-time " (or " time\-avg )
+Average call duration.
+.TQ
+.BR calls " (or " count )
+Call count.
+.TQ
+.BR errors " (or " error )
+Error count.
+.TQ
+.BR name " (or " syscall " or " syscall\-name )
+Syscall name.
+.RE
+.IP
+The default value is
+.BR time\-percent , total\-time , avg\-time , calls , errors , name .
+If the
+.B name
+field is not supplied explicitly, it is added as the last column.
+.TP
 .B \-w
 .TQ
 .B \-\-summary\-wall\-clock
@@ -1033,9 +1274,22 @@ Unless a :\fBwhen\fR=\,\fIexpr\fR subexp
 an injection is being made into every invocation of each syscall from the
 .IR set .
 .IP
-The format of the subexpression is one of the following:
+The format of the subexpression is:
+.RS 15
+.IP
+\fIfirst\/\fR[\fB..\fR\,\fIlast\/\fR][\fB+\fR[\,\fIstep\/\fR]]
+.RE
+.IP
+Number
+.I first
+stands for the first invocation number in the range, number
+.I last
+stands for the last invocation number in the range, and
+.I step
+stands for the step between two consecutive invocations.
+The following combinations are useful:
 .RS
-.TP 12
+.TP 18
 .I first
 For every syscall from the
 .IR set ,
@@ -1043,6 +1297,15 @@ perform an injection for the syscall inv
 .I first
 only.
 .TQ
+\fIfirst\/\fB..\fR\,\fIlast\fR
+For every syscall from the
+.IR set ,
+perform an injection for the syscall invocation number
+.I first
+and all subsequent invocations until the invocation number
+.I last
+(inclusive).
+.TQ
 \fIfirst\/\fB+\fR
 For every syscall from the
 .IR set ,
@@ -1050,7 +1313,16 @@ perform injections for the syscall invoc
 .I first
 and all subsequent invocations.
 .TQ
-\fIfirst\/\fB+\fIstep\fR
+\fIfirst\/\fB..\fR\,\fIlast\/\fB+\fR
+For every syscall from the
+.IR set ,
+perform injections for the syscall invocation number
+.I first
+and all subsequent invocations until the invocation number
+.I last
+(inclusive).
+.TQ
+\fIfirst\/\fB+\fR\,\fIstep\fR
 For every syscall from the
 .IR set ,
 perform injections for syscall invocations number
@@ -1058,6 +1330,11 @@ perform injections for syscall invocatio
 .IR first + step ,
 .IR first + step + step ,
 and so on.
+.TQ
+\fIfirst\/\fB..\fR\,\fIlast\fB+\fR\,\fIstep\fR
+Same as the previous, but consider only syscall invocations with numbers up to
+.I last
+(inclusive).
 .RE
 .IP
 For example, to fail each third and subsequent chdir syscalls with
@@ -1069,7 +1346,9 @@ The valid range for numbers
 .I first
 and
 .I step
-is 1..65535.
+is 1..65535, and for number
+.I last
+is 1..65534.
 .IP
 An injection expression can contain only one
 .BR error =
@@ -1124,22 +1403,22 @@ option.
 Print the help summary.
 .TP
 .B \-\-seccomp\-bpf
-Enable (experimental) usage of seccomp-bpf (see
+Try to enable use of seccomp-bpf (see
 .BR seccomp (2))
 to have
 .BR ptrace (2)-stops
 only when system calls that are being traced occur in the traced processes.
-Implies the
-.B \-f
-option.
-An attempt to rely on seccomp-bpf to filter system calls may fail for various
-reasons, e.g. there are too many system calls to filter, the seccomp API is not
-available, or
+This option has no effect unless
+.BR \-f / \-\-follow\-forks
+is also specified.
+.B \-\-seccomp\-bpf
+is also not applicable to processes attached using
+.BR \-p / \-\-attach
+option.  An attempt to enable system calls filtering using seccomp-bpf may
+fail for various reasons, e.g. there are too many system calls to filter,
+the seccomp API is not available, or
 .B strace
 itself is being traced.
-.B \-\-seccomp\-bpf
-is also ineffective on processes attached using
-.BR \-p .
 In cases when seccomp-bpf filter setup failed,
 .B strace
 proceeds as usual and stops traced processes on every system call.
@@ -1378,7 +1657,9 @@ effective user
 .SM ID
 privileges while being traced.
 .LP
-A traced process runs slowly.
+A traced process runs slowly (but check out the
+.B \-\-seccomp\-bpf
+option).
 .LP
 Traced processes which are descended from
 .I command
@@ -1440,7 +1721,7 @@ Since 2009,
 .B strace
 is actively maintained by Dmitry Levin.
 .B strace
-gained support for AArch64, ARC, AVR32, Blackfin, Meta, Nios II, OpenSISC 1000,
+gained support for AArch64, ARC, AVR32, Blackfin, Meta, Nios II, OpenRISC 1000,
 RISC-V, Tile/TileGx, Xtensa architectures since that time.
 In 2012, unmaintained and apparently broken support for non-Linux operating
 systems was removed.
diff -pruN 5.5-3/.strace.1.in.date 5.9-0ubuntu2/.strace.1.in.date
--- 5.5-3/.strace.1.in.date	2020-02-06 16:24:09.000000000 +0000
+++ 5.9-0ubuntu2/.strace.1.in.date	2020-09-24 09:19:54.000000000 +0000
@@ -1 +1 @@
-2020-02-04
+2020-09-23
diff -pruN 5.5-3/strace.c 5.9-0ubuntu2/strace.c
--- 5.5-3/strace.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/strace.c	2020-08-25 14:29:30.000000000 +0000
@@ -26,9 +26,7 @@
 #include <dirent.h>
 #include <locale.h>
 #include <sys/utsname.h>
-#ifdef HAVE_PRCTL
-# include <sys/prctl.h>
-#endif
+#include <sys/prctl.h>
 
 #include "kill_save_errno.h"
 #include "filter_seccomp.h"
@@ -67,17 +65,28 @@ bool stack_trace_enabled;
 const unsigned int syscall_trap_sig = SIGTRAP | 0x80;
 
 cflag_t cflag = CFLAG_NONE;
-unsigned int followfork;
+bool followfork;
+bool output_separately;
 unsigned int ptrace_setoptions = PTRACE_O_TRACESYSGOOD | PTRACE_O_TRACEEXEC
 				 | PTRACE_O_TRACEEXIT;
+static struct xlat_data xflag_str[] = {
+	{ HEXSTR_NON_ASCII,	"non-ascii" },
+	{ HEXSTR_ALL,		"all" },
+};
 unsigned int xflag;
 bool debug_flag;
 bool Tflag;
+int Tflag_scale = 1000;
+int Tflag_width = 6;
 bool iflag;
+bool nflag;
 bool count_wallclock;
-unsigned int qflag;
-static unsigned int tflag;
+static int tflag_scale = 1000000000;
+static unsigned tflag_width = 0;
+static const char *tflag_format = NULL;
 static bool rflag;
+static int rflag_scale = 1000;
+static int rflag_width = 6;
 static bool print_pid_pfx;
 
 /* -I n */
@@ -102,6 +111,12 @@ enum {
 	DAEMONIZE_OPTS_GUARD__,
 	MAX_DAEMONIZE_OPTS    = DAEMONIZE_OPTS_GUARD__ - 1
 };
+static struct xlat_data daemonize_str[] = {
+	{ DAEMONIZE_GRANDCHILD,		"grandchild" },
+	{ DAEMONIZE_NEW_PGROUP,		"pgroup" },
+	{ DAEMONIZE_NEW_PGROUP,		"pgrp" },
+	{ DAEMONIZE_NEW_SESSION,	"session" },
+};
 /*
  * daemonized_tracer supports -D option.
  * With this option, strace forks twice.
@@ -119,8 +134,7 @@ static unsigned int daemonized_tracer;
 static int post_attach_sigstop = TCB_IGNORE_ONE_SIGSTOP;
 #define use_seize (post_attach_sigstop == 0)
 
-/* Show path associated with fd arguments */
-unsigned int show_fd_path;
+unsigned int pidns_translation;
 
 static bool detach_on_execve;
 
@@ -248,17 +262,17 @@ usage(void)
 
 	printf("\
 Usage: strace [-ACdffhi" K_OPT "qqrtttTvVwxxyyzZ] [-I N] [-b execve] [-e EXPR]...\n\
-              [-a COLUMN] [-o FILE] [-s STRSIZE] [-X FORMAT] [-P PATH]...\n\
-              [-p PID]... [--seccomp-bpf]\n\
+              [-a COLUMN] [-o FILE] [-s STRSIZE] [-X FORMAT] [-O OVERHEAD]\n\
+              [-S SORTBY] [-P PATH]... [-p PID]... [-U COLUMNS] [--seccomp-bpf]\n\
               { -p PID | [-DDD] [-E VAR=VAL]... [-u USERNAME] PROG [ARGS] }\n\
    or: strace -c[dfwzZ] [-I N] [-b execve] [-e EXPR]... [-O OVERHEAD]\n\
-              [-S SORTBY] [-P PATH]... [-p PID]... [--seccomp-bpf]\n\
+              [-S SORTBY] [-P PATH]... [-p PID]... [-U COLUMNS] [--seccomp-bpf]\n\
               { -p PID | [-DDD] [-E VAR=VAL]... [-u USERNAME] PROG [ARGS] }\n\
 \n\
 General:\n\
   -e EXPR        a qualifying expression: OPTION=[!]all or OPTION=[!]VAL1[,VAL2]...\n\
      options:    trace, abbrev, verbose, raw, signal, read, write, fault,\n\
-                 inject, status, kvm\n\
+                 inject, status, quiet, kvm, decode-fds\n\
 \n\
 Startup:\n\
   -E VAR=VAL, --env=VAR=VAL\n\
@@ -273,23 +287,28 @@ Startup:\n\
 Tracing:\n\
   -b execve, --detach-on=execve\n\
                  detach on execve syscall\n\
-  -D             run tracer process as a grandchild, not as a parent\n\
-  -DD            run tracer process in a separate process group\n\
-  -DDD           run tracer process in a separate session\n\
-  -f             follow forks\n\
-  -ff            follow forks with output into separate files\n\
-  -I INTERRUPTIBLE\n\
-     1:          no signals are blocked\n\
-     2:          fatal signals are blocked while decoding syscall (default)\n\
-     3:          fatal signals are always blocked (default if '-o FILE PROG')\n\
-     4:          fatal signals and SIGTSTP (^Z) are always blocked\n\
-                 (useful to make 'strace -o FILE PROG' not stop on ^Z)\n\
+  -D, --daemonize[=grandchild]\n\
+                 run tracer process as a grandchild, not as a parent\n\
+  -DD, --daemonize=pgroup\n\
+                 run tracer process in a separate process group\n\
+  -DDD, --daemonize=session\n\
+                 run tracer process in a separate session\n\
+  -f, --follow-forks\n\
+                 follow forks\n\
+  -ff, --follow-forks --output-separately\n\
+                 follow forks with output into separate files\n\
+  -I INTERRUPTIBLE, --interruptible=INTERRUPTIBLE\n\
+     1, anywhere:   no signals are blocked\n\
+     2, waiting:    fatal signals are blocked while decoding syscall (default)\n\
+     3, never:      fatal signals are always blocked (default if '-o FILE PROG')\n\
+     4, never_tstp: fatal signals and SIGTSTP (^Z) are always blocked\n\
+                    (useful to make 'strace -o FILE PROG' not stop on ^Z)\n\
 \n\
 Filtering:\n\
   -e trace=[!]{[?]SYSCALL[@64|@32|@x32]|[?]/REGEX|GROUP|all|none},\n\
   --trace=[!]{[?]SYSCALL[@64|@32|@x32]|[?]/REGEX|GROUP|all|none}\n\
                  trace only specified syscalls.\n\
-     groups:     %%creds, %%desc, %%file, %%fstat, %%fstatfs %%ipc, %%lstat,\n\
+     groups:     %%clock, %%creds, %%desc, %%file, %%fstat, %%fstatfs %%ipc, %%lstat,\n\
                  %%memory, %%net, %%process, %%pure, %%signal, %%stat, %%%%stat,\n\
                  %%statfs, %%%%statfs\n\
   -e signal=SET, --signal=SET\n\
@@ -300,8 +319,10 @@ Filtering:\n\
      statuses:   successful, failed, unfinished, unavailable, detached\n\
   -P PATH, --trace-path=PATH\n\
                  trace accesses to PATH\n\
-  -z             print only syscalls that returned without an error code\n\
-  -Z             print only syscalls that returned with an error code\n\
+  -z, --successful-only\n\
+                 print only syscalls that returned without an error code\n\
+  -Z, --failed-only\n\
+                 print only syscalls that returned with an error code\n\
 \n\
 Output format:\n\
   -a COLUMN, --columns=COLUMN\n\
@@ -316,8 +337,17 @@ Output format:\n\
                  dump the data read from the file descriptors in SET\n\
   -e write=SET, --write=SET\n\
                  dump the data written to the file descriptors in SET\n\
+  -e quiet=SET, --quiet=SET\n\
+                 suppress various informational messages\n\
+     messages:   attach, exit, path-resolution, personality, thread-execve\n\
   -e kvm=vcpu, --kvm=vcpu\n\
                  print exit reason of kvm vcpu\n\
+  -e decode-fds=SET, --decode-fds=SET\n\
+                 what kinds of file descritor information details to decode\n\
+     details:    dev (device major/minor for block/char device files)\n\
+                 path (file path),\n\
+                 pidfd (associated PID for pidfds),\n\
+                 socket (protocol-specific information for socket descriptors)\n\
   -i, --instruction-pointer\n\
                  print instruction pointer at time of syscall\n\
 "
@@ -328,39 +358,71 @@ Output format:\n\
 "
 #endif
 "\
+  -n, --syscall-number\n\
+                 print syscall number\n\
   -o FILE, --output=FILE\n\
                  send trace output to FILE instead of stderr\n\
   -A, --output-append-mode\n\
                  open the file provided in the -o option in append mode\n\
-  -q             suppress messages about attaching, detaching, etc.\n\
-  -qq            suppress messages about process exit status as well.\n\
-  -r             print relative timestamp\n\
+  --output-separately\n\
+                 output into separate files (by appending pid to file names)\n\
+  -q, --quiet=attach,personality\n\
+                 suppress messages about attaching, detaching, etc.\n\
+  -qq, --quiet=attach,personality,exit\n\
+                 suppress messages about process exit status as well.\n\
+  -qqq, --quiet=all\n\
+                 suppress all suppressible messages.\n\
+  -r, --relative-timestamps[=PRECISION]\n\
+                 print relative timestamp\n\
+     precision:  one of s, ms, us, ns; default is microseconds\n\
   -s STRSIZE, --string-limit=STRSIZE\n\
                  limit length of print strings to STRSIZE chars (default %d)\n\
-  -t             print absolute timestamp\n\
-  -tt            print absolute timestamp with usecs\n\
-  -ttt           print absolute UNIX time with usecs\n\
-  -T             print time spent in each syscall\n\
+  --absolute-timestamps=[[format:]FORMAT[,[precision:]PRECISION]]\n\
+                 set the format of absolute timestamps\n\
+     format:     none, time, or unix; default is time\n\
+     precision:  one of s, ms, us, ns; default is seconds\n\
+  -t, --absolute-timestamps[=time]\n\
+                 print absolute timestamp\n\
+  -tt, --absolute-timestamps=[time,]us\n\
+                 print absolute timestamp with usecs\n\
+  -ttt, --absolute-timestamps=unix,us\n\
+                 print absolute UNIX time with usecs\n\
+  -T, --syscall-times[=PRECISION]\n\
+                 print time spent in each syscall\n\
+     precision:  one of s, ms, us, ns; default is microseconds\n\
   -v, --no-abbrev\n\
                  verbose mode: print entities unabbreviated\n\
-  -x             print non-ascii strings in hex\n\
-  -xx            print all strings in hex\n\
-  -X FORMAT      set the FORMAT for printing of named constants and flags\n\
+  -x, --strings-in-hex=non-ascii\n\
+                 print non-ascii strings in hex\n\
+  -xx, --strings-in-hex[=all]\n\
+                 print all strings in hex\n\
+  -X FORMAT, --const-print-style=FORMAT\n\
+                 set the FORMAT for printing of named constants and flags\n\
      formats:    raw, abbrev, verbose\n\
-  -y             print paths associated with file descriptor arguments\n\
-  -yy            print protocol specific information associated with socket\n\
-                 file descriptors\n\
+  -y, --decode-fds[=path]\n\
+                 print paths associated with file descriptor arguments\n\
+  -yy, --decode-fds=all\n\
+                 print all available information associated with file\n\
+                 descriptors in addition to paths\n\
 \n\
 Statistics:\n\
   -c, --summary-only\n\
                  count time, calls, and errors for each syscall and report\n\
                  summary\n\
   -C, --summary  like -c, but also print the regular output\n\
-  -O OVERHEAD    set overhead for tracing syscalls to OVERHEAD usecs\n\
+  -O OVERHEAD[UNIT], --summary-syscall-overhead=OVERHEAD[UNIT]\n\
+                 set overhead for tracing syscalls to OVERHEAD UNITs\n\
+     units:      one of s, ms, us, ns; default is microseconds\n\
   -S SORTBY, --summary-sort-by=SORTBY\n\
-                 sort syscall counts by: time, calls, errors, name, nothing\n\
-                 (default %s)\n\
-  -w             summarise syscall latency (default is system time)\n\
+                 sort syscall counts by: time, min-time, max-time, avg-time,\n\
+                 calls, errors, name, nothing (default %s)\n\
+  -U COLUMNS, --summary-columns=COLUMNS\n\
+                 show specific columns in the summary report: comma-separated\n\
+                 list of time-percent, total-time, min-time, max-time, \n\
+                 avg-time, calls, errors, name\n\
+                 (default time-percent,total-time,avg-time,calls,errors,name)\n\
+  -w, --summary-wall-clock\n\
+                 summarise syscall latency (default is system time)\n\
 \n\
 Tampering:\n\
   -e inject=SET[:error=ERRNO|:retval=VALUE][:signal=SIG][:syscall=SYSCALL]\n\
@@ -368,10 +430,11 @@ Tampering:\n\
   --inject=SET[:error=ERRNO|:retval=VALUE][:signal=SIG][:syscall=SYSCALL]\n\
            [:delay_enter=DELAY][:delay_exit=DELAY][:when=WHEN]\n\
                  perform syscall tampering for the syscalls in SET\n\
-     delay:      milliseconds or NUMBER{s|ms|us|ns}\n\
-     when:       FIRST, FIRST+, or FIRST+STEP\n\
+     delay:      microseconds or NUMBER{s|ms|us|ns}\n\
+     when:       FIRST[..LAST][+[STEP]]\n\
   -e fault=SET[:error=ERRNO][:when=WHEN], --fault=SET[:error=ERRNO][:when=WHEN]\n\
                  synonym for -e inject with default ERRNO set to ENOSYS.\n\
+\n\
 Miscellaneous:\n\
   -d, --debug    enable debug output to stderr\n\
   -h, --help     print help message\n\
@@ -399,9 +462,14 @@ die(void)
 }
 
 static void
-error_opt_arg(int opt, const char *arg)
+error_opt_arg(int opt, const struct option *lopt, const char *arg)
 {
-	error_msg_and_help("invalid -%c argument: '%s'", opt, arg);
+	if (lopt && lopt->name) {
+		error_msg_and_help("invalid --%s argument: '%s'",
+				   lopt->name, arg);
+	} else {
+		error_msg_and_help("invalid -%c argument: '%s'", opt, arg);
+	}
 }
 
 static const char *ptrace_attach_cmd;
@@ -578,7 +646,7 @@ outf_perror(const struct tcb * const tcp
 		return;
 
 	/* This is ugly, but we don't store separate file names */
-	if (followfork >= 2)
+	if (output_separately)
 		perror_msg("%s.%u", outfname, tcp->pid);
 	else
 		perror_msg("%s", outfname);
@@ -682,13 +750,13 @@ printleader(struct tcb *tcp)
 	/* If -ff, "previous tcb we printed" is always the same as current,
 	 * because we have per-tcb output files.
 	 */
-	if (followfork >= 2)
+	if (output_separately)
 		printing_tcp = tcp;
 
 	if (printing_tcp) {
 		set_current_tcp(printing_tcp);
 		if (!tcp->staged_output_data && printing_tcp->curcol != 0 &&
-		    (followfork < 2 || printing_tcp == tcp)) {
+		    (!output_separately || printing_tcp == tcp)) {
 			/*
 			 * case 1: we have a shared log (i.e. not -ff), and last line
 			 * wasn't finished (same or different tcb, doesn't matter).
@@ -709,28 +777,23 @@ printleader(struct tcb *tcp)
 	else if (nprocs > 1 && !outfname)
 		tprintf("[pid %5u] ", tcp->pid);
 
-	if (tflag) {
+	if (tflag_format) {
 		struct timespec ts;
 		clock_gettime(CLOCK_REALTIME, &ts);
 
-		if (tflag > 2) {
-			tprintf("%lld.%06ld ",
-				(long long) ts.tv_sec, (long) ts.tv_nsec / 1000);
-		} else {
-			time_t local = ts.tv_sec;
-			char str[MAX(sizeof("HH:MM:SS"), sizeof(ts.tv_sec) * 3)];
-			struct tm *tm = localtime(&local);
+		time_t local = ts.tv_sec;
+		char str[MAX(sizeof("HH:MM:SS"), sizeof(local) * 3)];
+		struct tm *tm = localtime(&local);
 
-			if (tm)
-				strftime(str, sizeof(str), "%T", tm);
-			else
-				xsprintf(str, "%lld", (long long) local);
-			if (tflag > 1)
-				tprintf("%s.%06ld ",
-					str, (long) ts.tv_nsec / 1000);
-			else
-				tprintf("%s ", str);
-		}
+		if (tm)
+			strftime(str, sizeof(str), tflag_format, tm);
+		else
+			xsprintf(str, "%lld", (long long) local);
+		if (tflag_width)
+			tprintf("%s.%0*ld ", str, tflag_width,
+				(long) ts.tv_nsec / tflag_scale);
+		else
+			tprintf("%s ", str);
 	}
 
 	if (rflag) {
@@ -745,12 +808,17 @@ printleader(struct tcb *tcp)
 		ts_sub(&dts, &ts, &ots);
 		ots = ts;
 
-		tprintf("%s%6ld.%06ld%s ",
-			tflag ? "(+" : "",
-			(long) dts.tv_sec, (long) dts.tv_nsec / 1000,
-			tflag ? ")" : "");
+		tprintf("%s%6ld", tflag_format ? "(+" : "", (long) dts.tv_sec);
+		if (rflag_width) {
+			tprintf(".%0*ld",
+				rflag_width, (long) dts.tv_nsec / rflag_scale);
+		}
+		tprints(tflag_format ? ") " : " ");
 	}
 
+	if (nflag)
+		print_syscall_number(tcp);
+
 	if (iflag)
 		print_instruction_pointer(tcp);
 }
@@ -771,7 +839,7 @@ after_successful_attach(struct tcb *tcp,
 {
 	tcp->flags |= TCB_ATTACHED | TCB_STARTUP | flags;
 	tcp->outf = shared_log; /* if not -ff mode, the same file is for all */
-	if (followfork >= 2) {
+	if (output_separately) {
 		char name[PATH_MAX];
 		xsprintf(name, "%s.%u", outfname, tcp->pid);
 		tcp->outf = strace_fopen(name);
@@ -905,7 +973,7 @@ droptcb(struct tcb *tcp)
 			strace_close_memstream(tcp, publish);
 		}
 
-		if (followfork >= 2) {
+		if (output_separately) {
 			if (tcp->curcol != 0 && publish)
 				fprintf(tcp->outf, " <detached ...>\n");
 			fclose(tcp->outf);
@@ -1080,7 +1148,8 @@ detach(struct tcb *tcp)
 	}
 
  drop:
-	if (!qflag && (tcp->flags & TCB_ATTACHED))
+	if (!is_number_in_set(QUIET_ATTACH, quiet_set)
+	    && (tcp->flags & TCB_ATTACHED))
 		error_msg("Process %u detached", tcp->pid);
 
 	droptcb(tcp);
@@ -1133,7 +1202,7 @@ attach_tcb(struct tcb *const tcp)
 	unsigned int ntid = 0, nerr = 0;
 
 	if (followfork && tcp->pid != strace_child &&
-	    xsprintf(procdir, task_path, tcp->pid) > 0 &&
+	    xsprintf(procdir, task_path, get_proc_pid(tcp)) > 0 &&
 	    (dir = opendir(procdir)) != NULL) {
 		struct_dirent *de;
 
@@ -1161,7 +1230,7 @@ attach_tcb(struct tcb *const tcp)
 		closedir(dir);
 	}
 
-	if (!qflag) {
+	if (!is_number_in_set(QUIET_ATTACH, quiet_set)) {
 		if (ntid > nerr)
 			error_msg("Process %u attached"
 				  " with %u threads",
@@ -1261,6 +1330,7 @@ struct exec_params {
 	uid_t run_euid;
 	gid_t run_egid;
 	char **argv;
+	char **env;
 	char *pathname;
 	struct sigaction child_sa;
 };
@@ -1323,7 +1393,7 @@ exec_or_die(void)
 		  seccomp_filtering ? "enabled" : "disabled");
 	if (seccomp_filtering)
 		init_seccomp_filter();
-	execv(params->pathname, params->argv);
+	execve(params->pathname, params->argv, params->env);
 	perror_msg_and_die("exec");
 }
 
@@ -1392,7 +1462,7 @@ redirect_standard_fds(void)
 }
 
 static void
-startup_child(char **argv)
+startup_child(char **argv, char **env)
 {
 	strace_stat_t statbuf;
 	const char *filename;
@@ -1465,13 +1535,14 @@ startup_child(char **argv)
 	params_for_tracee.run_euid = (statbuf.st_mode & S_ISUID) ? statbuf.st_uid : run_uid;
 	params_for_tracee.run_egid = (statbuf.st_mode & S_ISGID) ? statbuf.st_gid : run_gid;
 	params_for_tracee.argv = argv;
+	params_for_tracee.env = env;
 	/*
 	 * On NOMMU, can be safely freed only after execve in tracee.
 	 * It's hard to know when that happens, so we just leak it.
 	 */
 	params_for_tracee.pathname = NOMMU_SYSTEM ? xstrdup(pathname) : pathname;
 
-#if defined HAVE_PRCTL && defined PR_SET_PTRACER && defined PR_SET_PTRACER_ANY
+#if defined PR_SET_PTRACER && defined PR_SET_PTRACER_ANY
 	if (daemonized_tracer)
 		prctl(PR_SET_PTRACER, PR_SET_PTRACER_ANY);
 #endif
@@ -1663,6 +1734,211 @@ set_sighandler(int signo, void (*sighand
 	sigaction(signo, &sa, oldact);
 }
 
+static int
+parse_interruptible_arg(const char *arg)
+{
+	static const struct xlat_data intr_str[] = {
+		{ INTR_ANYWHERE,	"anywhere" },
+		{ INTR_ANYWHERE,	"always" },
+		{ INTR_WHILE_WAIT,	"waiting" },
+		{ INTR_NEVER,		"never" },
+		{ INTR_BLOCK_TSTP_TOO,	"never_tstp" },
+	};
+
+	const struct xlat_data *intr_arg = find_xlat_val(intr_str, arg);
+
+	return intr_arg ? (int) intr_arg->val
+			: (int) string_to_uint_upto(arg, NUM_INTR_OPTS - 1);
+}
+
+static int
+parse_ts_arg(const char *in_arg)
+{
+	static const char format_pfx[] = "format:";
+	static const char scale_pfx[] = "precision:";
+
+	enum {
+		TOKEN_FORMAT = 1 << 0,
+		TOKEN_SCALE  = 1 << 1,
+	} token_type;
+	enum {
+		FK_UNSET,
+		FK_NONE,
+		FK_TIME,
+		FK_UNIX,
+	} format_kind = FK_UNSET;
+	int precision_width;
+	int precision_scale = 0;
+	char *arg = xstrdup(in_arg);
+	char *saveptr = NULL;
+
+	for (const char *token = strtok_r(arg, ",", &saveptr);
+	     token; token = strtok_r(NULL, ",", &saveptr)) {
+		token_type = TOKEN_FORMAT | TOKEN_SCALE;
+
+		if (!strncasecmp(token, format_pfx, sizeof(format_pfx) - 1)) {
+			token += sizeof(format_pfx) - 1;
+			token_type = TOKEN_FORMAT;
+		} else if (!strncasecmp(token, scale_pfx,
+					sizeof(scale_pfx) - 1)) {
+			token += sizeof(scale_pfx) - 1;
+			token_type = TOKEN_SCALE;
+
+		}
+
+		if (token_type & TOKEN_FORMAT) {
+			if (!strcasecmp(token, "none")) {
+				format_kind = FK_NONE;
+				continue;
+			} else if (!strcasecmp(token, "time")) {
+				format_kind = FK_TIME;
+				continue;
+			} else if (!strcasecmp(token, "unix")) {
+				format_kind = FK_UNIX;
+				continue;
+			}
+		}
+
+		if (token_type & TOKEN_SCALE) {
+			precision_scale =
+				str2timescale_optarg(token, &precision_width);
+
+			if (precision_scale > 0)
+				continue;
+		}
+
+		free(arg);
+		return -1;
+	}
+
+	switch (format_kind) {
+	case FK_UNSET:
+		if (!tflag_format)
+			tflag_format = "%T";
+		break;
+	case FK_NONE:
+		tflag_format = NULL;
+		break;
+	case FK_TIME:
+		tflag_format = "%T";
+		break;
+	case FK_UNIX:
+		tflag_format = "%s";
+		break;
+	}
+
+	if (precision_scale > 0) {
+		tflag_scale = precision_scale;
+		tflag_width = precision_width;
+	}
+
+	free(arg);
+	return 0;
+}
+
+static void
+remove_from_env(char **env, size_t *env_count, const char *var)
+{
+	const size_t len = strlen(var);
+	size_t w = 0;
+
+	debug_func_msg("Removing variable \"%s\" from the command environment",
+		       var);
+
+	for (size_t r = 0; r < *env_count; ++r) {
+		if (!strncmp(env[r], var, len) &&
+		    (env[r][len] == '=' || env[r][len] == '\0')) {
+			debug_func_msg("Skipping entry %zu (\"%s\")",
+				       r, env[r]);
+			continue;
+		}
+		if (w < r) {
+			debug_func_msg("Copying entry %zu to %zu", r, w);
+			env[w] = env[r];
+		}
+		++w;
+	}
+
+	if (w < *env_count) {
+		debug_func_msg("Decreasing env count from %zu to %zu",
+			       *env_count, w);
+		*env_count = w;
+	}
+}
+
+static void
+add_to_env(char **env, size_t *env_count, char *var, const size_t len)
+{
+	size_t r;
+
+	for (r = 0; r < *env_count; ++r) {
+		if (!strncmp(env[r], var, len) &&
+		    (env[r][len] == '=' || env[r][len] == '\0'))
+			break;
+	}
+
+	if (r < *env_count) {
+		debug_func_msg("Replacing entry %zu (\"%s\")"
+			       ", key=\"%.*s\", var=\"%s\"",
+			       r, env[r], (int) len, var, var);
+	} else {
+		debug_func_msg("Adding entry %zu"
+			       ", key=\"%.*s\", var=\"%s\"",
+			       r, (int) len, var, var);
+		*env_count += 1;
+	}
+
+	env[r] = var;
+}
+
+static void
+update_env(char **env, size_t *env_count, char *var)
+{
+	char *val = strchr(var, '=');
+
+	if (val)
+		add_to_env(env, env_count, var, val - var);
+	else
+		remove_from_env(env, env_count, var);
+}
+
+static char **
+make_env(char **orig_env, char *const *env_changes, size_t env_change_count)
+{
+	if (!env_change_count)
+		return orig_env;
+
+	char **new_env;
+	size_t new_env_count = 0;
+	size_t new_env_size;
+
+	/* Determining the environment variable count.  */
+	if (orig_env) {
+		for (; orig_env[new_env_count]; ++new_env_count)
+			;
+	}
+	new_env_size = new_env_count + env_change_count;
+
+	if (new_env_size < new_env_count || new_env_size < env_change_count ||
+	    new_env_size + 1 < new_env_size)
+		error_msg_and_die("Cannot construct new environment: the sum "
+				  "of old environment variable count (%zu) and "
+				  "environment changes count (%zu) is too big",
+				  new_env_count, env_change_count);
+
+	new_env_size++;
+	new_env = xallocarray(new_env_size, sizeof(*new_env));
+	if (new_env_count)
+		memcpy(new_env, orig_env, new_env_count * sizeof(*orig_env));
+
+	for (size_t i = 0; i < env_change_count; ++i)
+		update_env(new_env, &new_env_count, env_changes[i]);
+
+	new_env[new_env_count] = NULL;
+
+	return new_env;
+}
+
 /*
  * Initialization part of main() was eating much stack (~0.5k),
  * which was unused after init.
@@ -1674,8 +1950,51 @@ set_sighandler(int signo, void (*sighand
 static void ATTRIBUTE_NOINLINE
 init(int argc, char *argv[])
 {
+	static const char qflag_qual[] = "attach,personality";
+	static const char qqflag_qual[] = "exit,attach,personality";
+	static const char qqqflag_qual[] = "all";
+	static const char yflag_qual[] = "path";
+	static const char yyflag_qual[] = "all";
+	static const char tflag_str[] = "format:time";
+	static const char ttflag_str[] = "precision:us,format:time";
+	static const char tttflag_str[] = "format:unix,precision:us";
+
 	int c, i;
 	int optF = 0, zflags = 0;
+	int lopt_idx;
+	int daemonized_tracer_long = DAEMONIZE_NONE;
+	int xflag_long = HEXSTR_NONE;
+	int qflag_short = 0;
+	int followfork_short = 0;
+	int yflag_short = 0;
+	bool tflag_long_set = false;
+	int tflag_short = 0;
+	bool columns_set = false;
+	bool sortby_set = false;
+
+	/*
+	 * We can initialise global_path_set only after tracing backend
+	 * initialisation, so we store pointers to all the paths from
+	 * command-line arguments during parsing in this array and then,
+	 * after the successful backend initialisation, iterate over it
+	 * in order to add them to global_path_set.
+	 */
+	const char **pathtrace_paths = NULL;
+	size_t pathtrace_size = 0;
+	size_t pathtrace_count = 0;
+
+	/**
+	 * Storage for environment changes requested for command.  They
+	 * are stored in a temporary array and not applied as is during
+	 * command line parsing for two reasons:
+	 *  - putenv() changes environment of the tracer as well,
+	 *    which is unacceptable.
+	 *  - Environment changes have to be applied
+	 *    in a tracing-backend-specific way.
+	 */
+	char **env_changes = NULL;
+	size_t env_change_size = 0;
+	size_t env_change_count = 0;
 
 	if (!program_invocation_name || !*program_invocation_name) {
 		static char name[] = "strace";
@@ -1687,6 +2006,8 @@ init(int argc, char *argv[])
 
 	os_release = get_os_release();
 
+	pidns_init();
+
 	shared_log = stderr;
 	set_sortby(DEFAULT_SORTBY);
 	set_personality(DEFAULT_PERSONALITY);
@@ -1697,13 +2018,21 @@ init(int argc, char *argv[])
 # error Bug in DEFAULT_QUAL_FLAGS
 #endif
 	qualify_status("all");
+	qualify_quiet("none");
+	qualify_decode_fd("none");
 	qualify_signals("all");
 
 	static const char optstring[] =
-		"+a:Ab:cCdDe:E:fFhiI:ko:O:p:P:qrs:S:tTu:vVwxX:yzZ";
+		"+a:Ab:cCdDe:E:fFhiI:kno:O:p:P:qrs:S:tTu:U:vVwxX:yzZ";
 
 	enum {
 		GETOPT_SECCOMP = 0x100,
+		GETOPT_DAEMONIZE,
+		GETOPT_HEX_STR,
+		GETOPT_FOLLOWFORKS,
+		GETOPT_OUTPUT_SEPARATELY,
+		GETOPT_TS,
+		GETOPT_PIDNS_TRANSLATION,
 
 		GETOPT_QUAL_TRACE,
 		GETOPT_QUAL_ABBREV,
@@ -1716,6 +2045,8 @@ init(int argc, char *argv[])
 		GETOPT_QUAL_FAULT,
 		GETOPT_QUAL_INJECT,
 		GETOPT_QUAL_KVM,
+		GETOPT_QUAL_QUIET,
+		GETOPT_QUAL_DECODE_FD,
 	};
 	static const struct option longopts[] = {
 		{ "columns",		required_argument, 0, 'a' },
@@ -1724,20 +2055,39 @@ init(int argc, char *argv[])
 		{ "summary-only",	no_argument,	   0, 'c' },
 		{ "summary",		no_argument,	   0, 'C' },
 		{ "debug",		no_argument,	   0, 'd' },
+		{ "daemonize",		optional_argument, 0, GETOPT_DAEMONIZE },
+		{ "daemonised",		optional_argument, 0, GETOPT_DAEMONIZE },
+		{ "daemonized",		optional_argument, 0, GETOPT_DAEMONIZE },
 		{ "env",		required_argument, 0, 'E' },
+		{ "follow-forks",	no_argument,	   0, GETOPT_FOLLOWFORKS },
+		{ "output-separately",	no_argument,	   0,
+			GETOPT_OUTPUT_SEPARATELY },
 		{ "help",		no_argument,	   0, 'h' },
 		{ "instruction-pointer", no_argument,      0, 'i' },
+		{ "interruptible",	required_argument, 0, 'I' },
 		{ "stack-traces",	no_argument,	   0, 'k' },
+		{ "syscall-number",	no_argument,	   0, 'n' },
 		{ "output",		required_argument, 0, 'o' },
+		{ "summary-syscall-overhead", required_argument, 0, 'O' },
 		{ "attach",		required_argument, 0, 'p' },
 		{ "trace-path",		required_argument, 0, 'P' },
+		{ "relative-timestamps", optional_argument, 0, 'r' },
 		{ "string-limit",	required_argument, 0, 's' },
 		{ "summary-sort-by",	required_argument, 0, 'S' },
+		{ "absolute-timestamps", optional_argument, 0, GETOPT_TS },
+		{ "timestamps",		optional_argument, 0, GETOPT_TS },
+		{ "syscall-times",	optional_argument, 0, 'T' },
 		{ "user",		required_argument, 0, 'u' },
+		{ "summary-columns",	required_argument, 0, 'U' },
 		{ "no-abbrev",		no_argument,	   0, 'v' },
 		{ "version",		no_argument,	   0, 'V' },
 		{ "summary-wall-clock", no_argument,	   0, 'w' },
+		{ "strings-in-hex",	optional_argument, 0, GETOPT_HEX_STR },
 		{ "const-print-style",	required_argument, 0, 'X' },
+		{ "pidns-translation",	no_argument      , 0, GETOPT_PIDNS_TRANSLATION },
+		{ "successful-only",	no_argument,	   0, 'z' },
+		{ "failed-only",	no_argument,	   0, 'Z' },
+		{ "failing-only",	no_argument,	   0, 'Z' },
 		{ "seccomp-bpf",	no_argument,	   0, GETOPT_SECCOMP },
 
 		{ "trace",	required_argument, 0, GETOPT_QUAL_TRACE },
@@ -1751,16 +2101,26 @@ init(int argc, char *argv[])
 		{ "fault",	required_argument, 0, GETOPT_QUAL_FAULT },
 		{ "inject",	required_argument, 0, GETOPT_QUAL_INJECT },
 		{ "kvm",	required_argument, 0, GETOPT_QUAL_KVM },
+		{ "quiet",	optional_argument, 0, GETOPT_QUAL_QUIET },
+		{ "silent",	optional_argument, 0, GETOPT_QUAL_QUIET },
+		{ "silence",	optional_argument, 0, GETOPT_QUAL_QUIET },
+		{ "decode-fds",	optional_argument, 0, GETOPT_QUAL_DECODE_FD },
 
 		{ 0, 0, 0, 0 }
 	};
 
-	while ((c = getopt_long(argc, argv, optstring, longopts, NULL)) != EOF) {
+	lopt_idx = -1;
+	while ((c = getopt_long(argc, argv, optstring, longopts, &lopt_idx)) != EOF) {
+		const struct option *lopt = lopt_idx >= 0
+			&& (unsigned) lopt_idx < ARRAY_SIZE(longopts)
+			? longopts + lopt_idx : NULL;
+		lopt_idx = -1;
+
 		switch (c) {
 		case 'a':
 			acolumn = string_to_uint(optarg);
 			if (acolumn < 0)
-				error_opt_arg(c, optarg);
+				error_opt_arg(c, lopt, optarg);
 			break;
 		case 'A':
 			open_append = true;
@@ -1773,13 +2133,17 @@ init(int argc, char *argv[])
 			break;
 		case 'c':
 			if (cflag == CFLAG_BOTH) {
-				error_msg_and_help("-c and -C are mutually exclusive");
+				error_msg_and_help("-c/--summary-only and "
+						   "-C/--summary are mutually "
+						   "exclusive");
 			}
 			cflag = CFLAG_ONLY_STATS;
 			break;
 		case 'C':
 			if (cflag == CFLAG_ONLY_STATS) {
-				error_msg_and_help("-c and -C are mutually exclusive");
+				error_msg_and_help("-c/--summary-only and "
+						   "-C/--summary are mutually "
+						   "exclusive");
 			}
 			cflag = CFLAG_BOTH;
 			break;
@@ -1789,15 +2153,33 @@ init(int argc, char *argv[])
 		case 'D':
 			daemonized_tracer++;
 			break;
+		case GETOPT_DAEMONIZE:
+			daemonized_tracer_long =
+				find_arg_val(optarg, daemonize_str,
+					     DAEMONIZE_GRANDCHILD,
+					     DAEMONIZE_NONE);
+			if (daemonized_tracer_long <= DAEMONIZE_NONE)
+				error_opt_arg(c, lopt, optarg);
+			break;
 		case 'e':
 			qualify(optarg);
 			break;
 		case 'E':
-			if (putenv(optarg) < 0)
-				perror_msg_and_die("putenv");
+			if (env_change_count >= env_change_size)
+				env_changes = xgrowarray(env_changes,
+							 &env_change_size,
+							 sizeof(*env_changes));
+
+			env_changes[env_change_count++] = optarg;
 			break;
 		case 'f':
-			followfork++;
+			followfork_short++;
+			break;
+		case GETOPT_FOLLOWFORKS:
+			followfork = true;
+			break;
+		case GETOPT_OUTPUT_SEPARATELY:
+			output_separately = true;
 			break;
 		case 'F':
 			optF = 1;
@@ -1809,9 +2191,9 @@ init(int argc, char *argv[])
 			iflag = 1;
 			break;
 		case 'I':
-			opt_intr = string_to_uint_upto(optarg, NUM_INTR_OPTS - 1);
+			opt_intr = parse_interruptible_arg(optarg);
 			if (opt_intr <= 0)
-				error_opt_arg(c, optarg);
+				error_opt_arg(c, lopt, optarg);
 			break;
 		case 'k':
 #ifdef ENABLE_STACKTRACE
@@ -1822,43 +2204,71 @@ init(int argc, char *argv[])
 					  "build of strace");
 #endif
 			break;
+		case 'n':
+			nflag = 1;
+			break;
 		case 'o':
 			outfname = optarg;
 			break;
 		case 'O':
 			if (set_overhead(optarg) < 0)
-				error_opt_arg(c, optarg);
+				error_opt_arg(c, lopt, optarg);
 			break;
 		case 'p':
 			process_opt_p_list(optarg);
 			break;
 		case 'P':
-			pathtrace_select(optarg);
+			if (pathtrace_count >= pathtrace_size)
+				pathtrace_paths = xgrowarray(pathtrace_paths,
+					&pathtrace_size,
+					sizeof(pathtrace_paths[0]));
+
+			pathtrace_paths[pathtrace_count++] = optarg;
 			break;
 		case 'q':
-			qflag++;
+			qflag_short++;
 			break;
 		case 'r':
 			rflag = 1;
+			rflag_width = 6;
+			rflag_scale = str2timescale_optarg(optarg,
+							   &rflag_width);
+			if (rflag_scale < 0)
+				error_opt_arg(c, lopt, optarg);
 			break;
 		case 's':
 			i = string_to_uint(optarg);
 			if (i < 0 || (unsigned int) i > -1U / 4)
-				error_opt_arg(c, optarg);
+				error_opt_arg(c, lopt, optarg);
 			max_strlen = i;
 			break;
 		case 'S':
 			set_sortby(optarg);
+			sortby_set = true;
 			break;
 		case 't':
-			tflag++;
+			tflag_short++;
+			break;
+		case GETOPT_TS:
+			tflag_long_set = true;
+			if (parse_ts_arg(optarg ?: tflag_str))
+				error_opt_arg(c, lopt, optarg);
 			break;
 		case 'T':
 			Tflag = 1;
+			Tflag_width = 6;
+			Tflag_scale = str2timescale_optarg(optarg,
+							   &Tflag_width);
+			if (Tflag_scale < 0)
+				error_opt_arg(c, lopt, optarg);
 			break;
 		case 'u':
 			username = optarg;
 			break;
+		case 'U':
+			columns_set = true;
+			set_count_summary_columns(optarg);
+			break;
 		case 'v':
 			qualify_abbrev("none");
 			break;
@@ -1872,6 +2282,12 @@ init(int argc, char *argv[])
 		case 'x':
 			xflag++;
 			break;
+		case GETOPT_HEX_STR:
+			xflag_long = find_arg_val(optarg, xflag_str,
+						  HEXSTR_ALL, HEXSTR_NONE);
+			if (xflag_long <= HEXSTR_NONE)
+				error_opt_arg(c, lopt, optarg);
+			break;
 		case 'X':
 			if (!strcmp(optarg, "raw"))
 				xlat_verbosity = XLAT_STYLE_RAW;
@@ -1880,10 +2296,13 @@ init(int argc, char *argv[])
 			else if (!strcmp(optarg, "verbose"))
 				xlat_verbosity = XLAT_STYLE_VERBOSE;
 			else
-				error_opt_arg(c, optarg);
+				error_opt_arg(c, lopt, optarg);
 			break;
 		case 'y':
-			show_fd_path++;
+			yflag_short++;
+			break;
+		case GETOPT_PIDNS_TRANSLATION:
+			pidns_translation++;
 			break;
 		case 'z':
 			clear_number_set_array(status_set, 1);
@@ -1931,6 +2350,12 @@ init(int argc, char *argv[])
 		case GETOPT_QUAL_KVM:
 			qualify_kvm(optarg);
 			break;
+		case GETOPT_QUAL_QUIET:
+			qualify_quiet(optarg ?: qflag_qual);
+			break;
+		case GETOPT_QUAL_DECODE_FD:
+			qualify_decode_fd(optarg ?: yflag_qual);
+			break;
 		default:
 			error_msg_and_help(NULL);
 			break;
@@ -1944,8 +2369,18 @@ init(int argc, char *argv[])
 		error_msg_and_help("must have PROG [ARGS] or -p PID");
 	}
 
+	if (daemonized_tracer_long) {
+		if (daemonized_tracer) {
+			error_msg_and_die("-D and --daemonize cannot"
+					  " be provided simultaneously");
+		} else {
+			daemonized_tracer = daemonized_tracer_long;
+		}
+	}
+
 	if (!argc && daemonized_tracer) {
-		error_msg_and_help("PROG [ARGS] must be specified with -D");
+		error_msg_and_help("PROG [ARGS] must be specified with "
+				   "-D/--daemonize");
 	}
 
 	if (daemonized_tracer > (unsigned int) MAX_DAEMONIZE_OPTS)
@@ -1953,19 +2388,61 @@ init(int argc, char *argv[])
 				   "count is %d",
 				   daemonized_tracer, MAX_DAEMONIZE_OPTS);
 
+	if (tflag_short) {
+		if (tflag_long_set) {
+			error_msg_and_die("-t and --absolute-timestamps cannot"
+					  " be provided simultaneously");
+		}
+
+		parse_ts_arg(tflag_short == 1 ? tflag_str :
+			     tflag_short == 2 ? ttflag_str : tttflag_str);
+	}
+
+	if (xflag_long) {
+		if (xflag) {
+			error_msg_and_die("-x and --strings-in-hex cannot"
+					  " be provided simultaneously");
+		} else {
+			xflag = xflag_long;
+		}
+	}
+
+	if (yflag_short) {
+		if (decode_fd_set_updated) {
+			error_msg_and_die("-y and --decode-fds cannot"
+					  " be provided simultaneously");
+		}
+
+		qualify_decode_fd(yflag_short == 1 ? yflag_qual : yyflag_qual);
+	}
+
 	if (seccomp_filtering && detach_on_execve) {
 		error_msg("--seccomp-bpf is not enabled because"
 			  " it is not compatible with -b");
 		seccomp_filtering = false;
 	}
 
+	if (followfork_short) {
+		if (followfork) {
+			error_msg_and_die("-f and --follow-forks cannot"
+					  " be provided simultaneously");
+		} else if (followfork_short >= 2 && output_separately) {
+			error_msg_and_die("-ff and --output-separately cannot"
+					  " be provided simultaneously");
+		} else {
+			followfork = true;
+			output_separately = followfork_short >= 2;
+		}
+	}
+
 	if (seccomp_filtering) {
 		if (nprocs && (!argc || debug_flag))
 			error_msg("--seccomp-bpf is not enabled for processes"
 				  " attached with -p");
 		if (!followfork) {
-			error_msg("--seccomp-bpf implies -f");
-			followfork = 1;
+			error_msg("--seccomp-bpf cannot be used without "
+				  "-f/--follow-forks, disabling");
+			seccomp_filtering = false;
 		}
 	}
 
@@ -1974,32 +2451,63 @@ init(int argc, char *argv[])
 			error_msg("deprecated option -F ignored");
 		} else {
 			error_msg("option -F is deprecated, "
-				  "please use -f instead");
-			followfork = optF;
+				  "please use -f/--follow-forks instead");
+			followfork = true;
 		}
 	}
 
-	if (followfork >= 2 && cflag) {
-		error_msg_and_help("(-c or -C) and -ff are mutually exclusive");
+	if (output_separately && cflag) {
+		error_msg_and_help("(-c/--summary-only or -C/--summary) and"
+				   " -ff/--output-separately"
+				   " are mutually exclusive");
 	}
 
 	if (count_wallclock && !cflag) {
-		error_msg_and_help("-w must be given with (-c or -C)");
+		error_msg_and_help("-w/--summary-wall-clock must be given with"
+				   " (-c/--summary-only or -C/--summary)");
+	}
+
+	if (columns_set && !cflag) {
+		error_msg_and_help("-U/--summary-columns must be given with"
+				   " (-c/--summary-only or -C/--summary)");
+	}
+
+	if (sortby_set && !cflag) {
+		error_msg("-S/--summary-sort-by has no effect without"
+			  " (-c/--summary-only or -C/--summary)");
 	}
 
 	if (cflag == CFLAG_ONLY_STATS) {
 		if (iflag)
-			error_msg("-%c has no effect with -c", 'i');
+			error_msg("-i/--instruction-pointer has no effect "
+				  "with -c/--summary-only");
 		if (stack_trace_enabled)
-			error_msg("-%c has no effect with -c", 'k');
+			error_msg("-k/--stack-traces has no effect "
+				  "with -c/--summary-only");
+		if (nflag)
+			error_msg("-n/--syscall-number has no effect "
+				  "with -c/--summary-only");
 		if (rflag)
-			error_msg("-%c has no effect with -c", 'r');
-		if (tflag)
-			error_msg("-%c has no effect with -c", 't');
+			error_msg("-r/--relative-timestamps has no effect "
+				  "with -c/--summary-only");
+		if (tflag_format)
+			error_msg("-t/--absolute-timestamps has no effect "
+				  "with -c/--summary-only");
 		if (Tflag)
-			error_msg("-%c has no effect with -c", 'T');
-		if (show_fd_path)
-			error_msg("-%c has no effect with -c", 'y');
+			error_msg("-T/--syscall-times has no effect "
+				  "with -c/--summary-only");
+		if (!number_set_array_is_empty(decode_fd_set, 0))
+			error_msg("-y/--decode-fds has no effect "
+				  "with -c/--summary-only");
+	}
+
+	if (!outfname) {
+		if (output_separately && !followfork)
+			error_msg("--output-separately has no effect "
+				  "without -o/--output");
+		if (open_append)
+			error_msg("-A/--output-append-mode has no effect "
+				  "without -o/--output");
 	}
 
 #ifndef HAVE_OPEN_MEMSTREAM
@@ -2008,9 +2516,15 @@ init(int argc, char *argv[])
 #endif
 
 	if (zflags > 1)
-		error_msg("Only the last of -z/-Z options will take effect. "
+		error_msg("Only the last of "
+			  "-z/--successful-only/-Z/--failed-only options will "
+			  "take effect. "
 			  "See status qualifier for more complex filters.");
 
+	for (size_t cnt = 0; cnt < pathtrace_count; ++cnt)
+		pathtrace_select(pathtrace_paths[cnt]);
+	free(pathtrace_paths);
+
 	acolumn_spaces = xmalloc(acolumn + 1);
 	memset(acolumn_spaces, ' ', acolumn);
 	acolumn_spaces[acolumn] = '\0';
@@ -2027,7 +2541,8 @@ init(int argc, char *argv[])
 		struct passwd *pent;
 
 		if (getuid() != 0 || geteuid() != 0) {
-			error_msg_and_die("You must be root to use the -u option");
+			error_msg_and_die("You must be root to use "
+					  "the -u/--username option");
 		}
 		pent = getpwnam(username);
 		if (pent == NULL) {
@@ -2075,11 +2590,12 @@ init(int argc, char *argv[])
 			 * We can't do the <outfname>.PID funny business
 			 * when using popen, so prohibit it.
 			 */
-			if (followfork >= 2)
-				error_msg_and_help("piping the output and -ff "
+			if (output_separately)
+				error_msg_and_help("piping the output and "
+						   "-ff/--output-separately "
 						   "are mutually exclusive");
 			shared_log = strace_popen(outfname + 1);
-		} else if (followfork < 2) {
+		} else if (!output_separately) {
 			shared_log = strace_fopen(outfname);
 		} else if (strlen(outfname) >= PATH_MAX - sizeof(int) * 3) {
 			errno = ENAMETOOLONG;
@@ -2087,8 +2603,7 @@ init(int argc, char *argv[])
 		}
 	} else {
 		/* -ff without -o FILE is the same as single -f */
-		if (followfork >= 2)
-			followfork = 1;
+		output_separately = false;
 	}
 
 	if (!outfname || outfname[0] == '|' || outfname[0] == '!') {
@@ -2108,12 +2623,22 @@ init(int argc, char *argv[])
 	if (outfname && argc) {
 		if (!opt_intr)
 			opt_intr = INTR_NEVER;
-		if (!qflag)
-			qflag = 1;
+		if (!qflag_short && !quiet_set_updated)
+			qflag_short = 1;
 	}
 	if (!opt_intr)
 		opt_intr = INTR_WHILE_WAIT;
 
+	if (qflag_short) {
+		if (quiet_set_updated) {
+			error_msg_and_die("-q and -e quiet/--quiet cannot"
+					  " be provided simultaneously");
+		}
+
+		qualify_quiet(qflag_short == 1 ? qflag_qual :
+			      qflag_short == 2 ? qqflag_qual : qqqflag_qual);
+	}
+
 	/*
 	 * startup_child() must be called before the signal handlers get
 	 * installed below as they are inherited into the spawned process.
@@ -2121,7 +2646,19 @@ init(int argc, char *argv[])
 	 * in the startup_child() mode we kill the spawned process anyway.
 	 */
 	if (argc) {
-		startup_child(argv);
+		char **new_environ = make_env(environ, env_changes,
+					      env_change_count);
+		free(env_changes);
+
+		startup_child(argv, new_environ);
+
+		/*
+		 * On a NOMMU system, new_environ can be freed only after exec
+		 * in child, so we leak it in that case, similar to pathname
+		 * in startup_child().
+		 */
+		if (new_environ != environ && !NOMMU_SYSTEM)
+			free(new_environ);
 	}
 
 	set_sighandler(SIGTTOU, SIG_IGN, NULL);
@@ -2155,7 +2692,8 @@ init(int argc, char *argv[])
 	 * -f: yes (there can be more pids in the future); or
 	 * -p PID1,PID2: yes (there are already more than one pid)
 	 */
-	print_pid_pfx = (outfname && followfork < 2 && (followfork == 1 || nprocs > 1));
+	print_pid_pfx = outfname && !output_separately &&
+		((followfork && !output_separately) || nprocs > 1);
 }
 
 static struct tcb *
@@ -2259,18 +2797,20 @@ maybe_allocate_tcb(const int pid, int st
 			strace_child = 0;
 			return NULL;
 		}
-		/*
-		 * This can happen if we inherited an unknown child.
-		 * Example: (sleep 1 & exec strace true)
-		 */
-		error_msg("Exit of unknown pid %u ignored", pid);
+		if (!is_number_in_set(QUIET_EXIT, quiet_set)) {
+			/*
+			 * This can happen if we inherited an unknown child.
+			 * Example: (sleep 1 & exec strace true)
+			 */
+			error_msg("Exit of unknown pid %u ignored", pid);
+		}
 		return NULL;
 	}
 	if (followfork) {
 		/* We assume it's a fork/vfork/clone child */
 		struct tcb *tcp = alloctcb(pid);
 		after_successful_attach(tcp, post_attach_sigstop);
-		if (!qflag)
+		if (!is_number_in_set(QUIET_ATTACH, quiet_set))
 			error_msg("Process %d attached", pid);
 		return tcp;
 	} else {
@@ -2282,7 +2822,8 @@ maybe_allocate_tcb(const int pid, int st
 		 * observable stop here is the initial ptrace-stop.
 		 */
 		ptrace(PTRACE_DETACH, pid, NULL, 0L);
-		error_msg("Detached unknown pid %d", pid);
+		if (!is_number_in_set(QUIET_ATTACH, quiet_set))
+			error_msg("Detached unknown pid %d", pid);
 		return NULL;
 	}
 }
@@ -2350,9 +2891,12 @@ maybe_switch_tcbs(struct tcb *tcp, const
 	tcp = execve_thread;
 	tcp->pid = pid;
 	if (cflag != CFLAG_ONLY_STATS) {
-		printleader(tcp);
-		tprintf("+++ superseded by execve in pid %lu +++\n", old_pid);
-		line_ended();
+		if (!is_number_in_set(QUIET_THREAD_EXECVE, quiet_set)) {
+			printleader(tcp);
+			tprintf("+++ superseded by execve in pid %lu +++\n",
+				old_pid);
+			line_ended();
+		}
 		/*
 		 * Need to reopen memstream for thread
 		 * as we closed it in droptcb.
@@ -2403,7 +2947,7 @@ print_exited(struct tcb *tcp, const int
 	}
 
 	if (cflag != CFLAG_ONLY_STATS &&
-	    qflag < 2) {
+	    !is_number_in_set(QUIET_EXIT, quiet_set)) {
 		printleader(tcp);
 		tprintf("+++ exited with %d +++\n", WEXITSTATUS(status));
 		line_ended();
@@ -2419,7 +2963,7 @@ print_stopped(struct tcb *tcp, const sig
 		printleader(tcp);
 		if (si) {
 			tprintf("--- %s ", sprintsigname(sig));
-			printsiginfo(si);
+			printsiginfo(tcp, si);
 			tprints(" ---\n");
 		} else
 			tprintf("--- stopped by %s ---\n", sprintsigname(sig));
@@ -2466,7 +3010,7 @@ print_event_exit(struct tcb *tcp)
 		return;
 	}
 
-	if (followfork < 2 && printing_tcp && printing_tcp != tcp
+	if (!output_separately && printing_tcp && printing_tcp != tcp
 	    && printing_tcp->curcol != 0) {
 		set_current_tcp(printing_tcp);
 		tprints(" <unfinished ...>\n");
diff -pruN 5.5-3/strace-log-merge.1 5.9-0ubuntu2/strace-log-merge.1
--- 5.5-3/strace-log-merge.1	2020-02-06 16:23:56.000000000 +0000
+++ 5.9-0ubuntu2/strace-log-merge.1	2020-09-24 09:19:37.000000000 +0000
@@ -11,7 +11,7 @@
 .    BR "\\$1"
 ..
 .\"
-.TH STRACE-LOG-MERGE 1 "2020-02-04" "strace 5.5"
+.TH STRACE-LOG-MERGE 1 "2020-09-23" "strace 5.9"
 .\"
 .SH NAME
 strace-log-merge \- merge strace \-ff \-tt output
diff -pruN 5.5-3/strace.spec 5.9-0ubuntu2/strace.spec
--- 5.5-3/strace.spec	2020-02-06 16:23:56.000000000 +0000
+++ 5.9-0ubuntu2/strace.spec	2020-09-24 09:19:37.000000000 +0000
@@ -1,6 +1,6 @@
 Summary: Tracks and displays system calls associated with a running process
 Name: strace
-Version: 5.5
+Version: 5.9
 Release: 1%{?dist}
 # The test suite is GPLv2+, all the rest is LGPLv2.1+.
 License: LGPL-2.1+ and GPL-2.0+
@@ -39,6 +39,12 @@ BuildRequires: pkgconfig(bluez)
 %{?!buildroot:BuildRoot: %_tmppath/buildroot-%name-%version-%release}
 %define maybe_use_defattr %{?suse_version:%%defattr(-,root,root)}
 
+# Fallback definitions for make_build/make_install macros
+%{?!__make:       %global __make %_bindir/make}
+%{?!__install:    %global __install %_bindir/install}
+%{?!make_build:   %global make_build %__make %{?_smp_mflags}}
+%{?!make_install: %global make_install %__make install DESTDIR="%{?buildroot}" INSTALL="%__install -p"}
+
 %description
 The strace program intercepts and records the system calls called and
 received by a running process.  Strace can print a record of each
@@ -53,7 +59,7 @@ received by a process.
 %setup -q
 echo -n %version-%release > .tarball-version
 echo -n 2020 > .year
-echo -n 2020-02-04 > .strace.1.in.date
+echo -n 2020-09-23 > .strace.1.in.date
 
 %build
 echo 'BEGIN OF BUILD ENVIRONMENT INFORMATION'
@@ -69,10 +75,10 @@ echo 'END OF BUILD ENVIRONMENT INFORMATI
 
 CFLAGS_FOR_BUILD="$RPM_OPT_FLAGS"; export CFLAGS_FOR_BUILD
 %configure --enable-mpers=check
-make %{?_smp_mflags}
+%make_build
 
 %install
-make DESTDIR=%{buildroot} install
+%make_install
 
 # remove unpackaged files from the buildroot
 rm -f %{buildroot}%{_bindir}/strace-graph
@@ -85,7 +91,7 @@ wait
 
 %check
 %{buildroot}%{_bindir}/strace -V
-make %{?_smp_mflags} -k check VERBOSE=1
+%make_build -k check VERBOSE=1
 echo 'BEGIN OF TEST SUITE INFORMATION'
 tail -n 99999 -- tests*/test-suite.log tests*/ksysent.gen.log
 find tests* -type f -name '*.log' -print0 |
@@ -100,8 +106,20 @@ echo 'END OF TEST SUITE INFORMATION'
 %{_mandir}/man1/*
 
 %changelog
-* Thu Feb 06 2020 strace-devel@lists.strace.io - 5.5-1
-- strace 5.5 snapshot.
+* Thu Sep 24 2020 strace-devel@lists.strace.io - 5.9-1
+- strace 5.9 snapshot.
+
+* Thu Aug 06 2020 Dmitry V. Levin <ldv@altlinux.org> - 5.8-1
+- v5.7 -> v5.8.
+
+* Mon Jun 01 2020 Dmitry V. Levin <ldv@altlinux.org> - 5.7-1
+- v5.6 -> v5.7.
+
+* Tue Apr 07 2020 Dmitry V. Levin <ldv@altlinux.org> - 5.6-1
+- v5.5 -> v5.6.
+
+* Thu Feb 06 2020 Dmitry V. Levin <ldv@altlinux.org> - 5.5-1
+- v5.4 -> v5.5.
 
 * Thu Nov 28 2019 Dmitry V. Levin <ldv@altlinux.org> - 5.4-1
 - v5.3 -> v5.4.
diff -pruN 5.5-3/strace.spec.in 5.9-0ubuntu2/strace.spec.in
--- 5.5-3/strace.spec.in	2019-12-01 09:35:34.000000000 +0000
+++ 5.9-0ubuntu2/strace.spec.in	2020-09-03 18:42:36.000000000 +0000
@@ -39,6 +39,12 @@ BuildRequires: pkgconfig(bluez)
 %{?!buildroot:BuildRoot: %_tmppath/buildroot-%name-%version-%release}
 %define maybe_use_defattr %{?suse_version:%%defattr(-,root,root)}
 
+# Fallback definitions for make_build/make_install macros
+%{?!__make:       %global __make %_bindir/make}
+%{?!__install:    %global __install %_bindir/install}
+%{?!make_build:   %global make_build %__make %{?_smp_mflags}}
+%{?!make_install: %global make_install %__make install DESTDIR="%{?buildroot}" INSTALL="%__install -p"}
+
 %description
 The strace program intercepts and records the system calls called and
 received by a running process.  Strace can print a record of each
@@ -69,10 +75,10 @@ echo 'END OF BUILD ENVIRONMENT INFORMATI
 
 CFLAGS_FOR_BUILD="$RPM_OPT_FLAGS"; export CFLAGS_FOR_BUILD
 %configure --enable-mpers=check
-make %{?_smp_mflags}
+%make_build
 
 %install
-make DESTDIR=%{buildroot} install
+%make_install
 
 # remove unpackaged files from the buildroot
 rm -f %{buildroot}%{_bindir}/strace-graph
@@ -85,7 +91,7 @@ wait
 
 %check
 %{buildroot}%{_bindir}/strace -V
-make %{?_smp_mflags} -k check VERBOSE=1
+%make_build -k check VERBOSE=1
 echo 'BEGIN OF TEST SUITE INFORMATION'
 tail -n 99999 -- tests*/test-suite.log tests*/ksysent.gen.log
 find tests* -type f -name '*.log' -print0 |
@@ -103,6 +109,18 @@ echo 'END OF TEST SUITE INFORMATION'
 * @RPM_CHANGELOGTIME@ @PACKAGE_BUGREPORT@ - @PACKAGE_VERSION@-1
 - @PACKAGE_STRING@ snapshot.
 
+* Thu Aug 06 2020 Dmitry V. Levin <ldv@altlinux.org> - 5.8-1
+- v5.7 -> v5.8.
+
+* Mon Jun 01 2020 Dmitry V. Levin <ldv@altlinux.org> - 5.7-1
+- v5.6 -> v5.7.
+
+* Tue Apr 07 2020 Dmitry V. Levin <ldv@altlinux.org> - 5.6-1
+- v5.5 -> v5.6.
+
+* Thu Feb 06 2020 Dmitry V. Levin <ldv@altlinux.org> - 5.5-1
+- v5.4 -> v5.5.
+
 * Thu Nov 28 2019 Dmitry V. Levin <ldv@altlinux.org> - 5.4-1
 - v5.3 -> v5.4.
 
diff -pruN 5.5-3/syscall.c 5.9-0ubuntu2/syscall.c
--- 5.5-3/syscall.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/syscall.c	2020-08-25 14:29:30.000000000 +0000
@@ -268,9 +268,11 @@ update_personality(struct tcb *tcp, unsi
 		return;
 	tcp->currpers = personality;
 
-	if (!qflag) {
-		error_msg("[ Process PID=%d runs in %s mode. ]",
-			  tcp->pid, personality_names[personality]);
+	if (!is_number_in_set(QUIET_PERSONALITY, quiet_set)) {
+		printleader(tcp);
+		tprintf("[ Process PID=%d runs in %s mode. ]\n",
+			tcp->pid, personality_names[personality]);
+		line_ended();
 	}
 
 	if (need_mpers_warning[personality]) {
@@ -489,9 +491,12 @@ tamper_with_syscall_entering(struct tcb
 
 	struct inject_opts *opts = tcb_inject_opts(tcp);
 
-	if (!opts || opts->first == 0)
+	if (!opts || opts->first == 0 || opts->last == 0)
 		return 0;
 
+	if (opts->last != INJECT_LAST_INF)
+		--opts->last;
+
 	--opts->first;
 
 	if (opts->first != 0)
@@ -745,7 +750,7 @@ print_syscall_resume(struct tcb *tcp)
 	 * "strace -ff -oLOG test/threaded_execve" corner case.
 	 * It's the only case when -ff mode needs reprinting.
 	 */
-	if ((followfork < 2 && printing_tcp != tcp && !tcp->staged_output_data)
+	if ((!output_separately && printing_tcp != tcp && !tcp->staged_output_data)
 	    || (tcp->flags & TCB_REPRINT)) {
 		tcp->flags &= ~TCB_REPRINT;
 		printleader(tcp);
@@ -897,10 +902,17 @@ syscall_exiting_trace(struct tcb *tcp, s
 					tprintf("= %#" PRI_klx, tcp->u_rval);
 				}
 				break;
-			case RVAL_OCTAL:
+			case RVAL_OCTAL: {
+				unsigned long long mode =
+					zero_extend_signed_to_ull(tcp->u_rval);
 				tprints("= ");
-				print_numeric_long_umask(tcp->u_rval);
+#if ANY_WORDSIZE_LESS_THAN_KERNEL_LONG
+				if (current_klongsize < sizeof(tcp->u_rval))
+					mode = (unsigned int) mode;
+#endif
+				print_numeric_ll_umode_t(mode);
 				break;
+			}
 			case RVAL_UDECIMAL:
 #if ANY_WORDSIZE_LESS_THAN_KERNEL_LONG
 				if (current_klongsize < sizeof(tcp->u_rval)) {
@@ -913,12 +925,33 @@ syscall_exiting_trace(struct tcb *tcp, s
 				}
 				break;
 			case RVAL_FD:
-				if (show_fd_path) {
+				/*
+				 * printfd accepts int as fd and it makes
+				 * little sense to pass negative fds to it.
+				 */
+				if ((current_klongsize < sizeof(tcp->u_rval)) ||
+				    ((kernel_ulong_t) tcp->u_rval <= INT_MAX)) {
 					tprints("= ");
 					printfd(tcp, tcp->u_rval);
-				} else
+				} else {
 					tprintf("= %" PRI_kld, tcp->u_rval);
+				}
 				break;
+			case RVAL_TID:
+			case RVAL_SID:
+			case RVAL_TGID:
+			case RVAL_PGID: {
+				#define _(_t) [RVAL_##_t - RVAL_TID] = PT_##_t
+				static const enum pid_type types[] = {
+					_(TID), _(SID), _(TGID), _(PGID),
+				};
+				#undef _
+
+				tprints("= ");
+				printpid(tcp, tcp->u_rval,
+					 types[(sys_res & RVAL_MASK) - RVAL_TID]);
+				break;
+			}
 			default:
 				error_msg("invalid rval format");
 				break;
@@ -931,8 +964,12 @@ syscall_exiting_trace(struct tcb *tcp, s
 	}
 	if (Tflag) {
 		ts_sub(ts, ts, &tcp->etime);
-		tprintf(" <%ld.%06ld>",
-			(long) ts->tv_sec, (long) ts->tv_nsec / 1000);
+		tprintf(" <%ld", (long) ts->tv_sec);
+		if (Tflag_width) {
+			tprintf(".%0*ld",
+				Tflag_width, (long) ts->tv_nsec / Tflag_scale);
+		}
+		tprints(">");
 	}
 	tprints("\n");
 	dumpio(tcp);
@@ -1332,6 +1369,7 @@ get_scno(struct tcb *tcp)
 			return rc;
 	}
 
+	tcp->true_scno = tcp->scno;
 	tcp->scno = shuffle_scno(tcp->scno);
 
 	if (scno_is_valid(tcp->scno)) {
diff -pruN 5.5-3/sysent.h 5.9-0ubuntu2/sysent.h
--- 5.5-3/sysent.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/sysent.h	2020-06-01 14:15:16.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -38,5 +38,6 @@ typedef struct sysent {
 # define TRACE_PURE			002000000	/* Trace getter syscalls with no arguments. */
 # define TRACE_SECCOMP_DEFAULT		004000000	/* Syscall is traced by seccomp filter by default. */
 # define TRACE_CREDS			010000000	/* Trace process credentials-related syscalls. */
+# define TRACE_CLOCK			020000000	/* Trace syscalls reading or modifying system clocks. */
 
 #endif /* !STRACE_SYSENT_H */
diff -pruN 5.5-3/sysent_shorthand_defs.h 5.9-0ubuntu2/sysent_shorthand_defs.h
--- 5.5-3/sysent_shorthand_defs.h	2019-12-29 22:25:26.000000000 +0000
+++ 5.9-0ubuntu2/sysent_shorthand_defs.h	2020-06-01 14:15:16.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -29,6 +29,7 @@
 # define CST	0
 # define TSD	0
 # define TC	0
+# define TCL	0
 # define SEN(a)	0, 0
 
 #else	/*	!STRACE_TESTS_H	*/
@@ -55,6 +56,7 @@
 # define CST	COMPAT_SYSCALL_TYPES
 # define TSD	TRACE_SECCOMP_DEFAULT
 # define TC	TRACE_CREDS
+# define TCL	TRACE_CLOCK
 /* SEN(a) is defined elsewhere */
 
 #endif
diff -pruN 5.5-3/sysent_shorthand_undefs.h 5.9-0ubuntu2/sysent_shorthand_undefs.h
--- 5.5-3/sysent_shorthand_undefs.h	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/sysent_shorthand_undefs.h	2020-06-01 14:15:16.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2018 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -19,9 +19,13 @@
 #undef TSF
 #undef TFSF
 #undef TSFA
+#undef PU
 #undef NF
 #undef MA
 #undef SI
 #undef SE
 #undef CST
+#undef TSD
+#undef TC
+#undef TCL
 #undef SEN
diff -pruN 5.5-3/.tarball-version 5.9-0ubuntu2/.tarball-version
--- 5.5-3/.tarball-version	2020-02-06 16:24:09.000000000 +0000
+++ 5.9-0ubuntu2/.tarball-version	2020-09-24 09:19:54.000000000 +0000
@@ -1 +1 @@
-5.5
+5.9
diff -pruN 5.5-3/tee.c 5.9-0ubuntu2/tee.c
--- 5.5-3/tee.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tee.c	2020-09-23 16:28:11.000000000 +0000
@@ -0,0 +1,525 @@
+/*
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
+#include "defs.h"
+#include "print_fields.h"
+
+#include "types/tee.h"
+
+#define XLAT_MACROS_ONLY
+#include "xlat/tee_ioctl_cmds.h"
+#undef XLAT_MACROS_ONLY
+
+#include "xlat/tee_ioctl_gen_caps.h"
+#include "xlat/tee_ioctl_impl_ids.h"
+#include "xlat/tee_ioctl_login_types.h"
+#include "xlat/tee_ioctl_max_arg_size.h"
+#include "xlat/tee_ioctl_origins.h"
+#include "xlat/tee_ioctl_optee_caps.h"
+#include "xlat/tee_ioctl_param_attr_types.h"
+#include "xlat/tee_ioctl_shm_flags.h"
+
+#define TEE_IOCTL_PARAM_SIZE(x) (sizeof(struct_tee_ioctl_param) * (x))
+
+#define TEE_FETCH_BUF_DATA(buf_, arg_, params_) \
+	tee_fetch_buf_data(tcp, arg, &buf_, sizeof(arg_), \
+			   &arg_, &arg_.num_params, \
+			   params_)
+
+/* session id is printed as 0x%x in libteec */
+#define PRINT_FIELD_SESSION(prefix_, where_, field_) \
+	PRINT_FIELD_X(prefix_, where_, field_)
+
+static void
+tee_print_buf(struct_tee_ioctl_buf_data *buf)
+{
+	PRINT_FIELD_U("{", *buf, buf_len);
+	PRINT_FIELD_ADDR64(", ", *buf, buf_ptr);
+	tprints("}");
+}
+
+static int
+tee_fetch_buf_data(struct tcb *const tcp,
+		   const kernel_ulong_t arg,
+		   struct_tee_ioctl_buf_data *buf,
+		   size_t arg_size,
+		   void *arg_struct,
+		   unsigned *num_params,
+		   uint64_t *params)
+{
+	if (umove_or_printaddr(tcp, arg, buf))
+		return RVAL_IOCTL_DECODED;
+	if (buf->buf_len > TEE_MAX_ARG_SIZE || buf->buf_len < arg_size) {
+		tee_print_buf(buf);
+		return RVAL_IOCTL_DECODED;
+	}
+	if (umoven(tcp, buf->buf_ptr, arg_size, arg_struct)) {
+		tee_print_buf(buf);
+		return RVAL_IOCTL_DECODED;
+	}
+	if (entering(tcp) &&
+	    (arg_size + TEE_IOCTL_PARAM_SIZE(*num_params) != buf->buf_len)) {
+		/*
+		 * We could print whatever number of params
+		 * is in buf_data, but the kernel would ignore
+		 * them anyway (and return -EINVAL) if
+		 * the above condition is not satisfied.
+		 *
+		 * Except for on exiting. The kernel has the right
+		 * to update num_params but not buf_len
+		 * (see tee_ioctl_supp_recv)
+		 */
+		tee_print_buf(buf);
+		return RVAL_IOCTL_DECODED;
+	}
+	if (*num_params) {
+		*params = buf->buf_ptr + arg_size;
+	} else {
+		*params = 0;
+	}
+
+	return 0;
+}
+
+static bool
+tee_print_param_fn(struct tcb *tcp, void *elem_buf, size_t elem_size, void *data)
+{
+	struct_tee_ioctl_param *param = (struct_tee_ioctl_param *) elem_buf;
+
+	tprintf("{attr=");
+	printxval(tee_ioctl_param_attr_types,
+		    param->attr & ~TEE_IOCTL_PARAM_ATTR_META,
+		    "TEE_IOCTL_PARAM_ATTR_");
+	if (param->attr & TEE_IOCTL_PARAM_ATTR_META)
+		tprintf("|TEE_IOCTL_PARAM_ATTR_META");
+
+	switch (param->attr) {
+	case TEE_IOCTL_PARAM_ATTR_TYPE_NONE:
+		break;
+
+	case TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INPUT:
+	case TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INOUT:
+	case TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_OUTPUT:
+		tprintf(", shm_offs=%#llx", (unsigned long long) param->a);
+		tprintf(", size=%#llx", (unsigned long long) param->b);
+		tprintf(", shm_id=%llu", (unsigned long long) param->c);
+		break;
+
+	case TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INPUT:
+	case TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INOUT:
+	case TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_OUTPUT:
+	default:
+		PRINT_FIELD_X(", ", *param, a);
+		PRINT_FIELD_X(", ", *param, b);
+		PRINT_FIELD_X(", ", *param, c);
+		break;
+	}
+	tprints("}");
+	return true;
+}
+
+static void
+tee_print_params(struct tcb *const tcp, uint64_t params_start, unsigned num_params)
+{
+	struct_tee_ioctl_param param_buffer;
+
+	tprints(", params=");
+	print_array(tcp, params_start, num_params, &param_buffer, sizeof(param_buffer),
+		    tfetch_mem, tee_print_param_fn, NULL);
+}
+
+static int
+tee_version(struct tcb *const tcp, const kernel_ulong_t arg)
+{
+	struct_tee_ioctl_version_data version;
+
+	if (entering(tcp)) {
+		tprints(", ");
+		return 0;
+	}
+
+	if (umove_or_printaddr(tcp, arg, &version))
+		return RVAL_IOCTL_DECODED;
+
+	PRINT_FIELD_XVAL("{", version, impl_id,
+			 tee_ioctl_impl_ids, "TEE_IMPL_ID_???");
+	PRINT_FIELD_FLAGS(", ", version, gen_caps,
+			  tee_ioctl_gen_caps, "TEE_GEN_CAP_???");
+	if (version.impl_id == TEE_IMPL_ID_OPTEE) {
+		PRINT_FIELD_FLAGS(", ", version, impl_caps,
+				  tee_ioctl_optee_caps, "TEE_OPTEE_CAP_???");
+	} else {
+		PRINT_FIELD_X(", ", version, impl_caps);
+	}
+
+	tprints("}");
+	return RVAL_IOCTL_DECODED;
+}
+
+static int
+tee_open_session(struct tcb *const tcp, const kernel_ulong_t arg)
+{
+	int rval;
+	struct_tee_ioctl_buf_data buf_data;
+	struct_tee_ioctl_open_session_arg open_session;
+	uint64_t params;
+	gid_t gid;
+
+	if (entering(tcp)) {
+		tprints(", ");
+
+		if ((rval = TEE_FETCH_BUF_DATA(buf_data, open_session, &params)))
+			return rval;
+
+		PRINT_FIELD_U("{", buf_data, buf_len);
+		PRINT_FIELD_UUID(", buf_ptr={", open_session, uuid);
+		PRINT_FIELD_XVAL(", ", open_session, clnt_login,
+				 tee_ioctl_login_types, "TEE_IOCTL_LOGIN_???");
+		/*
+		 * tee_ioctl_open_session_arg.clnt_uuid is used to pass
+		 * connectionData, which is currently only used to indicate
+		 * which group the client application wishes to authenticate as
+		 * (when TEE_IOCTL_LOGIN_GROUP or TEE_IOCTL_LOGIN_GROUP_APPLICATION
+		 * are used).
+		 *
+		 * It is not an UUID; actual client UUID is computed in the kernel.
+		 */
+		switch (open_session.clnt_login) {
+		case TEE_IOCTL_LOGIN_PUBLIC:
+		case TEE_IOCTL_LOGIN_USER:
+		case TEE_IOCTL_LOGIN_APPLICATION:
+		case TEE_IOCTL_LOGIN_USER_APPLICATION:
+			break;
+		case TEE_IOCTL_LOGIN_GROUP:
+		case TEE_IOCTL_LOGIN_GROUP_APPLICATION:
+			memcpy(&gid, open_session.clnt_uuid, sizeof(gid));
+			printuid(", clnt_uuid=", gid);
+			break;
+		default:
+			PRINT_FIELD_X_ARRAY(", ", open_session, clnt_uuid);
+		}
+		PRINT_FIELD_U(", ", open_session, cancel_id);
+		PRINT_FIELD_U(", ", open_session, num_params);
+		tee_print_params(tcp, params, open_session.num_params);
+
+		tprints("}");
+		return 0;
+
+	} else if (syserror(tcp)) {
+		tprints("}");
+		return RVAL_IOCTL_DECODED;
+
+	} else {
+		tprints(" => ");
+		/*
+		 * Yes, params are [in/out] for TEE_IOC_OPEN_SESSION.
+		 * As for all other operations they are used in.
+		 */
+		if ((rval = TEE_FETCH_BUF_DATA(buf_data, open_session, &params)))
+			return rval;
+
+		PRINT_FIELD_SESSION("{", open_session, session);
+		PRINT_FIELD_U(", ", open_session, ret);
+		PRINT_FIELD_XVAL(", ", open_session, ret_origin, tee_ioctl_origins,
+				 "TEEC_ORIGIN_???");
+		tee_print_params(tcp, params, open_session.num_params);
+
+		tprints("}}");
+		return RVAL_IOCTL_DECODED;
+	}
+}
+
+static int
+tee_invoke(struct tcb *const tcp, const kernel_ulong_t arg)
+{
+	int rval;
+	struct_tee_ioctl_buf_data buf_data;
+	struct_tee_ioctl_invoke_arg invoke;
+	uint64_t params;
+
+	if (entering(tcp)) {
+		tprints(", ");
+		if ((rval = TEE_FETCH_BUF_DATA(buf_data, invoke, &params)))
+			return rval;
+
+		PRINT_FIELD_U("{", buf_data, buf_len);
+		PRINT_FIELD_U(", buf_ptr={", invoke, func);
+		PRINT_FIELD_SESSION(", ", invoke, session);
+		PRINT_FIELD_U(", ", invoke, cancel_id);
+		PRINT_FIELD_U(", ", invoke, num_params);
+		tee_print_params(tcp, params, invoke.num_params);
+
+		tprints("}");
+		return 0;
+
+	} else if (syserror(tcp)) {
+		tprints("}");
+		return RVAL_IOCTL_DECODED;
+
+	} else {
+		tprints(" => ");
+		if ((rval = TEE_FETCH_BUF_DATA(buf_data, invoke, &params)))
+			return rval;
+
+		PRINT_FIELD_U("{", invoke, ret);
+		PRINT_FIELD_XVAL(", ", invoke, ret_origin, tee_ioctl_origins,
+				 "TEEC_ORIGIN_???");
+		tee_print_params(tcp, params, invoke.num_params);
+
+		tprints("}}");
+		return RVAL_IOCTL_DECODED;
+	}
+}
+
+static int
+tee_cancel(struct tcb *const tcp, const kernel_ulong_t arg)
+{
+	struct_tee_ioctl_cancel_arg cancel;
+
+	tprints(", ");
+	if (umove_or_printaddr(tcp, arg, &cancel))
+		return RVAL_IOCTL_DECODED;
+
+	PRINT_FIELD_U("{", cancel, cancel_id);
+	PRINT_FIELD_SESSION(", ", cancel, session);
+
+	tprints("}");
+	return RVAL_IOCTL_DECODED;
+}
+
+static int
+tee_close_session(struct tcb *const tcp, const kernel_ulong_t arg)
+{
+	struct_tee_ioctl_close_session_arg close_session;
+
+	tprints(", ");
+	if (umove_or_printaddr(tcp, arg, &close_session))
+		return RVAL_IOCTL_DECODED;
+
+	PRINT_FIELD_SESSION("{", close_session, session);
+
+	tprints("}");
+	return RVAL_IOCTL_DECODED;
+}
+
+static int
+tee_suppl_recv(struct tcb *const tcp, const kernel_ulong_t arg)
+{
+	int rval;
+	struct_tee_ioctl_buf_data buf_data;
+	struct_tee_iocl_supp_recv_arg supp_recv;
+	uint64_t params;
+
+	if (entering(tcp)) {
+		tprints(", ");
+		if ((rval = TEE_FETCH_BUF_DATA(buf_data, supp_recv, &params)))
+			return rval;
+
+		PRINT_FIELD_U("{", buf_data, buf_len);
+		PRINT_FIELD_U(", buf_ptr={", supp_recv, func);
+		PRINT_FIELD_U(", ", supp_recv, num_params);
+		tee_print_params(tcp, params, supp_recv.num_params);
+
+		tprints("}");
+		return 0;
+
+	} else if (syserror(tcp)) {
+		tprints("}");
+		return RVAL_IOCTL_DECODED;
+
+	} else {
+		tprints(" => ");
+		if ((rval = TEE_FETCH_BUF_DATA(buf_data, supp_recv, &params)))
+			return rval;
+
+		/* num_params is [in/out] for TEE_IOC_SUPPL_RECV only */
+		PRINT_FIELD_U("{", supp_recv, num_params);
+		tee_print_params(tcp, params, supp_recv.num_params);
+
+		tprints("}}");
+		return RVAL_IOCTL_DECODED;
+	}
+}
+
+static int
+tee_suppl_send(struct tcb *const tcp, const kernel_ulong_t arg)
+{
+	int rval;
+	struct_tee_ioctl_buf_data buf_data;
+	struct_tee_iocl_supp_send_arg supp_send;
+	uint64_t params;
+
+	if (entering(tcp)) {
+		tprints(", ");
+		if ((rval = TEE_FETCH_BUF_DATA(buf_data, supp_send, &params)))
+			return rval;
+
+		PRINT_FIELD_U("{", buf_data, buf_len);
+		PRINT_FIELD_U(", buf_ptr={", supp_send, num_params);
+		tee_print_params(tcp, params, supp_send.num_params);
+
+		tprints("}");
+		return 0;
+
+	} else if (syserror(tcp)) {
+		tprints("}");
+		return RVAL_IOCTL_DECODED;
+
+	} else {
+		tprints(" => ");
+		if ((rval = TEE_FETCH_BUF_DATA(buf_data, supp_send, &params)))
+			return rval;
+
+		PRINT_FIELD_U("{", supp_send, ret);
+		tee_print_params(tcp, params, supp_send.num_params);
+
+		tprints("}}");
+		return RVAL_IOCTL_DECODED;
+	}
+}
+
+static int
+tee_shm_alloc(struct tcb *const tcp, const kernel_ulong_t arg)
+{
+	struct_tee_ioctl_shm_alloc_data shm_alloc;
+
+	if (entering(tcp)) {
+		tprints(", ");
+		if (umove_or_printaddr(tcp, arg, &shm_alloc))
+			return RVAL_IOCTL_DECODED;
+
+		PRINT_FIELD_X("{", shm_alloc, size);
+		PRINT_FIELD_FLAGS(", ", shm_alloc, flags,
+				  tee_ioctl_shm_flags, "TEE_IOCTL_SHM_???");
+		tprints("}");
+		return 0;
+
+	} else if (syserror(tcp)) {
+		return RVAL_IOCTL_DECODED;
+
+	} else {
+		tprints(" => ");
+		if (umove_or_printaddr(tcp, arg, &shm_alloc))
+			return RVAL_IOCTL_DECODED;
+
+		PRINT_FIELD_X("{", shm_alloc, size);
+		PRINT_FIELD_FLAGS(", ", shm_alloc, flags,
+				  tee_ioctl_shm_flags, "TEE_IOCTL_SHM_???");
+		PRINT_FIELD_D(", ", shm_alloc, id);
+
+		tprints("}");
+		return RVAL_IOCTL_DECODED;
+	}
+}
+
+static int
+tee_shm_register_fd(struct tcb *const tcp, const kernel_ulong_t arg)
+{
+	struct_tee_ioctl_shm_register_fd_data shm_register_fd;
+
+	if (entering(tcp)) {
+		tprints(", ");
+		if (umove_or_printaddr(tcp, arg, &shm_register_fd))
+			return RVAL_IOCTL_DECODED;
+
+		PRINT_FIELD_FD("{", shm_register_fd, fd, tcp);
+		PRINT_FIELD_FLAGS(", ", shm_register_fd, flags,
+				  tee_ioctl_shm_flags, "TEE_IOCTL_SHM_???");
+		tprints("}");
+		return 0;
+
+	} else if (syserror(tcp)) {
+		return RVAL_IOCTL_DECODED;
+
+	} else {
+		tprints(" => ");
+		if (umove_or_printaddr(tcp, arg, &shm_register_fd))
+			return RVAL_IOCTL_DECODED;
+
+		PRINT_FIELD_X("{", shm_register_fd, size);
+		PRINT_FIELD_D(", ", shm_register_fd, id);
+
+		tprints("}");
+		return RVAL_IOCTL_DECODED;
+	}
+}
+
+static int
+tee_shm_register(struct tcb *const tcp, const kernel_ulong_t arg)
+{
+	struct_tee_ioctl_shm_register_data shm_register;
+
+	if (entering(tcp)) {
+		tprints(", ");
+		if (umove_or_printaddr(tcp, arg, &shm_register))
+			return RVAL_IOCTL_DECODED;
+
+		PRINT_FIELD_ADDR64("{", shm_register, addr);
+		PRINT_FIELD_X(", ", shm_register, length);
+		PRINT_FIELD_FLAGS(", ", shm_register, flags,
+				  tee_ioctl_shm_flags, "TEE_IOCTL_SHM_???");
+		tprints("}");
+		return 0;
+
+	} else if (syserror(tcp)) {
+		return RVAL_IOCTL_DECODED;
+
+	} else {
+		tprints(" => ");
+		if (umove_or_printaddr(tcp, arg, &shm_register))
+			return RVAL_IOCTL_DECODED;
+
+		PRINT_FIELD_X("{", shm_register, length);
+		PRINT_FIELD_FLAGS(", ", shm_register, flags,
+				  tee_ioctl_shm_flags, "TEE_IOCTL_SHM_???");
+		PRINT_FIELD_D(", ", shm_register, id);
+
+		tprints("}");
+		return RVAL_IOCTL_DECODED;
+	}
+}
+
+int
+tee_ioctl(struct tcb *const tcp, const unsigned int code,
+	  const kernel_ulong_t arg)
+{
+	switch (code) {
+	case TEE_IOC_VERSION:
+		return tee_version(tcp, arg);
+
+	case TEE_IOC_OPEN_SESSION:
+		return tee_open_session(tcp, arg);
+
+	case TEE_IOC_INVOKE:
+		return tee_invoke(tcp, arg);
+
+	case TEE_IOC_CANCEL:
+		return tee_cancel(tcp, arg);
+
+	case TEE_IOC_CLOSE_SESSION:
+		return tee_close_session(tcp, arg);
+
+	case TEE_IOC_SUPPL_RECV:
+		return tee_suppl_recv(tcp, arg);
+
+	case TEE_IOC_SUPPL_SEND:
+		return tee_suppl_send(tcp, arg);
+
+	case TEE_IOC_SHM_ALLOC:
+		return tee_shm_alloc(tcp, arg);
+
+	case TEE_IOC_SHM_REGISTER_FD:
+		/* This one isn't upstream */
+		return tee_shm_register_fd(tcp, arg);
+
+	case TEE_IOC_SHM_REGISTER:
+		return tee_shm_register(tcp, arg);
+
+	default:
+		return RVAL_DECODED;
+	}
+}
diff -pruN 5.5-3/test-driver 5.9-0ubuntu2/test-driver
--- 5.5-3/test-driver	2020-02-06 16:23:37.000000000 +0000
+++ 5.9-0ubuntu2/test-driver	2020-09-24 09:19:03.000000000 +0000
@@ -3,7 +3,7 @@
 
 scriptversion=2018-03-07.03; # UTC
 
-# Copyright (C) 2011-2018 Free Software Foundation, Inc.
+# Copyright (C) 2011-2020 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -42,11 +42,13 @@ print_usage ()
 {
   cat <<END
 Usage:
-  test-driver --test-name=NAME --log-file=PATH --trs-file=PATH
-              [--expect-failure={yes|no}] [--color-tests={yes|no}]
-              [--enable-hard-errors={yes|no}] [--]
+  test-driver --test-name NAME --log-file PATH --trs-file PATH
+              [--expect-failure {yes|no}] [--color-tests {yes|no}]
+              [--enable-hard-errors {yes|no}] [--]
               TEST-SCRIPT [TEST-SCRIPT-ARGUMENTS]
+
 The '--test-name', '--log-file' and '--trs-file' options are mandatory.
+See the GNU Automake documentation for information.
 END
 }
 
diff -pruN 5.5-3/tests/bexecve.test 5.9-0ubuntu2/tests/bexecve.test
--- 5.5-3/tests/bexecve.test	2019-11-28 19:30:05.000000000 +0000
+++ 5.9-0ubuntu2/tests/bexecve.test	2020-04-03 22:58:26.000000000 +0000
@@ -3,7 +3,7 @@
 # Check -bexecve behavior.
 #
 # Copyright (c) 2015 Dmitry V. Levin <ldv@altlinux.org>
-# Copyright (c) 2015-2019 The strace developers.
+# Copyright (c) 2015-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -16,27 +16,26 @@ run_strace_redir()
 	$STRACE "$@" 2> "$LOG"
 }
 
-run_strace_redir -enone ../set_ptracer_any true ||
+run_strace_redir --quiet=personality -enone ../set_ptracer_any true ||
 	dump_log_and_fail_with "$STRACE $args: unexpected exit status"
 
-run_strace_redir -enone ../set_ptracer_any false
+run_strace_redir --quiet=personality -enone ../set_ptracer_any false
 [ $? -eq 1 ] ||
 	dump_log_and_fail_with "$STRACE $args: unexpected exit status"
 
-run_strace_redir -bexecve -enone ../set_ptracer_any false ||
+run_strace_redir --quiet=personality -bexecve -enone ../set_ptracer_any false ||
 	dump_log_and_fail_with "$STRACE $args: unexpected exit status"
 
 pattern_detached='[^:]*strace: Process [1-9][0-9]* detached'
-pattern_personality='[^:]*strace: \[ Process PID=[1-9][0-9]* runs in .* mode. \]'
 
 LC_ALL=C grep -x "$pattern_detached" "$LOG" > /dev/null ||
 	dump_log_and_fail_with "$STRACE $args: output mismatch"
 
-if LC_ALL=C grep -E -v -x "($pattern_detached|$pattern_personality)" "$LOG" > /dev/null; then
+if LC_ALL=C grep -E -v -x "$pattern_detached" "$LOG" > /dev/null; then
 	dump_log_and_fail_with "$STRACE $args: unexpected output"
 fi
 
-run_strace_redir --seccomp-bpf -bexecve -enone ../set_ptracer_any false ||
+run_strace_redir --quiet=personality --seccomp-bpf -bexecve -enone ../set_ptracer_any false ||
 	dump_log_and_fail_with "$STRACE $args: unexpected exit status"
 
 pattern_seccomp='[^:]*strace: --seccomp-bpf is not enabled because it is not compatible with -b'
@@ -45,7 +44,7 @@ LC_ALL=C grep -x "$pattern_detached" "$L
 LC_ALL=C grep -x "$pattern_seccomp" "$LOG" > /dev/null ||
 	dump_log_and_fail_with "$STRACE $args: output mismatch"
 
-pattern_all="$pattern_detached|$pattern_seccomp|$pattern_personality"
+pattern_all="$pattern_detached|$pattern_seccomp"
 if LC_ALL=C grep -E -v -x "$pattern_all" "$LOG" > /dev/null; then
 	dump_log_and_fail_with "$STRACE $args: unexpected output"
 fi
diff -pruN 5.5-3/tests/bpf.c 5.9-0ubuntu2/tests/bpf.c
--- 5.5-3/tests/bpf.c	2019-12-10 09:44:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/bpf.c	2020-09-06 08:00:00.000000000 +0000
@@ -2,7 +2,7 @@
  * Check bpf syscall decoding.
  *
  * Copyright (c) 2015-2017 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -27,6 +27,7 @@
 
 #include "xlat.h"
 #include "xlat/bpf_commands.h"
+#include "xlat/bpf_map_types.h"
 #include "xlat/bpf_prog_types.h"
 
 #if defined MPERS_IS_m32 || SIZEOF_KERNEL_LONG_T > 4
@@ -42,6 +43,10 @@
 # define BIG_ADDR_MAYBE(addr_)
 #endif
 
+#ifndef FD0_PATH
+# define FD0_PATH ""
+#endif
+
 #ifndef HAVE_STRUCT_BPF_INSN
 struct bpf_insn {
 	uint8_t	code;
@@ -75,6 +80,11 @@ union bpf_attr_data {
 	BPF_ATTR_DATA_FIELD(BPF_BTF_GET_FD_BY_ID);
 	BPF_ATTR_DATA_FIELD(BPF_TASK_FD_QUERY);
 	BPF_ATTR_DATA_FIELD(BPF_MAP_FREEZE);
+	BPF_ATTR_DATA_FIELD(BPF_MAP_LOOKUP_BATCH);
+	BPF_ATTR_DATA_FIELD(BPF_MAP_UPDATE_BATCH);
+	BPF_ATTR_DATA_FIELD(BPF_MAP_DELETE_BATCH);
+	BPF_ATTR_DATA_FIELD(BPF_LINK_CREATE);
+	BPF_ATTR_DATA_FIELD(BPF_LINK_UPDATE);
 	char char_data[256];
 };
 
@@ -109,8 +119,8 @@ sys_bpf(kernel_ulong_t cmd, kernel_ulong
 
 #ifdef INJECT_RETVAL
 	if (rc != INJECT_RETVAL)
-		error_msg_and_fail("Got a return value of %ld != %d",
-				   rc, INJECT_RETVAL);
+		error_msg_and_fail("Got a return value of %ld != %ld",
+				   rc, (long) INJECT_RETVAL);
 
 	static char inj_errstr[4096];
 
@@ -251,6 +261,8 @@ init_BPF_MAP_CREATE_attr7(struct bpf_att
 	attr->map_ifindex = ifindex_lo();
 }
 
+static_assert(ARRAY_SIZE(bpf_map_types_xdata) == 28,
+	      "The map_type for tests 1 and 2 below needs to be updated");
 static struct bpf_attr_check BPF_MAP_CREATE_checks[] = {
 	{
 		.data = { .BPF_MAP_CREATE_data = { .map_type = 2 } },
@@ -260,7 +272,7 @@ static struct bpf_attr_check BPF_MAP_CRE
 	},
 	{ /* 1 */
 		.data = { .BPF_MAP_CREATE_data = {
-			.map_type = 20,
+			.map_type = 27,
 			.key_size = 4,
 			.value_size = 8,
 			.max_entries = 256,
@@ -270,7 +282,7 @@ static struct bpf_attr_check BPF_MAP_CRE
 			.map_name = "0123456789abcde",
 		} },
 		.size = offsetof(struct BPF_MAP_CREATE_struct, map_name) + 8,
-		.str = "map_type=BPF_MAP_TYPE_REUSEPORT_SOCKARRAY, key_size=4"
+		.str = "map_type=BPF_MAP_TYPE_RINGBUF, key_size=4"
 		       ", value_size=8, max_entries=256"
 		       ", map_flags=BPF_F_NO_PREALLOC|BPF_F_NO_COMMON_LRU"
 				   "|BPF_F_NUMA_NODE|BPF_F_RDONLY|BPF_F_WRONLY"
@@ -282,7 +294,7 @@ static struct bpf_attr_check BPF_MAP_CRE
 	},
 	{ /* 2 */
 		.data = { .BPF_MAP_CREATE_data = {
-			.map_type = 26,
+			.map_type = 28,
 			.key_size = 0xface1e55,
 			.value_size = 0xbadc0ded,
 			.max_entries = 0xbeefcafe,
@@ -293,7 +305,7 @@ static struct bpf_attr_check BPF_MAP_CRE
 			.map_ifindex = 3141592653,
 		} },
 		.size = offsetofend(struct BPF_MAP_CREATE_struct, map_ifindex),
-		.str = "map_type=0x1a /* BPF_MAP_TYPE_??? */"
+		.str = "map_type=0x1c /* BPF_MAP_TYPE_??? */"
 		       ", key_size=4207812181, value_size=3134983661"
 		       ", max_entries=3203386110"
 		       ", map_flags=0xfffff800 /* BPF_F_??? */"
@@ -422,13 +434,35 @@ static struct bpf_attr_check BPF_MAP_CRE
 		       ", value_size=0"
 		       ", max_entries=0"
 		       ", map_flags=0"
-		       ", inner_map_fd=0"
+		       ", inner_map_fd=0" FD0_PATH
 		       ", map_name=\"\""
 		       ", map_ifindex=0"
 		       ", btf_fd=-1159983635"
 		       ", btf_key_type_id=4207869677"
 		       ", btf_value_type_id=3405705229"
 	},
+	{ /* 9 */
+		.data = { .BPF_MAP_CREATE_data = {
+			.btf_fd = 0xbadc0ded,
+			.btf_key_type_id = 0xfacefeed,
+			.btf_value_type_id = 0xcafef00d,
+			.btf_vmlinux_value_type_id = 0xdeadc0de,
+		} },
+		.size = offsetofend(struct BPF_MAP_CREATE_struct,
+				    btf_vmlinux_value_type_id),
+		.str = "map_type=BPF_MAP_TYPE_UNSPEC"
+		       ", key_size=0"
+		       ", value_size=0"
+		       ", max_entries=0"
+		       ", map_flags=0"
+		       ", inner_map_fd=0" FD0_PATH
+		       ", map_name=\"\""
+		       ", map_ifindex=0"
+		       ", btf_fd=-1159983635"
+		       ", btf_key_type_id=4207869677"
+		       ", btf_value_type_id=3405705229"
+		       ", btf_vmlinux_value_type_id=3735929054"
+	},
 };
 
 static const struct bpf_attr_check BPF_MAP_LOOKUP_ELEM_checks[] = {
@@ -606,7 +640,7 @@ print_BPF_PROG_LOAD_attr4(const struct b
 	       license, IFINDEX_LO_STR);
 }
 
-static_assert(ARRAY_SIZE(bpf_prog_types_xdata) == 27,
+static_assert(ARRAY_SIZE(bpf_prog_types_xdata) == 31,
 	      "The prog_type for test 5 below needs to be updated");
 static struct bpf_attr_check BPF_PROG_LOAD_checks[] = {
 	{
@@ -617,7 +651,7 @@ static struct bpf_attr_check BPF_PROG_LO
 	},
 	{ /* 1 */
 		.data = { .BPF_PROG_LOAD_data = {
-			.prog_type = 27,
+			.prog_type = 31,
 			.insn_cnt = 0xbadc0ded,
 			.insns = 0,
 			.license = 0,
@@ -628,7 +662,7 @@ static struct bpf_attr_check BPF_PROG_LO
 			.prog_flags = 0,
 		} },
 		.size = offsetofend(struct BPF_PROG_LOAD_struct, prog_flags),
-		.str = "prog_type=0x1b /* BPF_PROG_TYPE_??? */"
+		.str = "prog_type=0x1f /* BPF_PROG_TYPE_??? */"
 		       ", insn_cnt=3134983661, insns=NULL, license=NULL"
 		       ", log_level=42, log_size=3141592653, log_buf=NULL"
 		       ", kern_version=KERNEL_VERSION(51966, 240, 13)"
@@ -691,7 +725,7 @@ static struct bpf_attr_check BPF_PROG_LO
 	},
 	{ /* 5 */
 		.data = { .BPF_PROG_LOAD_data = {
-			.prog_type = 26,
+			.prog_type = 30,
 			.insn_cnt = 0xbadc0ded,
 			.insns = 0xffffffff00000000,
 			.license = 0xffffffff00000000,
@@ -703,7 +737,7 @@ static struct bpf_attr_check BPF_PROG_LO
 			.prog_name = "fedcba987654321",
 		} },
 		.size = offsetofend(struct BPF_PROG_LOAD_struct, prog_name),
-		.str = "prog_type=BPF_PROG_TYPE_TRACING"
+		.str = "prog_type=BPF_PROG_TYPE_SK_LOOKUP"
 		       ", insn_cnt=3134983661"
 		       ", insns=" BIG_ADDR("0xffffffff00000000", "NULL")
 		       ", license=" BIG_ADDR("0xffffffff00000000", "NULL")
@@ -764,7 +798,7 @@ static struct bpf_attr_check BPF_OBJ_PIN
 	{
 		.data = { .BPF_OBJ_PIN_data = { .pathname = 0 } },
 		.size = offsetofend(struct BPF_OBJ_PIN_struct, pathname),
-		.str = "pathname=NULL, bpf_fd=0"
+		.str = "pathname=NULL, bpf_fd=0" FD0_PATH
 	},
 	{
 		.data = { .BPF_OBJ_PIN_data = {
@@ -772,7 +806,7 @@ static struct bpf_attr_check BPF_OBJ_PIN
 		} },
 		.size = offsetofend(struct BPF_OBJ_PIN_struct, pathname),
 		.str = "pathname=" BIG_ADDR("0xffffffffffffffff", "0xffffffff")
-		       ", bpf_fd=0",
+		       ", bpf_fd=0" FD0_PATH,
 	},
 	{
 		.data = { .BPF_OBJ_PIN_data = { .bpf_fd = -1 } },
@@ -798,7 +832,7 @@ static const struct bpf_attr_check BPF_P
 	{
 		.data = { .BPF_PROG_ATTACH_data = { .target_fd = -1 } },
 		.size = offsetofend(struct BPF_PROG_ATTACH_struct, target_fd),
-		.str = "target_fd=-1, attach_bpf_fd=0"
+		.str = "target_fd=-1, attach_bpf_fd=0" FD0_PATH
 		       ", attach_type=BPF_CGROUP_INET_INGRESS, attach_flags=0"
 	},
 	{
@@ -806,13 +840,28 @@ static const struct bpf_attr_check BPF_P
 			.target_fd = -1,
 			.attach_bpf_fd = -2,
 			.attach_type = 2,
-			.attach_flags = 1
+			.attach_flags = 7
 		} },
 		.size = offsetofend(struct BPF_PROG_ATTACH_struct, attach_flags),
 		.str = "target_fd=-1, attach_bpf_fd=-2"
 		       ", attach_type=BPF_CGROUP_INET_SOCK_CREATE"
-		       ", attach_flags=BPF_F_ALLOW_OVERRIDE"
-	}
+		       ", attach_flags=BPF_F_ALLOW_OVERRIDE|BPF_F_ALLOW_MULTI"
+				       "|BPF_F_REPLACE"
+	},
+	{
+		.data = { .BPF_PROG_ATTACH_data = {
+			.target_fd = -1,
+			.attach_bpf_fd = -2,
+			.attach_type = 2,
+			.attach_flags = 0xf8,
+			.replace_bpf_fd = -3,
+		} },
+		.size = offsetofend(struct BPF_PROG_ATTACH_struct, replace_bpf_fd),
+		.str = "target_fd=-1, attach_bpf_fd=-2"
+		       ", attach_type=BPF_CGROUP_INET_SOCK_CREATE"
+		       ", attach_flags=0xf8 /* BPF_F_??? */"
+		       ", replace_bpf_fd=-3"
+	},
 };
 
 
@@ -1028,8 +1077,8 @@ print_BPF_PROG_QUERY_attr4(const struct
 	printf("query={target_fd=-1153374643"
 	       ", attach_type=0xfeedface /* BPF_??? */"
 	       ", query_flags=BPF_F_QUERY_EFFECTIVE|0xdeadf00c"
-	       ", attach_flags=BPF_F_ALLOW_MULTI|0xbeefcafc"
-#if defined(INJECT_RETVAL) && INJECT_RETVAL > 0
+	       ", attach_flags=BPF_F_ALLOW_MULTI|BPF_F_REPLACE|0xbeefcaf8"
+#if defined(INJECT_RETVAL)
 	       ", prog_ids=[0, 1, 4294967295, 2718281828], prog_cnt=4}"
 #else
 	       ", prog_ids=%p, prog_cnt=4}", prog_load_ids_ptr
@@ -1056,8 +1105,8 @@ print_BPF_PROG_QUERY_attr5(const struct
 	printf("query={target_fd=-1153374643"
 	       ", attach_type=0xfeedface /* BPF_??? */"
 	       ", query_flags=BPF_F_QUERY_EFFECTIVE|0xdeadf00c"
-	       ", attach_flags=BPF_F_ALLOW_MULTI|0xbeefcafc"
-#if defined(INJECT_RETVAL) && INJECT_RETVAL > 0
+	       ", attach_flags=BPF_F_ALLOW_MULTI|BPF_F_REPLACE|0xbeefcaf8"
+#if defined(INJECT_RETVAL)
 	       ", prog_ids=[0, 1, 4294967295, 2718281828, ... /* %p */]"
 	       ", prog_cnt=5}",
 	       prog_load_ids_ptr + ARRAY_SIZE(prog_load_ids)
@@ -1078,13 +1127,13 @@ static struct bpf_attr_check BPF_PROG_QU
 	{ /* 1 */
 		.data = { .BPF_PROG_QUERY_data = {
 			.target_fd = 3141592653U,
-			.attach_type = 16,
+			.attach_type = 37,
 			.query_flags = 1,
 			.attach_flags = 3,
 		} },
 		.size = offsetofend(struct BPF_PROG_QUERY_struct, attach_flags),
 		.str = "query={target_fd=-1153374643"
-		       ", attach_type=BPF_LIRC_MODE2"
+		       ", attach_type=BPF_XDP"
 		       ", query_flags=BPF_F_QUERY_EFFECTIVE"
 		       ", attach_flags=BPF_F_ALLOW_OVERRIDE|BPF_F_ALLOW_MULTI"
 		       ", prog_ids=NULL, prog_cnt=0}",
@@ -1092,17 +1141,17 @@ static struct bpf_attr_check BPF_PROG_QU
 	{ /* 2 */
 		.data = { .BPF_PROG_QUERY_data = {
 			.target_fd = 3141592653U,
-			.attach_type = 26,
+			.attach_type = 38,
 			.query_flags = 0xfffffffe,
-			.attach_flags = 0xfffffffc,
+			.attach_flags = 0xfffffff8,
 			.prog_ids = 0xffffffffffffffffULL,
 			.prog_cnt = 2718281828,
 		} },
 		.size = offsetofend(struct BPF_PROG_QUERY_struct, prog_cnt),
 		.str = "query={target_fd=-1153374643"
-		       ", attach_type=0x1a /* BPF_??? */"
+		       ", attach_type=0x26 /* BPF_??? */"
 		       ", query_flags=0xfffffffe /* BPF_F_QUERY_??? */"
-		       ", attach_flags=0xfffffffc /* BPF_F_??? */"
+		       ", attach_flags=0xfffffff8 /* BPF_F_??? */"
 		       ", prog_ids="
 		       BIG_ADDR("0xffffffffffffffff", "0xffffffff")
 		       ", prog_cnt=2718281828}",
@@ -1120,7 +1169,7 @@ static struct bpf_attr_check BPF_PROG_QU
 		.str = "query={target_fd=-1153374643"
 		       ", attach_type=0xfeedface /* BPF_??? */"
 		       ", query_flags=BPF_F_QUERY_EFFECTIVE|0xdeadf00c"
-		       ", attach_flags=BPF_F_ALLOW_MULTI|0xbeefcafc"
+		       ", attach_flags=BPF_F_ALLOW_MULTI|BPF_F_REPLACE|0xbeefcaf8"
 		       ", prog_ids=" BIG_ADDR_MAYBE("0xffffffffffffffff") "[]"
 		       ", prog_cnt=0}",
 	},
@@ -1166,7 +1215,7 @@ static struct bpf_attr_check BPF_RAW_TRA
 		.data = { .BPF_RAW_TRACEPOINT_OPEN_data = { .name = 0 } },
 		.size = offsetofend(struct BPF_RAW_TRACEPOINT_OPEN_struct,
 				    name),
-		.str = "raw_tracepoint={name=NULL, prog_fd=0}",
+		.str = "raw_tracepoint={name=NULL, prog_fd=0" FD0_PATH "}",
 	},
 	{ /* 1 */
 		.data = { .BPF_RAW_TRACEPOINT_OPEN_data = {
@@ -1240,16 +1289,16 @@ static const struct bpf_attr_check BPF_B
 
 static const struct bpf_attr_check BPF_TASK_FD_QUERY_checks[] = {
 	{
-		.data = { .BPF_TASK_FD_QUERY_data = { .pid = 0xdeadbeef } },
+		.data = { .BPF_TASK_FD_QUERY_data = { .pid = 1735928559 } },
 		.size = offsetofend(struct BPF_TASK_FD_QUERY_struct, pid),
-		.str = "task_fd_query={pid=3735928559, fd=0, flags=0"
-		       ", buf_len=0, buf=NULL, prog_id=0"
+		.str = "task_fd_query={pid=1735928559, fd=0" FD0_PATH
+		       ", flags=0, buf_len=0, buf=NULL, prog_id=0"
 		       ", fd_type=BPF_FD_TYPE_RAW_TRACEPOINT"
 		       ", probe_offset=0, probe_addr=0}"
 	},
 	{ /* 1 */
 		.data = { .BPF_TASK_FD_QUERY_data = {
-			.pid = 0xcafef00d,
+			.pid = 1405705229,
 			.fd = 0xdeadbeef,
 			.flags = 0xfacefeed,
 			.buf_len = 0xdefaced,
@@ -1260,7 +1309,7 @@ static const struct bpf_attr_check BPF_T
 			.probe_addr = 0xfac5fed5fac7fed8
 		} },
 		.size = offsetofend(struct BPF_TASK_FD_QUERY_struct, probe_addr),
-		.str = "task_fd_query={pid=3405705229"
+		.str = "task_fd_query={pid=1405705229"
 		       ", fd=-559038737"
 		       ", flags=4207869677"
 		       ", buf_len=233811181"
@@ -1272,6 +1321,117 @@ static const struct bpf_attr_check BPF_T
 	}
 };
 
+static const struct bpf_attr_check BPF_MAP_LOOKUP_BATCH_checks[] = {
+	{
+		.data = { .BPF_MAP_LOOKUP_BATCH_data = { .map_fd = -1 } },
+		.size = offsetofend(struct BPF_MAP_LOOKUP_BATCH_struct, map_fd ),
+		.str = "batch={in_batch=NULL, out_batch=NULL, keys=NULL"
+		       ", values=NULL, count=0, map_fd=-1, elem_flags=BPF_ANY"
+		       ", flags=0}"
+	},
+	{
+		.data = { .BPF_MAP_LOOKUP_BATCH_data = {
+			.in_batch = 0xfacefeed,
+			.out_batch = 0xbadc0ded,
+			.keys = 0xdeadf00d,
+			.values = 0xfffffffe,
+			.count = 3,
+			.map_fd = -1,
+			.elem_flags = 4,
+			.flags = 4
+		} },
+		.size = offsetofend(struct BPF_MAP_LOOKUP_BATCH_struct, flags),
+		.str = "batch={in_batch=0xfacefeed, out_batch=0xbadc0ded"
+		       ", keys=0xdeadf00d, values=0xfffffffe, count=3"
+		       ", map_fd=-1, elem_flags=BPF_F_LOCK, flags=0x4}"
+	}
+};
+
+static const struct bpf_attr_check BPF_MAP_UPDATE_BATCH_checks[] = {
+	{
+		.data = { .BPF_MAP_UPDATE_BATCH_data = { .map_fd = -1 } },
+		.size = offsetofend(struct BPF_MAP_UPDATE_BATCH_struct, map_fd ),
+		.str = "batch={keys=NULL, values=NULL, count=0, map_fd=-1"
+		       ", elem_flags=BPF_ANY, flags=0}"
+	},
+	{
+		.data = { .BPF_MAP_UPDATE_BATCH_data = {
+			.keys = 0xdeadf00d,
+			.values = 0xfffffffe,
+			.count = 3,
+			.map_fd = -1,
+			.elem_flags = 4,
+			.flags = 4
+		} },
+		.size = offsetofend(struct BPF_MAP_UPDATE_BATCH_struct, flags),
+		.str = "batch={keys=0xdeadf00d, values=0xfffffffe, count=3"
+		       ", map_fd=-1, elem_flags=BPF_F_LOCK, flags=0x4}"
+	}
+};
+
+static const struct bpf_attr_check BPF_MAP_DELETE_BATCH_checks[] = {
+	{
+		.data = { .BPF_MAP_DELETE_BATCH_data = { .map_fd = -1 } },
+		.size = offsetofend(struct BPF_MAP_DELETE_BATCH_struct, map_fd ),
+		.str = "batch={keys=NULL, count=0, map_fd=-1"
+		       ", elem_flags=BPF_ANY, flags=0}"
+	},
+	{
+		.data = { .BPF_MAP_DELETE_BATCH_data = {
+			.keys = 0xdeadf00d,
+			.count = 3,
+			.map_fd = -1,
+			.elem_flags = 4,
+			.flags = 4
+		} },
+		.size = offsetofend(struct BPF_MAP_DELETE_BATCH_struct, flags),
+		.str = "batch={keys=0xdeadf00d, count=3, map_fd=-1"
+		       ", elem_flags=BPF_F_LOCK, flags=0x4}"
+	}
+};
+
+static const struct bpf_attr_check BPF_LINK_CREATE_checks[] = {
+	{
+		.data = { .BPF_LINK_CREATE_data = { .prog_fd = -1, .target_fd = -2 } },
+		.size = offsetofend(struct BPF_LINK_CREATE_struct, flags),
+		.str = "link_create={prog_fd=-1, target_fd=-2"
+		       ", attach_type=BPF_CGROUP_INET_INGRESS, flags=0}"
+	},
+	{
+		.data = { .BPF_LINK_CREATE_data = {
+			.prog_fd = -1,
+			.target_fd = 0xdeadbeef,
+			.attach_type = 5,
+			.flags = 4
+		} },
+		.size = offsetofend(struct BPF_LINK_CREATE_struct, flags),
+		.str = "link_create={prog_fd=-1, target_fd=-559038737"
+		       ", attach_type=BPF_SK_SKB_STREAM_VERDICT, flags=0x4}"
+	}
+};
+
+static const struct bpf_attr_check BPF_LINK_UPDATE_checks[] = {
+	{
+		.data = { .BPF_LINK_UPDATE_data = {
+			.link_fd = -1,
+			.new_prog_fd = -2
+		} },
+		.size = offsetofend(struct BPF_LINK_UPDATE_struct, old_prog_fd),
+		.str = "link_update={link_fd=-1, new_prog_fd=-2, flags=0}"
+	},
+	{
+		.data = { .BPF_LINK_UPDATE_data = {
+			.link_fd = -1,
+			.new_prog_fd = 0xdeadbeef,
+			.flags = 4,
+			.old_prog_fd = 0xdeadf00d
+		} },
+		.size = offsetofend(struct BPF_LINK_UPDATE_struct, old_prog_fd),
+		.str = "link_update={link_fd=-1, new_prog_fd=-559038737"
+		       ", flags=BPF_F_REPLACE, old_prog_fd=-559026163}"
+	}
+};
+
 
 #define CHK(cmd_) \
 	{ \
@@ -1308,6 +1468,11 @@ main(void)
 		CHK(BPF_MAP_LOOKUP_AND_DELETE_ELEM),
 		CHK(BPF_MAP_FREEZE),
 		CHK(BPF_BTF_GET_NEXT_ID),
+		CHK(BPF_MAP_LOOKUP_BATCH),
+		CHK(BPF_MAP_UPDATE_BATCH),
+		CHK(BPF_MAP_DELETE_BATCH),
+		CHK(BPF_LINK_CREATE),
+		CHK(BPF_LINK_UPDATE),
 	};
 
 	page_size = get_page_size();
diff -pruN 5.5-3/tests/bpf-obj_get_info_by_fd.c 5.9-0ubuntu2/tests/bpf-obj_get_info_by_fd.c
--- 5.5-3/tests/bpf-obj_get_info_by_fd.c	2019-12-11 22:44:53.000000000 +0000
+++ 5.9-0ubuntu2/tests/bpf-obj_get_info_by_fd.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check bpf(BPF_OBJ_GET_INFO_BY_FD) decoding.
  *
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -87,6 +87,10 @@ print_map_create(void *attr_void, size_t
 		printf(", btf_fd=0</dev/null>"
 		       ", btf_key_type_id=0, btf_value_type_id=0");
 	}
+	if (size > offsetof(struct BPF_MAP_CREATE_struct,
+			    btf_vmlinux_value_type_id)) {
+		printf(", btf_vmlinux_value_type_id=0");
+	}
 	printf("}, %zu) = ", size);
 	if (rc >= 0)
 		printf("%ld<anon_inode:bpf-map>\n", rc);
@@ -353,6 +357,10 @@ main(int ac, char **av)
 	    offsetof(struct bpf_map_info_struct, ifindex))
 		printf(", ifindex=%u", map_info->ifindex);
 	if (bpf_map_get_info_attr.info_len >
+	    offsetof(struct bpf_map_info_struct, btf_vmlinux_value_type_id))
+		printf(", btf_vmlinux_value_type_id=%u",
+		       map_info->btf_vmlinux_value_type_id);
+	if (bpf_map_get_info_attr.info_len >
 	    offsetof(struct bpf_map_info_struct, netns_dev))
 		printf(", netns_dev=makedev(%#x, %#x)",
 		       major(map_info->netns_dev), minor(map_info->netns_dev));
diff -pruN 5.5-3/tests/bpf-success-long-y.c 5.9-0ubuntu2/tests/bpf-success-long-y.c
--- 5.5-3/tests/bpf-success-long-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/bpf-success-long-y.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,3 @@
+#define INJECT_RETVAL ((long) 0xbadc0de1e55beefULL)
+#define FD0_PATH "</dev/full>"
+#include "bpf.c"
diff -pruN 5.5-3/tests/bpf-success-long-y.test 5.9-0ubuntu2/tests/bpf-success-long-y.test
--- 5.5-3/tests/bpf-success-long-y.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/bpf-success-long-y.test	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,16 @@
+:#!/bin/sh -efu
+#
+# Copyright (c) 2018-2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: GPL-2.0-or-later
+
+. "${srcdir=.}/scno_tampering.sh"
+
+case "$SIZEOF_LONG" in
+	4) rval=508935919;;
+	8) rval=841540765612359407;;
+esac
+
+run_strace -a20 -y -e trace=bpf -e inject=bpf:retval="${rval}" ../bpf-success-long-y < /dev/full > "$EXP"
+match_diff "$LOG" "$EXP"
diff -pruN 5.5-3/tests/btrfs.c 5.9-0ubuntu2/tests/btrfs.c
--- 5.5-3/tests/btrfs.c	2019-07-24 17:12:18.000000000 +0000
+++ 5.9-0ubuntu2/tests/btrfs.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -815,7 +815,7 @@ btrfs_test_clone_ioctls(void)
 		args.dest_offset);
 }
 
-# define BTRFS_COMPRESS_TYPES 2
+# define BTRFS_COMPRESS_TYPES 3
 # define BTRFS_INVALID_COMPRESS (BTRFS_COMPRESS_TYPES + 1)
 
 static void
diff -pruN 5.5-3/tests/caps-abbrev.awk 5.9-0ubuntu2/tests/caps-abbrev.awk
--- 5.5-3/tests/caps-abbrev.awk	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/caps-abbrev.awk	2020-09-06 08:00:00.000000000 +0000
@@ -3,12 +3,13 @@
 # This file is part of caps strace test.
 #
 # Copyright (c) 2014-2018 Dmitry V. Levin <ldv@altlinux.org>
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 BEGIN {
-	cap = "(0|1<<CAP_[A-Z_]+(\\|1<<CAP_[A-Z_]+)*|1<<CAP_[A-Z_]+(\\|1<<CAP_[A-Z_]+){37}\\|0xffffffc0)"
+	cap = "(0|1<<CAP_[A-Z_]+(\\|1<<CAP_[A-Z_]+)*|1<<CAP_[A-Z_]+(\\|1<<CAP_[A-Z_]+){40}\\|0xfffffe00)"
 	s_efault = "-1 EFAULT (Bad address)"
 	r_efault = "-1 EFAULT \\(Bad address\\)"
 	r_einval = "-1 EINVAL \\(Invalid argument\\)"
diff -pruN 5.5-3/tests/caps.awk 5.9-0ubuntu2/tests/caps.awk
--- 5.5-3/tests/caps.awk	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/caps.awk	2020-09-06 08:00:00.000000000 +0000
@@ -2,13 +2,13 @@
 #
 # This file is part of caps strace test.
 #
-# Copyright (c) 2014-2018 Dmitry V. Levin <ldv@altlinux.org>
+# Copyright (c) 2014-2020 Dmitry V. Levin <ldv@altlinux.org>
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 BEGIN {
-	cap = "(0|1<<CAP_[A-Z_]+(\\|1<<CAP_[A-Z_]+)*|1<<CAP_[A-Z_]+(\\|1<<CAP_[A-Z_]+){37}\\|0xffffffc0)"
+	cap = "(0|1<<CAP_[A-Z_]+(\\|1<<CAP_[A-Z_]+)*|1<<CAP_[A-Z_]+(\\|1<<CAP_[A-Z_]+){40}\\|0xfffffe00)"
 	s_efault = "-1 EFAULT (Bad address)"
 	r_efault = "-1 EFAULT \\(Bad address\\)"
 	r_einval = "-1 EINVAL \\(Invalid argument\\)"
diff -pruN 5.5-3/tests/clock_nanosleep.c 5.9-0ubuntu2/tests/clock_nanosleep.c
--- 5.5-3/tests/clock_nanosleep.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/clock_nanosleep.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,22 +2,25 @@
  * Check decoding of clock_nanosleep and clock_gettime syscalls.
  *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-#include <assert.h>
-#include <stdio.h>
-#include <stdint.h>
-#include <signal.h>
-#include <time.h>
-#include <unistd.h>
-#include <sys/time.h>
 #include "scno.h"
 
+#ifdef __NR_clock_nanosleep
+
+# include <assert.h>
+# include <stdio.h>
+# include <stdint.h>
+# include <signal.h>
+# include <time.h>
+# include <unistd.h>
+# include <sys/time.h>
+
 static void
 handler(int signo)
 {
@@ -127,3 +130,9 @@ main(void)
 	puts("+++ exited with 0 +++");
 	return 0;
 }
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_clock_nanosleep")
+
+#endif
diff -pruN 5.5-3/tests/clone3.c 5.9-0ubuntu2/tests/clone3.c
--- 5.5-3/tests/clone3.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests/clone3.c	2020-06-07 08:00:00.000000000 +0000
@@ -50,9 +50,10 @@ struct test_clone_args {
 	uint64_t tls;
 	uint64_t set_tid;
 	uint64_t set_tid_size;
+	uint64_t cgroup;
 };
 
-#ifdef HAVE_STRUCT_CLONE_ARGS_SET_TID_SIZE
+#ifdef HAVE_STRUCT_CLONE_ARGS_CGROUP
 typedef struct clone_args struct_clone_args;
 #else
 typedef struct test_clone_args struct_clone_args;
@@ -66,18 +67,14 @@ enum validity_flag_bits {
 	TLS_VALID_BIT,
 };
 
-#define _(x_) x_ = 1 << x_##_BIT
-
 enum validity_flags {
-	_(STRUCT_VALID),
-	_(PIDFD_VALID),
-	_(CHILD_TID_VALID),
-	_(PARENT_TID_VALID),
-	_(TLS_VALID),
+	FLAG(STRUCT_VALID),
+	FLAG(PIDFD_VALID),
+	FLAG(CHILD_TID_VALID),
+	FLAG(PARENT_TID_VALID),
+	FLAG(TLS_VALID),
 };
 
-#undef _
-
 #define MAX_SET_TID_SIZE 32
 
 static const int child_exit_status = 42;
@@ -267,6 +264,10 @@ print_clone3(struct_clone_args *const ar
 	    (arg->set_tid || arg->set_tid_size))
 		print_set_tid(arg->set_tid, arg->set_tid_size);
 
+	if (sz > offsetof(struct_clone_args, cgroup) &&
+	    (arg->cgroup || arg->flags & CLONE_INTO_CGROUP))
+		printf(", cgroup=%" PRIu64, (uint64_t) arg->cgroup);
+
 	printf("}");
 
 	if (rc < 0)
@@ -405,6 +406,19 @@ main(int argc, char *argv[])
 	printf(", %zu) = %s" INJ_STR, sizeof(*arg), sprintrc(rc));
 	memset(arg, 0, sizeof(*arg));
 
+	arg->cgroup = 0xfacefeedbadc0ded;
+	rc = do_clone3(arg, sizeof(*arg), ERR(0) | ERR(E2BIG));
+	print_clone3(arg, rc, sizeof(*arg), STRUCT_VALID, "0", "0");
+	printf(", %zu) = %s" INJ_STR, sizeof(*arg), sprintrc(rc));
+	memset(arg, 0, sizeof(*arg));
+
+	arg->flags = CLONE_INTO_CGROUP;
+	rc = do_clone3(arg, sizeof(*arg), ERR(0) | ERR(EINVAL) | ERR(EBADF));
+	print_clone3(arg, rc, sizeof(*arg), STRUCT_VALID,
+		     "CLONE_INTO_CGROUP", "0");
+	printf(", %zu) = %s" INJ_STR, sizeof(*arg), sprintrc(rc));
+	memset(arg, 0, sizeof(*arg));
+
 	/*
 	 * NB: the following check is purposefully fragile (it will break
 	 *     when system's struct clone_args has additional fields,
@@ -446,18 +460,20 @@ main(int argc, char *argv[])
 	       ", %zu) = %s" INJ_STR,
 	       sizeof(*arg) + 16, sprintrc(rc));
 
-	arg->flags = 0xfacefeedbeefc0de;
+	arg->flags = 0xface3eefbeefc0de;
 	arg->exit_signal = 0x1e55c0de;
 	rc = do_clone3(arg, 64, ERR(EINVAL));
 	printf("clone3({flags=%s, child_tid=NULL, exit_signal=508936414"
 	       ", stack=NULL, stack_size=0, tls=NULL}, 64) = %s" INJ_STR,
-	       XLAT_KNOWN(0xfacefeedbeefc0de, "CLONE_VFORK|CLONE_PARENT"
+	       XLAT_KNOWN(0xface3eefbeefc0de, "CLONE_VFORK|CLONE_PARENT"
 	       "|CLONE_THREAD|CLONE_NEWNS|CLONE_SYSVSEM|CLONE_SETTLS"
 	       "|CLONE_CHILD_CLEARTID|CLONE_UNTRACED|CLONE_NEWCGROUP"
 	       "|CLONE_NEWUTS|CLONE_NEWIPC|CLONE_NEWUSER|CLONE_NEWPID|CLONE_IO"
-	       "|CLONE_CLEAR_SIGHAND|0xfacefeec004000de"), sprintrc(rc));
+	       "|CLONE_NEWTIME|CLONE_CLEAR_SIGHAND|CLONE_INTO_CGROUP"
+	       "|0xface3eec0040005e"),
+	       sprintrc(rc));
 
-	arg->flags = 0xdec0deac004000ffULL;
+	arg->flags = 0xdec0deac0040007fULL;
 	arg->exit_signal = 250;
 	arg->stack = 0xface1e55beeff00dULL;
 	arg->stack_size = 0xcaffeedefacedca7ULL;
@@ -465,7 +481,7 @@ main(int argc, char *argv[])
 	printf("clone3({flags=%s, exit_signal=250"
 	       ", stack=0xface1e55beeff00d, stack_size=0xcaffeedefacedca7}, 64)"
 	       " = %s" INJ_STR,
-	       XLAT_UNKNOWN(0xdec0deac004000ff, "CLONE_???"),
+	       XLAT_UNKNOWN(0xdec0deac0040007f, "CLONE_???"),
 	       sprintrc(rc));
 
 	arg->exit_signal = SIGCHLD;
diff -pruN 5.5-3/tests/clone-flags.test 5.9-0ubuntu2/tests/clone-flags.test
--- 5.5-3/tests/clone-flags.test	2019-06-20 09:49:27.000000000 +0000
+++ 5.9-0ubuntu2/tests/clone-flags.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
 #
 # Check decoding of clone flags.
 #
-# Copyright (c) 2019 The strace developers.
+# Copyright (c) 2019-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -15,10 +15,10 @@ case "$STRACE_ARCH" in
 esac
 
 # Find out the expected and reported child stack addresses.
-run_strace_match_grep -qq -e signal=none -e trace=$syscall
+run_strace_match_grep --silence=exits -e signal=none -e trace=$syscall
 CHILD_STACK_EXPECTED="$(sed -n 's/^clone[^(]*(child_stack=(\(0x[[:xdigit:]]\+\)|.*/\1/p' "$EXP")000"
 CHILD_STACK_REPORTED="$(sed -n 's/^clone[^(]*(child_stack=\(0x[[:xdigit:]]\+\),.*/\1/p' "$LOG")"
 export CHILD_STACK_EXPECTED CHILD_STACK_REPORTED
 
 # Use child stack addresses to check decoding.
-run_strace_match_diff -a35 -qq -y -e signal=none -e trace=$syscall
+run_strace_match_diff -a35 --silence=exits,personality -y -e signal=none -e trace=$syscall
diff -pruN 5.5-3/tests/clone_parent.c 5.9-0ubuntu2/tests/clone_parent.c
--- 5.5-3/tests/clone_parent.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests/clone_parent.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check handling of CLONE_PARENT'ed processes.
  *
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -17,6 +17,10 @@
 #include <sys/wait.h>
 #include <unistd.h>
 
+#ifndef QUIET_MSG
+# define QUIET_MSG 0
+#endif
+
 static int
 child(void *const arg)
 {
@@ -56,10 +60,14 @@ main(void)
 	FILE *const fp = fdopen(3, "a");
 	if (!fp)
 		perror_msg_and_fail("fdopen");
+#if !QUIET_MSG
 	if (fprintf(fp, "%s: Exit of unknown pid %d ignored\n",
 		    getenv("STRACE_EXE") ?: "strace", pid) < 0)
 		perror_msg_and_fail("fprintf");
+#endif
 
+#if !QUIET_MSG
 	puts("+++ exited with 0 +++");
+#endif
 	return 0;
 }
diff -pruN 5.5-3/tests/clone_parent.gen.test 5.9-0ubuntu2/tests/clone_parent.gen.test
--- 5.5-3/tests/clone_parent.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/clone_parent.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (clone_parent +clone_ptrace.test ); do not edit.
+set -- 
+. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests/clone_parent-q.c 5.9-0ubuntu2/tests/clone_parent-q.c
--- 5.5-3/tests/clone_parent-q.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/clone_parent-q.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define QUIET_MSG 0
+#include "clone_parent.c"
diff -pruN 5.5-3/tests/clone_parent-q.gen.test 5.9-0ubuntu2/tests/clone_parent-q.gen.test
--- 5.5-3/tests/clone_parent-q.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/clone_parent-q.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (clone_parent-q +clone_ptrace.test -q); do not edit.
+set -- -q
+. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests/clone_parent-qq.c 5.9-0ubuntu2/tests/clone_parent-qq.c
--- 5.5-3/tests/clone_parent-qq.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/clone_parent-qq.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define QUIET_MSG 1
+#include "clone_parent.c"
diff -pruN 5.5-3/tests/clone_parent-qq.gen.test 5.9-0ubuntu2/tests/clone_parent-qq.gen.test
--- 5.5-3/tests/clone_parent-qq.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/clone_parent-qq.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (clone_parent-qq +clone_ptrace.test -qq); do not edit.
+set -- -qq
+. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests/clone_parent--quiet-exit.c 5.9-0ubuntu2/tests/clone_parent--quiet-exit.c
--- 5.5-3/tests/clone_parent--quiet-exit.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/clone_parent--quiet-exit.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define QUIET_MSG 1
+#include "clone_parent.c"
diff -pruN 5.5-3/tests/clone_parent--quiet-exit.gen.test 5.9-0ubuntu2/tests/clone_parent--quiet-exit.gen.test
--- 5.5-3/tests/clone_parent--quiet-exit.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/clone_parent--quiet-exit.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (clone_parent--quiet-exit +clone_ptrace.test --quiet=exit,personality); do not edit.
+set -- --quiet=exit,personality
+. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests/clone_parent.test 5.9-0ubuntu2/tests/clone_parent.test
--- 5.5-3/tests/clone_parent.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/clone_parent.test	1970-01-01 00:00:00.000000000 +0000
@@ -1,10 +0,0 @@
-#!/bin/sh -efu
-#
-# Check handling of CLONE_PARENT'ed processes.
-#
-# Copyright (c) 2017-2018 The strace developers.
-# All rights reserved.
-#
-# SPDX-License-Identifier: GPL-2.0-or-later
-
-. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests/clone_ptrace.c 5.9-0ubuntu2/tests/clone_ptrace.c
--- 5.5-3/tests/clone_ptrace.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests/clone_ptrace.c	2020-07-17 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check handling of CLONE_PTRACE'ed processes.
  *
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -20,6 +20,13 @@
 
 static siginfo_t sinfo;
 
+#ifndef QUIET_ATTACH
+# define QUIET_ATTACH 0
+#endif
+#ifndef QUIET_EXIT
+# define QUIET_EXIT 0
+#endif
+
 static void
 handler(const int no, siginfo_t *const si, void *const uc)
 {
@@ -74,9 +81,11 @@ main(void)
 	FILE *const fp = fdopen(3, "a");
 	if (!fp)
 		perror_msg_and_fail("fdopen");
+#if !QUIET_ATTACH
 	if (fprintf(fp, "%s: Detached unknown pid %d\n",
 		    getenv("STRACE_EXE") ?: "strace", pid) < 0)
 		perror_msg_and_fail("fprintf");
+#endif
 
 	int status;
 	while (wait(&status) != pid) {
@@ -87,8 +96,11 @@ main(void)
 		error_msg_and_fail("unexpected child exit status %d", status);
 
 	printf("--- SIGCHLD {si_signo=SIGCHLD, si_code=CLD_KILLED, si_pid=%d"
-	       ", si_uid=%u, si_status=%s, si_utime=%u, si_stime=%u} ---\n"
-	       "+++ exited with 0 +++\n", pid, geteuid(), "SIGUSR1",
+	       ", si_uid=%d, si_status=%s, si_utime=%u, si_stime=%u} ---\n"
+#if !QUIET_EXIT
+	       "+++ exited with 0 +++\n"
+#endif
+	       , pid, geteuid(), "SIGUSR1",
 	       (unsigned int) sinfo.si_utime, (unsigned int) sinfo.si_stime);
 
 	return 0;
diff -pruN 5.5-3/tests/clone_ptrace-q.c 5.9-0ubuntu2/tests/clone_ptrace-q.c
--- 5.5-3/tests/clone_ptrace-q.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/clone_ptrace-q.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define QUIET_ATTACH 1
+#include "clone_ptrace.c"
diff -pruN 5.5-3/tests/clone_ptrace-q.gen.test 5.9-0ubuntu2/tests/clone_ptrace-q.gen.test
--- 5.5-3/tests/clone_ptrace-q.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/clone_ptrace-q.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (clone_ptrace-q +clone_ptrace.test -q); do not edit.
+set -- -q
+. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests/clone_ptrace-qq.c 5.9-0ubuntu2/tests/clone_ptrace-qq.c
--- 5.5-3/tests/clone_ptrace-qq.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/clone_ptrace-qq.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,3 @@
+#define QUIET_ATTACH 1
+#define QUIET_EXIT 1
+#include "clone_ptrace.c"
diff -pruN 5.5-3/tests/clone_ptrace-qq.gen.test 5.9-0ubuntu2/tests/clone_ptrace-qq.gen.test
--- 5.5-3/tests/clone_ptrace-qq.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/clone_ptrace-qq.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (clone_ptrace-qq +clone_ptrace.test -qq); do not edit.
+set -- -qq
+. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests/clone_ptrace--quiet-attach.c 5.9-0ubuntu2/tests/clone_ptrace--quiet-attach.c
--- 5.5-3/tests/clone_ptrace--quiet-attach.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/clone_ptrace--quiet-attach.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define QUIET_ATTACH 1
+#include "clone_ptrace.c"
diff -pruN 5.5-3/tests/clone_ptrace--quiet-attach.gen.test 5.9-0ubuntu2/tests/clone_ptrace--quiet-attach.gen.test
--- 5.5-3/tests/clone_ptrace--quiet-attach.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/clone_ptrace--quiet-attach.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (clone_ptrace--quiet-attach +clone_ptrace.test --quiet=attach,personality); do not edit.
+set -- --quiet=attach,personality
+. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests/clone_ptrace--quiet-exit.c 5.9-0ubuntu2/tests/clone_ptrace--quiet-exit.c
--- 5.5-3/tests/clone_ptrace--quiet-exit.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/clone_ptrace--quiet-exit.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define QUIET_EXIT 1
+#include "clone_ptrace.c"
diff -pruN 5.5-3/tests/clone_ptrace--quiet-exit.gen.test 5.9-0ubuntu2/tests/clone_ptrace--quiet-exit.gen.test
--- 5.5-3/tests/clone_ptrace--quiet-exit.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/clone_ptrace--quiet-exit.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (clone_ptrace--quiet-exit +clone_ptrace.test --quiet=exit,personality); do not edit.
+set -- --quiet=exit,personality
+. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests/clone_ptrace.test 5.9-0ubuntu2/tests/clone_ptrace.test
--- 5.5-3/tests/clone_ptrace.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/clone_ptrace.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
 #
 # Check handling of CLONE_PTRACE'ed processes.
 #
-# Copyright (c) 2017-2018 The strace developers.
+# Copyright (c) 2017-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,7 +10,7 @@
 . "${srcdir=.}/init.sh"
 
 run_prog > /dev/null 3>&1
-args="-e trace=none $args"
+args="-e trace=none ${1:---quiet=personality} $args"
 > "$LOG" || fail_ "failed to write $LOG"
 
 $STRACE -o "$LOG" $args > "$EXP" 2> "$OUT"-err 3> "$EXP"-err || {
diff -pruN 5.5-3/tests/close_range.c 5.9-0ubuntu2/tests/close_range.c
--- 5.5-3/tests/close_range.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/close_range.c	2020-09-23 16:29:35.000000000 +0000
@@ -0,0 +1,147 @@
+/*
+ * Check decoding of close_range syscall.
+ *
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+
+#ifdef __NR_close_range
+
+# include <fcntl.h>
+# include <stdio.h>
+# include <unistd.h>
+
+# ifdef HAVE_LINUX_CLOSE_RANGE_H
+#  include <linux/close_range.h>
+# else
+#  define CLOSE_RANGE_UNSHARE	(1U << 1)
+# endif
+
+# ifndef FD0_PATH
+#  define FD0_PATH ""
+# endif
+# ifndef FD7_PATH
+#  define FD7_PATH ""
+# endif
+# ifndef SKIP_IF_PROC_IS_UNAVAILABLE
+#  define SKIP_IF_PROC_IS_UNAVAILABLE
+# endif
+
+static const char *errstr;
+
+static long
+k_close_range(const unsigned int fd1, const unsigned int fd2, const unsigned int flags)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+	const kernel_ulong_t arg1 = fill | fd1;
+	const kernel_ulong_t arg2 = fill | fd2;
+	const kernel_ulong_t arg3 = fill | flags;
+	const long rc = syscall(__NR_close_range, arg1, arg2, arg3, bad, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
+
+static void
+xdup2(int fd1, int fd2)
+{
+	if (dup2(fd1, fd2) != fd2)
+		perror_msg_and_fail("dup2(%d, %d)", fd1, fd2);
+}
+
+int
+main(void)
+{
+	SKIP_IF_PROC_IS_UNAVAILABLE;
+
+	const int fd0 = dup(0);
+	const int fd7 = dup(7);
+	const int fd7_min = MIN(7, fd7);
+	const int fd7_max = MAX(7, fd7);
+
+	k_close_range(-2, -1, 1);
+# ifndef PATH_TRACING
+	printf("close_range(-2, -1, 0x1 /* CLOSE_RANGE_??? */) = %s\n", errstr);
+# endif
+
+	k_close_range(-1, -2, 2);
+# ifndef PATH_TRACING
+	printf("close_range(-1, -2, CLOSE_RANGE_UNSHARE) = %s\n", errstr);
+# endif
+
+	k_close_range(-3, 0, 4);
+# ifndef PATH_TRACING
+	printf("close_range(-3, 0" FD0_PATH ", 0x4 /* CLOSE_RANGE_??? */)"
+	       " = %s\n", errstr);
+# endif
+
+	k_close_range(0, -4, -1);
+# ifndef PATH_TRACING
+	printf("close_range(0" FD0_PATH ", -4, CLOSE_RANGE_UNSHARE|%#x) = %s\n",
+	       (-1U & ~CLOSE_RANGE_UNSHARE), errstr);
+# endif
+
+	k_close_range(-5, 7, 0);
+	printf("close_range(-5, 7" FD7_PATH ", 0) = %s\n", errstr);
+
+	k_close_range(7, -6, 1);
+	printf("close_range(7" FD7_PATH ", -6, 0x1 /* CLOSE_RANGE_??? */)"
+	       " = %s\n", errstr);
+
+	k_close_range(7, 7, 4);
+	printf("close_range(7" FD7_PATH ", 7" FD7_PATH
+	       ", 0x4 /* CLOSE_RANGE_??? */) = %s\n", errstr);
+
+	k_close_range(-7, -7, 7);
+# ifndef PATH_TRACING
+	printf("close_range(-7, -7, CLOSE_RANGE_UNSHARE|0x5) = %s\n", errstr);
+# endif
+
+	k_close_range(7, 0, 0);
+	printf("close_range(7" FD7_PATH ", 0" FD0_PATH ", 0) = %s\n", errstr);
+
+	k_close_range(fd7, fd0, 0);
+	printf("close_range(%d" FD7_PATH ", %d" FD0_PATH ", 0) = %s\n",
+	       fd7, fd0, errstr);
+
+	if (k_close_range(0, 0, 0) == 0)
+		xdup2(fd0, 0);
+# ifndef PATH_TRACING
+	printf("close_range(0" FD0_PATH ", 0" FD0_PATH ", 0) = %s\n", errstr);
+# endif
+
+	if (k_close_range(fd0, fd0, 0) == 0)
+		xdup2(0, fd0);
+# ifndef PATH_TRACING
+	printf("close_range(%d" FD0_PATH ", %d" FD0_PATH ", 0) = %s\n",
+	       fd0, fd0, errstr);
+# endif
+
+	if (k_close_range(7, 7, 0) == 0)
+		xdup2(fd7, 7);
+	printf("close_range(7" FD7_PATH ", 7" FD7_PATH ", 0) = %s\n", errstr);
+
+	if (k_close_range(fd7, fd7, 0) == 0)
+		xdup2(7, fd7);
+	printf("close_range(%d" FD7_PATH ", %d" FD7_PATH ", 0) = %s\n",
+	       fd7, fd7, errstr);
+
+	if (k_close_range(fd7_max, -1, 0) == 0)
+		xdup2(fd7_min, fd7_max);
+	printf("close_range(%d" FD7_PATH ", -1, 0) = %s\n",
+	       fd7_max, errstr);
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_close_range")
+
+#endif
diff -pruN 5.5-3/tests/close_range.gen.test 5.9-0ubuntu2/tests/close_range.gen.test
--- 5.5-3/tests/close_range.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/close_range.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (close_range -a21 7>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a21 7>>/dev/full
diff -pruN 5.5-3/tests/close_range-P.c 5.9-0ubuntu2/tests/close_range-P.c
--- 5.5-3/tests/close_range-P.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/close_range-P.c	2020-09-06 08:00:00.000000000 +0000
@@ -0,0 +1,4 @@
+#define PATH_TRACING
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "close_range.c"
diff -pruN 5.5-3/tests/close_range-P.gen.test 5.9-0ubuntu2/tests/close_range-P.gen.test
--- 5.5-3/tests/close_range-P.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/close_range-P.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (close_range-P -a21 --trace=close_range -P /dev/full 7>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a21 --trace=close_range -P /dev/full 7>>/dev/full
diff -pruN 5.5-3/tests/close_range-y.c 5.9-0ubuntu2/tests/close_range-y.c
--- 5.5-3/tests/close_range-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/close_range-y.c	2020-09-06 08:00:00.000000000 +0000
@@ -0,0 +1,5 @@
+#define FD0_PATH "</dev/null>"
+#define FD7_PATH "</dev/full>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "close_range.c"
diff -pruN 5.5-3/tests/close_range-y.gen.test 5.9-0ubuntu2/tests/close_range-y.gen.test
--- 5.5-3/tests/close_range-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/close_range-y.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (close_range-y -a33 --trace=close_range -y 7>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a33 --trace=close_range -y 7>>/dev/full
diff -pruN 5.5-3/tests/close_range-yy.c 5.9-0ubuntu2/tests/close_range-yy.c
--- 5.5-3/tests/close_range-yy.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/close_range-yy.c	2020-09-06 08:00:00.000000000 +0000
@@ -0,0 +1,5 @@
+#define FD0_PATH "</dev/null<char 1:3>>"
+#define FD7_PATH "</dev/full<char 1:7>>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "close_range.c"
diff -pruN 5.5-3/tests/close_range-yy.gen.test 5.9-0ubuntu2/tests/close_range-yy.gen.test
--- 5.5-3/tests/close_range-yy.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/close_range-yy.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (close_range-yy -a33 --trace=close_range -yy 7>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a33 --trace=close_range -yy 7>>/dev/full
diff -pruN 5.5-3/tests/count-f.test 5.9-0ubuntu2/tests/count-f.test
--- 5.5-3/tests/count-f.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/count-f.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
 #
 # Check whether -c counts through forks and clones properly.
 #
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,7 +10,7 @@
 . "${srcdir=.}/init.sh"
 
 run_prog
-run_strace -q -f -c $args
+run_strace -e silent=attach -f -c $args
 match_grep
 
 exit 0
diff -pruN 5.5-3/tests/count.test 5.9-0ubuntu2/tests/count.test
--- 5.5-3/tests/count.test	2019-08-06 13:38:20.000000000 +0000
+++ 5.9-0ubuntu2/tests/count.test	2020-04-03 22:58:26.000000000 +0000
@@ -3,7 +3,7 @@
 # Check whether -c and -w options work.
 #
 # Copyright (c) 2014-2016 Dmitry V. Levin <ldv@altlinux.org>
-# Copyright (c) 2014-2018 The strace developers.
+# Copyright (c) 2014-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -36,6 +36,7 @@ HALFCLOCK=' *[^ ]+ +0\.[567][^n]*nanosle
 
 grep_log "$GENERIC"	-c
 grep_log "$GENERIC"	-c -O1
+grep_log "$GENERIC"	-c --summary-syscall-overhead=1
 grep_log "$GENERIC"	-c -enanosleep
 grep_log "$GENERIC"	-c -O1 -enanosleep
 grep_log "$WALLCLOCK"	-cw
@@ -43,7 +44,10 @@ grep_log "$WALLCLOCK"	-cw -O1
 grep_log "$WALLCLOCK1"	-cw -enanosleep
 grep_log "$WALLCLOCK1"	-cw -O1 -enanosleep
 grep_log "$HALFCLOCK"	-cw -O4.5e2ms -enanosleep
+grep_log "$HALFCLOCK"	-cw --summary-syscall-overhead=4.5e2ms -enanosleep
 grep_log "$HALFCLOCK"	-cw -O4.5e-1s -enanosleep
+grep_log "$HALFCLOCK"	-cw --summary-syscall-overhead=4.5e-1s -enanosleep
 grep_log "$HALFCLOCK"	-cw -O456789012ns -enanosleep
+grep_log "$HALFCLOCK"	-cw --summary-syscall-overhead=456789012ns -enanosleep
 
 exit 0
diff -pruN 5.5-3/tests/create_tmpfile.c 5.9-0ubuntu2/tests/create_tmpfile.c
--- 5.5-3/tests/create_tmpfile.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/create_tmpfile.c	2020-04-17 20:43:15.000000000 +0000
@@ -0,0 +1,46 @@
+/*
+ * Create a temporary file in the current directory.
+ *
+ * Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include <fcntl.h>
+#include <unistd.h>
+
+#ifndef O_TMPFILE
+# if defined __hppa__
+#  define O_TMPFILE	040000000
+# elif defined __alpha__
+#  define O_TMPFILE	0100000000
+# elif defined __sparc__
+#  define O_TMPFILE	0200000000
+# else
+#  define O_TMPFILE	020000000
+# endif
+#endif
+
+int
+create_tmpfile(unsigned int flags)
+{
+	int fd = open(".", O_TMPFILE | O_DIRECTORY | O_EXCL | flags, 0600);
+
+	if (fd < 0) {
+		/*
+		 * Since every test is executed in a separate directory,
+		 * there is no need to protect from race conditions.
+		 */
+		static const char fname[] = "create_tmpfile";
+
+		fd = open(fname, O_CREAT | O_EXCL | flags, 0600);
+		if (fd < 0)
+			perror_msg_and_fail("open: %s", fname);
+		if (unlink(fname))
+			perror_msg_and_fail("unlink: %s", fname);
+	}
+
+	return fd;
+}
diff -pruN 5.5-3/tests/delay.test 5.9-0ubuntu2/tests/delay.test
--- 5.5-3/tests/delay.test	2019-08-06 13:38:20.000000000 +0000
+++ 5.9-0ubuntu2/tests/delay.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
 #
 # Check delay injection.
 #
-# Copyright (c) 2018 The strace developers.
+# Copyright (c) 2018-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -12,7 +12,7 @@
 while read -r denter dexit denter_us dexit_us; do
 	[ -n "$denter" ] || continue
 
-	run_strace -f -r -egettimeofday \
+	run_strace --follow-forks -r -egettimeofday \
 		-einject=gettimeofday:delay_enter=$denter:delay_exit=$dexit \
 		../delay 4 $denter_us $dexit_us
 done <<-EOF
diff -pruN 5.5-3/tests/dev--decode-fds-dev.c 5.9-0ubuntu2/tests/dev--decode-fds-dev.c
--- 5.5-3/tests/dev--decode-fds-dev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/dev--decode-fds-dev.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_DEVNUM 1
+#include "dev-yy.c"
diff -pruN 5.5-3/tests/dev--decode-fds-dev.gen.test 5.9-0ubuntu2/tests/dev--decode-fds-dev.gen.test
--- 5.5-3/tests/dev--decode-fds-dev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/dev--decode-fds-dev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dev--decode-fds-dev -a30 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" -e decode-fds=dev); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a30 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" -e decode-fds=dev
diff -pruN 5.5-3/tests/dev--decode-fds-path.c 5.9-0ubuntu2/tests/dev--decode-fds-path.c
--- 5.5-3/tests/dev--decode-fds-path.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/dev--decode-fds-path.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_DEVNUM 0
+#include "dev-yy.c"
diff -pruN 5.5-3/tests/dev--decode-fds-path.gen.test 5.9-0ubuntu2/tests/dev--decode-fds-path.gen.test
--- 5.5-3/tests/dev--decode-fds-path.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/dev--decode-fds-path.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dev--decode-fds-path -a19 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" -e decode-fds=path); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a19 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" -e decode-fds=path
diff -pruN 5.5-3/tests/dev--decode-fds-socket.c 5.9-0ubuntu2/tests/dev--decode-fds-socket.c
--- 5.5-3/tests/dev--decode-fds-socket.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/dev--decode-fds-socket.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_DEVNUM 0
+#include "dev-yy.c"
diff -pruN 5.5-3/tests/dev--decode-fds-socket.gen.test 5.9-0ubuntu2/tests/dev--decode-fds-socket.gen.test
--- 5.5-3/tests/dev--decode-fds-socket.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/dev--decode-fds-socket.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dev--decode-fds-socket -a19 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" --decode-fds=socket); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a19 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" --decode-fds=socket
diff -pruN 5.5-3/tests/dev-yy.c 5.9-0ubuntu2/tests/dev-yy.c
--- 5.5-3/tests/dev-yy.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/dev-yy.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check printing of character/block device numbers in -yy mode.
  *
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -18,6 +18,16 @@
 
 #include <sys/sysmacros.h>
 
+#ifndef PRINT_DEVNUM
+# define PRINT_DEVNUM 1
+#endif
+
+#if PRINT_DEVNUM
+# define DEV_FMT "<%s<%s %u:%u>>"
+#else
+# define DEV_FMT "<%s>"
+#endif
+
 #if defined __NR_openat && defined O_PATH
 
 int
@@ -47,10 +57,13 @@ main(void)
 		printf("openat(AT_FDCWD, \"%s\", O_RDONLY|O_PATH) = %s",
 		       checks[i].path, sprintrc(fd));
 		if (fd >= 0)
-			printf("<%s<%s %u:%u>>",
-			       checks[i].path,
-			       checks[i].blk ? "block" : "char",
-			       checks[i].major, checks[i].minor);
+			printf(DEV_FMT,
+			       checks[i].path
+# if PRINT_DEVNUM
+			       , checks[i].blk ? "block" : "char",
+			       checks[i].major, checks[i].minor
+# endif
+			       );
 		puts("");
 
 		if (fd < 0) {
@@ -63,9 +76,13 @@ main(void)
 
 		int rc = fsync(fd);
 
-		printf("fsync(%ld<%s<%s %u:%u>>) = %s\n",
-		       fd, checks[i].path, checks[i].blk ? "block" : "char",
-		       checks[i].major, checks[i].minor, sprintrc(rc));
+		printf("fsync(%ld" DEV_FMT ") = %s\n",
+		       fd, checks[i].path,
+# if PRINT_DEVNUM
+		       checks[i].blk ? "block" : "char",
+		       checks[i].major, checks[i].minor,
+# endif
+		       sprintrc(rc));
 
 		close(fd);
 	}
diff -pruN 5.5-3/tests/dup2.c 5.9-0ubuntu2/tests/dup2.c
--- 5.5-3/tests/dup2.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/dup2.c	2020-04-24 23:03:14.000000000 +0000
@@ -1,5 +1,7 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Check decoding of dup2 syscall.
+ *
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -13,15 +15,103 @@
 # include <stdio.h>
 # include <unistd.h>
 
+# ifndef FD0_PATH
+#  define FD0_PATH ""
+# endif
+# ifndef FD9_PATH
+#  define FD9_PATH ""
+# endif
+# ifndef SKIP_IF_PROC_IS_UNAVAILABLE
+#  define SKIP_IF_PROC_IS_UNAVAILABLE
+# endif
+
+static const char *errstr;
+
+static long
+k_dup2(const unsigned int fd1, const unsigned int fd2)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+	const kernel_ulong_t arg1 = fill | fd1;
+	const kernel_ulong_t arg2 = fill | fd2;
+	const long rc = syscall(__NR_dup2, arg1, arg2, bad, bad, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
+
 int
 main(void)
 {
-	const long int fd_old = (long int) 0xdeadbeefffffffffULL;
-	const long int fd_new = (long int) 0xdeadbeeffffffffeULL;
+	SKIP_IF_PROC_IS_UNAVAILABLE;
+
+	int fd0 = dup(0);
+	int fd9 = dup(9);
 
-	long rc = syscall(__NR_dup2, fd_old, fd_new);
-	printf("dup2(%d, %d) = %ld %s (%m)\n",
-	       (int) fd_old, (int) fd_new, rc, errno2name());
+	if (k_dup2(0, 0))
+		perror_msg_and_skip("dup2");
+# ifndef PATH_TRACING
+	printf("dup2(0" FD0_PATH ", 0" FD0_PATH ") = 0" FD0_PATH "\n");
+# endif
+
+	k_dup2(-1, -2);
+# ifndef PATH_TRACING
+	printf("dup2(-1, -2) = %s\n", errstr);
+# endif
+
+	k_dup2(-2, -1);
+# ifndef PATH_TRACING
+	printf("dup2(-2, -1) = %s\n", errstr);
+# endif
+
+	k_dup2(-3, 0);
+# ifndef PATH_TRACING
+	printf("dup2(-3, 0" FD0_PATH ") = %s\n", errstr);
+# endif
+
+	k_dup2(0, -4);
+# ifndef PATH_TRACING
+	printf("dup2(0" FD0_PATH ", -4) = %s\n", errstr);
+# endif
+
+	k_dup2(-5, 9);
+	printf("dup2(-5, 9" FD9_PATH ") = %s\n", errstr);
+
+	k_dup2(9, -6);
+	printf("dup2(9" FD9_PATH ", -6) = %s\n", errstr);
+
+	k_dup2(9, 9);
+	printf("dup2(9" FD9_PATH ", 9" FD9_PATH ") = 9" FD9_PATH "\n");
+
+	k_dup2(0, fd0);
+# ifndef PATH_TRACING
+	printf("dup2(0" FD0_PATH ", %d" FD0_PATH ") = %d" FD0_PATH "\n",
+	       fd0, fd0);
+# endif
+
+	k_dup2(9, fd9);
+	printf("dup2(9" FD9_PATH ", %d" FD9_PATH ") = %d" FD9_PATH "\n",
+	       fd9, fd9);
+
+	k_dup2(0, fd9);
+	printf("dup2(0" FD0_PATH ", %d" FD9_PATH ") = %d" FD0_PATH "\n",
+	       fd9, fd9);
+
+	k_dup2(9, fd0);
+	printf("dup2(9" FD9_PATH ", %d" FD0_PATH ") = %d" FD9_PATH "\n",
+	       fd0, fd0);
+
+	close(fd0);
+	close(fd9);
+
+	k_dup2(0, fd0);
+# ifndef PATH_TRACING
+	printf("dup2(0" FD0_PATH ", %d) = %d" FD0_PATH "\n",
+	       fd0, fd0);
+# endif
+
+	k_dup2(9, fd9);
+	printf("dup2(9" FD9_PATH ", %d) = %d" FD9_PATH "\n",
+	       fd9, fd9);
 
 	puts("+++ exited with 0 +++");
 	return 0;
diff -pruN 5.5-3/tests/dup2.gen.test 5.9-0ubuntu2/tests/dup2.gen.test
--- 5.5-3/tests/dup2.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests/dup2.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -1,4 +1,4 @@
 #!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup2 -a13 ); do not edit.
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup2 -a11 9>>/dev/full); do not edit.
 . "${srcdir=.}/init.sh"
-run_strace_match_diff -a13 
+run_strace_match_diff -a11 9>>/dev/full
diff -pruN 5.5-3/tests/dup2-P.c 5.9-0ubuntu2/tests/dup2-P.c
--- 5.5-3/tests/dup2-P.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/dup2-P.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,4 @@
+#define PATH_TRACING
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup2.c"
diff -pruN 5.5-3/tests/dup2-P.gen.test 5.9-0ubuntu2/tests/dup2-P.gen.test
--- 5.5-3/tests/dup2-P.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/dup2-P.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup2-P -a11 --trace=dup2 -P /dev/full 9>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a11 --trace=dup2 -P /dev/full 9>>/dev/full
diff -pruN 5.5-3/tests/dup2-y.c 5.9-0ubuntu2/tests/dup2-y.c
--- 5.5-3/tests/dup2-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/dup2-y.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,5 @@
+#define FD0_PATH "</dev/null>"
+#define FD9_PATH "</dev/full>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup2.c"
diff -pruN 5.5-3/tests/dup2-y.gen.test 5.9-0ubuntu2/tests/dup2-y.gen.test
--- 5.5-3/tests/dup2-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/dup2-y.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup2-y -a13 --trace=dup2 -y 9>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a13 --trace=dup2 -y 9>>/dev/full
diff -pruN 5.5-3/tests/dup2-yy.c 5.9-0ubuntu2/tests/dup2-yy.c
--- 5.5-3/tests/dup2-yy.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/dup2-yy.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,5 @@
+#define FD0_PATH "</dev/null<char 1:3>>"
+#define FD9_PATH "</dev/full<char 1:7>>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup2.c"
diff -pruN 5.5-3/tests/dup2-yy.gen.test 5.9-0ubuntu2/tests/dup2-yy.gen.test
--- 5.5-3/tests/dup2-yy.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/dup2-yy.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup2-yy -a13 --trace=dup2 -yy 9>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a13 --trace=dup2 -yy 9>>/dev/full
diff -pruN 5.5-3/tests/dup3.c 5.9-0ubuntu2/tests/dup3.c
--- 5.5-3/tests/dup3.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/dup3.c	2020-04-24 23:03:14.000000000 +0000
@@ -1,28 +1,140 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Check decoding of dup3 syscall.
+ *
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-#include <fcntl.h>
 #include "scno.h"
 
-#if defined __NR_dup3 && defined O_CLOEXEC
+#ifdef __NR_dup3
 
+# include <fcntl.h>
 # include <stdio.h>
 # include <unistd.h>
 
+# ifndef O_CLOEXEC
+#  if defined __alpha__ || defined __hppa__
+#   define O_CLOEXEC	010000000
+#  elif defined __sparc__
+#   define O_CLOEXEC	020000000
+#  else
+#   define O_CLOEXEC	02000000
+#  endif
+# endif /* !O_CLOEXEC */
+
+# ifndef FD0_PATH
+#  define FD0_PATH ""
+# endif
+# ifndef FD7_PATH
+#  define FD7_PATH ""
+# endif
+# ifndef SKIP_IF_PROC_IS_UNAVAILABLE
+#  define SKIP_IF_PROC_IS_UNAVAILABLE
+# endif
+
+static const char *errstr;
+
+static long
+k_dup3(const unsigned int fd1, const unsigned int fd2, const unsigned int flags)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+	const kernel_ulong_t arg1 = fill | fd1;
+	const kernel_ulong_t arg2 = fill | fd2;
+	const kernel_ulong_t arg3 = fill | flags;
+	const long rc = syscall(__NR_dup3, arg1, arg2, arg3, bad, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
+
 int
 main(void)
 {
-	const long int fd_old = (long int) 0xdeadbeefffffffffULL;
-	const long int fd_new = (long int) 0xdeadbeeffffffffeULL;
+	SKIP_IF_PROC_IS_UNAVAILABLE;
+
+	int fd0 = dup(0);
+	int fd7 = dup(7);
 
-	long rc = syscall(__NR_dup3, fd_old, fd_new, O_CLOEXEC);
-	printf("dup3(%d, %d, O_CLOEXEC) = %ld %s (%m)\n",
-	       (int) fd_old, (int) fd_new, rc, errno2name());
+	k_dup3(0, 0, 0);
+# ifndef PATH_TRACING
+	printf("dup3(0" FD0_PATH ", 0" FD0_PATH ", 0) = %s\n", errstr);
+# endif
+
+	k_dup3(-1, -2, O_CLOEXEC);
+# ifndef PATH_TRACING
+	printf("dup3(-1, -2, O_CLOEXEC) = %s\n", errstr);
+# endif
+
+	k_dup3(-2, -1, O_TRUNC);
+# ifndef PATH_TRACING
+	printf("dup3(-2, -1, O_TRUNC) = %s\n", errstr);
+# endif
+
+	k_dup3(-3, 0, O_TRUNC | O_CLOEXEC);
+# ifndef PATH_TRACING
+	printf("dup3(-3, 0" FD0_PATH ", O_TRUNC|O_CLOEXEC) = %s\n", errstr);
+# endif
+
+	k_dup3(0, -4, O_RDONLY);
+# ifndef PATH_TRACING
+	printf("dup3(0" FD0_PATH ", -4, 0) = %s\n", errstr);
+# endif
+
+	k_dup3(-5, 7, O_WRONLY);
+	printf("dup3(-5, 7" FD7_PATH ", 0x1 /* O_??? */) = %s\n", errstr);
+
+	k_dup3(7, -6, O_RDWR);
+	printf("dup3(7" FD7_PATH ", -6, 0x2 /* O_??? */) = %s\n", errstr);
+
+	k_dup3(7, 7, O_CLOEXEC);
+	printf("dup3(7" FD7_PATH ", 7" FD7_PATH ", O_CLOEXEC) = %s\n", errstr);
+
+	k_dup3(-7, -7, 7);
+# ifndef PATH_TRACING
+	printf("dup3(-7, -7, %s) = %s\n",
+#  ifdef __sparc__
+	       "O_NDELAY|0x3"
+#  else
+	       "0x7 /* O_??? */"
+#  endif
+	       , errstr);
+# endif
+
+	if (k_dup3(0, fd0, O_CLOEXEC) != fd0)
+		perror_msg_and_skip("dup3");
+# ifndef PATH_TRACING
+	printf("dup3(0" FD0_PATH ", %d" FD0_PATH ", O_CLOEXEC) = %d" FD0_PATH
+	       "\n", fd0, fd0);
+# endif
+
+	k_dup3(7, fd7, 0);
+	printf("dup3(7" FD7_PATH ", %d" FD7_PATH ", 0) = %d" FD7_PATH
+	       "\n", fd7, fd7);
+
+	k_dup3(0, fd7, O_CLOEXEC);
+	printf("dup3(0" FD0_PATH ", %d" FD7_PATH ", O_CLOEXEC) = %d" FD0_PATH
+	       "\n", fd7, fd7);
+
+	k_dup3(7, fd0, 0);
+	printf("dup3(7" FD7_PATH ", %d" FD0_PATH ", 0) = %d" FD7_PATH
+	       "\n", fd0, fd0);
+
+	close(fd0);
+	close(fd7);
+
+	k_dup3(0, fd0, O_CLOEXEC);
+# ifndef PATH_TRACING
+	printf("dup3(0" FD0_PATH ", %d, O_CLOEXEC) = %d" FD0_PATH "\n",
+	       fd0, fd0);
+# endif
+
+	k_dup3(7, fd7, 0);
+	printf("dup3(7" FD7_PATH ", %d, 0) = %d" FD7_PATH "\n",
+	       fd7, fd7);
 
 	puts("+++ exited with 0 +++");
 	return 0;
@@ -30,6 +142,6 @@ main(void)
 
 #else
 
-SKIP_MAIN_UNDEFINED("__NR_dup3 && O_CLOEXEC")
+SKIP_MAIN_UNDEFINED("__NR_dup3")
 
 #endif
diff -pruN 5.5-3/tests/dup3.gen.test 5.9-0ubuntu2/tests/dup3.gen.test
--- 5.5-3/tests/dup3.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests/dup3.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -1,4 +1,4 @@
 #!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup3 -a24 ); do not edit.
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup3 -a13 7>>/dev/full); do not edit.
 . "${srcdir=.}/init.sh"
-run_strace_match_diff -a24 
+run_strace_match_diff -a13 7>>/dev/full
diff -pruN 5.5-3/tests/dup3-P.c 5.9-0ubuntu2/tests/dup3-P.c
--- 5.5-3/tests/dup3-P.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/dup3-P.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,4 @@
+#define PATH_TRACING
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup3.c"
diff -pruN 5.5-3/tests/dup3-P.gen.test 5.9-0ubuntu2/tests/dup3-P.gen.test
--- 5.5-3/tests/dup3-P.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/dup3-P.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup3-P -a13 --trace=dup3 -P /dev/full 7>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a13 --trace=dup3 -P /dev/full 7>>/dev/full
diff -pruN 5.5-3/tests/dup3-y.c 5.9-0ubuntu2/tests/dup3-y.c
--- 5.5-3/tests/dup3-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/dup3-y.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,5 @@
+#define FD0_PATH "</dev/null>"
+#define FD7_PATH "</dev/full>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup3.c"
diff -pruN 5.5-3/tests/dup3-y.gen.test 5.9-0ubuntu2/tests/dup3-y.gen.test
--- 5.5-3/tests/dup3-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/dup3-y.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup3-y -a15 --trace=dup3 -y 7>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a15 --trace=dup3 -y 7>>/dev/full
diff -pruN 5.5-3/tests/dup3-yy.c 5.9-0ubuntu2/tests/dup3-yy.c
--- 5.5-3/tests/dup3-yy.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/dup3-yy.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,5 @@
+#define FD0_PATH "</dev/null<char 1:3>>"
+#define FD7_PATH "</dev/full<char 1:7>>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup3.c"
diff -pruN 5.5-3/tests/dup3-yy.gen.test 5.9-0ubuntu2/tests/dup3-yy.gen.test
--- 5.5-3/tests/dup3-yy.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/dup3-yy.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup3-yy -a15 --trace=dup3 -yy 7>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a15 --trace=dup3 -yy 7>>/dev/full
diff -pruN 5.5-3/tests/dup.c 5.9-0ubuntu2/tests/dup.c
--- 5.5-3/tests/dup.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/dup.c	2020-04-24 23:03:14.000000000 +0000
@@ -1,20 +1,72 @@
 /*
- * Copyright (c) 2016-2018 The strace developers.
+ * Check decoding of dup syscall.
+ *
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-#include <stdio.h>
-#include <unistd.h>
+#include "scno.h"
+
+#ifdef __NR_dup
+
+# include <stdio.h>
+# include <unistd.h>
+
+# ifndef FD0_PATH
+#  define FD0_PATH ""
+# endif
+# ifndef FD9_PATH
+#  define FD9_PATH ""
+# endif
+# ifndef SKIP_IF_PROC_IS_UNAVAILABLE
+#  define SKIP_IF_PROC_IS_UNAVAILABLE
+# endif
+
+static const char *errstr;
+
+static long
+k_dup(const unsigned int fd)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+	const kernel_ulong_t arg1 = fill | fd;
+	const long rc = syscall(__NR_dup, arg1, bad, bad, bad, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
 
 int
 main(void)
 {
-	int rc = dup(-1);
-	printf("dup(-1) = %d %s (%m)\n", rc, errno2name());
+	SKIP_IF_PROC_IS_UNAVAILABLE;
+
+	k_dup(-1);
+# ifndef PATH_TRACING
+	printf("dup(-1) = %s\n", errstr);
+# endif
+
+	int d1 = k_dup(0);
+# ifndef PATH_TRACING
+	printf("dup(0" FD0_PATH ") = %d" FD0_PATH "\n", d1);
+# endif
+
+	int d2 = k_dup(d1);
+# ifndef PATH_TRACING
+	printf("dup(%d" FD0_PATH ") = %d" FD0_PATH "\n", d1, d2);
+# endif
+
+	d2 = k_dup(9);
+	printf("dup(9" FD9_PATH ") = %d" FD9_PATH "\n", d2);
 
 	puts("+++ exited with 0 +++");
 	return 0;
 }
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_dup")
+
+#endif
diff -pruN 5.5-3/tests/dup.gen.test 5.9-0ubuntu2/tests/dup.gen.test
--- 5.5-3/tests/dup.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests/dup.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -1,4 +1,4 @@
 #!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup -a8 ); do not edit.
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup -a7 9>>/dev/full); do not edit.
 . "${srcdir=.}/init.sh"
-run_strace_match_diff -a8 
+run_strace_match_diff -a7 9>>/dev/full
diff -pruN 5.5-3/tests/dup-P.c 5.9-0ubuntu2/tests/dup-P.c
--- 5.5-3/tests/dup-P.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/dup-P.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,4 @@
+#define PATH_TRACING
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup.c"
diff -pruN 5.5-3/tests/dup-P.gen.test 5.9-0ubuntu2/tests/dup-P.gen.test
--- 5.5-3/tests/dup-P.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/dup-P.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup-P -a7 --trace=dup -P /dev/full 9>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a7 --trace=dup -P /dev/full 9>>/dev/full
diff -pruN 5.5-3/tests/dup-y.c 5.9-0ubuntu2/tests/dup-y.c
--- 5.5-3/tests/dup-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/dup-y.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,5 @@
+#define FD0_PATH "</dev/null>"
+#define FD9_PATH "</dev/full>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup.c"
diff -pruN 5.5-3/tests/dup-y.gen.test 5.9-0ubuntu2/tests/dup-y.gen.test
--- 5.5-3/tests/dup-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/dup-y.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup-y -a8 --trace=dup -y 9>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a8 --trace=dup -y 9>>/dev/full
diff -pruN 5.5-3/tests/dup-yy.c 5.9-0ubuntu2/tests/dup-yy.c
--- 5.5-3/tests/dup-yy.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/dup-yy.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,5 @@
+#define FD0_PATH "</dev/null<char 1:3>>"
+#define FD9_PATH "</dev/full<char 1:7>>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup.c"
diff -pruN 5.5-3/tests/dup-yy.gen.test 5.9-0ubuntu2/tests/dup-yy.gen.test
--- 5.5-3/tests/dup-yy.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/dup-yy.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup-yy -a8 --trace=dup -yy 9>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a8 --trace=dup -yy 9>>/dev/full
diff -pruN 5.5-3/tests/faccessat2.c 5.9-0ubuntu2/tests/faccessat2.c
--- 5.5-3/tests/faccessat2.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/faccessat2.c	2020-09-23 16:29:35.000000000 +0000
@@ -0,0 +1,174 @@
+/*
+ * Check decoding of faccessat2 syscall.
+ *
+ * Copyright (c) 2016-2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+
+#ifdef __NR_faccessat2
+
+# include <fcntl.h>
+# include <stdio.h>
+# include <unistd.h>
+
+# define XLAT_MACROS_ONLY
+#  include "xlat/faccessat_flags.h"
+# undef XLAT_MACROS_ONLY
+
+# ifndef FD_PATH
+#  define FD_PATH ""
+# endif
+# ifndef SKIP_IF_PROC_IS_UNAVAILABLE
+#  define SKIP_IF_PROC_IS_UNAVAILABLE
+# endif
+
+static const char *errstr;
+
+static long
+k_faccessat2(const unsigned int dirfd,
+	     const void *const pathname,
+	     const unsigned int mode,
+	     const unsigned int flags)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+
+	const kernel_ulong_t arg1 = fill | dirfd;
+	const kernel_ulong_t arg2 = (uintptr_t) pathname;
+	const kernel_ulong_t arg3 = fill | mode;
+	const kernel_ulong_t arg4 = fill | flags;
+	const long rc = syscall(__NR_faccessat2,
+				arg1, arg2, arg3, arg4, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
+
+int
+main(void)
+{
+	SKIP_IF_PROC_IS_UNAVAILABLE;
+
+	TAIL_ALLOC_OBJECT_CONST_PTR(const char, unterminated);
+	char *unterminated_str;
+	if (asprintf(&unterminated_str, "%p", unterminated) < 0)
+                perror_msg_and_fail("asprintf");
+	const void *const efault = unterminated + 1;
+	char *efault_str;
+	if (asprintf(&efault_str, "%p", efault) < 0)
+                perror_msg_and_fail("asprintf");
+
+	typedef struct {
+		char sym;
+		char null;
+	} sym_null;
+
+	TAIL_ALLOC_OBJECT_CONST_PTR(sym_null, dot);
+	dot->sym = '.';
+	dot->null = '\0';
+	const char *const null = &dot->null;
+
+	TAIL_ALLOC_OBJECT_CONST_PTR(sym_null, slash);
+	slash->sym = '/';
+	slash->null = '\0';
+
+	static const char path[] = "/dev/full";
+	const char *const fd_path = tail_memdup(path, sizeof(path));
+        int fd = open(path, O_WRONLY);
+        if (fd < 0)
+                perror_msg_and_fail("open: %s", path);
+	char *fd_str;
+	if (asprintf(&fd_str, "%d%s", fd, FD_PATH) < 0)
+                perror_msg_and_fail("asprintf");
+	char *path_quoted;
+	if (asprintf(&path_quoted, "\"%s\"", path) < 0)
+                perror_msg_and_fail("asprintf");
+
+	struct {
+		int val;
+		const char *str;
+	} dirfds[] = {
+		{ ARG_STR(-1) },
+		{ -100, "AT_FDCWD" },
+		{ fd, fd_str },
+	}, modes[] = {
+		{ ARG_STR(F_OK) },
+		{ ARG_STR(R_OK) },
+		{ ARG_STR(W_OK) },
+		{ ARG_STR(X_OK) },
+		{ ARG_STR(R_OK|W_OK) },
+		{ ARG_STR(R_OK|X_OK) },
+		{ ARG_STR(W_OK|X_OK) },
+		{ ARG_STR(R_OK|W_OK|X_OK) },
+		{ 8, "0x8 /* ?_OK */" },
+		{ -1, "R_OK|W_OK|X_OK|0xfffffff8" },
+	}, flags[] = {
+		{ ARG_STR(0) },
+		{ ARG_STR(AT_SYMLINK_NOFOLLOW) },
+		{ ARG_STR(AT_EACCESS) },
+		{ ARG_STR(AT_EMPTY_PATH) },
+		{ ARG_STR(AT_SYMLINK_NOFOLLOW|AT_EACCESS) },
+		{ ARG_STR(AT_SYMLINK_NOFOLLOW|AT_EMPTY_PATH) },
+		{ ARG_STR(AT_EACCESS|AT_EMPTY_PATH) },
+		{ ARG_STR(AT_SYMLINK_NOFOLLOW|AT_EACCESS|AT_EMPTY_PATH) },
+		{ 1, "0x1 /* AT_??? */" },
+		{ -1, "AT_SYMLINK_NOFOLLOW|AT_EACCESS|AT_EMPTY_PATH|0xffffecff" },
+	};
+
+	struct {
+		const void *val;
+		const char *str;
+	} paths[] = {
+		{ 0, "NULL" },
+		{ efault, efault_str },
+		{ unterminated, unterminated_str },
+		{ null, "\"\"" },
+		{ &dot->sym, "\".\"" },
+		{ &slash->sym, "\"/\"" },
+		{ fd_path, path_quoted },
+	};
+
+	for (unsigned int dirfd_i = 0;
+	     dirfd_i < ARRAY_SIZE(dirfds);
+	     ++dirfd_i) {
+		for (unsigned int path_i = 0;
+		     path_i < ARRAY_SIZE(paths);
+		     ++path_i) {
+			for (unsigned int mode_i = 0;
+			     mode_i < ARRAY_SIZE(modes);
+			     ++mode_i) {
+				for (unsigned int flag_i = 0;
+				     flag_i < ARRAY_SIZE(flags);
+				     ++flag_i) {
+					k_faccessat2(dirfds[dirfd_i].val,
+						    paths[path_i].val,
+						    modes[mode_i].val,
+						    flags[flag_i].val);
+# ifdef PATH_TRACING
+					if (dirfds[dirfd_i].val == fd ||
+					    paths[path_i].val == fd_path)
+# endif
+					printf("faccessat2(%s, %s, %s, %s) = %s\n",
+					       dirfds[dirfd_i].str,
+					       paths[path_i].str,
+					       modes[mode_i].str,
+					       flags[flag_i].str,
+					       errstr);
+				}
+			}
+		}
+	}
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_faccessat2")
+
+#endif
diff -pruN 5.5-3/tests/faccessat2-P.c 5.9-0ubuntu2/tests/faccessat2-P.c
--- 5.5-3/tests/faccessat2-P.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/faccessat2-P.c	2020-07-04 08:00:00.000000000 +0000
@@ -0,0 +1,4 @@
+#define PATH_TRACING
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "faccessat2.c"
diff -pruN 5.5-3/tests/faccessat2-P.gen.test 5.9-0ubuntu2/tests/faccessat2-P.gen.test
--- 5.5-3/tests/faccessat2-P.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/faccessat2-P.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (faccessat2-P -a27 --trace=faccessat2 -P /dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a27 --trace=faccessat2 -P /dev/full
diff -pruN 5.5-3/tests/faccessat2.test 5.9-0ubuntu2/tests/faccessat2.test
--- 5.5-3/tests/faccessat2.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/faccessat2.test	2020-07-04 08:00:00.000000000 +0000
@@ -0,0 +1,19 @@
+#!/bin/sh
+#
+# Check decoding of faccessat2 syscall.
+#
+# Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
+# All rights reserved.
+#
+# SPDX-License-Identifier: GPL-2.0-or-later
+
+. "${srcdir=.}/init.sh"
+
+check_prog sed
+
+run_prog > /dev/null
+run_strace -a27 --trace=faccessat2 "$@" $args > "$EXP"
+
+# Filter out faccessat2() calls made by ld.so and libc.
+sed -n '/^faccessat2(-1, NULL,/,$p' < "$LOG" > "$OUT"
+match_diff "$OUT" "$EXP"
diff -pruN 5.5-3/tests/faccessat2-y.c 5.9-0ubuntu2/tests/faccessat2-y.c
--- 5.5-3/tests/faccessat2-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/faccessat2-y.c	2020-07-04 08:00:00.000000000 +0000
@@ -0,0 +1,4 @@
+#define FD_PATH "</dev/full>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "faccessat2.c"
diff -pruN 5.5-3/tests/faccessat2-y.gen.test 5.9-0ubuntu2/tests/faccessat2-y.gen.test
--- 5.5-3/tests/faccessat2-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/faccessat2-y.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (faccessat2-y +faccessat2.test -a28 -y); do not edit.
+set -- -a28 -y
+. "${srcdir=.}/faccessat2.test"
diff -pruN 5.5-3/tests/faccessat2-yy.c 5.9-0ubuntu2/tests/faccessat2-yy.c
--- 5.5-3/tests/faccessat2-yy.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/faccessat2-yy.c	2020-07-04 08:00:00.000000000 +0000
@@ -0,0 +1,4 @@
+#define FD_PATH "</dev/full<char 1:7>>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "faccessat2.c"
diff -pruN 5.5-3/tests/faccessat2-yy.gen.test 5.9-0ubuntu2/tests/faccessat2-yy.gen.test
--- 5.5-3/tests/faccessat2-yy.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/faccessat2-yy.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (faccessat2-yy +faccessat2.test -a28 -yy); do not edit.
+set -- -a28 -yy
+. "${srcdir=.}/faccessat2.test"
diff -pruN 5.5-3/tests/faccessat.c 5.9-0ubuntu2/tests/faccessat.c
--- 5.5-3/tests/faccessat.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/faccessat.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,5 +1,7 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Check decoding of faccessat syscall.
+ *
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,18 +12,133 @@
 
 #ifdef __NR_faccessat
 
+# include <fcntl.h>
 # include <stdio.h>
 # include <unistd.h>
 
+# ifndef FD_PATH
+#  define FD_PATH ""
+# endif
+# ifndef SKIP_IF_PROC_IS_UNAVAILABLE
+#  define SKIP_IF_PROC_IS_UNAVAILABLE
+# endif
+
+static const char *errstr;
+
+static long
+k_faccessat(const unsigned int dirfd,
+	    const void *const pathname,
+	    const unsigned int mode)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+
+	const kernel_ulong_t arg1 = fill | dirfd;
+	const kernel_ulong_t arg2 = (uintptr_t) pathname;
+	const kernel_ulong_t arg3 = fill | mode;
+	const long rc = syscall(__NR_faccessat,
+				arg1, arg2, arg3, bad, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
+
 int
 main(void)
 {
-	static const char sample[] = "faccessat.sample";
-	const long int fd = (long int) 0xdeadbeefffffffffULL;
+	SKIP_IF_PROC_IS_UNAVAILABLE;
 
-	long rc = syscall(__NR_faccessat, fd, sample, F_OK);
-	printf("faccessat(%d, \"%s\", F_OK) = %ld %s (%m)\n",
-	       (int) fd, sample, rc, errno2name());
+	TAIL_ALLOC_OBJECT_CONST_PTR(const char, unterminated);
+	char *unterminated_str;
+	if (asprintf(&unterminated_str, "%p", unterminated) < 0)
+                perror_msg_and_fail("asprintf");
+	const void *const efault = unterminated + 1;
+	char *efault_str;
+	if (asprintf(&efault_str, "%p", efault) < 0)
+                perror_msg_and_fail("asprintf");
+
+	typedef struct {
+		char sym;
+		char null;
+	} sym_null;
+
+	TAIL_ALLOC_OBJECT_CONST_PTR(sym_null, dot);
+	dot->sym = '.';
+	dot->null = '\0';
+	const char *const null = &dot->null;
+
+	TAIL_ALLOC_OBJECT_CONST_PTR(sym_null, slash);
+	slash->sym = '/';
+	slash->null = '\0';
+
+	static const char path[] = "/dev/full";
+	const char *const fd_path = tail_memdup(path, sizeof(path));
+        int fd = open(path, O_WRONLY);
+        if (fd < 0)
+                perror_msg_and_fail("open: %s", path);
+	char *fd_str;
+	if (asprintf(&fd_str, "%d%s", fd, FD_PATH) < 0)
+                perror_msg_and_fail("asprintf");
+	char *path_quoted;
+	if (asprintf(&path_quoted, "\"%s\"", path) < 0)
+                perror_msg_and_fail("asprintf");
+
+	struct {
+		int val;
+		const char *str;
+	} dirfds[] = {
+		{ ARG_STR(-1) },
+		{ -100, "AT_FDCWD" },
+		{ fd, fd_str },
+	}, modes[] = {
+		{ ARG_STR(F_OK) },
+		{ ARG_STR(R_OK) },
+		{ ARG_STR(W_OK) },
+		{ ARG_STR(X_OK) },
+		{ ARG_STR(R_OK|W_OK) },
+		{ ARG_STR(R_OK|X_OK) },
+		{ ARG_STR(W_OK|X_OK) },
+		{ ARG_STR(R_OK|W_OK|X_OK) },
+		{ 8, "0x8 /* ?_OK */" },
+		{ -1, "R_OK|W_OK|X_OK|0xfffffff8" },
+	};
+
+	struct {
+		const void *val;
+		const char *str;
+	} paths[] = {
+		{ 0, "NULL" },
+		{ efault, efault_str },
+		{ unterminated, unterminated_str },
+		{ null, "\"\"" },
+		{ &dot->sym, "\".\"" },
+		{ &slash->sym, "\"/\"" },
+		{ fd_path, path_quoted },
+	};
+
+	for (unsigned int dirfd_i = 0;
+	     dirfd_i < ARRAY_SIZE(dirfds);
+	     ++dirfd_i) {
+		for (unsigned int path_i = 0;
+		     path_i < ARRAY_SIZE(paths);
+		     ++path_i) {
+			for (unsigned int mode_i = 0;
+			     mode_i < ARRAY_SIZE(modes);
+			     ++mode_i) {
+				k_faccessat(dirfds[dirfd_i].val,
+					    paths[path_i].val,
+					    modes[mode_i].val);
+# ifdef PATH_TRACING
+				if (dirfds[dirfd_i].val == fd ||
+				    paths[path_i].val == fd_path)
+# endif
+				printf("faccessat(%s, %s, %s) = %s\n",
+				       dirfds[dirfd_i].str,
+				       paths[path_i].str,
+				       modes[mode_i].str,
+				       errstr);
+			}
+		}
+	}
 
 	puts("+++ exited with 0 +++");
 	return 0;
diff -pruN 5.5-3/tests/faccessat.gen.test 5.9-0ubuntu2/tests/faccessat.gen.test
--- 5.5-3/tests/faccessat.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests/faccessat.gen.test	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-#!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (faccessat -P $NAME.sample); do not edit.
-. "${srcdir=.}/init.sh"
-run_strace_match_diff -P $NAME.sample
diff -pruN 5.5-3/tests/faccessat-P.c 5.9-0ubuntu2/tests/faccessat-P.c
--- 5.5-3/tests/faccessat-P.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/faccessat-P.c	2020-07-04 08:00:00.000000000 +0000
@@ -0,0 +1,4 @@
+#define PATH_TRACING
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "faccessat.c"
diff -pruN 5.5-3/tests/faccessat-P.gen.test 5.9-0ubuntu2/tests/faccessat-P.gen.test
--- 5.5-3/tests/faccessat-P.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/faccessat-P.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (faccessat-P -a23 --trace=faccessat -P /dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a23 --trace=faccessat -P /dev/full
diff -pruN 5.5-3/tests/faccessat.test 5.9-0ubuntu2/tests/faccessat.test
--- 5.5-3/tests/faccessat.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/faccessat.test	2020-07-04 08:00:00.000000000 +0000
@@ -0,0 +1,19 @@
+#!/bin/sh
+#
+# Check decoding of faccessat syscall.
+#
+# Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
+# All rights reserved.
+#
+# SPDX-License-Identifier: GPL-2.0-or-later
+
+. "${srcdir=.}/init.sh"
+
+check_prog sed
+
+run_prog > /dev/null
+run_strace -a23 --trace=faccessat "$@" $args > "$EXP"
+
+# Filter out faccessat() calls made by ld.so and libc.
+sed -n '/^faccessat(-1, NULL,/,$p' < "$LOG" > "$OUT"
+match_diff "$OUT" "$EXP"
diff -pruN 5.5-3/tests/faccessat-y.c 5.9-0ubuntu2/tests/faccessat-y.c
--- 5.5-3/tests/faccessat-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/faccessat-y.c	2020-07-04 08:00:00.000000000 +0000
@@ -0,0 +1,4 @@
+#define FD_PATH "</dev/full>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "faccessat.c"
diff -pruN 5.5-3/tests/faccessat-y.gen.test 5.9-0ubuntu2/tests/faccessat-y.gen.test
--- 5.5-3/tests/faccessat-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/faccessat-y.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (faccessat-y +faccessat.test -a24 -y); do not edit.
+set -- -a24 -y
+. "${srcdir=.}/faccessat.test"
diff -pruN 5.5-3/tests/faccessat-yy.c 5.9-0ubuntu2/tests/faccessat-yy.c
--- 5.5-3/tests/faccessat-yy.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/faccessat-yy.c	2020-07-04 08:00:00.000000000 +0000
@@ -0,0 +1,4 @@
+#define FD_PATH "</dev/full<char 1:7>>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "faccessat.c"
diff -pruN 5.5-3/tests/faccessat-yy.gen.test 5.9-0ubuntu2/tests/faccessat-yy.gen.test
--- 5.5-3/tests/faccessat-yy.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/faccessat-yy.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (faccessat-yy +faccessat.test -a24 -yy); do not edit.
+set -- -a24 -yy
+. "${srcdir=.}/faccessat.test"
diff -pruN 5.5-3/tests/fanotify_init.c 5.9-0ubuntu2/tests/fanotify_init.c
--- 5.5-3/tests/fanotify_init.c	2019-07-16 17:46:47.000000000 +0000
+++ 5.9-0ubuntu2/tests/fanotify_init.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of fanotify_init syscall.
  *
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -44,13 +44,14 @@ main(void)
 		{ F8ILL_KULONG_MASK, "FAN_CLASS_NOTIF" },
 		{ (kernel_ulong_t) 0xffffffff0000000cULL,
 			"0xc /* FAN_CLASS_??? */" },
-		{ (kernel_ulong_t) 0xdec0deddefacec04ULL,
-			"FAN_CLASS_CONTENT|0xefacec00 /* FAN_??? */" },
+		{ (kernel_ulong_t) 0xdec0deddeface004ULL,
+			"FAN_CLASS_CONTENT|0xeface000 /* FAN_??? */" },
 		{ (kernel_ulong_t) 0xffffffffffffffffULL,
 			"0xc /* FAN_CLASS_??? */|FAN_CLOEXEC|FAN_NONBLOCK|"
 			"FAN_UNLIMITED_QUEUE|FAN_UNLIMITED_MARKS|"
 			"FAN_ENABLE_AUDIT|FAN_REPORT_TID|FAN_REPORT_FID|"
-			"0xfffffc80" },
+			"FAN_REPORT_DIR_FID|FAN_REPORT_NAME|"
+			"0xfffff080" },
 	};
 	static const struct strval event_f_flags[] = {
 		{ F8ILL_KULONG_MASK, "O_RDONLY" },
diff -pruN 5.5-3/tests/fanotify_mark.c 5.9-0ubuntu2/tests/fanotify_mark.c
--- 5.5-3/tests/fanotify_mark.c	2019-07-16 17:46:47.000000000 +0000
+++ 5.9-0ubuntu2/tests/fanotify_mark.c	2020-04-15 13:39:57.000000000 +0000
@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -68,11 +68,6 @@ struct strval {
 	const char *str;
 };
 
-struct strval64 {
-	uint64_t val;
-	const char *str;
-};
-
 # define STR16 "0123456789abcdef"
 # define STR64 STR16 STR16 STR16 STR16
 
@@ -150,15 +145,16 @@ main(void)
 			"FAN_OPEN_PERM|"
 			"FAN_ACCESS_PERM|"
 			"FAN_OPEN_EXEC_PERM|"
+			"FAN_DIR_MODIFY|"
 			"FAN_ONDIR|"
 			"FAN_EVENT_ON_CHILD|"
-			"0xdeadfeedb7f8a000"
+			"0xdeadfeedb7f0a000"
 # endif
 # if XLAT_VERBOSE
 			" */"
 # endif
 			},
-		{ ARG_ULL_STR(0xffffffffb7f8a000)
+		{ ARG_ULL_STR(0xffffffffb7f0a000)
 # if !XLAT_RAW
 			" /* FAN_??? */"
 # endif
diff -pruN 5.5-3/tests/fchmod.c 5.9-0ubuntu2/tests/fchmod.c
--- 5.5-3/tests/fchmod.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/fchmod.c	2020-06-01 14:15:16.000000000 +0000
@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2016 Fabien Siron <fabien.siron@epita.fr>
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -22,14 +22,7 @@
 int
 main(void)
 {
-	static const char fname[] = "fchmod_test_file";
-
-	int fd = open(fname, O_CREAT|O_RDONLY, 0400);
-	if (fd < 0)
-		perror_msg_and_fail("open");
-
-	if (unlink(fname))
-		perror_msg_and_fail("unlink");
+	int fd = create_tmpfile(O_RDWR);
 
 	long rc = syscall(__NR_fchmod, fd, 0600);
 	printf("fchmod(%d, 0600) = %s\n", fd, sprintrc(rc));
diff -pruN 5.5-3/tests/fcntl64.c 5.9-0ubuntu2/tests/fcntl64.c
--- 5.5-3/tests/fcntl64.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/fcntl64.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -27,6 +27,7 @@ test_flock64_lk64(void)
 	fl->l_len = FILE_LEN;
 
 	long rc = invoke_test_syscall(0, F_SETLK64, fl);
+	pidns_print_leader();
 	printf("%s(0, F_SETLK64, {l_type=F_RDLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d}) = %s\n",
 	       TEST_SYSCALL_STR, FILE_LEN, errstr);
@@ -35,11 +36,13 @@ test_flock64_lk64(void)
 		return;
 
 	invoke_test_syscall(0, F_GETLK64, fl);
+	pidns_print_leader();
 	printf("%s(0, F_GETLK64, {l_type=F_UNLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d, l_pid=0}) = 0\n",
 	       TEST_SYSCALL_STR, FILE_LEN);
 
 	invoke_test_syscall(0, F_SETLKW64, fl);
+	pidns_print_leader();
 	printf("%s(0, F_SETLKW64, {l_type=F_UNLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d}) = 0\n",
 	       TEST_SYSCALL_STR, FILE_LEN);
diff -pruN 5.5-3/tests/fcntl64--pidns-translation.c 5.9-0ubuntu2/tests/fcntl64--pidns-translation.c
--- 5.5-3/tests/fcntl64--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/fcntl64--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "fcntl64.c"
diff -pruN 5.5-3/tests/fcntl64--pidns-translation.gen.test 5.9-0ubuntu2/tests/fcntl64--pidns-translation.gen.test
--- 5.5-3/tests/fcntl64--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/fcntl64--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (fcntl64--pidns-translation test_pidns -a8 -e trace=fcntl64); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a8 -e trace=fcntl64
diff -pruN 5.5-3/tests/fcntl.c 5.9-0ubuntu2/tests/fcntl.c
--- 5.5-3/tests/fcntl.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/fcntl.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -24,6 +24,7 @@ test_flock64_undecoded(const int cmd, co
 		.l_len = 0xdefaced2cafef00dULL
 	};
 	invoke_test_syscall(0, cmd, &fl);
+	pidns_print_leader();
 	printf("%s(0, %s, %p) = %s\n",
 	       TEST_SYSCALL_STR, name, &fl, errstr);
 }
diff -pruN 5.5-3/tests/fcntl-common.c 5.9-0ubuntu2/tests/fcntl-common.c
--- 5.5-3/tests/fcntl-common.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/fcntl-common.c	2020-08-25 14:29:30.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -13,6 +13,8 @@
 #include <unistd.h>
 #include <assert.h>
 #include "flock.h"
+#include "pidns.h"
+#include "scno.h"
 
 #define FILE_LEN 4096
 
@@ -48,12 +50,14 @@ test_flock_einval(const int cmd, const c
 	fl->l_len = (TYPEOF_FLOCK_OFF_T) 0xdefaced2cafef00dULL;
 
 	invoke_test_syscall(0, cmd, fl);
+	pidns_print_leader();
 	printf("%s(0, %s, {l_type=F_RDLCK, l_whence=SEEK_SET"
 	       ", l_start=%jd, l_len=%jd}) = %s\n", TEST_SYSCALL_STR, name,
 	       (intmax_t) fl->l_start, (intmax_t) fl->l_len, errstr);
 
 	void *const bad_addr = (void *) fl + 1;
 	invoke_test_syscall(0, cmd, bad_addr);
+	pidns_print_leader();
 	printf("%s(0, %s, %p) = %s\n",
 	       TEST_SYSCALL_STR, name, bad_addr, errstr);
 }
@@ -72,12 +76,14 @@ test_flock64_einval(const int cmd, const
 	fl->l_len = (TYPEOF_FLOCK_OFF_T) 0xdefaced2cafef00dULL;
 
 	invoke_test_syscall(0, cmd, fl);
+	pidns_print_leader();
 	printf("%s(0, %s, {l_type=F_RDLCK, l_whence=SEEK_SET"
 	       ", l_start=%jd, l_len=%jd}) = %s\n", TEST_SYSCALL_STR, name,
 	       (intmax_t) fl->l_start, (intmax_t) fl->l_len, errstr);
 
 	void *const bad_addr = (void *) fl + 1;
 	invoke_test_syscall(0, cmd, bad_addr);
+	pidns_print_leader();
 	printf("%s(0, %s, %p) = %s\n",
 	       TEST_SYSCALL_STR, name, bad_addr, errstr);
 }
@@ -94,6 +100,7 @@ test_flock(void)
 	fl->l_len = FILE_LEN;
 
 	long rc = invoke_test_syscall(0, F_SETLK, fl);
+	pidns_print_leader();
 	printf("%s(0, F_SETLK, {l_type=F_RDLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d}) = %s\n",
 	       TEST_SYSCALL_STR, FILE_LEN, errstr);
@@ -101,11 +108,13 @@ test_flock(void)
 		return;
 
 	invoke_test_syscall(0, F_GETLK, fl);
+	pidns_print_leader();
 	printf("%s(0, F_GETLK, {l_type=F_UNLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d, l_pid=0}) = 0\n",
 	       TEST_SYSCALL_STR, FILE_LEN);
 
 	invoke_test_syscall(0, F_SETLKW, fl);
+	pidns_print_leader();
 	printf("%s(0, F_SETLKW, {l_type=F_UNLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d}) = 0\n",
 	       TEST_SYSCALL_STR, FILE_LEN);
@@ -124,6 +133,7 @@ test_flock64_ofd(void)
 	fl->l_len = FILE_LEN;
 
 	long rc = invoke_test_syscall(0, F_OFD_SETLK, fl);
+	pidns_print_leader();
 	printf("%s(0, F_OFD_SETLK, {l_type=F_RDLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d}) = %s\n",
 	       TEST_SYSCALL_STR, FILE_LEN, errstr);
@@ -131,11 +141,13 @@ test_flock64_ofd(void)
 		return;
 
 	invoke_test_syscall(0, F_OFD_GETLK, fl);
+	pidns_print_leader();
 	printf("%s(0, F_OFD_GETLK, {l_type=F_UNLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d, l_pid=0}) = 0\n",
 	       TEST_SYSCALL_STR, FILE_LEN);
 
 	invoke_test_syscall(0, F_OFD_SETLKW, fl);
+	pidns_print_leader();
 	printf("%s(0, F_OFD_SETLKW, {l_type=F_UNLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d}) = 0\n",
 	       TEST_SYSCALL_STR, FILE_LEN);
@@ -167,18 +179,21 @@ test_flock64(void)
 static long
 test_f_owner_ex_type_pid(const int cmd, const char *const cmd_name,
 			 const int type, const char *const type_name,
-			 pid_t pid)
+			 enum pid_type pid_type, pid_t pid)
 {
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct_kernel_f_owner_ex, fo);
 
 	fo->type = type;
 	fo->pid = pid;
 	long rc = invoke_test_syscall(0, cmd, fo);
-	printf("%s(0, %s, {type=%s, pid=%d}) = %s\n",
-	       TEST_SYSCALL_STR, cmd_name, type_name, fo->pid, errstr);
+	pidns_print_leader();
+	printf("%s(0, %s, {type=%s, pid=%d%s}) = %s\n",
+	       TEST_SYSCALL_STR, cmd_name, type_name,
+	       fo->pid, pidns_pid2str(pid_type), errstr);
 
 	void *bad_addr = (void *) fo + 1;
 	invoke_test_syscall(0, cmd, bad_addr);
+	pidns_print_leader();
 	printf("%s(0, %s, %p) = %s\n",
 	       TEST_SYSCALL_STR, cmd_name, bad_addr, errstr);
 
@@ -187,35 +202,35 @@ test_f_owner_ex_type_pid(const int cmd,
 
 static void
 test_f_owner_ex_umove_or_printaddr(const int type, const char *const type_name,
-				   pid_t pid)
+				   enum pid_type pid_type, pid_t pid)
 {
 	long rc = test_f_owner_ex_type_pid(ARG_STR(F_SETOWN_EX),
-					   type, type_name, pid);
+					   type, type_name, pid_type, pid);
 	if (!rc)
 		test_f_owner_ex_type_pid(ARG_STR(F_GETOWN_EX),
-					 type, type_name, pid);
+					 type, type_name, pid_type, pid);
 }
 
 static void
 test_f_owner_ex(void)
 {
-	static const struct {
+	struct {
 		int type;
 		const char *type_name;
-		pid_t pid[2];
+		enum pid_type pid_type;
+		pid_t pid;
 	} a[] = {
-		{ ARG_STR(F_OWNER_TID), { 1234567890, 20 } },
-		{ ARG_STR(F_OWNER_PID), { 1298126790, 30 } },
-		{ ARG_STR(F_OWNER_PGRP), { 1294567890, 40 } }
+		{ ARG_STR(F_OWNER_TID), PT_NONE, 1234567890 },
+		{ ARG_STR(F_OWNER_PID), PT_NONE, 1234567890 },
+		{ ARG_STR(F_OWNER_PGRP), PT_NONE, 1234567890 },
+		{ ARG_STR(F_OWNER_TID), PT_TID, syscall(__NR_gettid) },
+		{ ARG_STR(F_OWNER_PID), PT_TGID, getpid() },
+		{ ARG_STR(F_OWNER_PGRP), PT_PGID, getpgid(0) },
 	};
 
-	for (unsigned int i = 0; i < ARRAY_SIZE(a); i++) {
-		for (unsigned int j = 0; j < ARRAY_SIZE(a[0].pid); j++) {
-			test_f_owner_ex_umove_or_printaddr(a[i].type,
-							   a[i].type_name,
-							   a[i].pid[j]);
-		}
-	}
+	for (unsigned int i = 0; i < ARRAY_SIZE(a); i++)
+		test_f_owner_ex_umove_or_printaddr(a[i].type, a[i].type_name,
+			a[i].pid_type, a[i].pid);
 }
 #endif /* TEST_F_OWNER_EX */
 
@@ -229,6 +244,23 @@ struct fcntl_cmd_check {
 };
 
 static void
+test_xetown(void)
+{
+	const int pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
+
+	invoke_test_syscall(0, F_SETOWN, (void *) (intptr_t) pid);
+	pidns_print_leader();
+	printf("%s(0, F_SETOWN, %d%s) = %s\n",
+		TEST_SYSCALL_STR, pid, pid_str, errstr);
+
+	invoke_test_syscall(0, F_GETOWN, NULL);
+	pidns_print_leader();
+	printf("%s(0, F_GETOWN) = %d%s\n",
+		TEST_SYSCALL_STR, pid, pid_str);
+}
+
+static void
 print_retval_flags(const struct fcntl_cmd_check *check, long rc)
 {
 	if (check->print_flags) {
@@ -243,12 +275,14 @@ static void
 test_other_set_cmd(const struct fcntl_cmd_check *check)
 {
 	invoke_test_syscall(check->fd, check->cmd, (void *) check->arg);
+	pidns_print_leader();
 	printf("%s(%d, %s, %s) = %s\n",
 	       TEST_SYSCALL_STR, check->fd,
 	       check->cmd_str, check->arg_str, errstr);
 
 	/* bad file fd */
 	invoke_test_syscall(-1, check->cmd, (void *) check->arg);
+	pidns_print_leader();
 	printf("%s(-1, %s, %s) = %s\n",
 	       TEST_SYSCALL_STR, check->cmd_str,
 	       check->arg_str, errstr);
@@ -258,12 +292,14 @@ static void
 test_other_get_cmd(const struct fcntl_cmd_check *check)
 {
 	long rc = invoke_test_syscall(check->fd, check->cmd, NULL);
+	pidns_print_leader();
 	printf("%s(%d, %s) = ",
 	       TEST_SYSCALL_STR, check->fd, check->cmd_str);
 	print_retval_flags(check, rc);
 
 	/* bad file fd */
 	invoke_test_syscall(-1, check->cmd, NULL);
+	pidns_print_leader();
 	printf("%s(-1, %s) = %s\n",
 	       TEST_SYSCALL_STR, check->cmd_str, errstr);
 }
@@ -315,7 +351,6 @@ test_fcntl_others(void)
 {
 	static const struct fcntl_cmd_check set_checks[] = {
 		{ 0, ARG_STR(F_SETFD), ARG_STR(FD_CLOEXEC) },
-		{ 0, ARG_STR(F_SETOWN), ARG_STR(20) },
 #ifdef F_SETPIPE_SZ
 		{ 0, ARG_STR(F_SETPIPE_SZ), ARG_STR(4097) },
 #endif
@@ -336,7 +371,6 @@ test_fcntl_others(void)
 	static const struct fcntl_cmd_check get_checks[] = {
 		{ 0, ARG_STR(F_GETFD), .print_flags = print_flags_getfd },
 		{ 1, ARG_STR(F_GETFD), .print_flags = print_flags_getfd },
-		{ 0, ARG_STR(F_GETOWN) },
 #ifdef F_GETPIPE_SZ
 		{ 0, ARG_STR(F_GETPIPE_SZ) },
 #endif
@@ -352,20 +386,16 @@ test_fcntl_others(void)
 static void
 create_sample(void)
 {
-	char fname[] = TEST_SYSCALL_STR "_XXXXXX";
-
 	(void) close(0);
-	if (mkstemp(fname))
-		perror_msg_and_fail("mkstemp: %s", fname);
-	if (unlink(fname))
-		perror_msg_and_fail("unlink: %s", fname);
-	if (ftruncate(0, FILE_LEN))
+	if (ftruncate(create_tmpfile(O_RDWR), FILE_LEN))
 		perror_msg_and_fail("ftruncate");
 }
 
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	create_sample();
 	test_flock();
 	test_flock64();
@@ -373,7 +403,9 @@ main(void)
 	test_f_owner_ex();
 #endif
 	test_fcntl_others();
+	test_xetown();
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests/fcntl--pidns-translation.c 5.9-0ubuntu2/tests/fcntl--pidns-translation.c
--- 5.5-3/tests/fcntl--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/fcntl--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "fcntl.c"
diff -pruN 5.5-3/tests/fcntl--pidns-translation.gen.test 5.9-0ubuntu2/tests/fcntl--pidns-translation.gen.test
--- 5.5-3/tests/fcntl--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/fcntl--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (fcntl--pidns-translation test_pidns -a8 -e trace=fcntl); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a8 -e trace=fcntl
diff -pruN 5.5-3/tests/file_ioctl.c 5.9-0ubuntu2/tests/file_ioctl.c
--- 5.5-3/tests/file_ioctl.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/file_ioctl.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -11,6 +11,7 @@
 
 # include <stdio.h>
 # include <sys/ioctl.h>
+# include <linux/types.h>
 # include <linux/fiemap.h>
 # include <linux/fs.h>
 # include "xlat.h"
diff -pruN 5.5-3/tests/fill_memory.c 5.9-0ubuntu2/tests/fill_memory.c
--- 5.5-3/tests/fill_memory.c	2019-03-18 02:40:16.000000000 +0000
+++ 5.9-0ubuntu2/tests/fill_memory.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -24,3 +24,39 @@ fill_memory(void *ptr, size_t size)
 {
 	fill_memory_ex(ptr, size, 0x80, 0x80);
 }
+
+void
+fill_memory16_ex(void *ptr, size_t size, uint16_t start,
+	         unsigned int period)
+{
+	uint16_t *p = ptr;
+	size_t i;
+
+	for (i = 0; i < size / sizeof(uint16_t); i++) {
+		p[i] = start + i % period;
+	}
+}
+
+void
+fill_memory16(void *ptr, size_t size)
+{
+	fill_memory16_ex(ptr, size, 0x80c0, 0x8000);
+}
+
+void
+fill_memory32_ex(void *ptr, size_t size, uint32_t start,
+	         unsigned int period)
+{
+	uint32_t *p = ptr;
+	size_t i;
+
+	for (i = 0; i < size / sizeof(uint32_t); i++) {
+		p[i] = start + i % period;
+	}
+}
+
+void
+fill_memory32(void *ptr, size_t size)
+{
+	fill_memory32_ex(ptr, size, 0x80a0c0e0, 0x80000000);
+}
diff -pruN 5.5-3/tests/filter_seccomp-flag.c 5.9-0ubuntu2/tests/filter_seccomp-flag.c
--- 5.5-3/tests/filter_seccomp-flag.c	2019-11-15 22:33:53.000000000 +0000
+++ 5.9-0ubuntu2/tests/filter_seccomp-flag.c	2020-04-15 13:39:57.000000000 +0000
@@ -2,7 +2,7 @@
  * Check that syscall numbers do not conflict with seccomp filter flags.
  *
  * Copyright (c) 2019 Paul Chaignon <paul.chaignon@gmail.com>
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -22,12 +22,6 @@
 # undef XLAT_MACROS_ONLY
 #endif
 
-#ifdef __x86_64__
-# ifndef __X32_SYSCALL_BIT
-#  define __X32_SYSCALL_BIT     0x40000000
-# endif
-#endif
-
 /* Define these shorthand notations to simplify the syscallent files. */
 #include "sysent_shorthand_defs.h"
 
@@ -36,13 +30,13 @@ const struct_sysent sysent0[] = {
 };
 
 #if SUPPORTED_PERSONALITIES > 1
-static const struct_sysent sysent1[] = {
+const struct_sysent sysent1[] = {
 # include "syscallent1.h"
 };
 #endif
 
 #if SUPPORTED_PERSONALITIES > 2
-static const struct_sysent sysent2[] = {
+const struct_sysent sysent2[] = {
 # include "syscallent2.h"
 };
 #endif
diff -pruN 5.5-3/tests/fork--pidns-translation.awk 5.9-0ubuntu2/tests/fork--pidns-translation.awk
--- 5.5-3/tests/fork--pidns-translation.awk	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/fork--pidns-translation.awk	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,15 @@
+/fork/ {
+        match($0, "([0-9]+) in strace\x27s PID NS", a);
+        if (a[1])
+                fork_pid = a[1]
+}
+
+/exited with 0/ {
+        if (!exit_pid)
+                exit_pid = $1
+}
+
+END {
+        if (!fork_pid || !exit_pid || fork_pid != exit_pid)
+                exit 1
+}
diff -pruN 5.5-3/tests/fork--pidns-translation.c 5.9-0ubuntu2/tests/fork--pidns-translation.c
--- 5.5-3/tests/fork--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/fork--pidns-translation.c	2020-09-23 16:29:35.000000000 +0000
@@ -0,0 +1,78 @@
+/*
+ * Test PID namespace translation
+ *
+ * Copyright (c) 2020 Ákos Uzonyi <uzonyi.akos@gmail.com>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+#include "pidns.h"
+
+#ifdef __NR_fork
+
+# include <errno.h>
+# include <limits.h>
+# include <sched.h>
+# include <signal.h>
+# include <stdio.h>
+# include <stdlib.h>
+# include <sys/wait.h>
+# include <unistd.h>
+# include <linux/sched.h>
+# include "nsfs.h"
+
+# ifndef CLONE_NEWUSER
+#  define CLONE_NEWUSER 0x10000000
+# endif
+
+# ifndef CLONE_NEWPID
+#  define CLONE_NEWPID 0x20000000
+# endif
+
+static int
+fork_chain(int depth)
+{
+	if (!depth)
+		return 0;
+
+	int pid = syscall(__NR_fork);
+	if (pid < 0)
+		return errno;
+
+	if (!pid)
+		_exit(fork_chain(depth - 1));
+
+	int status;
+	if (wait(&status) < 0)
+		return errno;
+
+	if (!WIFEXITED(status))
+		return -1;
+
+	return WEXITSTATUS(status);
+}
+
+int main(void)
+{
+	check_ns_ioctl();
+
+	if (unshare(CLONE_NEWPID | CLONE_NEWUSER) < 0) {
+		if (errno == EPERM)
+			perror_msg_and_skip("unshare");
+
+		perror_msg_and_fail("unshare");
+	}
+
+	errno = fork_chain(2);
+	if (errno)
+		perror("fork_chain");
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_fork")
+
+#endif
diff -pruN 5.5-3/tests/fork--pidns-translation.test 5.9-0ubuntu2/tests/fork--pidns-translation.test
--- 5.5-3/tests/fork--pidns-translation.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/fork--pidns-translation.test	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,14 @@
+#!/bin/sh
+#
+# Check pidns translation of fork's return value.
+#
+# Copyright (c) 2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: LGPL-2.1-or-later
+
+. "${srcdir=.}/init.sh"
+
+run_prog
+run_strace -a6 --pidns-translation -f -e trace=fork $args
+match_awk
diff -pruN 5.5-3/tests/futex.c 5.9-0ubuntu2/tests/futex.c
--- 5.5-3/tests/futex.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/futex.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -495,7 +495,7 @@ main(int argc, char *argv[])
 	 *                 wake val2 processes waiting for uaddr2 in case
 	 *                 operation encoded in val3 (change of value at uaddr2
 	 *                 and comparison of previous value against provided
-	 *                 constant) succeedes with value at uaddr2. Operation
+	 *                 constant) succeeds with value at uaddr2. Operation
 	 *                 result is written to value of uaddr2 (in any case).
 	 * 1. uaddr   - futex address
 	 * 2. op      - FUTEX_WAKE_OP
diff -pruN 5.5-3/tests/gen_tests.am 5.9-0ubuntu2/tests/gen_tests.am
--- 5.5-3/tests/gen_tests.am	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests/gen_tests.am	2020-09-24 09:18:50.000000000 +0000
@@ -1,5 +1,5 @@
 # Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in; do not edit.
-GEN_TESTS = _newselect.gen.test _newselect-P.gen.test accept.gen.test accept4.gen.test access.gen.test acct.gen.test add_key.gen.test adjtimex.gen.test aio.gen.test aio_pgetevents.gen.test alarm.gen.test bpf.gen.test bpf-obj_get_info_by_fd.gen.test bpf-obj_get_info_by_fd-prog.gen.test bpf-obj_get_info_by_fd-prog-v.gen.test bpf-obj_get_info_by_fd-v.gen.test bpf-v.gen.test btrfs.gen.test chmod.gen.test chown.gen.test chown32.gen.test chroot.gen.test clock.gen.test clock_adjtime.gen.test clock_nanosleep.gen.test clock_xettime.gen.test clone3.gen.test clone3-Xabbrev.gen.test clone3-Xraw.gen.test clone3-Xverbose.gen.test clone3-success-Xabbrev.gen.test clone3-success-Xraw.gen.test clone3-success-Xverbose.gen.test copy_file_range.gen.test creat.gen.test delete_module.gen.test dev-yy.gen.test dup.gen.test dup2.gen.test dup3.gen.test epoll_create.gen.test epoll_create1.gen.test epoll_ctl.gen.test epoll_pwait.gen.test epoll_wait.gen.test erestartsys.gen.test execveat.gen.test execveat-v.gen.test faccessat.gen.test fadvise64_64.gen.test fallocate.gen.test fanotify_init.gen.test fanotify_mark.gen.test fanotify_mark-Xabbrev.gen.test fanotify_mark-Xraw.gen.test fanotify_mark-Xverbose.gen.test fchdir.gen.test fchmod.gen.test fchmodat.gen.test fchown.gen.test fchown32.gen.test fchownat.gen.test fcntl.gen.test fcntl64.gen.test fdatasync.gen.test file_handle.gen.test file_ioctl.gen.test filter_seccomp.gen.test filter_seccomp-flag.gen.test finit_module.gen.test flock.gen.test fork-f.gen.test fsconfig.gen.test fsconfig-P.gen.test fsmount.gen.test fsopen.gen.test fspick.gen.test fspick-P.gen.test fstat.gen.test fstat-Xabbrev.gen.test fstat-Xraw.gen.test fstat-Xverbose.gen.test fstat64.gen.test fstat64-Xabbrev.gen.test fstat64-Xraw.gen.test fstat64-Xverbose.gen.test fstatat64.gen.test fstatfs.gen.test fstatfs64.gen.test fsync.gen.test fsync-y.gen.test ftruncate.gen.test ftruncate64.gen.test futimesat.gen.test get_mempolicy.gen.test getcpu.gen.test getcwd.gen.test getdents.gen.test getdents64.gen.test getegid.gen.test getegid-creds.gen.test getegid32.gen.test getegid32-creds.gen.test geteuid.gen.test geteuid-creds.gen.test geteuid32.gen.test geteuid32-creds.gen.test getgid.gen.test getgid-creds.gen.test getgid32.gen.test getgid32-creds.gen.test getgroups.gen.test getgroups32.gen.test getpeername.gen.test getpgrp.gen.test getpid.gen.test getppid.gen.test getrandom.gen.test getresgid.gen.test getresgid32.gen.test getresuid.gen.test getresuid32.gen.test getrlimit.gen.test getrusage.gen.test getsid.gen.test getsockname.gen.test gettid.gen.test getuid-creds.gen.test getuid32.gen.test getuid32-creds.gen.test getxxid.gen.test group_req.gen.test inet-cmsg.gen.test init_module.gen.test inotify.gen.test inotify_init.gen.test inotify_init1.gen.test inotify_init1-y.gen.test io_uring_enter.gen.test io_uring_register.gen.test io_uring_setup.gen.test ioctl_block.gen.test ioctl_dm.gen.test ioctl_dm-v.gen.test ioctl_evdev.gen.test ioctl_evdev-Xabbrev.gen.test ioctl_evdev-Xraw.gen.test ioctl_evdev-Xverbose.gen.test ioctl_evdev-v.gen.test ioctl_evdev-v-Xabbrev.gen.test ioctl_evdev-v-Xraw.gen.test ioctl_evdev-v-Xverbose.gen.test ioctl_evdev-success-Xabbrev.gen.test ioctl_evdev-success-Xraw.gen.test ioctl_evdev-success-Xverbose.gen.test ioctl_evdev-success-v.gen.test ioctl_evdev-success-v-Xabbrev.gen.test ioctl_evdev-success-v-Xraw.gen.test ioctl_evdev-success-v-Xverbose.gen.test ioctl_inotify.gen.test ioctl_kvm_run.gen.test ioctl_kvm_run-v.gen.test ioctl_kvm_run_auxstr_vcpu.gen.test ioctl_loop.gen.test ioctl_loop-nv.gen.test ioctl_loop-v.gen.test ioctl_mtd.gen.test ioctl_nbd.gen.test ioctl_nsfs.gen.test ioctl_perf.gen.test ioctl_ptp.gen.test ioctl_random.gen.test ioctl_rtc.gen.test ioctl_rtc-v.gen.test ioctl_scsi.gen.test ioctl_sg_io_v3.gen.test ioctl_sg_io_v4.gen.test ioctl_sock_gifconf.gen.test ioctl_uffdio.gen.test ioctl_v4l2.gen.test ioctl_watchdog.gen.test ioperm.gen.test iopl.gen.test ioprio.gen.test ioprio-Xabbrev.gen.test ioprio-Xraw.gen.test ioprio-Xverbose.gen.test ip_mreq.gen.test ipc.gen.test ipc_msg.gen.test ipc_msg-Xabbrev.gen.test ipc_msg-Xraw.gen.test ipc_msg-Xverbose.gen.test ipc_msgbuf-Xabbrev.gen.test ipc_msgbuf-Xraw.gen.test ipc_msgbuf-Xverbose.gen.test ipc_sem.gen.test ipc_sem-Xabbrev.gen.test ipc_sem-Xraw.gen.test ipc_sem-Xverbose.gen.test ipc_shm.gen.test ipc_shm-Xabbrev.gen.test ipc_shm-Xraw.gen.test ipc_shm-Xverbose.gen.test kcmp.gen.test kcmp-y.gen.test kern_features.gen.test kernel_version.gen.test kernel_version-Xabbrev.gen.test kernel_version-Xraw.gen.test kernel_version-Xverbose.gen.test kexec_file_load.gen.test kexec_load.gen.test keyctl.gen.test keyctl-Xabbrev.gen.test keyctl-Xraw.gen.test keyctl-Xverbose.gen.test kill.gen.test ksysent.gen.test lchown.gen.test lchown32.gen.test link.gen.test linkat.gen.test lookup_dcookie.gen.test lstat.gen.test lstat64.gen.test madvise.gen.test maybe_switch_current_tcp.gen.test mbind.gen.test mbind-Xabbrev.gen.test mbind-Xraw.gen.test mbind-Xverbose.gen.test membarrier.gen.test memfd_create.gen.test memfd_create-Xabbrev.gen.test memfd_create-Xraw.gen.test memfd_create-Xverbose.gen.test migrate_pages.gen.test mincore.gen.test mkdir.gen.test mkdirat.gen.test mknod.gen.test mknodat.gen.test mlock.gen.test mlock2.gen.test mlockall.gen.test mmap-Xabbrev.gen.test mmap-Xraw.gen.test mmap-Xverbose.gen.test mmap64.gen.test mmap64-Xabbrev.gen.test mmap64-Xraw.gen.test mmap64-Xverbose.gen.test mmsg.gen.test mmsg-silent.gen.test mmsg_name.gen.test mmsg_name-v.gen.test modify_ldt.gen.test mount.gen.test mount-Xabbrev.gen.test mount-Xraw.gen.test mount-Xverbose.gen.test move_mount.gen.test move_mount-P.gen.test move_pages.gen.test move_pages-Xabbrev.gen.test move_pages-Xraw.gen.test move_pages-Xverbose.gen.test mq.gen.test mq_sendrecv.gen.test mq_sendrecv-read.gen.test mq_sendrecv-write.gen.test msg_control.gen.test msg_control-v.gen.test msg_name.gen.test munlockall.gen.test nanosleep.gen.test net-icmp_filter.gen.test net-packet_mreq.gen.test net-packet_mreq-Xabbrev.gen.test net-packet_mreq-Xraw.gen.test net-packet_mreq-Xverbose.gen.test net-sockaddr.gen.test net-tpacket_req.gen.test net-tpacket_stats.gen.test net-yy-inet6.gen.test netlink_audit.gen.test netlink_crypto.gen.test netlink_generic.gen.test netlink_kobject_uevent.gen.test netlink_netfilter.gen.test netlink_protocol.gen.test netlink_route.gen.test netlink_selinux.gen.test netlink_xfrm.gen.test newfstatat.gen.test nfnetlink_acct.gen.test nfnetlink_cthelper.gen.test nfnetlink_ctnetlink.gen.test nfnetlink_ctnetlink_exp.gen.test nfnetlink_cttimeout.gen.test nfnetlink_ipset.gen.test nfnetlink_nft_compat.gen.test nfnetlink_nftables.gen.test nfnetlink_osf.gen.test nfnetlink_queue.gen.test nfnetlink_ulog.gen.test nlattr.gen.test nlattr_br_port_msg.gen.test nlattr_crypto_user_alg.gen.test nlattr_dcbmsg.gen.test nlattr_fib_rule_hdr.gen.test nlattr_ifaddrlblmsg.gen.test nlattr_ifaddrmsg.gen.test nlattr_ifinfomsg.gen.test nlattr_ifla_af_spec.gen.test nlattr_ifla_brport.gen.test nlattr_ifla_linkinfo.gen.test nlattr_ifla_port.gen.test nlattr_ifla_xdp.gen.test nlattr_inet_diag_msg.gen.test nlattr_inet_diag_req_compat.gen.test nlattr_inet_diag_req_v2.gen.test nlattr_mdba_mdb_entry.gen.test nlattr_mdba_router_port.gen.test nlattr_ndmsg.gen.test nlattr_ndtmsg.gen.test nlattr_netconfmsg.gen.test nlattr_netlink_diag_msg.gen.test nlattr_nlmsgerr.gen.test nlattr_packet_diag_msg.gen.test nlattr_rtgenmsg.gen.test nlattr_rtmsg.gen.test nlattr_smc_diag_msg.gen.test nlattr_tc_stats.gen.test nlattr_tca_stab.gen.test nlattr_tcamsg.gen.test nlattr_tcmsg.gen.test nlattr_unix_diag_msg.gen.test old_mmap.gen.test old_mmap-P.gen.test old_mmap-Xabbrev.gen.test old_mmap-Xraw.gen.test old_mmap-Xverbose.gen.test old_mmap-v-none.gen.test oldfstat.gen.test oldlstat.gen.test oldselect.gen.test oldselect-P.gen.test oldselect-efault.gen.test oldselect-efault-P.gen.test oldstat.gen.test open.gen.test open_tree.gen.test open_tree-P.gen.test openat.gen.test orphaned_process_group.gen.test osf_utimes.gen.test pause.gen.test perf_event_open.gen.test perf_event_open_nonverbose.gen.test perf_event_open_unabbrev.gen.test personality-Xabbrev.gen.test personality-Xraw.gen.test personality-Xverbose.gen.test pidfd_open.gen.test pidfd_open-P.gen.test pidfd_open-y.gen.test pidfd_send_signal.gen.test pipe2.gen.test pkey_alloc.gen.test pkey_free.gen.test pkey_mprotect.gen.test ppoll.gen.test ppoll-P.gen.test ppoll-v.gen.test pread64-pwrite64.gen.test preadv.gen.test preadv-pwritev.gen.test preadv2-pwritev2.gen.test printpath-umovestr.gen.test printpath-umovestr-peekdata.gen.test printpath-umovestr-undumpable.gen.test printsignal-Xabbrev.gen.test printsignal-Xraw.gen.test printsignal-Xverbose.gen.test printstr.gen.test printstrn-umoven.gen.test printstrn-umoven-peekdata.gen.test printstrn-umoven-undumpable.gen.test prlimit64.gen.test process_vm_readv.gen.test process_vm_writev.gen.test pselect6.gen.test ptrace.gen.test ptrace_syscall_info.gen.test pwritev.gen.test quotactl.gen.test quotactl-Xabbrev.gen.test quotactl-Xraw.gen.test quotactl-Xverbose.gen.test quotactl-v.gen.test quotactl-xfs.gen.test quotactl-xfs-v.gen.test read-write.gen.test readahead.gen.test readdir.gen.test readlink.gen.test readlinkat.gen.test reboot.gen.test recv-MSG_TRUNC.gen.test recvfrom.gen.test recvfrom-MSG_TRUNC.gen.test recvmmsg-timeout.gen.test recvmsg.gen.test regex.gen.test remap_file_pages.gen.test remap_file_pages-Xabbrev.gen.test remap_file_pages-Xraw.gen.test remap_file_pages-Xverbose.gen.test rename.gen.test renameat.gen.test renameat2.gen.test request_key.gen.test riscv_flush_icache.gen.test rmdir.gen.test rt_sigpending.gen.test rt_sigprocmask.gen.test rt_sigqueueinfo.gen.test rt_sigreturn.gen.test rt_sigsuspend.gen.test rt_sigtimedwait.gen.test rt_tgsigqueueinfo.gen.test s390_guarded_storage.gen.test s390_guarded_storage-v.gen.test s390_pci_mmio_read_write.gen.test s390_runtime_instr.gen.test s390_sthyi.gen.test s390_sthyi-v.gen.test sched.gen.test sched_get_priority_mxx.gen.test sched_rr_get_interval.gen.test sched_xetaffinity.gen.test sched_xetattr.gen.test sched_xetparam.gen.test sched_xetscheduler.gen.test sched_yield.gen.test seccomp-filter.gen.test seccomp-filter-v.gen.test seccomp_get_action_avail.gen.test select.gen.test select-P.gen.test semop.gen.test semop-indirect.gen.test semtimedop.gen.test sendfile.gen.test sendfile64.gen.test set_mempolicy.gen.test set_mempolicy-Xabbrev.gen.test set_mempolicy-Xraw.gen.test set_mempolicy-Xverbose.gen.test setdomainname.gen.test setfsgid.gen.test setfsgid32.gen.test setfsuid.gen.test setfsuid32.gen.test setgid.gen.test setgid32.gen.test setgroups.gen.test setgroups32.gen.test sethostname.gen.test setns.gen.test setregid.gen.test setregid32.gen.test setresgid.gen.test setresgid32.gen.test setresuid.gen.test setresuid32.gen.test setreuid.gen.test setreuid32.gen.test setrlimit.gen.test setrlimit-Xabbrev.gen.test setrlimit-Xraw.gen.test setrlimit-Xverbose.gen.test setuid.gen.test setuid32.gen.test shmxt.gen.test shutdown.gen.test sigaction.gen.test siginfo.gen.test signal.gen.test signal_receive.gen.test signalfd4.gen.test sigpending.gen.test sigprocmask.gen.test sigreturn.gen.test sigsuspend.gen.test so_error.gen.test so_linger.gen.test so_peercred.gen.test so_peercred-Xabbrev.gen.test so_peercred-Xraw.gen.test so_peercred-Xverbose.gen.test sock_filter-v.gen.test sock_filter-v-Xabbrev.gen.test sock_filter-v-Xraw.gen.test sock_filter-v-Xverbose.gen.test sockaddr_xlat-Xabbrev.gen.test sockaddr_xlat-Xraw.gen.test sockaddr_xlat-Xverbose.gen.test socketcall.gen.test sockopt-sol_netlink.gen.test sockopt-timestamp.gen.test splice.gen.test stat.gen.test stat64.gen.test statfs.gen.test statfs64.gen.test status-all.gen.test status-failed.gen.test status-none.gen.test status-successful.gen.test status-unfinished.gen.test statx.gen.test swap.gen.test sxetmask.gen.test symlink.gen.test symlinkat.gen.test sync.gen.test sync_file_range.gen.test sync_file_range2.gen.test sysinfo.gen.test syslog.gen.test tee.gen.test time.gen.test timer_create.gen.test timer_xettime.gen.test timerfd_xettime.gen.test times.gen.test times-fail.gen.test trace_creds.gen.test trace_fstat.gen.test trace_fstatfs.gen.test trace_lstat.gen.test trace_personality_32.gen.test trace_personality_64.gen.test trace_personality_regex_32.gen.test trace_personality_regex_64.gen.test trace_personality_regex_x32.gen.test trace_personality_x32.gen.test trace_question.gen.test trace_stat.gen.test trace_stat_like.gen.test trace_statfs.gen.test trace_statfs_like.gen.test truncate.gen.test truncate64.gen.test ugetrlimit.gen.test umask.gen.test umoven-illptr.gen.test umovestr-illptr.gen.test umovestr3.gen.test unlink.gen.test unlinkat.gen.test unshare.gen.test userfaultfd.gen.test ustat.gen.test utime.gen.test utimensat.gen.test utimensat-Xabbrev.gen.test utimensat-Xraw.gen.test utimensat-Xverbose.gen.test utimes.gen.test vfork-f.gen.test vhangup.gen.test vmsplice.gen.test wait4.gen.test wait4-v.gen.test waitid.gen.test waitid-v.gen.test waitpid.gen.test xattr.gen.test xattr-strings.gen.test xet_robust_list.gen.test xetitimer.gen.test xetpgid.gen.test xetpriority.gen.test xettimeofday.gen.test
+GEN_TESTS = _newselect.gen.test _newselect-P.gen.test accept.gen.test accept4.gen.test access.gen.test acct.gen.test add_key.gen.test adjtimex.gen.test aio.gen.test aio_pgetevents.gen.test alarm.gen.test bpf.gen.test bpf-obj_get_info_by_fd.gen.test bpf-obj_get_info_by_fd-prog.gen.test bpf-obj_get_info_by_fd-prog-v.gen.test bpf-obj_get_info_by_fd-v.gen.test bpf-v.gen.test btrfs.gen.test chmod.gen.test chown.gen.test chown32.gen.test chroot.gen.test clock.gen.test clock_adjtime.gen.test clock_nanosleep.gen.test clock_xettime.gen.test clone3.gen.test clone3-Xabbrev.gen.test clone3-Xraw.gen.test clone3-Xverbose.gen.test clone3-success-Xabbrev.gen.test clone3-success-Xraw.gen.test clone3-success-Xverbose.gen.test clone_parent.gen.test clone_parent--quiet-exit.gen.test clone_parent-q.gen.test clone_parent-qq.gen.test clone_ptrace--quiet-attach.gen.test clone_ptrace--quiet-exit.gen.test clone_ptrace-q.gen.test clone_ptrace-qq.gen.test close_range.gen.test close_range-P.gen.test close_range-y.gen.test close_range-yy.gen.test copy_file_range.gen.test creat.gen.test delete_module.gen.test dev--decode-fds-dev.gen.test dev--decode-fds-path.gen.test dev--decode-fds-socket.gen.test dev-yy.gen.test dup.gen.test dup-P.gen.test dup-y.gen.test dup-yy.gen.test dup2.gen.test dup2-P.gen.test dup2-y.gen.test dup2-yy.gen.test dup3.gen.test dup3-P.gen.test dup3-y.gen.test dup3-yy.gen.test epoll_create.gen.test epoll_create1.gen.test epoll_ctl.gen.test epoll_pwait.gen.test epoll_wait.gen.test erestartsys.gen.test execveat.gen.test execveat-v.gen.test faccessat-P.gen.test faccessat-y.gen.test faccessat-yy.gen.test faccessat2-P.gen.test faccessat2-y.gen.test faccessat2-yy.gen.test fadvise64_64.gen.test fallocate.gen.test fanotify_init.gen.test fanotify_mark.gen.test fanotify_mark-Xabbrev.gen.test fanotify_mark-Xraw.gen.test fanotify_mark-Xverbose.gen.test fchdir.gen.test fchmod.gen.test fchmodat.gen.test fchown.gen.test fchown32.gen.test fchownat.gen.test fcntl.gen.test fcntl--pidns-translation.gen.test fcntl64.gen.test fcntl64--pidns-translation.gen.test fdatasync.gen.test file_handle.gen.test file_ioctl.gen.test filter_seccomp.gen.test filter_seccomp-flag.gen.test finit_module.gen.test flock.gen.test fork-f.gen.test fsconfig.gen.test fsconfig-P.gen.test fsmount.gen.test fsopen.gen.test fspick.gen.test fspick-P.gen.test fstat.gen.test fstat-Xabbrev.gen.test fstat-Xraw.gen.test fstat-Xverbose.gen.test fstat64.gen.test fstat64-Xabbrev.gen.test fstat64-Xraw.gen.test fstat64-Xverbose.gen.test fstatat64.gen.test fstatfs.gen.test fstatfs64.gen.test fsync.gen.test fsync-y.gen.test ftruncate.gen.test ftruncate64.gen.test futimesat.gen.test get_mempolicy.gen.test getcpu.gen.test getcwd.gen.test getdents.gen.test getdents-v.gen.test getdents64.gen.test getdents64-v.gen.test getegid.gen.test getegid-creds.gen.test getegid32.gen.test getegid32-creds.gen.test geteuid.gen.test geteuid-creds.gen.test geteuid32.gen.test geteuid32-creds.gen.test getgid.gen.test getgid-creds.gen.test getgid32.gen.test getgid32-creds.gen.test getgroups.gen.test getgroups32.gen.test getpeername.gen.test getpgrp.gen.test getpgrp--pidns-translation.gen.test getpid.gen.test getpid--pidns-translation.gen.test getppid.gen.test getrandom.gen.test getresgid.gen.test getresgid32.gen.test getresuid.gen.test getresuid32.gen.test getrlimit.gen.test getrusage.gen.test getsid.gen.test getsid--pidns-translation.gen.test getsockname.gen.test gettid.gen.test getuid-creds.gen.test getuid32.gen.test getuid32-creds.gen.test getxgid.gen.test getxpid.gen.test getxuid.gen.test group_req.gen.test inet-cmsg.gen.test init_module.gen.test inotify.gen.test inotify_init.gen.test inotify_init1.gen.test inotify_init1-y.gen.test io_uring_enter.gen.test io_uring_register.gen.test io_uring_setup.gen.test ioctl_block.gen.test ioctl_dm.gen.test ioctl_dm-v.gen.test ioctl_evdev.gen.test ioctl_evdev-Xabbrev.gen.test ioctl_evdev-Xraw.gen.test ioctl_evdev-Xverbose.gen.test ioctl_evdev-v.gen.test ioctl_evdev-v-Xabbrev.gen.test ioctl_evdev-v-Xraw.gen.test ioctl_evdev-v-Xverbose.gen.test ioctl_evdev-success-Xabbrev.gen.test ioctl_evdev-success-Xraw.gen.test ioctl_evdev-success-Xverbose.gen.test ioctl_evdev-success-v.gen.test ioctl_evdev-success-v-Xabbrev.gen.test ioctl_evdev-success-v-Xraw.gen.test ioctl_evdev-success-v-Xverbose.gen.test ioctl_hdio.gen.test ioctl_hdio-Xabbrev.gen.test ioctl_hdio-Xraw.gen.test ioctl_hdio-Xverbose.gen.test ioctl_hdio-v.gen.test ioctl_hdio-v-Xabbrev.gen.test ioctl_hdio-v-Xraw.gen.test ioctl_hdio-v-Xverbose.gen.test ioctl_hdio-success.gen.test ioctl_hdio-success-Xabbrev.gen.test ioctl_hdio-success-Xraw.gen.test ioctl_hdio-success-Xverbose.gen.test ioctl_hdio-success-v.gen.test ioctl_hdio-success-v-Xabbrev.gen.test ioctl_hdio-success-v-Xraw.gen.test ioctl_hdio-success-v-Xverbose.gen.test ioctl_inotify.gen.test ioctl_kvm_run.gen.test ioctl_kvm_run-v.gen.test ioctl_kvm_run_auxstr_vcpu.gen.test ioctl_loop.gen.test ioctl_loop-nv.gen.test ioctl_loop-v.gen.test ioctl_mtd.gen.test ioctl_nbd.gen.test ioctl_nsfs.gen.test ioctl_perf.gen.test ioctl_perf-success.gen.test ioctl_ptp.gen.test ioctl_random.gen.test ioctl_rtc.gen.test ioctl_rtc-v.gen.test ioctl_scsi.gen.test ioctl_sg_io_v3.gen.test ioctl_sg_io_v4.gen.test ioctl_sock_gifconf.gen.test ioctl_tee.gen.test ioctl_uffdio.gen.test ioctl_v4l2.gen.test ioctl_v4l2-Xabbrev.gen.test ioctl_v4l2-Xraw.gen.test ioctl_v4l2-Xverbose.gen.test ioctl_v4l2-v.gen.test ioctl_v4l2-v-Xabbrev.gen.test ioctl_v4l2-v-Xraw.gen.test ioctl_v4l2-v-Xverbose.gen.test ioctl_v4l2-success.gen.test ioctl_v4l2-success-Xabbrev.gen.test ioctl_v4l2-success-Xraw.gen.test ioctl_v4l2-success-Xverbose.gen.test ioctl_v4l2-success-v.gen.test ioctl_v4l2-success-v-Xabbrev.gen.test ioctl_v4l2-success-v-Xraw.gen.test ioctl_v4l2-success-v-Xverbose.gen.test ioctl_watchdog.gen.test ioperm.gen.test iopl.gen.test ioprio.gen.test ioprio--pidns-translation.gen.test ioprio-Xabbrev.gen.test ioprio-Xraw.gen.test ioprio-Xverbose.gen.test ip_mreq.gen.test ipc.gen.test ipc_msg.gen.test ipc_msg-Xabbrev.gen.test ipc_msg-Xraw.gen.test ipc_msg-Xverbose.gen.test ipc_msgbuf-Xabbrev.gen.test ipc_msgbuf-Xraw.gen.test ipc_msgbuf-Xverbose.gen.test ipc_sem.gen.test ipc_sem-Xabbrev.gen.test ipc_sem-Xraw.gen.test ipc_sem-Xverbose.gen.test ipc_shm.gen.test ipc_shm-Xabbrev.gen.test ipc_shm-Xraw.gen.test ipc_shm-Xverbose.gen.test kcmp.gen.test kcmp-y.gen.test kcmp-y--pidns-translation.gen.test kern_features.gen.test kernel_version.gen.test kernel_version-Xabbrev.gen.test kernel_version-Xraw.gen.test kernel_version-Xverbose.gen.test kexec_file_load.gen.test kexec_load.gen.test keyctl.gen.test keyctl-Xabbrev.gen.test keyctl-Xraw.gen.test keyctl-Xverbose.gen.test kill.gen.test kill--pidns-translation.gen.test ksysent.gen.test lchown.gen.test lchown32.gen.test link.gen.test linkat.gen.test lookup_dcookie.gen.test lstat.gen.test lstat64.gen.test madvise.gen.test maybe_switch_current_tcp.gen.test maybe_switch_current_tcp--quiet-thread-execve.gen.test mbind.gen.test mbind-Xabbrev.gen.test mbind-Xraw.gen.test mbind-Xverbose.gen.test membarrier.gen.test memfd_create.gen.test memfd_create-Xabbrev.gen.test memfd_create-Xraw.gen.test memfd_create-Xverbose.gen.test migrate_pages.gen.test migrate_pages--pidns-translation.gen.test mincore.gen.test mkdir.gen.test mkdirat.gen.test mknod.gen.test mknodat.gen.test mlock.gen.test mlock2.gen.test mlockall.gen.test mmap-Xabbrev.gen.test mmap-Xraw.gen.test mmap-Xverbose.gen.test mmap64.gen.test mmap64-Xabbrev.gen.test mmap64-Xraw.gen.test mmap64-Xverbose.gen.test mmsg.gen.test mmsg-silent.gen.test mmsg_name.gen.test mmsg_name-v.gen.test modify_ldt.gen.test mount.gen.test mount-Xabbrev.gen.test mount-Xraw.gen.test mount-Xverbose.gen.test move_mount.gen.test move_mount-P.gen.test move_pages.gen.test move_pages-Xabbrev.gen.test move_pages-Xraw.gen.test move_pages-Xverbose.gen.test move_pages--pidns-translation.gen.test mq.gen.test mq_sendrecv.gen.test mq_sendrecv-read.gen.test mq_sendrecv-write.gen.test msg_control.gen.test msg_control-v.gen.test msg_name.gen.test munlockall.gen.test nanosleep.gen.test net--decode-fds-dev-netlink.gen.test net--decode-fds-none-netlink.gen.test net--decode-fds-path-netlink.gen.test net--decode-fds-socket-netlink.gen.test net-icmp_filter.gen.test net-packet_mreq.gen.test net-packet_mreq-Xabbrev.gen.test net-packet_mreq-Xraw.gen.test net-packet_mreq-Xverbose.gen.test net-sockaddr.gen.test net-sockaddr--pidns-translation.gen.test net-tpacket_req.gen.test net-tpacket_stats.gen.test net-yy-inet6.gen.test netlink_audit.gen.test netlink_crypto.gen.test netlink_generic.gen.test netlink_kobject_uevent.gen.test netlink_netfilter.gen.test netlink_protocol.gen.test netlink_route.gen.test netlink_selinux.gen.test netlink_xfrm.gen.test newfstatat.gen.test nfnetlink_acct.gen.test nfnetlink_cthelper.gen.test nfnetlink_ctnetlink.gen.test nfnetlink_ctnetlink_exp.gen.test nfnetlink_cttimeout.gen.test nfnetlink_ipset.gen.test nfnetlink_nft_compat.gen.test nfnetlink_nftables.gen.test nfnetlink_osf.gen.test nfnetlink_queue.gen.test nfnetlink_ulog.gen.test nlattr.gen.test nlattr_br_port_msg.gen.test nlattr_crypto_user_alg.gen.test nlattr_dcbmsg.gen.test nlattr_fib_rule_hdr.gen.test nlattr_ifaddrlblmsg.gen.test nlattr_ifaddrmsg.gen.test nlattr_ifinfomsg.gen.test nlattr_ifla_af_spec.gen.test nlattr_ifla_brport.gen.test nlattr_ifla_linkinfo.gen.test nlattr_ifla_port.gen.test nlattr_ifla_xdp.gen.test nlattr_ifla_xdp-y.gen.test nlattr_inet_diag_msg.gen.test nlattr_inet_diag_req_compat.gen.test nlattr_inet_diag_req_v2.gen.test nlattr_mdba_mdb_entry.gen.test nlattr_mdba_router_port.gen.test nlattr_ndmsg.gen.test nlattr_ndtmsg.gen.test nlattr_netconfmsg.gen.test nlattr_netlink_diag_msg.gen.test nlattr_nlmsgerr.gen.test nlattr_packet_diag_msg.gen.test nlattr_rtgenmsg.gen.test nlattr_rtmsg.gen.test nlattr_smc_diag_msg.gen.test nlattr_tc_stats.gen.test nlattr_tca_stab.gen.test nlattr_tcamsg.gen.test nlattr_tcmsg.gen.test nlattr_unix_diag_msg.gen.test old_mmap.gen.test old_mmap-P.gen.test old_mmap-Xabbrev.gen.test old_mmap-Xraw.gen.test old_mmap-Xverbose.gen.test old_mmap-v-none.gen.test oldfstat.gen.test oldlstat.gen.test oldselect.gen.test oldselect-P.gen.test oldselect-efault.gen.test oldselect-efault-P.gen.test oldstat.gen.test open.gen.test open_tree.gen.test open_tree-P.gen.test openat.gen.test openat2.gen.test openat2-Xabbrev.gen.test openat2-Xraw.gen.test openat2-Xverbose.gen.test openat2-v.gen.test openat2-v-y.gen.test openat2-v-y-Xabbrev.gen.test openat2-v-y-Xraw.gen.test openat2-v-y-Xverbose.gen.test openat2-y.gen.test orphaned_process_group.gen.test osf_utimes.gen.test pause.gen.test perf_event_open.gen.test perf_event_open_nonverbose.gen.test perf_event_open_unabbrev.gen.test personality-Xabbrev.gen.test personality-Xraw.gen.test personality-Xverbose.gen.test pidfd_getfd.gen.test pidfd_getfd-y.gen.test pidfd_getfd-yy.gen.test pidfd_open.gen.test pidfd_open--decode-fd-path.gen.test pidfd_open--decode-fd-pidfd.gen.test pidfd_open--decode-fd-socket.gen.test pidfd_open-P.gen.test pidfd_open-y.gen.test pidfd_open-yy.gen.test pidfd_open--pidns-translation.gen.test pidfd_send_signal.gen.test pidfd_send_signal--pidns-translation.gen.test pipe2.gen.test pkey_alloc.gen.test pkey_free.gen.test pkey_mprotect.gen.test ppoll.gen.test ppoll-P.gen.test ppoll-v.gen.test pread64-pwrite64.gen.test preadv.gen.test preadv-pwritev.gen.test preadv2-pwritev2.gen.test printpath-umovestr.gen.test printpath-umovestr-peekdata.gen.test printpath-umovestr-undumpable.gen.test printsignal-Xabbrev.gen.test printsignal-Xraw.gen.test printsignal-Xverbose.gen.test printstr.gen.test printstrn-umoven.gen.test printstrn-umoven-peekdata.gen.test printstrn-umoven-undumpable.gen.test prlimit64.gen.test prlimit64--pidns-translation.gen.test process_vm_readv.gen.test process_vm_readv--pidns-translation.gen.test process_vm_writev.gen.test process_vm_writev--pidns-translation.gen.test pselect6.gen.test ptrace.gen.test ptrace_syscall_info.gen.test pwritev.gen.test quotactl.gen.test quotactl-Xabbrev.gen.test quotactl-Xraw.gen.test quotactl-Xverbose.gen.test quotactl-v.gen.test quotactl-xfs.gen.test quotactl-xfs-v.gen.test read-write.gen.test readahead.gen.test readdir.gen.test readlink.gen.test readlinkat.gen.test reboot.gen.test recv-MSG_TRUNC.gen.test recvfrom.gen.test recvfrom-MSG_TRUNC.gen.test recvmmsg-timeout.gen.test recvmsg.gen.test regex.gen.test remap_file_pages.gen.test remap_file_pages-Xabbrev.gen.test remap_file_pages-Xraw.gen.test remap_file_pages-Xverbose.gen.test rename.gen.test renameat.gen.test renameat2.gen.test request_key.gen.test riscv_flush_icache.gen.test rmdir.gen.test rt_sigpending.gen.test rt_sigprocmask.gen.test rt_sigqueueinfo.gen.test rt_sigqueueinfo--pidns-translation.gen.test rt_sigreturn.gen.test rt_sigsuspend.gen.test rt_sigtimedwait.gen.test rt_tgsigqueueinfo.gen.test rt_tgsigqueueinfo--pidns-translation.gen.test s390_guarded_storage.gen.test s390_guarded_storage-v.gen.test s390_pci_mmio_read_write.gen.test s390_runtime_instr.gen.test s390_sthyi.gen.test s390_sthyi-v.gen.test sched.gen.test sched_get_priority_mxx.gen.test sched_rr_get_interval.gen.test sched_xetaffinity.gen.test sched_xetaffinity--pidns-translation.gen.test sched_xetattr.gen.test sched_xetattr--pidns-translation.gen.test sched_xetparam.gen.test sched_xetparam--pidns-translation.gen.test sched_xetscheduler.gen.test sched_xetscheduler--pidns-translation.gen.test sched_yield.gen.test seccomp-filter.gen.test seccomp-filter-v.gen.test seccomp_get_action_avail.gen.test select.gen.test select-P.gen.test semop.gen.test semop-indirect.gen.test semtimedop.gen.test sendfile.gen.test sendfile64.gen.test set_mempolicy.gen.test set_mempolicy-Xabbrev.gen.test set_mempolicy-Xraw.gen.test set_mempolicy-Xverbose.gen.test setdomainname.gen.test setfsgid.gen.test setfsgid32.gen.test setfsuid.gen.test setfsuid32.gen.test setgid.gen.test setgid32.gen.test setgroups.gen.test setgroups32.gen.test sethostname.gen.test setns.gen.test setregid.gen.test setregid32.gen.test setresgid.gen.test setresgid32.gen.test setresuid.gen.test setresuid32.gen.test setreuid.gen.test setreuid32.gen.test setrlimit.gen.test setrlimit-Xabbrev.gen.test setrlimit-Xraw.gen.test setrlimit-Xverbose.gen.test setuid.gen.test setuid32.gen.test shmxt.gen.test shutdown.gen.test sigaction.gen.test siginfo.gen.test signal.gen.test signal_receive.gen.test signal_receive--pidns-translation.gen.test signalfd4.gen.test sigpending.gen.test sigprocmask.gen.test sigreturn.gen.test sigsuspend.gen.test so_error.gen.test so_linger.gen.test so_peercred.gen.test so_peercred-Xabbrev.gen.test so_peercred-Xraw.gen.test so_peercred-Xverbose.gen.test so_peercred--pidns-translation.gen.test sock_filter-v.gen.test sock_filter-v-Xabbrev.gen.test sock_filter-v-Xraw.gen.test sock_filter-v-Xverbose.gen.test sockaddr_xlat-Xabbrev.gen.test sockaddr_xlat-Xraw.gen.test sockaddr_xlat-Xverbose.gen.test socketcall.gen.test sockopt-sol_netlink.gen.test sockopt-timestamp.gen.test splice.gen.test stat.gen.test stat64.gen.test statfs.gen.test statfs64.gen.test status-all.gen.test status-failed.gen.test status-failed-long.gen.test status-failed-status.gen.test status-none.gen.test status-successful.gen.test status-successful-long.gen.test status-successful-status.gen.test status-unfinished.gen.test statx.gen.test strace--absolute-timestamps.gen.test strace--absolute-timestamps-format-time.gen.test strace--absolute-timestamps-format-time-precision-s.gen.test strace--absolute-timestamps-format-time-precision-ms.gen.test strace--absolute-timestamps-format-time-precision-us.gen.test strace--absolute-timestamps-format-time-precision-ns.gen.test strace--absolute-timestamps-format-unix-precision-s.gen.test strace--absolute-timestamps-format-unix-precision-ms.gen.test strace--absolute-timestamps-format-unix-precision-us.gen.test strace--absolute-timestamps-format-unix-precision-ns.gen.test strace--follow-forks-output-separately.gen.test strace--relative-timestamps.gen.test strace--relative-timestamps-s.gen.test strace--relative-timestamps-ms.gen.test strace--relative-timestamps-us.gen.test strace--relative-timestamps-ns.gen.test strace--syscall-times.gen.test strace--syscall-times-s.gen.test strace--syscall-times-ms.gen.test strace--syscall-times-us.gen.test strace--syscall-times-ns.gen.test strace--strings-in-hex.gen.test strace--strings-in-hex-all.gen.test strace--strings-in-hex-non-ascii.gen.test strace--timestamps.gen.test strace--timestamps-time.gen.test strace--timestamps-time-s.gen.test strace--timestamps-time-ms.gen.test strace--timestamps-time-us.gen.test strace--timestamps-time-ns.gen.test strace--timestamps-unix-s.gen.test strace--timestamps-unix-ms.gen.test strace--timestamps-unix-us.gen.test strace--timestamps-unix-ns.gen.test strace-n.gen.test strace-x.gen.test strace-xx.gen.test swap.gen.test sxetmask.gen.test symlink.gen.test symlinkat.gen.test sync.gen.test sync_file_range.gen.test sync_file_range2.gen.test sysinfo.gen.test syslog.gen.test tee.gen.test tgkill.gen.test tgkill--pidns-translation.gen.test threads-execve--quiet-thread-execve.gen.test threads-execve-q.gen.test threads-execve-qq.gen.test threads-execve-qqq.gen.test time.gen.test timer_create.gen.test timer_xettime.gen.test timerfd_xettime.gen.test times.gen.test times-fail.gen.test tkill.gen.test tkill--pidns-translation.gen.test trace_clock.gen.test trace_creds.gen.test trace_fstat.gen.test trace_fstatfs.gen.test trace_lstat.gen.test trace_personality_32.gen.test trace_personality_64.gen.test trace_personality_regex_32.gen.test trace_personality_regex_64.gen.test trace_personality_regex_x32.gen.test trace_personality_x32.gen.test trace_question.gen.test trace_stat.gen.test trace_stat_like.gen.test trace_statfs.gen.test trace_statfs_like.gen.test trie_test.gen.test truncate.gen.test truncate64.gen.test ugetrlimit.gen.test umask.gen.test umoven-illptr.gen.test umovestr-illptr.gen.test umovestr3.gen.test umovestr_cached_adjacent.gen.test unlink.gen.test unlinkat.gen.test unshare.gen.test userfaultfd.gen.test ustat.gen.test utime.gen.test utimensat.gen.test utimensat-Xabbrev.gen.test utimensat-Xraw.gen.test utimensat-Xverbose.gen.test utimes.gen.test vfork-f.gen.test vhangup.gen.test vmsplice.gen.test wait4.gen.test wait4-v.gen.test waitid.gen.test waitid-v.gen.test waitpid.gen.test xattr.gen.test xattr-strings.gen.test xet_robust_list.gen.test xet_robust_list--pidns-translation.gen.test xetitimer.gen.test xetpgid.gen.test xetpgid--pidns-translation.gen.test xetpriority.gen.test xetpriority--pidns-translation.gen.test xettimeofday.gen.test
 
 $(srcdir)/_newselect.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
@@ -100,6 +100,42 @@ $(srcdir)/clone3-success-Xraw.gen.test:
 $(srcdir)/clone3-success-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/clone_parent.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_parent--quiet-exit.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_parent-q.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_parent-qq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_ptrace--quiet-attach.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_ptrace--quiet-exit.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_ptrace-q.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_ptrace-qq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/close_range.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/close_range-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/close_range-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/close_range-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/copy_file_range.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -109,18 +145,54 @@ $(srcdir)/creat.gen.test: $(abs_srcdir)/
 $(srcdir)/delete_module.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/dev--decode-fds-dev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dev--decode-fds-path.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dev--decode-fds-socket.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/dev-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/dup.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/dup-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/dup2.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/dup2-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup2-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup2-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/dup3.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/dup3-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup3-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup3-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/epoll_create.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -145,7 +217,22 @@ $(srcdir)/execveat.gen.test: $(abs_srcdi
 $(srcdir)/execveat-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
-$(srcdir)/faccessat.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+$(srcdir)/faccessat-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat2-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat2-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat2-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/fadvise64_64.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
@@ -190,9 +277,15 @@ $(srcdir)/fchownat.gen.test: $(abs_srcdi
 $(srcdir)/fcntl.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/fcntl--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/fcntl64.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/fcntl64--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/fdatasync.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -295,9 +388,15 @@ $(srcdir)/getcwd.gen.test: $(abs_srcdir)
 $(srcdir)/getdents.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getdents-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getdents64.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getdents64-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getegid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -346,9 +445,15 @@ $(srcdir)/getpeername.gen.test: $(abs_sr
 $(srcdir)/getpgrp.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getpgrp--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getpid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getpid--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getppid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -376,6 +481,9 @@ $(srcdir)/getrusage.gen.test: $(abs_srcd
 $(srcdir)/getsid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getsid--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getsockname.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -391,7 +499,13 @@ $(srcdir)/getuid32.gen.test: $(abs_srcdi
 $(srcdir)/getuid32-creds.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
-$(srcdir)/getxxid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+$(srcdir)/getxgid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/getxpid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/getxuid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/group_req.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
@@ -478,6 +592,54 @@ $(srcdir)/ioctl_evdev-success-v-Xraw.gen
 $(srcdir)/ioctl_evdev-success-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioctl_hdio.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-v-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-v-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-v-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-v-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioctl_inotify.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -511,6 +673,9 @@ $(srcdir)/ioctl_nsfs.gen.test: $(abs_src
 $(srcdir)/ioctl_perf.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioctl_perf-success.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioctl_ptp.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -535,12 +700,60 @@ $(srcdir)/ioctl_sg_io_v4.gen.test: $(abs
 $(srcdir)/ioctl_sock_gifconf.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioctl_tee.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioctl_uffdio.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/ioctl_v4l2.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioctl_v4l2-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-v-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-v-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-v-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-v-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioctl_watchdog.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -553,6 +766,9 @@ $(srcdir)/iopl.gen.test: $(abs_srcdir)/g
 $(srcdir)/ioprio.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioprio--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioprio-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -619,6 +835,9 @@ $(srcdir)/kcmp.gen.test: $(abs_srcdir)/g
 $(srcdir)/kcmp-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/kcmp-y--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/kern_features.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -655,6 +874,9 @@ $(srcdir)/keyctl-Xverbose.gen.test: $(ab
 $(srcdir)/kill.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/kill--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ksysent.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -685,6 +907,9 @@ $(srcdir)/madvise.gen.test: $(abs_srcdir
 $(srcdir)/maybe_switch_current_tcp.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/maybe_switch_current_tcp--quiet-thread-execve.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/mbind.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -715,6 +940,9 @@ $(srcdir)/memfd_create-Xverbose.gen.test
 $(srcdir)/migrate_pages.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/migrate_pages--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/mincore.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -805,6 +1033,9 @@ $(srcdir)/move_pages-Xraw.gen.test: $(ab
 $(srcdir)/move_pages-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/move_pages--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/mq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -832,6 +1063,18 @@ $(srcdir)/munlockall.gen.test: $(abs_src
 $(srcdir)/nanosleep.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/net--decode-fds-dev-netlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/net--decode-fds-none-netlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/net--decode-fds-path-netlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/net--decode-fds-socket-netlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/net-icmp_filter.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -850,6 +1093,9 @@ $(srcdir)/net-packet_mreq-Xverbose.gen.t
 $(srcdir)/net-sockaddr.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/net-sockaddr--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/net-tpacket_req.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -961,6 +1207,9 @@ $(srcdir)/nlattr_ifla_port.gen.test: $(a
 $(srcdir)/nlattr_ifla_xdp.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/nlattr_ifla_xdp-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/nlattr_inet_diag_msg.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1069,6 +1318,36 @@ $(srcdir)/open_tree-P.gen.test: $(abs_sr
 $(srcdir)/openat.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/openat2.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v-y-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v-y-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v-y-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/orphaned_process_group.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1096,18 +1375,45 @@ $(srcdir)/personality-Xraw.gen.test: $(a
 $(srcdir)/personality-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/pidfd_getfd.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_getfd-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_getfd-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pidfd_open.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/pidfd_open--decode-fd-path.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_open--decode-fd-pidfd.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_open--decode-fd-socket.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pidfd_open-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/pidfd_open-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/pidfd_open-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_open--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pidfd_send_signal.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/pidfd_send_signal--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pipe2.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1174,12 +1480,21 @@ $(srcdir)/printstrn-umoven-undumpable.ge
 $(srcdir)/prlimit64.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/prlimit64--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/process_vm_readv.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/process_vm_readv--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/process_vm_writev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/process_vm_writev--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pselect6.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1288,6 +1603,9 @@ $(srcdir)/rt_sigprocmask.gen.test: $(abs
 $(srcdir)/rt_sigqueueinfo.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/rt_sigqueueinfo--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/rt_sigreturn.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1300,6 +1618,9 @@ $(srcdir)/rt_sigtimedwait.gen.test: $(ab
 $(srcdir)/rt_tgsigqueueinfo.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/rt_tgsigqueueinfo--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/s390_guarded_storage.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1330,15 +1651,27 @@ $(srcdir)/sched_rr_get_interval.gen.test
 $(srcdir)/sched_xetaffinity.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/sched_xetaffinity--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sched_xetattr.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/sched_xetattr--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sched_xetparam.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/sched_xetparam--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sched_xetscheduler.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/sched_xetscheduler--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sched_yield.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1477,6 +1810,9 @@ $(srcdir)/signal.gen.test: $(abs_srcdir)
 $(srcdir)/signal_receive.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/signal_receive--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/signalfd4.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1510,6 +1846,9 @@ $(srcdir)/so_peercred-Xraw.gen.test: $(a
 $(srcdir)/so_peercred-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/so_peercred--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sock_filter-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1561,18 +1900,141 @@ $(srcdir)/status-all.gen.test: $(abs_src
 $(srcdir)/status-failed.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/status-failed-long.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/status-failed-status.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/status-none.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/status-successful.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/status-successful-long.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/status-successful-status.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/status-unfinished.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/statx.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/strace--absolute-timestamps.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time-precision-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time-precision-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time-precision-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time-precision-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-unix-precision-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-unix-precision-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-unix-precision-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-unix-precision-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--follow-forks-output-separately.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--strings-in-hex.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--strings-in-hex-all.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--strings-in-hex-non-ascii.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-unix-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-unix-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-unix-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-unix-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace-n.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace-x.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace-xx.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/swap.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1603,6 +2065,24 @@ $(srcdir)/syslog.gen.test: $(abs_srcdir)
 $(srcdir)/tee.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/tgkill.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/tgkill--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/threads-execve--quiet-thread-execve.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/threads-execve-q.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/threads-execve-qq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/threads-execve-qqq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/time.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1621,6 +2101,15 @@ $(srcdir)/times.gen.test: $(abs_srcdir)/
 $(srcdir)/times-fail.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/tkill.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/tkill--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/trace_clock.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/trace_creds.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1666,6 +2155,9 @@ $(srcdir)/trace_statfs.gen.test: $(abs_s
 $(srcdir)/trace_statfs_like.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/trie_test.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/truncate.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1687,6 +2179,9 @@ $(srcdir)/umovestr-illptr.gen.test: $(ab
 $(srcdir)/umovestr3.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/umovestr_cached_adjacent.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/unlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1753,14 +2248,23 @@ $(srcdir)/xattr-strings.gen.test: $(abs_
 $(srcdir)/xet_robust_list.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/xet_robust_list--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/xetitimer.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/xetpgid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/xetpgid--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/xetpriority.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/xetpriority--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/xettimeofday.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
diff -pruN 5.5-3/tests/gen_tests.in 5.9-0ubuntu2/tests/gen_tests.in
--- 5.5-3/tests/gen_tests.in	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests/gen_tests.in	2020-09-23 12:56:26.000000000 +0000
@@ -38,13 +38,37 @@ clone3-Xverbose	-a16 -Xverbose -e trace=
 clone3-success-Xabbrev	+clone3-success.test -a16 -Xabbrev
 clone3-success-Xraw	+clone3-success.test -a16 -Xraw
 clone3-success-Xverbose	+clone3-success.test -a16 -Xverbose
+clone_parent +clone_ptrace.test
+clone_parent--quiet-exit +clone_ptrace.test --quiet=exit,personality
+clone_parent-q +clone_ptrace.test -q
+clone_parent-qq +clone_ptrace.test -qq
+clone_ptrace--quiet-attach +clone_ptrace.test --quiet=attach,personality
+clone_ptrace--quiet-exit +clone_ptrace.test --quiet=exit,personality
+clone_ptrace-q +clone_ptrace.test -q
+clone_ptrace-qq +clone_ptrace.test -qq
+close_range	-a21 7>>/dev/full
+close_range-P	-a21 --trace=close_range -P /dev/full 7>>/dev/full
+close_range-y	-a33 --trace=close_range -y 7>>/dev/full
+close_range-yy	-a33 --trace=close_range -yy 7>>/dev/full
 copy_file_range
 creat	-a20
 delete_module	-a23
+dev--decode-fds-dev	-a30 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" -e decode-fds=dev
+dev--decode-fds-path	-a19 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" -e decode-fds=path
+dev--decode-fds-socket	-a19 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" --decode-fds=socket
 dev-yy	-a30 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" -yy
-dup	-a8
-dup2	-a13
-dup3	-a24
+dup	-a7 9>>/dev/full
+dup-P	-a7 --trace=dup -P /dev/full 9>>/dev/full
+dup-y	-a8 --trace=dup -y 9>>/dev/full
+dup-yy	-a8 --trace=dup -yy 9>>/dev/full
+dup2	-a11 9>>/dev/full
+dup2-P	-a11 --trace=dup2 -P /dev/full 9>>/dev/full
+dup2-y	-a13 --trace=dup2 -y 9>>/dev/full
+dup2-yy	-a13 --trace=dup2 -yy 9>>/dev/full
+dup3	-a13 7>>/dev/full
+dup3-P	-a13 --trace=dup3 -P /dev/full 7>>/dev/full
+dup3-y	-a15 --trace=dup3 -y 7>>/dev/full
+dup3-yy	-a15 --trace=dup3 -yy 7>>/dev/full
 epoll_create	-a17
 epoll_create1	-a28
 epoll_ctl
@@ -53,7 +77,12 @@ epoll_wait	-a26
 erestartsys	-a34 -e signal=none -e trace=recvfrom
 execveat
 execveat-v	-v -e trace=execveat
-faccessat	-P $NAME.sample
+faccessat-P	-a23 --trace=faccessat -P /dev/full
+faccessat-y	+faccessat.test -a24 -y
+faccessat-yy	+faccessat.test -a24 -yy
+faccessat2-P	-a27 --trace=faccessat2 -P /dev/full
+faccessat2-y	+faccessat2.test -a28 -y
+faccessat2-yy	+faccessat2.test -a28 -yy
 fadvise64_64	+fadvise64.test
 fallocate	-a18
 fanotify_init
@@ -68,7 +97,9 @@ fchown	-a16
 fchown32	-a18
 fchownat
 fcntl	-a8
+fcntl--pidns-translation	test_pidns -a8 -e trace=fcntl
 fcntl64	-a8
+fcntl64--pidns-translation	test_pidns -a8 -e trace=fcntl64
 fdatasync	-a14
 file_handle	-e trace=name_to_handle_at,open_by_handle_at
 file_ioctl	+ioctl.test
@@ -102,8 +133,10 @@ futimesat	-a28
 get_mempolicy	-s3 -a38
 getcpu	-a25
 getcwd	-a18
-getdents	-a22 -v
-getdents64	-a24 -v
+getdents	-a31
+getdents-v	-a22 -v --trace=getdents
+getdents64	-a33
+getdents64-v	-a24 -v --trace=getdents64
 getegid	+getuid.test
 getegid-creds	+getuid.test
 getegid32	+getuid.test
@@ -120,7 +153,9 @@ getgroups	-a17
 getgroups32	-a19
 getpeername	-a27
 getpgrp	-a10
+getpgrp--pidns-translation	test_pidns -e trace=getpgrp -a10
 getpid	-a9
+getpid--pidns-translation	test_pidns -e trace=getpid -a9
 getppid	-a10
 getrandom	-a32 -s3
 getresgid	-a25
@@ -130,12 +165,15 @@ getresuid32	-a27
 getrlimit	-a27
 getrusage	-v
 getsid	-a10
+getsid--pidns-translation	test_pidns -e trace=getsid -a10
 getsockname	-a27
 gettid	-a9
 getuid-creds	+getuid.test
 getuid32	+getuid.test
 getuid32-creds	+getuid.test
-getxxid	-a10 -e trace=getxpid,getxuid,getxgid
+getxgid	-a10
+getxpid	-a10
+getxuid	-a10
 group_req	-e trace=setsockopt
 inet-cmsg	-e trace=recvmsg
 init_module	-a27
@@ -164,6 +202,22 @@ ioctl_evdev-success-v	+ioctl_evdev-succe
 ioctl_evdev-success-v-Xabbrev	+ioctl_evdev-success.test -v -Xabbrev
 ioctl_evdev-success-v-Xraw	+ioctl_evdev-success.test -a27 -v -Xraw
 ioctl_evdev-success-v-Xverbose	+ioctl_evdev-success.test -a43 -v -Xverbose
+ioctl_hdio	+ioctl.test -a27
+ioctl_hdio-Xabbrev	+ioctl.test -a27 -Xabbrev
+ioctl_hdio-Xraw	+ioctl.test -a20 -Xraw
+ioctl_hdio-Xverbose	+ioctl.test -a39 -Xverbose
+ioctl_hdio-v	+ioctl.test -a27 -v
+ioctl_hdio-v-Xabbrev	+ioctl.test -a27 -v -Xabbrev
+ioctl_hdio-v-Xraw	+ioctl.test -a20 -v -Xraw
+ioctl_hdio-v-Xverbose	+ioctl.test -a39 -v -Xverbose
+ioctl_hdio-success	+ioctl-success.sh -a27
+ioctl_hdio-success-Xabbrev	+ioctl-success.sh -a27 -Xabbrev
+ioctl_hdio-success-Xraw	+ioctl-success.sh -a20 -Xraw
+ioctl_hdio-success-Xverbose	+ioctl-success.sh -a39 -Xverbose
+ioctl_hdio-success-v	+ioctl-success.sh -a27 -v
+ioctl_hdio-success-v-Xabbrev	+ioctl-success.sh -a27 -v -Xabbrev
+ioctl_hdio-success-v-Xraw	+ioctl-success.sh -a20 -v -Xraw
+ioctl_hdio-success-v-Xverbose	+ioctl-success.sh -a39 -v -Xverbose
 ioctl_inotify	+ioctl.test
 ioctl_kvm_run	+ioctl.test -a36 -y
 ioctl_kvm_run-v	+ioctl.test -v -a36 -y
@@ -175,6 +229,7 @@ ioctl_mtd	+ioctl.test
 ioctl_nbd	+ioctl.test -y
 ioctl_nsfs	+ioctl.test -esignal=none
 ioctl_perf	+ioctl.test
+ioctl_perf-success +ioctl-success.sh -a35
 ioctl_ptp	+ioctl.test
 ioctl_random	+ioctl.test
 ioctl_rtc	+ioctl.test
@@ -183,12 +238,29 @@ ioctl_scsi	+ioctl.test
 ioctl_sg_io_v3	+ioctl.test
 ioctl_sg_io_v4	+ioctl.test
 ioctl_sock_gifconf	+ioctl.test -a28 -s1
+ioctl_tee	+ioctl.test
 ioctl_uffdio	+ioctl.test
 ioctl_v4l2	+ioctl.test
+ioctl_v4l2-Xabbrev	+ioctl.test -Xabbrev
+ioctl_v4l2-Xraw	+ioctl.test -Xraw
+ioctl_v4l2-Xverbose	+ioctl.test -Xverbose
+ioctl_v4l2-v	+ioctl.test -v
+ioctl_v4l2-v-Xabbrev	+ioctl.test -v -Xabbrev
+ioctl_v4l2-v-Xraw	+ioctl.test -v -Xraw
+ioctl_v4l2-v-Xverbose	+ioctl.test -v -Xverbose
+ioctl_v4l2-success	+ioctl-success.sh -a29
+ioctl_v4l2-success-Xabbrev	+ioctl-success.sh -a29 -Xabbrev
+ioctl_v4l2-success-Xraw	+ioctl-success.sh -a27 -Xraw
+ioctl_v4l2-success-Xverbose	+ioctl-success.sh -a30 -Xverbose
+ioctl_v4l2-success-v	+ioctl-success.sh -a29 -v
+ioctl_v4l2-success-v-Xabbrev	+ioctl-success.sh -a29 -v -Xabbrev
+ioctl_v4l2-success-v-Xraw	+ioctl-success.sh -a27 -v -Xraw
+ioctl_v4l2-success-v-Xverbose	+ioctl-success.sh -a29 -v -Xverbose
 ioctl_watchdog	+ioctl.test
 ioperm	-a27
 iopl	-a8
 ioprio	-a18 -e trace=ioprio_get,ioprio_set
+ioprio--pidns-translation	test_pidns -a18 -e trace=ioprio_get,ioprio_set
 ioprio-Xabbrev	-a18 -e trace=ioprio_get,ioprio_set -Xabbrev
 ioprio-Xraw	-a18 -e trace=ioprio_get,ioprio_set -Xraw
 ioprio-Xverbose	-a18 -e trace=ioprio_get,ioprio_set -Xverbose
@@ -211,6 +283,7 @@ ipc_shm-Xraw	+ipc.sh -Xraw -a19
 ipc_shm-Xverbose	+ipc.sh -Xverbose -a34
 kcmp	-a22
 kcmp-y	-a22 -y -e trace=kcmp
+kcmp-y--pidns-translation	test_pidns -a22 -y -e trace=kcmp
 kern_features -a16
 kernel_version	-a16 -v -e trace=bpf
 kernel_version-Xabbrev	-a16 -Xabbrev -v -e trace=bpf
@@ -223,6 +296,7 @@ keyctl-Xabbrev	-a31 -s10 -e trace=keyctl
 keyctl-Xraw	-a13 -s10 -e trace=keyctl -Xraw
 keyctl-Xverbose	-a41 -s10 -e trace=keyctl -Xverbose
 kill	-a12 -esignal=none
+kill--pidns-translation	test_pidns -a12 -e trace=kill -esignal=none
 ksysent	../$NAME
 lchown	-a30
 lchown32	-a32
@@ -233,6 +307,7 @@ lstat	-a31 --no-abbrev --trace-path=stat
 lstat64	-a32 --no-abbrev --trace-path=stat.sample --trace-path=/dev/full
 madvise	-a33
 maybe_switch_current_tcp	-a30 -f -e trace=execveat
+maybe_switch_current_tcp--quiet-thread-execve	-a30 -s48 -f -e trace=execveat --quiet=personality,thread-execve
 mbind
 mbind-Xabbrev	-Xabbrev -e trace=mbind
 mbind-Xraw	-a33 -Xraw -e trace=mbind
@@ -243,6 +318,7 @@ memfd_create-Xabbrev	-Xabbrev -e trace=m
 memfd_create-Xraw	-a30 -Xraw -e trace=memfd_create
 memfd_create-Xverbose	-Xverbose -e trace=memfd_create
 migrate_pages	-a33
+migrate_pages--pidns-translation	test_pidns -a33 -e trace=migrate_pages
 mincore	-a22
 mkdir	-a20
 mkdirat	-a28
@@ -273,6 +349,7 @@ move_pages	-s3
 move_pages-Xabbrev	-s3 -e trace=move_pages -Xabbrev
 move_pages-Xraw	-s3 -a36 -e trace=move_pages -Xraw
 move_pages-Xverbose	-s3 -e trace=move_pages -Xverbose
+move_pages--pidns-translation	test_pidns -s3 -e trace=move_pages
 mq	-a32 -e trace=mq_getsetattr,mq_open,mq_unlink
 mq_sendrecv	-a14 -e trace=mq_open,mq_notify,mq_timedsend,mq_timedreceive,mq_unlink
 mq_sendrecv-read	-eread=0 -a14 -e trace=mq_open,mq_notify,mq_timedsend,mq_timedreceive,mq_unlink
@@ -282,12 +359,17 @@ msg_control-v	-v -a21 -e trace=sendmsg
 msg_name	-a20 -e trace=recvmsg
 munlockall	-a13
 nanosleep	-a20
+net--decode-fds-dev-netlink	+net-yy-netlink.test --decode-fds=dev
+net--decode-fds-none-netlink	+net-yy-netlink.test --decode-fds=none -a9
+net--decode-fds-path-netlink	+net-yy-netlink.test --decode-fds=path
+net--decode-fds-socket-netlink	+net-yy-netlink.test --decode-fds=socket
 net-icmp_filter	-e trace=getsockopt,setsockopt
 net-packet_mreq -e trace=setsockopt
 net-packet_mreq-Xabbrev	-e trace=setsockopt -Xabbrev
 net-packet_mreq-Xraw	-e trace=setsockopt -Xraw
 net-packet_mreq-Xverbose	-e trace=setsockopt -Xverbose
 net-sockaddr	-a24 -e trace=connect
+net-sockaddr--pidns-translation	test_pidns -a24 -e trace=connect
 net-tpacket_req -e trace=setsockopt
 net-tpacket_stats -e trace=getsockopt
 net-yy-inet6	+net-yy-inet.test
@@ -325,6 +407,7 @@ nlattr_ifla_brport		+netlink_sock_diag.t
 nlattr_ifla_linkinfo		+netlink_sock_diag.test
 nlattr_ifla_port		+netlink_sock_diag.test
 nlattr_ifla_xdp			+netlink_sock_diag.test
+nlattr_ifla_xdp-y		+netlink_sock_diag.test -y; exec 9</dev/full
 nlattr_inet_diag_msg		+netlink_sock_diag.test
 nlattr_inet_diag_req_compat	+netlink_sock_diag.test
 nlattr_inet_diag_req_v2		+netlink_sock_diag.test
@@ -335,7 +418,7 @@ nlattr_ndtmsg			+netlink_sock_diag.test
 nlattr_netconfmsg		+netlink_sock_diag.test
 nlattr_netlink_diag_msg		+netlink_sock_diag.test
 nlattr_nlmsgerr			+netlink_sock_diag.test
-nlattr_packet_diag_msg		+netlink_sock_diag-v.sh
+nlattr_packet_diag_msg		+netlink_sock_diag.test -v
 nlattr_rtgenmsg			+netlink_sock_diag.test
 nlattr_rtmsg			+netlink_sock_diag.test
 nlattr_smc_diag_msg		+netlink_sock_diag.test
@@ -359,8 +442,18 @@ oldselect-efault-P	-a13 -e trace=select
 oldstat	-a32 -v -P stat.sample -P /dev/full
 open	-a30 -P $NAME.sample
 open_tree -a30 -y
-open_tree-P -a30 -y -P /dev/full -e trace=open_tree
+open_tree-P -a30 --decode-fds -P /dev/full -e trace=open_tree
 openat	-a36 -P $NAME.sample
+openat2	-a35
+openat2-Xabbrev	--trace=openat2 -a35 -Xabbrev
+openat2-Xraw	--trace=openat2 -a32 -Xraw
+openat2-Xverbose	--trace=openat2 -a35 -Xverbose
+openat2-v	--trace=openat2 -a35 -v
+openat2-v-y	--trace=openat2 -a36 -v -y </dev/full
+openat2-v-y-Xabbrev	--trace=openat2 -a35 -v -y -Xabbrev </dev/full
+openat2-v-y-Xraw	--trace=openat2 -a32 -v -y -Xraw </dev/full
+openat2-v-y-Xverbose	--trace=openat2 -a44 -v -y -Xverbose </dev/full
+openat2-y	--trace=openat2 -a36 -y </dev/full
 orphaned_process_group	. "${srcdir=.}/PTRACE_SEIZE.sh"; run_strace_match_diff -f -e trace=none -e signal='!chld'
 osf_utimes	-a21
 pause	-a8 -esignal=none
@@ -370,10 +463,19 @@ perf_event_open_unabbrev	-a1 -v -e trace
 personality-Xabbrev	+personality.test -Xabbrev
 personality-Xraw	+personality.test -a15 -Xraw
 personality-Xverbose	+personality.test -Xverbose
+pidfd_getfd	-a18 -Xverbose -e signal=none </dev/full
+pidfd_getfd-y	--trace=pidfd_getfd -a18 -e signal=none -y </dev/full
+pidfd_getfd-yy	--trace=pidfd_getfd -a18 -e signal=none -yy </dev/full
 pidfd_open	-a17
+pidfd_open--decode-fd-path	-a17 -e decode-fd=path -e trace=pidfd_open
+pidfd_open--decode-fd-pidfd	-a17 -e decode-fd=pidfd -e trace=pidfd_open
+pidfd_open--decode-fd-socket	-a17 -e decode-fd=socket -e trace=pidfd_open
 pidfd_open-P	-a17 -P /dev/full -e trace=pidfd_open
 pidfd_open-y	-a17 -y -e trace=pidfd_open
+pidfd_open-yy	-a17 -yy -e trace=pidfd_open
+pidfd_open--pidns-translation	test_pidns -a17 -e trace=pidfd_open
 pidfd_send_signal
+pidfd_send_signal--pidns-translation test_pidns -e trace=pidfd_send_signal
 pipe2	-a15
 pkey_alloc	-a17
 pkey_free	-a13
@@ -396,8 +498,11 @@ printstrn-umoven	-s4096 -e signal=none -
 printstrn-umoven-peekdata	-e signal=none -e trace=add_key
 printstrn-umoven-undumpable	-e signal=none -e trace=add_key
 prlimit64
+prlimit64--pidns-translation     test_pidns -e trace=prlimit64
 process_vm_readv	-s5 -a37
+process_vm_readv--pidns-translation	test_pidns -s5 -a37 -e trace=process_vm_readv
 process_vm_writev	-s5 -a38
+process_vm_writev--pidns-translation	test_pidns -s5 -a38 -e trace=process_vm_writev
 pselect6
 ptrace	-a23 -e signal=none
 ptrace_syscall_info	-a35 -e signal=none -e trace=ptrace
@@ -434,10 +539,12 @@ rmdir	-a22
 rt_sigpending	-a20
 rt_sigprocmask
 rt_sigqueueinfo	-esignal=none
+rt_sigqueueinfo--pidns-translation	test_pidns -esignal=none -e trace=rt_sigqueueinfo
 rt_sigreturn	-esignal='!USR1'
 rt_sigsuspend	-a20 -esignal=none
 rt_sigtimedwait	-a38
 rt_tgsigqueueinfo	-esignal=none
+rt_tgsigqueueinfo--pidns-translation	test_pidns -esignal=none -e trace=rt_tgsigqueueinfo
 s390_guarded_storage	-a32
 s390_guarded_storage-v	-e trace=s390_guarded_storage -a32 -v
 s390_pci_mmio_read_write	-e trace=s390_pci_mmio_read,s390_pci_mmio_write -a30
@@ -448,9 +555,13 @@ sched	test_trace_expr times -e/sched
 sched_get_priority_mxx	-a33 -e trace=sched_get_priority_min,sched_get_priority_max
 sched_rr_get_interval	-a31
 sched_xetaffinity	-a28 -e trace=sched_getaffinity,sched_setaffinity
+sched_xetaffinity--pidns-translation	test_pidns -a28 -e trace=sched_getaffinity,sched_setaffinity
 sched_xetattr	-a29 -e trace=sched_getattr,sched_setattr
+sched_xetattr--pidns-translation	test_pidns -a29 -e trace=sched_getattr,sched_setattr
 sched_xetparam	-a23 -e trace=sched_getparam,sched_setparam
+sched_xetparam--pidns-translation	test_pidns -a23 -e trace=sched_getparam,sched_setparam
 sched_xetscheduler	-a22 -e trace=sched_getscheduler,sched_setscheduler
+sched_xetscheduler--pidns-translation	test_pidns -a22 -e trace=sched_getscheduler,sched_setscheduler
 sched_yield	-a14
 seccomp-filter	-e trace=seccomp
 seccomp-filter-v	-v -e trace=seccomp
@@ -497,6 +608,7 @@ sigaction	-a31
 siginfo	-e trace=none
 signal	-a25 -e signal=none -e trace='/^signal$'
 signal_receive	-a16 -e trace=kill
+signal_receive--pidns-translation	test_pidns -a16 -e trace=kill
 signalfd4
 sigpending	-a15
 sigprocmask	-a34
@@ -508,6 +620,7 @@ so_peercred	-e trace=getsockopt
 so_peercred-Xabbrev	-e trace=getsockopt -Xabbrev
 so_peercred-Xraw	-e trace=getsockopt -Xraw -a39
 so_peercred-Xverbose	-e trace=getsockopt -Xverbose
+so_peercred--pidns-translation	test_pidns -e trace=getsockopt
 sock_filter-v	-v -e trace=getsockopt,setsockopt
 sock_filter-v-Xabbrev	-v -e trace=getsockopt,setsockopt -X abbrev
 sock_filter-v-Xraw	-a 37 -v -e trace=getsockopt,setsockopt -X raw
@@ -525,10 +638,51 @@ statfs	-a17
 statfs64	-a23
 status-all	-a10 -e trace=chdir --status=detached,failed,successful,unavailable,unfinished
 status-failed	-a10 -e trace=chdir -Z
+status-failed-long	-a10 -e trace=chdir --failed-only
+status-failed-status	-a10 -e trace=chdir -e status=failed
 status-none	-e trace=all --status=none
 status-successful	-a10 -e trace=chdir -z
+status-successful-long	-a10 -e trace=chdir --successful-only
+status-successful-status	-a10 -e trace=chdir --status=successful
 status-unfinished	-a10 -e trace=all --status=unfinished
 statx	-a32 --no-abbrev --trace-path=stat.sample --trace-path=/dev/full
+strace--absolute-timestamps +strace-t.test --absolute-timestamps
+strace--absolute-timestamps-format-time +strace-t.test --absolute-timestamps=format:time
+strace--absolute-timestamps-format-time-precision-s +strace-t.test --absolute-timestamps=format:time --absolute-timestamps=precision:s
+strace--absolute-timestamps-format-time-precision-ms +strace-tt.test 3 --absolute-timestamps=format:time --absolute-timestamps=precision:ms
+strace--absolute-timestamps-format-time-precision-us +strace-tt.test 6 --absolute-timestamps=format:time --absolute-timestamps=precision:us
+strace--absolute-timestamps-format-time-precision-ns +strace-tt.test 9 --absolute-timestamps=format:time --absolute-timestamps=precision:ns
+strace--absolute-timestamps-format-unix-precision-s +strace-ttt.test 0 --absolute-timestamps=format:unix --absolute-timestamps=precision:s
+strace--absolute-timestamps-format-unix-precision-ms +strace-ttt.test 3 --absolute-timestamps=precision:ms --absolute-timestamps=format:unix
+strace--absolute-timestamps-format-unix-precision-us +strace-ttt.test 6 --absolute-timestamps=precision:us --absolute-timestamps=format:unix
+strace--absolute-timestamps-format-unix-precision-ns +strace-ttt.test 9 --absolute-timestamps=format:unix --absolute-timestamps=precision:ns
+strace--follow-forks-output-separately +strace-ff.test --follow-forks --output-separately
+strace--relative-timestamps +strace-r.test --relative-timestamps
+strace--relative-timestamps-s +strace-r.test --relative-timestamps=s
+strace--relative-timestamps-ms +strace-r.test --relative-timestamps=ms
+strace--relative-timestamps-us +strace-r.test --relative-timestamps=us
+strace--relative-timestamps-ns +strace-r.test --relative-timestamps=ns
+strace--syscall-times +strace-T.test --syscall-times
+strace--syscall-times-s +strace-T.test --syscall-times=s
+strace--syscall-times-ms +strace-T.test --syscall-times=ms
+strace--syscall-times-us +strace-T.test --syscall-times=us
+strace--syscall-times-ns +strace-T.test --syscall-times=ns
+strace--strings-in-hex	--trace=chdir --strings-in-hex --columns=18
+strace--strings-in-hex-all	--trace=chdir --strings-in-hex=all --columns=18
+strace--strings-in-hex-non-ascii	--trace=chdir --strings-in-hex=non-ascii --columns=12
+strace--timestamps +strace-t.test --timestamps
+strace--timestamps-time +strace-t.test --timestamps=time
+strace--timestamps-time-s +strace-t.test --timestamps=time,s
+strace--timestamps-time-ms +strace-tt.test 3 --timestamps=time,ms
+strace--timestamps-time-us +strace-tt.test 6 --timestamps=time,us
+strace--timestamps-time-ns +strace-tt.test 9 --timestamps=time,ns
+strace--timestamps-unix-s +strace-ttt.test 0 --timestamps=unix,s
+strace--timestamps-unix-ms +strace-ttt.test 3 --timestamps=unix,ms
+strace--timestamps-unix-us +strace-ttt.test 6 --timestamps=unix,us
+strace--timestamps-unix-ns +strace-ttt.test 9 --timestamps=unix,ns
+strace-n	-e trace=listen -n -qq -a 12
+strace-x	-e trace=chdir -x -a 12
+strace-xx	-e trace=chdir -xx -a 18
 swap	-a23 -e trace=swapon,swapoff
 sxetmask	-a11 -e trace=sgetmask,ssetmask
 symlink	-a34
@@ -539,12 +693,21 @@ sync_file_range2
 sysinfo	-a14
 syslog	-a35
 tee
+tgkill	-a15 --signal='!cont'
+tgkill--pidns-translation       test_pidns -a15 --signal='!cont' -e trace=tgkill
+threads-execve--quiet-thread-execve +threads-execve.test -s40 --quiet=personality,thread-execve
+threads-execve-q +threads-execve.test -q
+threads-execve-qq +threads-execve.test -qq
+threads-execve-qqq +threads-execve.test -qqq
 time	-a10
 timer_create
 timer_xettime	-e trace=timer_create,timer_settime,timer_gettime
 timerfd_xettime	-e trace=timerfd_create,timerfd_settime,timerfd_gettime
 times	-esignal=none
 times-fail	-a12 -e trace=times
+tkill	-a12 --signal='!cont'
+tkill--pidns-translation       test_pidns --signal='!cont' -a12 -e trace=tkill
+trace_clock	test_trace_expr 'clock_nanosleep|times' -e%clock
 trace_creds	test_trace_expr '([gs]et[^p]*([gu]id|groups)|caps|prctl|[fl]?chown|print(path-umovestr|strn-umoven)-undumpable|ptrace|quotactl|rt_sigtimedwait|rt_(tg)?sigqueueinfo).*' -e%creds
 trace_fstat	test_trace_expr '' -e%fstat -v -P stat.sample -P /dev/full
 trace_fstatfs	test_trace_expr '' -e%fstatfs
@@ -560,6 +723,7 @@ trace_stat	test_trace_expr '' -e%stat -v
 trace_stat_like	test_trace_expr '' -e%%stat -v -P stat.sample -P /dev/full
 trace_statfs	test_trace_expr '' -e%statfs
 trace_statfs_like	test_trace_expr '' -e%%statfs
+trie_test    run_prog
 truncate
 truncate64
 ugetrlimit	-a28
@@ -567,6 +731,7 @@ umask	-a11
 umoven-illptr	-a36 -e trace=nanosleep
 umovestr-illptr	-a11 -e trace=chdir
 umovestr3	-a14 -e trace=chdir
+umovestr_cached_adjacent	+umovestr_cached.test 3
 unlink	-a24
 unlinkat	-a35
 unshare	-a11
@@ -589,7 +754,10 @@ waitpid	-a28
 xattr	-a22 -e trace=getxattr,fgetxattr,lgetxattr,setxattr,fsetxattr,lsetxattr,listxattr,flistxattr,llistxattr,removexattr,fremovexattr,lremovexattr
 xattr-strings	-a22 -s 4 -e trace=fsetxattr
 xet_robust_list	-a24 -e trace=get_robust_list,set_robust_list
+xet_robust_list--pidns-translation	test_pidns -a24 -e trace=get_robust_list,set_robust_list
 xetitimer	-a29 -e trace=setitimer,getitimer
 xetpgid	-a11 -e trace=getpgid,setpgid
-xetpriority	-a29 -e trace=getpriority,setpriority
+xetpgid--pidns-translation	test_pidns -a11 -e trace=getpgid,setpgid
+xetpriority	-a27 -e trace=getpriority,setpriority
+xetpriority--pidns-translation	test_pidns -a27 -e trace=getpriority,setpriority
 xettimeofday	-a20 -e trace=gettimeofday,settimeofday
diff -pruN 5.5-3/tests/getdents64.c 5.9-0ubuntu2/tests/getdents64.c
--- 5.5-3/tests/getdents64.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/getdents64.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,6 +1,8 @@
 /*
+ * Check decoding of getdents64 syscall.
+ *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -11,115 +13,29 @@
 
 #ifdef __NR_getdents64
 
-# include <assert.h>
-# include <dirent.h>
-# include <fcntl.h>
-# include <inttypes.h>
-# include <stddef.h>
-# include <stdio.h>
-# include <sys/stat.h>
-# include <unistd.h>
-
-static const char fname[] =
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nZ";
-static const char qname[] =
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nZ";
-
-typedef struct {
-		uint64_t d_ino;
-		uint64_t d_off;
-		unsigned short d_reclen;
-		unsigned char d_type;
-		char d_name[256];
-} kernel_dirent64;
+# define kernel_dirent_type kernel_dirent64_t
+# define NR_getdents	__NR_getdents64
+# define STR_getdents	"getdents64"
 
-static char buf[8192];
+# include "xgetdents.c"
 
-static const char *
-str_d_type(const unsigned char d_type)
-{
-	switch (d_type) {
-		case DT_DIR:
-			return "DT_DIR";
-		case DT_REG:
-			return "DT_REG";
-		default:
-			return "DT_UNKNOWN";
-	}
-}
+# if VERBOSE
 static void
-print_dirent(const kernel_dirent64 *d)
-{
-	const unsigned int d_name_offset = offsetof(kernel_dirent64, d_name);
-	int d_name_len = d->d_reclen - d_name_offset;
-	assert(d_name_len > 0);
-
-	printf("{d_ino=%" PRIu64 ", d_off=%" PRId64
-	       ", d_reclen=%u, d_type=%s, d_name=",
-	       d->d_ino, d->d_off, d->d_reclen, str_d_type(d->d_type));
-
-	if (d->d_name[0] == '.')
-		printf("\"%.*s\"}", d_name_len, d->d_name);
-	else
-		printf("\"%s\"}", qname);
-}
-
-int
-main(void)
+print_dirent(const kernel_dirent_type *d)
 {
-	static const char dname[] = "getdents64.test.tmp.dir";
-
-	assert(!mkdir(dname, 0700));
-	assert(!chdir(dname));
-	(void) close(0);
-	assert(!creat(fname, 0600));
-	assert(!close(0));
-	assert(!open(".", O_RDONLY | O_DIRECTORY));
-
-	unsigned long count = (unsigned long) 0xfacefeeddeadbeefULL;
-	long rc = syscall(__NR_getdents64, (long) 0xdefacedffffffffULL, NULL,
-			  count);
-	printf("getdents64(-1, NULL, %u) = %ld %s (%m)\n",
-	       (unsigned) count, rc, errno2name());
-
-	count = (unsigned long) 0xfacefeed00000000ULL | sizeof(buf);
-	while ((rc = syscall(__NR_getdents64, 0, buf, count))) {
-		kernel_dirent64 *d;
-		long i;
-
-		if (rc < 0)
-			perror_msg_and_skip("getdents64");
-		printf("getdents64(0, [");
-		for (i = 0; i < rc; i += d->d_reclen) {
-			d = (kernel_dirent64 *) &buf[i];
-			if (i)
-				printf(", ");
-			print_dirent(d);
-		}
-		printf("], %u) = %ld\n", (unsigned) count, rc);
-	}
-	printf("getdents64(0, [], %u) = 0\n", (unsigned) count);
-	puts("+++ exited with 0 +++");
-	assert(!unlink(fname));
-	assert(!chdir(".."));
-	assert(!rmdir(dname));
-
-	return 0;
+	const unsigned int d_name_offset = offsetof(kernel_dirent_type, d_name);
+	int d_name_len = (int) d->d_reclen - d_name_offset;
+	if (d_name_len <= 0)
+		error_msg_and_fail("d_name_len = %d", d_name_len);
+
+	PRINT_FIELD_U("{", *d, d_ino);
+	PRINT_FIELD_U(", ", *d, d_off);
+	PRINT_FIELD_U(", ", *d, d_reclen);
+	printf(", d_type=%s, d_name=", str_d_type(d->d_type));
+	print_quoted_cstring(d->d_name, d_name_len);
+	printf("}");
 }
+# endif
 
 #else
 
diff -pruN 5.5-3/tests/getdents64.gen.test 5.9-0ubuntu2/tests/getdents64.gen.test
--- 5.5-3/tests/getdents64.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests/getdents64.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -1,4 +1,4 @@
 #!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getdents64 -a24 -v); do not edit.
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getdents64 -a33 ); do not edit.
 . "${srcdir=.}/init.sh"
-run_strace_match_diff -a24 -v
+run_strace_match_diff -a33 
diff -pruN 5.5-3/tests/getdents64-v.c 5.9-0ubuntu2/tests/getdents64-v.c
--- 5.5-3/tests/getdents64-v.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/getdents64-v.c	2020-04-11 01:01:47.000000000 +0000
@@ -0,0 +1,3 @@
+/* Check --no-abbrev decoding of getdents64 syscall.  */
+#define VERBOSE 1
+#include "getdents64.c"
diff -pruN 5.5-3/tests/getdents64-v.gen.test 5.9-0ubuntu2/tests/getdents64-v.gen.test
--- 5.5-3/tests/getdents64-v.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/getdents64-v.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getdents64-v -a24 -v --trace=getdents64); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a24 -v --trace=getdents64
diff -pruN 5.5-3/tests/getdents.c 5.9-0ubuntu2/tests/getdents.c
--- 5.5-3/tests/getdents.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/getdents.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,6 +1,8 @@
 /*
+ * Check decoding of getdents syscall.
+ *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -11,109 +13,30 @@
 
 #ifdef __NR_getdents
 
-# include <assert.h>
-# include <dirent.h>
-# include <fcntl.h>
-# include <stddef.h>
-# include <stdio.h>
-# include <sys/stat.h>
-# include <unistd.h>
-
-static const char fname[] =
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nZ";
-static const char qname[] =
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nZ";
+# define kernel_dirent_type kernel_dirent_t
+# define NR_getdents	__NR_getdents
+# define STR_getdents	"getdents"
 
-static char buf[8192];
+# include "xgetdents.c"
 
-static const char *
-str_d_type(const unsigned char d_type)
-{
-	switch (d_type) {
-		case DT_DIR:
-			return "DT_DIR";
-		case DT_REG:
-			return "DT_REG";
-		default:
-			return "DT_UNKNOWN";
-	}
-}
+# if VERBOSE
 static void
-print_dirent(const kernel_dirent *d)
+print_dirent(const kernel_dirent_type *d)
 {
-	const unsigned int d_name_offset = offsetof(kernel_dirent, d_name);
-	int d_name_len = d->d_reclen - d_name_offset - 1;
-	assert(d_name_len > 0);
-
-	printf("{d_ino=%llu, d_off=%llu, d_reclen=%u, d_name=",
-	       (unsigned long long) d->d_ino,
-	       (unsigned long long) d->d_off, d->d_reclen);
-
-	if (d->d_name[0] == '.')
-		printf("\"%.*s\"", d_name_len, d->d_name);
-	else
-		printf("\"%s\"", qname);
-
+	const unsigned int d_name_offset = offsetof(kernel_dirent_type, d_name);
+	int d_name_len = (int) d->d_reclen - d_name_offset - 1;
+	if (d_name_len <= 0)
+		error_msg_and_fail("d_name_len = %d", d_name_len);
+
+	PRINT_FIELD_U("{", *d, d_ino);
+	PRINT_FIELD_U(", ", *d, d_off);
+	PRINT_FIELD_U(", ", *d, d_reclen);
+	printf(", d_name=");
+	print_quoted_cstring(d->d_name, d_name_len);
 	printf(", d_type=%s}",
 	       str_d_type(*((const char *) d + d->d_reclen - 1)));
 }
-
-int
-main(void)
-{
-	static const char dname[] = "getdents.test.tmp.dir";
-
-	assert(!mkdir(dname, 0700));
-	assert(!chdir(dname));
-	(void) close(0);
-	assert(!creat(fname, 0600));
-	assert(!close(0));
-	assert(!open(".", O_RDONLY | O_DIRECTORY));
-
-	unsigned long count = (unsigned long) 0xfacefeeddeadbeefULL;
-	long rc = syscall(__NR_getdents, (long) 0xdefacedffffffffULL, NULL,
-			  count);
-	printf("getdents(-1, NULL, %u) = %ld %s (%m)\n",
-	       (unsigned) count, rc, errno2name());
-
-	count = (unsigned long) 0xfacefeed00000000ULL | sizeof(buf);
-	while ((rc = syscall(__NR_getdents, 0, buf, count))) {
-		kernel_dirent *d;
-		long i;
-
-		if (rc < 0)
-			perror_msg_and_skip("getdents");
-		printf("getdents(0, [");
-		for (i = 0; i < rc; i += d->d_reclen) {
-			d = (kernel_dirent *) &buf[i];
-			if (i)
-				printf(", ");
-			print_dirent(d);
-		}
-		printf("], %u) = %ld\n", (unsigned) count, rc);
-	}
-	printf("getdents(0, [], %u) = 0\n", (unsigned) count);
-	puts("+++ exited with 0 +++");
-	assert(!unlink(fname));
-	assert(!chdir(".."));
-	assert(!rmdir(dname));
-
-	return 0;
-}
+# endif
 
 #else
 
diff -pruN 5.5-3/tests/getdents.gen.test 5.9-0ubuntu2/tests/getdents.gen.test
--- 5.5-3/tests/getdents.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests/getdents.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -1,4 +1,4 @@
 #!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getdents -a22 -v); do not edit.
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getdents -a31 ); do not edit.
 . "${srcdir=.}/init.sh"
-run_strace_match_diff -a22 -v
+run_strace_match_diff -a31 
diff -pruN 5.5-3/tests/getdents-v.c 5.9-0ubuntu2/tests/getdents-v.c
--- 5.5-3/tests/getdents-v.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/getdents-v.c	2020-04-11 01:01:47.000000000 +0000
@@ -0,0 +1,3 @@
+/* Check --no-abbrev decoding of getdents syscall.  */
+#define VERBOSE 1
+#include "getdents.c"
diff -pruN 5.5-3/tests/getdents-v.gen.test 5.9-0ubuntu2/tests/getdents-v.gen.test
--- 5.5-3/tests/getdents-v.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/getdents-v.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getdents-v -a22 -v --trace=getdents); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a22 -v --trace=getdents
diff -pruN 5.5-3/tests/getpgrp.c 5.9-0ubuntu2/tests/getpgrp.c
--- 5.5-3/tests/getpgrp.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/getpgrp.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -7,6 +7,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #ifdef __NR_getpgrp
 
@@ -16,8 +17,13 @@
 int
 main(void)
 {
-	printf("getpgrp() = %ld\n", syscall(__NR_getpgrp));
+	PIDNS_TEST_INIT;
 
+	pidns_print_leader();
+	printf("getpgrp() = %d%s\n", (int) syscall(__NR_getpgrp),
+		pidns_pid2str(PT_PGID));
+
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests/getpgrp--pidns-translation.c 5.9-0ubuntu2/tests/getpgrp--pidns-translation.c
--- 5.5-3/tests/getpgrp--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/getpgrp--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "getpgrp.c"
diff -pruN 5.5-3/tests/getpgrp--pidns-translation.gen.test 5.9-0ubuntu2/tests/getpgrp--pidns-translation.gen.test
--- 5.5-3/tests/getpgrp--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/getpgrp--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getpgrp--pidns-translation test_pidns -e trace=getpgrp -a10); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -e trace=getpgrp -a10
diff -pruN 5.5-3/tests/getpid.c 5.9-0ubuntu2/tests/getpid.c
--- 5.5-3/tests/getpid.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/getpid.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -7,6 +7,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #if defined __NR_getpid && (!defined __NR_getxpid || __NR_getxpid != __NR_getpid)
 
@@ -16,7 +17,12 @@
 int
 main(void)
 {
-	printf("getpid() = %ld\n", syscall(__NR_getpid));
+	PIDNS_TEST_INIT;
+
+	pidns_print_leader();
+	printf("getpid() = %d%s\n", (int) syscall(__NR_getpid),
+		pidns_pid2str(PT_TGID));
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests/getpid--pidns-translation.c 5.9-0ubuntu2/tests/getpid--pidns-translation.c
--- 5.5-3/tests/getpid--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/getpid--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "getpid.c"
diff -pruN 5.5-3/tests/getpid--pidns-translation.gen.test 5.9-0ubuntu2/tests/getpid--pidns-translation.gen.test
--- 5.5-3/tests/getpid--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/getpid--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getpid--pidns-translation test_pidns -e trace=getpid -a9); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -e trace=getpid -a9
diff -pruN 5.5-3/tests/get_process_reaper.c 5.9-0ubuntu2/tests/get_process_reaper.c
--- 5.5-3/tests/get_process_reaper.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/get_process_reaper.c	2020-04-03 22:58:26.000000000 +0000
@@ -0,0 +1,108 @@
+/*
+ * Print the process reaper id.
+ *
+ * Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include <stdio.h>
+#include <unistd.h>
+#include <sys/wait.h>
+
+/* PARENT - CHILD - GRANDCHILD */
+
+static int
+grandchild(int read_fd, int write_fd)
+{
+	/* wait for notification from PARENT about CHILD completion */
+	pid_t pid;
+	if (read(read_fd, &pid, sizeof(pid)) != 0)
+		perror_msg_and_fail("read");
+
+	/* write ppid to PARENT */
+	pid = getppid();
+	if (write(write_fd, &pid, sizeof(pid)) != sizeof(pid))
+		perror_msg_and_fail("write");
+
+	_exit(0);
+}
+
+static int
+child(int read_fd, int write_fd)
+{
+	pid_t pid = fork();
+	if (pid < 0)
+		perror_msg_and_fail("fork");
+
+	if (!pid)
+		return grandchild(read_fd, write_fd);
+	else
+		_exit(0);
+}
+
+static int
+parent(pid_t pid, int read_fd, int write_fd)
+{
+	/* wait for CHILD completion */
+	int status;
+	if (waitpid(pid, &status, 0) != pid)
+		perror_msg_and_fail("waitpid");
+	if (status != 0)
+		error_msg_and_fail("status %x", status);
+
+	/* notify GRANDCHILD about CHILD completion */
+	close(write_fd),
+	      write_fd = -1;
+
+	/* read ppid of GRANDCHILD */
+	if (read(read_fd, &pid, sizeof(pid)) != sizeof(pid))
+		perror_msg_and_fail("read");
+
+	printf("%d\n", pid);
+	return 0;
+}
+
+int
+main(void)
+{
+	int parent_grandchild_fds[2];
+#define parent_read_fd		parent_grandchild_fds[0]
+#define grandchild_write_fd	parent_grandchild_fds[1]
+
+	int grandchild_parent_fds[2];
+#define grandchild_read_fd	grandchild_parent_fds[0]
+#define parent_write_fd		grandchild_parent_fds[1]
+
+	if (pipe(parent_grandchild_fds) ||
+	    pipe(grandchild_parent_fds))
+		perror_msg_and_fail("pipe");
+
+	pid_t pid = fork();
+	if (pid < 0)
+		perror_msg_and_fail("fork");
+
+	if (!pid) {
+		/* CHILD */
+		close(parent_read_fd),
+		      parent_read_fd = -1;
+
+		close(parent_write_fd),
+		      parent_write_fd = -1;
+
+		return child(grandchild_read_fd,
+			     grandchild_write_fd);
+	} else {
+		/* PARENT */
+		close(grandchild_read_fd),
+		      grandchild_read_fd = -1;
+
+		close(grandchild_write_fd),
+		      grandchild_write_fd = -1;
+
+		return parent(pid, parent_read_fd,
+				   parent_write_fd);
+	}
+}
diff -pruN 5.5-3/tests/getrusage.c 5.9-0ubuntu2/tests/getrusage.c
--- 5.5-3/tests/getrusage.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/getrusage.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2016 Fei Jie <feij.fnst@cn.fujitsu.com>
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -18,30 +18,41 @@
 # include <unistd.h>
 # include <errno.h>
 
+# include "kernel_rusage.h"
 # include "xlat.h"
 # include "xlat/usagewho.h"
 
 int
-invoke_print(int who, const char *who_str, struct rusage *usage)
+invoke_print(int who, const char *who_str, kernel_rusage_t *usage)
 {
 	int rc = syscall(__NR_getrusage, who, usage);
 	int saved_errno = errno;
 	printf("getrusage(%s, {ru_utime={tv_sec=%lld, tv_usec=%llu}"
-	       ", ru_stime={tv_sec=%lld, tv_usec=%llu}, ru_maxrss=%lu"
-	       ", ru_ixrss=%lu, ru_idrss=%lu, ru_isrss=%lu, ru_minflt=%lu"
-	       ", ru_majflt=%lu, ru_nswap=%lu, ru_inblock=%lu"
-	       ", ru_oublock=%lu, ru_msgsnd=%lu, ru_msgrcv=%lu"
-	       ", ru_nsignals=%lu, ru_nvcsw=%lu, ru_nivcsw=%lu}) = %s\n",
+	       ", ru_stime={tv_sec=%lld, tv_usec=%llu}, ru_maxrss=%llu"
+	       ", ru_ixrss=%llu, ru_idrss=%llu, ru_isrss=%llu, ru_minflt=%llu"
+	       ", ru_majflt=%llu, ru_nswap=%llu, ru_inblock=%llu"
+	       ", ru_oublock=%llu, ru_msgsnd=%llu, ru_msgrcv=%llu"
+	       ", ru_nsignals=%llu, ru_nvcsw=%llu, ru_nivcsw=%llu}) = %s\n",
 	       who_str,
 	       (long long) usage->ru_utime.tv_sec,
 	       zero_extend_signed_to_ull(usage->ru_utime.tv_usec),
 	       (long long) usage->ru_stime.tv_sec,
 	       zero_extend_signed_to_ull(usage->ru_stime.tv_usec),
-	       usage->ru_maxrss, usage->ru_ixrss, usage->ru_idrss,
-	       usage->ru_isrss, usage->ru_minflt, usage->ru_majflt,
-	       usage->ru_nswap, usage->ru_inblock, usage->ru_oublock,
-	       usage->ru_msgsnd, usage->ru_msgrcv, usage->ru_nsignals,
-	       usage->ru_nvcsw, usage->ru_nivcsw, sprintrc(rc));
+	       zero_extend_signed_to_ull(usage->ru_maxrss),
+	       zero_extend_signed_to_ull(usage->ru_ixrss),
+	       zero_extend_signed_to_ull(usage->ru_idrss),
+	       zero_extend_signed_to_ull(usage->ru_isrss),
+	       zero_extend_signed_to_ull(usage->ru_minflt),
+	       zero_extend_signed_to_ull(usage->ru_majflt),
+	       zero_extend_signed_to_ull(usage->ru_nswap),
+	       zero_extend_signed_to_ull(usage->ru_inblock),
+	       zero_extend_signed_to_ull(usage->ru_oublock),
+	       zero_extend_signed_to_ull(usage->ru_msgsnd),
+	       zero_extend_signed_to_ull(usage->ru_msgrcv),
+	       zero_extend_signed_to_ull(usage->ru_nsignals),
+	       zero_extend_signed_to_ull(usage->ru_nvcsw),
+	       zero_extend_signed_to_ull(usage->ru_nivcsw),
+	       sprintrc(rc));
 	errno = saved_errno;
 	return rc;
 }
@@ -49,7 +60,7 @@ invoke_print(int who, const char *who_st
 int
 main(void)
 {
-	TAIL_ALLOC_OBJECT_CONST_PTR(struct rusage, usage);
+	TAIL_ALLOC_OBJECT_CONST_PTR(kernel_rusage_t, usage);
 	if (invoke_print(ARG_STR(RUSAGE_SELF), usage)) {
 		perror_msg_and_fail("RUSAGE_SELF");
 	}
diff -pruN 5.5-3/tests/getsid.c 5.9-0ubuntu2/tests/getsid.c
--- 5.5-3/tests/getsid.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/getsid.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,20 +1,27 @@
 /*
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include "pidns.h"
+
 #include <stdio.h>
 #include <unistd.h>
 
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	pid_t pid = getpid();
-	printf("getsid(%d) = %d\n", pid, getsid(pid));
+	pidns_print_leader();
+	printf("getsid(%d%s) = %d%s\n", pid, pidns_pid2str(PT_TGID),
+		getsid(pid), pidns_pid2str(PT_SID));
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests/getsid--pidns-translation.c 5.9-0ubuntu2/tests/getsid--pidns-translation.c
--- 5.5-3/tests/getsid--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/getsid--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "getsid.c"
diff -pruN 5.5-3/tests/getsid--pidns-translation.gen.test 5.9-0ubuntu2/tests/getsid--pidns-translation.gen.test
--- 5.5-3/tests/getsid--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/getsid--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getsid--pidns-translation test_pidns -e trace=getsid -a10); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -e trace=getsid -a10
diff -pruN 5.5-3/tests/gettid.c 5.9-0ubuntu2/tests/gettid.c
--- 5.5-3/tests/gettid.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/gettid.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -9,11 +9,17 @@
 #include <stdio.h>
 #include <unistd.h>
 #include "scno.h"
+#include "pidns.h"
 
 int
 main(void)
 {
-	printf("gettid() = %ld\n", syscall(__NR_gettid));
+	PIDNS_TEST_INIT;
+
+	pidns_print_leader();
+	printf("gettid() = %d%s\n", (int) syscall(__NR_gettid),
+		pidns_pid2str(PT_TID));
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests/gettid--pidns-translation.c 5.9-0ubuntu2/tests/gettid--pidns-translation.c
--- 5.5-3/tests/gettid--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/gettid--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "gettid.c"
diff -pruN 5.5-3/tests/gettid--pidns-translation.test 5.9-0ubuntu2/tests/gettid--pidns-translation.test
--- 5.5-3/tests/gettid--pidns-translation.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/gettid--pidns-translation.test	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,18 @@
+#!/bin/sh
+#
+# Check pidns translation of gettid's return value.
+#
+# Copyright (c) 2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: LGPL-2.1-or-later
+
+. "${srcdir=.}/init.sh"
+
+run_prog > /dev/null
+run_strace -a9 --pidns-translation -f -e trace=gettid $args > "$EXP"
+parent_pid="$(tail -n 2 $LOG | head -n 1 | cut -d' ' -f1)"
+init_pid="$(tail -n 1 $LOG | cut -d' ' -f1)"
+# uniq: filter out extra gettid calls made by musl libc
+grep -E -v "^($parent_pid|$init_pid) |unfinished|resumed" "$LOG" | uniq > "$OUT"
+match_diff "$OUT" "$EXP"
diff -pruN 5.5-3/tests/getuid.test 5.9-0ubuntu2/tests/getuid.test
--- 5.5-3/tests/getuid.test	2020-01-05 21:09:51.000000000 +0000
+++ 5.9-0ubuntu2/tests/getuid.test	2020-03-31 22:57:10.000000000 +0000
@@ -9,14 +9,25 @@
 
 . "${srcdir=.}/init.sh"
 
+check_prog grep
 check_prog uniq
+
 if [ "${NAME%-creds}" = "$NAME" ]; then
 	syscall="$NAME"
 else
 	NAME="${NAME%-creds}"
 	syscall='%creds'
 fi
+
 run_prog > /dev/null
 run_strace -qq -a9 -e"$syscall" $args > "$EXP"
-uniq < "$LOG" > "$OUT"
+
+case "$STRACE_ARCH:$syscall" in
+	mips:%creds)
+		grep -Fxv 'prctl(PR_GET_FP_MODE) = 0' < "$LOG" | uniq > "$OUT"
+		;;
+	*)	uniq < "$LOG" > "$OUT"
+		;;
+esac
+
 match_diff "$OUT" "$EXP"
diff -pruN 5.5-3/tests/getxgid.c 5.9-0ubuntu2/tests/getxgid.c
--- 5.5-3/tests/getxgid.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/getxgid.c	2020-04-03 22:58:26.000000000 +0000
@@ -0,0 +1,31 @@
+/*
+ * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2016-2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+
+#ifdef __NR_getxgid
+
+# include <stdio.h>
+# include <unistd.h>
+
+int
+main(void)
+{
+	long id = syscall(__NR_getxgid);
+	printf("getxgid() = %ld (egid %ld)\n", id, id);
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_getxgid")
+
+#endif
diff -pruN 5.5-3/tests/getxgid.gen.test 5.9-0ubuntu2/tests/getxgid.gen.test
--- 5.5-3/tests/getxgid.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/getxgid.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getxgid -a10 ); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a10 
diff -pruN 5.5-3/tests/getxpid.c 5.9-0ubuntu2/tests/getxpid.c
--- 5.5-3/tests/getxpid.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/getxpid.c	2020-04-03 22:58:26.000000000 +0000
@@ -0,0 +1,34 @@
+/*
+ * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2016-2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+
+#ifdef __NR_getxpid
+
+# include <stdio.h>
+# include <unistd.h>
+
+int
+main(void)
+{
+	long id = syscall(__NR_getxpid);
+	pid_t ppid = getppid();
+
+	printf("getxpid() = %ld (ppid %ld)\n", id, (long) ppid);
+	printf("getxpid() = %ld (ppid %ld)\n", id, (long) ppid);
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_getxpid")
+
+#endif
diff -pruN 5.5-3/tests/getxpid.gen.test 5.9-0ubuntu2/tests/getxpid.gen.test
--- 5.5-3/tests/getxpid.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/getxpid.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getxpid -a10 ); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a10 
diff -pruN 5.5-3/tests/getxuid.c 5.9-0ubuntu2/tests/getxuid.c
--- 5.5-3/tests/getxuid.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/getxuid.c	2020-04-03 22:58:26.000000000 +0000
@@ -0,0 +1,31 @@
+/*
+ * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2016-2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+
+#ifdef __NR_getxuid
+
+# include <stdio.h>
+# include <unistd.h>
+
+int
+main(void)
+{
+	long id = syscall(__NR_getxuid);
+	printf("getxuid() = %ld (euid %ld)\n", id, id);
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_getxuid")
+
+#endif
diff -pruN 5.5-3/tests/getxuid.gen.test 5.9-0ubuntu2/tests/getxuid.gen.test
--- 5.5-3/tests/getxuid.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/getxuid.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getxuid -a10 ); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a10 
diff -pruN 5.5-3/tests/getxxid.c 5.9-0ubuntu2/tests/getxxid.c
--- 5.5-3/tests/getxxid.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/getxxid.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,42 +0,0 @@
-/*
- * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
- * All rights reserved.
- *
- * SPDX-License-Identifier: GPL-2.0-or-later
- */
-
-#include "tests.h"
-#include "scno.h"
-
-#if defined __NR_getxpid && defined __NR_getxuid && defined __NR_getxgid
-
-# include <stdio.h>
-# include <unistd.h>
-
-int
-main(void)
-{
-	long id;
-	pid_t ppid;
-
-	id = syscall(__NR_getxpid);
-	ppid = getppid();
-	printf("getxpid() = %ld (ppid %ld)\n", id, (long) ppid);
-	printf("getxpid() = %ld (ppid %ld)\n", id, (long) ppid);
-
-	id = syscall(__NR_getxuid);
-	printf("getxuid() = %ld (euid %ld)\n", id, id);
-
-	id = syscall(__NR_getxgid);
-	printf("getxgid() = %ld (egid %ld)\n", id, id);
-
-	puts("+++ exited with 0 +++");
-	return 0;
-}
-
-#else
-
-SKIP_MAIN_UNDEFINED("__NR_getxpid && __NR_getxuid && __NR_getxgid")
-
-#endif
diff -pruN 5.5-3/tests/getxxid.gen.test 5.9-0ubuntu2/tests/getxxid.gen.test
--- 5.5-3/tests/getxxid.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests/getxxid.gen.test	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-#!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getxxid -a10 -e trace=getxpid,getxuid,getxgid); do not edit.
-. "${srcdir=.}/init.sh"
-run_strace_match_diff -a10 -e trace=getxpid,getxuid,getxgid
diff -pruN 5.5-3/tests/init.sh 5.9-0ubuntu2/tests/init.sh
--- 5.5-3/tests/init.sh	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests/init.sh	2020-08-25 14:29:30.000000000 +0000
@@ -189,7 +189,7 @@ match_diff()
 # dump both files and fail with ERROR_MESSAGE.
 match_grep()
 {
-	local output patterns error pattern cnt failed=
+	local output patterns error pattern cnt failed= rc negated
 	if [ $# -eq 0 ]; then
 		output="$LOG"
 	else
@@ -211,7 +211,15 @@ match_grep()
 
 	cnt=1
 	while read -r pattern; do
-		LC_ALL=C grep -E -x -e "$pattern" < "$output" > /dev/null || {
+		negated=0
+		[ "x${pattern#!}" = "x${pattern}" ] ||
+			negated=1
+
+		rc="$negated"
+		LC_ALL=C grep -E -x -e "${pattern#!}" < "$output" > /dev/null ||
+			rc="$((!negated))"
+
+		[ 0 = "$rc" ] || {
 			test -n "$failed" || {
 				echo 'Failed patterns of expected output:'
 				failed=1
@@ -219,7 +227,8 @@ match_grep()
 			printf '#%d: %s\n' "$cnt" "$pattern"
 		}
 		cnt=$(($cnt + 1))
-	done < "$patterns"
+	done < "$patterns" ||
+		fail_ "Error reading patterns from \"$patterns\""
 	test -z "$failed" || {
 		echo 'Actual output:'
 		cat < "$output"
@@ -231,7 +240,7 @@ match_grep()
 run_strace_match_diff()
 {
 	args="$*"
-	[ -n "$args" -a -z "${args##*-e trace=*}" ] ||
+	[ -n "$args" -a \( -z "${args##*-e trace=*}" -o -z "${args##*--trace=*}" \) ] ||
 		set -- -e trace="$NAME" "$@"
 	run_prog > /dev/null
 	run_strace "$@" $args > "$EXP"
@@ -242,7 +251,7 @@ run_strace_match_diff()
 run_strace_match_grep()
 {
 	args="$*"
-	[ -n "$args" -a -z "${args##*-e trace=*}" ] ||
+	[ -n "$args" -a \( -z "${args##*-e trace=*}" -o -z "${args##*--trace=*}" \) ] ||
 		set -- -e trace="$NAME" "$@"
 	run_prog > /dev/null
 	run_strace "$@" $args > "$EXP"
@@ -281,7 +290,7 @@ require_min_nproc()
 	local min_nproc
 	min_nproc="$1"; shift
 
-	check_prog
+	check_prog nproc
 	local nproc
 	nproc="$(nproc)"
 
@@ -339,6 +348,13 @@ test_pure_prog_set()
 
 		try_run_prog "../$t" || continue
 		run_strace $prog_args "$@" "../$t" > "$expfile"
+
+		case "$STRACE_ARCH:$MIPS_ABI:$NAME" in
+			mips:o32:*creds)
+				sed -i '/^prctl(PR_GET_FP_MODE)  *= 0$/d' "$LOG"
+				;;
+		esac
+
 		match_diff "$LOG" "$expfile"
 	} < /dev/null; done
 }
@@ -371,6 +387,36 @@ test_prog_set()
 	test_pure_prog_set "$@" < "$srcdir/$NAME.in"
 }
 
+test_pidns_run_strace()
+{
+	local parent_pid init_pid
+
+	check_prog tail
+	check_prog cut
+	check_prog grep
+
+	run_prog > /dev/null
+	run_strace --pidns-translation -f $@ $args > "$EXP"
+
+	# filter out logs made by the parent or init process of the pidns test
+	parent_pid="$(tail -n 2 $LOG | head -n 1 | cut -d' ' -f1)"
+	init_pid="$(tail -n 1 $LOG | cut -d' ' -f1)"
+	grep -E -v "^($parent_pid|$init_pid) " "$LOG" > "$OUT"
+	match_diff "$OUT" "$EXP"
+}
+
+test_pidns()
+{
+	check_prog unshare
+	unshare -Urpf true || framework_skip_ "unshare -Urpf true failed"
+
+	test_pidns_run_strace "$@"
+
+	# test PID translation when /proc is mounted from an other namespace
+	STRACE="unshare -Urpf $STRACE"
+	test_pidns_run_strace "$@"
+}
+
 check_prog cat
 check_prog rm
 
@@ -412,7 +458,7 @@ fi
 : "${STRACE_EXE:=$STRACE}"
 export STRACE_EXE
 
-: "${TIMEOUT_DURATION:=600}"
+: "${TIMEOUT_DURATION:=1500}"
 : "${SLEEP_A_BIT:=sleep 1}"
 
 [ -z "${VERBOSE-}" ] ||
diff -pruN 5.5-3/tests/inject-nf.c 5.9-0ubuntu2/tests/inject-nf.c
--- 5.5-3/tests/inject-nf.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/inject-nf.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check decoding of return values injected into a syscall that "never fails".
  *
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -16,28 +16,26 @@
 
 #include "raw_syscall.h"
 
-#ifdef __alpha__
-/* alpha has no getpid */
-# define SC_NR __NR_getpgrp
-# define SC_NAME "getpgrp"
-# define getpid getpgrp
+#ifdef __NR_geteuid32
+# define SC_NR __NR_geteuid32
+# define SC_NAME "geteuid32"
 #else
-# define SC_NR __NR_getpid
-# define SC_NAME "getpid"
+# define SC_NR __NR_geteuid
+# define SC_NAME "geteuid"
 #endif
 
 #ifdef raw_syscall_0
 # define INVOKE_SC(err) raw_syscall_0(SC_NR, &err)
 #else
-/* No raw_syscall_0, let's use getpid() and hope for the best.  */
-# define INVOKE_SC(err) getpid()
+/* No raw_syscall_0, let's use geteuid() and hope for the best. */
+# define INVOKE_SC(err) geteuid()
 #endif
 
 /*
  * This prototype is intentionally different
  * from the prototype provided by <unistd.h>.
  */
-extern kernel_ulong_t getpid(void);
+extern kernel_ulong_t geteuid(void);
 
 int
 main(int ac, char **av)
@@ -45,7 +43,7 @@ main(int ac, char **av)
 	assert(ac == 1 || ac == 2);
 
 	kernel_ulong_t expected =
-		(ac == 1) ? getpid() : strtoull(av[1], NULL, 0);
+		(ac == 1) ? geteuid() : strtoull(av[1], NULL, 0);
 	kernel_ulong_t err = 0;
 	kernel_ulong_t rc = INVOKE_SC(err);
 
diff -pruN 5.5-3/tests/inject-nf.test 5.9-0ubuntu2/tests/inject-nf.test
--- 5.5-3/tests/inject-nf.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/inject-nf.test	2020-08-03 08:00:00.000000000 +0000
@@ -2,21 +2,14 @@
 #
 # Check decoding of return values injected into a syscall that "never fails".
 #
-# Copyright (c) 2018 The strace developers.
+# Copyright (c) 2018-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/scno_tampering.sh"
 
-case "$STRACE_ARCH" in
-alpha)
-	SYSCALL=getpgrp
-	;;
-*)
-	SYSCALL=getpid
-	;;
-esac
+SYSCALL='/^geteuid(32)?$'
 
 run_prog
 prog="$args"
diff -pruN 5.5-3/tests/ioctl_block.c 5.9-0ubuntu2/tests/ioctl_block.c
--- 5.5-3/tests/ioctl_block.c	2019-07-24 17:12:18.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_block.c	2020-08-25 14:29:30.000000000 +0000
@@ -2,14 +2,16 @@
  * This file is part of ioctl_block strace test.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include "pidns.h"
 #include <errno.h>
+#include <unistd.h>
 #include <inttypes.h>
 #include <stdio.h>
 #include <string.h>
@@ -41,12 +43,15 @@ static struct xlat_data block_argless[]
 #define TEST_NULL_ARG(cmd)						\
 	do {								\
 		ioctl(-1, cmd, 0);					\
+		pidns_print_leader();					\
 		printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n", #cmd);	\
 	} while (0)
 
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	TEST_NULL_ARG(BLKBSZGET);
 	TEST_NULL_ARG(BLKBSZSET);
 	TEST_NULL_ARG(BLKFRAGET);
@@ -91,18 +96,22 @@ main(void)
 #endif
 
 	ioctl(-1, BLKRASET, lmagic);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKRASET, %lu) = -1 EBADF (%m)\n", lmagic);
 
 	ioctl(-1, BLKFRASET, lmagic);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKFRASET, %lu) = -1 EBADF (%m)\n", lmagic);
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(int, val_int);
 	*val_int = magic;
 
 	ioctl(-1, BLKROSET, val_int);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKROSET, [%d]) = -1 EBADF (%m)\n", *val_int);
 
 	ioctl(-1, BLKBSZSET, val_int);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKBSZSET, [%d]) = -1 EBADF (%m)\n", *val_int);
 
 	uint64_t *pair_int64 = tail_alloc(sizeof(*pair_int64) * 2);
@@ -111,18 +120,21 @@ main(void)
 
 #ifdef BLKDISCARD
 	ioctl(-1, BLKDISCARD, pair_int64);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKDISCARD, [%" PRIu64 ", %" PRIu64 "])"
 	       " = -1 EBADF (%m)\n", pair_int64[0], pair_int64[1]);
 #endif
 
 #ifdef BLKSECDISCARD
 	ioctl(-1, BLKSECDISCARD, pair_int64);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKSECDISCARD, [%" PRIu64 ", %" PRIu64 "])"
 	       " = -1 EBADF (%m)\n", pair_int64[0], pair_int64[1]);
 #endif
 
 #ifdef BLKZEROOUT
 	ioctl(-1, BLKZEROOUT, pair_int64);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKZEROOUT, [%" PRIu64 ", %" PRIu64 "])"
 	       " = -1 EBADF (%m)\n", pair_int64[0], pair_int64[1]);
 #endif
@@ -134,6 +146,7 @@ main(void)
 	blkpg->data = (void *) (unsigned long) 0xcafef00dfffffeedULL;
 
 	ioctl(-1, BLKPG, blkpg);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKPG, {op=%s, flags=%d, datalen=%d"
 	       ", data=%#lx}) = -1 EBADF (%m)\n",
 	       "BLKPG_RESIZE_PARTITION", blkpg->flags, blkpg->datalen,
@@ -149,6 +162,7 @@ main(void)
 	blkpg->data = bp;
 
 	ioctl(-1, BLKPG, blkpg);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKPG, {op=%s, flags=%d, datalen=%d"
 	       ", data={start=%lld, length=%lld, pno=%d"
 	       ", devname=\"%.*s\"..., volname=\"%.*s\"...}})"
@@ -162,25 +176,31 @@ main(void)
 #if defined BLKTRACESETUP && defined HAVE_STRUCT_BLK_USER_TRACE_SETUP
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct blk_user_trace_setup, buts);
 	fill_memory(buts, sizeof(*buts));
+	buts->pid = getpid();
 
 	ioctl(-1, BLKTRACESETUP, buts);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKTRACESETUP, {act_mask=%hu, buf_size=%u, buf_nr=%u"
-	       ", start_lba=%" PRI__u64 ", end_lba=%" PRI__u64 ", pid=%u})"
+	       ", start_lba=%" PRI__u64 ", end_lba=%" PRI__u64 ", pid=%d%s})"
 	       " = -1 EBADF (%m)\n",
 	       buts->act_mask, buts->buf_size, buts->buf_nr,
-	       buts->start_lba, buts->end_lba, buts->pid);
+	       buts->start_lba, buts->end_lba, buts->pid,
+	       pidns_pid2str(PT_TGID));
 #endif
 
 	unsigned int i;
 	for (i = 0; i < ARRAY_SIZE(block_argless); ++i) {
 		ioctl(-1, (unsigned long) block_argless[i].val, lmagic);
+		pidns_print_leader();
 		printf("ioctl(-1, %s) = -1 EBADF (%m)\n", block_argless[i].str);
 	}
 
 	ioctl(-1, _IOC(_IOC_READ, 0x12, 0xfe, 0xff), lmagic);
+	pidns_print_leader();
 	printf("ioctl(-1, %s, %#lx) = -1 EBADF (%m)\n",
 	       "_IOC(_IOC_READ, 0x12, 0xfe, 0xff)", lmagic);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests/ioctl_block--pidns-translation.c 5.9-0ubuntu2/tests/ioctl_block--pidns-translation.c
--- 5.5-3/tests/ioctl_block--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_block--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "ioctl_block.c"
diff -pruN 5.5-3/tests/ioctl_block--pidns-translation.test 5.9-0ubuntu2/tests/ioctl_block--pidns-translation.test
--- 5.5-3/tests/ioctl_block--pidns-translation.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_block--pidns-translation.test	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,22 @@
+#!/bin/sh
+#
+# Check pidns translation of ioctl(BLK*) syscall decoding.
+#
+# Copyright (c) 2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: LGPL-2.1-or-later
+
+. "${srcdir=.}/init.sh"
+
+check_prog head
+check_prog tail
+check_prog cut
+check_prog grep
+
+run_prog > /dev/null
+run_strace --pidns-translation -f -a16 -e trace=ioctl $@ $args > "$EXP"
+parent_pid="$(tail -n 2 $LOG | head -n 1 | cut -d' ' -f1)"
+init_pid="$(tail -n 1 $LOG | cut -d' ' -f1)"
+grep -E -v "^($parent_pid|$init_pid) |ioctl\([0123][,<]" "$LOG" > "$OUT"
+match_diff "$OUT" "$EXP"
diff -pruN 5.5-3/tests/ioctl.c 5.9-0ubuntu2/tests/ioctl.c
--- 5.5-3/tests/ioctl.c	2018-12-30 15:35:21.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -14,6 +14,8 @@
 #include <termios.h>
 #include <sys/ioctl.h>
 
+#include <linux/types.h>
+
 #ifdef HAVE_LINUX_MMTIMER_H
 # include <linux/mmtimer.h>
 #endif
diff -pruN 5.5-3/tests/ioctl_evdev.c 5.9-0ubuntu2/tests/ioctl_evdev.c
--- 5.5-3/tests/ioctl_evdev.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_evdev.c	2020-08-03 08:00:00.000000000 +0000
@@ -2,7 +2,7 @@
  * This file is part of ioctl_evdev strace test.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -50,7 +50,7 @@ static void
 print_ffe_common(const struct ff_effect *const ffe, const char *const type_str)
 {
 	printf("ioctl(-1, %s", XLAT_STR(EVIOCSFF));
-	printf(", {type=%s, id=%" PRIu16
+	printf(", {type=%s, id=%" PRId16
 	       ", direction=%" PRIu16 ", ",
 	       sprintxlat(type_str, ffe->type, NULL),
 	       ffe->id, ffe->direction);
@@ -223,7 +223,7 @@ main(void)
 	for (i = 0; i < ARRAY_SIZE(ike->scancode); ++i) {
 		if (i > 0)
 			printf(", ");
-		printf("%" PRIx8, ike->scancode[i]);
+		printf("%#" PRIx8, ike->scancode[i]);
 	}
 	printf("]");
 #  else
diff -pruN 5.5-3/tests/ioctl_evdev-success.c 5.9-0ubuntu2/tests/ioctl_evdev-success.c
--- 5.5-3/tests/ioctl_evdev-success.c	2019-10-22 17:44:08.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_evdev-success.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -99,10 +99,10 @@ print_input_id(long rc, const void *ptr,
 		printf("%p", id);
 		return;
 	}
-	printf("{ID_BUS=%" PRIu16
-	       ", ID_VENDOR=%" PRIu16
-	       ", ID_PRODUCT=%" PRIu16
-	       ", ID_VERSION=%" PRIu16 "}",
+	printf("{bustype=%" PRIu16
+	       ", vendor=%" PRIu16
+	       ", product=%" PRIu16
+	       ", version=%" PRIu16 "}",
 	       id->bustype, id->vendor, id->product, id->version);
 }
 
diff -pruN 5.5-3/tests/ioctl_hdio.c 5.9-0ubuntu2/tests/ioctl_hdio.c
--- 5.5-3/tests/ioctl_hdio.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,227 @@
+/*
+ * Check HDIO_* ioctl decoding.
+ *
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+
+#include <errno.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <linux/hdreg.h>
+#include <sys/ioctl.h>
+
+static const char *errstr;
+
+static long
+do_ioctl(kernel_ulong_t cmd, kernel_ulong_t arg)
+{
+	long rc = ioctl(-1, cmd, arg);
+
+	errstr = sprintrc(rc);
+
+#ifdef INJECT_RETVAL
+	if (rc != INJECT_RETVAL)
+		error_msg_and_fail("Got a return value of %ld != %ld",
+				   rc, (long) INJECT_RETVAL);
+
+	static char inj_errstr[4096];
+
+	snprintf(inj_errstr, sizeof(inj_errstr), "%s (INJECTED)", errstr);
+	errstr = inj_errstr;
+#endif
+
+	return rc;
+}
+
+static inline long
+do_ioctl_ptr(kernel_ulong_t cmd, const void *arg)
+{
+	return do_ioctl(cmd, (uintptr_t) arg);
+}
+
+int
+main(int argc, char *argv[])
+{
+#ifdef INJECT_RETVAL
+	unsigned long num_skip;
+	bool locked = false;
+
+	if (argc < 2)
+		error_msg_and_fail("Usage: %s NUM_SKIP", argv[0]);
+
+	num_skip = strtoul(argv[1], NULL, 0);
+
+	for (size_t i = 0; i < num_skip; i++) {
+		long ret = ioctl(-1, HDIO_GET_UNMASKINTR, 0);
+
+		printf("ioctl(-1, %s, 0) = %s%s\n",
+		       XLAT_STR(HDIO_GET_UNMASKINTR), sprintrc(ret),
+		       ret == INJECT_RETVAL ? " (INJECTED)" : "");
+
+		if (ret != INJECT_RETVAL)
+			continue;
+
+		locked = true;
+		break;
+	}
+
+	if (!locked)
+		error_msg_and_fail("Hasn't locked on ioctl(-1"
+				   ", HDIO_GET_UNMASKINTR, 0) returning %d",
+				   INJECT_RETVAL);
+#endif
+
+	long rc;
+
+	/* Decoding is not supported */
+	static const struct {
+		uint32_t cmd;
+		const char *str;
+	} unsupp_cmds[] = {
+		{ ARG_STR(HDIO_GET_UNMASKINTR) },
+		{ ARG_STR(HDIO_GET_MULTCOUNT) },
+		{ ARG_STR(HDIO_GET_QDMA) },
+		{ ARG_STR(HDIO_SET_XFER) },
+		{ ARG_STR(HDIO_OBSOLETE_IDENTITY) },
+		{ ARG_STR(HDIO_GET_KEEPSETTINGS) },
+		{ ARG_STR(HDIO_GET_32BIT) },
+		{ ARG_STR(HDIO_GET_NOWERR) },
+		{ ARG_STR(HDIO_GET_DMA) },
+		{ ARG_STR(HDIO_GET_NICE) },
+		{ ARG_STR(HDIO_GET_IDENTITY) },
+		{ ARG_STR(HDIO_GET_WCACHE) },
+		{ ARG_STR(HDIO_GET_ACOUSTIC) },
+		{ ARG_STR(HDIO_GET_ADDRESS) },
+		{ ARG_STR(HDIO_GET_BUSSTATE) },
+		{ ARG_STR(HDIO_TRISTATE_HWIF) },
+		{ ARG_STR(HDIO_DRIVE_RESET) },
+		{ ARG_STR(HDIO_DRIVE_TASKFILE) },
+		{ ARG_STR(HDIO_DRIVE_TASK) },
+		{ ARG_STR(HDIO_SET_MULTCOUNT) },
+		{ ARG_STR(HDIO_SET_UNMASKINTR) },
+		{ ARG_STR(HDIO_SET_KEEPSETTINGS) },
+		{ ARG_STR(HDIO_SET_32BIT) },
+		{ ARG_STR(HDIO_SET_NOWERR) },
+		{ ARG_STR(HDIO_SET_DMA) },
+		{ ARG_STR(HDIO_SET_PIO_MODE) },
+		{ ARG_STR(HDIO_SCAN_HWIF) },
+		{ ARG_STR(HDIO_UNREGISTER_HWIF) },
+		{ ARG_STR(HDIO_SET_NICE) },
+		{ ARG_STR(HDIO_SET_WCACHE) },
+		{ ARG_STR(HDIO_SET_ACOUSTIC) },
+		{ ARG_STR(HDIO_SET_BUSSTATE) },
+		{ ARG_STR(HDIO_SET_QDMA) },
+		{ ARG_STR(HDIO_SET_ADDRESS) },
+	};
+
+	for (size_t i = 0; i < ARRAY_SIZE(unsupp_cmds); i++) {
+		do_ioctl(unsupp_cmds[i].cmd, 0);
+		printf("ioctl(-1, " XLAT_FMT ", 0) = %s\n",
+		       XLAT_SEL(unsupp_cmds[i].cmd, unsupp_cmds[i].str),
+		       errstr);
+
+		do_ioctl(unsupp_cmds[i].cmd,
+			 (unsigned long) 0xbadc0deddeadc0deULL);
+		printf("ioctl(-1, " XLAT_FMT ", %#lx) = %s\n",
+		       XLAT_SEL(unsupp_cmds[i].cmd, unsupp_cmds[i].str),
+		       (unsigned long) 0xbadc0deddeadc0deULL, errstr);
+	}
+
+
+	/* HDIO_GETGEO */
+	do_ioctl(HDIO_GETGEO, 0);
+	printf("ioctl(-1, %s, NULL) = %s\n",
+	       XLAT_STR(HDIO_GETGEO), errstr);
+
+	TAIL_ALLOC_OBJECT_CONST_PTR(struct hd_geometry, p_hd_geom);
+
+	p_hd_geom->heads = 0xca;
+	p_hd_geom->sectors = 0xfe;
+	p_hd_geom->cylinders = 0xbabe;
+	p_hd_geom->start = (unsigned long) 0xbadc0deddeadfaceULL;
+
+	do_ioctl_ptr(HDIO_GETGEO, (char *) p_hd_geom + 1);
+	printf("ioctl(-1, %s, %p) = %s\n",
+	       XLAT_STR(HDIO_GETGEO), (char *) p_hd_geom + 1, errstr);
+
+	rc = do_ioctl_ptr(HDIO_GETGEO, p_hd_geom);
+	printf("ioctl(-1, %s, ", XLAT_STR(HDIO_GETGEO));
+	if (rc >= 0) {
+		printf("{heads=202, sectors=254, cylinders=47806, start=%lu}",
+		       (unsigned long) 0xbadc0deddeadfaceULL);
+	} else {
+		printf("%p", p_hd_geom);
+	}
+	printf(") = %s\n", errstr);
+
+	/* HDIO_DRIVE_CMD */
+	do_ioctl(HDIO_DRIVE_CMD, 0);
+	printf("ioctl(-1, %s, NULL) = %s\n",
+	       XLAT_STR(HDIO_DRIVE_CMD), errstr);
+
+	TAIL_ALLOC_OBJECT_CONST_PTR(struct hd_drive_cmd_hdr, p_hd_drive_cmd);
+	struct hd_drive_cmd_hdr *p_hd_drive_cmd2 =
+		tail_alloc(sizeof(*p_hd_drive_cmd2) + 16);
+	struct hd_drive_cmd_hdr *p_hd_drive_cmd3 =
+		tail_alloc(sizeof(*p_hd_drive_cmd3) + DEFAULT_STRLEN + 1);
+
+	fill_memory(p_hd_drive_cmd2, sizeof(*p_hd_drive_cmd2) + 16);
+	fill_memory(p_hd_drive_cmd3,
+		    sizeof(*p_hd_drive_cmd3) + DEFAULT_STRLEN + 1);
+
+	p_hd_drive_cmd->command = 0xca;
+	p_hd_drive_cmd->sector_number = 0xff;
+	p_hd_drive_cmd->feature = 0xee;
+	p_hd_drive_cmd->sector_count = 0;
+
+	do_ioctl_ptr(HDIO_DRIVE_CMD, (char *) p_hd_drive_cmd + 1);
+	printf("ioctl(-1, %s, %p) = %s\n",
+	       XLAT_STR(HDIO_DRIVE_CMD), (char *) p_hd_drive_cmd + 1, errstr);
+
+	for (size_t i = 0; i < 2; i++) {
+		p_hd_drive_cmd->sector_count = i;
+
+		rc = do_ioctl_ptr(HDIO_DRIVE_CMD, p_hd_drive_cmd);
+		printf("ioctl(-1, %s, {command=" XLAT_FMT ", sector_number=255"
+		       ", feature=238, sector_count=%zu",
+		       XLAT_STR(HDIO_DRIVE_CMD),
+		       XLAT_SEL(0xca, "ATA_CMD_WRITE"), i);
+		if (rc >= 0) {
+			printf("} => {/* status */ 0xca, /* error */ 255"
+			       ", /* nsector */ 238");
+			if (i)
+				printf(", %p", p_hd_drive_cmd + 1);
+		}
+		printf("}) = %s\n", errstr);
+	}
+
+	rc = do_ioctl_ptr(HDIO_DRIVE_CMD, p_hd_drive_cmd2);
+	printf("ioctl(-1, %s, {command=0x80" NRAW(" /* ATA_CMD_??? */")
+	       ", sector_number=129, feature=130, sector_count=131",
+	       XLAT_STR(HDIO_DRIVE_CMD));
+	if (rc >= 0) {
+		printf("} => {/* status */ 0x80, /* error */ 129"
+		       ", /* nsector */ 130, %p", p_hd_drive_cmd2 + 1);
+	}
+	printf("}) = %s\n", errstr);
+
+	rc = do_ioctl_ptr(HDIO_DRIVE_CMD, p_hd_drive_cmd3);
+	printf("ioctl(-1, %s, {command=0x80" NRAW(" /* ATA_CMD_??? */")
+	       ", sector_number=129, feature=130, sector_count=131",
+	       XLAT_STR(HDIO_DRIVE_CMD));
+	if (rc >= 0) {
+		printf("} => {/* status */ 0x80, /* error */ 129"
+		       ", /* nsector */ 130, ");
+		print_quoted_hex(p_hd_drive_cmd3 + 1, DEFAULT_STRLEN);
+		printf("...");
+	}
+	printf("}) = %s\n", errstr);
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
diff -pruN 5.5-3/tests/ioctl_hdio.gen.test 5.9-0ubuntu2/tests/ioctl_hdio.gen.test
--- 5.5-3/tests/ioctl_hdio.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio +ioctl.test -a27); do not edit.
+set -- -a27
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests/ioctl_hdio-success.c 5.9-0ubuntu2/tests/ioctl_hdio-success.c
--- 5.5-3/tests/ioctl_hdio-success.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-success.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define INJECT_RETVAL 42
+#include "ioctl_hdio.c"
diff -pruN 5.5-3/tests/ioctl_hdio-success.gen.test 5.9-0ubuntu2/tests/ioctl_hdio-success.gen.test
--- 5.5-3/tests/ioctl_hdio-success.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-success.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-success +ioctl-success.sh -a27); do not edit.
+set -- -a27
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests/ioctl_hdio-success-v.c 5.9-0ubuntu2/tests/ioctl_hdio-success-v.c
--- 5.5-3/tests/ioctl_hdio-success-v.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-success-v.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define VERBOSE 1
+#include "ioctl_hdio-success.c"
diff -pruN 5.5-3/tests/ioctl_hdio-success-v.gen.test 5.9-0ubuntu2/tests/ioctl_hdio-success-v.gen.test
--- 5.5-3/tests/ioctl_hdio-success-v.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-success-v.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-success-v +ioctl-success.sh -a27 -v); do not edit.
+set -- -a27 -v
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests/ioctl_hdio-success-v-Xabbrev.c 5.9-0ubuntu2/tests/ioctl_hdio-success-v-Xabbrev.c
--- 5.5-3/tests/ioctl_hdio-success-v-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-success-v-Xabbrev.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "ioctl_hdio-success-v.c"
diff -pruN 5.5-3/tests/ioctl_hdio-success-v-Xabbrev.gen.test 5.9-0ubuntu2/tests/ioctl_hdio-success-v-Xabbrev.gen.test
--- 5.5-3/tests/ioctl_hdio-success-v-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-success-v-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-success-v-Xabbrev +ioctl-success.sh -a27 -v -Xabbrev); do not edit.
+set -- -a27 -v -Xabbrev
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests/ioctl_hdio-success-v-Xraw.c 5.9-0ubuntu2/tests/ioctl_hdio-success-v-Xraw.c
--- 5.5-3/tests/ioctl_hdio-success-v-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-success-v-Xraw.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "ioctl_hdio-success-v.c"
diff -pruN 5.5-3/tests/ioctl_hdio-success-v-Xraw.gen.test 5.9-0ubuntu2/tests/ioctl_hdio-success-v-Xraw.gen.test
--- 5.5-3/tests/ioctl_hdio-success-v-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-success-v-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-success-v-Xraw +ioctl-success.sh -a20 -v -Xraw); do not edit.
+set -- -a20 -v -Xraw
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests/ioctl_hdio-success-v-Xverbose.c 5.9-0ubuntu2/tests/ioctl_hdio-success-v-Xverbose.c
--- 5.5-3/tests/ioctl_hdio-success-v-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-success-v-Xverbose.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "ioctl_hdio-success-v.c"
diff -pruN 5.5-3/tests/ioctl_hdio-success-v-Xverbose.gen.test 5.9-0ubuntu2/tests/ioctl_hdio-success-v-Xverbose.gen.test
--- 5.5-3/tests/ioctl_hdio-success-v-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-success-v-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-success-v-Xverbose +ioctl-success.sh -a39 -v -Xverbose); do not edit.
+set -- -a39 -v -Xverbose
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests/ioctl_hdio-success-Xabbrev.c 5.9-0ubuntu2/tests/ioctl_hdio-success-Xabbrev.c
--- 5.5-3/tests/ioctl_hdio-success-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-success-Xabbrev.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "ioctl_hdio-success.c"
diff -pruN 5.5-3/tests/ioctl_hdio-success-Xabbrev.gen.test 5.9-0ubuntu2/tests/ioctl_hdio-success-Xabbrev.gen.test
--- 5.5-3/tests/ioctl_hdio-success-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-success-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-success-Xabbrev +ioctl-success.sh -a27 -Xabbrev); do not edit.
+set -- -a27 -Xabbrev
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests/ioctl_hdio-success-Xraw.c 5.9-0ubuntu2/tests/ioctl_hdio-success-Xraw.c
--- 5.5-3/tests/ioctl_hdio-success-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-success-Xraw.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "ioctl_hdio-success.c"
diff -pruN 5.5-3/tests/ioctl_hdio-success-Xraw.gen.test 5.9-0ubuntu2/tests/ioctl_hdio-success-Xraw.gen.test
--- 5.5-3/tests/ioctl_hdio-success-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-success-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-success-Xraw +ioctl-success.sh -a20 -Xraw); do not edit.
+set -- -a20 -Xraw
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests/ioctl_hdio-success-Xverbose.c 5.9-0ubuntu2/tests/ioctl_hdio-success-Xverbose.c
--- 5.5-3/tests/ioctl_hdio-success-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-success-Xverbose.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "ioctl_hdio-success.c"
diff -pruN 5.5-3/tests/ioctl_hdio-success-Xverbose.gen.test 5.9-0ubuntu2/tests/ioctl_hdio-success-Xverbose.gen.test
--- 5.5-3/tests/ioctl_hdio-success-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-success-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-success-Xverbose +ioctl-success.sh -a39 -Xverbose); do not edit.
+set -- -a39 -Xverbose
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests/ioctl_hdio-v.c 5.9-0ubuntu2/tests/ioctl_hdio-v.c
--- 5.5-3/tests/ioctl_hdio-v.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-v.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define VERBOSE 1
+#include "ioctl_hdio.c"
diff -pruN 5.5-3/tests/ioctl_hdio-v.gen.test 5.9-0ubuntu2/tests/ioctl_hdio-v.gen.test
--- 5.5-3/tests/ioctl_hdio-v.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-v.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-v +ioctl.test -a27 -v); do not edit.
+set -- -a27 -v
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests/ioctl_hdio-v-Xabbrev.c 5.9-0ubuntu2/tests/ioctl_hdio-v-Xabbrev.c
--- 5.5-3/tests/ioctl_hdio-v-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-v-Xabbrev.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "ioctl_hdio-v.c"
diff -pruN 5.5-3/tests/ioctl_hdio-v-Xabbrev.gen.test 5.9-0ubuntu2/tests/ioctl_hdio-v-Xabbrev.gen.test
--- 5.5-3/tests/ioctl_hdio-v-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-v-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-v-Xabbrev +ioctl.test -a27 -v -Xabbrev); do not edit.
+set -- -a27 -v -Xabbrev
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests/ioctl_hdio-v-Xraw.c 5.9-0ubuntu2/tests/ioctl_hdio-v-Xraw.c
--- 5.5-3/tests/ioctl_hdio-v-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-v-Xraw.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "ioctl_hdio-v.c"
diff -pruN 5.5-3/tests/ioctl_hdio-v-Xraw.gen.test 5.9-0ubuntu2/tests/ioctl_hdio-v-Xraw.gen.test
--- 5.5-3/tests/ioctl_hdio-v-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-v-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-v-Xraw +ioctl.test -a20 -v -Xraw); do not edit.
+set -- -a20 -v -Xraw
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests/ioctl_hdio-v-Xverbose.c 5.9-0ubuntu2/tests/ioctl_hdio-v-Xverbose.c
--- 5.5-3/tests/ioctl_hdio-v-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-v-Xverbose.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "ioctl_hdio-v.c"
diff -pruN 5.5-3/tests/ioctl_hdio-v-Xverbose.gen.test 5.9-0ubuntu2/tests/ioctl_hdio-v-Xverbose.gen.test
--- 5.5-3/tests/ioctl_hdio-v-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-v-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-v-Xverbose +ioctl.test -a39 -v -Xverbose); do not edit.
+set -- -a39 -v -Xverbose
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests/ioctl_hdio-Xabbrev.c 5.9-0ubuntu2/tests/ioctl_hdio-Xabbrev.c
--- 5.5-3/tests/ioctl_hdio-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-Xabbrev.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "ioctl_hdio.c"
diff -pruN 5.5-3/tests/ioctl_hdio-Xabbrev.gen.test 5.9-0ubuntu2/tests/ioctl_hdio-Xabbrev.gen.test
--- 5.5-3/tests/ioctl_hdio-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-Xabbrev +ioctl.test -a27 -Xabbrev); do not edit.
+set -- -a27 -Xabbrev
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests/ioctl_hdio-Xraw.c 5.9-0ubuntu2/tests/ioctl_hdio-Xraw.c
--- 5.5-3/tests/ioctl_hdio-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-Xraw.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "ioctl_hdio.c"
diff -pruN 5.5-3/tests/ioctl_hdio-Xraw.gen.test 5.9-0ubuntu2/tests/ioctl_hdio-Xraw.gen.test
--- 5.5-3/tests/ioctl_hdio-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-Xraw +ioctl.test -a20 -Xraw); do not edit.
+set -- -a20 -Xraw
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests/ioctl_hdio-Xverbose.c 5.9-0ubuntu2/tests/ioctl_hdio-Xverbose.c
--- 5.5-3/tests/ioctl_hdio-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-Xverbose.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "ioctl_hdio.c"
diff -pruN 5.5-3/tests/ioctl_hdio-Xverbose.gen.test 5.9-0ubuntu2/tests/ioctl_hdio-Xverbose.gen.test
--- 5.5-3/tests/ioctl_hdio-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_hdio-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-Xverbose +ioctl.test -a39 -Xverbose); do not edit.
+set -- -a39 -Xverbose
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests/ioctl_loop.c 5.9-0ubuntu2/tests/ioctl_loop.c
--- 5.5-3/tests/ioctl_loop.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_loop.c	2020-08-03 08:00:00.000000000 +0000
@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2016 JingPiao Chen <chenjingpiao@gmail.com>
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -22,6 +22,12 @@
 #include <linux/loop.h>
 #include "print_fields.h"
 
+#ifdef HAVE_STRUCT_LOOP_CONFIG
+typedef struct loop_config struct_loop_config;
+#else
+# include "types/loop.h"
+#endif
+
 #define XLAT_MACROS_ONLY
 #include "xlat/loop_cmds.h"
 #undef XLAT_MACROS_ONLY
@@ -155,6 +161,27 @@ print_loop_info64(struct loop_info64 * c
 #endif /* !ABBREV */
 }
 
+static void
+print_loop_config(struct_loop_config *config, bool print_reserved)
+{
+#if ABBREV
+	printf("%p", config);
+#else
+	printf("{fd=%d, block_size=%u, info=",
+	       (int) config->fd, config->block_size);
+	print_loop_info64(&config->info, false, "LO_CRYPT_NONE", NULL,
+			  "LO_FLAGS_READ_ONLY");
+	if (print_reserved) {
+		printf(", __reserved=");
+		for (size_t i = 0; i < ARRAY_SIZE(config->__reserved); ++i)
+			printf("%s%#llx", (i ? ", " : "["),
+			       (unsigned long long) config->__reserved[i]);
+		printf("]");
+	}
+	printf("}");
+#endif /* !ABBREV */
+}
+
 int
 main(void)
 {
@@ -167,6 +194,7 @@ main(void)
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct loop_info, info);
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct loop_info64, info64);
+	TAIL_ALLOC_OBJECT_CONST_PTR(struct_loop_config, config);
 
 	/* Unknown loop commands */
 	sys_ioctl(-1, unknown_loop_cmd, magic);
@@ -178,12 +206,12 @@ main(void)
 	       _IOC_SIZE((unsigned int) unknown_loop_cmd),
 	       (unsigned long) magic);
 
-	sys_ioctl(-1, LOOP_SET_BLOCK_SIZE + 1, magic);
+	sys_ioctl(-1, LOOP_CONFIGURE + 1, magic);
 	printf("ioctl(-1, _IOC(%s, 0x4c, %#x, %#x), %#lx) = "
 	       "-1 EBADF (%m)\n",
 	       _IOC_NONE ? "0" : "_IOC_NONE",
-	       _IOC_NR(LOOP_SET_BLOCK_SIZE + 1),
-	       _IOC_SIZE(LOOP_SET_BLOCK_SIZE + 1),
+	       _IOC_NR(LOOP_CONFIGURE + 1),
+	       _IOC_SIZE(LOOP_CONFIGURE + 1),
 	       (unsigned long) magic);
 
 	sys_ioctl(-1, LOOP_CTL_GET_FREE + 1, magic);
@@ -281,6 +309,32 @@ main(void)
 	ioctl(-1, LOOP_GET_STATUS64, (unsigned long) info64 | kernel_mask);
 	printf("ioctl(-1, LOOP_GET_STATUS64, %p) = -1 EBADF (%m)\n", info64);
 
+	/* LOOP_CONFIGURE */
+	ioctl(-1, LOOP_CONFIGURE, NULL);
+	printf("ioctl(-1, LOOP_CONFIGURE, NULL) = -1 EBADF (%m)\n");
+
+	fill_memory(config, sizeof(*config));
+	config->info.lo_flags = LO_FLAGS_READ_ONLY;
+	config->info.lo_encrypt_type = LO_CRYPT_NONE;
+	memset(config->info.lo_file_name, 'C', sizeof(config->info.lo_file_name));
+	memset(config->info.lo_crypt_name, 'D', sizeof(config->info.lo_crypt_name));
+	memset(config->info.lo_encrypt_key, 'E', sizeof(config->info.lo_encrypt_key));
+
+	ioctl(-1, LOOP_CONFIGURE, (void *) config + ALIGNOF(config));
+	printf("ioctl(-1, LOOP_CONFIGURE, %p) = -1 EBADF (%m)\n",
+	       (void *) config + ALIGNOF(config));
+
+	printf("ioctl(-1, LOOP_CONFIGURE, ");
+	print_loop_config(config, true);
+	ioctl(-1, LOOP_CONFIGURE, config);
+	printf(") = -1 EBADF (%m)\n");
+
+	memset(config->__reserved, 0, sizeof(config->__reserved));
+	printf("ioctl(-1, LOOP_CONFIGURE, ");
+	print_loop_config(config, false);
+	ioctl(-1, LOOP_CONFIGURE, config);
+	printf(") = -1 EBADF (%m)\n");
+
 	/* LOOP_CHANGE_FD */
 	sys_ioctl(-1, LOOP_CHANGE_FD, magic);
 	printf("ioctl(-1, LOOP_CHANGE_FD, %d) = -1 EBADF (%m)\n",
diff -pruN 5.5-3/tests/ioctl_nsfs.c 5.9-0ubuntu2/tests/ioctl_nsfs.c
--- 5.5-3/tests/ioctl_nsfs.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_nsfs.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of NS_* commands of ioctl syscall.
  *
  * Copyright (c) 2017 Nikolay Marchuk <marchuk.nikolay.a@gmail.com>
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
diff -pruN 5.5-3/tests/ioctl_perf-success.c 5.9-0ubuntu2/tests/ioctl_perf-success.c
--- 5.5-3/tests/ioctl_perf-success.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_perf-success.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check decoding of successful PERF_EVENT_IOC_{ID,QUERY_BPF} ioctls.
  *
- * Copyright (c) 2018 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -9,29 +9,31 @@
 
 #include "tests.h"
 
-#ifdef HAVE_LINUX_PERF_EVENT_H
 
-# include <assert.h>
-# include <inttypes.h>
-# include <stdio.h>
-# include <stdlib.h>
-# include <string.h>
-# include <sys/ioctl.h>
+#include <assert.h>
+#include <inttypes.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <sys/ioctl.h>
+
+#ifdef HAVE_LINUX_PERF_EVENT_H
 # include <linux/perf_event.h>
+#endif
 
-# ifndef PERF_EVENT_IOC_ID
-#  define PERF_EVENT_IOC_ID			_IOR('$', 7, void *)
-# endif
+#ifndef PERF_EVENT_IOC_ID
+# define PERF_EVENT_IOC_ID			_IOR('$', 7, void *)
+#endif
 
-# ifndef PERF_EVENT_IOC_QUERY_BPF
-#  define PERF_EVENT_IOC_QUERY_BPF		_IOWR('$', 10, void *)
+#ifndef PERF_EVENT_IOC_QUERY_BPF
+# define PERF_EVENT_IOC_QUERY_BPF		_IOWR('$', 10, void *)
 
 struct perf_event_query_bpf {
         uint32_t ids_len;
         uint32_t prog_cnt;
         uint32_t ids[0];
 };
-# endif
+#endif
 
 int
 main(int argc, char **argv)
@@ -137,9 +139,3 @@ main(int argc, char **argv)
 	puts("+++ exited with 0 +++");
 	return 0;
 }
-
-#else
-
-SKIP_MAIN_UNDEFINED("HAVE_LINUX_PERF_EVENT_H");
-
-#endif
diff -pruN 5.5-3/tests/ioctl_perf-success.gen.test 5.9-0ubuntu2/tests/ioctl_perf-success.gen.test
--- 5.5-3/tests/ioctl_perf-success.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_perf-success.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_perf-success +ioctl-success.sh -a35); do not edit.
+set -- -a35
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests/ioctl_perf-success.test 5.9-0ubuntu2/tests/ioctl_perf-success.test
--- 5.5-3/tests/ioctl_perf-success.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_perf-success.test	1970-01-01 00:00:00.000000000 +0000
@@ -1,20 +0,0 @@
-#!/bin/sh -efu
-#
-# Check decoding of successful PERF_EVENT_IOC_{ID,QUERY_BPF} ioctls.
-#
-# Copyright (c) 2018 The strace developers.
-# All rights reserved.
-#
-# SPDX-License-Identifier: GPL-2.0-or-later
-
-. "${srcdir=.}/scno_tampering.sh"
-
-: ${IOCTL_INJECT_START=256}
-: ${IOCTL_INJECT_RETVAL=42}
-
-run_prog
-run_strace -a35 -e trace=ioctl \
-	-e inject=ioctl:retval="${IOCTL_INJECT_RETVAL}":when="${IOCTL_INJECT_START}+" \
-	../ioctl_perf-success "${IOCTL_INJECT_START}" "${IOCTL_INJECT_RETVAL}" > "$EXP"
-grep -v '^ioctl([012][,<]' < "$LOG" > "$OUT"
-match_diff "$OUT" "$EXP"
diff -pruN 5.5-3/tests/ioctl-success.sh 5.9-0ubuntu2/tests/ioctl-success.sh
--- 5.5-3/tests/ioctl-success.sh	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl-success.sh	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,21 @@
+#!/bin/sh -efu
+#
+# Check decoding of ioctls using syscall injection.
+#
+# Expects a binary that accepts IOCTL_INJECT_START as the first argument.
+#
+# Copyright (c) 2018-2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: GPL-2.0-or-later
+
+. "${srcdir=.}/scno_tampering.sh"
+
+: ${IOCTL_INJECT_START=256}
+: ${IOCTL_INJECT_RETVAL=42}
+
+run_strace -a50 "$@" -e trace=ioctl \
+	-e inject=ioctl:retval="${IOCTL_INJECT_RETVAL}":when="${IOCTL_INJECT_START}+" \
+	"../$NAME" "${IOCTL_INJECT_START}" "${IOCTL_INJECT_RETVAL}" > "$EXP"
+grep -v '^ioctl([012][,<]' < "$LOG" > "$OUT"
+match_diff "$OUT" "$EXP"
diff -pruN 5.5-3/tests/ioctl_tee.c 5.9-0ubuntu2/tests/ioctl_tee.c
--- 5.5-3/tests/ioctl_tee.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_tee.c	2020-09-23 16:28:11.000000000 +0000
@@ -0,0 +1,437 @@
+/*
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+
+#ifdef HAVE_LINUX_TEE_H
+
+# include <fcntl.h>
+# include <stdio.h>
+# include <string.h>
+
+# include <linux/tee.h>
+
+# include <sys/ioctl.h>
+# include <sys/stat.h>
+# include <sys/types.h>
+
+# include "xlat.h"
+
+# define NUM_PARAMS 8
+# define RVAL_EBADF " = -1 EBADF (%m)\n"
+
+# define UUID_SIZE 16
+
+# ifndef TEE_IOCTL_PARAM_ATTR_META
+#  define TEE_IOCTL_PARAM_ATTR_META 0x100
+# endif
+
+# ifndef HAVE_STRUCT_TEE_IOCTL_SHM_REGISTER_FD_DATA
+struct tee_ioctl_shm_register_fd_data {
+	__s64 fd;
+	__u64 size;
+	__u32 flags;
+	__u8  _pad1[4];
+	__u32 id;
+	__u8  _pad2[4];
+} ATTRIBUTE_ALIGNED(8);
+# endif
+
+# ifndef HAVE_STRUCT_TEE_IOCTL_SHM_REGISTER_DATA
+struct tee_ioctl_shm_register_data {
+	__u64 addr;
+	__u64 length;
+	__u32 flags;
+	__s32 id;
+};
+# endif
+
+# ifndef TEE_IOC_SHM_REGISTER_FD
+#  define TEE_IOC_SHM_REGISTER_FD _IOWR(TEE_IOC_MAGIC, TEE_IOC_BASE + 8, \
+					struct tee_ioctl_shm_register_fd_data)
+# endif
+
+# ifndef TEE_IOC_SHM_REGISTER
+#  define TEE_IOC_SHM_REGISTER    _IOWR(TEE_IOC_MAGIC, TEE_IOC_BASE + 9, \
+					struct tee_ioctl_shm_register_data)
+# endif
+
+
+typedef struct {
+	uint8_t b[UUID_SIZE];
+} uuid_t;
+
+# define UUID_INIT(a_, b_, c_, d0, d1, d2, d3, d4, d5, d6, d7)		\
+{ .b = {((a_) >> 24) & 0xff, ((a_) >> 16) & 0xff,			\
+        ((a_) >> 8) & 0xff, (a_) & 0xff,				\
+        ((b_) >> 8) & 0xff, (b_) & 0xff,				\
+        ((c_) >> 8) & 0xff, (c_) & 0xff,				\
+        (d0), (d1), (d2), (d3), (d4), (d5), (d6), (d7)} }
+
+# define CHK_NULL(ioctl_)						\
+	do {								\
+		ioctl(-1, ioctl_, NULL);				\
+		printf("ioctl(-1, " #ioctl_ ", NULL)" RVAL_EBADF);	\
+	} while (0)
+
+# define CHK_BUF(ioctl_)						\
+	do {								\
+		ioctl(-1, ioctl_, &buf_data);				\
+		printf("ioctl(-1, " #ioctl_				\
+		       ", {buf_len=%llu, buf_ptr=%#llx})" RVAL_EBADF,	\
+		       (unsigned long long) buf_data.buf_len,		\
+		       (unsigned long long) buf_data.buf_ptr);		\
+	} while (0)
+
+# define DEFINE_BUF_W_PARAMS(type_, shorthand_)				\
+	const size_t shorthand_ ## _size = sizeof(type_) +		\
+		NUM_PARAMS * sizeof(struct tee_ioctl_param);		\
+	union {								\
+		type_ shorthand_;					\
+		uint8_t data[shorthand_ ## _size];			\
+	} shorthand_ ## _buf
+
+static const unsigned long one_beef = (unsigned long) 0xcafef00ddeadbeefULL;
+static const unsigned long two_beef = (unsigned long) 0xbadc0dedbadc0dedULL;
+static const unsigned long red_beef = (unsigned long) 0xdefacedbeef0beefULL;
+static const unsigned long blu_beef = (unsigned long) 0xfacefeedcafef00dULL;
+
+static const uuid_t uuid_beef = UUID_INIT(0xdeadbeef, 0xcafe, 0xc0de,
+					  0xba, 0xdc, 0x0d, 0xed,
+					  0xfa, 0xce, 0xfe, 0xed);
+
+static void
+fill_params(struct tee_ioctl_param *params)
+{
+	for (unsigned i = 0; i < NUM_PARAMS; i++) {
+		params[i].a = two_beef;
+		params[i].b = red_beef;
+		params[i].c = blu_beef;
+	}
+	params[0].attr = TEE_IOCTL_PARAM_ATTR_TYPE_NONE;
+	params[1].attr = TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INPUT;
+	params[2].attr = TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_OUTPUT;
+	params[3].attr = TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INOUT;
+	params[4].attr = TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INPUT;
+	params[5].attr = TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_OUTPUT;
+	params[6].attr = TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INOUT;
+	params[7].attr = TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INPUT |
+			 TEE_IOCTL_PARAM_ATTR_META;
+}
+
+static void
+print_params(struct tee_ioctl_param *params)
+{
+	printf("{attr=TEE_IOCTL_PARAM_ATTR_TYPE_NONE}, "
+	       "{attr=TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INPUT, a=%#llx, b=%#llx, c=%#llx}, "
+	       "{attr=TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_OUTPUT, a=%#llx, b=%#llx, c=%#llx}, "
+	       "{attr=TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INOUT, a=%#llx, b=%#llx, c=%#llx}, "
+	       "{attr=TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INPUT, shm_offs=%#llx, size=%#llx, shm_id=%llu}, "
+	       "{attr=TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_OUTPUT, shm_offs=%#llx, size=%#llx, shm_id=%llu}, "
+	       "{attr=TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INOUT, shm_offs=%#llx, size=%#llx, shm_id=%llu}, "
+	       "{attr=TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INPUT|TEE_IOCTL_PARAM_ATTR_META, a=%#llx, b=%#llx, c=%#llx}",
+	       (unsigned long long) two_beef, (unsigned long long) red_beef,
+	       (unsigned long long) blu_beef, (unsigned long long) two_beef,
+	       (unsigned long long) red_beef, (unsigned long long) blu_beef,
+	       (unsigned long long) two_beef, (unsigned long long) red_beef,
+	       (unsigned long long) blu_beef, (unsigned long long) two_beef,
+	       (unsigned long long) red_beef, (unsigned long long) blu_beef,
+	       (unsigned long long) two_beef, (unsigned long long) red_beef,
+	       (unsigned long long) blu_beef, (unsigned long long) two_beef,
+	       (unsigned long long) red_beef, (unsigned long long) blu_beef,
+	       (unsigned long long) two_beef, (unsigned long long) red_beef,
+	       (unsigned long long) blu_beef
+	       );
+}
+
+int
+main(void)
+{
+	gid_t gid;
+
+	struct tee_ioctl_cancel_arg cancel;
+	struct tee_ioctl_shm_alloc_data shm_alloc;
+	struct tee_ioctl_shm_register_data shm_register;
+	struct tee_ioctl_close_session_arg close_session;
+	struct tee_ioctl_shm_register_fd_data shm_register_fd;
+
+	struct tee_ioctl_buf_data buf_data;
+	struct tee_ioctl_param *params = NULL;
+
+	DEFINE_BUF_W_PARAMS(struct tee_ioctl_invoke_arg, invoke);
+	DEFINE_BUF_W_PARAMS(struct tee_iocl_supp_recv_arg, supp_recv);
+	DEFINE_BUF_W_PARAMS(struct tee_iocl_supp_send_arg, supp_send);
+	DEFINE_BUF_W_PARAMS(struct tee_ioctl_open_session_arg, open_session);
+
+	static const char null_path[] = "/dev/null";
+	int fd = open(null_path, O_RDONLY);
+
+	/* NULL as arg */
+	CHK_NULL(TEE_IOC_CANCEL);
+	CHK_NULL(TEE_IOC_INVOKE);
+	CHK_NULL(TEE_IOC_VERSION);
+	CHK_NULL(TEE_IOC_SHM_ALLOC);
+	CHK_NULL(TEE_IOC_SUPPL_RECV);
+	CHK_NULL(TEE_IOC_SUPPL_SEND);
+	CHK_NULL(TEE_IOC_OPEN_SESSION);
+	CHK_NULL(TEE_IOC_SHM_REGISTER);
+	CHK_NULL(TEE_IOC_CLOSE_SESSION);
+
+	/* Valid parameterless calls */
+	ioctl(-1, TEE_IOC_SHM_REGISTER_FD, NULL);
+	printf("ioctl(-1, _IOC(_IOC_READ|_IOC_WRITE, 0xa4, 0x8, 0x20), NULL)"
+	       RVAL_EBADF);
+	ioctl(-1, _IOC(_IOC_NONE, 0xa4, 0xa, 0), NULL);
+	printf("ioctl(-1, _IOC(_IOC_NONE, 0xa4, 0xa, 0), 0)" RVAL_EBADF);
+
+	cancel.cancel_id = (uint32_t) one_beef;
+	cancel.session = (uint32_t) two_beef;
+	ioctl(-1, TEE_IOC_CANCEL, &cancel);
+	printf("ioctl(-1, TEE_IOC_CANCEL, {cancel_id=%u, session=%#x})" RVAL_EBADF,
+	       (uint32_t) one_beef, (uint32_t) two_beef);
+
+	close_session.session = (uint32_t) red_beef;
+	ioctl(-1, TEE_IOC_CLOSE_SESSION, &close_session);
+	printf("ioctl(-1, TEE_IOC_CLOSE_SESSION, {session=%#x})" RVAL_EBADF,
+	       (uint32_t) red_beef);
+
+	shm_alloc.size = one_beef;
+	shm_alloc.flags = TEE_IOCTL_SHM_MAPPED | TEE_IOCTL_SHM_DMA_BUF | 0x80;
+	ioctl(-1, TEE_IOC_SHM_ALLOC, &shm_alloc);
+	printf("ioctl(-1, TEE_IOC_SHM_ALLOC, {size=%#llx, "
+	       "flags=TEE_IOCTL_SHM_MAPPED|TEE_IOCTL_SHM_DMA_BUF|0x80})" RVAL_EBADF,
+	       (unsigned long long) one_beef);
+
+	shm_register.addr = red_beef;
+	shm_register.length = blu_beef;
+	shm_register.flags = TEE_IOCTL_SHM_MAPPED | 0x80;
+	ioctl(-1, TEE_IOC_SHM_REGISTER, &shm_register);
+	printf("ioctl(-1, TEE_IOC_SHM_REGISTER, {addr=%#llx, length=%#llx, "
+	       "flags=TEE_IOCTL_SHM_MAPPED|0x80})" RVAL_EBADF,
+	       (unsigned long long) red_beef,
+	       (unsigned long long) blu_beef);
+
+	if (fd >= 0) {
+		shm_register_fd.fd = fd;
+		shm_register_fd.flags = TEE_IOCTL_SHM_DMA_BUF;
+		ioctl(-1, TEE_IOC_SHM_REGISTER_FD, &shm_register_fd);
+		printf("ioctl(-1, _IOC(_IOC_READ|_IOC_WRITE, 0xa4, 0x8, 0x20), "
+		       "{fd=%d, flags=TEE_IOCTL_SHM_DMA_BUF})" RVAL_EBADF, fd);
+	}
+
+	/* Beef in buf_data */
+	buf_data.buf_ptr = one_beef;
+	buf_data.buf_len = two_beef;
+	CHK_BUF(TEE_IOC_INVOKE);
+	CHK_BUF(TEE_IOC_OPEN_SESSION);
+	CHK_BUF(TEE_IOC_SUPPL_RECV);
+	CHK_BUF(TEE_IOC_SUPPL_SEND);
+
+	/* Valid calls with parameters */
+	invoke_buf.invoke.func = (uint32_t) one_beef;
+	invoke_buf.invoke.session = (uint32_t) two_beef;
+	invoke_buf.invoke.cancel_id = (uint32_t) red_beef;
+	invoke_buf.invoke.num_params = NUM_PARAMS;
+	params = (struct tee_ioctl_param *)(&invoke_buf.invoke + 1);
+	fill_params(params);
+	buf_data.buf_ptr = (uintptr_t) &invoke_buf;
+	buf_data.buf_len = invoke_size;
+	ioctl(-1, TEE_IOC_INVOKE, &buf_data);
+	printf("ioctl(-1, TEE_IOC_INVOKE, {buf_len=%llu, "
+	       "buf_ptr={func=%u, session=%#x, cancel_id=%u, "
+	       "num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       (uint32_t) one_beef, (uint32_t) two_beef,
+	       (uint32_t) red_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	open_session_buf.open_session.clnt_login = TEE_IOCTL_LOGIN_PUBLIC;
+	gid = (gid_t) blu_beef;
+	memcpy(&open_session_buf.open_session.clnt_uuid, &gid, sizeof(gid_t));
+	memcpy(&open_session_buf.open_session.uuid, &uuid_beef, UUID_SIZE);
+	open_session_buf.open_session.cancel_id = (uint32_t) red_beef;
+	open_session_buf.open_session.num_params = NUM_PARAMS;
+	params = (struct tee_ioctl_param *)(&open_session_buf.open_session + 1);
+	fill_params(params);
+	buf_data.buf_ptr = (uintptr_t) &open_session_buf;
+	buf_data.buf_len = open_session_size;
+	ioctl(-1, TEE_IOC_OPEN_SESSION, &buf_data);
+	printf("ioctl(-1, TEE_IOC_OPEN_SESSION, {buf_len=%llu, "
+	       "buf_ptr={uuid=deadbeef-cafe-c0de-badc-0dedfacefeed, "
+	       "clnt_login=TEE_IOCTL_LOGIN_PUBLIC, "
+	       "cancel_id=%u, "
+	       "num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       (uint32_t) red_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	/* All the login types */
+	open_session_buf.open_session.clnt_login = TEE_IOCTL_LOGIN_USER;
+	ioctl(-1, TEE_IOC_OPEN_SESSION, &buf_data);
+	printf("ioctl(-1, TEE_IOC_OPEN_SESSION, {buf_len=%llu, "
+	       "buf_ptr={uuid=deadbeef-cafe-c0de-badc-0dedfacefeed, "
+	       "clnt_login=TEE_IOCTL_LOGIN_USER, "
+	       "cancel_id=%u, "
+	       "num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       (uint32_t) red_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	open_session_buf.open_session.clnt_login = TEE_IOCTL_LOGIN_GROUP;
+	ioctl(-1, TEE_IOC_OPEN_SESSION, &buf_data);
+	printf("ioctl(-1, TEE_IOC_OPEN_SESSION, {buf_len=%llu, "
+	       "buf_ptr={uuid=deadbeef-cafe-c0de-badc-0dedfacefeed, "
+	       "clnt_login=TEE_IOCTL_LOGIN_GROUP, "
+	       "clnt_uuid=%u, cancel_id=%u, "
+	       "num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       gid, (uint32_t) red_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	open_session_buf.open_session.clnt_login = TEE_IOCTL_LOGIN_APPLICATION;
+	ioctl(-1, TEE_IOC_OPEN_SESSION, &buf_data);
+	printf("ioctl(-1, TEE_IOC_OPEN_SESSION, {buf_len=%llu, "
+	       "buf_ptr={uuid=deadbeef-cafe-c0de-badc-0dedfacefeed, "
+	       "clnt_login=TEE_IOCTL_LOGIN_APPLICATION, "
+	       "cancel_id=%u, "
+	       "num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       (uint32_t) red_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	open_session_buf.open_session.clnt_login = TEE_IOCTL_LOGIN_USER_APPLICATION;
+	ioctl(-1, TEE_IOC_OPEN_SESSION, &buf_data);
+	printf("ioctl(-1, TEE_IOC_OPEN_SESSION, {buf_len=%llu, "
+	       "buf_ptr={uuid=deadbeef-cafe-c0de-badc-0dedfacefeed, "
+	       "clnt_login=TEE_IOCTL_LOGIN_USER_APPLICATION, "
+	       "cancel_id=%u, "
+	       "num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       (uint32_t) red_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	open_session_buf.open_session.clnt_login = TEE_IOCTL_LOGIN_GROUP_APPLICATION;
+	ioctl(-1, TEE_IOC_OPEN_SESSION, &buf_data);
+	printf("ioctl(-1, TEE_IOC_OPEN_SESSION, {buf_len=%llu, "
+	       "buf_ptr={uuid=deadbeef-cafe-c0de-badc-0dedfacefeed, "
+	       "clnt_login=TEE_IOCTL_LOGIN_GROUP_APPLICATION, "
+	       "clnt_uuid=%u, cancel_id=%u, "
+	       "num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       gid, (uint32_t) red_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	open_session_buf.open_session.clnt_login = 0xff;
+	ioctl(-1, TEE_IOC_OPEN_SESSION, &buf_data);
+	printf("ioctl(-1, TEE_IOC_OPEN_SESSION, {buf_len=%llu, "
+	       "buf_ptr={uuid=deadbeef-cafe-c0de-badc-0dedfacefeed, "
+	       "clnt_login=%#x /* TEE_IOCTL_LOGIN_??? */, "
+	       "clnt_uuid=[", (unsigned long long) buf_data.buf_len,
+	       open_session_buf.open_session.clnt_login);
+	for (unsigned i = 0; i < UUID_SIZE; i++) {
+		if (i > 0)
+			printf(", ");
+		printf("%#x", open_session_buf.open_session.clnt_uuid[i]);
+	}
+	printf("], cancel_id=%u, "
+	       "num_params=%u, params=[",
+	       (uint32_t) red_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	supp_recv_buf.supp_recv.func = (uint32_t) blu_beef;
+	supp_recv_buf.supp_recv.num_params = NUM_PARAMS;
+	params = (struct tee_ioctl_param *)(&supp_recv_buf.supp_recv + 1);
+	fill_params(params);
+	buf_data.buf_ptr = (uintptr_t) &supp_recv_buf;
+	buf_data.buf_len = supp_recv_size;
+	ioctl(-1, TEE_IOC_SUPPL_RECV, &buf_data);
+	printf("ioctl(-1, TEE_IOC_SUPPL_RECV, {buf_len=%llu, "
+	       "buf_ptr={func=%u, "
+	       "num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       (uint32_t) blu_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	supp_send_buf.supp_send.num_params = NUM_PARAMS;
+	params = (struct tee_ioctl_param *)(&supp_send_buf.supp_send + 1);
+	fill_params(params);
+	buf_data.buf_ptr = (uintptr_t) &supp_send_buf;
+	buf_data.buf_len = supp_send_size;
+	ioctl(-1, TEE_IOC_SUPPL_SEND, &buf_data);
+	printf("ioctl(-1, TEE_IOC_SUPPL_SEND, {buf_len=%llu, "
+	       "buf_ptr={num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	/* Valid buf, but unmatching num_params */
+	invoke_buf.invoke.num_params = 0;
+	supp_recv_buf.supp_recv.num_params = 0;
+	supp_send_buf.supp_send.num_params = 0;
+	open_session_buf.open_session.num_params = 0;
+
+	buf_data.buf_ptr = (uintptr_t) &invoke_buf;
+	buf_data.buf_len = invoke_size;
+	CHK_BUF(TEE_IOC_INVOKE);
+	buf_data.buf_ptr = (uintptr_t) &open_session_buf;
+	buf_data.buf_len = open_session_size;
+	CHK_BUF(TEE_IOC_OPEN_SESSION);
+	buf_data.buf_ptr = (uintptr_t) &supp_recv_buf;
+	buf_data.buf_len = supp_recv_size;
+	CHK_BUF(TEE_IOC_SUPPL_RECV);
+	buf_data.buf_ptr = (uintptr_t) &supp_send_buf;
+	buf_data.buf_len = supp_send_size;
+	CHK_BUF(TEE_IOC_SUPPL_SEND);
+
+	invoke_buf.invoke.num_params = NUM_PARAMS;
+	supp_recv_buf.supp_recv.num_params = NUM_PARAMS;
+	supp_send_buf.supp_send.num_params = NUM_PARAMS;
+	open_session_buf.open_session.num_params = NUM_PARAMS;
+
+	/* Invalid buf_len */
+	buf_data.buf_len = 0;
+	CHK_BUF(TEE_IOC_INVOKE);
+	CHK_BUF(TEE_IOC_OPEN_SESSION);
+	CHK_BUF(TEE_IOC_SUPPL_RECV);
+	CHK_BUF(TEE_IOC_SUPPL_SEND);
+
+	buf_data.buf_len = (unsigned long long) -1;
+	CHK_BUF(TEE_IOC_INVOKE);
+	CHK_BUF(TEE_IOC_OPEN_SESSION);
+	CHK_BUF(TEE_IOC_SUPPL_RECV);
+	CHK_BUF(TEE_IOC_SUPPL_SEND);
+
+	/* Valid buf_len, invalid buf_ptr */
+	buf_data.buf_ptr = one_beef;
+	buf_data.buf_len = invoke_size;
+	CHK_BUF(TEE_IOC_INVOKE);
+	buf_data.buf_len = open_session_size;
+	CHK_BUF(TEE_IOC_OPEN_SESSION);
+	buf_data.buf_len = supp_recv_size;
+	CHK_BUF(TEE_IOC_SUPPL_RECV);
+	buf_data.buf_len = supp_send_size;
+	CHK_BUF(TEE_IOC_SUPPL_SEND);
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else /* !HAVE_LINUX_TEE_H */
+
+SKIP_MAIN_UNDEFINED("HAVE_LINUX_TEE_H")
+
+#endif /* HAVE_LINUX_TEE_H */
diff -pruN 5.5-3/tests/ioctl_tee.gen.test 5.9-0ubuntu2/tests/ioctl_tee.gen.test
--- 5.5-3/tests/ioctl_tee.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_tee.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_tee +ioctl.test ); do not edit.
+set -- 
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests/ioctl_uffdio.c 5.9-0ubuntu2/tests/ioctl_uffdio.c
--- 5.5-3/tests/ioctl_uffdio.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_uffdio.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
  * Copyright (c)      2016 Red Hat, Inc.
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -135,6 +135,13 @@ main(void)
 	       " mode=UFFDIO_COPY_MODE_DONTWAKE, copy=%#zx}) = %d\n",
 	       fd, area2, area1, pagesize, pagesize, rc);
 
+	copy_struct->mode = 0xdeadbeef;;
+	rc = ioctl(fd, UFFDIO_COPY, copy_struct);
+	printf("ioctl(%d, UFFDIO_COPY, {dst=%p, src=%p, len=%#zx,"
+	       " mode=UFFDIO_COPY_MODE_DONTWAKE|UFFDIO_COPY_MODE_WP|0xdeadbeec"
+	       "}) = %s\n",
+	       fd, area2, area1, pagesize, sprintrc(rc));
+
 	/* ---- ZEROPAGE ---- */
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct uffdio_zeropage, zero_struct);
 	madvise(area2, pagesize, MADV_DONTNEED);
diff -pruN 5.5-3/tests/ioctl_v4l2.c 5.9-0ubuntu2/tests/ioctl_v4l2.c
--- 5.5-3/tests/ioctl_v4l2.c	2019-08-05 22:48:31.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -8,11 +8,23 @@
 
 #include "tests.h"
 #include <errno.h>
+#include <stdint.h>
 #include <stdio.h>
 #include <string.h>
 #include <sys/ioctl.h>
-#include <linux/types.h>
-#include <linux/videodev2.h>
+#include "kernel_v4l2_types.h"
+
+#define XLAT_MACROS_ONLY
+# include "xlat/v4l2_ioctl_cmds.h"
+#undef XLAT_MACROS_ONLY
+
+#ifndef V4L2_CTRL_FLAG_NEXT_CTRL
+# define V4L2_CTRL_FLAG_NEXT_CTRL 0x80000000
+#endif
+
+#ifndef V4L2_CTRL_CLASS_DETECT
+# define V4L2_CTRL_CLASS_DETECT 0x00a30000
+#endif
 
 #define cc0(arg) ((unsigned int) (unsigned char) (arg))
 #define cc1(arg) ((unsigned int) (unsigned char) ((unsigned int) (arg) >> 8))
@@ -70,8 +82,21 @@ init_v4l2_format(struct v4l2_format *con
 		     i < ARRAY_SIZE(f->fmt.pix_mp.plane_fmt);
 		     i++) {
 			cur_pix[i].sizeimage = 0x1e3c531c | i;
-			cur_pix[i].bytesperline = 0xa983d721 | i;
+			if (sizeof(cur_pix[i].bytesperline) ==
+			    sizeof(uint32_t)) {
+				cur_pix[i].bytesperline = 0xa983d721 | i;
+			} else {
+# if WORDS_BIGENDIAN
+				cur_pix[i].bytesperline = 0xa983;
+				cur_pix[i].reserved[0] = 0xd721 | i;
+# else
+				cur_pix[i].bytesperline = 0xd721 | i;
+				cur_pix[i].reserved[0] = 0xa983;
+# endif
+			}
 		}
+		if (buf_type == V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE)
+			f->fmt.pix_mp.num_planes = 1;
 		break;
 	}
 #endif
@@ -85,10 +110,10 @@ init_v4l2_format(struct v4l2_format *con
 		f->fmt.win.w.height = 0xbbd886c8;
 		f->fmt.win.field = V4L2_FIELD_ANY;
 		f->fmt.win.chromakey = 0xdb1f991f;
-		f->fmt.win.clipcount = 2;
+		f->fmt.win.clipcount =
+			buf_type == V4L2_BUF_TYPE_VIDEO_OVERLAY ? 3 : 2;
 		f->fmt.win.clips =
-			tail_alloc(sizeof(*f->fmt.win.clips) *
-			f->fmt.win.clipcount);
+			tail_alloc(sizeof(*f->fmt.win.clips) * 2);
 		f->fmt.win.clips[0].c.left = 0x3313d36e;
 		f->fmt.win.clips[0].c.top = 0xcdffe510;
 		f->fmt.win.clips[0].c.width = 0x2064f3a8;
@@ -101,6 +126,9 @@ init_v4l2_format(struct v4l2_format *con
 		f->fmt.win.bitmap = (void *) -2UL;
 #ifdef HAVE_STRUCT_V4L2_WINDOW_GLOBAL_ALPHA
 		f->fmt.win.global_alpha = 0xce;
+#else
+		((uint8_t *) &f->fmt.win)[offsetofend(struct v4l2_window,
+						      bitmap)] = 0xce;
 #endif
 		break;
 	case V4L2_BUF_TYPE_VBI_CAPTURE:
@@ -138,7 +166,12 @@ init_v4l2_format(struct v4l2_format *con
 	case V4L2_BUF_TYPE_SDR_OUTPUT:
 		f->fmt.sdr.pixelformat = sf_magic;
 # ifdef HAVE_STRUCT_V4L2_SDR_FORMAT_BUFFERSIZE
-		f->fmt.sdr.buffersize = 0x25afabfb;
+		if (sizeof(f->fmt.sdr.buffersize == sizeof(uint32_t)))
+			f->fmt.sdr.buffersize = 0x25afabfb;
+		else
+			((uint32_t *) &f->fmt.sdr)[1] = 0x25afabfb;
+# else
+		((uint32_t *) &f->fmt.sdr)[1] = 0x25afabfb;
 # endif
 		break;
 #endif
@@ -155,8 +188,8 @@ init_v4l2_format(struct v4l2_format *con
 
 static void
 dprint_ioctl_v4l2(struct v4l2_format *const f,
-		  const char *request, const unsigned int buf_type,
-		  const char *buf_type_string)
+		  XLAT_SEL(unsigned reqval, const char *reqstr),
+		  const unsigned int buf_type, const char *buf_type_string)
 {
 	int saved_errno;
 
@@ -164,12 +197,16 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 	case V4L2_BUF_TYPE_VIDEO_CAPTURE:
 	case V4L2_BUF_TYPE_VIDEO_OUTPUT:
 		saved_errno = errno;
-		printf("ioctl(-1, %s, {type=%s"
+		printf("ioctl(-1, " XLAT_FMT ", {type=" XLAT_FMT
 		       ", fmt.pix={width=%u, height=%u, pixelformat=",
-		       request,
-		       buf_type_string,
+		       XLAT_SEL(reqval, reqstr),
+		       XLAT_SEL(buf_type, buf_type_string),
 		       f->fmt.pix.width, f->fmt.pix.height);
 
+#if XLAT_RAW
+		printf("%#x", buf_type == V4L2_BUF_TYPE_VIDEO_CAPTURE
+			      ? magic : pf_magic);
+#else /* !XLAT_RAW */
 		if (buf_type == V4L2_BUF_TYPE_VIDEO_CAPTURE)
 			printf("v4l2_fourcc('\\x%x', '\\x%x', '\\x%x', '\\x%x')",
 			       cc0(magic), cc1(magic), cc2(magic), cc3(magic));
@@ -178,12 +215,15 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 			       "/* V4L2_PIX_FMT_SPCA508 */",
 			       cc0(pf_magic), cc1(pf_magic), cc2(pf_magic),
 			       cc3(pf_magic));
+#endif /* XLAT_RAW */
 
 		errno = saved_errno;
-		printf(", field=V4L2_FIELD_NONE, bytesperline=%u, sizeimage=%u"
-		       ", colorspace=V4L2_COLORSPACE_JPEG}}) = -1 EBADF (%m)\n",
+		printf(", field=" XLAT_FMT ", bytesperline=%u, sizeimage=%u"
+		       ", colorspace=" XLAT_FMT "}}) = -1 EBADF (%m)\n",
+		       XLAT_ARGS(V4L2_FIELD_NONE),
 		       f->fmt.pix.bytesperline,
-		       f->fmt.pix.sizeimage);
+		       f->fmt.pix.sizeimage,
+		       XLAT_ARGS(V4L2_COLORSPACE_JPEG));
 		break;
 #if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE
 	case V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE:
@@ -191,13 +231,17 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 		unsigned int i;
 
 		saved_errno = errno;
-		printf("ioctl(-1, %s"
-		       ", {type=%s"
+		printf("ioctl(-1, " XLAT_FMT
+		       ", {type=" XLAT_FMT
 		       ", fmt.pix_mp={width=%u, height=%u, pixelformat=",
-		       request,
-		       buf_type_string,
+		       XLAT_SEL(reqval, reqstr),
+		       XLAT_SEL(buf_type, buf_type_string),
 		       f->fmt.pix_mp.width, f->fmt.pix_mp.height);
 
+# if XLAT_RAW
+		printf("%#x", buf_type == V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE
+			      ? magic : pf_magic);
+# else /* !XLAT_RAW */
 		if (buf_type == V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE)
 			printf("v4l2_fourcc('\\x%x', '\\x%x', '\\x%x', '\\x%x')",
 			       cc0(magic), cc1(magic), cc2(magic), cc3(magic));
@@ -206,21 +250,35 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 			       "/* V4L2_PIX_FMT_SPCA508 */",
 			       cc0(pf_magic), cc1(pf_magic), cc2(pf_magic),
 			       cc3(pf_magic));
+# endif /* XLAT_RAW */
 
-		printf(", field=V4L2_FIELD_NONE, colorspace="
-		       "V4L2_COLORSPACE_JPEG, plane_fmt=[");
+		printf(", field=" XLAT_FMT ", colorspace=" XLAT_FMT
+		       ", plane_fmt=[",
+		       XLAT_ARGS(V4L2_FIELD_NONE),
+		       XLAT_ARGS(V4L2_COLORSPACE_JPEG));
 		for (i = 0;
-		     i < ARRAY_SIZE(f->fmt.pix_mp.plane_fmt);
+		     i < (buf_type == V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE
+		          ? 1 : ARRAY_SIZE(f->fmt.pix_mp.plane_fmt));
 		     ++i) {
 			if (i)
 				printf(", ");
 			printf("{sizeimage=%u, bytesperline=%u}",
 			f->fmt.pix_mp.plane_fmt[i].sizeimage,
-			f->fmt.pix_mp.plane_fmt[i].bytesperline);
+			sizeof(f->fmt.pix_mp.plane_fmt[i].bytesperline) ==
+			sizeof(uint32_t)
+			? f->fmt.pix_mp.plane_fmt[i].bytesperline :
+# if WORDS_BIGENDIAN
+			(f->fmt.pix_mp.plane_fmt[i].bytesperline << 16) |
+			f->fmt.pix_mp.plane_fmt[i].reserved[0]
+# else
+			f->fmt.pix_mp.plane_fmt[i].bytesperline |
+			(f->fmt.pix_mp.plane_fmt[i].reserved[0] << 16)
+# endif
+			);
 		}
 		errno = saved_errno;
 		printf("], num_planes=%u}}) = -1 EBADF (%m)\n",
-		f->fmt.pix_mp.num_planes);
+		       f->fmt.pix_mp.num_planes);
 		break;
 	}
 #endif
@@ -228,20 +286,17 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 	case V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY:
 #endif
 	case V4L2_BUF_TYPE_VIDEO_OVERLAY:
-		printf("ioctl(-1, %s, {type=%s"
+		saved_errno = errno;
+		printf("ioctl(-1, " XLAT_FMT ", {type=" XLAT_FMT
 		       ", fmt.win={left=%d, top=%d, width=%u, height=%u"
-		       ", field=V4L2_FIELD_ANY, chromakey=%#x, clips="
+		       ", field=" XLAT_FMT ", chromakey=%#x, clips="
 		       "[{left=%d, top=%d, width=%u, height=%u}, "
-		       "{left=%d, top=%d, width=%u, height=%u}]"
-		       ", clipcount=%u, bitmap=%p"
-#ifdef HAVE_STRUCT_V4L2_WINDOW_GLOBAL_ALPHA
-		       ", global_alpha=%#x"
-#endif
-		       "}}) = -1 EBADF (%m)\n",
-		       request,
-		       buf_type_string,
+		       "{left=%d, top=%d, width=%u, height=%u}",
+		       XLAT_SEL(reqval, reqstr),
+		       XLAT_SEL(buf_type, buf_type_string),
 		       f->fmt.win.w.left, f->fmt.win.w.top,
 		       f->fmt.win.w.width, f->fmt.win.w.height,
+		       XLAT_ARGS(V4L2_FIELD_ANY),
 		       f->fmt.win.chromakey,
 		       f->fmt.win.clips[0].c.left,
 		       f->fmt.win.clips[0].c.top,
@@ -250,24 +305,37 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 		       f->fmt.win.clips[1].c.left,
 		       f->fmt.win.clips[1].c.top,
 		       f->fmt.win.clips[1].c.width,
-		       f->fmt.win.clips[1].c.height,
-		       f->fmt.win.clipcount, f->fmt.win.bitmap
+		       f->fmt.win.clips[1].c.height);
+		if (f->fmt.win.clipcount > 2)
+			printf(", ... /* %p */", f->fmt.win.clips + 2);
+		errno = saved_errno;
+		printf("], clipcount=%u, bitmap=%p"
+		       ", global_alpha=%#x"
+		       "}}) = -1 EBADF (%m)\n",
+		       f->fmt.win.clipcount, f->fmt.win.bitmap,
 #ifdef HAVE_STRUCT_V4L2_WINDOW_GLOBAL_ALPHA
-		       , f->fmt.win.global_alpha
+		       f->fmt.win.global_alpha
+#else
+		       ((uint8_t *) &f->fmt.win)[offsetofend(struct v4l2_window,
+							     bitmap)]
 #endif
 		       );
 		break;
 	case V4L2_BUF_TYPE_VBI_CAPTURE:
 	case V4L2_BUF_TYPE_VBI_OUTPUT:
 		saved_errno = errno;
-		printf("ioctl(-1, %s, {type=%s"
+		printf("ioctl(-1, " XLAT_FMT ", {type=" XLAT_FMT
 		       ", fmt.vbi={sampling_rate=%u, offset=%u"
 		       ", samples_per_line=%u, sample_format=",
-		       request,
-		       buf_type_string,
+		       XLAT_SEL(reqval, reqstr),
+		       XLAT_SEL(buf_type, buf_type_string),
 		       f->fmt.vbi.sampling_rate, f->fmt.vbi.offset,
 		       f->fmt.vbi.samples_per_line);
 
+#if XLAT_RAW
+		printf("%#x", buf_type == V4L2_BUF_TYPE_VBI_CAPTURE
+			      ? magic : pf_magic);
+#else /* !XLAT_RAW */
 		if (buf_type == V4L2_BUF_TYPE_VBI_CAPTURE)
 			printf("v4l2_fourcc('\\x%x', '\\x%x', '\\x%x', '\\x%x')",
 			       cc0(magic), cc1(magic), cc2(magic), cc3(magic));
@@ -276,24 +344,27 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 			       "/* V4L2_PIX_FMT_SPCA508 */",
 			       cc0(pf_magic), cc1(pf_magic), cc2(pf_magic),
 			       cc3(pf_magic));
+#endif /* XLAT_RAW */
 
 		errno = saved_errno;
-		printf(", start=[%u, %u], count=[%u, %u]"
-		       ", flags=V4L2_VBI_INTERLACED}})"
+		printf(", start=[%d, %d], count=[%u, %u]"
+		       ", flags=" XLAT_FMT "}})"
 		       " = -1 EBADF (%m)\n",
 		       f->fmt.vbi.start[0], f->fmt.vbi.start[1],
-		       f->fmt.vbi.count[0], f->fmt.vbi.count[1]);
+		       f->fmt.vbi.count[0], f->fmt.vbi.count[1],
+		       XLAT_ARGS(V4L2_VBI_INTERLACED));
 		break;
 #if HAVE_DECL_V4L2_BUF_TYPE_SLICED_VBI_CAPTURE
 	case V4L2_BUF_TYPE_SLICED_VBI_CAPTURE:
 	case V4L2_BUF_TYPE_SLICED_VBI_OUTPUT: {
 		unsigned int i, j;
 
-		printf("ioctl(-1, %s, {type=%s"
-		       ", fmt.sliced={service_set=V4L2_SLICED_VPS"
+		printf("ioctl(-1, " XLAT_FMT ", {type=" XLAT_FMT
+		       ", fmt.sliced={service_set=" XLAT_FMT
 		       ", io_size=%u, service_lines=[",
-		       request,
-		       buf_type_string,
+		       XLAT_SEL(reqval, reqstr),
+		       XLAT_SEL(buf_type, buf_type_string),
+		       XLAT_ARGS(V4L2_SLICED_VPS),
 		       f->fmt.sliced.io_size);
 		for (i = 0;
 		     i < ARRAY_SIZE(f->fmt.sliced.service_lines);
@@ -321,30 +392,38 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 #if HAVE_DECL_V4L2_BUF_TYPE_SDR_CAPTURE
 	case V4L2_BUF_TYPE_SDR_CAPTURE:
 		saved_errno = errno;
-		printf("ioctl(-1, %s, {type=%s"
+		printf("ioctl(-1, " XLAT_FMT ", {type=" XLAT_FMT
 		       ", fmt.sdr={pixelformat=",
-		       request,
-		       buf_type_string);
+		       XLAT_SEL(reqval, reqstr),
+		       XLAT_SEL(buf_type, buf_type_string));
 
+# if XLAT_RAW
+		if (buf_type == V4L2_BUF_TYPE_SDR_CAPTURE)
+			printf("%#x", magic);
+#  if HAVE_DECL_V4L2_BUF_TYPE_SDR_OUTPUT
+		else
+			printf("%#x", sf_magic);
+#  endif
+# else /* !XLAT_RAW */
 		if (buf_type == V4L2_BUF_TYPE_SDR_CAPTURE)
 			printf("v4l2_fourcc('\\x%x', '\\x%x', '\\x%x', '\\x%x')",
 			       cc0(magic), cc1(magic), cc2(magic), cc3(magic));
-# if HAVE_DECL_V4L2_BUF_TYPE_SDR_OUTPUT
+#  if HAVE_DECL_V4L2_BUF_TYPE_SDR_OUTPUT
 		else
 			printf("v4l2_fourcc('%c', '%c', '%c', '%c') "
 			       "/* V4L2_SDR_FMT_RU12LE */",
 			       cc0(sf_magic), cc1(sf_magic), cc2(sf_magic),
 			       cc3(sf_magic));
-# endif
+#  endif
+# endif /* XLAT_RAW */
 
 		errno = saved_errno;
-		printf(
-# ifdef HAVE_STRUCT_V4L2_SDR_FORMAT_BUFFERSIZE
-		       ", buffersize=%u"
-# endif
-		       "}}) = -1 EBADF (%m)\n"
+		printf(", buffersize=%u}}) = -1 EBADF (%m)\n"
 # ifdef HAVE_STRUCT_V4L2_SDR_FORMAT_BUFFERSIZE
-		       , f->fmt.sdr.buffersize
+		       , sizeof(f->fmt.sdr.buffersize == sizeof(uint32_t))
+			? f->fmt.sdr.buffersize : ((uint32_t *) &f->fmt.sdr)[1]
+# else
+		       , ((uint32_t *) &f->fmt.sdr)[1]
 # endif
 		       );
 		break;
@@ -352,7 +431,8 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 	}
 }
 #define print_ioctl_v4l2(v4l2_format, request, buf_type)	\
-	dprint_ioctl_v4l2((v4l2_format), (request), (buf_type), #buf_type)
+	dprint_ioctl_v4l2((v4l2_format), XLAT_SEL(request, #request), \
+			  (buf_type), #buf_type)
 
 int
 main(void)
@@ -364,267 +444,559 @@ main(void)
 
 	unsigned char cc[sizeof(int)] = { 'A', '\'', '\\', '\xfa' };
 
+	/* Unknown */
+	static const struct {
+		uint32_t flags;
+		const char *str;
+	} cmd_flags[] = {
+		{ ARG_STR(_IOC_NONE) },
+		{ ARG_STR(_IOC_READ) },
+		{ ARG_STR(_IOC_WRITE) },
+		{ ARG_STR(_IOC_READ|_IOC_WRITE) },
+	};
+	static const uint8_t unknown_cmds[] = {
+		1, 3, 6 /* VIDIOC_G_MPEGCOMP */, 7 /* VIDIOC_S_MPEGCOMP */,
+		12, 13, 20, 31, 32, 35, 42, 43, 44, 45, 51, 52, 53,
+		81 /* VIDIOC_G_CHIP_IDENT_OLD */,
+		83 /* VIDIOC_ENUM_DV_PRESETS */, 84 /* VIDIOC_S_DV_PRESET */,
+		85 /* VIDIOC_G_DV_PRESET */, 86 /* VIDIOC_QUERY_DV_PRESET */,
+		104 /* 103 is the last existing */, 255
+	};
+
+	for (size_t i = 0; i < ARRAY_SIZE(unknown_cmds); i++) {
+		/* Trying to hit common argument sizes */
+		for (size_t j = 0; j < 256; j += 4) {
+			for (size_t k = 0; k < ARRAY_SIZE(cmd_flags); k++) {
+				uint32_t ioc = _IOC(cmd_flags[k].flags, 'V',
+						    unknown_cmds[i], j);
+				/*
+				 * Conflicts with VT* and VBG* ioctls
+				 * that happen to also use 'V' command type.
+				 */
+				switch (ioc) {
+				/* VT_GETMODE */
+				case _IOC(_IOC_NONE, 'V', 1, 0):
+				/* VT_GETSTATE */
+				case _IOC(_IOC_NONE, 'V', 3, 0):
+				/* VBG_IOCTL_VMMDEV_REQUEST_BIG */
+				case _IOC(_IOC_READ|_IOC_WRITE, 'V', 3, 0):
+				/* VT_ACTIVATE */
+				case _IOC(_IOC_NONE, 'V', 6, 0):
+				/* VT_WAITACTIVE */
+				case _IOC(_IOC_NONE, 'V', 7, 0):
+				/* VT_UNLOCKSWITCH */
+				case _IOC(_IOC_NONE, 'V', 12, 0):
+				/* VBG_IOCTL_CHANGE_FILTER_MASK */
+				case _IOC(_IOC_READ|_IOC_WRITE, 'V', 12, 32):
+				/* VT_GETHIFONTMASK */
+				case _IOC(_IOC_NONE, 'V', 13, 0):
+					continue;
+				/* VBG_IOCTL_ACQUIRE_GUEST_CAPABILITIES */
+				case _IOC(_IOC_READ|_IOC_WRITE, 'V', 13, 36):
+					continue;
+				}
+
+				ioctl(-1, ioc, 0);
+				printf("ioctl(-1, " NABBR("%#x") VERB(" /* ")
+				       NRAW("_IOC(%s, 0x56, %#x, %#zx)")
+				       VERB(" */") ", 0) = -1 EBADF (%m)\n"
+#if XLAT_RAW || XLAT_VERBOSE
+				       , ioc
+#endif
+#if !XLAT_RAW
+				       , cmd_flags[k].str, unknown_cmds[i], j
+#endif
+				       );
+
+				ioctl(-1, ioc,
+				      (unsigned long) 0xbadc0deddeadc0deULL);
+				printf("ioctl(-1, " NABBR("%#x") VERB(" /* ")
+				       NRAW("_IOC(%s, 0x56, %#x, %#zx)")
+				       VERB(" */") ", %#lx) = -1 EBADF (%m)\n",
+#if XLAT_RAW || XLAT_VERBOSE
+				       ioc,
+#endif
+#if !XLAT_RAW
+				       cmd_flags[k].str, unknown_cmds[i], j,
+#endif
+				       (unsigned long) 0xbadc0deddeadc0deULL);
+			}
+		}
+	}
+
+	/* Decoding is not supported */
+	static const struct {
+		uint32_t cmd;
+		const char *str;
+	} unsupp_cmds[] = {
+		{ ARG_STR(VIDIOC_OVERLAY) },
+#ifdef VIDIOC_EXPBUF
+		{ ARG_STR(VIDIOC_EXPBUF) },
+#endif
+		{ ARG_STR(VIDIOC_G_AUDIO) },
+		{ ARG_STR(VIDIOC_S_AUDIO) },
+		{ ARG_STR(VIDIOC_QUERYMENU) },
+#ifdef VIDIOC_G_EDID
+		{ ARG_STR(VIDIOC_G_EDID) },
+#endif
+#ifdef VIDIOC_S_EDID
+		{ ARG_STR(VIDIOC_S_EDID) },
+#endif
+		{ ARG_STR(VIDIOC_G_OUTPUT) },
+		{ ARG_STR(VIDIOC_S_OUTPUT) },
+		{ ARG_STR(VIDIOC_ENUMOUTPUT) },
+		{ ARG_STR(VIDIOC_G_AUDOUT) },
+		{ ARG_STR(VIDIOC_S_AUDOUT) },
+		{ ARG_STR(VIDIOC_G_MODULATOR) },
+		{ ARG_STR(VIDIOC_S_MODULATOR) },
+		{ ARG_STR(VIDIOC_G_FREQUENCY) },
+		{ ARG_STR(VIDIOC_S_FREQUENCY) },
+		{ ARG_STR(VIDIOC_G_JPEGCOMP) },
+		{ ARG_STR(VIDIOC_S_JPEGCOMP) },
+		{ ARG_STR(VIDIOC_QUERYSTD) },
+		{ ARG_STR(VIDIOC_ENUMAUDIO) },
+		{ ARG_STR(VIDIOC_ENUMAUDOUT) },
+		{ ARG_STR(VIDIOC_G_PRIORITY) },
+		{ ARG_STR(VIDIOC_S_PRIORITY) },
+		{ ARG_STR(VIDIOC_G_SLICED_VBI_CAP) },
+		{ ARG_STR(VIDIOC_LOG_STATUS) },
+#ifdef VIDIOC_G_ENC_INDEX
+		{ ARG_STR(VIDIOC_G_ENC_INDEX) },
+#endif
+#ifdef VIDIOC_ENCODER_CMD
+		{ ARG_STR(VIDIOC_ENCODER_CMD) },
+#endif
+#ifdef VIDIOC_TRY_ENCODER_CMD
+		{ ARG_STR(VIDIOC_TRY_ENCODER_CMD) },
+#endif
+#ifdef VIDIOC_DBG_S_REGISTER
+		{ ARG_STR(VIDIOC_DBG_S_REGISTER) },
+#endif
+#ifdef VIDIOC_DBG_G_REGISTER
+		{ ARG_STR(VIDIOC_DBG_G_REGISTER) },
+#endif
+#ifdef VIDIOC_G_CHIP_IDENT_OLD
+		{ ARG_STR(VIDIOC_G_CHIP_IDENT_OLD) },
+#endif
+#ifdef VIDIOC_DBG_G_CHIP_IDENT
+		/* Broken on RHEL 6/7 */
+		/* { ARG_STR(VIDIOC_DBG_G_CHIP_IDENT) }, */
+#endif
+#ifdef VIDIOC_S_HW_FREQ_SEEK
+		{ ARG_STR(VIDIOC_S_HW_FREQ_SEEK) },
+#endif
+#ifdef VIDIOC_ENUM_DV_PRESETS
+		/* Next 4 are broken on RHEL 6 */
+		/* { ARG_STR(VIDIOC_ENUM_DV_PRESETS) }, */
+#endif
+#ifdef VIDIOC_S_DV_PRESET
+		/* { ARG_STR(VIDIOC_S_DV_PRESET) }, */
+#endif
+#ifdef VIDIOC_G_DV_PRESET
+		/* { ARG_STR(VIDIOC_G_DV_PRESET) }, */
+#endif
+#ifdef VIDIOC_QUERY_DV_PRESET
+		/* { ARG_STR(VIDIOC_QUERY_DV_PRESET) }, */
+#endif
+#ifdef VIDIOC_S_DV_TIMINGS
+		{ ARG_STR(VIDIOC_S_DV_TIMINGS) },
+#endif
+#ifdef VIDIOC_G_DV_TIMINGS
+		{ ARG_STR(VIDIOC_G_DV_TIMINGS) },
+#endif
+#ifdef VIDIOC_DQEVENT
+		{ ARG_STR(VIDIOC_DQEVENT) },
+#endif
+#ifdef VIDIOC_SUBSCRIBE_EVENT
+		{ ARG_STR(VIDIOC_SUBSCRIBE_EVENT) },
+#endif
+#ifdef VIDIOC_UNSUBSCRIBE_EVENT
+		{ ARG_STR(VIDIOC_UNSUBSCRIBE_EVENT) },
+#endif
+#ifdef VIDIOC_PREPARE_BUF
+		{ ARG_STR(VIDIOC_PREPARE_BUF) },
+#endif
+#ifdef VIDIOC_G_SELECTION
+		{ ARG_STR(VIDIOC_G_SELECTION) },
+#endif
+#ifdef VIDIOC_S_SELECTION
+		{ ARG_STR(VIDIOC_S_SELECTION) },
+#endif
+#ifdef VIDIOC_DECODER_CMD
+		{ ARG_STR(VIDIOC_DECODER_CMD) },
+#endif
+#ifdef VIDIOC_TRY_DECODER_CMD
+		{ ARG_STR(VIDIOC_TRY_DECODER_CMD) },
+#endif
+#ifdef VIDIOC_ENUM_DV_TIMINGS
+		{ ARG_STR(VIDIOC_ENUM_DV_TIMINGS) },
+#endif
+#ifdef VIDIOC_QUERY_DV_TIMINGS
+		{ ARG_STR(VIDIOC_QUERY_DV_TIMINGS) },
+#endif
+#ifdef VIDIOC_DV_TIMINGS_CAP
+		{ ARG_STR(VIDIOC_DV_TIMINGS_CAP) },
+#endif
+#ifdef VIDIOC_ENUM_FREQ_BANDS
+		{ ARG_STR(VIDIOC_ENUM_FREQ_BANDS) },
+#endif
+#ifdef VIDIOC_DBG_G_CHIP_INFO
+		{ ARG_STR(VIDIOC_DBG_G_CHIP_INFO) },
+#endif
+#ifdef VIDIOC_QUERY_EXT_CTRL
+		{ ARG_STR(VIDIOC_QUERY_EXT_CTRL) },
+#endif
+#ifdef VIDIOC_SUBDEV_ENUM_MBUS_CODE
+		{ ARG_STR(VIDIOC_SUBDEV_ENUM_MBUS_CODE) },
+#endif
+#ifdef VIDIOC_SUBDEV_G_FMT
+		{ ARG_STR(VIDIOC_SUBDEV_G_FMT) },
+#endif
+#ifdef VIDIOC_SUBDEV_S_FMT
+		{ ARG_STR(VIDIOC_SUBDEV_S_FMT) },
+#endif
+#ifdef VIDIOC_SUBDEV_G_FRAME_INTERVAL
+		{ ARG_STR(VIDIOC_SUBDEV_G_FRAME_INTERVAL) },
+#endif
+#ifdef VIDIOC_SUBDEV_S_FRAME_INTERVAL
+		{ ARG_STR(VIDIOC_SUBDEV_S_FRAME_INTERVAL) },
+#endif
+#ifdef VIDIOC_SUBDEV_G_CROP
+		{ ARG_STR(VIDIOC_SUBDEV_G_CROP) },
+#endif
+#ifdef VIDIOC_SUBDEV_S_CROP
+		{ ARG_STR(VIDIOC_SUBDEV_S_CROP) },
+#endif
+#ifdef VIDIOC_SUBDEV_G_SELECTION
+		{ ARG_STR(VIDIOC_SUBDEV_G_SELECTION) },
+#endif
+#ifdef VIDIOC_SUBDEV_S_SELECTION
+		{ ARG_STR(VIDIOC_SUBDEV_S_SELECTION) },
+#endif
+#ifdef VIDIOC_SUBDEV_ENUM_FRAME_SIZE
+		{ ARG_STR(VIDIOC_SUBDEV_ENUM_FRAME_SIZE) },
+#endif
+#ifdef VIDIOC_SUBDEV_ENUM_FRAME_INTERVAL
+		{ ARG_STR(VIDIOC_SUBDEV_ENUM_FRAME_INTERVAL) },
+#endif
+	};
+
+	for (size_t i = 0; i < ARRAY_SIZE(unsupp_cmds); i++) {
+		switch (unsupp_cmds[i].cmd) {
+		/*
+		 * VIDIOC_G_SLICED_VBI_CAP macro has been changed from
+		 * IOR to IOWR in Linux v2.6.19-rc1~643^2~37, skip it.
+		 */
+		case _IOR('V', 69, struct v4l2_sliced_vbi_cap):
+			continue;
+		}
+
+		ioctl(-1, unsupp_cmds[i].cmd, 0);
+		printf("ioctl(-1, " XLAT_FMT ", 0) = -1 EBADF (%m)\n",
+		       XLAT_SEL(unsupp_cmds[i].cmd, unsupp_cmds[i].str));
+
+		ioctl(-1, unsupp_cmds[i].cmd,
+		      (unsigned long) 0xbadc0deddeadc0deULL);
+		printf("ioctl(-1, " XLAT_FMT ", %#lx) = -1 EBADF (%m)\n",
+		       XLAT_SEL(unsupp_cmds[i].cmd, unsupp_cmds[i].str),
+		       (unsigned long) 0xbadc0deddeadc0deULL);
+	}
+
 	/* VIDIOC_QUERYCAP */
 	ioctl(-1, VIDIOC_QUERYCAP, 0);
-	printf("ioctl(-1, VIDIOC_QUERYCAP, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QUERYCAP));
 
 	ioctl(-1, VIDIOC_QUERYCAP, page);
-	printf("ioctl(-1, VIDIOC_QUERYCAP, %p) = -1 EBADF (%m)\n", page);
+	printf("ioctl(-1, %s, %p) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QUERYCAP), page);
 
 	/* VIDIOC_ENUM_FMT */
 	ioctl(-1, VIDIOC_ENUM_FMT, 0);
-	printf("ioctl(-1, VIDIOC_ENUM_FMT, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUM_FMT));
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct v4l2_fmtdesc, p_fmtdesc);
 	p_fmtdesc->index = magic;
 	p_fmtdesc->type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
 	ioctl(-1, VIDIOC_ENUM_FMT, p_fmtdesc);
-	printf("ioctl(-1, VIDIOC_ENUM_FMT, {index=%u"
-	       ", type=V4L2_BUF_TYPE_VIDEO_CAPTURE}) = -1 EBADF (%m)\n",
-	       p_fmtdesc->index);
+	printf("ioctl(-1, %s, {index=%u, type=" XLAT_FMT
+	       "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUM_FMT), p_fmtdesc->index,
+	       XLAT_ARGS(V4L2_BUF_TYPE_VIDEO_CAPTURE));
 
 	/* VIDIOC_G_FMT */
 	ioctl(-1, VIDIOC_G_FMT, 0);
-	printf("ioctl(-1, VIDIOC_G_FMT, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT));
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct v4l2_format, p_format);
 
 	p_format->type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
 	ioctl(-1, VIDIOC_G_FMT, p_format);
-	printf("ioctl(-1, VIDIOC_G_FMT"
-	       ", {type=V4L2_BUF_TYPE_VIDEO_CAPTURE}) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {type=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT),
+	       XLAT_ARGS(V4L2_BUF_TYPE_VIDEO_CAPTURE));
 #if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE
 	p_format->type = V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE;
 	ioctl(-1, VIDIOC_G_FMT, p_format);
-	printf("ioctl(-1, VIDIOC_G_FMT"
-	       ", {type=V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE}) ="
-	       " -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {type=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT),
+	       XLAT_ARGS(V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE));
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY
 	p_format->type = V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY;
 	ioctl(-1, VIDIOC_G_FMT, p_format);
-	printf("ioctl(-1, VIDIOC_G_FMT"
-	       ", {type=V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY}) ="
-	       " -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {type=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT),
+	       XLAT_ARGS(V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY));
 #endif
 	p_format->type = V4L2_BUF_TYPE_VIDEO_OVERLAY;
 	ioctl(-1, VIDIOC_G_FMT, p_format);
-	printf("ioctl(-1, VIDIOC_G_FMT"
-	       ", {type=V4L2_BUF_TYPE_VIDEO_OVERLAY}) ="
-	       " -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {type=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT),
+	       XLAT_ARGS(V4L2_BUF_TYPE_VIDEO_OVERLAY));
 
 	p_format->type = V4L2_BUF_TYPE_VBI_CAPTURE;
 	ioctl(-1, VIDIOC_G_FMT, p_format);
-	printf("ioctl(-1, VIDIOC_G_FMT"
-	       ", {type=V4L2_BUF_TYPE_VBI_CAPTURE}) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {type=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT),
+	       XLAT_ARGS(V4L2_BUF_TYPE_VBI_CAPTURE));
 #if HAVE_DECL_V4L2_BUF_TYPE_SLICED_VBI_CAPTURE
 	p_format->type = V4L2_BUF_TYPE_SLICED_VBI_CAPTURE;
 	ioctl(-1, VIDIOC_G_FMT, p_format);
-	printf("ioctl(-1, VIDIOC_G_FMT"
-	       ", {type=V4L2_BUF_TYPE_SLICED_VBI_CAPTURE}) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {type=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT),
+	       XLAT_ARGS(V4L2_BUF_TYPE_SLICED_VBI_CAPTURE));
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_SDR_CAPTURE
 	p_format->type = V4L2_BUF_TYPE_SDR_CAPTURE;
 	ioctl(-1, VIDIOC_G_FMT, p_format);
-	printf("ioctl(-1, VIDIOC_G_FMT"
-	       ", {type=V4L2_BUF_TYPE_SDR_CAPTURE}) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {type=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT),
+	       XLAT_ARGS(V4L2_BUF_TYPE_SDR_CAPTURE));
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_SDR_OUTPUT
 	p_format->type = V4L2_BUF_TYPE_SDR_OUTPUT;
 	ioctl(-1, VIDIOC_G_FMT, p_format);
-	printf("ioctl(-1, VIDIOC_G_FMT"
-	       ", {type=V4L2_BUF_TYPE_SDR_OUTPUT}) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {type=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT),
+	       XLAT_ARGS(V4L2_BUF_TYPE_SDR_OUTPUT));
 #endif
 	/* VIDIOC_S_FMT */
 	ioctl(-1, VIDIOC_S_FMT, 0);
-	printf("ioctl(-1, VIDIOC_S_FMT, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_FMT));
 
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VIDEO_OUTPUT);
 	ioctl(-1, VIDIOC_S_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_S_FMT", V4L2_BUF_TYPE_VIDEO_OUTPUT);
+	print_ioctl_v4l2(p_format, VIDIOC_S_FMT,
+			 V4L2_BUF_TYPE_VIDEO_OUTPUT);
 #if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE);
 	ioctl(-1, VIDIOC_S_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_S_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_S_FMT,
 			 V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE);
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY);
 	ioctl(-1, VIDIOC_S_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_S_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_S_FMT,
 			 V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY);
 #endif
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VIDEO_OVERLAY);
 	ioctl(-1, VIDIOC_S_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_S_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_S_FMT,
 			 V4L2_BUF_TYPE_VIDEO_OVERLAY);
 
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VBI_CAPTURE);
 	ioctl(-1, VIDIOC_S_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_S_FMT", V4L2_BUF_TYPE_VBI_CAPTURE);
+	print_ioctl_v4l2(p_format, VIDIOC_S_FMT, V4L2_BUF_TYPE_VBI_CAPTURE);
 #if HAVE_DECL_V4L2_BUF_TYPE_SLICED_VBI_CAPTURE
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_SLICED_VBI_CAPTURE);
 	ioctl(-1, VIDIOC_S_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_S_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_S_FMT,
 			 V4L2_BUF_TYPE_SLICED_VBI_CAPTURE);
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_SDR_CAPTURE
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_SDR_CAPTURE);
 	ioctl(-1, VIDIOC_S_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_S_FMT", V4L2_BUF_TYPE_SDR_CAPTURE);
+	print_ioctl_v4l2(p_format, VIDIOC_S_FMT, V4L2_BUF_TYPE_SDR_CAPTURE);
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_SDR_OUTPUT
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_SDR_OUTPUT);
 	ioctl(-1, VIDIOC_S_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_S_FMT", V4L2_BUF_TYPE_SDR_OUTPUT);
+	print_ioctl_v4l2(p_format, VIDIOC_S_FMT, V4L2_BUF_TYPE_SDR_OUTPUT);
 #endif
 	/* VIDIOC_TRY_FMT */
 	ioctl(-1, VIDIOC_TRY_FMT, 0);
-	printf("ioctl(-1, VIDIOC_TRY_FMT, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_TRY_FMT));
 
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VIDEO_OUTPUT);
 	ioctl(-1, VIDIOC_TRY_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_TRY_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_TRY_FMT,
 			 V4L2_BUF_TYPE_VIDEO_OUTPUT);
 #if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE);
 	ioctl(-1, VIDIOC_TRY_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_TRY_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_TRY_FMT,
 			 V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE);
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY);
 	ioctl(-1, VIDIOC_TRY_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_TRY_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_TRY_FMT,
 			 V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY);
 #endif
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VIDEO_OVERLAY);
 	ioctl(-1, VIDIOC_TRY_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_TRY_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_TRY_FMT,
 			 V4L2_BUF_TYPE_VIDEO_OVERLAY);
 
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VBI_CAPTURE);
 	ioctl(-1, VIDIOC_TRY_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_TRY_FMT", V4L2_BUF_TYPE_VBI_CAPTURE);
+	print_ioctl_v4l2(p_format, VIDIOC_TRY_FMT, V4L2_BUF_TYPE_VBI_CAPTURE);
 #if HAVE_DECL_V4L2_BUF_TYPE_SLICED_VBI_CAPTURE
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_SLICED_VBI_CAPTURE);
 	ioctl(-1, VIDIOC_TRY_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_TRY_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_TRY_FMT,
 			 V4L2_BUF_TYPE_SLICED_VBI_CAPTURE);
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_SDR_CAPTURE
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_SDR_CAPTURE);
 	ioctl(-1, VIDIOC_TRY_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_TRY_FMT", V4L2_BUF_TYPE_SDR_CAPTURE);
+	print_ioctl_v4l2(p_format, VIDIOC_TRY_FMT, V4L2_BUF_TYPE_SDR_CAPTURE);
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_SDR_OUTPUT
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_SDR_OUTPUT);
 	ioctl(-1, VIDIOC_TRY_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_TRY_FMT", V4L2_BUF_TYPE_SDR_OUTPUT);
+	print_ioctl_v4l2(p_format, VIDIOC_TRY_FMT, V4L2_BUF_TYPE_SDR_OUTPUT);
 #endif
 	struct v4l2_format *const p_v4l2_format =
 		page_end - sizeof(*p_v4l2_format);
 	ioctl(-1, VIDIOC_TRY_FMT, p_v4l2_format);
-	printf("ioctl(-1, VIDIOC_TRY_FMT, {type=%#x /* V4L2_BUF_TYPE_??? */})"
-	       " = -1 EBADF (%m)\n", p_v4l2_format->type);
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */") "})"
+	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_TRY_FMT), p_v4l2_format->type);
 
 	/* VIDIOC_REQBUFS */
 	ioctl(-1, VIDIOC_REQBUFS, 0);
-	printf("ioctl(-1, VIDIOC_REQBUFS, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_REQBUFS));
 
 	struct v4l2_requestbuffers *const p_v4l2_requestbuffers =
 		page_end - sizeof(*p_v4l2_requestbuffers);
 	ioctl(-1, VIDIOC_REQBUFS, p_v4l2_requestbuffers);
-	printf("ioctl(-1, VIDIOC_REQBUFS, {type=%#x /* V4L2_BUF_TYPE_??? */, "
-	       "memory=%#x /* V4L2_MEMORY_??? */, count=%u})"
+	printf("ioctl(-1, %s, {type=%#x"
+	       NRAW(" /* V4L2_BUF_TYPE_??? */")
+	       ", memory=%#x" NRAW(" /* V4L2_MEMORY_??? */") ", count=%u})"
 	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_REQBUFS),
 	       p_v4l2_requestbuffers->type,
 	       p_v4l2_requestbuffers->memory,
 	       p_v4l2_requestbuffers->count);
 
 	/* VIDIOC_QUERYBUF */
 	ioctl(-1, VIDIOC_QUERYBUF, 0);
-	printf("ioctl(-1, VIDIOC_QUERYBUF, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QUERYBUF));
 
-	struct v4l2_buffer *const p_v4l2_buffer =
+	kernel_v4l2_buffer_t *const p_v4l2_buffer =
 		page_end - sizeof(*p_v4l2_buffer);
 	ioctl(-1, VIDIOC_QUERYBUF, p_v4l2_buffer);
-	printf("ioctl(-1, VIDIOC_QUERYBUF, {type=%#x /* V4L2_BUF_TYPE_??? */"
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */")
 	       ", index=%u}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QUERYBUF),
 	       p_v4l2_buffer->type, p_v4l2_buffer->index);
 
 	/* VIDIOC_QBUF */
 	ioctl(-1, VIDIOC_QBUF, 0);
-	printf("ioctl(-1, VIDIOC_QBUF, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QBUF));
 
 	ioctl(-1, VIDIOC_QBUF, p_v4l2_buffer);
-	printf("ioctl(-1, VIDIOC_QBUF, {type=%#x /* V4L2_BUF_TYPE_??? */"
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */")
 	       ", index=%u}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QBUF),
 	       p_v4l2_buffer->type, p_v4l2_buffer->index);
 
 	/* VIDIOC_DQBUF */
 	ioctl(-1, VIDIOC_DQBUF, 0);
-	printf("ioctl(-1, VIDIOC_DQBUF, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_DQBUF));
 
 	ioctl(-1, VIDIOC_DQBUF, p_v4l2_buffer);
-	printf("ioctl(-1, VIDIOC_DQBUF, {type=%#x"
-	       " /* V4L2_BUF_TYPE_??? */}) = -1 EBADF (%m)\n",
-	       p_v4l2_buffer->type);
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */")
+	       "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_DQBUF), p_v4l2_buffer->type);
 
 	/* VIDIOC_G_FBUF */
 	ioctl(-1, VIDIOC_G_FBUF, 0);
-	printf("ioctl(-1, VIDIOC_G_FBUF, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FBUF));
 
 	ioctl(-1, VIDIOC_G_FBUF, page);
-	printf("ioctl(-1, VIDIOC_G_FBUF, %p) = -1 EBADF (%m)\n", page);
+	printf("ioctl(-1, %s, %p) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FBUF), page);
 
 	/* VIDIOC_S_FBUF */
 	ioctl(-1, VIDIOC_S_FBUF, 0);
-	printf("ioctl(-1, VIDIOC_S_FBUF, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_FBUF));
 
 	struct v4l2_framebuffer *const p_v4l2_framebuffer =
 		page_end - sizeof(*p_v4l2_framebuffer);
 	ioctl(-1, VIDIOC_S_FBUF, p_v4l2_framebuffer);
-	printf("ioctl(-1, VIDIOC_S_FBUF, {capability=%#x"
+	printf("ioctl(-1, %s, {capability=%#x"
 	       ", flags=%#x, base=%p}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_FBUF),
 	       p_v4l2_framebuffer->capability,
 	       p_v4l2_framebuffer->flags,
 	       p_v4l2_framebuffer->base);
 
 	/* VIDIOC_STREAMON */
 	ioctl(-1, VIDIOC_STREAMON, 0);
-	printf("ioctl(-1, VIDIOC_STREAMON, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_STREAMON));
 
 	int *const p_int = page_end - sizeof(int);
 	ioctl(-1, VIDIOC_STREAMON, p_int);
-	printf("ioctl(-1, VIDIOC_STREAMON, [%#x /* V4L2_BUF_TYPE_??? */])"
-	       " = -1 EBADF (%m)\n", *p_int);
+	printf("ioctl(-1, %s, [%#x" NRAW(" /* V4L2_BUF_TYPE_??? */") "])"
+	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_STREAMON), *p_int);
 
 	/* VIDIOC_STREAMOFF */
 	ioctl(-1, VIDIOC_STREAMOFF, 0);
-	printf("ioctl(-1, VIDIOC_STREAMOFF, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_STREAMOFF));
 
 	ioctl(-1, VIDIOC_STREAMOFF, p_int);
-	printf("ioctl(-1, VIDIOC_STREAMOFF, [%#x /* V4L2_BUF_TYPE_??? */])"
-	       " = -1 EBADF (%m)\n", *p_int);
+	printf("ioctl(-1, %s, [%#x" NRAW(" /* V4L2_BUF_TYPE_??? */") "])"
+	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_STREAMOFF), *p_int);
 
 	/* VIDIOC_G_PARM */
 	ioctl(-1, VIDIOC_G_PARM, 0);
-	printf("ioctl(-1, VIDIOC_G_PARM, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_PARM));
 
 	struct v4l2_streamparm *const p_v4l2_streamparm =
 		page_end - sizeof(*p_v4l2_streamparm);
 	ioctl(-1, VIDIOC_G_PARM, p_v4l2_streamparm);
-	printf("ioctl(-1, VIDIOC_G_PARM, {type=%#x /* V4L2_BUF_TYPE_??? */})"
-	       " = -1 EBADF (%m)\n", p_v4l2_streamparm->type);
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */") "})"
+	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_PARM), p_v4l2_streamparm->type);
 
 	/* VIDIOC_S_PARM */
 	ioctl(-1, VIDIOC_S_PARM, 0);
-	printf("ioctl(-1, VIDIOC_S_PARM, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_PARM));
 
 	ioctl(-1, VIDIOC_S_PARM, p_v4l2_streamparm);
-	printf("ioctl(-1, VIDIOC_S_PARM, {type=%#x /* V4L2_BUF_TYPE_??? */})"
-	       " = -1 EBADF (%m)\n", p_v4l2_streamparm->type);
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */") "})"
+	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_PARM), p_v4l2_streamparm->type);
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct v4l2_streamparm, p_streamparm);
 	p_streamparm->type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
@@ -633,62 +1005,72 @@ main(void)
 	p_streamparm->parm.capture.timeperframe.numerator = 0xdeadbeef;
 	p_streamparm->parm.capture.timeperframe.denominator = 0xbadc0ded;
 	ioctl(-1, VIDIOC_S_PARM, p_streamparm);
-	printf("ioctl(-1, VIDIOC_S_PARM, {type=V4L2_BUF_TYPE_VIDEO_CAPTURE"
-	       ", parm.capture={capability=V4L2_CAP_TIMEPERFRAME"
-	       ", capturemode=V4L2_MODE_HIGHQUALITY, timeperframe=%u/%u"
-	       ", extendedmode=%u, readbuffers=%u}}) = -1 EBADF (%m)\n",
+	printf("ioctl(-1, %s, {type=" XLAT_FMT
+	       ", parm.capture={capability=" XLAT_FMT
+	       ", capturemode=" XLAT_FMT ", timeperframe=%u/%u"
+	       ", extendedmode=%#x, readbuffers=%u}}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_PARM), XLAT_ARGS(V4L2_BUF_TYPE_VIDEO_CAPTURE),
+	       XLAT_ARGS(V4L2_CAP_TIMEPERFRAME), XLAT_ARGS(V4L2_MODE_HIGHQUALITY),
 	       p_streamparm->parm.capture.timeperframe.numerator,
 	       p_streamparm->parm.capture.timeperframe.denominator, -1U, -1U);
 
 	p_streamparm->type = V4L2_BUF_TYPE_VIDEO_OUTPUT;
 	p_streamparm->parm.output.outputmode = 0;
 	ioctl(-1, VIDIOC_S_PARM, p_streamparm);
-	printf("ioctl(-1, VIDIOC_S_PARM, {type=V4L2_BUF_TYPE_VIDEO_OUTPUT"
-	       ", parm.output={capability=V4L2_CAP_TIMEPERFRAME"
+	printf("ioctl(-1, %s, {type=" XLAT_FMT
+	       ", parm.output={capability=" XLAT_FMT
 	       ", outputmode=0, timeperframe=%u/%u"
-	       ", extendedmode=%u, writebuffers=%u}}) = -1 EBADF (%m)\n",
+	       ", extendedmode=%#x, writebuffers=%u}}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_PARM), XLAT_ARGS(V4L2_BUF_TYPE_VIDEO_OUTPUT),
+	       XLAT_ARGS(V4L2_CAP_TIMEPERFRAME),
 	       p_streamparm->parm.output.timeperframe.numerator,
 	       p_streamparm->parm.output.timeperframe.denominator, -1U, -1U);
 
 	/* VIDIOC_G_STD */
 	ioctl(-1, VIDIOC_G_STD, 0);
-	printf("ioctl(-1, VIDIOC_G_STD, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_STD));
 
 	ioctl(-1, VIDIOC_G_STD, page);
-	printf("ioctl(-1, VIDIOC_G_STD, %p) = -1 EBADF (%m)\n", page);
+	printf("ioctl(-1, %s, %p) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_STD), page);
 
 	/* VIDIOC_S_STD */
 	ioctl(-1, VIDIOC_S_STD, 0);
-	printf("ioctl(-1, VIDIOC_S_STD, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_STD));
 
 	long long *const p_longlong = page_end - sizeof(*p_longlong);
 	ioctl(-1, VIDIOC_S_STD, p_longlong);
-	printf("ioctl(-1, VIDIOC_S_STD, [%#llx]) = -1 EBADF (%m)\n",
-	       *p_longlong);
+	printf("ioctl(-1, %s, [%#llx]) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_STD), *p_longlong);
 
 	/* VIDIOC_ENUMSTD */
 	ioctl(-1, VIDIOC_ENUMSTD, 0);
-	printf("ioctl(-1, VIDIOC_ENUMSTD, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUMSTD));
 
 	struct v4l2_standard *const p_v4l2_standard =
 		page_end - sizeof(*p_v4l2_standard);
 	ioctl(-1, VIDIOC_ENUMSTD, p_v4l2_standard);
-	printf("ioctl(-1, VIDIOC_ENUMSTD, {index=%u}) = -1 EBADF (%m)\n",
-	       p_v4l2_standard->index);
+	printf("ioctl(-1, %s, {index=%u}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUMSTD), p_v4l2_standard->index);
 
 	/* VIDIOC_ENUMINPUT */
 	ioctl(-1, VIDIOC_ENUMINPUT, 0);
-	printf("ioctl(-1, VIDIOC_ENUMINPUT, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUMINPUT));
 
 	struct v4l2_input *const p_v4l2_input =
 		page_end - sizeof(*p_v4l2_input);
 	ioctl(-1, VIDIOC_ENUMINPUT, p_v4l2_input);
-	printf("ioctl(-1, VIDIOC_ENUMINPUT, {index=%u}) = -1 EBADF (%m)\n",
-	       p_v4l2_input->index);
+	printf("ioctl(-1, %s, {index=%u}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUMINPUT), p_v4l2_input->index);
 
 	/* VIDIOC_G_CTRL */
 	ioctl(-1, VIDIOC_G_CTRL, 0);
-	printf("ioctl(-1, VIDIOC_G_CTRL, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_CTRL));
 
 	static const struct v4l2_control v4l2_control_vals[] = {
 		{ .id = 0,                    .value = 3141592653U },
@@ -699,55 +1081,59 @@ main(void)
 		{ .id = 0xa40000,             .value = -1 },
 	};
 	static const char *id_strs[] = {
-		"0 /* V4L2_CID_??? */",
-		"0x97abcd /* V4L2_CID_??? */",
-		"V4L2_CTRL_CLASS_USER+0",
-		"V4L2_CID_MPEG_VIDEO_H264_CPB_SIZE",
-		"V4L2_CTRL_CLASS_DETECT+0x1234",
-		"0xa40000 /* V4L2_CID_??? */",
+		"0" NRAW(" /* V4L2_CID_??? */"),
+		"0x97abcd" NRAW(" /* V4L2_CID_??? */"),
+		XLAT_KNOWN(0x980000, "V4L2_CTRL_CLASS_USER+0"),
+		XLAT_KNOWN(0x990a64, "V4L2_CID_MPEG_VIDEO_H264_CPB_SIZE"),
+		XLAT_KNOWN(0xa31234, "V4L2_CTRL_CLASS_DETECT+0x1234"),
+		"0xa40000" NRAW(" /* V4L2_CID_??? */"),
 	};
 
 	struct v4l2_control *const p_v4l2_control =
 		page_end - sizeof(*p_v4l2_control);
 	ioctl(-1, VIDIOC_G_CTRL, p_v4l2_control);
-	printf("ioctl(-1, VIDIOC_G_CTRL, {id=%#x /* V4L2_CID_??? */})"
-	       " = -1 EBADF (%m)\n", p_v4l2_control->id);
+	printf("ioctl(-1, %s, {id=%#x" NRAW(" /* V4L2_CID_??? */")
+	       "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_CTRL), p_v4l2_control->id);
 
 	/* VIDIOC_S_CTRL */
 	ioctl(-1, VIDIOC_S_CTRL, 0);
-	printf("ioctl(-1, VIDIOC_S_CTRL, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_CTRL));
 
 	ioctl(-1, VIDIOC_S_CTRL, p_v4l2_control);
-	printf("ioctl(-1, VIDIOC_S_CTRL, {id=%#x /* V4L2_CID_??? */"
+	printf("ioctl(-1, %s, {id=%#x" NRAW(" /* V4L2_CID_??? */")
 	       ", value=%d}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_CTRL),
 	       p_v4l2_control->id, p_v4l2_control->value);
 
 	for (size_t i = 0; i < ARRAY_SIZE(id_strs); i++) {
 		struct v4l2_control v4l2_c = v4l2_control_vals[i];
 
 		ioctl(-1, VIDIOC_G_CTRL, &v4l2_c);
-		printf("ioctl(-1, VIDIOC_G_CTRL, {id=%s}) = -1 EBADF (%m)\n",
-		       id_strs[i]);
+		printf("ioctl(-1, %s, {id=%s}) = -1 EBADF (%m)\n",
+		       XLAT_STR(VIDIOC_G_CTRL), id_strs[i]);
 
 		ioctl(-1, VIDIOC_S_CTRL, &v4l2_c);
-		printf("ioctl(-1, VIDIOC_S_CTRL, {id=%s, value=%d})"
-		       " = -1 EBADF (%m)\n",
-		       id_strs[i], v4l2_c.value);
+		printf("ioctl(-1, %s, {id=%s, value=%d}) = -1 EBADF (%m)\n",
+		       XLAT_STR(VIDIOC_S_CTRL), id_strs[i], v4l2_c.value);
 	}
 
 	/* VIDIOC_G_TUNER */
 	ioctl(-1, VIDIOC_G_TUNER, 0);
-	printf("ioctl(-1, VIDIOC_G_TUNER, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_TUNER));
 
 	struct v4l2_tuner *const p_v4l2_tuner =
 		page_end - sizeof(*p_v4l2_tuner);
 	ioctl(-1, VIDIOC_G_TUNER, p_v4l2_tuner);
-	printf("ioctl(-1, VIDIOC_G_TUNER, {index=%u})"
-	       " = -1 EBADF (%m)\n", p_v4l2_tuner->index);
+	printf("ioctl(-1, %s, {index=%u}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_TUNER), p_v4l2_tuner->index);
 
 	/* VIDIOC_S_TUNER */
 	ioctl(-1, VIDIOC_S_TUNER, 0);
-	printf("ioctl(-1, VIDIOC_S_TUNER, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_TUNER));
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct v4l2_tuner, p_tuner);
 	p_tuner->index = 0x4fb6df39;
@@ -761,79 +1147,98 @@ main(void)
 	p_tuner->signal = 0x10bf92c8;
 	p_tuner->afc = 0x3bf7e18b;
 	ioctl(-1, VIDIOC_S_TUNER, p_tuner);
-	printf("ioctl(-1, VIDIOC_S_TUNER, {index=%u"
-	       ", name=\"cum tacent clamant\""
-	       ", type=V4L2_TUNER_RADIO, capability=V4L2_TUNER_CAP_LOW"
+	printf("ioctl(-1, %s, {index=%u, name=\"cum tacent clamant\""
+	       ", type=" XLAT_FMT ", capability=" XLAT_FMT
 	       ", rangelow=%u, rangehigh=%u"
-	       ", rxsubchans=V4L2_TUNER_SUB_MONO"
-	       ", audmode=V4L2_TUNER_MODE_MONO, signal=%d, afc=%d"
-	       "}) = -1 EBADF (%m)\n",
-	       p_tuner->index, p_tuner->rangelow,
-	       p_tuner->rangehigh, p_tuner->signal, p_tuner->afc);
+	       ", rxsubchans=" XLAT_FMT ", audmode=" XLAT_FMT
+	       ", signal=%d, afc=%d}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_TUNER), p_tuner->index,
+	       XLAT_ARGS(V4L2_TUNER_RADIO), XLAT_ARGS(V4L2_TUNER_CAP_LOW),
+	       p_tuner->rangelow, p_tuner->rangehigh,
+	       XLAT_ARGS(V4L2_TUNER_SUB_MONO), XLAT_ARGS(V4L2_TUNER_MODE_MONO),
+	       p_tuner->signal, p_tuner->afc);
 
 	/* VIDIOC_QUERYCTRL */
 	ioctl(-1, VIDIOC_QUERYCTRL, 0);
-	printf("ioctl(-1, VIDIOC_QUERYCTRL, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QUERYCTRL));
 
 	struct v4l2_queryctrl *const p_v4l2_queryctrl =
 		page_end - sizeof(*p_v4l2_queryctrl);
 	ioctl(-1, VIDIOC_QUERYCTRL, p_v4l2_queryctrl);
-#ifdef V4L2_CTRL_FLAG_NEXT_CTRL
-	printf("ioctl(-1, VIDIOC_QUERYCTRL, {id=V4L2_CTRL_FLAG_NEXT_CTRL"
-	       "|%#x /* V4L2_CID_??? */}) = -1 EBADF (%m)\n",
-	       p_v4l2_queryctrl->id & ~V4L2_CTRL_FLAG_NEXT_CTRL);
+	printf("ioctl(-1, %s, {id="
+#if XLAT_RAW
+	      "%#x"
+#else
+	       XLAT_FMT "|%#x /* V4L2_CID_??? */"
+#endif
+	       "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QUERYCTRL),
+#if XLAT_RAW
+	       p_v4l2_queryctrl->id
 #else
-	printf("ioctl(-1, VIDIOC_QUERYCTRL, {id=%#x /* V4L2_CID_??? */})"
-	       " = -1 EBADF (%m)\n", p_v4l2_queryctrl->id);
+	       XLAT_ARGS(V4L2_CTRL_FLAG_NEXT_CTRL),
+	       p_v4l2_queryctrl->id & ~V4L2_CTRL_FLAG_NEXT_CTRL
 #endif
+	       );
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct v4l2_queryctrl, p_queryctrl);
 	p_queryctrl->id = V4L2_CID_SATURATION;
 	ioctl(-1, VIDIOC_QUERYCTRL, p_queryctrl);
-	printf("ioctl(-1, VIDIOC_QUERYCTRL, {id=V4L2_CID_SATURATION})"
-	       " = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {id=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QUERYCTRL), XLAT_ARGS(V4L2_CID_SATURATION));
 
 	/* VIDIOC_G_INPUT */
 	ioctl(-1, VIDIOC_G_INPUT, 0);
-	printf("ioctl(-1, VIDIOC_G_INPUT, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_INPUT));
 
 	ioctl(-1, VIDIOC_G_INPUT, page);
-	printf("ioctl(-1, VIDIOC_G_INPUT, %p) = -1 EBADF (%m)\n", page);
+	printf("ioctl(-1, %s, %p) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_INPUT), page);
 
 	/* VIDIOC_S_INPUT */
 	ioctl(-1, VIDIOC_S_INPUT, 0);
-	printf("ioctl(-1, VIDIOC_S_INPUT, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_INPUT));
 
 	ioctl(-1, VIDIOC_S_INPUT, p_int);
-	printf("ioctl(-1, VIDIOC_S_INPUT, [%u]) = -1 EBADF (%m)\n", *p_int);
+	printf("ioctl(-1, %s, [%u]) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_INPUT), *p_int);
 
 	/* VIDIOC_CROPCAP */
 	ioctl(-1, VIDIOC_CROPCAP, 0);
-	printf("ioctl(-1, VIDIOC_CROPCAP, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_CROPCAP));
 
 	struct v4l2_cropcap *const p_v4l2_cropcap =
 		page_end - sizeof(*p_v4l2_cropcap);
 	ioctl(-1, VIDIOC_CROPCAP, p_v4l2_cropcap);
-	printf("ioctl(-1, VIDIOC_CROPCAP, {type=%#x /* V4L2_BUF_TYPE_??? */})"
-	       " = -1 EBADF (%m)\n", p_v4l2_cropcap->type);
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */") "})"
+	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_CROPCAP), p_v4l2_cropcap->type);
 
 	/* VIDIOC_G_CROP */
 	ioctl(-1, VIDIOC_G_CROP, 0);
-	printf("ioctl(-1, VIDIOC_G_CROP, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_CROP));
 
 	struct v4l2_crop *const p_v4l2_crop =
 		page_end - sizeof(*p_v4l2_crop);
 	ioctl(-1, VIDIOC_G_CROP, p_v4l2_crop);
-	printf("ioctl(-1, VIDIOC_G_CROP, {type=%#x /* V4L2_BUF_TYPE_??? */})"
-	       " = -1 EBADF (%m)\n", p_v4l2_crop->type);
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */") "})"
+	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_CROP), p_v4l2_crop->type);
 
 	/* VIDIOC_S_CROP */
 	ioctl(-1, VIDIOC_S_CROP, 0);
-	printf("ioctl(-1, VIDIOC_S_CROP, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_CROP));
 
 	ioctl(-1, VIDIOC_S_CROP, p_v4l2_crop);
-	printf("ioctl(-1, VIDIOC_S_CROP, {type=%#x /* V4L2_BUF_TYPE_??? */"
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */")
 	       ", c={left=%d, top=%d, width=%u, height=%u}}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_CROP),
 	       p_v4l2_crop->type,
 	       p_v4l2_crop->c.left,
 	       p_v4l2_crop->c.top,
@@ -843,36 +1248,42 @@ main(void)
 #ifdef VIDIOC_S_EXT_CTRLS
 	/* VIDIOC_S_EXT_CTRLS */
 	ioctl(-1, VIDIOC_S_EXT_CTRLS, 0);
-	printf("ioctl(-1, VIDIOC_S_EXT_CTRLS, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_EXT_CTRLS));
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct v4l2_ext_controls, p_ext_controls);
 	p_ext_controls->ctrl_class = V4L2_CTRL_CLASS_USER;
 	p_ext_controls->count = 0;
 	p_ext_controls->controls = (void *) -2UL;
 	ioctl(-1, VIDIOC_S_EXT_CTRLS, p_ext_controls);
-	printf("ioctl(-1, VIDIOC_S_EXT_CTRLS, {ctrl_class=V4L2_CTRL_CLASS_USER"
-	       ", count=%u}) = -1 EBADF (%m)\n", p_ext_controls->count);
+	printf("ioctl(-1, %s, {ctrl_class=" XLAT_FMT ", count=%u})"
+	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_EXT_CTRLS), XLAT_ARGS(V4L2_CTRL_CLASS_USER),
+	       p_ext_controls->count);
 
 	p_ext_controls->ctrl_class = 0x00a30000;
 	p_ext_controls->count = magic;
 	ioctl(-1, VIDIOC_S_EXT_CTRLS, p_ext_controls);
-	printf("ioctl(-1, VIDIOC_S_EXT_CTRLS, {ctrl_class=V4L2_CTRL_CLASS_DETECT"
+	printf("ioctl(-1, %s, {ctrl_class=" XLAT_FMT
 	       ", count=%u, controls=%p}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_EXT_CTRLS), XLAT_ARGS(V4L2_CTRL_CLASS_DETECT),
 	       p_ext_controls->count, p_ext_controls->controls);
 
 	p_ext_controls->ctrl_class = 0x00a40000;
 	p_ext_controls->count = magic;
 	ioctl(-1, VIDIOC_S_EXT_CTRLS, p_ext_controls);
-	printf("ioctl(-1, VIDIOC_S_EXT_CTRLS"
-	       ", {ctrl_class=0xa40000 /* V4L2_CTRL_CLASS_??? */"
+	printf("ioctl(-1, %s"
+	       ", {ctrl_class=0xa40000" NRAW(" /* V4L2_CTRL_CLASS_??? */")
 	       ", count=%u, controls=%p}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_EXT_CTRLS),
 	       p_ext_controls->count, p_ext_controls->controls);
 
 	p_ext_controls->ctrl_class = V4L2_CTRL_CLASS_MPEG;
 	p_ext_controls->count = magic;
 	ioctl(-1, VIDIOC_S_EXT_CTRLS, p_ext_controls);
-	printf("ioctl(-1, VIDIOC_S_EXT_CTRLS, {ctrl_class=V4L2_CTRL_CLASS_MPEG"
+	printf("ioctl(-1, %s, {ctrl_class=" XLAT_FMT
 	       ", count=%u, controls=%p}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_EXT_CTRLS), XLAT_ARGS(V4L2_CTRL_CLASS_MPEG),
 	       p_ext_controls->count, p_ext_controls->controls);
 
 # if HAVE_DECL_V4L2_CTRL_TYPE_STRING
@@ -888,107 +1299,132 @@ main(void)
 		tail_alloc(p_ext_controls->controls[1].size);
 
 	ioctl(-1, VIDIOC_S_EXT_CTRLS, p_ext_controls);
-	printf("ioctl(-1, VIDIOC_S_EXT_CTRLS"
-	       ", {ctrl_class=V4L2_CTRL_CLASS_MPEG, count=%u, controls="
-	       "[{id=V4L2_CID_BRIGHTNESS, size=0, value=%d, value64=%lld}"
-	       ", {id=V4L2_CID_CONTRAST, size=2, string=\"\\377\\377\"}"
-	       "] => controls="
-	       "[{id=V4L2_CID_BRIGHTNESS, size=0, value=%d, value64=%lld}"
-	       ", {id=V4L2_CID_CONTRAST, size=2, string=\"\\377\\377\"}"
+	printf("ioctl(-1, %s, {ctrl_class=" XLAT_FMT ", count=%u, controls="
+	       "[{id=" XLAT_FMT ", size=0, value=%d, value64=%lld}"
+	       ", {id=" XLAT_FMT ", size=2, string=\"\\377\\377\"}"
+	       "]} => {controls="
+	       "[{id=" XLAT_FMT ", size=0, value=%d, value64=%lld}"
+	       ", {id=" XLAT_FMT ", size=2, string=\"\\377\\377\"}"
 	       "], error_idx=%u}) = -1 EBADF (%m)\n",
-	       p_ext_controls->count,
+	       XLAT_STR(VIDIOC_S_EXT_CTRLS), XLAT_ARGS(V4L2_CTRL_CLASS_MPEG),
+	       p_ext_controls->count, XLAT_ARGS(V4L2_CID_BRIGHTNESS),
 	       p_ext_controls->controls[0].value,
 	       (long long) p_ext_controls->controls[0].value64,
+	       XLAT_ARGS(V4L2_CID_CONTRAST), XLAT_ARGS(V4L2_CID_BRIGHTNESS),
 	       p_ext_controls->controls[0].value,
 	       (long long) p_ext_controls->controls[0].value64,
-	       p_ext_controls->error_idx);
+	       XLAT_ARGS(V4L2_CID_CONTRAST), p_ext_controls->error_idx);
 
 	++p_ext_controls->count;
 	ioctl(-1, VIDIOC_S_EXT_CTRLS, p_ext_controls);
-	printf("ioctl(-1, VIDIOC_S_EXT_CTRLS"
-	       ", {ctrl_class=V4L2_CTRL_CLASS_MPEG, count=%u, controls="
-	       "[{id=V4L2_CID_BRIGHTNESS, size=0, value=%d, value64=%lld}"
-	       ", {id=V4L2_CID_CONTRAST, size=2, string=\"\\377\\377\"}"
+	printf("ioctl(-1, %s, {ctrl_class=" XLAT_FMT ", count=%u, controls="
+	       "[{id=" XLAT_FMT ", size=0, value=%d, value64=%lld}"
+	       ", {id=" XLAT_FMT ", size=2, string=\"\\377\\377\"}"
 	       ", ... /* %p */]}) = -1 EBADF (%m)\n",
-	       p_ext_controls->count,
+	       XLAT_STR(VIDIOC_S_EXT_CTRLS), XLAT_ARGS(V4L2_CTRL_CLASS_MPEG),
+	       p_ext_controls->count, XLAT_ARGS(V4L2_CID_BRIGHTNESS),
 	       p_ext_controls->controls[0].value,
 	       (long long) p_ext_controls->controls[0].value64,
-	       p_ext_controls->controls + 2);
+	       XLAT_ARGS(V4L2_CID_CONTRAST), p_ext_controls->controls + 2);
 # endif /* HAVE_DECL_V4L2_CTRL_TYPE_STRING */
 
 	/* VIDIOC_TRY_EXT_CTRLS */
 	ioctl(-1, VIDIOC_TRY_EXT_CTRLS, 0);
-	printf("ioctl(-1, VIDIOC_TRY_EXT_CTRLS, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_TRY_EXT_CTRLS));
 
 	p_ext_controls->ctrl_class = V4L2_CTRL_CLASS_USER;
 	p_ext_controls->count = magic;
 	p_ext_controls->controls = (void *) -2UL;
 	ioctl(-1, VIDIOC_TRY_EXT_CTRLS, p_ext_controls);
-	printf("ioctl(-1, VIDIOC_TRY_EXT_CTRLS"
-	       ", {ctrl_class=V4L2_CTRL_CLASS_USER, count=%u, controls=%p})"
+	printf("ioctl(-1, %s, {ctrl_class=" XLAT_FMT ", count=%u, controls=%p})"
 	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_TRY_EXT_CTRLS), XLAT_ARGS(V4L2_CTRL_CLASS_USER),
 	       p_ext_controls->count, p_ext_controls->controls);
 
 	/* VIDIOC_G_EXT_CTRLS */
 	ioctl(-1, VIDIOC_G_EXT_CTRLS, 0);
-	printf("ioctl(-1, VIDIOC_G_EXT_CTRLS, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_EXT_CTRLS));
 
 	ioctl(-1, VIDIOC_G_EXT_CTRLS, p_ext_controls);
-	printf("ioctl(-1, VIDIOC_G_EXT_CTRLS"
-	       ", {ctrl_class=V4L2_CTRL_CLASS_USER, count=%u, controls=%p"
+	printf("ioctl(-1, %s, {ctrl_class=" XLAT_FMT ", count=%u, controls=%p"
 	       ", error_idx=%u}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_EXT_CTRLS), XLAT_ARGS(V4L2_CTRL_CLASS_USER),
 	       p_ext_controls->count, p_ext_controls->controls,
 	       p_ext_controls->error_idx);
 #endif /* VIDIOC_S_EXT_CTRLS */
 
-#ifdef VIDIOC_ENUM_FRAMESIZES
+#ifdef HAVE_STRUCT_V4L2_FRMSIZEENUM
 	ioctl(-1, VIDIOC_ENUM_FRAMESIZES, 0);
-	printf("ioctl(-1, VIDIOC_ENUM_FRAMESIZES, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMESIZES));
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct v4l2_frmsizeenum, p_frmsizeenum);
 	p_frmsizeenum->index = magic;
 	p_frmsizeenum->pixel_format = fourcc(cc[0], cc[1], cc[2], cc[3]);
 
 	ioctl(-1, VIDIOC_ENUM_FRAMESIZES, p_frmsizeenum);
-	printf("ioctl(-1, VIDIOC_ENUM_FRAMESIZES, {index=%u"
-	       ", pixel_format=v4l2_fourcc('%c', '\\%c', '\\%c', '\\x%x')})"
-	       " = -1 EBADF (%m)\n", p_frmsizeenum->index,
-	       cc[0], cc[1], cc[2], cc[3]);
-#endif /* VIDIOC_ENUM_FRAMESIZES */
+	printf("ioctl(-1, %s, {index=%u, pixel_format="
+# if XLAT_RAW
+	       "0x%hhx%hhx%hhx%hhx"
+# else /* !XLAT_RAW */
+	       "v4l2_fourcc('%c', '\\%c', '\\%c', '\\x%x')"
+# endif /* XLAT_RAW */
+	       "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMESIZES), p_frmsizeenum->index,
+# if XLAT_RAW
+	       cc[3], cc[2], cc[1], cc[0]
+# else /* !XLAT_RAW */
+	       cc[0], cc[1], cc[2], cc[3]
+# endif /* XLAT_RAW */
+	       );
+#endif /* HAVE_STRUCT_V4L2_FRMSIZEENUM */
 
-#ifdef VIDIOC_ENUM_FRAMEINTERVALS
+#ifdef HAVE_STRUCT_V4L2_FRMIVALENUM
 	ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, 0);
-	printf("ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMEINTERVALS));
 
 	struct v4l2_frmivalenum *const p_v4l2_frmivalenum =
 		page_end - sizeof(*p_v4l2_frmivalenum);
 	ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, p_v4l2_frmivalenum);
-	printf("ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, {index=%u"
-	       ", pixel_format=v4l2_fourcc('\\x%x', '\\x%x', '\\x%x', '\\x%x')"
+	printf("ioctl(-1, %s, {index=%u, pixel_format="
+# if XLAT_RAW
+	       "%#x"
+# else /* !XLAT_RAW */
+	       "v4l2_fourcc('\\x%x', '\\x%x', '\\x%x', '\\x%x')"
+# endif /* XLAT_RAW */
 	       ", width=%u, height=%u}) = -1 EBADF (%m)\n",
-	       p_v4l2_frmivalenum->index,
+	       XLAT_STR(VIDIOC_ENUM_FRAMEINTERVALS), p_v4l2_frmivalenum->index,
+# if XLAT_RAW
+	       p_v4l2_frmivalenum->pixel_format,
+# else /* !XLAT_RAW */
 	       cc0(p_v4l2_frmivalenum->pixel_format),
 	       cc1(p_v4l2_frmivalenum->pixel_format),
 	       cc2(p_v4l2_frmivalenum->pixel_format),
 	       cc3(p_v4l2_frmivalenum->pixel_format),
+# endif /* XLAT_RAW */
 	       p_v4l2_frmivalenum->width,
 	       p_v4l2_frmivalenum->height);
-#endif /* VIDIOC_ENUM_FRAMEINTERVALS */
+#endif /* HAVE_STRUCT_V4L2_FRMIVALENUM */
 
-#ifdef VIDIOC_CREATE_BUFS
+#ifdef HAVE_STRUCT_V4L2_CREATE_BUFFERS
 	ioctl(-1, VIDIOC_CREATE_BUFS, 0);
-	printf("ioctl(-1, VIDIOC_CREATE_BUFS, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_CREATE_BUFS));
 
 	struct v4l2_create_buffers *const p_v4l2_create_buffers =
 		page_end - sizeof(*p_v4l2_create_buffers);
 	ioctl(-1, VIDIOC_CREATE_BUFS, p_v4l2_create_buffers);
-	printf("ioctl(-1, VIDIOC_CREATE_BUFS, {count=%u, memory=%#x"
-	       " /* V4L2_MEMORY_??? */, format={type=%#x"
-	       " /* V4L2_BUF_TYPE_??? */}}) = -1 EBADF (%m)\n",
+	printf("ioctl(-1, %s, {count=%u, memory=%#x"
+	       NRAW(" /* V4L2_MEMORY_??? */") ", format={type=%#x"
+	       NRAW(" /* V4L2_BUF_TYPE_??? */") "}}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_CREATE_BUFS),
 	       p_v4l2_create_buffers->count,
 	       p_v4l2_create_buffers->memory,
 	       p_v4l2_create_buffers->format.type);
-#endif /* VIDIOC_CREATE_BUFS */
+#endif /* HAVE_STRUCT_V4L2_CREATE_BUFFERS */
 
 	puts("+++ exited with 0 +++");
 	return 0;
diff -pruN 5.5-3/tests/ioctl_v4l2-success.c 5.9-0ubuntu2/tests/ioctl_v4l2-success.c
--- 5.5-3/tests/ioctl_v4l2-success.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-success.c	2020-09-06 08:00:00.000000000 +0000
@@ -0,0 +1,1473 @@
+/*
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+
+#include <stdint.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <sys/ioctl.h>
+#include "kernel_v4l2_types.h"
+
+#define XLAT_MACROS_ONLY
+# include "xlat/v4l2_ioctl_cmds.h"
+#undef XLAT_MACROS_ONLY
+
+static bool
+fill_fmt(struct v4l2_format *f)
+{
+	static struct v4l2_clip *clips;
+
+	switch (f->type) {
+	case V4L2_BUF_TYPE_VIDEO_CAPTURE:
+	case V4L2_BUF_TYPE_VIDEO_OUTPUT:
+		f->fmt.pix.width        = 0xdeadc0de;
+		f->fmt.pix.height       = 0xfeedbeef;
+		f->fmt.pix.pixelformat  = 0xb5315258; /* forurcc_be("XR15") */
+		f->fmt.pix.field = f->type == V4L2_BUF_TYPE_VIDEO_CAPTURE
+			? V4L2_FIELD_ALTERNATE : 0xdec0ded1;
+		f->fmt.pix.bytesperline = 0xbadc0ded;
+		f->fmt.pix.sizeimage    = 0xface1e55;
+		f->fmt.pix.colorspace   = V4L2_COLORSPACE_REC709;
+		break;
+
+	case V4L2_BUF_TYPE_VIDEO_OVERLAY:
+#if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY
+	case V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY:
+#endif
+		f->fmt.win.w.left    = 0xa0a1a2a3;
+		f->fmt.win.w.top     = 0xb0b1b2b3;
+		f->fmt.win.w.width   = 0xc0c1c2c3;
+		f->fmt.win.w.height  = 0xd0d1d2d3;
+		f->fmt.win.field     = f->type == V4L2_BUF_TYPE_VIDEO_OVERLAY
+			? V4L2_FIELD_ANY : 10;
+		f->fmt.win.chromakey = 0xbeefface;
+
+		if (!clips)
+			clips = tail_alloc(sizeof(*clips) * 3);
+		f->fmt.win.clips = clips;
+
+		f->fmt.win.clips[0].c.left   = 0xa4a5a6a7;
+		f->fmt.win.clips[0].c.top    = 0xb4b5b6b7;
+		f->fmt.win.clips[0].c.width  = 0xc4c5c6c7;
+		f->fmt.win.clips[0].c.height = 0xd4d5d6d7;
+		f->fmt.win.clips[0].next     = clips;
+
+		f->fmt.win.clips[1].c.left   = 0xa8a9aaab;
+		f->fmt.win.clips[1].c.top    = 0xb8b9babb;
+		f->fmt.win.clips[1].c.width  = 0xc8c9cacb;
+		f->fmt.win.clips[1].c.height = 0xd8d9dadb;
+
+		f->fmt.win.clips[2].c.left   = 0xacadaeaf;
+		f->fmt.win.clips[2].c.top    = 0xbcbdbebf;
+		f->fmt.win.clips[2].c.width  = 0xcccdcecf;
+		f->fmt.win.clips[2].c.height = 0xdcdddedf;
+		f->fmt.win.clips[2].next     = clips + 1;
+
+		f->fmt.win.clipcount = f->type == V4L2_BUF_TYPE_VIDEO_OVERLAY
+			? 4 : 0;
+		f->fmt.win.bitmap    = f->type == V4L2_BUF_TYPE_VIDEO_OVERLAY
+			? NULL : clips;
+		break;
+
+	case V4L2_BUF_TYPE_VBI_CAPTURE:
+	case V4L2_BUF_TYPE_VBI_OUTPUT:
+		f->fmt.vbi.sampling_rate    = 0xdecaffed;
+		f->fmt.vbi.offset           = 0xcafefeed;
+		f->fmt.vbi.samples_per_line = 0xbeefaced;
+		f->fmt.vbi.sample_format    = V4L2_PIX_FMT_RGB555X;
+
+		f->fmt.vbi.start[0] = 0xdec0ded0;
+		f->fmt.vbi.start[1] = 0xdec0ded1;
+		f->fmt.vbi.count[0] = 0xacceded2;
+		f->fmt.vbi.count[1] = 0xacceded3;
+
+		f->fmt.vbi.flags = f->type == V4L2_BUF_TYPE_VBI_CAPTURE
+			? 0x3 : 0x1ce50d1c;
+		break;
+
+#if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE
+	case V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE:
+	case V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE:
+		f->fmt.pix_mp.width        = 0xdeaffade;
+		f->fmt.pix_mp.height       = 0xfadeb1a5;
+		f->fmt.pix_mp.pixelformat  = 0x36314454;
+		f->fmt.pix_mp.field        = V4L2_FIELD_NONE;
+		f->fmt.pix_mp.colorspace   = 13;
+
+		for (size_t i = 0; i < VIDEO_MAX_PLANES; i++) {
+			f->fmt.pix_mp.plane_fmt[i].sizeimage = 0xd0decad0 ^ i;
+			if (sizeof(f->fmt.pix_mp.plane_fmt[i].bytesperline) ==
+			    sizeof(uint32_t)) {
+				f->fmt.pix_mp.plane_fmt[i].bytesperline
+					= 0xd0decad1 ^ i;
+			} else {
+# if WORDS_BIGENDIAN
+				f->fmt.pix_mp.plane_fmt[i].bytesperline
+					= 0xd0de;
+				f->fmt.pix_mp.plane_fmt[i].reserved[0]
+					= 0xcad1 ^ i;
+# else
+				f->fmt.pix_mp.plane_fmt[i].bytesperline
+					= 0xcad1 ^ i;
+				f->fmt.pix_mp.plane_fmt[i].reserved[0]
+					= 0xd0de;
+# endif
+			}
+		}
+
+		f->fmt.pix_mp.num_planes   = f->type ==
+			V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE ? 0xd5 : 0;
+		break;
+#endif
+#if HAVE_DECL_V4L2_BUF_TYPE_SLICED_VBI_CAPTURE
+	case V4L2_BUF_TYPE_SLICED_VBI_CAPTURE:
+	case V4L2_BUF_TYPE_SLICED_VBI_OUTPUT:
+		f->fmt.sliced.service_set = 0xfeed;
+		for (size_t i = 0; i < 2; i++) {
+			for (size_t j = 0; j < 24; j++) {
+				f->fmt.sliced.service_lines[i][j] =
+					0xdead ^ (i << 8) ^ j;
+			}
+		}
+		f->fmt.sliced.io_size = 0xdefaceed;
+		break;
+#endif
+#if HAVE_DECL_V4L2_BUF_TYPE_SDR_CAPTURE
+	case V4L2_BUF_TYPE_SDR_CAPTURE:
+# if HAVE_DECL_V4L2_BUF_TYPE_SDR_OUTPUT
+	case V4L2_BUF_TYPE_SDR_OUTPUT:
+# endif
+		f->fmt.sdr.pixelformat = V4L2_SDR_FMT_CU8;
+# ifdef HAVE_STRUCT_V4L2_SDR_FORMAT_BUFFERSIZE
+		if (sizeof(f->fmt.sdr.buffersize == sizeof(uint32_t)))
+			f->fmt.sdr.buffersize = 0xbadc0ded;
+		else
+			((uint32_t *) &f->fmt.sdr)[1] = 0xbadc0ded;
+# else
+		((uint32_t *) &f->fmt.sdr)[1] = 0xbadc0ded;
+# endif
+		break;
+#endif
+	default:
+		return false;
+	}
+
+	return true;
+}
+
+static void
+print_fmt(const char *pfx, struct v4l2_format *f)
+{
+	switch (f->type) {
+	case V4L2_BUF_TYPE_VIDEO_CAPTURE:
+	case V4L2_BUF_TYPE_VIDEO_OUTPUT:
+		printf("%sfmt.pix={width=3735929054, height=4276993775"
+		       ", pixelformat=" RAW("0xb5315258")
+		       NRAW("v4l2_fourcc('X', 'R', '1', '\\xb5')"
+		            " /* V4L2_PIX_FMT_XRGB555X */")
+		       ", field=%s, bytesperline=3134983661"
+		       ", sizeimage=4207812181, colorspace="
+		       XLAT_KNOWN(0x3, "V4L2_COLORSPACE_REC709") "}",
+		       pfx, f->type == V4L2_BUF_TYPE_VIDEO_CAPTURE
+			? XLAT_STR(V4L2_FIELD_ALTERNATE)
+			: XLAT_UNKNOWN(0xdec0ded1, "V4L2_FIELD_???"));
+		break;
+
+	case V4L2_BUF_TYPE_VIDEO_OVERLAY:
+#if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY
+	case V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY:
+#endif
+		printf("%sfmt.win={left=-1600019805, top=-1330531661"
+		       ", width=3233923779, height=3503411923, field=%s"
+		       ", chromakey=0xbeefface, clips=[",
+		       pfx, f->type == V4L2_BUF_TYPE_VIDEO_OVERLAY
+			? XLAT_STR(V4L2_FIELD_ANY)
+			: XLAT_UNKNOWN(0xa, "V4L2_FIELD_???"));
+		if (f->type == V4L2_BUF_TYPE_VIDEO_OVERLAY) {
+			printf("{left=-1532647769, top=-1263159625"
+			       ", width=3301295815, height=3570783959}, "
+			       "{left=-1465275733, top=-1195787589"
+			       ", width=3368667851, height=3638155995}, "
+			       "{left=-1397903697, top=-1128415553"
+			       ", width=3436039887, height=3705528031}, "
+			       "... /* %p */", f->fmt.win.clips + 3);
+		}
+		printf("], clipcount=%d, bitmap=",
+		       f->type == V4L2_BUF_TYPE_VIDEO_OVERLAY ? 4 : 0);
+
+		if (f->type == V4L2_BUF_TYPE_VIDEO_OVERLAY)
+			printf("NULL");
+		else
+			printf("%p", f->fmt.win.bitmap);
+
+#ifdef HAVE_STRUCT_V4L2_WINDOW_GLOBAL_ALPHA
+		printf(", global_alpha=%#hhx}", f->fmt.win.global_alpha);
+#else
+		struct win_ga {
+			struct v4l2_rect w;
+			uint32_t field;
+			uint32_t chromakey;
+			struct v4l2_clip *clips;
+			uint32_t clipcount;
+			void *bitmap;
+			uint8_t global_alpha;
+		};
+		printf(", global_alpha=%#hhx}",
+		       ((struct win_ga *) &f->fmt.win)->global_alpha);
+#endif
+		break;
+
+	case V4L2_BUF_TYPE_VBI_CAPTURE:
+	case V4L2_BUF_TYPE_VBI_OUTPUT:
+		printf("%sfmt.vbi={sampling_rate=3737845741, offset=3405709037"
+		       ", samples_per_line=3203378413, sample_format="
+		       RAW("0x51424752") NRAW("v4l2_fourcc('R', 'G', 'B', 'Q')"
+		       " /* V4L2_PIX_FMT_RGB555X */")
+		       ", start=[-557785392, -557785391]"
+		       ", count=[2899238610, 2899238611], flags=%s}",
+		       pfx, f->type == V4L2_BUF_TYPE_VBI_CAPTURE
+			? XLAT_KNOWN(0x3, "V4L2_VBI_UNSYNC|V4L2_VBI_INTERLACED")
+			: XLAT_UNKNOWN(0x1ce50d1c, "V4L2_VBI_???"));
+		break;
+
+#if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE
+	case V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE:
+	case V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE:
+		printf("%sfmt.pix_mp={width=3736074974, height=4208898469"
+		       ", pixelformat=" RAW("0x36314454")
+		       NRAW("v4l2_fourcc('T', 'D', '1', '6')")
+		       ", field=%s, colorspace=0xd"
+		       NRAW(" /* V4L2_COLORSPACE_??? */") ", plane_fmt=[",
+		       pfx, XLAT_STR(V4L2_FIELD_NONE));
+		if (f->type == V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE) {
+			printf("{sizeimage=3504261840, bytesperline=3504261841}"
+			", "
+			       "{sizeimage=3504261841, bytesperline=3504261840}"
+			       ", "
+			       "{sizeimage=3504261842, bytesperline=3504261843}"
+			       ", "
+			       "{sizeimage=3504261843, bytesperline=3504261842}"
+			       ", "
+			       "{sizeimage=3504261844, bytesperline=3504261845}"
+			       ", "
+			       "{sizeimage=3504261845, bytesperline=3504261844}"
+			       ", "
+			       "{sizeimage=3504261846, bytesperline=3504261847}"
+			       ", "
+			       "{sizeimage=3504261847, bytesperline=3504261846}"
+			       "], num_planes=213}");
+		} else {
+			printf("], num_planes=0}");
+		}
+		break;
+#endif
+#if HAVE_DECL_V4L2_BUF_TYPE_SLICED_VBI_CAPTURE
+	case V4L2_BUF_TYPE_SLICED_VBI_CAPTURE:
+	case V4L2_BUF_TYPE_SLICED_VBI_OUTPUT:
+		printf("%sfmt.sliced={service_set="
+		       XLAT_UNKNOWN(0xfeed, "V4L2_SLICED_???")
+		       ", io_size=3740978925, service_lines=[[0xdead, 0xdeac"
+		       ", 0xdeaf, 0xdeae, 0xdea9, 0xdea8, 0xdeab, 0xdeaa"
+		       ", 0xdea5, 0xdea4, 0xdea7, 0xdea6, 0xdea1, 0xdea0"
+		       ", 0xdea3, 0xdea2, 0xdebd, 0xdebc, 0xdebf, 0xdebe"
+		       ", 0xdeb9, 0xdeb8, 0xdebb, 0xdeba], [0xdfad, 0xdfac"
+		       ", 0xdfaf, 0xdfae, 0xdfa9, 0xdfa8, 0xdfab, 0xdfaa"
+		       ", 0xdfa5, 0xdfa4, 0xdfa7, 0xdfa6, 0xdfa1, 0xdfa0"
+		       ", 0xdfa3, 0xdfa2, 0xdfbd, 0xdfbc, 0xdfbf, 0xdfbe"
+		       ", 0xdfb9, 0xdfb8, 0xdfbb, 0xdfba]]}",
+		       pfx);
+		break;
+#endif
+#if HAVE_DECL_V4L2_BUF_TYPE_SDR_CAPTURE
+	case V4L2_BUF_TYPE_SDR_CAPTURE:
+# if HAVE_DECL_V4L2_BUF_TYPE_SDR_OUTPUT
+	case V4L2_BUF_TYPE_SDR_OUTPUT:
+# endif
+		printf("%sfmt.sdr={pixelformat=" RAW("0x38305543")
+		       NRAW("v4l2_fourcc('C', 'U', '0', '8')"
+			    " /* V4L2_SDR_FMT_CU8 */")
+		       ", buffersize=3134983661}",
+		       pfx);
+		break;
+#endif
+	}
+}
+
+int
+main(int argc, char **argv)
+{
+	unsigned long num_skip;
+	long inject_retval;
+	bool locked = false;
+
+	if (argc == 1)
+		return 0;
+
+	if (argc < 3)
+		error_msg_and_fail("Usage: %s NUM_SKIP INJECT_RETVAL", argv[0]);
+
+	num_skip = strtoul(argv[1], NULL, 0);
+	inject_retval = strtol(argv[2], NULL, 0);
+
+	if (inject_retval < 0)
+		error_msg_and_fail("Expected non-negative INJECT_RETVAL, "
+				   "but got %ld", inject_retval);
+
+	for (unsigned int i = 0; i < num_skip; i++) {
+		long rc = ioctl(-1, VIDIOC_QUERYCAP, NULL);
+		printf("ioctl(-1, %s, NULL) = %s%s\n",
+		       XLAT_STR(VIDIOC_QUERYCAP), sprintrc(rc),
+		       rc == inject_retval ? " (INJECTED)" : "");
+
+		if (rc != inject_retval)
+			continue;
+
+		locked = true;
+		break;
+	}
+
+	if (!locked)
+		error_msg_and_fail("Hasn't locked on ioctl(-1"
+				   ", VIDIOC_QUERYCAP, NULL) returning %lu",
+				   inject_retval);
+
+
+	/* VIDIOC_QUERYCAP */
+	struct v4l2_capability *caps = tail_alloc(sizeof(*caps));
+
+	fill_memory(caps, sizeof(*caps));
+	caps->capabilities = 0xdeadbeef;
+#ifdef HAVE_STRUCT_V4L2_CAPABILITY_DEVICE_CAPS
+	caps->device_caps = 0xfacefeed;
+#else
+	caps->reserved[0] = 0xfacefeed;
+#endif
+
+	ioctl(-1, VIDIOC_QUERYCAP, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_QUERYCAP), inject_retval);
+
+	ioctl(-1, VIDIOC_QUERYCAP, (char *) caps + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_QUERYCAP), (char *) caps + 1, inject_retval);
+
+	ioctl(-1, VIDIOC_QUERYCAP, caps);
+	printf("ioctl(-1, %s, {driver=", XLAT_STR(VIDIOC_QUERYCAP));
+	print_quoted_cstring((char *) caps->driver, sizeof(caps->driver));
+	printf(", card=");
+	print_quoted_cstring((char *) caps->card, sizeof(caps->card));
+	printf(", bus_info=");
+	print_quoted_cstring((char *) caps->bus_info, sizeof(caps->bus_info));
+	printf(", version="
+#ifdef WORDS_BIGENDIAN
+	       XLAT_KNOWN(0xd0d1d2d3, "KERNEL_VERSION(53457, 210, 211)")
+#else
+	       XLAT_KNOWN(0xd3d2d1d0, "KERNEL_VERSION(54226, 209, 208)")
+#endif
+	       ", capabilities=" XLAT_KNOWN(0xdeadbeef,
+	       "V4L2_CAP_VIDEO_CAPTURE|V4L2_CAP_VIDEO_OUTPUT"
+	       "|V4L2_CAP_VIDEO_OVERLAY|V4L2_CAP_VBI_OUTPUT"
+	       "|V4L2_CAP_SLICED_VBI_CAPTURE|V4L2_CAP_SLICED_VBI_OUTPUT"
+	       "|V4L2_CAP_VIDEO_OUTPUT_OVERLAY|V4L2_CAP_HW_FREQ_SEEK"
+	       "|V4L2_CAP_RDS_OUTPUT|V4L2_CAP_VIDEO_CAPTURE_MPLANE"
+	       "|V4L2_CAP_VIDEO_OUTPUT_MPLANE|V4L2_CAP_VIDEO_M2M"
+	       "|V4L2_CAP_TUNER|V4L2_CAP_RADIO|V4L2_CAP_MODULATOR"
+	       "|V4L2_CAP_EXT_PIX_FORMAT|V4L2_CAP_META_CAPTURE|V4L2_CAP_ASYNCIO"
+	       "|V4L2_CAP_STREAMING|V4L2_CAP_META_OUTPUT|V4L2_CAP_TOUCH"
+	       "|V4L2_CAP_DEVICE_CAPS|0x40000008"));
+	printf(", device_caps=" XLAT_KNOWN(0xfacefeed,
+	       "V4L2_CAP_VIDEO_CAPTURE|V4L2_CAP_VIDEO_OVERLAY"
+	       "|V4L2_CAP_VBI_OUTPUT|V4L2_CAP_SLICED_VBI_CAPTURE"
+	       "|V4L2_CAP_SLICED_VBI_OUTPUT|V4L2_CAP_VIDEO_OUTPUT_OVERLAY"
+	       "|V4L2_CAP_HW_FREQ_SEEK|V4L2_CAP_RDS_OUTPUT"
+	       "|V4L2_CAP_VIDEO_CAPTURE_MPLANE|V4L2_CAP_VIDEO_OUTPUT_MPLANE"
+	       "|V4L2_CAP_VIDEO_M2M_MPLANE|V4L2_CAP_VIDEO_M2M|V4L2_CAP_AUDIO"
+	       "|V4L2_CAP_RADIO|V4L2_CAP_MODULATOR|V4L2_CAP_SDR_OUTPUT"
+	       "|V4L2_CAP_META_CAPTURE|V4L2_CAP_ASYNCIO|V4L2_CAP_META_OUTPUT"
+	       "|V4L2_CAP_TOUCH|V4L2_CAP_DEVICE_CAPS|0x60000008"));
+	printf("}) = %ld (INJECTED)\n", inject_retval);
+
+
+	/* VIDIOC_ENUM_FMT */
+	static const struct strval32 buf_types[] = {
+		{ ARG_XLAT_UNKNOWN(0, "V4L2_BUF_TYPE_???") },
+		{ ARG_XLAT_KNOWN(0x1, "V4L2_BUF_TYPE_VIDEO_CAPTURE") },
+		{ ARG_XLAT_KNOWN(0x2, "V4L2_BUF_TYPE_VIDEO_OUTPUT") },
+		{ ARG_XLAT_KNOWN(0x3, "V4L2_BUF_TYPE_VIDEO_OVERLAY") },
+		{ ARG_XLAT_KNOWN(0x4, "V4L2_BUF_TYPE_VBI_CAPTURE") },
+		{ ARG_XLAT_KNOWN(0x5, "V4L2_BUF_TYPE_VBI_OUTPUT") },
+		{ ARG_XLAT_KNOWN(0x6, "V4L2_BUF_TYPE_SLICED_VBI_CAPTURE") },
+		{ ARG_XLAT_KNOWN(0x7, "V4L2_BUF_TYPE_SLICED_VBI_OUTPUT") },
+		{ ARG_XLAT_KNOWN(0x8, "V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY") },
+		{ ARG_XLAT_KNOWN(0x9, "V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE") },
+		{ ARG_XLAT_KNOWN(0xa, "V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE") },
+		{ ARG_XLAT_KNOWN(0xb, "V4L2_BUF_TYPE_SDR_CAPTURE") },
+		{ ARG_XLAT_KNOWN(0xc, "V4L2_BUF_TYPE_SDR_OUTPUT") },
+		{ ARG_XLAT_KNOWN(0xd, "V4L2_BUF_TYPE_META_CAPTURE") },
+		{ ARG_XLAT_KNOWN(0xe, "V4L2_BUF_TYPE_META_OUTPUT") },
+		{ ARG_XLAT_UNKNOWN(0xf, "V4L2_BUF_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0x80, "V4L2_BUF_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0xbadc0ded, "V4L2_BUF_TYPE_???") },
+	};
+	static const struct strval32 fmtdesc_flags[] = {
+		{ ARG_STR(0) },
+		{ ARG_XLAT_KNOWN(0x1, "V4L2_FMT_FLAG_COMPRESSED") },
+		{ ARG_XLAT_KNOWN(0x3e, "V4L2_FMT_FLAG_EMULATED"
+				       "|V4L2_FMT_FLAG_CONTINUOUS_BYTESTREAM"
+				       "|V4L2_FMT_FLAG_DYN_RESOLUTION"
+				       "|V4L2_FMT_FLAG_ENC_CAP_FRAME_INTERVAL"
+				       "|0x20") },
+		{ ARG_XLAT_UNKNOWN(0xdead0000, "V4L2_FMT_FLAG_???") },
+	};
+	static const struct strval32 fmtdesc_fmts[] = {
+		{ 0x4c47504a, RAW("0x4c47504a")
+			      NRAW("v4l2_fourcc('J', 'P', 'G', 'L')"
+			           " /* V4L2_PIX_FMT_JPGL */") },
+		{ 0xbadc0ded, RAW("0xbadc0ded")
+			      NRAW("v4l2_fourcc('\\xed', '\\x0d', '\\xdc',"
+			           " '\\xba')") },
+	};
+	struct v4l2_fmtdesc *fmtdesc = tail_alloc(sizeof(*fmtdesc));
+
+	fill_memory(fmtdesc, sizeof(*fmtdesc));
+	fmtdesc->index = 0xdeac0de;
+
+	ioctl(-1, VIDIOC_ENUM_FMT, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FMT), inject_retval);
+
+	ioctl(-1, VIDIOC_ENUM_FMT, (char *) fmtdesc + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FMT), (char *) fmtdesc + 1, inject_retval);
+
+	for (size_t i = 0; i < ARRAY_SIZE(buf_types); i++) {
+		for (size_t j = 0; j < ARRAY_SIZE(fmtdesc_flags); j++) {
+			for (size_t k = 0; k < ARRAY_SIZE(fmtdesc_fmts); k++) {
+				fmtdesc->type = buf_types[i].val;
+				fmtdesc->flags = fmtdesc_flags[j].val;
+				fmtdesc->pixelformat = fmtdesc_fmts[k].val;
+
+				ioctl(-1, VIDIOC_ENUM_FMT, fmtdesc);
+				printf("ioctl(-1, %s, {index=233488606, type=%s"
+				       ", flags=%s, description=",
+				       XLAT_STR(VIDIOC_ENUM_FMT),
+				       buf_types[i].str,
+				       fmtdesc_flags[j].str);
+				print_quoted_cstring((char *) fmtdesc->description,
+					sizeof(fmtdesc->description));
+				printf(", pixelformat=%s}) = %ld (INJECTED)\n",
+				       fmtdesc_fmts[k].str, inject_retval);
+
+				fill_memory_ex(fmtdesc->description,
+					       sizeof(fmtdesc->description),
+					       (i * 9 + j) * 7 + k,
+					       (k * 3 + j) * 11 + i + 5);
+			}
+		}
+	}
+
+
+	/* VIDIOC_REQBUFS */
+	static const struct strval32 reqb_mems[] = {
+		{ ARG_XLAT_UNKNOWN(0, "V4L2_MEMORY_???") },
+		{ ARG_XLAT_KNOWN(0x1, "V4L2_MEMORY_MMAP") },
+		{ ARG_XLAT_KNOWN(0x4, "V4L2_MEMORY_DMABUF") },
+		{ ARG_XLAT_UNKNOWN(0x5, "V4L2_MEMORY_???") },
+		{ ARG_XLAT_UNKNOWN(0xbadc0ded, "V4L2_MEMORY_???") },
+	};
+	struct v4l2_requestbuffers *reqb = tail_alloc(sizeof(*reqb));
+
+	fill_memory(reqb, sizeof(*reqb));
+	reqb->count = 0xfeedface;
+
+	ioctl(-1, VIDIOC_REQBUFS, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_REQBUFS), inject_retval);
+
+	ioctl(-1, VIDIOC_REQBUFS, (char *) reqb + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_REQBUFS), (char *) reqb + 1, inject_retval);
+
+	for (size_t i = 0; i < MAX(ARRAY_SIZE(buf_types),
+				   ARRAY_SIZE(reqb_mems)); i++) {
+		reqb->type = buf_types[i % ARRAY_SIZE(buf_types)].val;
+		reqb->memory = reqb_mems[i % ARRAY_SIZE(reqb_mems)].val;
+
+		ioctl(-1, VIDIOC_REQBUFS, reqb);
+		printf("ioctl(-1, %s, {type=%s, memory=%s"
+		       ", count=4277009102 => 4277009102}) = %ld (INJECTED)\n",
+		       XLAT_STR(VIDIOC_REQBUFS),
+		       buf_types[i % ARRAY_SIZE(buf_types)].str,
+		       reqb_mems[i % ARRAY_SIZE(reqb_mems)].str,
+		       inject_retval);
+	}
+
+
+	/* VIDIOC_G_FMT, VIDIOC_S_FMT, VIDIOC_TRY_FMT */
+	static const struct strval32 fmt_cmds[] = {
+		{ ARG_STR(VIDIOC_G_FMT) },
+		{ ARG_STR(VIDIOC_S_FMT) },
+		{ ARG_STR(VIDIOC_TRY_FMT) },
+	};
+
+	struct v4l2_format *fmt = tail_alloc(sizeof(*fmt));
+
+	for (size_t i = 0; i < ARRAY_SIZE(fmt_cmds); i++) {
+		ioctl(-1, fmt_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(fmt_cmds[i].str, fmt_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, fmt_cmds[i].val, (char *) fmt + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(fmt_cmds[i].str, fmt_cmds[i].val, NULL),
+		       (char *) fmt + 1, inject_retval);
+
+		for (size_t j = 0; j < ARRAY_SIZE(buf_types); j++) {
+			fill_memory(fmt, sizeof(*fmt));
+
+			fmt->type = buf_types[j].val;
+			if (!fill_fmt(fmt))
+				continue;
+
+			ioctl(-1, fmt_cmds[i].val, fmt);
+			printf("ioctl(-1, %s, {type=%s",
+			       sprintxlat(fmt_cmds[i].str, fmt_cmds[i].val,
+					  NULL),
+			       buf_types[j].str);
+			print_fmt(", ", fmt);
+			if (fmt_cmds[i].val != VIDIOC_G_FMT &&
+			    buf_types[j].val != V4L2_BUF_TYPE_VIDEO_OVERLAY &&
+			    buf_types[j].val != 8)
+				print_fmt("} => {", fmt);
+			printf("}) = %ld (INJECTED)\n", inject_retval);
+		}
+	}
+
+
+	/* VIDIOC_QUERYBUF, VIDIOC_QBUF, VIDIOC_DQBUF */
+	static const struct strval32 buf_cmds[] = {
+		{ ARG_STR(VIDIOC_QUERYBUF) },
+		{ ARG_STR(VIDIOC_QBUF) },
+		{ ARG_STR(VIDIOC_DQBUF) },
+	};
+
+	kernel_v4l2_buffer_t *buf = tail_alloc(sizeof(*buf));
+
+	for (size_t i = 0; i < ARRAY_SIZE(buf_cmds); i++) {
+		ioctl(-1, buf_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(buf_cmds[i].str, buf_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, buf_cmds[i].val, (char *) buf + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(buf_cmds[i].str, buf_cmds[i].val, NULL),
+		       (char *) buf + 1, inject_retval);
+
+		fill_memory(buf, sizeof(*buf));
+		buf->index     = 0xdeadc0de;
+		buf->type      = V4L2_BUF_TYPE_VIDEO_CAPTURE;
+		buf->bytesused = 0xdecaffee;
+		buf->flags     = 0x1ff; /* TODO: update */
+		buf->field     = V4L2_FIELD_TOP;
+
+		buf->timestamp.tv_sec  = 0x1e55c0de;
+		buf->timestamp.tv_usec = 999999;
+
+		buf->timecode.type = V4L2_TC_TYPE_24FPS;
+		buf->timecode.flags = 0xbeefdeaf;
+
+		buf->memory    = V4L2_MEMORY_MMAP;
+		buf->m.offset  = 0xfacefeed;
+		buf->length    = 0xcafebed5;
+		buf->reserved  = 0xdeefaced;
+
+		ioctl(-1, buf_cmds[i].val, buf);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_KNOWN(0x1, "V4L2_BUF_TYPE_VIDEO_CAPTURE")
+		       ", index=3735929054, memory="
+		       XLAT_KNOWN(0x1, "V4L2_MEMORY_MMAP")
+		       ", m.offset=0xfacefeed, length=3405692629"
+		       ", bytesused=3737845742, flags=" RAW("0x1ff")
+#if !XLAT_RAW
+		       XLAT_KNOWN(0x1ff, "V4L2_BUF_FLAG_MAPPED"
+		       "|V4L2_BUF_FLAG_QUEUED|V4L2_BUF_FLAG_DONE"
+		       "|V4L2_BUF_FLAG_KEYFRAME|V4L2_BUF_FLAG_PFRAME"
+		       "|V4L2_BUF_FLAG_BFRAME|V4L2_BUF_FLAG_ERROR"
+		       "|V4L2_BUF_FLAG_IN_REQUEST|V4L2_BUF_FLAG_TIMECODE") "|"
+		       XLAT_KNOWN(0, "V4L2_BUF_FLAG_TIMESTAMP_UNKNOWN") "|"
+		       XLAT_KNOWN(0, "V4L2_BUF_FLAG_TSTAMP_SRC_EOF")
+#endif
+		       "%s, ...}) = %ld (INJECTED)\n",
+		       sprintxlat(buf_cmds[i].str, buf_cmds[i].val, NULL),
+		       buf_cmds[i].val == VIDIOC_DQBUF
+			? ", timestamp={tv_sec=508936414, tv_usec=999999}" : "",
+		       inject_retval);
+
+		buf->type      = V4L2_BUF_TYPE_VBI_CAPTURE;
+		buf->flags     = 0x268040;
+		buf->field     = 0xb;
+		buf->memory    = V4L2_MEMORY_USERPTR;
+		buf->m.userptr = (long) 0xdefaced0dec0ded1LL;
+
+		ioctl(-1, buf_cmds[i].val, buf);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_KNOWN(0x4, "V4L2_BUF_TYPE_VBI_CAPTURE")
+		       ", index=3735929054, memory="
+		       XLAT_KNOWN(0x2, "V4L2_MEMORY_USERPTR")
+		       ", m.userptr=%p, length=3405692629"
+		       ", bytesused=3737845742, flags=" RAW("0x268040")
+#if !XLAT_RAW
+		       XLAT_KNOWN(0x200040, "V4L2_BUF_FLAG_ERROR|0x200000") "|"
+		       XLAT_UNKNOWN(0x8000, "V4L2_BUF_FLAG_TIMESTAMP_???") "|"
+		       XLAT_UNKNOWN(0x60000, "V4L2_BUF_FLAG_TSTAMP_SRC_???")
+#endif
+		       "%s, ...}) = %ld (INJECTED)\n",
+		       sprintxlat(buf_cmds[i].str, buf_cmds[i].val, NULL),
+		       (void *) (intptr_t) 0xdefaced0dec0ded1LL,
+		       buf_cmds[i].val == VIDIOC_DQBUF
+			? ", timestamp={tv_sec=508936414, tv_usec=999999}" : "",
+		       inject_retval);
+
+		buf->type      = 0x9;
+		buf->flags     = 0;
+
+		ioctl(-1, buf_cmds[i].val, buf);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_KNOWN(0x9, "V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE")
+		       ", index=3735929054, memory="
+		       XLAT_KNOWN(0x2, "V4L2_MEMORY_USERPTR")
+		       ", m.userptr=%p, length=3405692629"
+		       ", bytesused=3737845742, flags=" RAW("0")
+#if !XLAT_RAW
+		       XLAT_KNOWN(0, "V4L2_BUF_FLAG_TIMESTAMP_UNKNOWN") "|"
+		       XLAT_KNOWN(0, "V4L2_BUF_FLAG_TSTAMP_SRC_EOF")
+#endif
+		       "%s, ...}) = %ld (INJECTED)\n",
+		       sprintxlat(buf_cmds[i].str, buf_cmds[i].val, NULL),
+		       (void *) (intptr_t) 0xdefaced0dec0ded1LL,
+		       buf_cmds[i].val == VIDIOC_DQBUF
+			? ", timestamp={tv_sec=508936414, tv_usec=999999}" : "",
+		       inject_retval);
+
+		buf->type      = 0xa;
+		buf->memory    = V4L2_MEMORY_OVERLAY;
+		buf->flags     = 0x2000;
+
+		ioctl(-1, buf_cmds[i].val, buf);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_KNOWN(0xa, "V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE")
+		       ", index=3735929054, memory="
+		       XLAT_KNOWN(0x3, "V4L2_MEMORY_OVERLAY")
+		       ", length=3405692629, bytesused=3737845742"
+		       ", flags=" RAW("0x2000")
+#if !XLAT_RAW
+		       XLAT_KNOWN(0x2000, "V4L2_BUF_FLAG_TIMESTAMP_MONOTONIC")
+		       "|" XLAT_KNOWN(0, "V4L2_BUF_FLAG_TSTAMP_SRC_EOF")
+#endif
+		       "%s, ...}) = %ld (INJECTED)\n",
+		       sprintxlat(buf_cmds[i].str, buf_cmds[i].val, NULL),
+		       buf_cmds[i].val == VIDIOC_DQBUF
+			? ", timestamp={tv_sec=508936414, tv_usec=999999}" : "",
+		       inject_retval);
+	}
+
+
+	/* VIDIOC_G_FBUF, VIDIOC_S_FBUF */
+	static const struct strval32 fbuf_cmds[] = {
+		{ ARG_STR(VIDIOC_G_FBUF) },
+		{ ARG_STR(VIDIOC_S_FBUF) },
+	};
+
+	struct v4l2_framebuffer *fbuf = tail_alloc(sizeof(*fbuf));
+
+	for (size_t i = 0; i < ARRAY_SIZE(fbuf_cmds); i++) {
+		ioctl(-1, fbuf_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(fbuf_cmds[i].str, fbuf_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, fbuf_cmds[i].val, (char *) fbuf + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(fbuf_cmds[i].str, fbuf_cmds[i].val, NULL),
+		       (char *) fbuf + 1, inject_retval);
+
+		fill_memory32(fbuf, sizeof(*fbuf));
+		fbuf->base = NULL;
+
+		ioctl(-1, fbuf_cmds[i].val, fbuf);
+		printf("ioctl(-1, %s, {capability=0x80a0c0e0, flags=0x80a0c0e1"
+		       ", base=NULL}) = %ld (INJECTED)\n",
+		       sprintxlat(fbuf_cmds[i].str, fbuf_cmds[i].val, NULL),
+		       inject_retval);
+	}
+
+
+	/* VIDIOC_G_PARM, VIDIOC_S_PARM */
+	static const struct strval32 sparm_cmds[] = {
+		{ ARG_STR(VIDIOC_G_PARM) },
+		{ ARG_STR(VIDIOC_S_PARM) },
+	};
+
+	struct v4l2_streamparm *sparm = tail_alloc(sizeof(*sparm));
+
+	for (size_t i = 0; i < ARRAY_SIZE(sparm_cmds); i++) {
+		ioctl(-1, sparm_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(sparm_cmds[i].str, sparm_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, sparm_cmds[i].val, (char *) sparm + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(sparm_cmds[i].str, sparm_cmds[i].val, NULL),
+		       (char *) sparm + 1, inject_retval);
+
+		fill_memory32(sparm, sizeof(*sparm));
+
+		ioctl(-1, sparm_cmds[i].val, sparm);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_UNKNOWN(0x80a0c0e0, "V4L2_BUF_TYPE_???")
+		       "}) = %ld (INJECTED)\n",
+		       sprintxlat(sparm_cmds[i].str, sparm_cmds[i].val, NULL),
+		       inject_retval);
+
+		sparm->type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
+
+		static const char *parm_str1 = "parm.capture={capability="
+			XLAT_UNKNOWN(0x80a0c0e1, "V4L2_CAP_???")
+			", capturemode="
+			XLAT_UNKNOWN(0x80a0c0e2, "V4L2_MODE_???")
+			", timeperframe=2158018787/2158018788"
+			", extendedmode=0x80a0c0e5, readbuffers=2158018790}";
+
+		ioctl(-1, sparm_cmds[i].val, sparm);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_KNOWN(0x1, "V4L2_BUF_TYPE_VIDEO_CAPTURE")
+		       ", %s}%s%s%s) = %ld (INJECTED)\n",
+		       sprintxlat(sparm_cmds[i].str, sparm_cmds[i].val, NULL),
+		       parm_str1,
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? " => {" : "",
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? parm_str1 : "",
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? "}" : "",
+		       inject_retval);
+
+		sparm->parm.capture.capability = 0x1000;
+		sparm->parm.capture.capturemode = 0x1;
+
+		static const char *parm_str2 = "parm.capture={capability="
+			XLAT_KNOWN(0x1000, "V4L2_CAP_TIMEPERFRAME")
+			", capturemode="
+			XLAT_KNOWN(0x1, "V4L2_MODE_HIGHQUALITY")
+			", timeperframe=2158018787/2158018788"
+			", extendedmode=0x80a0c0e5, readbuffers=2158018790}";
+
+		ioctl(-1, sparm_cmds[i].val, sparm);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_KNOWN(0x1, "V4L2_BUF_TYPE_VIDEO_CAPTURE")
+		       ", %s}%s%s%s) = %ld (INJECTED)\n",
+		       sprintxlat(sparm_cmds[i].str, sparm_cmds[i].val, NULL),
+		       parm_str2,
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? " => {" : "",
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? parm_str2 : "",
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? "}" : "",
+		       inject_retval);
+
+		sparm->type = 0x9;
+		sparm->parm.capture.capability = 0xdeadbeef;
+		sparm->parm.capture.capturemode = 0xadec0ded;
+
+		ioctl(-1, sparm_cmds[i].val, sparm);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_KNOWN(0x9, "V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE")
+		       "}) = %ld (INJECTED)\n",
+		       sprintxlat(sparm_cmds[i].str, sparm_cmds[i].val, NULL),
+		       inject_retval);
+
+		fill_memory32(sparm, sizeof(*sparm));
+		sparm->type = V4L2_BUF_TYPE_VIDEO_OUTPUT;
+
+		static const char *parm_str3 = "parm.output={capability="
+			XLAT_UNKNOWN(0x80a0c0e1, "V4L2_CAP_???")
+			", outputmode="
+			XLAT_UNKNOWN(0x80a0c0e2, "V4L2_MODE_???")
+			", timeperframe=2158018787/2158018788"
+			", extendedmode=0x80a0c0e5, writebuffers=2158018790}";
+
+		ioctl(-1, sparm_cmds[i].val, sparm);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_KNOWN(0x2, "V4L2_BUF_TYPE_VIDEO_OUTPUT")
+		       ", %s}%s%s%s) = %ld (INJECTED)\n",
+		       sprintxlat(sparm_cmds[i].str, sparm_cmds[i].val, NULL),
+		       parm_str3,
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? " => {" : "",
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? parm_str3 : "",
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? "}" : "",
+		       inject_retval);
+
+	}
+
+
+	/* VIDIOC_G_STD, VIDIOC_S_STD */
+	static const struct strval32 stdid_cmds[] = {
+		{ ARG_STR(VIDIOC_G_STD) },
+		{ ARG_STR(VIDIOC_S_STD) },
+	};
+	static const struct strval64 stdids[] = {
+		{ ARG_STR(0) },
+		{ ARG_STR(0x1) },
+		{ ARG_STR(0xb000) },
+		{ ARG_STR(0x3ffffff) },
+		{ ARG_STR(0xffffffff) },
+		{ ARG_ULL_STR(0xbadc0deddeadface) },
+	};
+
+	v4l2_std_id *stdid = tail_alloc(sizeof(*stdid));
+
+	for (size_t i = 0; i < ARRAY_SIZE(stdid_cmds); i++) {
+		ioctl(-1, stdid_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(stdid_cmds[i].str, stdid_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, stdid_cmds[i].val, (char *) stdid + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(stdid_cmds[i].str, stdid_cmds[i].val, NULL),
+		       (char *) stdid + 1, inject_retval);
+
+		for (size_t j = 0; j < ARRAY_SIZE(stdids); j++) {
+			*stdid = stdids[j].val;
+
+			ioctl(-1, stdid_cmds[i].val, stdid);
+			printf("ioctl(-1, %s, [%s]) = %ld (INJECTED)\n",
+			       sprintxlat(stdid_cmds[i].str, stdid_cmds[i].val, NULL),
+			       stdids[j].str, inject_retval);
+
+		}
+	}
+
+
+	/* VIDIOC_ENUMSTD */
+	struct v4l2_standard *std = tail_alloc(sizeof(*std));
+
+	ioctl(-1, VIDIOC_ENUMSTD, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUMSTD), inject_retval);
+
+	ioctl(-1, VIDIOC_ENUMSTD, (char *) std + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUMSTD), (char *) std + 1, inject_retval);
+
+	for (size_t i = 0; i < ARRAY_SIZE(stdids); i++) {
+		fill_memory32(&std->frameperiod, sizeof(*std) -
+			      offsetof(struct v4l2_standard, frameperiod));
+		fill_memory_ex(std->name, sizeof(std->name), i * 47 + 1, 255);
+		std->index = 0xdeadface;
+		std->id = stdids[i].val;
+
+		ioctl(-1, VIDIOC_ENUMSTD, std);
+		printf("ioctl(-1, %s, {index=3735943886, name=",
+		       XLAT_STR(VIDIOC_ENUMSTD));
+		print_quoted_cstring((char *) std->name, sizeof(std->name));
+		printf(", frameperiod=2158018784/2158018785"
+		       ", framelines=2158018786}) = %ld (INJECTED)\n",
+		       inject_retval);
+	}
+
+
+	/* VIDIOC_ENUMINPUT */
+	static const struct strval32 input_types[] = {
+		{ ARG_XLAT_UNKNOWN(0, "V4L2_INPUT_TYPE_???") },
+		{ V4L2_INPUT_TYPE_TUNER,
+		  XLAT_KNOWN(0x1, "V4L2_INPUT_TYPE_TUNER") },
+		{ V4L2_INPUT_TYPE_CAMERA,
+		  XLAT_KNOWN(0x2, "V4L2_INPUT_TYPE_CAMERA") },
+		{ ARG_XLAT_UNKNOWN(0x4, "V4L2_INPUT_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0xdeadc0de, "V4L2_INPUT_TYPE_???") },
+	};
+
+	struct v4l2_input *input = tail_alloc(sizeof(*input));
+
+	ioctl(-1, VIDIOC_ENUMINPUT, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUMINPUT), inject_retval);
+
+	ioctl(-1, VIDIOC_ENUMINPUT, (char *) input + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUMINPUT), (char *) input + 1, inject_retval);
+
+	for (size_t i = 0; i < ARRAY_SIZE(stdids); i++) {
+		for (size_t j = 0; j < ARRAY_SIZE(input_types); j++) {
+			fill_memory32(input, sizeof(*input));
+			fill_memory_ex(input->name, sizeof(input->name),
+				       i * 47 + 13, 255);
+			input->type = input_types[j].val;
+			input->std = stdids[i].val;
+
+			ioctl(-1, VIDIOC_ENUMINPUT, input);
+			printf("ioctl(-1, %s, {index=2158018784, name=",
+			       XLAT_STR(VIDIOC_ENUMINPUT));
+			print_quoted_cstring((char *) input->name,
+					     sizeof(input->name));
+			printf(", type=%s}) = %ld (INJECTED)\n",
+			       input_types[j].str, inject_retval);
+		}
+	}
+
+
+	/* VIDIOC_G_CTRL, VIDIOC_S_CTRL */
+	static const struct strval32 ctrl_cmds[] = {
+		{ ARG_STR(VIDIOC_G_CTRL) },
+		{ ARG_STR(VIDIOC_S_CTRL) },
+	};
+
+	struct v4l2_control *ctrl = tail_alloc(sizeof(*ctrl));
+
+	for (size_t i = 0; i < ARRAY_SIZE(ctrl_cmds); i++) {
+		ioctl(-1, ctrl_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(ctrl_cmds[i].str, ctrl_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, ctrl_cmds[i].val, (char *) ctrl + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(ctrl_cmds[i].str, ctrl_cmds[i].val, NULL),
+		       (char *) ctrl + 1, inject_retval);
+
+		/* NB: cid printing is mostly tested in ioctl_v4l2.c */
+		fill_memory32(ctrl, sizeof(*ctrl));
+		ioctl(-1, ctrl_cmds[i].val, ctrl);
+		printf("ioctl(-1, %s, {id=0x80a0c0e0"
+		       NRAW(" /* V4L2_CID_??? */")
+		       ", value=-2136948511%s}) = %ld (INJECTED)\n",
+		       sprintxlat(ctrl_cmds[i].str, ctrl_cmds[i].val, NULL),
+		       ctrl_cmds[i].val == VIDIOC_S_CTRL
+			? " => -2136948511" : "",
+		       inject_retval);
+	}
+
+
+	/* VIDIOC_G_TUNER, VIDIOC_S_TUNER */
+	static const struct strval32 tuner_cmds[] = {
+		{ ARG_STR(VIDIOC_G_TUNER) },
+		{ ARG_STR(VIDIOC_S_TUNER) },
+	};
+	static const struct strval32 tuner_types[] = {
+		{ ARG_XLAT_UNKNOWN(0, "V4L2_TUNER_???") },
+		{ ARG_XLAT_KNOWN(0x1, "V4L2_TUNER_RADIO") },
+		{ ARG_XLAT_KNOWN(0x5, "V4L2_TUNER_RF") },
+		{ ARG_XLAT_UNKNOWN(0x6, "V4L2_TUNER_???") },
+		{ ARG_XLAT_UNKNOWN(0xdeadc0de, "V4L2_TUNER_???") },
+	};
+	static const struct strval32 tuner_caps[] = {
+		{ ARG_STR(0) },
+		{ ARG_XLAT_KNOWN(0x1fff, "V4L2_TUNER_CAP_LOW"
+				 "|V4L2_TUNER_CAP_NORM"
+				 "|V4L2_TUNER_CAP_HWSEEK_BOUNDED"
+				 "|V4L2_TUNER_CAP_HWSEEK_WRAP"
+				 "|V4L2_TUNER_CAP_STEREO|V4L2_TUNER_CAP_LANG2"
+				 "|V4L2_TUNER_CAP_LANG1|V4L2_TUNER_CAP_RDS"
+				 "|V4L2_TUNER_CAP_RDS_BLOCK_IO"
+				 "|V4L2_TUNER_CAP_RDS_CONTROLS"
+				 "|V4L2_TUNER_CAP_FREQ_BANDS"
+				 "|V4L2_TUNER_CAP_HWSEEK_PROG_LIM"
+				 "|V4L2_TUNER_CAP_1HZ") },
+		{ ARG_XLAT_KNOWN(0xdeadc0de, "V4L2_TUNER_CAP_NORM"
+				 "|V4L2_TUNER_CAP_HWSEEK_BOUNDED"
+				 "|V4L2_TUNER_CAP_HWSEEK_WRAP"
+				 "|V4L2_TUNER_CAP_STEREO|V4L2_TUNER_CAP_LANG1"
+				 "|V4L2_TUNER_CAP_RDS|0xdeadc000") },
+		{ ARG_XLAT_UNKNOWN(0xffffe000, "V4L2_TUNER_CAP_???") },
+	};
+	static const struct strval32 tuner_rxsc[] = {
+		{ ARG_STR(0) },
+		{ ARG_XLAT_KNOWN(0x1f, "V4L2_TUNER_SUB_MONO"
+				 "|V4L2_TUNER_SUB_STEREO|V4L2_TUNER_SUB_LANG2"
+				 "|V4L2_TUNER_SUB_LANG1|V4L2_TUNER_SUB_RDS") },
+		{ ARG_XLAT_KNOWN(0xbeefface, "V4L2_TUNER_SUB_STEREO"
+				 "|V4L2_TUNER_SUB_LANG2|V4L2_TUNER_SUB_LANG1"
+				 "|0xbeeffac0") },
+		{ ARG_XLAT_UNKNOWN(0xffffffe0, "V4L2_TUNER_SUB_???") },
+
+	};
+	static const struct strval32 tuner_amodes[] = {
+		{ ARG_XLAT_KNOWN(0, "V4L2_TUNER_MODE_MONO") },
+		{ ARG_XLAT_KNOWN(0x2, "V4L2_TUNER_MODE_LANG2") },
+		{ ARG_XLAT_KNOWN(0x4, "V4L2_TUNER_MODE_LANG1_LANG2") },
+		{ ARG_XLAT_UNKNOWN(0x5, "V4L2_TUNER_MODE_???") },
+		{ ARG_XLAT_UNKNOWN(0xcaffeeed, "V4L2_TUNER_MODE_???") },
+	};
+	static const size_t tuner_iters = MAX(MAX(MAX(ARRAY_SIZE(tuner_types),
+						      ARRAY_SIZE(tuner_caps)),
+						  ARRAY_SIZE(tuner_rxsc)),
+					      ARRAY_SIZE(tuner_amodes));
+
+	struct v4l2_tuner *tuner = tail_alloc(sizeof(*tuner));
+
+	for (size_t i = 0; i < ARRAY_SIZE(tuner_cmds); i++) {
+		ioctl(-1, tuner_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(tuner_cmds[i].str, tuner_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, tuner_cmds[i].val, (char *) tuner + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(tuner_cmds[i].str, tuner_cmds[i].val, NULL),
+		       (char *) tuner + 1, inject_retval);
+
+		for (size_t j = 0; j < tuner_iters; j++) {
+			fill_memory32(tuner, sizeof(*tuner));
+			fill_memory_ex(tuner->name, sizeof(tuner->name),
+				       j * 47 + 7, 255);
+			tuner->type =
+				tuner_types[j % ARRAY_SIZE(tuner_types)].val;
+			tuner->capability =
+				tuner_caps[j % ARRAY_SIZE(tuner_caps)].val;
+			tuner->rxsubchans =
+				tuner_rxsc[j % ARRAY_SIZE(tuner_rxsc)].val;
+			tuner->audmode =
+				tuner_amodes[j % ARRAY_SIZE(tuner_amodes)].val;
+
+			ioctl(-1, tuner_cmds[i].val, tuner);
+			printf("ioctl(-1, %s, {index=2158018784",
+			       sprintxlat(tuner_cmds[i].str,
+					  tuner_cmds[i].val, NULL));
+			for (size_t k = 0;
+			     k < (tuner_cmds[i].val == VIDIOC_S_TUNER ? 2 : 1);
+			     k++) {
+				printf("%sname=", k ? "} => {" : ", ");
+				print_quoted_cstring((char *) tuner->name,
+						     sizeof(tuner->name));
+				printf(", type=%s, capability=%s"
+				       ", rangelow=2158018795"
+				       ", rangehigh=2158018796, rxsubchans=%s"
+				       ", audmode=%s, signal=-2136948497"
+				       ", afc=-2136948496",
+				       tuner_types[j %
+						   ARRAY_SIZE(tuner_types)].str,
+				       tuner_caps[j %
+						  ARRAY_SIZE(tuner_caps)].str,
+				       tuner_rxsc[j %
+						  ARRAY_SIZE(tuner_rxsc)].str,
+				       tuner_amodes[j %
+						 ARRAY_SIZE(tuner_amodes)].str);
+			}
+			printf("}) = %ld (INJECTED)\n", inject_retval);
+		}
+	}
+
+
+	/* VIDIOC_QUERYCTRL */
+	static const struct strval32 cids[] = {
+		{ ARG_XLAT_UNKNOWN(0, "V4L2_CID_???") },
+		{ ARG_XLAT_UNKNOWN(0x97abcd, "V4L2_CID_???") },
+		{ ARG_XLAT_KNOWN(0x980000, "V4L2_CTRL_CLASS_USER+0") },
+		{ ARG_XLAT_KNOWN(0x990a64,
+				 "V4L2_CID_MPEG_VIDEO_H264_CPB_SIZE") },
+		{ ARG_XLAT_KNOWN(0xa31234, "V4L2_CTRL_CLASS_DETECT+0x1234") },
+		{ ARG_XLAT_UNKNOWN(0xa40000, "V4L2_CID_???") },
+		{ 0xdeadc0de,
+#if XLAT_RAW
+		  "0xdeadc0de"
+#else
+		  XLAT_KNOWN(0xc0000000, "V4L2_CTRL_FLAG_NEXT_CTRL"
+					 "|V4L2_CTRL_FLAG_NEXT_COMPOUND")
+		  "|0x1eadc0de /* V4L2_CID_??? */"
+#endif
+			      },
+	};
+	static const struct strval32 ctrl_types[] = {
+		{ ARG_XLAT_UNKNOWN(0, "V4L2_CTRL_TYPE_???") },
+		{ ARG_XLAT_KNOWN(0x1, "V4L2_CTRL_TYPE_INTEGER") },
+		{ ARG_XLAT_KNOWN(0x2, "V4L2_CTRL_TYPE_BOOLEAN") },
+		{ ARG_XLAT_KNOWN(0x3, "V4L2_CTRL_TYPE_MENU") },
+		{ ARG_XLAT_KNOWN(0x4, "V4L2_CTRL_TYPE_BUTTON") },
+		{ ARG_XLAT_KNOWN(0x5, "V4L2_CTRL_TYPE_INTEGER64") },
+		{ ARG_XLAT_KNOWN(0x6, "V4L2_CTRL_TYPE_CTRL_CLASS") },
+		{ ARG_XLAT_KNOWN(0x7, "V4L2_CTRL_TYPE_STRING") },
+		{ ARG_XLAT_KNOWN(0x8, "V4L2_CTRL_TYPE_BITMASK") },
+		{ ARG_XLAT_KNOWN(0x9, "V4L2_CTRL_TYPE_INTEGER_MENU") },
+		{ ARG_XLAT_UNKNOWN(0xa, "V4L2_CTRL_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0xff, "V4L2_CTRL_TYPE_???") },
+		{ ARG_XLAT_KNOWN(0x100, "V4L2_CTRL_TYPE_U8") },
+		{ ARG_XLAT_KNOWN(0x101, "V4L2_CTRL_TYPE_U16") },
+		{ ARG_XLAT_KNOWN(0x102, "V4L2_CTRL_TYPE_U32") },
+		{ ARG_XLAT_UNKNOWN(0x103, "V4L2_CTRL_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0x104, "V4L2_CTRL_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0x105, "V4L2_CTRL_TYPE_???") },
+		{ ARG_XLAT_KNOWN(0x106, "V4L2_CTRL_TYPE_AREA") },
+		{ ARG_XLAT_UNKNOWN(0x107, "V4L2_CTRL_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0xdeadc0de, "V4L2_CTRL_TYPE_???") },
+	};
+	static const struct strval32 ctrl_flags[] = {
+		{ ARG_STR(0) },
+		{ ARG_XLAT_KNOWN(0x7ff, "V4L2_CTRL_FLAG_DISABLED"
+					"|V4L2_CTRL_FLAG_GRABBED"
+					"|V4L2_CTRL_FLAG_READ_ONLY"
+					"|V4L2_CTRL_FLAG_UPDATE"
+					"|V4L2_CTRL_FLAG_INACTIVE"
+					"|V4L2_CTRL_FLAG_SLIDER"
+					"|V4L2_CTRL_FLAG_WRITE_ONLY"
+					"|V4L2_CTRL_FLAG_VOLATILE"
+					"|V4L2_CTRL_FLAG_HAS_PAYLOAD"
+					"|V4L2_CTRL_FLAG_EXECUTE_ON_WRITE"
+					"|V4L2_CTRL_FLAG_MODIFY_LAYOUT") },
+		{ ARG_XLAT_KNOWN(0xbeefface, "V4L2_CTRL_FLAG_GRABBED"
+					     "|V4L2_CTRL_FLAG_READ_ONLY"
+					     "|V4L2_CTRL_FLAG_UPDATE"
+					     "|V4L2_CTRL_FLAG_WRITE_ONLY"
+					     "|V4L2_CTRL_FLAG_VOLATILE"
+					     "|V4L2_CTRL_FLAG_EXECUTE_ON_WRITE"
+					     "|0xbeeff800") },
+		{ ARG_XLAT_UNKNOWN(0xfffff800, "V4L2_CTRL_FLAG_???") },
+	};
+	static const size_t qctrl_iters = MAX(MAX(ARRAY_SIZE(cids),
+						  ARRAY_SIZE(ctrl_types)),
+					       ARRAY_SIZE(ctrl_flags));
+
+	struct v4l2_queryctrl *qctrl = tail_alloc(sizeof(*qctrl));
+
+	ioctl(-1, VIDIOC_QUERYCTRL, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_QUERYCTRL), inject_retval);
+
+	ioctl(-1, VIDIOC_QUERYCTRL, (char *) qctrl + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_QUERYCTRL), (char *) qctrl + 1, inject_retval);
+
+	for (size_t i = 0; i < qctrl_iters; i++) {
+		fill_memory32(qctrl, sizeof(*qctrl));
+		fill_memory_ex(qctrl->name, sizeof(qctrl->name),
+			       i * 47 + 5, 255);
+		qctrl->id    = cids[i % ARRAY_SIZE(cids)].val;
+		qctrl->type  = ctrl_types[i % ARRAY_SIZE(ctrl_types)].val;
+		qctrl->flags = ctrl_flags[i % ARRAY_SIZE(ctrl_flags)].val;
+
+		if (i % 2)
+			memset(qctrl->reserved, 0, sizeof(qctrl->reserved));
+
+		ioctl(-1, VIDIOC_QUERYCTRL, qctrl);
+		printf("ioctl(-1, %s, {id=%s, type=%s, name=",
+		       XLAT_STR(VIDIOC_QUERYCTRL),
+		       cids[i % ARRAY_SIZE(cids)].str,
+		       ctrl_types[i % ARRAY_SIZE(ctrl_types)].str);
+		print_quoted_cstring((char *) qctrl->name, sizeof(qctrl->name));
+#if VERBOSE
+		printf(", minimum=-2136948502, maximum=-2136948501"
+		       ", step=-2136948500, default_value=-2136948499"
+		       ", flags=%s%s",
+		       ctrl_flags[i % ARRAY_SIZE(ctrl_flags)].str,
+		       i % 2 ? "" : ", reserved=[0x80a0c0ef, 0x80a0c0f0]");
+#else
+		printf(", ...");
+#endif
+		printf("}) = %ld (INJECTED)\n", inject_retval);
+	}
+
+
+	/* VIDIOC_G_INPUT, VIDIOC_S_INPUT */
+	static const struct strval32 input_cmds[] = {
+		{ ARG_STR(VIDIOC_G_INPUT) },
+		{ ARG_STR(VIDIOC_S_INPUT) },
+	};
+	static const struct strval32 inputids[] = {
+		{ ARG_STR(0) },
+		{ ARG_STR(1) },
+		{ ARG_STR(1578221295) },
+		{ ARG_STR(31415926) },
+		{ ARG_STR(4294967295) },
+	};
+
+	int *inputid = tail_alloc(sizeof(*inputid));
+
+	for (size_t i = 0; i < ARRAY_SIZE(input_cmds); i++) {
+		ioctl(-1, input_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(input_cmds[i].str, input_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, input_cmds[i].val, (char *) inputid + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(input_cmds[i].str, input_cmds[i].val, NULL),
+		       (char *) inputid + 1, inject_retval);
+
+		for (size_t j = 0; j < ARRAY_SIZE(inputids); j++) {
+			*inputid = inputids[j].val;
+
+			ioctl(-1, input_cmds[i].val, inputid);
+			printf("ioctl(-1, %s, [%s]) = %ld (INJECTED)\n",
+			       sprintxlat(input_cmds[i].str, input_cmds[i].val,
+					  NULL),
+			       inputids[j].str, inject_retval);
+
+		}
+	}
+
+
+	/* VIDIOC_CROPCAP */
+	struct v4l2_cropcap *ccap = tail_alloc(sizeof(*ccap));
+
+	fill_memory32(ccap, sizeof(*ccap));
+
+	ioctl(-1, VIDIOC_CROPCAP, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_CROPCAP), inject_retval);
+
+	ioctl(-1, VIDIOC_CROPCAP, (char *) ccap + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_CROPCAP), (char *) ccap + 1, inject_retval);
+
+	for (size_t i = 0; i < ARRAY_SIZE(buf_types); i++) {
+		ccap->type = buf_types[i].val;
+
+		ioctl(-1, VIDIOC_CROPCAP, ccap);
+		printf("ioctl(-1, %s, {type=%s"
+		       ", bounds={left=-2136948511, top=-2136948510"
+		       ", width=2158018787, height=2158018788}"
+		       ", defrect={left=-2136948507, top=-2136948506"
+		       ", width=2158018791, height=2158018792}"
+		       ", pixelaspect=2158018793/2158018794})"
+		       " = %ld (INJECTED)\n",
+		       XLAT_STR(VIDIOC_CROPCAP),
+		       buf_types[i].str, inject_retval);
+	}
+
+
+	/* VIDIOC_G_CROP, VIDIOC_S_CROP */
+	static const struct strval32 crop_cmds[] = {
+		{ ARG_STR(VIDIOC_G_CROP) },
+		{ ARG_STR(VIDIOC_S_CROP) },
+	};
+	struct v4l2_crop *crop = tail_alloc(sizeof(*crop));
+
+	for (size_t i = 0; i < ARRAY_SIZE(crop_cmds); i++) {
+		fill_memory32(crop, sizeof(*crop));
+
+		ioctl(-1, crop_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(crop_cmds[i].str, crop_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, crop_cmds[i].val, (char *) crop + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(crop_cmds[i].str, crop_cmds[i].val, NULL),
+		       (char *) crop + 1, inject_retval);
+
+		for (size_t j = 0; j < ARRAY_SIZE(buf_types); j++) {
+			crop->type = buf_types[j].val;
+
+			ioctl(-1, crop_cmds[i].val, crop);
+			printf("ioctl(-1, %s, {type=%s, c={left=-2136948511"
+			       ", top=-2136948510, width=2158018787"
+			       ", height=2158018788}}) = %ld (INJECTED)\n",
+			       sprintxlat(crop_cmds[i].str, crop_cmds[i].val,
+					  NULL),
+			       buf_types[j].str, inject_retval);
+		}
+	}
+
+
+#ifdef VIDIOC_S_EXT_CTRLS
+	/* VIDIOC_S_EXT_CTRLS, VIDIOC_TRY_EXT_CTRLS, VIDIOC_G_EXT_CTRLS */
+	static const struct strval32 ectrl_cmds[] = {
+		{ ARG_STR(VIDIOC_S_EXT_CTRLS) },
+		{ ARG_STR(VIDIOC_TRY_EXT_CTRLS) },
+		{ ARG_STR(VIDIOC_G_EXT_CTRLS) },
+	};
+	/* static const struct strval32 ectrl_which = {
+	}; */
+
+	struct v4l2_ext_controls *ectrls = tail_alloc(sizeof(*ectrls));
+	/* struct v4l2_ext_control *ectrl = tail_alloc(sizeof(*ectrl) * 2); */
+
+	for (size_t i = 0; i < ARRAY_SIZE(ectrl_cmds); i++) {
+		fill_memory32(ectrls, sizeof(*ectrls));
+
+		ioctl(-1, ectrl_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(ectrl_cmds[i].str, ectrl_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, ectrl_cmds[i].val, (char *) ectrls + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(ectrl_cmds[i].str, ectrl_cmds[i].val, NULL),
+		       (char *) ectrls + 1, inject_retval);
+	}
+
+#endif /* VIDIOC_S_EXT_CTRLS */
+
+
+#ifdef HAVE_STRUCT_V4L2_FRMSIZEENUM
+	/* VIDIOC_ENUM_FRAMESIZES */
+	static const struct strval32 frmsz_simple_types[] = {
+		{ ARG_XLAT_UNKNOWN(0, "V4L2_FRMSIZE_TYPE_???") },
+		{ ARG_XLAT_KNOWN(0x2, "V4L2_FRMSIZE_TYPE_CONTINUOUS") },
+		{ ARG_XLAT_UNKNOWN(0x4, "V4L2_FRMSIZE_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0xdeadf157, "V4L2_FRMSIZE_TYPE_???") },
+	};
+
+	struct v4l2_frmsizeenum *fse = tail_alloc(sizeof(*fse));
+
+	ioctl(-1, VIDIOC_ENUM_FRAMESIZES, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMESIZES), inject_retval);
+
+	ioctl(-1, VIDIOC_ENUM_FRAMESIZES, (char *) fse + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMESIZES), (char *) fse + 1,
+	       inject_retval);
+
+	fill_memory32(fse, sizeof(*fse));
+	fse->type = V4L2_FRMSIZE_TYPE_DISCRETE;
+
+	ioctl(-1, VIDIOC_ENUM_FRAMESIZES, fse);
+	printf("ioctl(-1, %s, {index=2158018784, pixel_format="
+	       RAW("0x80a0c0e1")
+	       NRAW("v4l2_fourcc('\\xe1', '\\xc0', '\\xa0', '\\x80')")
+	       ", type=" XLAT_KNOWN(0x1, "V4L2_FRMSIZE_TYPE_DISCRETE")
+	       ", discrete={width=2158018787, height=2158018788}"
+	       "}) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMESIZES), inject_retval);
+
+	fse->pixel_format = 0x5c22270d;
+	fse->type = V4L2_FRMSIZE_TYPE_STEPWISE;
+
+	ioctl(-1, VIDIOC_ENUM_FRAMESIZES, fse);
+	printf("ioctl(-1, %s, {index=2158018784, pixel_format="
+	       RAW("0x5c22270d")
+	       NRAW("v4l2_fourcc('\\x0d', '\\\'', '\"', '\\\\')")
+	       ", type=" XLAT_KNOWN(0x3, "V4L2_FRMSIZE_TYPE_STEPWISE")
+	       ", stepwise={min_width=2158018787, max_width=2158018788"
+	       ", step_width=2158018789, min_height=2158018790"
+	       ", max_height=2158018791, step_height=2158018792}"
+	       "}) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMESIZES), inject_retval);
+
+	for (size_t i = 0; i < ARRAY_SIZE(frmsz_simple_types); i++) {
+		fill_memory32(fse, sizeof(*fse));
+		fse->type = frmsz_simple_types[i].val;
+
+		ioctl(-1, VIDIOC_ENUM_FRAMESIZES, fse);
+		printf("ioctl(-1, %s, {index=2158018784, pixel_format="
+		       RAW("0x80a0c0e1")
+		       NRAW("v4l2_fourcc('\\xe1', '\\xc0', '\\xa0', '\\x80')")
+		       ", type=%s}) = %ld (INJECTED)\n",
+		       XLAT_STR(VIDIOC_ENUM_FRAMESIZES),
+		       frmsz_simple_types[i].str, inject_retval);
+
+	}
+#endif /* HAVE_STRUCT_V4L2_FRMSIZEENUM */
+
+
+#ifdef HAVE_STRUCT_V4L2_FRMIVALENUM
+	/* VIDIOC_ENUM_FRAMEINTERVALS */
+	static const struct strval32 frmival_simple_types[] = {
+		{ ARG_XLAT_UNKNOWN(0, "V4L2_FRMIVAL_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0x4, "V4L2_FRMIVAL_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0xdeadf157, "V4L2_FRMIVAL_TYPE_???") },
+	};
+	static const struct strval32 frmival_step_types[] = {
+		{ ARG_XLAT_KNOWN(0x2, "V4L2_FRMIVAL_TYPE_CONTINUOUS") },
+		{ ARG_XLAT_KNOWN(0x3, "V4L2_FRMIVAL_TYPE_STEPWISE") },
+	};
+
+	struct v4l2_frmivalenum *fie = tail_alloc(sizeof(*fie));
+
+	ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMEINTERVALS), inject_retval);
+
+	ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, (char *) fie + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMEINTERVALS), (char *) fie + 1,
+	       inject_retval);
+
+	fill_memory32(fie, sizeof(*fie));
+	fie->type = V4L2_FRMIVAL_TYPE_DISCRETE;
+
+	ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, fie);
+	printf("ioctl(-1, %s, {index=2158018784, pixel_format="
+	       RAW("0x80a0c0e1")
+	       NRAW("v4l2_fourcc('\\xe1', '\\xc0', '\\xa0', '\\x80')")
+	       ", width=2158018786, height=2158018787"
+	       ", type=" XLAT_KNOWN(0x1, "V4L2_FRMIVAL_TYPE_DISCRETE")
+	       ", discrete=2158018789/2158018790}) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMEINTERVALS), inject_retval);
+
+	fie->pixel_format = 0x5c22270d;
+
+	for (size_t i = 0; i < ARRAY_SIZE(frmival_step_types); i++) {
+		fie->type = frmival_step_types[i].val;
+
+		ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, fie);
+		printf("ioctl(-1, %s, {index=2158018784, pixel_format="
+		       RAW("0x5c22270d")
+		       NRAW("v4l2_fourcc('\\x0d', '\\\'', '\"', '\\\\')")
+		       ", width=2158018786, height=2158018787, type=%s"
+		       ", stepwise={min=2158018789/2158018790"
+		       ", max=2158018791/2158018792"
+		       ", step=2158018793/2158018794}}) = %ld (INJECTED)\n",
+		       XLAT_STR(VIDIOC_ENUM_FRAMEINTERVALS),
+		       frmival_step_types[i].str, inject_retval);
+	}
+
+	for (size_t i = 0; i < ARRAY_SIZE(frmival_simple_types); i++) {
+		fill_memory32(fie, sizeof(*fie));
+		fie->type = frmival_simple_types[i].val;
+
+		ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, fie);
+		printf("ioctl(-1, %s, {index=2158018784, pixel_format="
+		       RAW("0x80a0c0e1")
+		       NRAW("v4l2_fourcc('\\xe1', '\\xc0', '\\xa0', '\\x80')")
+	               ", width=2158018786, height=2158018787, type=%s})"
+		       " = %ld (INJECTED)\n",
+		       XLAT_STR(VIDIOC_ENUM_FRAMEINTERVALS),
+		       frmival_simple_types[i].str, inject_retval);
+
+	}
+#endif /* HAVE_STRUCT_V4L2_FRMIVALENUM */
+
+
+#ifdef HAVE_STRUCT_V4L2_CREATE_BUFFERS
+	/* VIDIOC_CREATE_BUFS */
+	struct v4l2_create_buffers *cbuf = tail_alloc(sizeof(*cbuf));
+
+	fill_memory32(cbuf, sizeof(*cbuf));
+
+	ioctl(-1, VIDIOC_CREATE_BUFS, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_CREATE_BUFS), inject_retval);
+
+	ioctl(-1, VIDIOC_CREATE_BUFS, (char *) cbuf + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_CREATE_BUFS), (char *) cbuf + 1, inject_retval);
+
+	for (size_t i = 0; i < MAX(ARRAY_SIZE(buf_types),
+				   ARRAY_SIZE(reqb_mems)); i++) {
+		cbuf->memory = reqb_mems[i % ARRAY_SIZE(reqb_mems)].val;
+		cbuf->format.type = buf_types[i % ARRAY_SIZE(buf_types)].val;
+		if (!fill_fmt(&cbuf->format))
+			continue;
+
+		ioctl(-1, VIDIOC_CREATE_BUFS, cbuf);
+		printf("ioctl(-1, %s, {count=2158018785, memory=%s"
+		       ", format={type=%s",
+		       XLAT_STR(VIDIOC_CREATE_BUFS),
+		       reqb_mems[i % ARRAY_SIZE(reqb_mems)].str,
+		       buf_types[i % ARRAY_SIZE(buf_types)].str);
+		print_fmt(", ", &cbuf->format);
+		printf("}}) = %ld ({index=2158018784, count=2158018785})"
+		       " (INJECTED)\n", inject_retval);
+	}
+#endif /* HAVE_STRUCT_V4L2_CREATE_BUFFERS */
+
+	puts("+++ exited with 0 +++");
+
+	return 0;
+}
diff -pruN 5.5-3/tests/ioctl_v4l2-success.gen.test 5.9-0ubuntu2/tests/ioctl_v4l2-success.gen.test
--- 5.5-3/tests/ioctl_v4l2-success.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-success.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-success +ioctl-success.sh -a29); do not edit.
+set -- -a29
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests/ioctl_v4l2-success-v.c 5.9-0ubuntu2/tests/ioctl_v4l2-success-v.c
--- 5.5-3/tests/ioctl_v4l2-success-v.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-success-v.c	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,2 @@
+#define VERBOSE 1
+#include "ioctl_v4l2-success.c"
diff -pruN 5.5-3/tests/ioctl_v4l2-success-v.gen.test 5.9-0ubuntu2/tests/ioctl_v4l2-success-v.gen.test
--- 5.5-3/tests/ioctl_v4l2-success-v.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-success-v.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-success-v +ioctl-success.sh -a29 -v); do not edit.
+set -- -a29 -v
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests/ioctl_v4l2-success-v-Xabbrev.c 5.9-0ubuntu2/tests/ioctl_v4l2-success-v-Xabbrev.c
--- 5.5-3/tests/ioctl_v4l2-success-v-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-success-v-Xabbrev.c	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "ioctl_v4l2-success-v.c"
diff -pruN 5.5-3/tests/ioctl_v4l2-success-v-Xabbrev.gen.test 5.9-0ubuntu2/tests/ioctl_v4l2-success-v-Xabbrev.gen.test
--- 5.5-3/tests/ioctl_v4l2-success-v-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-success-v-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-success-v-Xabbrev +ioctl-success.sh -a29 -v -Xabbrev); do not edit.
+set -- -a29 -v -Xabbrev
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests/ioctl_v4l2-success-v-Xraw.c 5.9-0ubuntu2/tests/ioctl_v4l2-success-v-Xraw.c
--- 5.5-3/tests/ioctl_v4l2-success-v-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-success-v-Xraw.c	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "ioctl_v4l2-success-v.c"
diff -pruN 5.5-3/tests/ioctl_v4l2-success-v-Xraw.gen.test 5.9-0ubuntu2/tests/ioctl_v4l2-success-v-Xraw.gen.test
--- 5.5-3/tests/ioctl_v4l2-success-v-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-success-v-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-success-v-Xraw +ioctl-success.sh -a27 -v -Xraw); do not edit.
+set -- -a27 -v -Xraw
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests/ioctl_v4l2-success-v-Xverbose.c 5.9-0ubuntu2/tests/ioctl_v4l2-success-v-Xverbose.c
--- 5.5-3/tests/ioctl_v4l2-success-v-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-success-v-Xverbose.c	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "ioctl_v4l2-success-v.c"
diff -pruN 5.5-3/tests/ioctl_v4l2-success-v-Xverbose.gen.test 5.9-0ubuntu2/tests/ioctl_v4l2-success-v-Xverbose.gen.test
--- 5.5-3/tests/ioctl_v4l2-success-v-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-success-v-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-success-v-Xverbose +ioctl-success.sh -a29 -v -Xverbose); do not edit.
+set -- -a29 -v -Xverbose
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests/ioctl_v4l2-success-Xabbrev.c 5.9-0ubuntu2/tests/ioctl_v4l2-success-Xabbrev.c
--- 5.5-3/tests/ioctl_v4l2-success-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-success-Xabbrev.c	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "ioctl_v4l2-success.c"
diff -pruN 5.5-3/tests/ioctl_v4l2-success-Xabbrev.gen.test 5.9-0ubuntu2/tests/ioctl_v4l2-success-Xabbrev.gen.test
--- 5.5-3/tests/ioctl_v4l2-success-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-success-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-success-Xabbrev +ioctl-success.sh -a29 -Xabbrev); do not edit.
+set -- -a29 -Xabbrev
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests/ioctl_v4l2-success-Xraw.c 5.9-0ubuntu2/tests/ioctl_v4l2-success-Xraw.c
--- 5.5-3/tests/ioctl_v4l2-success-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-success-Xraw.c	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "ioctl_v4l2-success.c"
diff -pruN 5.5-3/tests/ioctl_v4l2-success-Xraw.gen.test 5.9-0ubuntu2/tests/ioctl_v4l2-success-Xraw.gen.test
--- 5.5-3/tests/ioctl_v4l2-success-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-success-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-success-Xraw +ioctl-success.sh -a27 -Xraw); do not edit.
+set -- -a27 -Xraw
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests/ioctl_v4l2-success-Xverbose.c 5.9-0ubuntu2/tests/ioctl_v4l2-success-Xverbose.c
--- 5.5-3/tests/ioctl_v4l2-success-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-success-Xverbose.c	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "ioctl_v4l2-success.c"
diff -pruN 5.5-3/tests/ioctl_v4l2-success-Xverbose.gen.test 5.9-0ubuntu2/tests/ioctl_v4l2-success-Xverbose.gen.test
--- 5.5-3/tests/ioctl_v4l2-success-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-success-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-success-Xverbose +ioctl-success.sh -a30 -Xverbose); do not edit.
+set -- -a30 -Xverbose
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests/ioctl_v4l2-v.c 5.9-0ubuntu2/tests/ioctl_v4l2-v.c
--- 5.5-3/tests/ioctl_v4l2-v.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-v.c	2020-03-28 16:57:34.000000000 +0000
@@ -0,0 +1,3 @@
+/* This file is part of ioctl_v4l2-v strace test. */
+#define VERBOSE 1
+#include "ioctl_v4l2.c"
diff -pruN 5.5-3/tests/ioctl_v4l2-v.gen.test 5.9-0ubuntu2/tests/ioctl_v4l2-v.gen.test
--- 5.5-3/tests/ioctl_v4l2-v.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-v.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-v +ioctl.test -v); do not edit.
+set -- -v
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests/ioctl_v4l2-v-Xabbrev.c 5.9-0ubuntu2/tests/ioctl_v4l2-v-Xabbrev.c
--- 5.5-3/tests/ioctl_v4l2-v-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-v-Xabbrev.c	2020-03-28 16:57:34.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "ioctl_v4l2-v.c"
diff -pruN 5.5-3/tests/ioctl_v4l2-v-Xabbrev.gen.test 5.9-0ubuntu2/tests/ioctl_v4l2-v-Xabbrev.gen.test
--- 5.5-3/tests/ioctl_v4l2-v-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-v-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-v-Xabbrev +ioctl.test -v -Xabbrev); do not edit.
+set -- -v -Xabbrev
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests/ioctl_v4l2-v-Xraw.c 5.9-0ubuntu2/tests/ioctl_v4l2-v-Xraw.c
--- 5.5-3/tests/ioctl_v4l2-v-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-v-Xraw.c	2020-03-28 16:57:34.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "ioctl_v4l2-v.c"
diff -pruN 5.5-3/tests/ioctl_v4l2-v-Xraw.gen.test 5.9-0ubuntu2/tests/ioctl_v4l2-v-Xraw.gen.test
--- 5.5-3/tests/ioctl_v4l2-v-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-v-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-v-Xraw +ioctl.test -v -Xraw); do not edit.
+set -- -v -Xraw
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests/ioctl_v4l2-v-Xverbose.c 5.9-0ubuntu2/tests/ioctl_v4l2-v-Xverbose.c
--- 5.5-3/tests/ioctl_v4l2-v-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-v-Xverbose.c	2020-03-28 16:57:34.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "ioctl_v4l2-v.c"
diff -pruN 5.5-3/tests/ioctl_v4l2-v-Xverbose.gen.test 5.9-0ubuntu2/tests/ioctl_v4l2-v-Xverbose.gen.test
--- 5.5-3/tests/ioctl_v4l2-v-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-v-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-v-Xverbose +ioctl.test -v -Xverbose); do not edit.
+set -- -v -Xverbose
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests/ioctl_v4l2-Xabbrev.c 5.9-0ubuntu2/tests/ioctl_v4l2-Xabbrev.c
--- 5.5-3/tests/ioctl_v4l2-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-Xabbrev.c	2020-03-28 16:57:34.000000000 +0000
@@ -0,0 +1 @@
+#include "ioctl_v4l2.c"
diff -pruN 5.5-3/tests/ioctl_v4l2-Xabbrev.gen.test 5.9-0ubuntu2/tests/ioctl_v4l2-Xabbrev.gen.test
--- 5.5-3/tests/ioctl_v4l2-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-Xabbrev +ioctl.test -Xabbrev); do not edit.
+set -- -Xabbrev
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests/ioctl_v4l2-Xraw.c 5.9-0ubuntu2/tests/ioctl_v4l2-Xraw.c
--- 5.5-3/tests/ioctl_v4l2-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-Xraw.c	2020-03-28 16:57:34.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "ioctl_v4l2.c"
diff -pruN 5.5-3/tests/ioctl_v4l2-Xraw.gen.test 5.9-0ubuntu2/tests/ioctl_v4l2-Xraw.gen.test
--- 5.5-3/tests/ioctl_v4l2-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-Xraw +ioctl.test -Xraw); do not edit.
+set -- -Xraw
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests/ioctl_v4l2-Xverbose.c 5.9-0ubuntu2/tests/ioctl_v4l2-Xverbose.c
--- 5.5-3/tests/ioctl_v4l2-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-Xverbose.c	2020-03-28 16:57:34.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "ioctl_v4l2.c"
diff -pruN 5.5-3/tests/ioctl_v4l2-Xverbose.gen.test 5.9-0ubuntu2/tests/ioctl_v4l2-Xverbose.gen.test
--- 5.5-3/tests/ioctl_v4l2-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioctl_v4l2-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-Xverbose +ioctl.test -Xverbose); do not edit.
+set -- -Xverbose
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests/ioprio.c 5.9-0ubuntu2/tests/ioprio.c
--- 5.5-3/tests/ioprio.c	2019-09-24 15:31:28.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioprio.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,15 +2,15 @@
  * Check decoding of ioprio_get and ioprio_set syscalls.
  *
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-
 #include "scno.h"
+#include "pidns.h"
 
 #if defined(__NR_ioprio_get) && defined(__NR_ioprio_set)
 
@@ -30,12 +30,18 @@ enum {
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	static const kernel_ulong_t bogus_which =
 		(kernel_ulong_t) 0xdeadfacefa57beefULL;
 	static const kernel_ulong_t bogus_who =
 		(kernel_ulong_t) 0xbadc0dedda7a1057ULL;
 	static const kernel_ulong_t bogus_ioprio =
 		(kernel_ulong_t) 0xdec0ded1facefeedULL;
+
+	const int pid = getpid();
+	const int pgid = getpgid(0);
+
 # if !XLAT_RAW
 	static const char * const bogus_ioprio_str =
 		"IOPRIO_PRIO_VALUE(0x7d677 /* IOPRIO_CLASS_??? */, 7917)";
@@ -46,6 +52,7 @@ main(void)
 
 	rc = syscall(__NR_ioprio_get, bogus_which, bogus_who);
 	errstr = sprintrc(rc);
+	pidns_print_leader();
 # if XLAT_RAW
 	printf("ioprio_get(%#x, %d) = %s\n",
 	       (int) bogus_which, (int) bogus_who, errstr);
@@ -54,42 +61,52 @@ main(void)
 	       (int) bogus_which, (int) bogus_who, errstr);
 # endif
 
-	rc = syscall(__NR_ioprio_get, 1, 0);
+	rc = syscall(__NR_ioprio_get, 1, pid);
 	errstr = sprintrc(rc);
+	pidns_print_leader();
+	printf("ioprio_get(");
 # if XLAT_RAW
-	printf("ioprio_get(0x1, 0) = %s\n", errstr);
+	printf("0x1, ");
+# elif XLAT_VERBOSE
+	printf("0x1 /* IOPRIO_WHO_PROCESS */, ");
 # else /* XLAT_ABBREV */
-#  if XLAT_VERBOSE
-	printf("ioprio_get(0x1 /* IOPRIO_WHO_PROCESS */, 0) = %s", errstr);
-#  else
-	printf("ioprio_get(IOPRIO_WHO_PROCESS, 0) = %s", errstr);
-#  endif
+	printf("IOPRIO_WHO_PROCESS, ");
+# endif
+	printf("%d%s) = %s", pid, pidns_pid2str(PT_TGID), errstr);
+# if !XLAT_RAW
 	if (rc >= 0) {
 		printf(" (IOPRIO_PRIO_VALUE(");
 		printxval(ioprio_class, (unsigned int) rc >> 13,
 			  "IOPRIO_CLASS_???");
 		printf(", %u))", (unsigned int) rc & 0x1fff);
 	}
-	puts("");
 # endif
+	puts("");
 
-	rc = syscall(__NR_ioprio_set, 2, 0, 8191);
+	rc = syscall(__NR_ioprio_set, 2, pgid, 8191);
 	errstr = sprintrc(rc);
+	pidns_print_leader();
+	printf("ioprio_set(");
 # if XLAT_RAW
-	printf("ioprio_set(%#x, 0, 8191) = %s\n", 2, errstr);
+	printf("%#x", 2);
 # elif XLAT_VERBOSE
-	printf("ioprio_set(%#x /* IOPRIO_WHO_PGRP */, 0, 8191"
-	       " /* IOPRIO_PRIO_VALUE(0 /* IOPRIO_CLASS_NONE */, 8191) */)"
-	       " = %s\n",
-	       2, errstr);
+	printf("%#x /* IOPRIO_WHO_PGRP */", 2);
 # else /* XLAT_ABBREV */
-	printf("ioprio_set(IOPRIO_WHO_PGRP, 0"
-	       ", IOPRIO_PRIO_VALUE(IOPRIO_CLASS_NONE, 8191)) = %s\n",
-	       errstr);
+	printf("IOPRIO_WHO_PGRP");
+# endif
+	printf(", %d%s", pgid, pidns_pid2str(PT_PGID));
+# if XLAT_RAW
+	printf(", 8191)");
+# elif XLAT_VERBOSE
+	printf(", 8191 /* IOPRIO_PRIO_VALUE(0 /* IOPRIO_CLASS_NONE */, 8191) */)");
+# else /* XLAT_ABBREV */
+	printf(", IOPRIO_PRIO_VALUE(IOPRIO_CLASS_NONE, 8191))");
 # endif
+	printf(" = %s\n", errstr);
 
 	rc = syscall(__NR_ioprio_set, bogus_which, bogus_who, bogus_ioprio);
 	errstr = sprintrc(rc);
+	pidns_print_leader();
 # if XLAT_RAW
 	printf("ioprio_set(%#x, %d, %d) = %s\n",
 	       (int) bogus_which, (int) bogus_who, (int) bogus_ioprio,
@@ -104,6 +121,7 @@ main(void)
 	       errstr);
 # endif
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 
 	return 0;
diff -pruN 5.5-3/tests/ioprio--pidns-translation.c 5.9-0ubuntu2/tests/ioprio--pidns-translation.c
--- 5.5-3/tests/ioprio--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioprio--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "ioprio.c"
diff -pruN 5.5-3/tests/ioprio--pidns-translation.gen.test 5.9-0ubuntu2/tests/ioprio--pidns-translation.gen.test
--- 5.5-3/tests/ioprio--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ioprio--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioprio--pidns-translation test_pidns -a18 -e trace=ioprio_get,ioprio_set); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a18 -e trace=ioprio_get,ioprio_set
diff -pruN 5.5-3/tests/io_uring_register.c 5.9-0ubuntu2/tests/io_uring_register.c
--- 5.5-3/tests/io_uring_register.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests/io_uring_register.c	2020-06-28 08:00:00.000000000 +0000
@@ -25,16 +25,21 @@
 # endif
 
 /* From tests/bpf.c */
-#if defined MPERS_IS_m32 || SIZEOF_KERNEL_LONG_T > 4
-# define BIG_ADDR_MAYBE(addr_)
-#elif defined __arm__ || defined __i386__ || defined __mips__ \
+# if defined MPERS_IS_m32 || SIZEOF_KERNEL_LONG_T > 4
+#  define BIG_ADDR_MAYBE(addr_)
+# elif defined __arm__ || defined __i386__ || defined __mips__ \
    || defined __powerpc__ || defined __riscv__ || defined __s390__ \
    || defined __sparc__ || defined __tile__
-# define BIG_ADDR_MAYBE(addr_) addr_ " or "
-#else
-# define BIG_ADDR_MAYBE(addr_)
-#endif
+#  define BIG_ADDR_MAYBE(addr_) addr_ " or "
+# else
+#  define BIG_ADDR_MAYBE(addr_)
+# endif
 
+# if WORDS_BIGENDIAN
+#  define BE_LE(be_, le_) be_
+# else
+#  define BE_LE(be_, le_) le_
+# endif
 
 static const char *errstr;
 
@@ -81,12 +86,12 @@ main(void)
 
 	int fd_full = open(path_full, O_RDONLY);
 	if (fd_full < 0)
-		perror_msg_and_fail("open: %s", path_null);
+		perror_msg_and_fail("open: %s", path_full);
 
 	int fds[] = { fd_full, fd_null };
 	const int *arg_fds = tail_memdup(fds, sizeof(fds));
 
-	static const unsigned int invalid_ops[] = { 0xbadc0dedU, 7 };
+	static const unsigned int invalid_ops[] = { 0xbadc0dedU, 11 };
 
 	for (size_t i = 0; i < ARRAY_SIZE(invalid_ops); i++) {
 		sys_io_uring_register(fd_null, invalid_ops[i], path_null,
@@ -104,6 +109,8 @@ main(void)
 		{ 1, "IORING_UNREGISTER_BUFFERS" },
 		{ 3, "IORING_UNREGISTER_FILES" },
 		{ 5, "IORING_UNREGISTER_EVENTFD" },
+		{ 9, "IORING_REGISTER_PERSONALITY" },
+		{ 10, "IORING_UNREGISTER_PERSONALITY" },
 	};
 
 	for (size_t i = 0; i < ARRAY_SIZE(no_arg_ops); i++) {
@@ -129,6 +136,7 @@ main(void)
 	} fd_arr_ops[] = {
 		{ 2, "IORING_REGISTER_FILES" },
 		{ 4, "IORING_REGISTER_EVENTFD" },
+		{ 7, "IORING_REGISTER_EVENTFD_ASYNC" },
 	};
 
 	for (size_t i = 0; i < ARRAY_SIZE(fd_arr_ops); i++) {
@@ -141,7 +149,7 @@ main(void)
 		       (unsigned int) ARRAY_SIZE(fds), errstr);
 	}
 
-#ifdef HAVE_STRUCT_IO_URING_FILES_UPDATE
+# ifdef HAVE_STRUCT_IO_URING_FILES_UPDATE
 	struct io_uring_files_update bogus_iufu;
 	struct io_uring_files_update iufu;
 
@@ -154,7 +162,8 @@ main(void)
 	sys_io_uring_register(fd_null, 6, &bogus_iufu, 0);
 	printf("io_uring_register(%u<%s>, IORING_REGISTER_FILES_UPDATE"
 	       ", {offset=%" PRIu32 ", resv=%#" PRIx32 ", fds="
-	       BIG_ADDR_MAYBE("0x8f8e8d8c8b8a8988") "[]}, 0) = %s\n",
+	       BIG_ADDR_MAYBE(BE_LE("0x88898a8b8c8d8e8f", "0x8f8e8d8c8b8a8988"))
+	       "[]}, 0) = %s\n",
 	       fd_null, path_null,
 	       ((uint32_t *) &bogus_iufu)[0], ((uint32_t *) &bogus_iufu)[1],
 	       errstr);
@@ -167,7 +176,111 @@ main(void)
 	       ", {offset=3735929054, fds=[%u<%s>, %u<%s>]}, %u) = %s\n",
 	       fd_null, path_null, fd_full, path_full, fd_null, path_null,
 	       (unsigned int) ARRAY_SIZE(fds), errstr);
-#endif
+# endif
+
+# ifdef HAVE_STRUCT_IO_URING_PROBE
+	struct io_uring_probe *probe = tail_alloc(sizeof(*probe) +
+		       (DEFAULT_STRLEN + 1) * sizeof(struct io_uring_probe_op));
+
+	sys_io_uring_register(fd_null, IORING_REGISTER_PROBE, NULL, 0xfacefeed);
+	printf("io_uring_register(%u<%s>, IORING_REGISTER_PROBE"
+	       ", NULL, 4207869677) = %s\n",
+	       fd_null, path_null, errstr);
+
+	sys_io_uring_register(fd_null, IORING_REGISTER_PROBE, probe,
+			      0xfacefeed);
+	printf("io_uring_register(%u<%s>, IORING_REGISTER_PROBE"
+	       ", %p, 4207869677) = %s\n",
+	       fd_null, path_null, probe, errstr);
+
+	sys_io_uring_register(fd_null, IORING_REGISTER_PROBE,
+			      (char *) probe + 1, DEFAULT_STRLEN + 1);
+	printf("io_uring_register(%u<%s>, IORING_REGISTER_PROBE"
+	       ", %p, %d) = %s\n",
+	       fd_null, path_null, (char *) probe + 1, DEFAULT_STRLEN + 1,
+	       errstr);
+
+	sys_io_uring_register(fd_null, IORING_REGISTER_PROBE, probe, 0);
+	printf("io_uring_register(%u<%s>, IORING_REGISTER_PROBE"
+	       ", {last_op=%u /* IORING_OP_??? */, ops_len=%hhu, resv=%#hx"
+	       ", resv2=[%#x, %#x, %#x], ops=[]}, 0) = %s\n",
+	       fd_null, path_null, probe->last_op, probe->ops_len, probe->resv,
+	       probe->resv2[0], probe->resv2[1], probe->resv2[2], errstr);
+
+	probe->last_op = IORING_OP_READV;
+	probe->resv = 0;
+	sys_io_uring_register(fd_null, IORING_REGISTER_PROBE, probe, 0);
+	printf("io_uring_register(%u<%s>, IORING_REGISTER_PROBE"
+	       ", {last_op=IORING_OP_READV, ops_len=%hhu"
+	       ", resv2=[%#x, %#x, %#x], ops=[]}, 0) = %s\n",
+	       fd_null, path_null, probe->ops_len,
+	       probe->resv2[0], probe->resv2[1], probe->resv2[2], errstr);
+
+	probe->last_op = IORING_OP_EPOLL_CTL;
+	probe->resv2[0] = 0;
+	probe->resv2[2] = 0;
+
+	probe->ops[0].op = IORING_OP_NOP;
+	probe->ops[0].resv = 0xde;
+	probe->ops[0].flags = 0;
+	probe->ops[0].resv2 = 0xbeefface;
+
+	probe->ops[1].op = 33;
+	probe->ops[1].resv = 0;
+	probe->ops[1].flags = IO_URING_OP_SUPPORTED;
+	probe->ops[1].resv2 = 0xdeadc0de;
+
+	probe->ops[2].op = 34;
+	probe->ops[2].resv = 0xaf;
+	probe->ops[2].flags = 0xbeef;
+	probe->ops[2].resv2 = 0;
+
+	probe->ops[3].op = 0xfe;
+	probe->ops[3].resv = 0;
+	probe->ops[3].flags = 0xc0de;
+	probe->ops[3].resv2 = 0;
+
+	sys_io_uring_register(fd_null, IORING_REGISTER_PROBE, probe, 4);
+	printf("io_uring_register(%u<%s>, IORING_REGISTER_PROBE"
+	       ", {last_op=IORING_OP_EPOLL_CTL, ops_len=%hhu"
+	       ", resv2=[0, %#x, 0], ops=["
+	       "{op=IORING_OP_NOP, resv=0xde, flags=0, resv2=0xbeefface}, "
+	       "{op=IORING_OP_TEE, flags=IO_URING_OP_SUPPORTED"
+	       ", resv2=0xdeadc0de}, "
+	       "{op=34 /* IORING_OP_??? */, resv=0xaf"
+	       ", flags=IO_URING_OP_SUPPORTED|0xbeee}, "
+	       "{op=254 /* IORING_OP_??? */"
+	       ", flags=0xc0de /* IO_URING_OP_??? */}]}, 4) = %s\n",
+	       fd_null, path_null, probe->ops_len, probe->resv2[1], errstr);
+
+	probe->last_op = 34;
+	probe->resv2[1] = 0;
+	fill_memory_ex(probe->ops, sizeof(probe->ops[0]) * (DEFAULT_STRLEN + 1),
+		    0x40, 0x80);
+	sys_io_uring_register(fd_null, IORING_REGISTER_PROBE, probe,
+			      DEFAULT_STRLEN + 1);
+	printf("io_uring_register(%u<%s>, IORING_REGISTER_PROBE"
+	       ", {last_op=34 /* IORING_OP_??? */, ops_len=%hhu, ops=[",
+	       fd_null, path_null, probe->ops_len);
+	for (size_t i = 0; i < DEFAULT_STRLEN; i++) {
+		printf("%s{op=%u /* IORING_OP_??? */, resv=%#hhx"
+		       ", flags=%s%#hx%s, resv2=%#x}",
+		       i ? ", " : "",
+		       probe->ops[i].op, probe->ops[i].resv,
+		       probe->ops[i].flags & 1 ? "IO_URING_OP_SUPPORTED|" : "",
+		       (typeof(probe->ops[i].flags)) (probe->ops[i].flags & ~1),
+		       probe->ops[i].flags & 1 ? "" : " /* IO_URING_OP_??? */",
+		       probe->ops[i].resv2);
+	}
+	printf(", ...]}, %d) = %s\n", DEFAULT_STRLEN + 1, errstr);
+
+	probe->last_op = 0;
+	probe->ops_len = 0;
+	memset(probe->ops, 0, sizeof(probe->ops[0]) * (DEFAULT_STRLEN + 1));
+	sys_io_uring_register(fd_null, IORING_REGISTER_PROBE, probe, 8);
+	printf("io_uring_register(%u<%s>, IORING_REGISTER_PROBE, %p, 8) = %s\n",
+	       fd_null, path_null, probe, errstr);
+# endif
 
 	puts("+++ exited with 0 +++");
 	return 0;
diff -pruN 5.5-3/tests/io_uring_setup.c 5.9-0ubuntu2/tests/io_uring_setup.c
--- 5.5-3/tests/io_uring_setup.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests/io_uring_setup.c	2020-09-23 16:29:35.000000000 +0000
@@ -27,6 +27,7 @@
 # include "xlat.h"
 
 # include "xlat/uring_setup_features.h"
+# include "xlat/uring_cqring_flags.h"
 
 # ifdef HAVE_STRUCT_IO_URING_PARAMS_FEATURES
 #  ifdef HAVE_STRUCT_IO_URING_PARAMS_WQ_FD
@@ -144,20 +145,40 @@ main(void)
 						params->sq_off.resv2);
 
 			printf("}, cq_off={head=%u, tail=%u, ring_mask=%u"
-			       ", ring_entries=%u, overflow=%u, cqes=%u",
+			       ", ring_entries=%u, overflow=%u, cqes=%u, flags=",
 			       params->cq_off.head,
 			       params->cq_off.tail,
 			       params->cq_off.ring_mask,
 			       params->cq_off.ring_entries,
 			       params->cq_off.overflow,
 			       params->cq_off.cqes);
-			if (params->cq_off.resv[0] || params->cq_off.resv[1]) {
-				printf(", resv=[%#llx, %#llx]",
+# ifdef HAVE_STRUCT_IO_CQRING_OFFSETS_FLAGS
+			printflags(uring_cqring_flags,
+			       params->cq_off.flags,
+			       "IORING_CQ_???");
+			if (params->cq_off.resv1)
+				printf(", resv1=%#x", params->cq_off.resv1);
+			if (params->cq_off.resv2)
+				printf(", resv2=%#llx",
 				       (unsigned long long)
-						params->cq_off.resv[0],
+						params->cq_off.resv2);
+# else
+			union {
+				struct {
+					uint32_t flags;
+					uint32_t resv1;
+				} s;
+				uint64_t v;
+			} u = { .v = params->cq_off.resv[0] };
+			printflags(uring_cqring_flags, u.s.flags,
+				   "IORING_CQ_???");
+			if (u.s.resv1)
+				printf(", resv1=%#x", u.s.resv1);
+			if (params->cq_off.resv[1])
+				printf(", resv2=%#llx",
 				       (unsigned long long)
 						params->cq_off.resv[1]);
-			}
+# endif
 
 			printf("}}) = %ld<anon_inode:[io_uring]>\n", rc);
 		}
diff -pruN 5.5-3/tests/ipc_msg.c 5.9-0ubuntu2/tests/ipc_msg.c
--- 5.5-3/tests/ipc_msg.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/ipc_msg.c	2020-09-19 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2015 Elvira Khabirova <lineprinter0@gmail.com>
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -20,18 +20,24 @@
 # define MSG_STAT_ANY 13
 #endif
 
+#undef TEST_MSGCTL_BOGUS_ADDR
+
+/*
+ * Starting with commit glibc-2.32~83, on every 32-bit architecture
+ * where 32-bit time_t support is enabled, glibc tries to retrieve
+ * the data provided in the third argument of msgctl call.
+ */
+#if GLIBC_PREREQ_GE(2, 32) && defined __TIMESIZE && __TIMESIZE != 64
+# define TEST_MSGCTL_BOGUS_ADDR 0
+#endif
 /*
  * Before glibc-2.22-122-gbe48165, ppc64 code tried to retrieve data
  * provided in third argument of msgctl call (in case of IPC_SET cmd)
  * which led to segmentation fault.
  */
-#undef TEST_MSGCTL_BOGUS_ADDR
-#if defined __GLIBC__ && (defined POWERPC64 || defined POWERPC64LE)
-# if !(defined __GLIBC_MINOR__) \
-   || ((__GLIBC__ << 16) + __GLIBC_MINOR__ < (2 << 16) + 23)
-#  define TEST_MSGCTL_BOGUS_ADDR 0
-# endif
-#endif /* __GLIBC__ && (POWERPC64 || POWERPC64LE) */
+#if GLIBC_PREREQ_LT(2, 23) && (defined POWERPC64 || defined POWERPC64LE)
+# define TEST_MSGCTL_BOGUS_ADDR 0
+#endif
 
 #ifndef TEST_MSGCTL_BOGUS_ADDR
 # define TEST_MSGCTL_BOGUS_ADDR 1
@@ -43,6 +49,7 @@
 # define str_ipc_rmid "0"
 # define str_ipc_set "0x1"
 # define str_ipc_stat "0x2"
+# define str_ipc_info "0x3"
 # define str_msg_stat "0xb"
 # define str_msg_info "0xc"
 # define str_msg_stat_any "0xd"
@@ -55,6 +62,7 @@
 # define str_ipc_rmid "0 /\\* IPC_RMID \\*/"
 # define str_ipc_set "0x1 /\\* IPC_SET \\*/"
 # define str_ipc_stat "0x2 /\\* IPC_STAT \\*/"
+# define str_ipc_info "0x3 /\\* IPC_INFO \\*/"
 # define str_msg_stat "0xb /\\* MSG_STAT \\*/"
 # define str_msg_info "0xc /\\* MSG_INFO \\*/"
 # define str_msg_stat_any "0xd /\\* MSG_STAT_ANY \\*/"
@@ -66,6 +74,7 @@
 # define str_ipc_rmid "IPC_RMID"
 # define str_ipc_set "IPC_SET"
 # define str_ipc_stat "IPC_STAT"
+# define str_ipc_info "IPC_INFO"
 # define str_msg_stat "MSG_STAT"
 # define str_msg_info "MSG_INFO"
 # define str_msg_stat_any "MSG_STAT_ANY"
@@ -84,6 +93,68 @@ cleanup(void)
 	id = -1;
 }
 
+static void
+print_msginfo(const char *const str_ipc_cmd,
+	      const struct msginfo *const info,
+	      const int rc)
+{
+	if (rc < 0) {
+		printf("msgctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
+		       id, str_ipc_64, str_ipc_cmd, info, sprintrc_grep(rc));
+		return;
+	}
+
+	printf("msgctl\\(%d, (%s\\|)?%s, \\{msgpool=%d, msgmap=%d, msgmax=%d"
+	       ", msgmnb=%d, msgmni=%d, msgssz=%d, msgtql=%d, msgseg=%u\\}\\)"
+	       " = %d\n",
+	       id,
+	       str_ipc_64,
+	       str_ipc_cmd,
+	       info->msgpool,
+	       info->msgmap,
+	       info->msgmax,
+	       info->msgmnb,
+	       info->msgmni,
+	       info->msgssz,
+	       info->msgtql,
+	       (unsigned) info->msgseg,
+	       rc);
+}
+
+static void
+print_msqid_ds(const char *const str_ipc_cmd,
+	       const struct msqid_ds *const ds,
+	       const int rc)
+{
+	if (rc < 0) {
+		printf("msgctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
+		       id, str_ipc_64, str_ipc_cmd, ds, sprintrc_grep(rc));
+		return;
+	}
+
+	printf("msgctl\\(%d, (%s\\|)?%s, \\{msg_perm=\\{uid=%u"
+	       ", gid=%u, mode=%#o, key=%u, cuid=%u, cgid=%u\\}"
+	       ", msg_stime=%u, msg_rtime=%u, msg_ctime=%u, msg_qnum=%u"
+	       ", msg_qbytes=%u, msg_lspid=%d, msg_lrpid=%d\\}\\) = %d\n",
+	       id,
+	       str_ipc_64,
+	       str_ipc_cmd,
+	       (unsigned) ds->msg_perm.uid,
+	       (unsigned) ds->msg_perm.gid,
+	       (unsigned) ds->msg_perm.mode,
+	       (unsigned) ds->msg_perm.__key,
+	       (unsigned) ds->msg_perm.cuid,
+	       (unsigned) ds->msg_perm.cgid,
+	       (unsigned) ds->msg_stime,
+	       (unsigned) ds->msg_rtime,
+	       (unsigned) ds->msg_ctime,
+	       (unsigned) ds->msg_qnum,
+	       (unsigned) ds->msg_qbytes,
+	       (int) ds->msg_lspid,
+	       (int) ds->msg_lrpid,
+	       rc);
+}
+
 int
 main(void)
 {
@@ -98,7 +169,10 @@ main(void)
 	static const int bogus_flags = 0xface1e55 & ~IPC_CREAT;
 
 	int rc;
-	struct msqid_ds ds;
+	union {
+		struct msqid_ds ds;
+		struct msginfo info;
+	} buf;
 
 	rc = msgget(bogus_key, bogus_flags);
 	printf("msgget\\(%#llx, %s\\|%#04o\\) = %s\n",
@@ -123,39 +197,32 @@ main(void)
 	       sprintrc_grep(rc));
 #endif
 
-	if (msgctl(id, IPC_STAT, &ds))
+	rc = msgctl(id, IPC_STAT, &buf.ds);
+	if (rc < 0)
 		perror_msg_and_skip("msgctl IPC_STAT");
-	printf("msgctl\\(%d, (%s\\|)?%s, \\{msg_perm=\\{uid=%u"
-	       ", gid=%u, mode=%#o, key=%u, cuid=%u, cgid=%u\\}, msg_stime=%u"
-	       ", msg_rtime=%u, msg_ctime=%u, msg_qnum=%u, msg_qbytes=%u"
-	       ", msg_lspid=%u, msg_lrpid=%u\\}\\) = 0\n",
-	       id, str_ipc_64, str_ipc_stat,
-	       (unsigned) ds.msg_perm.uid, (unsigned) ds.msg_perm.gid,
-	       (unsigned) ds.msg_perm.mode, (unsigned) ds.msg_perm.__key,
-	       (unsigned) ds.msg_perm.cuid, (unsigned) ds.msg_perm.cgid,
-	       (unsigned) ds.msg_stime, (unsigned) ds.msg_rtime,
-	       (unsigned) ds.msg_ctime, (unsigned) ds.msg_qnum,
-	       (unsigned) ds.msg_qbytes, (unsigned) ds.msg_lspid,
-	       (unsigned) ds.msg_lrpid);
+	print_msqid_ds(str_ipc_stat, &buf.ds, rc);
 
-	if (msgctl(id, IPC_SET, &ds))
+	if (msgctl(id, IPC_SET, &buf.ds))
 		perror_msg_and_skip("msgctl IPC_SET");
 	printf("msgctl\\(%d, (%s\\|)?%s, \\{msg_perm=\\{uid=%u"
-	       ", gid=%u, mode=%#o\\}, ...\\}\\) = 0\n",
-	       id, str_ipc_64, str_ipc_set, (unsigned) ds.msg_perm.uid,
-	       (unsigned) ds.msg_perm.gid, (unsigned) ds.msg_perm.mode);
-
-	rc = msgctl(0, MSG_INFO, &ds);
-	printf("msgctl\\(0, (%s\\|)?%s, %p\\) = %s\n",
-	       str_ipc_64, str_msg_info, &ds, sprintrc_grep(rc));
+	       ", gid=%u, mode=%#o\\}, msg_qbytes=%u\\}\\) = 0\n",
+	       id, str_ipc_64, str_ipc_set,
+	       (unsigned) buf.ds.msg_perm.uid,
+	       (unsigned) buf.ds.msg_perm.gid,
+	       (unsigned) buf.ds.msg_perm.mode,
+	       (unsigned) buf.ds.msg_qbytes);
+
+	rc = msgctl(id, IPC_INFO, &buf.ds);
+	print_msginfo(str_ipc_info, &buf.info, rc);
 
-	rc = msgctl(id, MSG_STAT, &ds);
-	printf("msgctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
-	       id, str_ipc_64, str_msg_stat, &ds, sprintrc_grep(rc));
+	rc = msgctl(id, MSG_INFO, &buf.ds);
+	print_msginfo(str_msg_info, &buf.info, rc);
 
-	rc = msgctl(id, MSG_STAT_ANY, &ds);
-	printf("msgctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
-	       id, str_ipc_64, str_msg_stat_any, &ds, sprintrc_grep(rc));
+	rc = msgctl(id, MSG_STAT, &buf.ds);
+	print_msqid_ds(str_msg_stat, &buf.ds, rc);
+
+	rc = msgctl(id, MSG_STAT_ANY, &buf.ds);
+	print_msqid_ds(str_msg_stat_any, &buf.ds, rc);
 
 	return 0;
 }
diff -pruN 5.5-3/tests/ipc_sem.c 5.9-0ubuntu2/tests/ipc_sem.c
--- 5.5-3/tests/ipc_sem.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/ipc_sem.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2015 Andreas Schwab <schwab@suse.de>
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -11,6 +11,7 @@
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <sys/sem.h>
 
 #include "xlat.h"
@@ -24,7 +25,9 @@
 # define str_ipc_flags "0xface1e00"
 # define str_ipc_private "0"
 # define str_ipc_rmid "0"
+# define str_ipc_set "0x1"
 # define str_ipc_stat "0x2"
+# define str_ipc_info "0x3"
 # define str_sem_stat "0x12"
 # define str_sem_info "0x13"
 # define str_sem_stat_any "0x14"
@@ -35,7 +38,9 @@
 	"0xface1e00 /\\* IPC_CREAT\\|IPC_EXCL\\|IPC_NOWAIT\\|0xface1000 \\*/"
 # define str_ipc_private "0 /\\* IPC_PRIVATE \\*/"
 # define str_ipc_rmid "0 /\\* IPC_RMID \\*/"
+# define str_ipc_set "0x1 /\\* IPC_SET \\*/"
 # define str_ipc_stat "0x2 /\\* IPC_STAT \\*/"
+# define str_ipc_info "0x3 /\\* IPC_INFO \\*/"
 # define str_sem_stat "0x12 /\\* SEM_STAT \\*/"
 # define str_sem_info "0x13 /\\* SEM_INFO \\*/"
 # define str_sem_stat_any "0x14 /\\* SEM_STAT_ANY \\*/"
@@ -45,7 +50,9 @@
 # define str_ipc_flags "IPC_CREAT\\|IPC_EXCL\\|IPC_NOWAIT\\|0xface1000"
 # define str_ipc_private "IPC_PRIVATE"
 # define str_ipc_rmid "IPC_RMID"
+# define str_ipc_set "IPC_SET"
 # define str_ipc_stat "IPC_STAT"
+# define str_ipc_info "IPC_INFO"
 # define str_sem_stat "SEM_STAT"
 # define str_sem_info "SEM_INFO"
 # define str_sem_stat_any "SEM_STAT_ANY"
@@ -72,6 +79,66 @@ cleanup(void)
 	id = -1;
 }
 
+static void
+print_semid_ds(const char *const str_ipc_cmd,
+              const struct semid_ds *const ds,
+              const int rc)
+{
+	if (rc < 0) {
+		printf("semctl\\(%d, 0, (%s\\|)?%s, (%p|\\[%p\\])\\) = %s\n",
+		       id, str_ipc_64, str_ipc_cmd, &ds, &ds,
+		       sprintrc_grep(rc));
+		return;
+	}
+	printf("semctl\\(%d, 0, (%s\\|)?%s, \\{sem_perm=\\{uid=%u, gid=%u"
+		", mode=%#o, key=%u, cuid=%u, cgid=%u\\}, sem_otime=%llu"
+		", sem_ctime=%llu, sem_nsems=%llu\\}\\) = %d\n",
+		id,
+		str_ipc_64,
+		str_ipc_cmd,
+		(unsigned) ds->sem_perm.uid,
+		(unsigned) ds->sem_perm.gid,
+		(unsigned) ds->sem_perm.mode,
+		(unsigned) ds->sem_perm.__key,
+		(unsigned) ds->sem_perm.cuid,
+		(unsigned) ds->sem_perm.cgid,
+		(unsigned long long) ds->sem_otime,
+		(unsigned long long) ds->sem_ctime,
+		(unsigned long long) ds->sem_nsems,
+		rc);
+}
+
+static void
+print_sem_info(const char *const str_ipc_cmd,
+               const struct seminfo *const info,
+               const int rc)
+{
+	if (rc < 0) {
+		printf("semctl\\(%d, 0, (%s\\|)?%s, (%p|\\[%p\\])\\) = %s\n",
+		       id, str_ipc_64, str_ipc_cmd, &info, &info,
+		       sprintrc_grep(rc));
+		return;
+	}
+
+	printf("semctl\\(%d, 0, (%s\\|)?%s, \\{semmap=%d, semmni=%d"
+	       ", semmns=%d, semmnu=%d, semmsl=%d, semopm=%d, semume=%d"
+	       ", semusz=%d, semvmx=%d, semaem=%d\\}\\) = %d\n",
+	       id,
+	       str_ipc_64,
+	       str_ipc_cmd,
+	       info->semmap,
+	       info->semmni,
+	       info->semmns,
+	       info->semmnu,
+	       info->semmsl,
+	       info->semopm,
+	       info->semume,
+	       info->semusz,
+	       info->semvmx,
+	       info->semaem,
+	       rc);
+}
+
 int
 main(void)
 {
@@ -91,6 +158,8 @@ main(void)
 	struct semid_ds ds;
 	struct seminfo info;
 
+	memset(&ds, 0, sizeof(ds));
+
 	rc = semget(bogus_key, bogus_size, bogus_flags);
 	printf("semget\\(%#llx, %d, %s\\|%#04o\\) = %s\n",
 	       zero_extend_signed_to_ull(bogus_key), bogus_size,
@@ -108,25 +177,41 @@ main(void)
 	       bogus_semid, bogus_semnum, str_ipc_64, str_bogus_cmd,
 	       bogus_arg, bogus_arg, sprintrc_grep(rc));
 
+	un.__buf = &info;
+	rc = semctl(id, 0, IPC_INFO, un);
+        print_sem_info(str_ipc_info, &info, rc);
+
+	rc = semctl(id, 0, SEM_INFO, un);
+        print_sem_info(str_sem_info, &info, rc);
+
 	un.buf = &ds;
-	if (semctl(id, 0, IPC_STAT, un))
+	rc = semctl(id, 0, IPC_STAT, un);
+	if (rc < 0)
 		perror_msg_and_skip("semctl IPC_STAT");
-	printf("semctl\\(%d, 0, (%s\\|)?%s, \\[?%p\\]?\\) = 0\n",
-	       id, str_ipc_64, str_ipc_stat, &ds);
+	print_semid_ds(str_ipc_stat, &ds, rc);
 
-	un.__buf = &info;
-	rc = semctl(0, 0, SEM_INFO, un);
-	printf("semctl\\(0, 0, (%s\\|)?%s, \\[?%p\\]?\\) = %s\n",
-	       str_ipc_64, str_sem_info, &info, sprintrc_grep(rc));
+	if (semctl(id, 0, IPC_SET, un))
+		perror_msg_and_skip("semctl IPC_SET");
+	printf("semctl\\(%d, 0, (%s\\|)?%s, \\{sem_perm=\\{uid=%u, gid=%u"
+	       ", mode=%#o\\}\\}\\) = 0\n",
+	       id, str_ipc_64, str_ipc_set,
+	       (unsigned) ds.sem_perm.uid,
+	       (unsigned) ds.sem_perm.gid,
+	       (unsigned) ds.sem_perm.mode);
 
-	un.buf = &ds;
 	rc = semctl(id, 0, SEM_STAT, un);
-	printf("semctl\\(%d, 0, (%s\\|)?%s, \\[?%p\\]?\\) = %s\n",
-	       id, str_ipc_64, str_sem_stat, &ds, sprintrc_grep(rc));
+	print_semid_ds(str_sem_stat, &ds, rc);
 
+/*
+ * glibc fails to pass the buffer for SEM_STAT_ANY command,
+ * so the kernel receives garbage instead of un.buf address:
+ * https://sourceware.org/bugzilla/show_bug.cgi?id=26637
+ * musl doesn't pass the buffer either.
+ */
+#if 0
 	rc = semctl(id, 0, SEM_STAT_ANY, un);
-	printf("semctl\\(%d, 0, (%s\\|)?%s, (%p|\\[(%p|NULL)\\]|NULL)\\) = %s\n",
-	       id, str_ipc_64, str_sem_stat_any, &ds, &ds, sprintrc_grep(rc));
+	print_semid_ds(str_sem_stat_any, &ds, rc);
+#endif
 
 	return 0;
 }
diff -pruN 5.5-3/tests/ipc_shm.c 5.9-0ubuntu2/tests/ipc_shm.c
--- 5.5-3/tests/ipc_shm.c	2019-11-28 19:30:05.000000000 +0000
+++ 5.9-0ubuntu2/tests/ipc_shm.c	2020-09-19 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2015 Elvira Khabirova <lineprinter0@gmail.com>
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -39,6 +39,7 @@
 # define str_ipc_rmid "0"
 # define str_ipc_set "0x1"
 # define str_ipc_stat "0x2"
+# define str_ipc_info "0x3"
 # define str_shm_stat "0xd"
 # define str_shm_info "0xe"
 # define str_shm_stat_any "0xf"
@@ -53,6 +54,7 @@
 # define str_ipc_rmid "0 /\\* IPC_RMID \\*/"
 # define str_ipc_set "0x1 /\\* IPC_SET \\*/"
 # define str_ipc_stat "0x2 /\\* IPC_STAT \\*/"
+# define str_ipc_info "0x3 /\\* IPC_INFO \\*/"
 # define str_shm_stat "0xd /\\* SHM_STAT \\*/"
 # define str_shm_info "0xe /\\* SHM_INFO \\*/"
 # define str_shm_stat_any "0xf /\\* SHM_STAT_ANY \\*/"
@@ -66,6 +68,7 @@
 # define str_ipc_rmid "IPC_RMID"
 # define str_ipc_set "IPC_SET"
 # define str_ipc_stat "IPC_STAT"
+# define str_ipc_info "IPC_INFO"
 # define str_shm_stat "SHM_STAT"
 # define str_shm_info "SHM_INFO"
 # define str_shm_stat_any "SHM_STAT_ANY"
@@ -73,6 +76,21 @@
 # define str_bogus_cmd "0xdefaced2 /\\* SHM_\\?\\?\\? \\*/"
 #endif
 
+#undef TEST_SHMCTL_BOGUS_ADDR
+
+/*
+ * Starting with commit glibc-2.32~80, on every 32-bit architecture
+ * where 32-bit time_t support is enabled, glibc tries to retrieve
+ * the data provided in the third argument of shmctl call.
+ */
+#if GLIBC_PREREQ_GE(2, 32) && defined __TIMESIZE && __TIMESIZE != 64
+# define TEST_SHMCTL_BOGUS_ADDR 0
+#endif
+
+#ifndef TEST_SHMCTL_BOGUS_ADDR
+# define TEST_SHMCTL_BOGUS_ADDR 1
+#endif
+
 static int id = -1;
 
 static void
@@ -84,6 +102,89 @@ cleanup(void)
 	id = -1;
 }
 
+static void
+print_shmid_ds(const char *const str_ipc_cmd,
+	       const struct shmid_ds *const ds,
+	       const int rc)
+{
+	if (rc < 0) {
+		printf("shmctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
+		       id, str_ipc_64, str_ipc_cmd, ds, sprintrc_grep(rc));
+		return;
+	}
+	printf("shmctl\\(%d, (%s\\|)?%s, \\{shm_perm=\\{uid=%u, gid=%u"
+		", mode=%#o, key=%u, cuid=%u, cgid=%u\\}, shm_segsz=%u"
+		", shm_cpid=%d, shm_lpid=%d, shm_nattch=%u, shm_atime=%u"
+		", shm_dtime=%u, shm_ctime=%u\\}\\) = %d\n",
+		id,
+		str_ipc_64,
+		str_ipc_cmd,
+		(unsigned) ds->shm_perm.uid,
+		(unsigned) ds->shm_perm.gid,
+		(unsigned) ds->shm_perm.mode,
+		(unsigned) ds->shm_perm.__key,
+		(unsigned) ds->shm_perm.cuid,
+		(unsigned) ds->shm_perm.cgid,
+		(unsigned) ds->shm_segsz,
+		(int) ds->shm_cpid,
+		(int) ds->shm_lpid,
+		(unsigned) ds->shm_nattch,
+		(unsigned) ds->shm_atime,
+		(unsigned) ds->shm_dtime,
+		(unsigned) ds->shm_ctime,
+		rc);
+}
+
+static void
+print_ipc_info(const char *const str_ipc_cmd,
+               const struct shminfo *const info,
+               const int rc)
+{
+	if (rc < 0) {
+		printf("shmctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
+		       id, str_ipc_64, str_ipc_cmd, info, sprintrc_grep(rc));
+		return;
+	}
+
+	printf("shmctl\\(%d, (%s\\|)?%s, \\{shmmax=%llu, shmmin=%llu"
+	       ", shmmni=%llu, shmseg=%llu, shmall=%llu\\}\\) = %d\n",
+	       id,
+	       str_ipc_64,
+	       str_ipc_cmd,
+	       (unsigned long long) info->shmmax,
+	       (unsigned long long) info->shmmin,
+	       (unsigned long long) info->shmmni,
+	       (unsigned long long) info->shmseg,
+	       (unsigned long long) info->shmall,
+	       rc);
+}
+
+static void
+print_shm_info(const char *const str_ipc_cmd,
+              const struct shm_info *const info,
+              const int rc)
+{
+	if (rc < 0) {
+		printf("shmctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
+		       id, str_ipc_64, str_ipc_cmd, info, sprintrc_grep(rc));
+		return;
+	}
+
+	printf("shmctl\\(%d, (%s\\|)?%s, \\{used_ids=%d, shm_tot=%llu"
+	       ", shm_rss=%llu, shm_swp=%llu, swap_attempts=%llu"
+	       ", swap_successes=%llu\\}\\) = %d\n",
+	       id,
+	       str_ipc_64,
+	       str_ipc_cmd,
+	       info->used_ids,
+	       (unsigned long long) info->shm_tot,
+	       (unsigned long long) info->shm_rss,
+	       (unsigned long long) info->shm_swp,
+	       (unsigned long long) info->swap_attempts,
+	       (unsigned long long) info->swap_successes,
+	       rc);
+}
+
 int
 main(void)
 {
@@ -92,7 +193,9 @@ main(void)
 	static const key_t bogus_key = (key_t) 0xeca86420fdb97531ULL;
 	static const int bogus_id = 0xdefaced1;
 	static const int bogus_cmd = 0xdefaced2;
+#if TEST_SHMCTL_BOGUS_ADDR
 	static void * const bogus_addr = (void *) -1L;
+#endif
 	static const size_t bogus_size =
 	/*
 	 * musl sets size to SIZE_MAX if size argument is greater than
@@ -109,7 +212,11 @@ main(void)
 	static const unsigned int huge_flags = 21 << SHM_HUGE_SHIFT;
 	int bogus_flags;
 	int rc;
-	struct shmid_ds ds;
+	union {
+		struct shmid_ds ds;
+		struct shminfo ipc_info;
+		struct shm_info shm_info;
+	} buf;
 
 	rc = shmget(bogus_key, bogus_size, 0);
 	printf("shmget\\(%#llx, %zu, 000\\) = %s\n",
@@ -160,45 +267,38 @@ main(void)
 	printf("shmctl\\(%d, (%s\\|)?%s, NULL\\) = %s\n",
 	       bogus_id, str_ipc_64, str_bogus_cmd, sprintrc_grep(rc));
 
+#if TEST_SHMCTL_BOGUS_ADDR
 	rc = shmctl(bogus_id, IPC_STAT, bogus_addr);
 	printf("shmctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
 	       bogus_id, str_ipc_64, str_ipc_stat, bogus_addr,
 	       sprintrc_grep(rc));
+#endif
 
-	if (shmctl(id, IPC_STAT, &ds))
+	rc = shmctl(id, IPC_STAT, &buf.ds);
+	if (rc < 0)
 		perror_msg_and_skip("shmctl IPC_STAT");
-	printf("shmctl\\(%d, (%s\\|)?%s, \\{shm_perm=\\{uid=%u, gid=%u, "
-		"mode=%#o, key=%u, cuid=%u, cgid=%u\\}, shm_segsz=%u, shm_cpid=%u, "
-		"shm_lpid=%u, shm_nattch=%u, shm_atime=%u, shm_dtime=%u, "
-		"shm_ctime=%u\\}\\) = 0\n",
-		id, str_ipc_64, str_ipc_stat,
-		(unsigned) ds.shm_perm.uid, (unsigned) ds.shm_perm.gid,
-		(unsigned) ds.shm_perm.mode, (unsigned) ds.shm_perm.__key,
-		(unsigned) ds.shm_perm.cuid, (unsigned) ds.shm_perm.cgid,
-		(unsigned) ds.shm_segsz, (unsigned) ds.shm_cpid,
-		(unsigned) ds.shm_lpid, (unsigned) ds.shm_nattch,
-		(unsigned) ds.shm_atime, (unsigned) ds.shm_dtime,
-		(unsigned) ds. shm_ctime);
+	print_shmid_ds(str_ipc_stat, &buf.ds, rc);
 
-	if (shmctl(id, IPC_SET, &ds))
+	if (shmctl(id, IPC_SET, &buf.ds))
 		perror_msg_and_skip("shmctl IPC_SET");
 	printf("shmctl\\(%d, (%s\\|)?%s, \\{shm_perm=\\{uid=%u, gid=%u"
-	       ", mode=%#o\\}, ...\\}\\) = 0\n",
+	       ", mode=%#o\\}\\}\\) = 0\n",
 	       id, str_ipc_64, str_ipc_set,
-	       (unsigned) ds.shm_perm.uid, (unsigned) ds.shm_perm.gid,
-	       (unsigned) ds.shm_perm.mode);
+	       (unsigned) buf.ds.shm_perm.uid,
+	       (unsigned) buf.ds.shm_perm.gid,
+	       (unsigned) buf.ds.shm_perm.mode);
 
-	rc = shmctl(0, SHM_INFO, &ds);
-	printf("shmctl\\(0, (%s\\|)?%s, %p\\) = %s\n",
-	       str_ipc_64, str_shm_info, &ds, sprintrc_grep(rc));
+	rc = shmctl(id, IPC_INFO, &buf.ds);
+	print_ipc_info(str_ipc_info, &buf.ipc_info, rc);
 
-	rc = shmctl(id, SHM_STAT, &ds);
-	printf("shmctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
-	       id, str_ipc_64, str_shm_stat, &ds, sprintrc_grep(rc));
+	rc = shmctl(id, SHM_INFO, &buf.ds);
+	print_shm_info(str_shm_info, &buf.shm_info, rc);
 
-	rc = shmctl(id, SHM_STAT_ANY, &ds);
-	printf("shmctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
-	       id, str_ipc_64, str_shm_stat_any, &ds, sprintrc_grep(rc));
+	rc = shmctl(id, SHM_STAT, &buf.ds);
+	print_shmid_ds(str_shm_stat, &buf.ds, rc);
+
+	rc = shmctl(id, SHM_STAT_ANY, &buf.ds);
+	print_shmid_ds(str_shm_stat_any, &buf.ds, rc);
 
 	return 0;
 }
diff -pruN 5.5-3/tests/kcmp.c 5.9-0ubuntu2/tests/kcmp.c
--- 5.5-3/tests/kcmp.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/kcmp.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,15 +2,15 @@
  * Check decoding of kcmp syscall.
  *
  * Copyright (c) 2016-2017 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-
 #include "scno.h"
+#include "pidns.h"
 
 #ifdef __NR_kcmp
 
@@ -64,7 +64,26 @@ static const char zero_path[] = "/dev/ze
 static void
 printpidfd(const char *prefix, pid_t pid, unsigned fd)
 {
-	printf("%s%d", prefix, fd);
+	const char *path = NULL;
+
+# if VERBOSE_FD
+	if (pid == getpid()) {
+		switch (fd)
+		{
+		case NULL_FD:
+			path = null_path;
+			break;
+		case ZERO_FD:
+			path = zero_path;
+			break;
+		}
+	}
+# endif
+
+	if (path)
+		printf("%s%d<%s>", prefix, fd, path);
+	else
+		printf("%s%d", prefix, fd);
 }
 
 /*
@@ -82,7 +101,11 @@ do_kcmp(kernel_ulong_t pid1, kernel_ulon
 	rc = syscall(__NR_kcmp, pid1, pid2, type, idx1, idx2);
 	errstr = sprintrc(rc);
 
-	printf("kcmp(%d, %d, ", (int) pid1, (int) pid2);
+	const char *pid_str = pidns_pid2str(PT_TGID);
+	pidns_print_leader();
+	printf("kcmp(%d%s, %d%s, ",
+		(int) pid1, (int) pid1 == getpid() ? pid_str : "",
+		(int) pid2, (int) pid2 == getpid() ? pid_str : "");
 
 	if (type_str)
 		printf("%s", type_str);
@@ -127,6 +150,8 @@ do_kcmp(kernel_ulong_t pid1, kernel_ulon
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	static const kernel_ulong_t bogus_pid1 =
 		(kernel_ulong_t) 0xdeadca75face1057ULL;
 	static const kernel_ulong_t bogus_pid2 =
@@ -179,7 +204,7 @@ main(void)
 	/* KCMP_FILE is the only type which has additional args */
 	do_kcmp(3141592653U, 2718281828U, ARG_STR(KCMP_FILE), bogus_idx1,
 		bogus_idx2);
-	do_kcmp(-1, -1, ARG_STR(KCMP_FILE), NULL_FD, ZERO_FD);
+	do_kcmp(getpid(), getpid(), ARG_STR(KCMP_FILE), NULL_FD, ZERO_FD);
 
 	/* Types without additional args */
 	do_kcmp(-1, -1, ARG_STR(KCMP_VM), bogus_idx1, bogus_idx2);
@@ -198,10 +223,11 @@ main(void)
 	for (i = 0; i < ARRAY_SIZE(slot_data); i++) {
 		memcpy(slot, slot_data + i, sizeof(*slot));
 
-		do_kcmp(getpid(), getppid(), ARG_STR(KCMP_EPOLL_TFD), NULL_FD,
+		do_kcmp(getpid(), -1, ARG_STR(KCMP_EPOLL_TFD), NULL_FD,
 			(uintptr_t) slot, 1);
 	}
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 
 	return 0;
diff -pruN 5.5-3/tests/kcmp-y--pidns-translation.c 5.9-0ubuntu2/tests/kcmp-y--pidns-translation.c
--- 5.5-3/tests/kcmp-y--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/kcmp-y--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "kcmp-y.c"
diff -pruN 5.5-3/tests/kcmp-y--pidns-translation.gen.test 5.9-0ubuntu2/tests/kcmp-y--pidns-translation.gen.test
--- 5.5-3/tests/kcmp-y--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/kcmp-y--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (kcmp-y--pidns-translation test_pidns -a22 -y -e trace=kcmp); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a22 -y -e trace=kcmp
diff -pruN 5.5-3/tests/kernel_version.c 5.9-0ubuntu2/tests/kernel_version.c
--- 5.5-3/tests/kernel_version.c	2019-12-10 09:44:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/kernel_version.c	2020-09-06 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check kernel version decoding.
  *
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -34,9 +34,9 @@ static void
 print_bpf_attr(void)
 {
 #if XLAT_RAW
-	printf("{prog_type=0x1b"
+	printf("{prog_type=0x1f"
 #else
-	printf("{prog_type=0x1b /* BPF_PROG_TYPE_??? */"
+	printf("{prog_type=0x1f /* BPF_PROG_TYPE_??? */"
 #endif
 		", insn_cnt=3134983661"
 		", insns=NULL"
@@ -79,7 +79,7 @@ main(void)
 {
 	long ret;
 	struct BPF_PROG_LOAD_struct prog = {
-		.prog_type = 27,
+		.prog_type = 31,
 		.insn_cnt = 0xbadc0ded,
 		.insns = 0,
 		.license = 0,
diff -pruN 5.5-3/tests/kill.c 5.9-0ubuntu2/tests/kill.c
--- 5.5-3/tests/kill.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/kill.c	2020-09-23 16:29:35.000000000 +0000
@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
  * Copyright (c) 2016 Fei Jie <feij.fnst@cn.fujitsu.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -11,6 +11,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #ifdef __NR_kill
 
@@ -26,6 +27,8 @@ handler(int sig)
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	const struct sigaction act = { .sa_handler = handler };
 	if (sigaction(SIGALRM, &act, NULL))
 		perror_msg_and_fail("sigaction");
@@ -37,18 +40,23 @@ main(void)
 		perror_msg_and_fail("sigprocmask");
 
 	const int pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
 	long rc = syscall(__NR_kill, pid, (long) 0xdefaced00000000ULL | SIGALRM);
-	printf("kill(%d, SIGALRM) = %ld\n", pid, rc);
+	pidns_print_leader();
+	printf("kill(%d%s, SIGALRM) = %ld\n", pid, pid_str, rc);
 
 	const long big_pid = (long) 0xfacefeedbadc0dedULL;
 	const long big_sig = (long) 0xdeadbeefcafef00dULL;
 	rc = syscall(__NR_kill, big_pid, big_sig);
+	pidns_print_leader();
 	printf("kill(%d, %d) = %ld %s (%m)\n",
 	       (int) big_pid, (int) big_sig, rc, errno2name());
 
 	rc = syscall(__NR_kill, (long) 0xdefaced00000000ULL | pid, 0);
-	printf("kill(%d, 0) = %ld\n", pid, rc);
+	pidns_print_leader();
+	printf("kill(%d%s, 0) = %ld\n", pid, pid_str, rc);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests/kill--pidns-translation.c 5.9-0ubuntu2/tests/kill--pidns-translation.c
--- 5.5-3/tests/kill--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/kill--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "kill.c"
diff -pruN 5.5-3/tests/kill--pidns-translation.gen.test 5.9-0ubuntu2/tests/kill--pidns-translation.gen.test
--- 5.5-3/tests/kill--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/kill--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (kill--pidns-translation test_pidns -a12 -e trace=kill -esignal=none); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a12 -e trace=kill -esignal=none
diff -pruN 5.5-3/tests/looping_threads.test 5.9-0ubuntu2/tests/looping_threads.test
--- 5.5-3/tests/looping_threads.test	2019-11-28 19:30:05.000000000 +0000
+++ 5.9-0ubuntu2/tests/looping_threads.test	2020-09-03 18:42:36.000000000 +0000
@@ -2,7 +2,7 @@
 #
 # Check tracing of looping threads.
 #
-# Copyright (c) 2009-2019 The strace developers.
+# Copyright (c) 2009-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -20,16 +20,16 @@ inc="$(nproc)"
 [ "$inc" -ge 1 ] || inc=1
 
 timeout_2="$(($TIMEOUT_DURATION/2))"
-timeout_8="$(($TIMEOUT_DURATION/8))"
+timeout_16="$(($TIMEOUT_DURATION/16))"
 nproc=1
 
-run_prog "../$NAME" "$timeout_8" "$nproc"
+run_prog "../$NAME" "$timeout_16" "$nproc"
 
 while :; do
-	run_strace -f -qq -enone -esignal=none "../$NAME" "$timeout_2" "$nproc"
+	run_strace --follow-forks -qq -enone -esignal=none "../$NAME" "$timeout_2" "$nproc"
 
 	s1="$(date +%s)"
-	[ "$(($s1-$s0))" -lt "$timeout_8" ] ||
+	[ "$(($s1-$s0))" -lt "$timeout_16" ] ||
 		break
 
 	nproc="$(($nproc+$inc))"
diff -pruN 5.5-3/tests/Makefile.am 5.9-0ubuntu2/tests/Makefile.am
--- 5.5-3/tests/Makefile.am	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests/Makefile.am	2020-08-25 14:29:30.000000000 +0000
@@ -30,6 +30,7 @@ AM_LDFLAGS = $(ARCH_MFLAGS)
 
 libtests_a_SOURCES = \
 	create_nl_socket.c \
+	create_tmpfile.c \
 	errno2name.c \
 	error_msg.c \
 	fill_memory.c \
@@ -43,6 +44,8 @@ libtests_a_SOURCES = \
 	libsocketcall.c \
 	lock_file.c \
 	overflowuid.c \
+	pidns.c \
+	pidns.h \
 	pipe_maxfd.c \
 	print_quoted_string.c \
 	print_time.c \
@@ -63,6 +66,7 @@ libtests_a_SOURCES = \
 	test_ucopy.h \
 	tests.h \
 	tprintf.c \
+	xmalloc_for_tests.c \
 	# end of libtests_a_SOURCES
 libtests_a_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 check_LIBRARIES = libtests.a
@@ -84,12 +88,20 @@ check_PROGRAMS = $(PURE_EXECUTABLES) \
 	bpf-obj_get_info_by_fd-prog-v \
 	bpf-obj_get_info_by_fd-v \
 	bpf-success \
+	bpf-success-long-y \
 	bpf-success-v \
 	caps-abbrev \
 	check_sigblock \
 	check_sigign \
 	clone_parent \
+	clone_parent--quiet-exit \
+	clone_parent-q \
+	clone_parent-qq \
 	clone_ptrace \
+	clone_ptrace--quiet-attach \
+	clone_ptrace--quiet-exit \
+	clone_ptrace-q \
+	clone_ptrace-qq \
 	clone3-success \
 	clone3-success-Xabbrev \
 	clone3-success-Xraw \
@@ -98,16 +110,25 @@ check_PROGRAMS = $(PURE_EXECUTABLES) \
 	delay \
 	execve-v \
 	execveat-v \
+	fcntl--pidns-translation \
+	fcntl64--pidns-translation \
 	filter_seccomp-flag \
 	filter_seccomp-perf \
 	filter-unavailable \
 	fork-f \
+	fork--pidns-translation \
 	fsync-y \
+	get_process_reaper \
+	getpgrp--pidns-translation	\
 	getpid	\
+	getpid--pidns-translation	\
 	getppid	\
+	getsid--pidns-translation \
 	gettid \
+	gettid--pidns-translation \
 	inject-nf \
 	int_0x80 \
+	ioctl_block--pidns-translation \
 	ioctl_dm-v \
 	ioctl_evdev-success \
 	ioctl_evdev-success-Xabbrev \
@@ -117,22 +138,46 @@ check_PROGRAMS = $(PURE_EXECUTABLES) \
 	ioctl_evdev-success-v-Xabbrev \
 	ioctl_evdev-success-v-Xraw \
 	ioctl_evdev-success-v-Xverbose \
+	ioctl_hdio-success \
+	ioctl_hdio-success-Xabbrev \
+	ioctl_hdio-success-Xraw \
+	ioctl_hdio-success-Xverbose \
+	ioctl_hdio-success-v \
+	ioctl_hdio-success-v-Xabbrev \
+	ioctl_hdio-success-v-Xraw \
+	ioctl_hdio-success-v-Xverbose \
 	ioctl_loop-nv \
 	ioctl_loop-v \
 	ioctl_nsfs \
 	ioctl_perf-success \
 	ioctl_rtc-v \
+	ioctl_v4l2-success \
+	ioctl_v4l2-success-Xabbrev \
+	ioctl_v4l2-success-Xraw \
+	ioctl_v4l2-success-Xverbose \
+	ioctl_v4l2-success-v \
+	ioctl_v4l2-success-v-Xabbrev \
+	ioctl_v4l2-success-v-Xraw \
+	ioctl_v4l2-success-v-Xverbose \
+	ioprio--pidns-translation \
 	is_linux_mips_n64 \
+	kcmp-y--pidns-translation \
 	kill_child \
+	kill--pidns-translation \
 	ksysent \
 	list_sigaction_signum \
 	localtime \
 	looping_threads \
+	migrate_pages--pidns-translation \
 	mmsg-silent \
 	mmsg_name-v \
+	move_pages--pidns-translation \
 	msg_control-v \
 	net-accept-connect \
+	net-sockaddr--pidns-translation \
 	net-tpacket_stats-success \
+	nlattr_ifla_xdp-y \
+	netlink_audit--pidns-translation \
 	netlink_inet_diag \
 	netlink_netlink_diag \
 	netlink_unix_diag \
@@ -144,11 +189,20 @@ check_PROGRAMS = $(PURE_EXECUTABLES) \
 	pc \
 	perf_event_open_nonverbose \
 	perf_event_open_unabbrev \
+	pidfd_open--pidns-translation \
+	pidfd_send_signal--pidns-translation \
+	pidns-cache \
+	poll-P \
+	ppoll-P \
 	ppoll-v \
+	prlimit64--pidns-translation \
 	prctl-seccomp-filter-v \
 	prctl-seccomp-strict \
 	prctl-spec-inject \
 	print_maxfd \
+	print_ppid_tracerpid \
+	process_vm_readv--pidns-translation \
+	process_vm_writev--pidns-translation \
 	qual_fault \
 	qual_inject-error-signal \
 	qual_inject-retval \
@@ -162,7 +216,13 @@ check_PROGRAMS = $(PURE_EXECUTABLES) \
 	quotactl-xfs-v \
 	redirect-fds \
 	restart_syscall \
+	rt_sigqueueinfo--pidns-translation \
+	rt_tgsigqueueinfo--pidns-translation \
 	run_expect_termsig \
+	sched_xetaffinity--pidns-translation \
+	sched_xetattr--pidns-translation \
+	sched_xetparam--pidns-translation \
+	sched_xetscheduler--pidns-translation \
 	scm_rights \
 	seccomp-filter-v \
 	seccomp-strict \
@@ -170,22 +230,35 @@ check_PROGRAMS = $(PURE_EXECUTABLES) \
 	set_ptracer_any \
 	set_sigblock \
 	set_sigign \
+	setpgrp-exec \
 	signal_receive \
+	signal_receive--pidns-translation \
 	sleep \
 	stack-fcall \
 	stack-fcall-attach \
 	stack-fcall-mangled \
 	status-none-threads \
 	status-unfinished-threads \
+	so_peercred--pidns-translation \
 	syslog-success \
+	tgkill--pidns-translation \
 	threads-execve \
+	threads-execve--quiet-thread-execve \
+	threads-execve-q \
+	threads-execve-qq \
+	threads-execve-qqq \
+	tkill--pidns-translation \
 	tracer_ppid_pgid_sid \
+	trie_test \
 	unblock_reset_raise \
 	unix-pair-send-recv \
 	unix-pair-sendto-recvfrom \
 	vfork-f \
 	wait4-v \
 	waitid-v \
+	xetpgid--pidns-translation \
+	xetpriority--pidns-translation \
+	xet_robust_list--pidns-translation \
 	zeroargc \
 	# end of check_PROGRAMS
 
@@ -200,6 +273,7 @@ localtime_LDADD = $(clock_LIBS) $(LDADD)
 looping_threads_LDADD = -lpthread $(LDADD)
 lstat64_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 maybe_switch_current_tcp_LDADD = -lpthread $(LDADD)
+maybe_switch_current_tcp__quiet_thread_execve_LDADD = -lpthread $(LDADD)
 mmap64_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 mmap64_Xabbrev_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 mmap64_Xraw_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
@@ -216,6 +290,10 @@ statfs_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE
 status_none_threads_LDADD = -lpthread $(LDADD)
 status_unfinished_threads_LDADD = -lpthread $(LDADD)
 threads_execve_LDADD = -lpthread $(clock_LIBS) $(LDADD)
+threads_execve__quiet_thread_execve_LDADD = -lpthread $(clock_LIBS) $(LDADD)
+threads_execve_q_LDADD = -lpthread $(clock_LIBS) $(LDADD)
+threads_execve_qq_LDADD = -lpthread $(clock_LIBS) $(LDADD)
+threads_execve_qqq_LDADD = -lpthread $(clock_LIBS) $(LDADD)
 times_LDADD = $(clock_LIBS) $(LDADD)
 truncate64_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 uio_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
@@ -230,6 +308,11 @@ stack_fcall_mangled_SOURCES = stack-fcal
 	stack-fcall-mangled-0.c stack-fcall-mangled-1.c \
 	stack-fcall-mangled-2.c stack-fcall-mangled-3.c
 
+trie_test_SOURCES = trie_test.c trie_for_tests.c
+trie_test_CPPFLAGS = $(AM_CPPFLAGS) $(CODE_COVERAGE_CPPFLAGS)
+trie_test_CFLAGS = $(AM_CFLAGS) $(CODE_COVERAGE_CFLAGS)
+trie_test_LDADD = $(LDADD) $(CODE_COVERAGE_LIBS)
+
 include gen_tests.am
 
 if ENABLE_STACKTRACE
@@ -242,6 +325,7 @@ STACKTRACE_TESTS =
 endif
 
 DECODER_TESTS = \
+	bpf-success-long-y.test \
 	bpf-success-v.test \
 	bpf-success.test \
 	brk.test \
@@ -260,13 +344,15 @@ DECODER_TESTS = \
 	execve-v.test \
 	execve.test \
 	fadvise64.test \
+	faccessat.test \
+	faccessat2.test \
 	futex.test \
 	getuid.test \
 	int_0x80.test \
 	inotify_init-y.test \
 	ioctl.test \
+	ioctl_block--pidns-translation.test \
 	ioctl_evdev-success.test \
-	ioctl_perf-success.test \
 	ipc_msgbuf.test \
 	kern_features-fault.test \
 	llseek.test \
@@ -324,7 +410,6 @@ MISC_TESTS = \
 	attach-f-p.test \
 	attach-p-cmd.test \
 	bexecve.test \
-	clone_parent.test \
 	clone_ptrace.test \
 	count-f.test \
 	count.test \
@@ -338,15 +423,19 @@ MISC_TESTS = \
 	filtering_fd-syntax.test \
 	filtering_syscall-syntax.test \
 	first_exec_failure.test \
+	fork--pidns-translation.test \
 	get_regs.test \
+	gettid--pidns-translation.test \
 	inject-nf.test \
 	interactive_block.test \
 	kill_child.test \
 	localtime.test \
 	looping_threads.test \
+	netlink_audit--pidns-translation.test \
 	opipe.test \
 	options-syntax.test \
 	pc.test \
+	pidns-cache.test \
 	printpath-umovestr-legacy.test \
 	printstrn-umoven-legacy.test \
 	qual_fault-syntax.test \
@@ -374,6 +463,8 @@ MISC_TESTS = \
 	strace-DD.test \
 	strace-DDD.test \
 	strace-E.test \
+	strace-E-override.test \
+	strace-E-unset.test \
 	strace-S.test \
 	strace-T.test \
 	strace-V.test \
@@ -422,6 +513,7 @@ EXTRA_DIST = \
 	filter_seccomp.in \
 	filter_seccomp.sh \
 	filter-unavailable.expected \
+	fork--pidns-translation.awk \
 	fstatat.c \
 	fstatx.c \
 	gen_pure_executables.sh \
@@ -430,6 +522,7 @@ EXTRA_DIST = \
 	getresugid.c \
 	init.sh \
 	init_delete_module.h \
+	ioctl-success.sh \
 	ioctl_kvm_run_common.c \
 	ipc.sh \
 	kernel_old_timespec.h \
@@ -438,7 +531,6 @@ EXTRA_DIST = \
 	lstatx.c \
 	match.awk \
 	net.expected \
-	netlink_sock_diag-v.sh \
 	nlattr_ifla.h \
 	pipe.expected \
 	print_user_desc.c \
@@ -467,11 +559,22 @@ EXTRA_DIST = \
 	sockname.c \
 	stack-fcall.h \
 	status-detached.expected \
+	strace--follow-forks-output-separately.expected \
+	strace--relative-timestamps.expected \
+	strace--relative-timestamps-s.expected \
+	strace--relative-timestamps-ms.expected \
+	strace--relative-timestamps-us.expected \
+	strace--relative-timestamps-ns.expected \
+	strace--syscall-times.expected \
+	strace--syscall-times-s.expected \
+	strace--syscall-times-ms.expected \
+	strace--syscall-times-us.expected \
+	strace--syscall-times-ns.expected \
 	strace-C.expected \
 	strace-D.expected \
-	strace-DD.expected \
 	strace-DDD.expected \
 	strace-E.expected \
+	strace-E-unset.expected \
 	strace-T.expected \
 	strace-ff.expected \
 	strace-k-demangle.expected \
@@ -484,6 +587,7 @@ EXTRA_DIST = \
 	strace.supp \
 	sun_path.expected \
 	syntax.sh \
+	trace_clock.in \
 	trace_creds.in \
 	trace_fstat.in \
 	trace_fstatfs.in \
@@ -505,6 +609,7 @@ EXTRA_DIST = \
 	unix-pair-send-recv.expected \
 	unix-pair-sendto-recvfrom.expected \
 	xchownx.c \
+	xgetdents.c \
 	xgetrlimit.c \
 	xselect.c \
 	xstatfs.c \
diff -pruN 5.5-3/tests/Makefile.in 5.9-0ubuntu2/tests/Makefile.in
--- 5.5-3/tests/Makefile.in	2020-02-06 16:23:37.000000000 +0000
+++ 5.9-0ubuntu2/tests/Makefile.in	2020-09-24 09:19:03.000000000 +0000
@@ -1,7 +1,7 @@
-# Makefile.in generated by automake 1.16.1 from Makefile.am.
+# Makefile.in generated by automake 1.16.2 from Makefile.am.
 # @configure_input@
 
-# Copyright (C) 1994-2018 Free Software Foundation, Inc.
+# Copyright (C) 1994-2020 Free Software Foundation, Inc.
 
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -110,69 +110,161 @@ check_PROGRAMS = $(am__EXEEXT_1) _newsel
 	bpf-obj_get_info_by_fd-prog$(EXEEXT) \
 	bpf-obj_get_info_by_fd-prog-v$(EXEEXT) \
 	bpf-obj_get_info_by_fd-v$(EXEEXT) bpf-success$(EXEEXT) \
-	bpf-success-v$(EXEEXT) caps-abbrev$(EXEEXT) \
-	check_sigblock$(EXEEXT) check_sigign$(EXEEXT) \
-	clone_parent$(EXEEXT) clone_ptrace$(EXEEXT) \
-	clone3-success$(EXEEXT) clone3-success-Xabbrev$(EXEEXT) \
-	clone3-success-Xraw$(EXEEXT) clone3-success-Xverbose$(EXEEXT) \
-	count-f$(EXEEXT) delay$(EXEEXT) execve-v$(EXEEXT) \
-	execveat-v$(EXEEXT) filter_seccomp-flag$(EXEEXT) \
-	filter_seccomp-perf$(EXEEXT) filter-unavailable$(EXEEXT) \
-	fork-f$(EXEEXT) fsync-y$(EXEEXT) getpid$(EXEEXT) \
-	getppid$(EXEEXT) gettid$(EXEEXT) inject-nf$(EXEEXT) \
-	int_0x80$(EXEEXT) ioctl_dm-v$(EXEEXT) \
-	ioctl_evdev-success$(EXEEXT) \
+	bpf-success-long-y$(EXEEXT) bpf-success-v$(EXEEXT) \
+	caps-abbrev$(EXEEXT) check_sigblock$(EXEEXT) \
+	check_sigign$(EXEEXT) clone_parent$(EXEEXT) \
+	clone_parent--quiet-exit$(EXEEXT) clone_parent-q$(EXEEXT) \
+	clone_parent-qq$(EXEEXT) clone_ptrace$(EXEEXT) \
+	clone_ptrace--quiet-attach$(EXEEXT) \
+	clone_ptrace--quiet-exit$(EXEEXT) clone_ptrace-q$(EXEEXT) \
+	clone_ptrace-qq$(EXEEXT) clone3-success$(EXEEXT) \
+	clone3-success-Xabbrev$(EXEEXT) clone3-success-Xraw$(EXEEXT) \
+	clone3-success-Xverbose$(EXEEXT) count-f$(EXEEXT) \
+	delay$(EXEEXT) execve-v$(EXEEXT) execveat-v$(EXEEXT) \
+	fcntl--pidns-translation$(EXEEXT) \
+	fcntl64--pidns-translation$(EXEEXT) \
+	filter_seccomp-flag$(EXEEXT) filter_seccomp-perf$(EXEEXT) \
+	filter-unavailable$(EXEEXT) fork-f$(EXEEXT) \
+	fork--pidns-translation$(EXEEXT) fsync-y$(EXEEXT) \
+	get_process_reaper$(EXEEXT) \
+	getpgrp--pidns-translation$(EXEEXT) getpid$(EXEEXT) \
+	getpid--pidns-translation$(EXEEXT) getppid$(EXEEXT) \
+	getsid--pidns-translation$(EXEEXT) gettid$(EXEEXT) \
+	gettid--pidns-translation$(EXEEXT) inject-nf$(EXEEXT) \
+	int_0x80$(EXEEXT) ioctl_block--pidns-translation$(EXEEXT) \
+	ioctl_dm-v$(EXEEXT) ioctl_evdev-success$(EXEEXT) \
 	ioctl_evdev-success-Xabbrev$(EXEEXT) \
 	ioctl_evdev-success-Xraw$(EXEEXT) \
 	ioctl_evdev-success-Xverbose$(EXEEXT) \
 	ioctl_evdev-success-v$(EXEEXT) \
 	ioctl_evdev-success-v-Xabbrev$(EXEEXT) \
 	ioctl_evdev-success-v-Xraw$(EXEEXT) \
-	ioctl_evdev-success-v-Xverbose$(EXEEXT) ioctl_loop-nv$(EXEEXT) \
+	ioctl_evdev-success-v-Xverbose$(EXEEXT) \
+	ioctl_hdio-success$(EXEEXT) \
+	ioctl_hdio-success-Xabbrev$(EXEEXT) \
+	ioctl_hdio-success-Xraw$(EXEEXT) \
+	ioctl_hdio-success-Xverbose$(EXEEXT) \
+	ioctl_hdio-success-v$(EXEEXT) \
+	ioctl_hdio-success-v-Xabbrev$(EXEEXT) \
+	ioctl_hdio-success-v-Xraw$(EXEEXT) \
+	ioctl_hdio-success-v-Xverbose$(EXEEXT) ioctl_loop-nv$(EXEEXT) \
 	ioctl_loop-v$(EXEEXT) ioctl_nsfs$(EXEEXT) \
 	ioctl_perf-success$(EXEEXT) ioctl_rtc-v$(EXEEXT) \
-	is_linux_mips_n64$(EXEEXT) kill_child$(EXEEXT) \
-	ksysent$(EXEEXT) list_sigaction_signum$(EXEEXT) \
-	localtime$(EXEEXT) looping_threads$(EXEEXT) \
-	mmsg-silent$(EXEEXT) mmsg_name-v$(EXEEXT) \
+	ioctl_v4l2-success$(EXEEXT) \
+	ioctl_v4l2-success-Xabbrev$(EXEEXT) \
+	ioctl_v4l2-success-Xraw$(EXEEXT) \
+	ioctl_v4l2-success-Xverbose$(EXEEXT) \
+	ioctl_v4l2-success-v$(EXEEXT) \
+	ioctl_v4l2-success-v-Xabbrev$(EXEEXT) \
+	ioctl_v4l2-success-v-Xraw$(EXEEXT) \
+	ioctl_v4l2-success-v-Xverbose$(EXEEXT) \
+	ioprio--pidns-translation$(EXEEXT) is_linux_mips_n64$(EXEEXT) \
+	kcmp-y--pidns-translation$(EXEEXT) kill_child$(EXEEXT) \
+	kill--pidns-translation$(EXEEXT) ksysent$(EXEEXT) \
+	list_sigaction_signum$(EXEEXT) localtime$(EXEEXT) \
+	looping_threads$(EXEEXT) \
+	migrate_pages--pidns-translation$(EXEEXT) mmsg-silent$(EXEEXT) \
+	mmsg_name-v$(EXEEXT) move_pages--pidns-translation$(EXEEXT) \
 	msg_control-v$(EXEEXT) net-accept-connect$(EXEEXT) \
-	net-tpacket_stats-success$(EXEEXT) netlink_inet_diag$(EXEEXT) \
-	netlink_netlink_diag$(EXEEXT) netlink_unix_diag$(EXEEXT) \
-	nsyscalls$(EXEEXT) nsyscalls-d$(EXEEXT) oldselect-P$(EXEEXT) \
+	net-sockaddr--pidns-translation$(EXEEXT) \
+	net-tpacket_stats-success$(EXEEXT) nlattr_ifla_xdp-y$(EXEEXT) \
+	netlink_audit--pidns-translation$(EXEEXT) \
+	netlink_inet_diag$(EXEEXT) netlink_netlink_diag$(EXEEXT) \
+	netlink_unix_diag$(EXEEXT) nsyscalls$(EXEEXT) \
+	nsyscalls-d$(EXEEXT) oldselect-P$(EXEEXT) \
 	oldselect-efault-P$(EXEEXT) orphaned_process_group$(EXEEXT) \
 	pc$(EXEEXT) perf_event_open_nonverbose$(EXEEXT) \
-	perf_event_open_unabbrev$(EXEEXT) ppoll-v$(EXEEXT) \
+	perf_event_open_unabbrev$(EXEEXT) \
+	pidfd_open--pidns-translation$(EXEEXT) \
+	pidfd_send_signal--pidns-translation$(EXEEXT) \
+	pidns-cache$(EXEEXT) poll-P$(EXEEXT) ppoll-P$(EXEEXT) \
+	ppoll-v$(EXEEXT) prlimit64--pidns-translation$(EXEEXT) \
 	prctl-seccomp-filter-v$(EXEEXT) prctl-seccomp-strict$(EXEEXT) \
 	prctl-spec-inject$(EXEEXT) print_maxfd$(EXEEXT) \
+	print_ppid_tracerpid$(EXEEXT) \
+	process_vm_readv--pidns-translation$(EXEEXT) \
+	process_vm_writev--pidns-translation$(EXEEXT) \
 	qual_fault$(EXEEXT) qual_inject-error-signal$(EXEEXT) \
 	qual_inject-retval$(EXEEXT) qual_inject-signal$(EXEEXT) \
 	qual_signal$(EXEEXT) quotactl-success$(EXEEXT) \
 	quotactl-success-v$(EXEEXT) quotactl-v$(EXEEXT) \
 	quotactl-xfs-success$(EXEEXT) quotactl-xfs-success-v$(EXEEXT) \
 	quotactl-xfs-v$(EXEEXT) redirect-fds$(EXEEXT) \
-	restart_syscall$(EXEEXT) run_expect_termsig$(EXEEXT) \
+	restart_syscall$(EXEEXT) \
+	rt_sigqueueinfo--pidns-translation$(EXEEXT) \
+	rt_tgsigqueueinfo--pidns-translation$(EXEEXT) \
+	run_expect_termsig$(EXEEXT) \
+	sched_xetaffinity--pidns-translation$(EXEEXT) \
+	sched_xetattr--pidns-translation$(EXEEXT) \
+	sched_xetparam--pidns-translation$(EXEEXT) \
+	sched_xetscheduler--pidns-translation$(EXEEXT) \
 	scm_rights$(EXEEXT) seccomp-filter-v$(EXEEXT) \
 	seccomp-strict$(EXEEXT) select-P$(EXEEXT) \
 	set_ptracer_any$(EXEEXT) set_sigblock$(EXEEXT) \
-	set_sigign$(EXEEXT) signal_receive$(EXEEXT) sleep$(EXEEXT) \
+	set_sigign$(EXEEXT) setpgrp-exec$(EXEEXT) \
+	signal_receive$(EXEEXT) \
+	signal_receive--pidns-translation$(EXEEXT) sleep$(EXEEXT) \
 	stack-fcall$(EXEEXT) stack-fcall-attach$(EXEEXT) \
 	stack-fcall-mangled$(EXEEXT) status-none-threads$(EXEEXT) \
-	status-unfinished-threads$(EXEEXT) syslog-success$(EXEEXT) \
-	threads-execve$(EXEEXT) tracer_ppid_pgid_sid$(EXEEXT) \
+	status-unfinished-threads$(EXEEXT) \
+	so_peercred--pidns-translation$(EXEEXT) \
+	syslog-success$(EXEEXT) tgkill--pidns-translation$(EXEEXT) \
+	threads-execve$(EXEEXT) \
+	threads-execve--quiet-thread-execve$(EXEEXT) \
+	threads-execve-q$(EXEEXT) threads-execve-qq$(EXEEXT) \
+	threads-execve-qqq$(EXEEXT) tkill--pidns-translation$(EXEEXT) \
+	tracer_ppid_pgid_sid$(EXEEXT) trie_test$(EXEEXT) \
 	unblock_reset_raise$(EXEEXT) unix-pair-send-recv$(EXEEXT) \
 	unix-pair-sendto-recvfrom$(EXEEXT) vfork-f$(EXEEXT) \
-	wait4-v$(EXEEXT) waitid-v$(EXEEXT) zeroargc$(EXEEXT)
+	wait4-v$(EXEEXT) waitid-v$(EXEEXT) \
+	xetpgid--pidns-translation$(EXEEXT) \
+	xetpriority--pidns-translation$(EXEEXT) \
+	xet_robust_list--pidns-translation$(EXEEXT) zeroargc$(EXEEXT)
 @ENABLE_STACKTRACE_TRUE@@USE_DEMANGLE_TRUE@am__append_1 = strace-k-demangle.test
 TESTS = $(GEN_TESTS) $(DECODER_TESTS) $(MISC_TESTS) $(am__EXEEXT_2)
 subdir = tests
 ACLOCAL_M4 = $(top_srcdir)/aclocal.m4
-am__aclocal_m4_deps = $(top_srcdir)/types/check-cryptouser.m4 \
+am__aclocal_m4_deps = $(top_srcdir)/xlat/btrfs_compress_types.m4 \
+	$(top_srcdir)/xlat/close_range_flags.m4 \
+	$(top_srcdir)/xlat/loop_flags_options.m4 \
+	$(top_srcdir)/xlat/rtnl_ifla_xdp_attached_mode.m4 \
+	$(top_srcdir)/xlat/rtnl_ifla_xdp_attrs.m4 \
+	$(top_srcdir)/xlat/rtnl_link_attrs.m4 \
+	$(top_srcdir)/xlat/rtnl_tc_action_attrs.m4 \
+	$(top_srcdir)/xlat/rtnl_tca_stab_attrs.m4 \
+	$(top_srcdir)/xlat/rtnl_tca_stats_attrs.m4 \
+	$(top_srcdir)/xlat/st_check_enums.m4 \
+	$(top_srcdir)/xlat/sysctl_kern.m4 \
+	$(top_srcdir)/xlat/sysctl_net.m4 \
+	$(top_srcdir)/xlat/sysctl_net_core.m4 \
+	$(top_srcdir)/xlat/sysctl_net_ipv4.m4 \
+	$(top_srcdir)/xlat/sysctl_net_ipv4_conf.m4 \
+	$(top_srcdir)/xlat/sysctl_net_ipv4_route.m4 \
+	$(top_srcdir)/xlat/sysctl_net_ipv6.m4 \
+	$(top_srcdir)/xlat/sysctl_net_ipv6_route.m4 \
+	$(top_srcdir)/xlat/sysctl_net_unix.m4 \
+	$(top_srcdir)/xlat/sysctl_root.m4 \
+	$(top_srcdir)/xlat/sysctl_vm.m4 \
+	$(top_srcdir)/xlat/v4l2_buf_types.m4 \
+	$(top_srcdir)/xlat/v4l2_colorspaces.m4 \
+	$(top_srcdir)/xlat/v4l2_control_types.m4 \
+	$(top_srcdir)/xlat/v4l2_fields.m4 \
+	$(top_srcdir)/xlat/v4l2_framesize_types.m4 \
+	$(top_srcdir)/xlat/v4l2_memories.m4 \
+	$(top_srcdir)/xlat/v4l2_tuner_types.m4 \
+	$(top_srcdir)/xlat/waitid_types.m4 \
+	$(top_srcdir)/types/check-btrfs.m4 \
+	$(top_srcdir)/types/check-cryptouser.m4 \
 	$(top_srcdir)/types/check-evdev.m4 \
 	$(top_srcdir)/types/check-io_uring.m4 \
+	$(top_srcdir)/types/check-loop.m4 \
+	$(top_srcdir)/types/check-openat2.m4 \
 	$(top_srcdir)/types/check-rtnl_link.m4 \
 	$(top_srcdir)/types/check-rtnl_mdb.m4 \
 	$(top_srcdir)/types/check-rtnl_neightbl.m4 \
 	$(top_srcdir)/types/check-rtnl_route.m4 \
+	$(top_srcdir)/types/check-tee.m4 \
+	$(top_srcdir)/types/check-v4l2.m4 \
 	$(top_srcdir)/types/st_check_types.m4 \
 	$(top_srcdir)/m4/ax_code_coverage.m4 \
 	$(top_srcdir)/m4/ax_prog_cc_for_build.m4 \
@@ -201,12 +293,21 @@ am__EXEEXT_1 = _newselect$(EXEEXT) accep
 	clock_nanosleep$(EXEEXT) clock_xettime$(EXEEXT) \
 	clone-flags$(EXEEXT) clone3$(EXEEXT) clone3-Xabbrev$(EXEEXT) \
 	clone3-Xraw$(EXEEXT) clone3-Xverbose$(EXEEXT) \
+	close_range$(EXEEXT) close_range-P$(EXEEXT) \
+	close_range-y$(EXEEXT) close_range-yy$(EXEEXT) \
 	copy_file_range$(EXEEXT) creat$(EXEEXT) delete_module$(EXEEXT) \
-	dev-yy$(EXEEXT) dup$(EXEEXT) dup2$(EXEEXT) dup3$(EXEEXT) \
+	dev--decode-fds-dev$(EXEEXT) dev--decode-fds-path$(EXEEXT) \
+	dev--decode-fds-socket$(EXEEXT) dev-yy$(EXEEXT) dup$(EXEEXT) \
+	dup-P$(EXEEXT) dup-y$(EXEEXT) dup-yy$(EXEEXT) dup2$(EXEEXT) \
+	dup2-P$(EXEEXT) dup2-y$(EXEEXT) dup2-yy$(EXEEXT) dup3$(EXEEXT) \
+	dup3-P$(EXEEXT) dup3-y$(EXEEXT) dup3-yy$(EXEEXT) \
 	epoll_create$(EXEEXT) epoll_create1$(EXEEXT) \
 	epoll_ctl$(EXEEXT) epoll_pwait$(EXEEXT) epoll_wait$(EXEEXT) \
 	erestartsys$(EXEEXT) eventfd$(EXEEXT) execve$(EXEEXT) \
-	execveat$(EXEEXT) faccessat$(EXEEXT) fadvise64$(EXEEXT) \
+	execveat$(EXEEXT) faccessat$(EXEEXT) faccessat-P$(EXEEXT) \
+	faccessat-y$(EXEEXT) faccessat-yy$(EXEEXT) faccessat2$(EXEEXT) \
+	faccessat2-P$(EXEEXT) faccessat2-y$(EXEEXT) \
+	faccessat2-yy$(EXEEXT) fadvise64$(EXEEXT) \
 	fadvise64_64$(EXEEXT) fallocate$(EXEEXT) \
 	fanotify_init$(EXEEXT) fanotify_mark$(EXEEXT) \
 	fanotify_mark-Xabbrev$(EXEEXT) fanotify_mark-Xraw$(EXEEXT) \
@@ -224,17 +325,18 @@ am__EXEEXT_1 = _newselect$(EXEEXT) accep
 	fstatfs64$(EXEEXT) fsync$(EXEEXT) ftruncate$(EXEEXT) \
 	ftruncate64$(EXEEXT) futex$(EXEEXT) futimesat$(EXEEXT) \
 	get_mempolicy$(EXEEXT) getcpu$(EXEEXT) getcwd$(EXEEXT) \
-	getdents$(EXEEXT) getdents64$(EXEEXT) getegid$(EXEEXT) \
-	getegid32$(EXEEXT) geteuid$(EXEEXT) geteuid32$(EXEEXT) \
-	getgid$(EXEEXT) getgid32$(EXEEXT) getgroups$(EXEEXT) \
-	getgroups32$(EXEEXT) getpeername$(EXEEXT) getpgrp$(EXEEXT) \
-	getpid$(EXEEXT) getppid$(EXEEXT) getrandom$(EXEEXT) \
-	getresgid$(EXEEXT) getresgid32$(EXEEXT) getresuid$(EXEEXT) \
-	getresuid32$(EXEEXT) getrlimit$(EXEEXT) getrusage$(EXEEXT) \
-	getsid$(EXEEXT) getsockname$(EXEEXT) getuid$(EXEEXT) \
-	getuid32$(EXEEXT) getxxid$(EXEEXT) group_req$(EXEEXT) \
-	inet-cmsg$(EXEEXT) init_module$(EXEEXT) inotify$(EXEEXT) \
-	inotify_init$(EXEEXT) inotify_init-y$(EXEEXT) \
+	getdents$(EXEEXT) getdents-v$(EXEEXT) getdents64$(EXEEXT) \
+	getdents64-v$(EXEEXT) getegid$(EXEEXT) getegid32$(EXEEXT) \
+	geteuid$(EXEEXT) geteuid32$(EXEEXT) getgid$(EXEEXT) \
+	getgid32$(EXEEXT) getgroups$(EXEEXT) getgroups32$(EXEEXT) \
+	getpeername$(EXEEXT) getpgrp$(EXEEXT) getpid$(EXEEXT) \
+	getppid$(EXEEXT) getrandom$(EXEEXT) getresgid$(EXEEXT) \
+	getresgid32$(EXEEXT) getresuid$(EXEEXT) getresuid32$(EXEEXT) \
+	getrlimit$(EXEEXT) getrusage$(EXEEXT) getsid$(EXEEXT) \
+	getsockname$(EXEEXT) getuid$(EXEEXT) getuid32$(EXEEXT) \
+	getxgid$(EXEEXT) getxpid$(EXEEXT) getxuid$(EXEEXT) \
+	group_req$(EXEEXT) inet-cmsg$(EXEEXT) init_module$(EXEEXT) \
+	inotify$(EXEEXT) inotify_init$(EXEEXT) inotify_init-y$(EXEEXT) \
 	inotify_init1$(EXEEXT) inotify_init1-y$(EXEEXT) \
 	io_uring_enter$(EXEEXT) io_uring_register$(EXEEXT) \
 	io_uring_setup$(EXEEXT) ioctl$(EXEEXT) ioctl_block$(EXEEXT) \
@@ -242,16 +344,24 @@ am__EXEEXT_1 = _newselect$(EXEEXT) accep
 	ioctl_evdev-Xabbrev$(EXEEXT) ioctl_evdev-Xraw$(EXEEXT) \
 	ioctl_evdev-Xverbose$(EXEEXT) ioctl_evdev-v$(EXEEXT) \
 	ioctl_evdev-v-Xabbrev$(EXEEXT) ioctl_evdev-v-Xraw$(EXEEXT) \
-	ioctl_evdev-v-Xverbose$(EXEEXT) ioctl_inotify$(EXEEXT) \
+	ioctl_evdev-v-Xverbose$(EXEEXT) ioctl_hdio$(EXEEXT) \
+	ioctl_hdio-Xabbrev$(EXEEXT) ioctl_hdio-Xraw$(EXEEXT) \
+	ioctl_hdio-Xverbose$(EXEEXT) ioctl_hdio-v$(EXEEXT) \
+	ioctl_hdio-v-Xabbrev$(EXEEXT) ioctl_hdio-v-Xraw$(EXEEXT) \
+	ioctl_hdio-v-Xverbose$(EXEEXT) ioctl_inotify$(EXEEXT) \
 	ioctl_kvm_run$(EXEEXT) ioctl_kvm_run-v$(EXEEXT) \
 	ioctl_kvm_run_auxstr_vcpu$(EXEEXT) ioctl_loop$(EXEEXT) \
 	ioctl_mtd$(EXEEXT) ioctl_nbd$(EXEEXT) ioctl_perf$(EXEEXT) \
 	ioctl_ptp$(EXEEXT) ioctl_random$(EXEEXT) ioctl_rtc$(EXEEXT) \
 	ioctl_scsi$(EXEEXT) ioctl_sg_io_v3$(EXEEXT) \
 	ioctl_sg_io_v4$(EXEEXT) ioctl_sock_gifconf$(EXEEXT) \
-	ioctl_uffdio$(EXEEXT) ioctl_v4l2$(EXEEXT) \
-	ioctl_watchdog$(EXEEXT) ioperm$(EXEEXT) iopl$(EXEEXT) \
-	ioprio$(EXEEXT) ioprio-Xabbrev$(EXEEXT) ioprio-Xraw$(EXEEXT) \
+	ioctl_tee$(EXEEXT) ioctl_uffdio$(EXEEXT) ioctl_v4l2$(EXEEXT) \
+	ioctl_v4l2-Xabbrev$(EXEEXT) ioctl_v4l2-Xraw$(EXEEXT) \
+	ioctl_v4l2-Xverbose$(EXEEXT) ioctl_v4l2-v$(EXEEXT) \
+	ioctl_v4l2-v-Xabbrev$(EXEEXT) ioctl_v4l2-v-Xraw$(EXEEXT) \
+	ioctl_v4l2-v-Xverbose$(EXEEXT) ioctl_watchdog$(EXEEXT) \
+	ioperm$(EXEEXT) iopl$(EXEEXT) ioprio$(EXEEXT) \
+	ioprio-Xabbrev$(EXEEXT) ioprio-Xraw$(EXEEXT) \
 	ioprio-Xverbose$(EXEEXT) ip_mreq$(EXEEXT) ipc$(EXEEXT) \
 	ipc_msg$(EXEEXT) ipc_msg-Xabbrev$(EXEEXT) \
 	ipc_msg-Xraw$(EXEEXT) ipc_msg-Xverbose$(EXEEXT) \
@@ -270,6 +380,7 @@ am__EXEEXT_1 = _newselect$(EXEEXT) accep
 	linkat$(EXEEXT) llseek$(EXEEXT) lookup_dcookie$(EXEEXT) \
 	lseek$(EXEEXT) lstat$(EXEEXT) lstat64$(EXEEXT) \
 	madvise$(EXEEXT) maybe_switch_current_tcp$(EXEEXT) \
+	maybe_switch_current_tcp--quiet-thread-execve$(EXEEXT) \
 	mbind$(EXEEXT) mbind-Xabbrev$(EXEEXT) mbind-Xraw$(EXEEXT) \
 	mbind-Xverbose$(EXEEXT) membarrier$(EXEEXT) \
 	memfd_create$(EXEEXT) memfd_create-Xabbrev$(EXEEXT) \
@@ -288,9 +399,12 @@ am__EXEEXT_1 = _newselect$(EXEEXT) accep
 	move_pages-Xverbose$(EXEEXT) mq$(EXEEXT) mq_sendrecv$(EXEEXT) \
 	mq_sendrecv-read$(EXEEXT) mq_sendrecv-write$(EXEEXT) \
 	msg_control$(EXEEXT) msg_name$(EXEEXT) munlockall$(EXEEXT) \
-	nanosleep$(EXEEXT) net-icmp_filter$(EXEEXT) \
-	net-packet_mreq$(EXEEXT) net-packet_mreq-Xabbrev$(EXEEXT) \
-	net-packet_mreq-Xraw$(EXEEXT) \
+	nanosleep$(EXEEXT) net--decode-fds-dev-netlink$(EXEEXT) \
+	net--decode-fds-none-netlink$(EXEEXT) \
+	net--decode-fds-path-netlink$(EXEEXT) \
+	net--decode-fds-socket-netlink$(EXEEXT) \
+	net-icmp_filter$(EXEEXT) net-packet_mreq$(EXEEXT) \
+	net-packet_mreq-Xabbrev$(EXEEXT) net-packet_mreq-Xraw$(EXEEXT) \
 	net-packet_mreq-Xverbose$(EXEEXT) net-sockaddr$(EXEEXT) \
 	net-tpacket_req$(EXEEXT) net-tpacket_stats$(EXEEXT) \
 	net-y-unix$(EXEEXT) net-yy-inet$(EXEEXT) net-yy-inet6$(EXEEXT) \
@@ -329,19 +443,27 @@ am__EXEEXT_1 = _newselect$(EXEEXT) accep
 	old_mmap-v-none$(EXEEXT) oldfstat$(EXEEXT) oldlstat$(EXEEXT) \
 	oldselect$(EXEEXT) oldselect-efault$(EXEEXT) oldstat$(EXEEXT) \
 	open$(EXEEXT) open_tree$(EXEEXT) open_tree-P$(EXEEXT) \
-	openat$(EXEEXT) osf_utimes$(EXEEXT) pause$(EXEEXT) \
-	perf_event_open$(EXEEXT) personality$(EXEEXT) \
-	personality-Xabbrev$(EXEEXT) personality-Xraw$(EXEEXT) \
-	personality-Xverbose$(EXEEXT) pidfd_open$(EXEEXT) \
-	pidfd_open-P$(EXEEXT) pidfd_open-y$(EXEEXT) \
+	openat$(EXEEXT) openat2$(EXEEXT) openat2-Xabbrev$(EXEEXT) \
+	openat2-Xraw$(EXEEXT) openat2-Xverbose$(EXEEXT) \
+	openat2-v$(EXEEXT) openat2-v-y$(EXEEXT) \
+	openat2-v-y-Xabbrev$(EXEEXT) openat2-v-y-Xraw$(EXEEXT) \
+	openat2-v-y-Xverbose$(EXEEXT) openat2-y$(EXEEXT) \
+	osf_utimes$(EXEEXT) pause$(EXEEXT) perf_event_open$(EXEEXT) \
+	personality$(EXEEXT) personality-Xabbrev$(EXEEXT) \
+	personality-Xraw$(EXEEXT) personality-Xverbose$(EXEEXT) \
+	pidfd_getfd$(EXEEXT) pidfd_getfd-y$(EXEEXT) \
+	pidfd_getfd-yy$(EXEEXT) pidfd_open$(EXEEXT) \
+	pidfd_open--decode-fd-path$(EXEEXT) \
+	pidfd_open--decode-fd-pidfd$(EXEEXT) \
+	pidfd_open--decode-fd-socket$(EXEEXT) pidfd_open-P$(EXEEXT) \
+	pidfd_open-y$(EXEEXT) pidfd_open-yy$(EXEEXT) \
 	pidfd_send_signal$(EXEEXT) pipe$(EXEEXT) pipe2$(EXEEXT) \
 	pkey_alloc$(EXEEXT) pkey_free$(EXEEXT) pkey_mprotect$(EXEEXT) \
-	poll$(EXEEXT) poll-P$(EXEEXT) ppoll$(EXEEXT) ppoll-P$(EXEEXT) \
-	prctl-arg2-intptr$(EXEEXT) prctl-dumpable$(EXEEXT) \
-	prctl-name$(EXEEXT) prctl-no-args$(EXEEXT) \
-	prctl-pdeathsig$(EXEEXT) prctl-securebits$(EXEEXT) \
-	prctl-tid_address$(EXEEXT) prctl-tsc$(EXEEXT) \
-	pread64-pwrite64$(EXEEXT) preadv$(EXEEXT) \
+	poll$(EXEEXT) ppoll$(EXEEXT) prctl-arg2-intptr$(EXEEXT) \
+	prctl-dumpable$(EXEEXT) prctl-name$(EXEEXT) \
+	prctl-no-args$(EXEEXT) prctl-pdeathsig$(EXEEXT) \
+	prctl-securebits$(EXEEXT) prctl-tid_address$(EXEEXT) \
+	prctl-tsc$(EXEEXT) pread64-pwrite64$(EXEEXT) preadv$(EXEEXT) \
 	preadv-pwritev$(EXEEXT) preadv2-pwritev2$(EXEEXT) \
 	printpath-umovestr$(EXEEXT) \
 	printpath-umovestr-peekdata$(EXEEXT) \
@@ -402,29 +524,35 @@ am__EXEEXT_1 = _newselect$(EXEEXT) accep
 	sockopt-sol_netlink$(EXEEXT) sockopt-timestamp$(EXEEXT) \
 	splice$(EXEEXT) stat$(EXEEXT) stat64$(EXEEXT) statfs$(EXEEXT) \
 	statfs64$(EXEEXT) status-all$(EXEEXT) status-failed$(EXEEXT) \
+	status-failed-long$(EXEEXT) status-failed-status$(EXEEXT) \
 	status-none$(EXEEXT) status-none-f$(EXEEXT) \
-	status-successful$(EXEEXT) status-unfinished$(EXEEXT) \
-	statx$(EXEEXT) swap$(EXEEXT) sxetmask$(EXEEXT) \
-	symlink$(EXEEXT) symlinkat$(EXEEXT) sync$(EXEEXT) \
-	sync_file_range$(EXEEXT) sync_file_range2$(EXEEXT) \
-	sysinfo$(EXEEXT) syslog$(EXEEXT) tee$(EXEEXT) time$(EXEEXT) \
+	status-successful$(EXEEXT) status-successful-long$(EXEEXT) \
+	status-successful-status$(EXEEXT) status-unfinished$(EXEEXT) \
+	statx$(EXEEXT) strace--strings-in-hex$(EXEEXT) \
+	strace--strings-in-hex-all$(EXEEXT) \
+	strace--strings-in-hex-non-ascii$(EXEEXT) strace-n$(EXEEXT) \
+	strace-x$(EXEEXT) strace-xx$(EXEEXT) swap$(EXEEXT) \
+	sxetmask$(EXEEXT) symlink$(EXEEXT) symlinkat$(EXEEXT) \
+	sync$(EXEEXT) sync_file_range$(EXEEXT) \
+	sync_file_range2$(EXEEXT) sysinfo$(EXEEXT) syslog$(EXEEXT) \
+	tee$(EXEEXT) tgkill$(EXEEXT) time$(EXEEXT) \
 	timer_create$(EXEEXT) timer_xettime$(EXEEXT) \
 	timerfd_xettime$(EXEEXT) times$(EXEEXT) times-fail$(EXEEXT) \
-	truncate$(EXEEXT) truncate64$(EXEEXT) ugetrlimit$(EXEEXT) \
-	uio$(EXEEXT) umask$(EXEEXT) umount$(EXEEXT) umount2$(EXEEXT) \
-	umoven-illptr$(EXEEXT) umovestr$(EXEEXT) \
-	umovestr-illptr$(EXEEXT) umovestr2$(EXEEXT) umovestr3$(EXEEXT) \
-	umovestr_cached$(EXEEXT) uname$(EXEEXT) unlink$(EXEEXT) \
-	unlinkat$(EXEEXT) unshare$(EXEEXT) userfaultfd$(EXEEXT) \
-	ustat$(EXEEXT) utime$(EXEEXT) utimensat$(EXEEXT) \
-	utimensat-Xabbrev$(EXEEXT) utimensat-Xraw$(EXEEXT) \
-	utimensat-Xverbose$(EXEEXT) utimes$(EXEEXT) vhangup$(EXEEXT) \
-	vmsplice$(EXEEXT) wait4$(EXEEXT) waitid$(EXEEXT) \
-	waitpid$(EXEEXT) xattr$(EXEEXT) xattr-strings$(EXEEXT) \
-	xet_robust_list$(EXEEXT) xet_thread_area_x86$(EXEEXT) \
-	xetitimer$(EXEEXT) xetpgid$(EXEEXT) xetpriority$(EXEEXT) \
-	xettimeofday$(EXEEXT)
-AR = ar
+	tkill$(EXEEXT) truncate$(EXEEXT) truncate64$(EXEEXT) \
+	ugetrlimit$(EXEEXT) uio$(EXEEXT) umask$(EXEEXT) \
+	umount$(EXEEXT) umount2$(EXEEXT) umoven-illptr$(EXEEXT) \
+	umovestr$(EXEEXT) umovestr-illptr$(EXEEXT) umovestr2$(EXEEXT) \
+	umovestr3$(EXEEXT) umovestr_cached$(EXEEXT) \
+	umovestr_cached_adjacent$(EXEEXT) uname$(EXEEXT) \
+	unlink$(EXEEXT) unlinkat$(EXEEXT) unshare$(EXEEXT) \
+	userfaultfd$(EXEEXT) ustat$(EXEEXT) utime$(EXEEXT) \
+	utimensat$(EXEEXT) utimensat-Xabbrev$(EXEEXT) \
+	utimensat-Xraw$(EXEEXT) utimensat-Xverbose$(EXEEXT) \
+	utimes$(EXEEXT) vhangup$(EXEEXT) vmsplice$(EXEEXT) \
+	wait4$(EXEEXT) waitid$(EXEEXT) waitpid$(EXEEXT) xattr$(EXEEXT) \
+	xattr-strings$(EXEEXT) xet_robust_list$(EXEEXT) \
+	xet_thread_area_x86$(EXEEXT) xetitimer$(EXEEXT) \
+	xetpgid$(EXEEXT) xetpriority$(EXEEXT) xettimeofday$(EXEEXT)
 ARFLAGS = cru
 AM_V_AR = $(am__v_AR_@AM_V@)
 am__v_AR_ = $(am__v_AR_@AM_DEFAULT_V@)
@@ -433,6 +561,7 @@ am__v_AR_1 =
 libtests_a_AR = $(AR) $(ARFLAGS)
 libtests_a_LIBADD =
 am_libtests_a_OBJECTS = libtests_a-create_nl_socket.$(OBJEXT) \
+	libtests_a-create_tmpfile.$(OBJEXT) \
 	libtests_a-errno2name.$(OBJEXT) libtests_a-error_msg.$(OBJEXT) \
 	libtests_a-fill_memory.$(OBJEXT) \
 	libtests_a-get_page_size.$(OBJEXT) \
@@ -444,7 +573,7 @@ am_libtests_a_OBJECTS = libtests_a-creat
 	libtests_a-libmmsg.$(OBJEXT) \
 	libtests_a-libsocketcall.$(OBJEXT) \
 	libtests_a-lock_file.$(OBJEXT) \
-	libtests_a-overflowuid.$(OBJEXT) \
+	libtests_a-overflowuid.$(OBJEXT) libtests_a-pidns.$(OBJEXT) \
 	libtests_a-pipe_maxfd.$(OBJEXT) \
 	libtests_a-print_quoted_string.$(OBJEXT) \
 	libtests_a-print_time.$(OBJEXT) \
@@ -458,7 +587,8 @@ am_libtests_a_OBJECTS = libtests_a-creat
 	libtests_a-tail_alloc.$(OBJEXT) \
 	libtests_a-test_printpath.$(OBJEXT) \
 	libtests_a-test_printstrn.$(OBJEXT) \
-	libtests_a-test_ucopy.$(OBJEXT) libtests_a-tprintf.$(OBJEXT)
+	libtests_a-test_ucopy.$(OBJEXT) libtests_a-tprintf.$(OBJEXT) \
+	libtests_a-xmalloc_for_tests.$(OBJEXT)
 libtests_a_OBJECTS = $(am_libtests_a_OBJECTS)
 _newselect_SOURCES = _newselect.c
 _newselect_OBJECTS = _newselect.$(OBJEXT)
@@ -558,6 +688,10 @@ bpf_success_SOURCES = bpf-success.c
 bpf_success_OBJECTS = bpf-success.$(OBJEXT)
 bpf_success_LDADD = $(LDADD)
 bpf_success_DEPENDENCIES = libtests.a
+bpf_success_long_y_SOURCES = bpf-success-long-y.c
+bpf_success_long_y_OBJECTS = bpf-success-long-y.$(OBJEXT)
+bpf_success_long_y_LDADD = $(LDADD)
+bpf_success_long_y_DEPENDENCIES = libtests.a
 bpf_success_v_SOURCES = bpf-success-v.c
 bpf_success_v_OBJECTS = bpf-success-v.$(OBJEXT)
 bpf_success_v_LDADD = $(LDADD)
@@ -658,10 +792,55 @@ clone_parent_SOURCES = clone_parent.c
 clone_parent_OBJECTS = clone_parent.$(OBJEXT)
 clone_parent_LDADD = $(LDADD)
 clone_parent_DEPENDENCIES = libtests.a
+clone_parent__quiet_exit_SOURCES = clone_parent--quiet-exit.c
+clone_parent__quiet_exit_OBJECTS = clone_parent--quiet-exit.$(OBJEXT)
+clone_parent__quiet_exit_LDADD = $(LDADD)
+clone_parent__quiet_exit_DEPENDENCIES = libtests.a
+clone_parent_q_SOURCES = clone_parent-q.c
+clone_parent_q_OBJECTS = clone_parent-q.$(OBJEXT)
+clone_parent_q_LDADD = $(LDADD)
+clone_parent_q_DEPENDENCIES = libtests.a
+clone_parent_qq_SOURCES = clone_parent-qq.c
+clone_parent_qq_OBJECTS = clone_parent-qq.$(OBJEXT)
+clone_parent_qq_LDADD = $(LDADD)
+clone_parent_qq_DEPENDENCIES = libtests.a
 clone_ptrace_SOURCES = clone_ptrace.c
 clone_ptrace_OBJECTS = clone_ptrace.$(OBJEXT)
 clone_ptrace_LDADD = $(LDADD)
 clone_ptrace_DEPENDENCIES = libtests.a
+clone_ptrace__quiet_attach_SOURCES = clone_ptrace--quiet-attach.c
+clone_ptrace__quiet_attach_OBJECTS =  \
+	clone_ptrace--quiet-attach.$(OBJEXT)
+clone_ptrace__quiet_attach_LDADD = $(LDADD)
+clone_ptrace__quiet_attach_DEPENDENCIES = libtests.a
+clone_ptrace__quiet_exit_SOURCES = clone_ptrace--quiet-exit.c
+clone_ptrace__quiet_exit_OBJECTS = clone_ptrace--quiet-exit.$(OBJEXT)
+clone_ptrace__quiet_exit_LDADD = $(LDADD)
+clone_ptrace__quiet_exit_DEPENDENCIES = libtests.a
+clone_ptrace_q_SOURCES = clone_ptrace-q.c
+clone_ptrace_q_OBJECTS = clone_ptrace-q.$(OBJEXT)
+clone_ptrace_q_LDADD = $(LDADD)
+clone_ptrace_q_DEPENDENCIES = libtests.a
+clone_ptrace_qq_SOURCES = clone_ptrace-qq.c
+clone_ptrace_qq_OBJECTS = clone_ptrace-qq.$(OBJEXT)
+clone_ptrace_qq_LDADD = $(LDADD)
+clone_ptrace_qq_DEPENDENCIES = libtests.a
+close_range_SOURCES = close_range.c
+close_range_OBJECTS = close_range.$(OBJEXT)
+close_range_LDADD = $(LDADD)
+close_range_DEPENDENCIES = libtests.a
+close_range_P_SOURCES = close_range-P.c
+close_range_P_OBJECTS = close_range-P.$(OBJEXT)
+close_range_P_LDADD = $(LDADD)
+close_range_P_DEPENDENCIES = libtests.a
+close_range_y_SOURCES = close_range-y.c
+close_range_y_OBJECTS = close_range-y.$(OBJEXT)
+close_range_y_LDADD = $(LDADD)
+close_range_y_DEPENDENCIES = libtests.a
+close_range_yy_SOURCES = close_range-yy.c
+close_range_yy_OBJECTS = close_range-yy.$(OBJEXT)
+close_range_yy_LDADD = $(LDADD)
+close_range_yy_DEPENDENCIES = libtests.a
 copy_file_range_SOURCES = copy_file_range.c
 copy_file_range_OBJECTS = copy_file_range.$(OBJEXT)
 copy_file_range_LDADD = $(LDADD)
@@ -681,6 +860,18 @@ delete_module_SOURCES = delete_module.c
 delete_module_OBJECTS = delete_module.$(OBJEXT)
 delete_module_LDADD = $(LDADD)
 delete_module_DEPENDENCIES = libtests.a
+dev__decode_fds_dev_SOURCES = dev--decode-fds-dev.c
+dev__decode_fds_dev_OBJECTS = dev--decode-fds-dev.$(OBJEXT)
+dev__decode_fds_dev_LDADD = $(LDADD)
+dev__decode_fds_dev_DEPENDENCIES = libtests.a
+dev__decode_fds_path_SOURCES = dev--decode-fds-path.c
+dev__decode_fds_path_OBJECTS = dev--decode-fds-path.$(OBJEXT)
+dev__decode_fds_path_LDADD = $(LDADD)
+dev__decode_fds_path_DEPENDENCIES = libtests.a
+dev__decode_fds_socket_SOURCES = dev--decode-fds-socket.c
+dev__decode_fds_socket_OBJECTS = dev--decode-fds-socket.$(OBJEXT)
+dev__decode_fds_socket_LDADD = $(LDADD)
+dev__decode_fds_socket_DEPENDENCIES = libtests.a
 dev_yy_SOURCES = dev-yy.c
 dev_yy_OBJECTS = dev-yy.$(OBJEXT)
 dev_yy_LDADD = $(LDADD)
@@ -689,14 +880,50 @@ dup_SOURCES = dup.c
 dup_OBJECTS = dup.$(OBJEXT)
 dup_LDADD = $(LDADD)
 dup_DEPENDENCIES = libtests.a
+dup_P_SOURCES = dup-P.c
+dup_P_OBJECTS = dup-P.$(OBJEXT)
+dup_P_LDADD = $(LDADD)
+dup_P_DEPENDENCIES = libtests.a
+dup_y_SOURCES = dup-y.c
+dup_y_OBJECTS = dup-y.$(OBJEXT)
+dup_y_LDADD = $(LDADD)
+dup_y_DEPENDENCIES = libtests.a
+dup_yy_SOURCES = dup-yy.c
+dup_yy_OBJECTS = dup-yy.$(OBJEXT)
+dup_yy_LDADD = $(LDADD)
+dup_yy_DEPENDENCIES = libtests.a
 dup2_SOURCES = dup2.c
 dup2_OBJECTS = dup2.$(OBJEXT)
 dup2_LDADD = $(LDADD)
 dup2_DEPENDENCIES = libtests.a
+dup2_P_SOURCES = dup2-P.c
+dup2_P_OBJECTS = dup2-P.$(OBJEXT)
+dup2_P_LDADD = $(LDADD)
+dup2_P_DEPENDENCIES = libtests.a
+dup2_y_SOURCES = dup2-y.c
+dup2_y_OBJECTS = dup2-y.$(OBJEXT)
+dup2_y_LDADD = $(LDADD)
+dup2_y_DEPENDENCIES = libtests.a
+dup2_yy_SOURCES = dup2-yy.c
+dup2_yy_OBJECTS = dup2-yy.$(OBJEXT)
+dup2_yy_LDADD = $(LDADD)
+dup2_yy_DEPENDENCIES = libtests.a
 dup3_SOURCES = dup3.c
 dup3_OBJECTS = dup3.$(OBJEXT)
 dup3_LDADD = $(LDADD)
 dup3_DEPENDENCIES = libtests.a
+dup3_P_SOURCES = dup3-P.c
+dup3_P_OBJECTS = dup3-P.$(OBJEXT)
+dup3_P_LDADD = $(LDADD)
+dup3_P_DEPENDENCIES = libtests.a
+dup3_y_SOURCES = dup3-y.c
+dup3_y_OBJECTS = dup3-y.$(OBJEXT)
+dup3_y_LDADD = $(LDADD)
+dup3_y_DEPENDENCIES = libtests.a
+dup3_yy_SOURCES = dup3-yy.c
+dup3_yy_OBJECTS = dup3-yy.$(OBJEXT)
+dup3_yy_LDADD = $(LDADD)
+dup3_yy_DEPENDENCIES = libtests.a
 epoll_create_SOURCES = epoll_create.c
 epoll_create_OBJECTS = epoll_create.$(OBJEXT)
 epoll_create_LDADD = $(LDADD)
@@ -745,6 +972,34 @@ faccessat_SOURCES = faccessat.c
 faccessat_OBJECTS = faccessat.$(OBJEXT)
 faccessat_LDADD = $(LDADD)
 faccessat_DEPENDENCIES = libtests.a
+faccessat_P_SOURCES = faccessat-P.c
+faccessat_P_OBJECTS = faccessat-P.$(OBJEXT)
+faccessat_P_LDADD = $(LDADD)
+faccessat_P_DEPENDENCIES = libtests.a
+faccessat_y_SOURCES = faccessat-y.c
+faccessat_y_OBJECTS = faccessat-y.$(OBJEXT)
+faccessat_y_LDADD = $(LDADD)
+faccessat_y_DEPENDENCIES = libtests.a
+faccessat_yy_SOURCES = faccessat-yy.c
+faccessat_yy_OBJECTS = faccessat-yy.$(OBJEXT)
+faccessat_yy_LDADD = $(LDADD)
+faccessat_yy_DEPENDENCIES = libtests.a
+faccessat2_SOURCES = faccessat2.c
+faccessat2_OBJECTS = faccessat2.$(OBJEXT)
+faccessat2_LDADD = $(LDADD)
+faccessat2_DEPENDENCIES = libtests.a
+faccessat2_P_SOURCES = faccessat2-P.c
+faccessat2_P_OBJECTS = faccessat2-P.$(OBJEXT)
+faccessat2_P_LDADD = $(LDADD)
+faccessat2_P_DEPENDENCIES = libtests.a
+faccessat2_y_SOURCES = faccessat2-y.c
+faccessat2_y_OBJECTS = faccessat2-y.$(OBJEXT)
+faccessat2_y_LDADD = $(LDADD)
+faccessat2_y_DEPENDENCIES = libtests.a
+faccessat2_yy_SOURCES = faccessat2-yy.c
+faccessat2_yy_OBJECTS = faccessat2-yy.$(OBJEXT)
+faccessat2_yy_LDADD = $(LDADD)
+faccessat2_yy_DEPENDENCIES = libtests.a
 fadvise64_SOURCES = fadvise64.c
 fadvise64_OBJECTS = fadvise64.$(OBJEXT)
 fadvise64_LDADD = $(LDADD)
@@ -805,10 +1060,19 @@ fcntl_SOURCES = fcntl.c
 fcntl_OBJECTS = fcntl.$(OBJEXT)
 fcntl_LDADD = $(LDADD)
 fcntl_DEPENDENCIES = libtests.a
+fcntl__pidns_translation_SOURCES = fcntl--pidns-translation.c
+fcntl__pidns_translation_OBJECTS = fcntl--pidns-translation.$(OBJEXT)
+fcntl__pidns_translation_LDADD = $(LDADD)
+fcntl__pidns_translation_DEPENDENCIES = libtests.a
 fcntl64_SOURCES = fcntl64.c
 fcntl64_OBJECTS = fcntl64.$(OBJEXT)
 fcntl64_LDADD = $(LDADD)
 fcntl64_DEPENDENCIES = libtests.a
+fcntl64__pidns_translation_SOURCES = fcntl64--pidns-translation.c
+fcntl64__pidns_translation_OBJECTS =  \
+	fcntl64--pidns-translation.$(OBJEXT)
+fcntl64__pidns_translation_LDADD = $(LDADD)
+fcntl64__pidns_translation_DEPENDENCIES = libtests.a
 fdatasync_SOURCES = fdatasync.c
 fdatasync_OBJECTS = fdatasync.$(OBJEXT)
 fdatasync_LDADD = $(LDADD)
@@ -844,6 +1108,10 @@ flock_SOURCES = flock.c
 flock_OBJECTS = flock.$(OBJEXT)
 flock_LDADD = $(LDADD)
 flock_DEPENDENCIES = libtests.a
+fork__pidns_translation_SOURCES = fork--pidns-translation.c
+fork__pidns_translation_OBJECTS = fork--pidns-translation.$(OBJEXT)
+fork__pidns_translation_LDADD = $(LDADD)
+fork__pidns_translation_DEPENDENCIES = libtests.a
 fork_f_SOURCES = fork-f.c
 fork_f_OBJECTS = fork-f.$(OBJEXT)
 fork_f_LDADD = $(LDADD)
@@ -944,6 +1212,10 @@ get_mempolicy_SOURCES = get_mempolicy.c
 get_mempolicy_OBJECTS = get_mempolicy.$(OBJEXT)
 get_mempolicy_LDADD = $(LDADD)
 get_mempolicy_DEPENDENCIES = libtests.a
+get_process_reaper_SOURCES = get_process_reaper.c
+get_process_reaper_OBJECTS = get_process_reaper.$(OBJEXT)
+get_process_reaper_LDADD = $(LDADD)
+get_process_reaper_DEPENDENCIES = libtests.a
 getcpu_SOURCES = getcpu.c
 getcpu_OBJECTS = getcpu.$(OBJEXT)
 getcpu_LDADD = $(LDADD)
@@ -956,10 +1228,18 @@ getdents_SOURCES = getdents.c
 getdents_OBJECTS = getdents.$(OBJEXT)
 getdents_LDADD = $(LDADD)
 getdents_DEPENDENCIES = libtests.a
+getdents_v_SOURCES = getdents-v.c
+getdents_v_OBJECTS = getdents-v.$(OBJEXT)
+getdents_v_LDADD = $(LDADD)
+getdents_v_DEPENDENCIES = libtests.a
 getdents64_SOURCES = getdents64.c
 getdents64_OBJECTS = getdents64.$(OBJEXT)
 getdents64_LDADD = $(LDADD)
 getdents64_DEPENDENCIES = libtests.a
+getdents64_v_SOURCES = getdents64-v.c
+getdents64_v_OBJECTS = getdents64-v.$(OBJEXT)
+getdents64_v_LDADD = $(LDADD)
+getdents64_v_DEPENDENCIES = libtests.a
 getegid_SOURCES = getegid.c
 getegid_OBJECTS = getegid.$(OBJEXT)
 getegid_LDADD = $(LDADD)
@@ -1000,10 +1280,20 @@ getpgrp_SOURCES = getpgrp.c
 getpgrp_OBJECTS = getpgrp.$(OBJEXT)
 getpgrp_LDADD = $(LDADD)
 getpgrp_DEPENDENCIES = libtests.a
+getpgrp__pidns_translation_SOURCES = getpgrp--pidns-translation.c
+getpgrp__pidns_translation_OBJECTS =  \
+	getpgrp--pidns-translation.$(OBJEXT)
+getpgrp__pidns_translation_LDADD = $(LDADD)
+getpgrp__pidns_translation_DEPENDENCIES = libtests.a
 getpid_SOURCES = getpid.c
 getpid_OBJECTS = getpid.$(OBJEXT)
 getpid_LDADD = $(LDADD)
 getpid_DEPENDENCIES = libtests.a
+getpid__pidns_translation_SOURCES = getpid--pidns-translation.c
+getpid__pidns_translation_OBJECTS =  \
+	getpid--pidns-translation.$(OBJEXT)
+getpid__pidns_translation_LDADD = $(LDADD)
+getpid__pidns_translation_DEPENDENCIES = libtests.a
 getppid_SOURCES = getppid.c
 getppid_OBJECTS = getppid.$(OBJEXT)
 getppid_LDADD = $(LDADD)
@@ -1040,6 +1330,11 @@ getsid_SOURCES = getsid.c
 getsid_OBJECTS = getsid.$(OBJEXT)
 getsid_LDADD = $(LDADD)
 getsid_DEPENDENCIES = libtests.a
+getsid__pidns_translation_SOURCES = getsid--pidns-translation.c
+getsid__pidns_translation_OBJECTS =  \
+	getsid--pidns-translation.$(OBJEXT)
+getsid__pidns_translation_LDADD = $(LDADD)
+getsid__pidns_translation_DEPENDENCIES = libtests.a
 getsockname_SOURCES = getsockname.c
 getsockname_OBJECTS = getsockname.$(OBJEXT)
 getsockname_LDADD = $(LDADD)
@@ -1048,6 +1343,11 @@ gettid_SOURCES = gettid.c
 gettid_OBJECTS = gettid.$(OBJEXT)
 gettid_LDADD = $(LDADD)
 gettid_DEPENDENCIES = libtests.a
+gettid__pidns_translation_SOURCES = gettid--pidns-translation.c
+gettid__pidns_translation_OBJECTS =  \
+	gettid--pidns-translation.$(OBJEXT)
+gettid__pidns_translation_LDADD = $(LDADD)
+gettid__pidns_translation_DEPENDENCIES = libtests.a
 getuid_SOURCES = getuid.c
 getuid_OBJECTS = getuid.$(OBJEXT)
 getuid_LDADD = $(LDADD)
@@ -1056,10 +1356,18 @@ getuid32_SOURCES = getuid32.c
 getuid32_OBJECTS = getuid32.$(OBJEXT)
 getuid32_LDADD = $(LDADD)
 getuid32_DEPENDENCIES = libtests.a
-getxxid_SOURCES = getxxid.c
-getxxid_OBJECTS = getxxid.$(OBJEXT)
-getxxid_LDADD = $(LDADD)
-getxxid_DEPENDENCIES = libtests.a
+getxgid_SOURCES = getxgid.c
+getxgid_OBJECTS = getxgid.$(OBJEXT)
+getxgid_LDADD = $(LDADD)
+getxgid_DEPENDENCIES = libtests.a
+getxpid_SOURCES = getxpid.c
+getxpid_OBJECTS = getxpid.$(OBJEXT)
+getxpid_LDADD = $(LDADD)
+getxpid_DEPENDENCIES = libtests.a
+getxuid_SOURCES = getxuid.c
+getxuid_OBJECTS = getxuid.$(OBJEXT)
+getxuid_LDADD = $(LDADD)
+getxuid_DEPENDENCIES = libtests.a
 group_req_SOURCES = group_req.c
 group_req_OBJECTS = group_req.$(OBJEXT)
 group_req_LDADD = $(LDADD)
@@ -1120,6 +1428,12 @@ ioctl_block_SOURCES = ioctl_block.c
 ioctl_block_OBJECTS = ioctl_block.$(OBJEXT)
 ioctl_block_LDADD = $(LDADD)
 ioctl_block_DEPENDENCIES = libtests.a
+ioctl_block__pidns_translation_SOURCES =  \
+	ioctl_block--pidns-translation.c
+ioctl_block__pidns_translation_OBJECTS =  \
+	ioctl_block--pidns-translation.$(OBJEXT)
+ioctl_block__pidns_translation_LDADD = $(LDADD)
+ioctl_block__pidns_translation_DEPENDENCIES = libtests.a
 ioctl_dm_SOURCES = ioctl_dm.c
 ioctl_dm_OBJECTS = ioctl_dm.$(OBJEXT)
 ioctl_dm_LDADD = $(LDADD)
@@ -1199,6 +1513,76 @@ ioctl_evdev_v_Xverbose_SOURCES = ioctl_e
 ioctl_evdev_v_Xverbose_OBJECTS = ioctl_evdev-v-Xverbose.$(OBJEXT)
 ioctl_evdev_v_Xverbose_LDADD = $(LDADD)
 ioctl_evdev_v_Xverbose_DEPENDENCIES = libtests.a
+ioctl_hdio_SOURCES = ioctl_hdio.c
+ioctl_hdio_OBJECTS = ioctl_hdio.$(OBJEXT)
+ioctl_hdio_LDADD = $(LDADD)
+ioctl_hdio_DEPENDENCIES = libtests.a
+ioctl_hdio_Xabbrev_SOURCES = ioctl_hdio-Xabbrev.c
+ioctl_hdio_Xabbrev_OBJECTS = ioctl_hdio-Xabbrev.$(OBJEXT)
+ioctl_hdio_Xabbrev_LDADD = $(LDADD)
+ioctl_hdio_Xabbrev_DEPENDENCIES = libtests.a
+ioctl_hdio_Xraw_SOURCES = ioctl_hdio-Xraw.c
+ioctl_hdio_Xraw_OBJECTS = ioctl_hdio-Xraw.$(OBJEXT)
+ioctl_hdio_Xraw_LDADD = $(LDADD)
+ioctl_hdio_Xraw_DEPENDENCIES = libtests.a
+ioctl_hdio_Xverbose_SOURCES = ioctl_hdio-Xverbose.c
+ioctl_hdio_Xverbose_OBJECTS = ioctl_hdio-Xverbose.$(OBJEXT)
+ioctl_hdio_Xverbose_LDADD = $(LDADD)
+ioctl_hdio_Xverbose_DEPENDENCIES = libtests.a
+ioctl_hdio_success_SOURCES = ioctl_hdio-success.c
+ioctl_hdio_success_OBJECTS = ioctl_hdio-success.$(OBJEXT)
+ioctl_hdio_success_LDADD = $(LDADD)
+ioctl_hdio_success_DEPENDENCIES = libtests.a
+ioctl_hdio_success_Xabbrev_SOURCES = ioctl_hdio-success-Xabbrev.c
+ioctl_hdio_success_Xabbrev_OBJECTS =  \
+	ioctl_hdio-success-Xabbrev.$(OBJEXT)
+ioctl_hdio_success_Xabbrev_LDADD = $(LDADD)
+ioctl_hdio_success_Xabbrev_DEPENDENCIES = libtests.a
+ioctl_hdio_success_Xraw_SOURCES = ioctl_hdio-success-Xraw.c
+ioctl_hdio_success_Xraw_OBJECTS = ioctl_hdio-success-Xraw.$(OBJEXT)
+ioctl_hdio_success_Xraw_LDADD = $(LDADD)
+ioctl_hdio_success_Xraw_DEPENDENCIES = libtests.a
+ioctl_hdio_success_Xverbose_SOURCES = ioctl_hdio-success-Xverbose.c
+ioctl_hdio_success_Xverbose_OBJECTS =  \
+	ioctl_hdio-success-Xverbose.$(OBJEXT)
+ioctl_hdio_success_Xverbose_LDADD = $(LDADD)
+ioctl_hdio_success_Xverbose_DEPENDENCIES = libtests.a
+ioctl_hdio_success_v_SOURCES = ioctl_hdio-success-v.c
+ioctl_hdio_success_v_OBJECTS = ioctl_hdio-success-v.$(OBJEXT)
+ioctl_hdio_success_v_LDADD = $(LDADD)
+ioctl_hdio_success_v_DEPENDENCIES = libtests.a
+ioctl_hdio_success_v_Xabbrev_SOURCES = ioctl_hdio-success-v-Xabbrev.c
+ioctl_hdio_success_v_Xabbrev_OBJECTS =  \
+	ioctl_hdio-success-v-Xabbrev.$(OBJEXT)
+ioctl_hdio_success_v_Xabbrev_LDADD = $(LDADD)
+ioctl_hdio_success_v_Xabbrev_DEPENDENCIES = libtests.a
+ioctl_hdio_success_v_Xraw_SOURCES = ioctl_hdio-success-v-Xraw.c
+ioctl_hdio_success_v_Xraw_OBJECTS =  \
+	ioctl_hdio-success-v-Xraw.$(OBJEXT)
+ioctl_hdio_success_v_Xraw_LDADD = $(LDADD)
+ioctl_hdio_success_v_Xraw_DEPENDENCIES = libtests.a
+ioctl_hdio_success_v_Xverbose_SOURCES =  \
+	ioctl_hdio-success-v-Xverbose.c
+ioctl_hdio_success_v_Xverbose_OBJECTS =  \
+	ioctl_hdio-success-v-Xverbose.$(OBJEXT)
+ioctl_hdio_success_v_Xverbose_LDADD = $(LDADD)
+ioctl_hdio_success_v_Xverbose_DEPENDENCIES = libtests.a
+ioctl_hdio_v_SOURCES = ioctl_hdio-v.c
+ioctl_hdio_v_OBJECTS = ioctl_hdio-v.$(OBJEXT)
+ioctl_hdio_v_LDADD = $(LDADD)
+ioctl_hdio_v_DEPENDENCIES = libtests.a
+ioctl_hdio_v_Xabbrev_SOURCES = ioctl_hdio-v-Xabbrev.c
+ioctl_hdio_v_Xabbrev_OBJECTS = ioctl_hdio-v-Xabbrev.$(OBJEXT)
+ioctl_hdio_v_Xabbrev_LDADD = $(LDADD)
+ioctl_hdio_v_Xabbrev_DEPENDENCIES = libtests.a
+ioctl_hdio_v_Xraw_SOURCES = ioctl_hdio-v-Xraw.c
+ioctl_hdio_v_Xraw_OBJECTS = ioctl_hdio-v-Xraw.$(OBJEXT)
+ioctl_hdio_v_Xraw_LDADD = $(LDADD)
+ioctl_hdio_v_Xraw_DEPENDENCIES = libtests.a
+ioctl_hdio_v_Xverbose_SOURCES = ioctl_hdio-v-Xverbose.c
+ioctl_hdio_v_Xverbose_OBJECTS = ioctl_hdio-v-Xverbose.$(OBJEXT)
+ioctl_hdio_v_Xverbose_LDADD = $(LDADD)
+ioctl_hdio_v_Xverbose_DEPENDENCIES = libtests.a
 ioctl_inotify_SOURCES = ioctl_inotify.c
 ioctl_inotify_OBJECTS = ioctl_inotify.$(OBJEXT)
 ioctl_inotify_LDADD = $(LDADD)
@@ -1280,6 +1664,10 @@ ioctl_sock_gifconf_SOURCES = ioctl_sock_
 ioctl_sock_gifconf_OBJECTS = ioctl_sock_gifconf.$(OBJEXT)
 ioctl_sock_gifconf_LDADD = $(LDADD)
 ioctl_sock_gifconf_DEPENDENCIES = libtests.a
+ioctl_tee_SOURCES = ioctl_tee.c
+ioctl_tee_OBJECTS = ioctl_tee.$(OBJEXT)
+ioctl_tee_LDADD = $(LDADD)
+ioctl_tee_DEPENDENCIES = libtests.a
 ioctl_uffdio_SOURCES = ioctl_uffdio.c
 ioctl_uffdio_OBJECTS = ioctl_uffdio.$(OBJEXT)
 ioctl_uffdio_LDADD = $(LDADD)
@@ -1288,6 +1676,72 @@ ioctl_v4l2_SOURCES = ioctl_v4l2.c
 ioctl_v4l2_OBJECTS = ioctl_v4l2.$(OBJEXT)
 ioctl_v4l2_LDADD = $(LDADD)
 ioctl_v4l2_DEPENDENCIES = libtests.a
+ioctl_v4l2_Xabbrev_SOURCES = ioctl_v4l2-Xabbrev.c
+ioctl_v4l2_Xabbrev_OBJECTS = ioctl_v4l2-Xabbrev.$(OBJEXT)
+ioctl_v4l2_Xabbrev_LDADD = $(LDADD)
+ioctl_v4l2_Xabbrev_DEPENDENCIES = libtests.a
+ioctl_v4l2_Xraw_SOURCES = ioctl_v4l2-Xraw.c
+ioctl_v4l2_Xraw_OBJECTS = ioctl_v4l2-Xraw.$(OBJEXT)
+ioctl_v4l2_Xraw_LDADD = $(LDADD)
+ioctl_v4l2_Xraw_DEPENDENCIES = libtests.a
+ioctl_v4l2_Xverbose_SOURCES = ioctl_v4l2-Xverbose.c
+ioctl_v4l2_Xverbose_OBJECTS = ioctl_v4l2-Xverbose.$(OBJEXT)
+ioctl_v4l2_Xverbose_LDADD = $(LDADD)
+ioctl_v4l2_Xverbose_DEPENDENCIES = libtests.a
+ioctl_v4l2_success_SOURCES = ioctl_v4l2-success.c
+ioctl_v4l2_success_OBJECTS = ioctl_v4l2-success.$(OBJEXT)
+ioctl_v4l2_success_LDADD = $(LDADD)
+ioctl_v4l2_success_DEPENDENCIES = libtests.a
+ioctl_v4l2_success_Xabbrev_SOURCES = ioctl_v4l2-success-Xabbrev.c
+ioctl_v4l2_success_Xabbrev_OBJECTS =  \
+	ioctl_v4l2-success-Xabbrev.$(OBJEXT)
+ioctl_v4l2_success_Xabbrev_LDADD = $(LDADD)
+ioctl_v4l2_success_Xabbrev_DEPENDENCIES = libtests.a
+ioctl_v4l2_success_Xraw_SOURCES = ioctl_v4l2-success-Xraw.c
+ioctl_v4l2_success_Xraw_OBJECTS = ioctl_v4l2-success-Xraw.$(OBJEXT)
+ioctl_v4l2_success_Xraw_LDADD = $(LDADD)
+ioctl_v4l2_success_Xraw_DEPENDENCIES = libtests.a
+ioctl_v4l2_success_Xverbose_SOURCES = ioctl_v4l2-success-Xverbose.c
+ioctl_v4l2_success_Xverbose_OBJECTS =  \
+	ioctl_v4l2-success-Xverbose.$(OBJEXT)
+ioctl_v4l2_success_Xverbose_LDADD = $(LDADD)
+ioctl_v4l2_success_Xverbose_DEPENDENCIES = libtests.a
+ioctl_v4l2_success_v_SOURCES = ioctl_v4l2-success-v.c
+ioctl_v4l2_success_v_OBJECTS = ioctl_v4l2-success-v.$(OBJEXT)
+ioctl_v4l2_success_v_LDADD = $(LDADD)
+ioctl_v4l2_success_v_DEPENDENCIES = libtests.a
+ioctl_v4l2_success_v_Xabbrev_SOURCES = ioctl_v4l2-success-v-Xabbrev.c
+ioctl_v4l2_success_v_Xabbrev_OBJECTS =  \
+	ioctl_v4l2-success-v-Xabbrev.$(OBJEXT)
+ioctl_v4l2_success_v_Xabbrev_LDADD = $(LDADD)
+ioctl_v4l2_success_v_Xabbrev_DEPENDENCIES = libtests.a
+ioctl_v4l2_success_v_Xraw_SOURCES = ioctl_v4l2-success-v-Xraw.c
+ioctl_v4l2_success_v_Xraw_OBJECTS =  \
+	ioctl_v4l2-success-v-Xraw.$(OBJEXT)
+ioctl_v4l2_success_v_Xraw_LDADD = $(LDADD)
+ioctl_v4l2_success_v_Xraw_DEPENDENCIES = libtests.a
+ioctl_v4l2_success_v_Xverbose_SOURCES =  \
+	ioctl_v4l2-success-v-Xverbose.c
+ioctl_v4l2_success_v_Xverbose_OBJECTS =  \
+	ioctl_v4l2-success-v-Xverbose.$(OBJEXT)
+ioctl_v4l2_success_v_Xverbose_LDADD = $(LDADD)
+ioctl_v4l2_success_v_Xverbose_DEPENDENCIES = libtests.a
+ioctl_v4l2_v_SOURCES = ioctl_v4l2-v.c
+ioctl_v4l2_v_OBJECTS = ioctl_v4l2-v.$(OBJEXT)
+ioctl_v4l2_v_LDADD = $(LDADD)
+ioctl_v4l2_v_DEPENDENCIES = libtests.a
+ioctl_v4l2_v_Xabbrev_SOURCES = ioctl_v4l2-v-Xabbrev.c
+ioctl_v4l2_v_Xabbrev_OBJECTS = ioctl_v4l2-v-Xabbrev.$(OBJEXT)
+ioctl_v4l2_v_Xabbrev_LDADD = $(LDADD)
+ioctl_v4l2_v_Xabbrev_DEPENDENCIES = libtests.a
+ioctl_v4l2_v_Xraw_SOURCES = ioctl_v4l2-v-Xraw.c
+ioctl_v4l2_v_Xraw_OBJECTS = ioctl_v4l2-v-Xraw.$(OBJEXT)
+ioctl_v4l2_v_Xraw_LDADD = $(LDADD)
+ioctl_v4l2_v_Xraw_DEPENDENCIES = libtests.a
+ioctl_v4l2_v_Xverbose_SOURCES = ioctl_v4l2-v-Xverbose.c
+ioctl_v4l2_v_Xverbose_OBJECTS = ioctl_v4l2-v-Xverbose.$(OBJEXT)
+ioctl_v4l2_v_Xverbose_LDADD = $(LDADD)
+ioctl_v4l2_v_Xverbose_DEPENDENCIES = libtests.a
 ioctl_watchdog_SOURCES = ioctl_watchdog.c
 ioctl_watchdog_OBJECTS = ioctl_watchdog.$(OBJEXT)
 ioctl_watchdog_LDADD = $(LDADD)
@@ -1304,6 +1758,11 @@ ioprio_SOURCES = ioprio.c
 ioprio_OBJECTS = ioprio.$(OBJEXT)
 ioprio_LDADD = $(LDADD)
 ioprio_DEPENDENCIES = libtests.a
+ioprio__pidns_translation_SOURCES = ioprio--pidns-translation.c
+ioprio__pidns_translation_OBJECTS =  \
+	ioprio--pidns-translation.$(OBJEXT)
+ioprio__pidns_translation_LDADD = $(LDADD)
+ioprio__pidns_translation_DEPENDENCIES = libtests.a
 ioprio_Xabbrev_SOURCES = ioprio-Xabbrev.c
 ioprio_Xabbrev_OBJECTS = ioprio-Xabbrev.$(OBJEXT)
 ioprio_Xabbrev_LDADD = $(LDADD)
@@ -1400,6 +1859,11 @@ kcmp_y_SOURCES = kcmp-y.c
 kcmp_y_OBJECTS = kcmp-y.$(OBJEXT)
 kcmp_y_LDADD = $(LDADD)
 kcmp_y_DEPENDENCIES = libtests.a
+kcmp_y__pidns_translation_SOURCES = kcmp-y--pidns-translation.c
+kcmp_y__pidns_translation_OBJECTS =  \
+	kcmp-y--pidns-translation.$(OBJEXT)
+kcmp_y__pidns_translation_LDADD = $(LDADD)
+kcmp_y__pidns_translation_DEPENDENCIES = libtests.a
 kern_features_SOURCES = kern_features.c
 kern_features_OBJECTS = kern_features.$(OBJEXT)
 kern_features_LDADD = $(LDADD)
@@ -1448,6 +1912,10 @@ kill_SOURCES = kill.c
 kill_OBJECTS = kill.$(OBJEXT)
 kill_LDADD = $(LDADD)
 kill_DEPENDENCIES = libtests.a
+kill__pidns_translation_SOURCES = kill--pidns-translation.c
+kill__pidns_translation_OBJECTS = kill--pidns-translation.$(OBJEXT)
+kill__pidns_translation_LDADD = $(LDADD)
+kill__pidns_translation_DEPENDENCIES = libtests.a
 kill_child_SOURCES = kill_child.c
 kill_child_OBJECTS = kill_child.$(OBJEXT)
 kill_child_LDADD = $(LDADD)
@@ -1509,6 +1977,11 @@ madvise_DEPENDENCIES = libtests.a
 maybe_switch_current_tcp_SOURCES = maybe_switch_current_tcp.c
 maybe_switch_current_tcp_OBJECTS = maybe_switch_current_tcp.$(OBJEXT)
 maybe_switch_current_tcp_DEPENDENCIES = $(LDADD)
+maybe_switch_current_tcp__quiet_thread_execve_SOURCES =  \
+	maybe_switch_current_tcp--quiet-thread-execve.c
+maybe_switch_current_tcp__quiet_thread_execve_OBJECTS =  \
+	maybe_switch_current_tcp--quiet-thread-execve.$(OBJEXT)
+maybe_switch_current_tcp__quiet_thread_execve_DEPENDENCIES = $(LDADD)
 mbind_SOURCES = mbind.c
 mbind_OBJECTS = mbind.$(OBJEXT)
 mbind_LDADD = $(LDADD)
@@ -1549,6 +2022,12 @@ migrate_pages_SOURCES = migrate_pages.c
 migrate_pages_OBJECTS = migrate_pages.$(OBJEXT)
 migrate_pages_LDADD = $(LDADD)
 migrate_pages_DEPENDENCIES = libtests.a
+migrate_pages__pidns_translation_SOURCES =  \
+	migrate_pages--pidns-translation.c
+migrate_pages__pidns_translation_OBJECTS =  \
+	migrate_pages--pidns-translation.$(OBJEXT)
+migrate_pages__pidns_translation_LDADD = $(LDADD)
+migrate_pages__pidns_translation_DEPENDENCIES = libtests.a
 mincore_SOURCES = mincore.c
 mincore_OBJECTS = mincore.$(OBJEXT)
 mincore_LDADD = $(LDADD)
@@ -1661,6 +2140,12 @@ move_pages_SOURCES = move_pages.c
 move_pages_OBJECTS = move_pages.$(OBJEXT)
 move_pages_LDADD = $(LDADD)
 move_pages_DEPENDENCIES = libtests.a
+move_pages__pidns_translation_SOURCES =  \
+	move_pages--pidns-translation.c
+move_pages__pidns_translation_OBJECTS =  \
+	move_pages--pidns-translation.$(OBJEXT)
+move_pages__pidns_translation_LDADD = $(LDADD)
+move_pages__pidns_translation_DEPENDENCIES = libtests.a
 move_pages_Xabbrev_SOURCES = move_pages-Xabbrev.c
 move_pages_Xabbrev_OBJECTS = move_pages-Xabbrev.$(OBJEXT)
 move_pages_Xabbrev_LDADD = $(LDADD)
@@ -1708,6 +2193,27 @@ nanosleep_SOURCES = nanosleep.c
 nanosleep_OBJECTS = nanosleep.$(OBJEXT)
 nanosleep_LDADD = $(LDADD)
 nanosleep_DEPENDENCIES = libtests.a
+net__decode_fds_dev_netlink_SOURCES = net--decode-fds-dev-netlink.c
+net__decode_fds_dev_netlink_OBJECTS =  \
+	net--decode-fds-dev-netlink.$(OBJEXT)
+net__decode_fds_dev_netlink_LDADD = $(LDADD)
+net__decode_fds_dev_netlink_DEPENDENCIES = libtests.a
+net__decode_fds_none_netlink_SOURCES = net--decode-fds-none-netlink.c
+net__decode_fds_none_netlink_OBJECTS =  \
+	net--decode-fds-none-netlink.$(OBJEXT)
+net__decode_fds_none_netlink_LDADD = $(LDADD)
+net__decode_fds_none_netlink_DEPENDENCIES = libtests.a
+net__decode_fds_path_netlink_SOURCES = net--decode-fds-path-netlink.c
+net__decode_fds_path_netlink_OBJECTS =  \
+	net--decode-fds-path-netlink.$(OBJEXT)
+net__decode_fds_path_netlink_LDADD = $(LDADD)
+net__decode_fds_path_netlink_DEPENDENCIES = libtests.a
+net__decode_fds_socket_netlink_SOURCES =  \
+	net--decode-fds-socket-netlink.c
+net__decode_fds_socket_netlink_OBJECTS =  \
+	net--decode-fds-socket-netlink.$(OBJEXT)
+net__decode_fds_socket_netlink_LDADD = $(LDADD)
+net__decode_fds_socket_netlink_DEPENDENCIES = libtests.a
 net_accept_connect_SOURCES = net-accept-connect.c
 net_accept_connect_OBJECTS = net-accept-connect.$(OBJEXT)
 net_accept_connect_LDADD = $(LDADD)
@@ -1736,6 +2242,12 @@ net_sockaddr_SOURCES = net-sockaddr.c
 net_sockaddr_OBJECTS = net-sockaddr.$(OBJEXT)
 net_sockaddr_LDADD = $(LDADD)
 net_sockaddr_DEPENDENCIES = libtests.a
+net_sockaddr__pidns_translation_SOURCES =  \
+	net-sockaddr--pidns-translation.c
+net_sockaddr__pidns_translation_OBJECTS =  \
+	net-sockaddr--pidns-translation.$(OBJEXT)
+net_sockaddr__pidns_translation_LDADD = $(LDADD)
+net_sockaddr__pidns_translation_DEPENDENCIES = libtests.a
 net_tpacket_req_SOURCES = net-tpacket_req.c
 net_tpacket_req_OBJECTS = net-tpacket_req.$(OBJEXT)
 net_tpacket_req_LDADD = $(LDADD)
@@ -1773,6 +2285,12 @@ netlink_audit_SOURCES = netlink_audit.c
 netlink_audit_OBJECTS = netlink_audit.$(OBJEXT)
 netlink_audit_LDADD = $(LDADD)
 netlink_audit_DEPENDENCIES = libtests.a
+netlink_audit__pidns_translation_SOURCES =  \
+	netlink_audit--pidns-translation.c
+netlink_audit__pidns_translation_OBJECTS =  \
+	netlink_audit--pidns-translation.$(OBJEXT)
+netlink_audit__pidns_translation_LDADD = $(LDADD)
+netlink_audit__pidns_translation_DEPENDENCIES = libtests.a
 netlink_crypto_SOURCES = netlink_crypto.c
 netlink_crypto_OBJECTS = netlink_crypto.$(OBJEXT)
 netlink_crypto_LDADD = $(LDADD)
@@ -1921,6 +2439,10 @@ nlattr_ifla_xdp_SOURCES = nlattr_ifla_xd
 nlattr_ifla_xdp_OBJECTS = nlattr_ifla_xdp.$(OBJEXT)
 nlattr_ifla_xdp_LDADD = $(LDADD)
 nlattr_ifla_xdp_DEPENDENCIES = libtests.a
+nlattr_ifla_xdp_y_SOURCES = nlattr_ifla_xdp-y.c
+nlattr_ifla_xdp_y_OBJECTS = nlattr_ifla_xdp-y.$(OBJEXT)
+nlattr_ifla_xdp_y_LDADD = $(LDADD)
+nlattr_ifla_xdp_y_DEPENDENCIES = libtests.a
 nlattr_inet_diag_msg_SOURCES = nlattr_inet_diag_msg.c
 nlattr_inet_diag_msg_OBJECTS = nlattr_inet_diag_msg.$(OBJEXT)
 nlattr_inet_diag_msg_LDADD = $(LDADD)
@@ -2074,6 +2596,46 @@ openat_SOURCES = openat.c
 openat_OBJECTS = openat.$(OBJEXT)
 openat_LDADD = $(LDADD)
 openat_DEPENDENCIES = libtests.a
+openat2_SOURCES = openat2.c
+openat2_OBJECTS = openat2.$(OBJEXT)
+openat2_LDADD = $(LDADD)
+openat2_DEPENDENCIES = libtests.a
+openat2_Xabbrev_SOURCES = openat2-Xabbrev.c
+openat2_Xabbrev_OBJECTS = openat2-Xabbrev.$(OBJEXT)
+openat2_Xabbrev_LDADD = $(LDADD)
+openat2_Xabbrev_DEPENDENCIES = libtests.a
+openat2_Xraw_SOURCES = openat2-Xraw.c
+openat2_Xraw_OBJECTS = openat2-Xraw.$(OBJEXT)
+openat2_Xraw_LDADD = $(LDADD)
+openat2_Xraw_DEPENDENCIES = libtests.a
+openat2_Xverbose_SOURCES = openat2-Xverbose.c
+openat2_Xverbose_OBJECTS = openat2-Xverbose.$(OBJEXT)
+openat2_Xverbose_LDADD = $(LDADD)
+openat2_Xverbose_DEPENDENCIES = libtests.a
+openat2_v_SOURCES = openat2-v.c
+openat2_v_OBJECTS = openat2-v.$(OBJEXT)
+openat2_v_LDADD = $(LDADD)
+openat2_v_DEPENDENCIES = libtests.a
+openat2_v_y_SOURCES = openat2-v-y.c
+openat2_v_y_OBJECTS = openat2-v-y.$(OBJEXT)
+openat2_v_y_LDADD = $(LDADD)
+openat2_v_y_DEPENDENCIES = libtests.a
+openat2_v_y_Xabbrev_SOURCES = openat2-v-y-Xabbrev.c
+openat2_v_y_Xabbrev_OBJECTS = openat2-v-y-Xabbrev.$(OBJEXT)
+openat2_v_y_Xabbrev_LDADD = $(LDADD)
+openat2_v_y_Xabbrev_DEPENDENCIES = libtests.a
+openat2_v_y_Xraw_SOURCES = openat2-v-y-Xraw.c
+openat2_v_y_Xraw_OBJECTS = openat2-v-y-Xraw.$(OBJEXT)
+openat2_v_y_Xraw_LDADD = $(LDADD)
+openat2_v_y_Xraw_DEPENDENCIES = libtests.a
+openat2_v_y_Xverbose_SOURCES = openat2-v-y-Xverbose.c
+openat2_v_y_Xverbose_OBJECTS = openat2-v-y-Xverbose.$(OBJEXT)
+openat2_v_y_Xverbose_LDADD = $(LDADD)
+openat2_v_y_Xverbose_DEPENDENCIES = libtests.a
+openat2_y_SOURCES = openat2-y.c
+openat2_y_OBJECTS = openat2-y.$(OBJEXT)
+openat2_y_LDADD = $(LDADD)
+openat2_y_DEPENDENCIES = libtests.a
 orphaned_process_group_SOURCES = orphaned_process_group.c
 orphaned_process_group_OBJECTS = orphaned_process_group.$(OBJEXT)
 orphaned_process_group_LDADD = $(LDADD)
@@ -2118,10 +2680,43 @@ personality_Xverbose_SOURCES = personali
 personality_Xverbose_OBJECTS = personality-Xverbose.$(OBJEXT)
 personality_Xverbose_LDADD = $(LDADD)
 personality_Xverbose_DEPENDENCIES = libtests.a
+pidfd_getfd_SOURCES = pidfd_getfd.c
+pidfd_getfd_OBJECTS = pidfd_getfd.$(OBJEXT)
+pidfd_getfd_LDADD = $(LDADD)
+pidfd_getfd_DEPENDENCIES = libtests.a
+pidfd_getfd_y_SOURCES = pidfd_getfd-y.c
+pidfd_getfd_y_OBJECTS = pidfd_getfd-y.$(OBJEXT)
+pidfd_getfd_y_LDADD = $(LDADD)
+pidfd_getfd_y_DEPENDENCIES = libtests.a
+pidfd_getfd_yy_SOURCES = pidfd_getfd-yy.c
+pidfd_getfd_yy_OBJECTS = pidfd_getfd-yy.$(OBJEXT)
+pidfd_getfd_yy_LDADD = $(LDADD)
+pidfd_getfd_yy_DEPENDENCIES = libtests.a
 pidfd_open_SOURCES = pidfd_open.c
 pidfd_open_OBJECTS = pidfd_open.$(OBJEXT)
 pidfd_open_LDADD = $(LDADD)
 pidfd_open_DEPENDENCIES = libtests.a
+pidfd_open__decode_fd_path_SOURCES = pidfd_open--decode-fd-path.c
+pidfd_open__decode_fd_path_OBJECTS =  \
+	pidfd_open--decode-fd-path.$(OBJEXT)
+pidfd_open__decode_fd_path_LDADD = $(LDADD)
+pidfd_open__decode_fd_path_DEPENDENCIES = libtests.a
+pidfd_open__decode_fd_pidfd_SOURCES = pidfd_open--decode-fd-pidfd.c
+pidfd_open__decode_fd_pidfd_OBJECTS =  \
+	pidfd_open--decode-fd-pidfd.$(OBJEXT)
+pidfd_open__decode_fd_pidfd_LDADD = $(LDADD)
+pidfd_open__decode_fd_pidfd_DEPENDENCIES = libtests.a
+pidfd_open__decode_fd_socket_SOURCES = pidfd_open--decode-fd-socket.c
+pidfd_open__decode_fd_socket_OBJECTS =  \
+	pidfd_open--decode-fd-socket.$(OBJEXT)
+pidfd_open__decode_fd_socket_LDADD = $(LDADD)
+pidfd_open__decode_fd_socket_DEPENDENCIES = libtests.a
+pidfd_open__pidns_translation_SOURCES =  \
+	pidfd_open--pidns-translation.c
+pidfd_open__pidns_translation_OBJECTS =  \
+	pidfd_open--pidns-translation.$(OBJEXT)
+pidfd_open__pidns_translation_LDADD = $(LDADD)
+pidfd_open__pidns_translation_DEPENDENCIES = libtests.a
 pidfd_open_P_SOURCES = pidfd_open-P.c
 pidfd_open_P_OBJECTS = pidfd_open-P.$(OBJEXT)
 pidfd_open_P_LDADD = $(LDADD)
@@ -2130,10 +2725,24 @@ pidfd_open_y_SOURCES = pidfd_open-y.c
 pidfd_open_y_OBJECTS = pidfd_open-y.$(OBJEXT)
 pidfd_open_y_LDADD = $(LDADD)
 pidfd_open_y_DEPENDENCIES = libtests.a
+pidfd_open_yy_SOURCES = pidfd_open-yy.c
+pidfd_open_yy_OBJECTS = pidfd_open-yy.$(OBJEXT)
+pidfd_open_yy_LDADD = $(LDADD)
+pidfd_open_yy_DEPENDENCIES = libtests.a
 pidfd_send_signal_SOURCES = pidfd_send_signal.c
 pidfd_send_signal_OBJECTS = pidfd_send_signal.$(OBJEXT)
 pidfd_send_signal_LDADD = $(LDADD)
 pidfd_send_signal_DEPENDENCIES = libtests.a
+pidfd_send_signal__pidns_translation_SOURCES =  \
+	pidfd_send_signal--pidns-translation.c
+pidfd_send_signal__pidns_translation_OBJECTS =  \
+	pidfd_send_signal--pidns-translation.$(OBJEXT)
+pidfd_send_signal__pidns_translation_LDADD = $(LDADD)
+pidfd_send_signal__pidns_translation_DEPENDENCIES = libtests.a
+pidns_cache_SOURCES = pidns-cache.c
+pidns_cache_OBJECTS = pidns-cache.$(OBJEXT)
+pidns_cache_LDADD = $(LDADD)
+pidns_cache_DEPENDENCIES = libtests.a
 pipe_SOURCES = pipe.c
 pipe_OBJECTS = pipe.$(OBJEXT)
 pipe_LDADD = $(LDADD)
@@ -2239,6 +2848,10 @@ print_maxfd_SOURCES = print_maxfd.c
 print_maxfd_OBJECTS = print_maxfd.$(OBJEXT)
 print_maxfd_LDADD = $(LDADD)
 print_maxfd_DEPENDENCIES = libtests.a
+print_ppid_tracerpid_SOURCES = print_ppid_tracerpid.c
+print_ppid_tracerpid_OBJECTS = print_ppid_tracerpid.$(OBJEXT)
+print_ppid_tracerpid_LDADD = $(LDADD)
+print_ppid_tracerpid_DEPENDENCIES = libtests.a
 printpath_umovestr_SOURCES = printpath-umovestr.c
 printpath_umovestr_OBJECTS = printpath-umovestr.$(OBJEXT)
 printpath_umovestr_LDADD = $(LDADD)
@@ -2288,14 +2901,31 @@ prlimit64_SOURCES = prlimit64.c
 prlimit64_OBJECTS = prlimit64.$(OBJEXT)
 prlimit64_LDADD = $(LDADD)
 prlimit64_DEPENDENCIES = libtests.a
+prlimit64__pidns_translation_SOURCES = prlimit64--pidns-translation.c
+prlimit64__pidns_translation_OBJECTS =  \
+	prlimit64--pidns-translation.$(OBJEXT)
+prlimit64__pidns_translation_LDADD = $(LDADD)
+prlimit64__pidns_translation_DEPENDENCIES = libtests.a
 process_vm_readv_SOURCES = process_vm_readv.c
 process_vm_readv_OBJECTS = process_vm_readv.$(OBJEXT)
 process_vm_readv_LDADD = $(LDADD)
 process_vm_readv_DEPENDENCIES = libtests.a
+process_vm_readv__pidns_translation_SOURCES =  \
+	process_vm_readv--pidns-translation.c
+process_vm_readv__pidns_translation_OBJECTS =  \
+	process_vm_readv--pidns-translation.$(OBJEXT)
+process_vm_readv__pidns_translation_LDADD = $(LDADD)
+process_vm_readv__pidns_translation_DEPENDENCIES = libtests.a
 process_vm_writev_SOURCES = process_vm_writev.c
 process_vm_writev_OBJECTS = process_vm_writev.$(OBJEXT)
 process_vm_writev_LDADD = $(LDADD)
 process_vm_writev_DEPENDENCIES = libtests.a
+process_vm_writev__pidns_translation_SOURCES =  \
+	process_vm_writev--pidns-translation.c
+process_vm_writev__pidns_translation_OBJECTS =  \
+	process_vm_writev--pidns-translation.$(OBJEXT)
+process_vm_writev__pidns_translation_LDADD = $(LDADD)
+process_vm_writev__pidns_translation_DEPENDENCIES = libtests.a
 pselect6_SOURCES = pselect6.c
 pselect6_OBJECTS = pselect6.$(OBJEXT)
 pselect6_LDADD = $(LDADD)
@@ -2489,6 +3119,12 @@ rt_sigqueueinfo_SOURCES = rt_sigqueueinf
 rt_sigqueueinfo_OBJECTS = rt_sigqueueinfo.$(OBJEXT)
 rt_sigqueueinfo_LDADD = $(LDADD)
 rt_sigqueueinfo_DEPENDENCIES = libtests.a
+rt_sigqueueinfo__pidns_translation_SOURCES =  \
+	rt_sigqueueinfo--pidns-translation.c
+rt_sigqueueinfo__pidns_translation_OBJECTS =  \
+	rt_sigqueueinfo--pidns-translation.$(OBJEXT)
+rt_sigqueueinfo__pidns_translation_LDADD = $(LDADD)
+rt_sigqueueinfo__pidns_translation_DEPENDENCIES = libtests.a
 rt_sigreturn_SOURCES = rt_sigreturn.c
 rt_sigreturn_OBJECTS = rt_sigreturn.$(OBJEXT)
 rt_sigreturn_LDADD = $(LDADD)
@@ -2505,6 +3141,12 @@ rt_tgsigqueueinfo_SOURCES = rt_tgsigqueu
 rt_tgsigqueueinfo_OBJECTS = rt_tgsigqueueinfo.$(OBJEXT)
 rt_tgsigqueueinfo_LDADD = $(LDADD)
 rt_tgsigqueueinfo_DEPENDENCIES = libtests.a
+rt_tgsigqueueinfo__pidns_translation_SOURCES =  \
+	rt_tgsigqueueinfo--pidns-translation.c
+rt_tgsigqueueinfo__pidns_translation_OBJECTS =  \
+	rt_tgsigqueueinfo--pidns-translation.$(OBJEXT)
+rt_tgsigqueueinfo__pidns_translation_LDADD = $(LDADD)
+rt_tgsigqueueinfo__pidns_translation_DEPENDENCIES = libtests.a
 run_expect_termsig_SOURCES = run_expect_termsig.c
 run_expect_termsig_OBJECTS = run_expect_termsig.$(OBJEXT)
 run_expect_termsig_LDADD = $(LDADD)
@@ -2545,18 +3187,42 @@ sched_xetaffinity_SOURCES = sched_xetaff
 sched_xetaffinity_OBJECTS = sched_xetaffinity.$(OBJEXT)
 sched_xetaffinity_LDADD = $(LDADD)
 sched_xetaffinity_DEPENDENCIES = libtests.a
+sched_xetaffinity__pidns_translation_SOURCES =  \
+	sched_xetaffinity--pidns-translation.c
+sched_xetaffinity__pidns_translation_OBJECTS =  \
+	sched_xetaffinity--pidns-translation.$(OBJEXT)
+sched_xetaffinity__pidns_translation_LDADD = $(LDADD)
+sched_xetaffinity__pidns_translation_DEPENDENCIES = libtests.a
 sched_xetattr_SOURCES = sched_xetattr.c
 sched_xetattr_OBJECTS = sched_xetattr.$(OBJEXT)
 sched_xetattr_LDADD = $(LDADD)
 sched_xetattr_DEPENDENCIES = libtests.a
+sched_xetattr__pidns_translation_SOURCES =  \
+	sched_xetattr--pidns-translation.c
+sched_xetattr__pidns_translation_OBJECTS =  \
+	sched_xetattr--pidns-translation.$(OBJEXT)
+sched_xetattr__pidns_translation_LDADD = $(LDADD)
+sched_xetattr__pidns_translation_DEPENDENCIES = libtests.a
 sched_xetparam_SOURCES = sched_xetparam.c
 sched_xetparam_OBJECTS = sched_xetparam.$(OBJEXT)
 sched_xetparam_LDADD = $(LDADD)
 sched_xetparam_DEPENDENCIES = libtests.a
+sched_xetparam__pidns_translation_SOURCES =  \
+	sched_xetparam--pidns-translation.c
+sched_xetparam__pidns_translation_OBJECTS =  \
+	sched_xetparam--pidns-translation.$(OBJEXT)
+sched_xetparam__pidns_translation_LDADD = $(LDADD)
+sched_xetparam__pidns_translation_DEPENDENCIES = libtests.a
 sched_xetscheduler_SOURCES = sched_xetscheduler.c
 sched_xetscheduler_OBJECTS = sched_xetscheduler.$(OBJEXT)
 sched_xetscheduler_LDADD = $(LDADD)
 sched_xetscheduler_DEPENDENCIES = libtests.a
+sched_xetscheduler__pidns_translation_SOURCES =  \
+	sched_xetscheduler--pidns-translation.c
+sched_xetscheduler__pidns_translation_OBJECTS =  \
+	sched_xetscheduler--pidns-translation.$(OBJEXT)
+sched_xetscheduler__pidns_translation_LDADD = $(LDADD)
+sched_xetscheduler__pidns_translation_DEPENDENCIES = libtests.a
 sched_yield_SOURCES = sched_yield.c
 sched_yield_OBJECTS = sched_yield.$(OBJEXT)
 sched_yield_LDADD = $(LDADD)
@@ -2681,6 +3347,10 @@ setns_SOURCES = setns.c
 setns_OBJECTS = setns.$(OBJEXT)
 setns_LDADD = $(LDADD)
 setns_DEPENDENCIES = libtests.a
+setpgrp_exec_SOURCES = setpgrp-exec.c
+setpgrp_exec_OBJECTS = setpgrp-exec.$(OBJEXT)
+setpgrp_exec_LDADD = $(LDADD)
+setpgrp_exec_DEPENDENCIES = libtests.a
 setregid_SOURCES = setregid.c
 setregid_OBJECTS = setregid.$(OBJEXT)
 setregid_LDADD = $(LDADD)
@@ -2765,6 +3435,12 @@ signal_receive_SOURCES = signal_receive.
 signal_receive_OBJECTS = signal_receive.$(OBJEXT)
 signal_receive_LDADD = $(LDADD)
 signal_receive_DEPENDENCIES = libtests.a
+signal_receive__pidns_translation_SOURCES =  \
+	signal_receive--pidns-translation.c
+signal_receive__pidns_translation_OBJECTS =  \
+	signal_receive--pidns-translation.$(OBJEXT)
+signal_receive__pidns_translation_LDADD = $(LDADD)
+signal_receive__pidns_translation_DEPENDENCIES = libtests.a
 signalfd4_SOURCES = signalfd4.c
 signalfd4_OBJECTS = signalfd4.$(OBJEXT)
 signalfd4_LDADD = $(LDADD)
@@ -2801,6 +3477,12 @@ so_peercred_SOURCES = so_peercred.c
 so_peercred_OBJECTS = so_peercred.$(OBJEXT)
 so_peercred_LDADD = $(LDADD)
 so_peercred_DEPENDENCIES = libtests.a
+so_peercred__pidns_translation_SOURCES =  \
+	so_peercred--pidns-translation.c
+so_peercred__pidns_translation_OBJECTS =  \
+	so_peercred--pidns-translation.$(OBJEXT)
+so_peercred__pidns_translation_LDADD = $(LDADD)
+so_peercred__pidns_translation_DEPENDENCIES = libtests.a
 so_peercred_Xabbrev_SOURCES = so_peercred-Xabbrev.c
 so_peercred_Xabbrev_OBJECTS = so_peercred-Xabbrev.$(OBJEXT)
 so_peercred_Xabbrev_LDADD = $(LDADD)
@@ -2901,6 +3583,14 @@ status_failed_SOURCES = status-failed.c
 status_failed_OBJECTS = status-failed.$(OBJEXT)
 status_failed_LDADD = $(LDADD)
 status_failed_DEPENDENCIES = libtests.a
+status_failed_long_SOURCES = status-failed-long.c
+status_failed_long_OBJECTS = status-failed-long.$(OBJEXT)
+status_failed_long_LDADD = $(LDADD)
+status_failed_long_DEPENDENCIES = libtests.a
+status_failed_status_SOURCES = status-failed-status.c
+status_failed_status_OBJECTS = status-failed-status.$(OBJEXT)
+status_failed_status_LDADD = $(LDADD)
+status_failed_status_DEPENDENCIES = libtests.a
 status_none_SOURCES = status-none.c
 status_none_OBJECTS = status-none.$(OBJEXT)
 status_none_LDADD = $(LDADD)
@@ -2916,6 +3606,14 @@ status_successful_SOURCES = status-succe
 status_successful_OBJECTS = status-successful.$(OBJEXT)
 status_successful_LDADD = $(LDADD)
 status_successful_DEPENDENCIES = libtests.a
+status_successful_long_SOURCES = status-successful-long.c
+status_successful_long_OBJECTS = status-successful-long.$(OBJEXT)
+status_successful_long_LDADD = $(LDADD)
+status_successful_long_DEPENDENCIES = libtests.a
+status_successful_status_SOURCES = status-successful-status.c
+status_successful_status_OBJECTS = status-successful-status.$(OBJEXT)
+status_successful_status_LDADD = $(LDADD)
+status_successful_status_DEPENDENCIES = libtests.a
 status_unfinished_SOURCES = status-unfinished.c
 status_unfinished_OBJECTS = status-unfinished.$(OBJEXT)
 status_unfinished_LDADD = $(LDADD)
@@ -2928,6 +3626,33 @@ statx_SOURCES = statx.c
 statx_OBJECTS = statx.$(OBJEXT)
 statx_LDADD = $(LDADD)
 statx_DEPENDENCIES = libtests.a
+strace__strings_in_hex_SOURCES = strace--strings-in-hex.c
+strace__strings_in_hex_OBJECTS = strace--strings-in-hex.$(OBJEXT)
+strace__strings_in_hex_LDADD = $(LDADD)
+strace__strings_in_hex_DEPENDENCIES = libtests.a
+strace__strings_in_hex_all_SOURCES = strace--strings-in-hex-all.c
+strace__strings_in_hex_all_OBJECTS =  \
+	strace--strings-in-hex-all.$(OBJEXT)
+strace__strings_in_hex_all_LDADD = $(LDADD)
+strace__strings_in_hex_all_DEPENDENCIES = libtests.a
+strace__strings_in_hex_non_ascii_SOURCES =  \
+	strace--strings-in-hex-non-ascii.c
+strace__strings_in_hex_non_ascii_OBJECTS =  \
+	strace--strings-in-hex-non-ascii.$(OBJEXT)
+strace__strings_in_hex_non_ascii_LDADD = $(LDADD)
+strace__strings_in_hex_non_ascii_DEPENDENCIES = libtests.a
+strace_n_SOURCES = strace-n.c
+strace_n_OBJECTS = strace-n.$(OBJEXT)
+strace_n_LDADD = $(LDADD)
+strace_n_DEPENDENCIES = libtests.a
+strace_x_SOURCES = strace-x.c
+strace_x_OBJECTS = strace-x.$(OBJEXT)
+strace_x_LDADD = $(LDADD)
+strace_x_DEPENDENCIES = libtests.a
+strace_xx_SOURCES = strace-xx.c
+strace_xx_OBJECTS = strace-xx.$(OBJEXT)
+strace_xx_LDADD = $(LDADD)
+strace_xx_DEPENDENCIES = libtests.a
 swap_SOURCES = swap.c
 swap_OBJECTS = swap.$(OBJEXT)
 swap_LDADD = $(LDADD)
@@ -2972,9 +3697,33 @@ tee_SOURCES = tee.c
 tee_OBJECTS = tee.$(OBJEXT)
 tee_LDADD = $(LDADD)
 tee_DEPENDENCIES = libtests.a
+tgkill_SOURCES = tgkill.c
+tgkill_OBJECTS = tgkill.$(OBJEXT)
+tgkill_LDADD = $(LDADD)
+tgkill_DEPENDENCIES = libtests.a
+tgkill__pidns_translation_SOURCES = tgkill--pidns-translation.c
+tgkill__pidns_translation_OBJECTS =  \
+	tgkill--pidns-translation.$(OBJEXT)
+tgkill__pidns_translation_LDADD = $(LDADD)
+tgkill__pidns_translation_DEPENDENCIES = libtests.a
 threads_execve_SOURCES = threads-execve.c
 threads_execve_OBJECTS = threads-execve.$(OBJEXT)
 threads_execve_DEPENDENCIES = $(am__DEPENDENCIES_1) $(LDADD)
+threads_execve__quiet_thread_execve_SOURCES =  \
+	threads-execve--quiet-thread-execve.c
+threads_execve__quiet_thread_execve_OBJECTS =  \
+	threads-execve--quiet-thread-execve.$(OBJEXT)
+threads_execve__quiet_thread_execve_DEPENDENCIES =  \
+	$(am__DEPENDENCIES_1) $(LDADD)
+threads_execve_q_SOURCES = threads-execve-q.c
+threads_execve_q_OBJECTS = threads-execve-q.$(OBJEXT)
+threads_execve_q_DEPENDENCIES = $(am__DEPENDENCIES_1) $(LDADD)
+threads_execve_qq_SOURCES = threads-execve-qq.c
+threads_execve_qq_OBJECTS = threads-execve-qq.$(OBJEXT)
+threads_execve_qq_DEPENDENCIES = $(am__DEPENDENCIES_1) $(LDADD)
+threads_execve_qqq_SOURCES = threads-execve-qqq.c
+threads_execve_qqq_OBJECTS = threads-execve-qqq.$(OBJEXT)
+threads_execve_qqq_DEPENDENCIES = $(am__DEPENDENCIES_1) $(LDADD)
 time_SOURCES = time.c
 time_OBJECTS = time.$(OBJEXT)
 time_LDADD = $(LDADD)
@@ -2998,10 +3747,24 @@ times_fail_SOURCES = times-fail.c
 times_fail_OBJECTS = times-fail.$(OBJEXT)
 times_fail_LDADD = $(LDADD)
 times_fail_DEPENDENCIES = libtests.a
+tkill_SOURCES = tkill.c
+tkill_OBJECTS = tkill.$(OBJEXT)
+tkill_LDADD = $(LDADD)
+tkill_DEPENDENCIES = libtests.a
+tkill__pidns_translation_SOURCES = tkill--pidns-translation.c
+tkill__pidns_translation_OBJECTS = tkill--pidns-translation.$(OBJEXT)
+tkill__pidns_translation_LDADD = $(LDADD)
+tkill__pidns_translation_DEPENDENCIES = libtests.a
 tracer_ppid_pgid_sid_SOURCES = tracer_ppid_pgid_sid.c
 tracer_ppid_pgid_sid_OBJECTS = tracer_ppid_pgid_sid.$(OBJEXT)
 tracer_ppid_pgid_sid_LDADD = $(LDADD)
 tracer_ppid_pgid_sid_DEPENDENCIES = libtests.a
+am_trie_test_OBJECTS = trie_test-trie_test.$(OBJEXT) \
+	trie_test-trie_for_tests.$(OBJEXT)
+trie_test_OBJECTS = $(am_trie_test_OBJECTS)
+trie_test_DEPENDENCIES = $(LDADD) $(am__DEPENDENCIES_1)
+trie_test_LINK = $(CCLD) $(trie_test_CFLAGS) $(CFLAGS) $(AM_LDFLAGS) \
+	$(LDFLAGS) -o $@
 truncate_SOURCES = truncate.c
 truncate_OBJECTS = truncate.$(OBJEXT)
 truncate_LDADD = $(LDADD)
@@ -3054,6 +3817,10 @@ umovestr_cached_SOURCES = umovestr_cache
 umovestr_cached_OBJECTS = umovestr_cached.$(OBJEXT)
 umovestr_cached_LDADD = $(LDADD)
 umovestr_cached_DEPENDENCIES = libtests.a
+umovestr_cached_adjacent_SOURCES = umovestr_cached_adjacent.c
+umovestr_cached_adjacent_OBJECTS = umovestr_cached_adjacent.$(OBJEXT)
+umovestr_cached_adjacent_LDADD = $(LDADD)
+umovestr_cached_adjacent_DEPENDENCIES = libtests.a
 uname_SOURCES = uname.c
 uname_OBJECTS = uname.$(OBJEXT)
 uname_LDADD = $(LDADD)
@@ -3159,6 +3926,12 @@ xet_robust_list_SOURCES = xet_robust_lis
 xet_robust_list_OBJECTS = xet_robust_list.$(OBJEXT)
 xet_robust_list_LDADD = $(LDADD)
 xet_robust_list_DEPENDENCIES = libtests.a
+xet_robust_list__pidns_translation_SOURCES =  \
+	xet_robust_list--pidns-translation.c
+xet_robust_list__pidns_translation_OBJECTS =  \
+	xet_robust_list--pidns-translation.$(OBJEXT)
+xet_robust_list__pidns_translation_LDADD = $(LDADD)
+xet_robust_list__pidns_translation_DEPENDENCIES = libtests.a
 xet_thread_area_x86_SOURCES = xet_thread_area_x86.c
 xet_thread_area_x86_OBJECTS = xet_thread_area_x86.$(OBJEXT)
 xet_thread_area_x86_LDADD = $(LDADD)
@@ -3171,10 +3944,21 @@ xetpgid_SOURCES = xetpgid.c
 xetpgid_OBJECTS = xetpgid.$(OBJEXT)
 xetpgid_LDADD = $(LDADD)
 xetpgid_DEPENDENCIES = libtests.a
+xetpgid__pidns_translation_SOURCES = xetpgid--pidns-translation.c
+xetpgid__pidns_translation_OBJECTS =  \
+	xetpgid--pidns-translation.$(OBJEXT)
+xetpgid__pidns_translation_LDADD = $(LDADD)
+xetpgid__pidns_translation_DEPENDENCIES = libtests.a
 xetpriority_SOURCES = xetpriority.c
 xetpriority_OBJECTS = xetpriority.$(OBJEXT)
 xetpriority_LDADD = $(LDADD)
 xetpriority_DEPENDENCIES = libtests.a
+xetpriority__pidns_translation_SOURCES =  \
+	xetpriority--pidns-translation.c
+xetpriority__pidns_translation_OBJECTS =  \
+	xetpriority--pidns-translation.$(OBJEXT)
+xetpriority__pidns_translation_LDADD = $(LDADD)
+xetpriority__pidns_translation_DEPENDENCIES = libtests.a
 xettimeofday_SOURCES = xettimeofday.c
 xettimeofday_OBJECTS = xettimeofday.$(OBJEXT)
 xettimeofday_LDADD = $(LDADD)
@@ -3213,31 +3997,50 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/bpf-obj_get_info_by_fd-prog.Po \
 	./$(DEPDIR)/bpf-obj_get_info_by_fd-v.Po \
 	./$(DEPDIR)/bpf-obj_get_info_by_fd.Po \
-	./$(DEPDIR)/bpf-success-v.Po ./$(DEPDIR)/bpf-success.Po \
-	./$(DEPDIR)/bpf-v.Po ./$(DEPDIR)/bpf.Po ./$(DEPDIR)/brk.Po \
-	./$(DEPDIR)/btrfs.Po ./$(DEPDIR)/caps-abbrev.Po \
-	./$(DEPDIR)/caps.Po ./$(DEPDIR)/check_sigblock.Po \
-	./$(DEPDIR)/check_sigign.Po ./$(DEPDIR)/chmod.Po \
-	./$(DEPDIR)/chown.Po ./$(DEPDIR)/chown32.Po \
-	./$(DEPDIR)/chroot.Po ./$(DEPDIR)/clock_adjtime.Po \
-	./$(DEPDIR)/clock_nanosleep.Po ./$(DEPDIR)/clock_xettime.Po \
-	./$(DEPDIR)/clone-flags.Po ./$(DEPDIR)/clone3-Xabbrev.Po \
-	./$(DEPDIR)/clone3-Xraw.Po ./$(DEPDIR)/clone3-Xverbose.Po \
+	./$(DEPDIR)/bpf-success-long-y.Po ./$(DEPDIR)/bpf-success-v.Po \
+	./$(DEPDIR)/bpf-success.Po ./$(DEPDIR)/bpf-v.Po \
+	./$(DEPDIR)/bpf.Po ./$(DEPDIR)/brk.Po ./$(DEPDIR)/btrfs.Po \
+	./$(DEPDIR)/caps-abbrev.Po ./$(DEPDIR)/caps.Po \
+	./$(DEPDIR)/check_sigblock.Po ./$(DEPDIR)/check_sigign.Po \
+	./$(DEPDIR)/chmod.Po ./$(DEPDIR)/chown.Po \
+	./$(DEPDIR)/chown32.Po ./$(DEPDIR)/chroot.Po \
+	./$(DEPDIR)/clock_adjtime.Po ./$(DEPDIR)/clock_nanosleep.Po \
+	./$(DEPDIR)/clock_xettime.Po ./$(DEPDIR)/clone-flags.Po \
+	./$(DEPDIR)/clone3-Xabbrev.Po ./$(DEPDIR)/clone3-Xraw.Po \
+	./$(DEPDIR)/clone3-Xverbose.Po \
 	./$(DEPDIR)/clone3-success-Xabbrev.Po \
 	./$(DEPDIR)/clone3-success-Xraw.Po \
 	./$(DEPDIR)/clone3-success-Xverbose.Po \
 	./$(DEPDIR)/clone3-success.Po ./$(DEPDIR)/clone3.Po \
-	./$(DEPDIR)/clone_parent.Po ./$(DEPDIR)/clone_ptrace.Po \
-	./$(DEPDIR)/copy_file_range.Po ./$(DEPDIR)/count-f.Po \
-	./$(DEPDIR)/creat.Po ./$(DEPDIR)/delay.Po \
-	./$(DEPDIR)/delete_module.Po ./$(DEPDIR)/dev-yy.Po \
-	./$(DEPDIR)/dup.Po ./$(DEPDIR)/dup2.Po ./$(DEPDIR)/dup3.Po \
-	./$(DEPDIR)/epoll_create.Po ./$(DEPDIR)/epoll_create1.Po \
-	./$(DEPDIR)/epoll_ctl.Po ./$(DEPDIR)/epoll_pwait.Po \
-	./$(DEPDIR)/epoll_wait.Po ./$(DEPDIR)/erestartsys.Po \
-	./$(DEPDIR)/eventfd.Po ./$(DEPDIR)/execve-v.Po \
-	./$(DEPDIR)/execve.Po ./$(DEPDIR)/execveat-v.Po \
-	./$(DEPDIR)/execveat.Po ./$(DEPDIR)/faccessat.Po \
+	./$(DEPDIR)/clone_parent--quiet-exit.Po \
+	./$(DEPDIR)/clone_parent-q.Po ./$(DEPDIR)/clone_parent-qq.Po \
+	./$(DEPDIR)/clone_parent.Po \
+	./$(DEPDIR)/clone_ptrace--quiet-attach.Po \
+	./$(DEPDIR)/clone_ptrace--quiet-exit.Po \
+	./$(DEPDIR)/clone_ptrace-q.Po ./$(DEPDIR)/clone_ptrace-qq.Po \
+	./$(DEPDIR)/clone_ptrace.Po ./$(DEPDIR)/close_range-P.Po \
+	./$(DEPDIR)/close_range-y.Po ./$(DEPDIR)/close_range-yy.Po \
+	./$(DEPDIR)/close_range.Po ./$(DEPDIR)/copy_file_range.Po \
+	./$(DEPDIR)/count-f.Po ./$(DEPDIR)/creat.Po \
+	./$(DEPDIR)/delay.Po ./$(DEPDIR)/delete_module.Po \
+	./$(DEPDIR)/dev--decode-fds-dev.Po \
+	./$(DEPDIR)/dev--decode-fds-path.Po \
+	./$(DEPDIR)/dev--decode-fds-socket.Po ./$(DEPDIR)/dev-yy.Po \
+	./$(DEPDIR)/dup-P.Po ./$(DEPDIR)/dup-y.Po \
+	./$(DEPDIR)/dup-yy.Po ./$(DEPDIR)/dup.Po ./$(DEPDIR)/dup2-P.Po \
+	./$(DEPDIR)/dup2-y.Po ./$(DEPDIR)/dup2-yy.Po \
+	./$(DEPDIR)/dup2.Po ./$(DEPDIR)/dup3-P.Po \
+	./$(DEPDIR)/dup3-y.Po ./$(DEPDIR)/dup3-yy.Po \
+	./$(DEPDIR)/dup3.Po ./$(DEPDIR)/epoll_create.Po \
+	./$(DEPDIR)/epoll_create1.Po ./$(DEPDIR)/epoll_ctl.Po \
+	./$(DEPDIR)/epoll_pwait.Po ./$(DEPDIR)/epoll_wait.Po \
+	./$(DEPDIR)/erestartsys.Po ./$(DEPDIR)/eventfd.Po \
+	./$(DEPDIR)/execve-v.Po ./$(DEPDIR)/execve.Po \
+	./$(DEPDIR)/execveat-v.Po ./$(DEPDIR)/execveat.Po \
+	./$(DEPDIR)/faccessat-P.Po ./$(DEPDIR)/faccessat-y.Po \
+	./$(DEPDIR)/faccessat-yy.Po ./$(DEPDIR)/faccessat.Po \
+	./$(DEPDIR)/faccessat2-P.Po ./$(DEPDIR)/faccessat2-y.Po \
+	./$(DEPDIR)/faccessat2-yy.Po ./$(DEPDIR)/faccessat2.Po \
 	./$(DEPDIR)/fadvise64.Po ./$(DEPDIR)/fadvise64_64.Po \
 	./$(DEPDIR)/fallocate.Po ./$(DEPDIR)/fanotify_init.Po \
 	./$(DEPDIR)/fanotify_mark-Xabbrev.Po \
@@ -3246,49 +4049,59 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/fanotify_mark.Po ./$(DEPDIR)/fchdir.Po \
 	./$(DEPDIR)/fchmod.Po ./$(DEPDIR)/fchmodat.Po \
 	./$(DEPDIR)/fchown.Po ./$(DEPDIR)/fchown32.Po \
-	./$(DEPDIR)/fchownat.Po ./$(DEPDIR)/fcntl.Po \
+	./$(DEPDIR)/fchownat.Po \
+	./$(DEPDIR)/fcntl--pidns-translation.Po ./$(DEPDIR)/fcntl.Po \
+	./$(DEPDIR)/fcntl64--pidns-translation.Po \
 	./$(DEPDIR)/fcntl64.Po ./$(DEPDIR)/fdatasync.Po \
 	./$(DEPDIR)/fflush.Po ./$(DEPDIR)/file_handle.Po \
 	./$(DEPDIR)/file_ioctl.Po ./$(DEPDIR)/filter-unavailable.Po \
 	./$(DEPDIR)/filter_seccomp-flag.Po \
 	./$(DEPDIR)/filter_seccomp-perf.Po ./$(DEPDIR)/finit_module.Po \
-	./$(DEPDIR)/flock.Po ./$(DEPDIR)/fork-f.Po \
-	./$(DEPDIR)/fsconfig-P.Po ./$(DEPDIR)/fsconfig.Po \
-	./$(DEPDIR)/fsmount.Po ./$(DEPDIR)/fsopen.Po \
-	./$(DEPDIR)/fspick-P.Po ./$(DEPDIR)/fspick.Po \
-	./$(DEPDIR)/fstat-Xabbrev.Po ./$(DEPDIR)/fstat-Xraw.Po \
-	./$(DEPDIR)/fstat-Xverbose.Po ./$(DEPDIR)/fstat.Po \
-	./$(DEPDIR)/fstat64-Xabbrev.Po ./$(DEPDIR)/fstat64-Xraw.Po \
-	./$(DEPDIR)/fstat64-Xverbose.Po ./$(DEPDIR)/fstat64-fstat64.Po \
+	./$(DEPDIR)/flock.Po ./$(DEPDIR)/fork--pidns-translation.Po \
+	./$(DEPDIR)/fork-f.Po ./$(DEPDIR)/fsconfig-P.Po \
+	./$(DEPDIR)/fsconfig.Po ./$(DEPDIR)/fsmount.Po \
+	./$(DEPDIR)/fsopen.Po ./$(DEPDIR)/fspick-P.Po \
+	./$(DEPDIR)/fspick.Po ./$(DEPDIR)/fstat-Xabbrev.Po \
+	./$(DEPDIR)/fstat-Xraw.Po ./$(DEPDIR)/fstat-Xverbose.Po \
+	./$(DEPDIR)/fstat.Po ./$(DEPDIR)/fstat64-Xabbrev.Po \
+	./$(DEPDIR)/fstat64-Xraw.Po ./$(DEPDIR)/fstat64-Xverbose.Po \
+	./$(DEPDIR)/fstat64-fstat64.Po \
 	./$(DEPDIR)/fstatat64-fstatat64.Po ./$(DEPDIR)/fstatfs.Po \
 	./$(DEPDIR)/fstatfs64.Po ./$(DEPDIR)/fsync-y.Po \
 	./$(DEPDIR)/fsync.Po ./$(DEPDIR)/ftruncate.Po \
 	./$(DEPDIR)/ftruncate64-ftruncate64.Po ./$(DEPDIR)/futex.Po \
 	./$(DEPDIR)/futimesat.Po ./$(DEPDIR)/get_mempolicy.Po \
-	./$(DEPDIR)/getcpu.Po ./$(DEPDIR)/getcwd.Po \
-	./$(DEPDIR)/getdents.Po ./$(DEPDIR)/getdents64.Po \
-	./$(DEPDIR)/getegid.Po ./$(DEPDIR)/getegid32.Po \
-	./$(DEPDIR)/geteuid.Po ./$(DEPDIR)/geteuid32.Po \
-	./$(DEPDIR)/getgid.Po ./$(DEPDIR)/getgid32.Po \
-	./$(DEPDIR)/getgroups.Po ./$(DEPDIR)/getgroups32.Po \
-	./$(DEPDIR)/getpeername.Po ./$(DEPDIR)/getpgrp.Po \
-	./$(DEPDIR)/getpid.Po ./$(DEPDIR)/getppid.Po \
-	./$(DEPDIR)/getrandom.Po ./$(DEPDIR)/getresgid.Po \
-	./$(DEPDIR)/getresgid32.Po ./$(DEPDIR)/getresuid.Po \
-	./$(DEPDIR)/getresuid32.Po ./$(DEPDIR)/getrlimit.Po \
-	./$(DEPDIR)/getrusage.Po ./$(DEPDIR)/getsid.Po \
-	./$(DEPDIR)/getsockname.Po ./$(DEPDIR)/gettid.Po \
+	./$(DEPDIR)/get_process_reaper.Po ./$(DEPDIR)/getcpu.Po \
+	./$(DEPDIR)/getcwd.Po ./$(DEPDIR)/getdents-v.Po \
+	./$(DEPDIR)/getdents.Po ./$(DEPDIR)/getdents64-v.Po \
+	./$(DEPDIR)/getdents64.Po ./$(DEPDIR)/getegid.Po \
+	./$(DEPDIR)/getegid32.Po ./$(DEPDIR)/geteuid.Po \
+	./$(DEPDIR)/geteuid32.Po ./$(DEPDIR)/getgid.Po \
+	./$(DEPDIR)/getgid32.Po ./$(DEPDIR)/getgroups.Po \
+	./$(DEPDIR)/getgroups32.Po ./$(DEPDIR)/getpeername.Po \
+	./$(DEPDIR)/getpgrp--pidns-translation.Po \
+	./$(DEPDIR)/getpgrp.Po \
+	./$(DEPDIR)/getpid--pidns-translation.Po ./$(DEPDIR)/getpid.Po \
+	./$(DEPDIR)/getppid.Po ./$(DEPDIR)/getrandom.Po \
+	./$(DEPDIR)/getresgid.Po ./$(DEPDIR)/getresgid32.Po \
+	./$(DEPDIR)/getresuid.Po ./$(DEPDIR)/getresuid32.Po \
+	./$(DEPDIR)/getrlimit.Po ./$(DEPDIR)/getrusage.Po \
+	./$(DEPDIR)/getsid--pidns-translation.Po ./$(DEPDIR)/getsid.Po \
+	./$(DEPDIR)/getsockname.Po \
+	./$(DEPDIR)/gettid--pidns-translation.Po ./$(DEPDIR)/gettid.Po \
 	./$(DEPDIR)/getuid.Po ./$(DEPDIR)/getuid32.Po \
-	./$(DEPDIR)/getxxid.Po ./$(DEPDIR)/group_req.Po \
+	./$(DEPDIR)/getxgid.Po ./$(DEPDIR)/getxpid.Po \
+	./$(DEPDIR)/getxuid.Po ./$(DEPDIR)/group_req.Po \
 	./$(DEPDIR)/inet-cmsg.Po ./$(DEPDIR)/init_module.Po \
 	./$(DEPDIR)/inject-nf.Po ./$(DEPDIR)/inotify.Po \
 	./$(DEPDIR)/inotify_init-y.Po ./$(DEPDIR)/inotify_init.Po \
 	./$(DEPDIR)/inotify_init1-y.Po ./$(DEPDIR)/inotify_init1.Po \
 	./$(DEPDIR)/int_0x80.Po ./$(DEPDIR)/io_uring_enter.Po \
 	./$(DEPDIR)/io_uring_register.Po ./$(DEPDIR)/io_uring_setup.Po \
-	./$(DEPDIR)/ioctl.Po ./$(DEPDIR)/ioctl_block.Po \
-	./$(DEPDIR)/ioctl_dm-v.Po ./$(DEPDIR)/ioctl_dm.Po \
-	./$(DEPDIR)/ioctl_evdev-Xabbrev.Po \
+	./$(DEPDIR)/ioctl.Po \
+	./$(DEPDIR)/ioctl_block--pidns-translation.Po \
+	./$(DEPDIR)/ioctl_block.Po ./$(DEPDIR)/ioctl_dm-v.Po \
+	./$(DEPDIR)/ioctl_dm.Po ./$(DEPDIR)/ioctl_evdev-Xabbrev.Po \
 	./$(DEPDIR)/ioctl_evdev-Xraw.Po \
 	./$(DEPDIR)/ioctl_evdev-Xverbose.Po \
 	./$(DEPDIR)/ioctl_evdev-success-Xabbrev.Po \
@@ -3303,6 +4116,21 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/ioctl_evdev-v-Xraw.Po \
 	./$(DEPDIR)/ioctl_evdev-v-Xverbose.Po \
 	./$(DEPDIR)/ioctl_evdev-v.Po ./$(DEPDIR)/ioctl_evdev.Po \
+	./$(DEPDIR)/ioctl_hdio-Xabbrev.Po \
+	./$(DEPDIR)/ioctl_hdio-Xraw.Po \
+	./$(DEPDIR)/ioctl_hdio-Xverbose.Po \
+	./$(DEPDIR)/ioctl_hdio-success-Xabbrev.Po \
+	./$(DEPDIR)/ioctl_hdio-success-Xraw.Po \
+	./$(DEPDIR)/ioctl_hdio-success-Xverbose.Po \
+	./$(DEPDIR)/ioctl_hdio-success-v-Xabbrev.Po \
+	./$(DEPDIR)/ioctl_hdio-success-v-Xraw.Po \
+	./$(DEPDIR)/ioctl_hdio-success-v-Xverbose.Po \
+	./$(DEPDIR)/ioctl_hdio-success-v.Po \
+	./$(DEPDIR)/ioctl_hdio-success.Po \
+	./$(DEPDIR)/ioctl_hdio-v-Xabbrev.Po \
+	./$(DEPDIR)/ioctl_hdio-v-Xraw.Po \
+	./$(DEPDIR)/ioctl_hdio-v-Xverbose.Po \
+	./$(DEPDIR)/ioctl_hdio-v.Po ./$(DEPDIR)/ioctl_hdio.Po \
 	./$(DEPDIR)/ioctl_inotify.Po ./$(DEPDIR)/ioctl_kvm_run-v.Po \
 	./$(DEPDIR)/ioctl_kvm_run.Po \
 	./$(DEPDIR)/ioctl_kvm_run_auxstr_vcpu.Po \
@@ -3314,9 +4142,24 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/ioctl_rtc-v.Po ./$(DEPDIR)/ioctl_rtc.Po \
 	./$(DEPDIR)/ioctl_scsi.Po ./$(DEPDIR)/ioctl_sg_io_v3.Po \
 	./$(DEPDIR)/ioctl_sg_io_v4.Po \
-	./$(DEPDIR)/ioctl_sock_gifconf.Po ./$(DEPDIR)/ioctl_uffdio.Po \
-	./$(DEPDIR)/ioctl_v4l2.Po ./$(DEPDIR)/ioctl_watchdog.Po \
-	./$(DEPDIR)/ioperm.Po ./$(DEPDIR)/iopl.Po \
+	./$(DEPDIR)/ioctl_sock_gifconf.Po ./$(DEPDIR)/ioctl_tee.Po \
+	./$(DEPDIR)/ioctl_uffdio.Po ./$(DEPDIR)/ioctl_v4l2-Xabbrev.Po \
+	./$(DEPDIR)/ioctl_v4l2-Xraw.Po \
+	./$(DEPDIR)/ioctl_v4l2-Xverbose.Po \
+	./$(DEPDIR)/ioctl_v4l2-success-Xabbrev.Po \
+	./$(DEPDIR)/ioctl_v4l2-success-Xraw.Po \
+	./$(DEPDIR)/ioctl_v4l2-success-Xverbose.Po \
+	./$(DEPDIR)/ioctl_v4l2-success-v-Xabbrev.Po \
+	./$(DEPDIR)/ioctl_v4l2-success-v-Xraw.Po \
+	./$(DEPDIR)/ioctl_v4l2-success-v-Xverbose.Po \
+	./$(DEPDIR)/ioctl_v4l2-success-v.Po \
+	./$(DEPDIR)/ioctl_v4l2-success.Po \
+	./$(DEPDIR)/ioctl_v4l2-v-Xabbrev.Po \
+	./$(DEPDIR)/ioctl_v4l2-v-Xraw.Po \
+	./$(DEPDIR)/ioctl_v4l2-v-Xverbose.Po \
+	./$(DEPDIR)/ioctl_v4l2-v.Po ./$(DEPDIR)/ioctl_v4l2.Po \
+	./$(DEPDIR)/ioctl_watchdog.Po ./$(DEPDIR)/ioperm.Po \
+	./$(DEPDIR)/iopl.Po ./$(DEPDIR)/ioprio--pidns-translation.Po \
 	./$(DEPDIR)/ioprio-Xabbrev.Po ./$(DEPDIR)/ioprio-Xraw.Po \
 	./$(DEPDIR)/ioprio-Xverbose.Po ./$(DEPDIR)/ioprio.Po \
 	./$(DEPDIR)/ip_mreq.Po ./$(DEPDIR)/ipc.Po \
@@ -3329,7 +4172,8 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/ipc_sem-Xverbose.Po ./$(DEPDIR)/ipc_sem.Po \
 	./$(DEPDIR)/ipc_shm-Xabbrev.Po ./$(DEPDIR)/ipc_shm-Xraw.Po \
 	./$(DEPDIR)/ipc_shm-Xverbose.Po ./$(DEPDIR)/ipc_shm.Po \
-	./$(DEPDIR)/is_linux_mips_n64.Po ./$(DEPDIR)/kcmp-y.Po \
+	./$(DEPDIR)/is_linux_mips_n64.Po \
+	./$(DEPDIR)/kcmp-y--pidns-translation.Po ./$(DEPDIR)/kcmp-y.Po \
 	./$(DEPDIR)/kcmp.Po ./$(DEPDIR)/kern_features.Po \
 	./$(DEPDIR)/kernel_version-Xabbrev.Po \
 	./$(DEPDIR)/kernel_version-Xraw.Po \
@@ -3337,10 +4181,12 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/kernel_version.Po ./$(DEPDIR)/kexec_file_load.Po \
 	./$(DEPDIR)/kexec_load.Po ./$(DEPDIR)/keyctl-Xabbrev.Po \
 	./$(DEPDIR)/keyctl-Xraw.Po ./$(DEPDIR)/keyctl-Xverbose.Po \
-	./$(DEPDIR)/keyctl.Po ./$(DEPDIR)/kill.Po \
-	./$(DEPDIR)/kill_child.Po ./$(DEPDIR)/ksysent.Po \
-	./$(DEPDIR)/lchown.Po ./$(DEPDIR)/lchown32.Po \
+	./$(DEPDIR)/keyctl.Po ./$(DEPDIR)/kill--pidns-translation.Po \
+	./$(DEPDIR)/kill.Po ./$(DEPDIR)/kill_child.Po \
+	./$(DEPDIR)/ksysent.Po ./$(DEPDIR)/lchown.Po \
+	./$(DEPDIR)/lchown32.Po \
 	./$(DEPDIR)/libtests_a-create_nl_socket.Po \
+	./$(DEPDIR)/libtests_a-create_tmpfile.Po \
 	./$(DEPDIR)/libtests_a-errno2name.Po \
 	./$(DEPDIR)/libtests_a-error_msg.Po \
 	./$(DEPDIR)/libtests_a-fill_memory.Po \
@@ -3354,6 +4200,7 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/libtests_a-libsocketcall.Po \
 	./$(DEPDIR)/libtests_a-lock_file.Po \
 	./$(DEPDIR)/libtests_a-overflowuid.Po \
+	./$(DEPDIR)/libtests_a-pidns.Po \
 	./$(DEPDIR)/libtests_a-pipe_maxfd.Po \
 	./$(DEPDIR)/libtests_a-print_quoted_string.Po \
 	./$(DEPDIR)/libtests_a-print_time.Po \
@@ -3369,26 +4216,30 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/libtests_a-test_printpath.Po \
 	./$(DEPDIR)/libtests_a-test_printstrn.Po \
 	./$(DEPDIR)/libtests_a-test_ucopy.Po \
-	./$(DEPDIR)/libtests_a-tprintf.Po ./$(DEPDIR)/link.Po \
-	./$(DEPDIR)/linkat.Po ./$(DEPDIR)/list_sigaction_signum.Po \
-	./$(DEPDIR)/llseek.Po ./$(DEPDIR)/localtime.Po \
-	./$(DEPDIR)/lookup_dcookie.Po ./$(DEPDIR)/looping_threads.Po \
-	./$(DEPDIR)/lseek.Po ./$(DEPDIR)/lstat.Po \
-	./$(DEPDIR)/lstat64-lstat64.Po ./$(DEPDIR)/madvise.Po \
+	./$(DEPDIR)/libtests_a-tprintf.Po \
+	./$(DEPDIR)/libtests_a-xmalloc_for_tests.Po \
+	./$(DEPDIR)/link.Po ./$(DEPDIR)/linkat.Po \
+	./$(DEPDIR)/list_sigaction_signum.Po ./$(DEPDIR)/llseek.Po \
+	./$(DEPDIR)/localtime.Po ./$(DEPDIR)/lookup_dcookie.Po \
+	./$(DEPDIR)/looping_threads.Po ./$(DEPDIR)/lseek.Po \
+	./$(DEPDIR)/lstat.Po ./$(DEPDIR)/lstat64-lstat64.Po \
+	./$(DEPDIR)/madvise.Po \
+	./$(DEPDIR)/maybe_switch_current_tcp--quiet-thread-execve.Po \
 	./$(DEPDIR)/maybe_switch_current_tcp.Po \
 	./$(DEPDIR)/mbind-Xabbrev.Po ./$(DEPDIR)/mbind-Xraw.Po \
 	./$(DEPDIR)/mbind-Xverbose.Po ./$(DEPDIR)/mbind.Po \
 	./$(DEPDIR)/membarrier.Po ./$(DEPDIR)/memfd_create-Xabbrev.Po \
 	./$(DEPDIR)/memfd_create-Xraw.Po \
 	./$(DEPDIR)/memfd_create-Xverbose.Po \
-	./$(DEPDIR)/memfd_create.Po ./$(DEPDIR)/migrate_pages.Po \
-	./$(DEPDIR)/mincore.Po ./$(DEPDIR)/mkdir.Po \
-	./$(DEPDIR)/mkdirat.Po ./$(DEPDIR)/mknod.Po \
-	./$(DEPDIR)/mknodat.Po ./$(DEPDIR)/mlock.Po \
-	./$(DEPDIR)/mlock2.Po ./$(DEPDIR)/mlockall.Po \
-	./$(DEPDIR)/mmap-Xabbrev.Po ./$(DEPDIR)/mmap-Xraw.Po \
-	./$(DEPDIR)/mmap-Xverbose.Po ./$(DEPDIR)/mmap.Po \
-	./$(DEPDIR)/mmap64-mmap64.Po \
+	./$(DEPDIR)/memfd_create.Po \
+	./$(DEPDIR)/migrate_pages--pidns-translation.Po \
+	./$(DEPDIR)/migrate_pages.Po ./$(DEPDIR)/mincore.Po \
+	./$(DEPDIR)/mkdir.Po ./$(DEPDIR)/mkdirat.Po \
+	./$(DEPDIR)/mknod.Po ./$(DEPDIR)/mknodat.Po \
+	./$(DEPDIR)/mlock.Po ./$(DEPDIR)/mlock2.Po \
+	./$(DEPDIR)/mlockall.Po ./$(DEPDIR)/mmap-Xabbrev.Po \
+	./$(DEPDIR)/mmap-Xraw.Po ./$(DEPDIR)/mmap-Xverbose.Po \
+	./$(DEPDIR)/mmap.Po ./$(DEPDIR)/mmap64-mmap64.Po \
 	./$(DEPDIR)/mmap64_Xabbrev-mmap64-Xabbrev.Po \
 	./$(DEPDIR)/mmap64_Xraw-mmap64-Xraw.Po \
 	./$(DEPDIR)/mmap64_Xverbose-mmap64-Xverbose.Po \
@@ -3397,24 +4248,33 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/modify_ldt.Po ./$(DEPDIR)/mount-Xabbrev.Po \
 	./$(DEPDIR)/mount-Xraw.Po ./$(DEPDIR)/mount-Xverbose.Po \
 	./$(DEPDIR)/mount.Po ./$(DEPDIR)/move_mount-P.Po \
-	./$(DEPDIR)/move_mount.Po ./$(DEPDIR)/move_pages-Xabbrev.Po \
+	./$(DEPDIR)/move_mount.Po \
+	./$(DEPDIR)/move_pages--pidns-translation.Po \
+	./$(DEPDIR)/move_pages-Xabbrev.Po \
 	./$(DEPDIR)/move_pages-Xraw.Po \
 	./$(DEPDIR)/move_pages-Xverbose.Po ./$(DEPDIR)/move_pages.Po \
 	./$(DEPDIR)/mq.Po ./$(DEPDIR)/mq_sendrecv-read.Po \
 	./$(DEPDIR)/mq_sendrecv-write.Po ./$(DEPDIR)/mq_sendrecv.Po \
 	./$(DEPDIR)/msg_control-v.Po ./$(DEPDIR)/msg_control.Po \
 	./$(DEPDIR)/msg_name.Po ./$(DEPDIR)/munlockall.Po \
-	./$(DEPDIR)/nanosleep.Po ./$(DEPDIR)/net-accept-connect.Po \
+	./$(DEPDIR)/nanosleep.Po \
+	./$(DEPDIR)/net--decode-fds-dev-netlink.Po \
+	./$(DEPDIR)/net--decode-fds-none-netlink.Po \
+	./$(DEPDIR)/net--decode-fds-path-netlink.Po \
+	./$(DEPDIR)/net--decode-fds-socket-netlink.Po \
+	./$(DEPDIR)/net-accept-connect.Po \
 	./$(DEPDIR)/net-icmp_filter.Po \
 	./$(DEPDIR)/net-packet_mreq-Xabbrev.Po \
 	./$(DEPDIR)/net-packet_mreq-Xraw.Po \
 	./$(DEPDIR)/net-packet_mreq-Xverbose.Po \
-	./$(DEPDIR)/net-packet_mreq.Po ./$(DEPDIR)/net-sockaddr.Po \
-	./$(DEPDIR)/net-tpacket_req.Po \
+	./$(DEPDIR)/net-packet_mreq.Po \
+	./$(DEPDIR)/net-sockaddr--pidns-translation.Po \
+	./$(DEPDIR)/net-sockaddr.Po ./$(DEPDIR)/net-tpacket_req.Po \
 	./$(DEPDIR)/net-tpacket_stats-success.Po \
 	./$(DEPDIR)/net-tpacket_stats.Po ./$(DEPDIR)/net-y-unix.Po \
 	./$(DEPDIR)/net-yy-inet.Po ./$(DEPDIR)/net-yy-inet6.Po \
 	./$(DEPDIR)/net-yy-netlink.Po ./$(DEPDIR)/net-yy-unix.Po \
+	./$(DEPDIR)/netlink_audit--pidns-translation.Po \
 	./$(DEPDIR)/netlink_audit.Po ./$(DEPDIR)/netlink_crypto.Po \
 	./$(DEPDIR)/netlink_generic.Po \
 	./$(DEPDIR)/netlink_inet_diag.Po \
@@ -3445,7 +4305,9 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/nlattr_ifla_af_spec.Po \
 	./$(DEPDIR)/nlattr_ifla_brport.Po \
 	./$(DEPDIR)/nlattr_ifla_linkinfo.Po \
-	./$(DEPDIR)/nlattr_ifla_port.Po ./$(DEPDIR)/nlattr_ifla_xdp.Po \
+	./$(DEPDIR)/nlattr_ifla_port.Po \
+	./$(DEPDIR)/nlattr_ifla_xdp-y.Po \
+	./$(DEPDIR)/nlattr_ifla_xdp.Po \
 	./$(DEPDIR)/nlattr_inet_diag_msg.Po \
 	./$(DEPDIR)/nlattr_inet_diag_req_compat.Po \
 	./$(DEPDIR)/nlattr_inet_diag_req_v2.Po \
@@ -3470,7 +4332,13 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/oldselect-efault.Po ./$(DEPDIR)/oldselect.Po \
 	./$(DEPDIR)/oldstat.Po ./$(DEPDIR)/open.Po \
 	./$(DEPDIR)/open_tree-P.Po ./$(DEPDIR)/open_tree.Po \
-	./$(DEPDIR)/openat.Po ./$(DEPDIR)/orphaned_process_group.Po \
+	./$(DEPDIR)/openat.Po ./$(DEPDIR)/openat2-Xabbrev.Po \
+	./$(DEPDIR)/openat2-Xraw.Po ./$(DEPDIR)/openat2-Xverbose.Po \
+	./$(DEPDIR)/openat2-v-y-Xabbrev.Po \
+	./$(DEPDIR)/openat2-v-y-Xraw.Po \
+	./$(DEPDIR)/openat2-v-y-Xverbose.Po ./$(DEPDIR)/openat2-v-y.Po \
+	./$(DEPDIR)/openat2-v.Po ./$(DEPDIR)/openat2-y.Po \
+	./$(DEPDIR)/openat2.Po ./$(DEPDIR)/orphaned_process_group.Po \
 	./$(DEPDIR)/osf_utimes.Po ./$(DEPDIR)/pause.Po \
 	./$(DEPDIR)/pc.Po ./$(DEPDIR)/perf_event_open.Po \
 	./$(DEPDIR)/perf_event_open_nonverbose.Po \
@@ -3478,8 +4346,16 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/personality-Xabbrev.Po \
 	./$(DEPDIR)/personality-Xraw.Po \
 	./$(DEPDIR)/personality-Xverbose.Po ./$(DEPDIR)/personality.Po \
+	./$(DEPDIR)/pidfd_getfd-y.Po ./$(DEPDIR)/pidfd_getfd-yy.Po \
+	./$(DEPDIR)/pidfd_getfd.Po \
+	./$(DEPDIR)/pidfd_open--decode-fd-path.Po \
+	./$(DEPDIR)/pidfd_open--decode-fd-pidfd.Po \
+	./$(DEPDIR)/pidfd_open--decode-fd-socket.Po \
+	./$(DEPDIR)/pidfd_open--pidns-translation.Po \
 	./$(DEPDIR)/pidfd_open-P.Po ./$(DEPDIR)/pidfd_open-y.Po \
-	./$(DEPDIR)/pidfd_open.Po ./$(DEPDIR)/pidfd_send_signal.Po \
+	./$(DEPDIR)/pidfd_open-yy.Po ./$(DEPDIR)/pidfd_open.Po \
+	./$(DEPDIR)/pidfd_send_signal--pidns-translation.Po \
+	./$(DEPDIR)/pidfd_send_signal.Po ./$(DEPDIR)/pidns-cache.Po \
 	./$(DEPDIR)/pipe.Po ./$(DEPDIR)/pipe2.Po \
 	./$(DEPDIR)/pkey_alloc.Po ./$(DEPDIR)/pkey_free.Po \
 	./$(DEPDIR)/pkey_mprotect.Po ./$(DEPDIR)/poll-P.Po \
@@ -3496,7 +4372,7 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/pread64_pwrite64-pread64-pwrite64.Po \
 	./$(DEPDIR)/preadv-preadv.Po ./$(DEPDIR)/preadv2-pwritev2.Po \
 	./$(DEPDIR)/preadv_pwritev-preadv-pwritev.Po \
-	./$(DEPDIR)/print_maxfd.Po \
+	./$(DEPDIR)/print_maxfd.Po ./$(DEPDIR)/print_ppid_tracerpid.Po \
 	./$(DEPDIR)/printpath-umovestr-peekdata.Po \
 	./$(DEPDIR)/printpath-umovestr-undumpable.Po \
 	./$(DEPDIR)/printpath-umovestr.Po \
@@ -3505,8 +4381,12 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/printsignal-Xverbose.Po ./$(DEPDIR)/printstr.Po \
 	./$(DEPDIR)/printstrn-umoven-peekdata.Po \
 	./$(DEPDIR)/printstrn-umoven-undumpable.Po \
-	./$(DEPDIR)/printstrn-umoven.Po ./$(DEPDIR)/prlimit64.Po \
+	./$(DEPDIR)/printstrn-umoven.Po \
+	./$(DEPDIR)/prlimit64--pidns-translation.Po \
+	./$(DEPDIR)/prlimit64.Po \
+	./$(DEPDIR)/process_vm_readv--pidns-translation.Po \
 	./$(DEPDIR)/process_vm_readv.Po \
+	./$(DEPDIR)/process_vm_writev--pidns-translation.Po \
 	./$(DEPDIR)/process_vm_writev.Po ./$(DEPDIR)/pselect6.Po \
 	./$(DEPDIR)/ptrace.Po ./$(DEPDIR)/ptrace_syscall_info.Po \
 	./$(DEPDIR)/pwritev-pwritev.Po ./$(DEPDIR)/qual_fault.Po \
@@ -3536,9 +4416,11 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/request_key.Po ./$(DEPDIR)/restart_syscall.Po \
 	./$(DEPDIR)/riscv_flush_icache.Po ./$(DEPDIR)/rmdir.Po \
 	./$(DEPDIR)/rt_sigaction.Po ./$(DEPDIR)/rt_sigpending.Po \
-	./$(DEPDIR)/rt_sigprocmask.Po ./$(DEPDIR)/rt_sigqueueinfo.Po \
-	./$(DEPDIR)/rt_sigreturn.Po ./$(DEPDIR)/rt_sigsuspend.Po \
-	./$(DEPDIR)/rt_sigtimedwait.Po \
+	./$(DEPDIR)/rt_sigprocmask.Po \
+	./$(DEPDIR)/rt_sigqueueinfo--pidns-translation.Po \
+	./$(DEPDIR)/rt_sigqueueinfo.Po ./$(DEPDIR)/rt_sigreturn.Po \
+	./$(DEPDIR)/rt_sigsuspend.Po ./$(DEPDIR)/rt_sigtimedwait.Po \
+	./$(DEPDIR)/rt_tgsigqueueinfo--pidns-translation.Po \
 	./$(DEPDIR)/rt_tgsigqueueinfo.Po \
 	./$(DEPDIR)/run_expect_termsig.Po \
 	./$(DEPDIR)/s390_guarded_storage-v.Po \
@@ -3548,8 +4430,13 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/s390_sthyi.Po \
 	./$(DEPDIR)/sched_get_priority_mxx.Po \
 	./$(DEPDIR)/sched_rr_get_interval.Po \
-	./$(DEPDIR)/sched_xetaffinity.Po ./$(DEPDIR)/sched_xetattr.Po \
+	./$(DEPDIR)/sched_xetaffinity--pidns-translation.Po \
+	./$(DEPDIR)/sched_xetaffinity.Po \
+	./$(DEPDIR)/sched_xetattr--pidns-translation.Po \
+	./$(DEPDIR)/sched_xetattr.Po \
+	./$(DEPDIR)/sched_xetparam--pidns-translation.Po \
 	./$(DEPDIR)/sched_xetparam.Po \
+	./$(DEPDIR)/sched_xetscheduler--pidns-translation.Po \
 	./$(DEPDIR)/sched_xetscheduler.Po ./$(DEPDIR)/sched_yield.Po \
 	./$(DEPDIR)/scm_rights.Po ./$(DEPDIR)/seccomp-filter-v.Po \
 	./$(DEPDIR)/seccomp-filter.Po ./$(DEPDIR)/seccomp-strict.Po \
@@ -3567,22 +4454,25 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/setfsuid32.Po ./$(DEPDIR)/setgid.Po \
 	./$(DEPDIR)/setgid32.Po ./$(DEPDIR)/setgroups.Po \
 	./$(DEPDIR)/setgroups32.Po ./$(DEPDIR)/sethostname.Po \
-	./$(DEPDIR)/setns.Po ./$(DEPDIR)/setregid.Po \
-	./$(DEPDIR)/setregid32.Po ./$(DEPDIR)/setresgid.Po \
-	./$(DEPDIR)/setresgid32.Po ./$(DEPDIR)/setresuid.Po \
-	./$(DEPDIR)/setresuid32.Po ./$(DEPDIR)/setreuid.Po \
-	./$(DEPDIR)/setreuid32.Po ./$(DEPDIR)/setrlimit-Xabbrev.Po \
-	./$(DEPDIR)/setrlimit-Xraw.Po \
+	./$(DEPDIR)/setns.Po ./$(DEPDIR)/setpgrp-exec.Po \
+	./$(DEPDIR)/setregid.Po ./$(DEPDIR)/setregid32.Po \
+	./$(DEPDIR)/setresgid.Po ./$(DEPDIR)/setresgid32.Po \
+	./$(DEPDIR)/setresuid.Po ./$(DEPDIR)/setresuid32.Po \
+	./$(DEPDIR)/setreuid.Po ./$(DEPDIR)/setreuid32.Po \
+	./$(DEPDIR)/setrlimit-Xabbrev.Po ./$(DEPDIR)/setrlimit-Xraw.Po \
 	./$(DEPDIR)/setrlimit-Xverbose.Po ./$(DEPDIR)/setrlimit.Po \
 	./$(DEPDIR)/setuid.Po ./$(DEPDIR)/setuid32.Po \
 	./$(DEPDIR)/shmxt.Po ./$(DEPDIR)/shutdown.Po \
 	./$(DEPDIR)/sigaction.Po ./$(DEPDIR)/sigaltstack.Po \
 	./$(DEPDIR)/siginfo.Po ./$(DEPDIR)/signal.Po \
+	./$(DEPDIR)/signal_receive--pidns-translation.Po \
 	./$(DEPDIR)/signal_receive.Po ./$(DEPDIR)/signalfd4.Po \
 	./$(DEPDIR)/sigpending.Po ./$(DEPDIR)/sigprocmask.Po \
 	./$(DEPDIR)/sigreturn.Po ./$(DEPDIR)/sigsuspend.Po \
 	./$(DEPDIR)/sleep.Po ./$(DEPDIR)/so_error.Po \
-	./$(DEPDIR)/so_linger.Po ./$(DEPDIR)/so_peercred-Xabbrev.Po \
+	./$(DEPDIR)/so_linger.Po \
+	./$(DEPDIR)/so_peercred--pidns-translation.Po \
+	./$(DEPDIR)/so_peercred-Xabbrev.Po \
 	./$(DEPDIR)/so_peercred-Xraw.Po \
 	./$(DEPDIR)/so_peercred-Xverbose.Po ./$(DEPDIR)/so_peercred.Po \
 	./$(DEPDIR)/sock_filter-v-Xabbrev.Po \
@@ -3604,29 +4494,45 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/stack-fcall-mangled.Po ./$(DEPDIR)/stack-fcall.Po \
 	./$(DEPDIR)/stat.Po ./$(DEPDIR)/stat64-stat64.Po \
 	./$(DEPDIR)/statfs-statfs.Po ./$(DEPDIR)/statfs64.Po \
-	./$(DEPDIR)/status-all.Po ./$(DEPDIR)/status-failed.Po \
-	./$(DEPDIR)/status-none-f.Po \
+	./$(DEPDIR)/status-all.Po ./$(DEPDIR)/status-failed-long.Po \
+	./$(DEPDIR)/status-failed-status.Po \
+	./$(DEPDIR)/status-failed.Po ./$(DEPDIR)/status-none-f.Po \
 	./$(DEPDIR)/status-none-threads.Po ./$(DEPDIR)/status-none.Po \
+	./$(DEPDIR)/status-successful-long.Po \
+	./$(DEPDIR)/status-successful-status.Po \
 	./$(DEPDIR)/status-successful.Po \
 	./$(DEPDIR)/status-unfinished-threads.Po \
 	./$(DEPDIR)/status-unfinished.Po ./$(DEPDIR)/statx.Po \
+	./$(DEPDIR)/strace--strings-in-hex-all.Po \
+	./$(DEPDIR)/strace--strings-in-hex-non-ascii.Po \
+	./$(DEPDIR)/strace--strings-in-hex.Po ./$(DEPDIR)/strace-n.Po \
+	./$(DEPDIR)/strace-x.Po ./$(DEPDIR)/strace-xx.Po \
 	./$(DEPDIR)/swap.Po ./$(DEPDIR)/sxetmask.Po \
 	./$(DEPDIR)/symlink.Po ./$(DEPDIR)/symlinkat.Po \
 	./$(DEPDIR)/sync.Po ./$(DEPDIR)/sync_file_range.Po \
 	./$(DEPDIR)/sync_file_range2.Po ./$(DEPDIR)/sysinfo.Po \
 	./$(DEPDIR)/syslog-success.Po ./$(DEPDIR)/syslog.Po \
-	./$(DEPDIR)/tee.Po ./$(DEPDIR)/threads-execve.Po \
-	./$(DEPDIR)/time.Po ./$(DEPDIR)/timer_create.Po \
-	./$(DEPDIR)/timer_xettime.Po ./$(DEPDIR)/timerfd_xettime.Po \
-	./$(DEPDIR)/times-fail.Po ./$(DEPDIR)/times.Po \
-	./$(DEPDIR)/tracer_ppid_pgid_sid.Po ./$(DEPDIR)/truncate.Po \
+	./$(DEPDIR)/tee.Po ./$(DEPDIR)/tgkill--pidns-translation.Po \
+	./$(DEPDIR)/tgkill.Po \
+	./$(DEPDIR)/threads-execve--quiet-thread-execve.Po \
+	./$(DEPDIR)/threads-execve-q.Po \
+	./$(DEPDIR)/threads-execve-qq.Po \
+	./$(DEPDIR)/threads-execve-qqq.Po \
+	./$(DEPDIR)/threads-execve.Po ./$(DEPDIR)/time.Po \
+	./$(DEPDIR)/timer_create.Po ./$(DEPDIR)/timer_xettime.Po \
+	./$(DEPDIR)/timerfd_xettime.Po ./$(DEPDIR)/times-fail.Po \
+	./$(DEPDIR)/times.Po ./$(DEPDIR)/tkill--pidns-translation.Po \
+	./$(DEPDIR)/tkill.Po ./$(DEPDIR)/tracer_ppid_pgid_sid.Po \
+	./$(DEPDIR)/trie_test-trie_for_tests.Po \
+	./$(DEPDIR)/trie_test-trie_test.Po ./$(DEPDIR)/truncate.Po \
 	./$(DEPDIR)/truncate64-truncate64.Po ./$(DEPDIR)/ugetrlimit.Po \
 	./$(DEPDIR)/uio-uio.Po ./$(DEPDIR)/umask.Po \
 	./$(DEPDIR)/umount.Po ./$(DEPDIR)/umount2.Po \
 	./$(DEPDIR)/umoven-illptr.Po ./$(DEPDIR)/umovestr-illptr.Po \
 	./$(DEPDIR)/umovestr.Po ./$(DEPDIR)/umovestr2.Po \
 	./$(DEPDIR)/umovestr3.Po ./$(DEPDIR)/umovestr_cached.Po \
-	./$(DEPDIR)/uname.Po ./$(DEPDIR)/unblock_reset_raise.Po \
+	./$(DEPDIR)/umovestr_cached_adjacent.Po ./$(DEPDIR)/uname.Po \
+	./$(DEPDIR)/unblock_reset_raise.Po \
 	./$(DEPDIR)/unix-pair-send-recv.Po \
 	./$(DEPDIR)/unix-pair-sendto-recvfrom.Po ./$(DEPDIR)/unlink.Po \
 	./$(DEPDIR)/unlinkat.Po ./$(DEPDIR)/unshare.Po \
@@ -3639,10 +4545,15 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/wait4-v.Po ./$(DEPDIR)/wait4.Po \
 	./$(DEPDIR)/waitid-v.Po ./$(DEPDIR)/waitid.Po \
 	./$(DEPDIR)/waitpid.Po ./$(DEPDIR)/xattr-strings.Po \
-	./$(DEPDIR)/xattr.Po ./$(DEPDIR)/xet_robust_list.Po \
+	./$(DEPDIR)/xattr.Po \
+	./$(DEPDIR)/xet_robust_list--pidns-translation.Po \
+	./$(DEPDIR)/xet_robust_list.Po \
 	./$(DEPDIR)/xet_thread_area_x86.Po ./$(DEPDIR)/xetitimer.Po \
-	./$(DEPDIR)/xetpgid.Po ./$(DEPDIR)/xetpriority.Po \
-	./$(DEPDIR)/xettimeofday.Po ./$(DEPDIR)/zeroargc.Po
+	./$(DEPDIR)/xetpgid--pidns-translation.Po \
+	./$(DEPDIR)/xetpgid.Po \
+	./$(DEPDIR)/xetpriority--pidns-translation.Po \
+	./$(DEPDIR)/xetpriority.Po ./$(DEPDIR)/xettimeofday.Po \
+	./$(DEPDIR)/zeroargc.Po
 am__mv = mv -f
 AM_V_lt = $(am__v_lt_@AM_V@)
 am__v_lt_ = $(am__v_lt_@AM_DEFAULT_V@)
@@ -3667,85 +4578,121 @@ SOURCES = $(libtests_a_SOURCES) _newsele
 	block_reset_raise_run.c block_reset_run.c bpf.c \
 	bpf-obj_get_info_by_fd.c bpf-obj_get_info_by_fd-prog.c \
 	bpf-obj_get_info_by_fd-prog-v.c bpf-obj_get_info_by_fd-v.c \
-	bpf-success.c bpf-success-v.c bpf-v.c brk.c btrfs.c caps.c \
-	caps-abbrev.c check_sigblock.c check_sigign.c chmod.c chown.c \
-	chown32.c chroot.c clock_adjtime.c clock_nanosleep.c \
-	clock_xettime.c clone-flags.c clone3.c clone3-Xabbrev.c \
-	clone3-Xraw.c clone3-Xverbose.c clone3-success.c \
-	clone3-success-Xabbrev.c clone3-success-Xraw.c \
-	clone3-success-Xverbose.c clone_parent.c clone_ptrace.c \
+	bpf-success.c bpf-success-long-y.c bpf-success-v.c bpf-v.c \
+	brk.c btrfs.c caps.c caps-abbrev.c check_sigblock.c \
+	check_sigign.c chmod.c chown.c chown32.c chroot.c \
+	clock_adjtime.c clock_nanosleep.c clock_xettime.c \
+	clone-flags.c clone3.c clone3-Xabbrev.c clone3-Xraw.c \
+	clone3-Xverbose.c clone3-success.c clone3-success-Xabbrev.c \
+	clone3-success-Xraw.c clone3-success-Xverbose.c clone_parent.c \
+	clone_parent--quiet-exit.c clone_parent-q.c clone_parent-qq.c \
+	clone_ptrace.c clone_ptrace--quiet-attach.c \
+	clone_ptrace--quiet-exit.c clone_ptrace-q.c clone_ptrace-qq.c \
+	close_range.c close_range-P.c close_range-y.c close_range-yy.c \
 	copy_file_range.c count-f.c creat.c delay.c delete_module.c \
-	dev-yy.c dup.c dup2.c dup3.c epoll_create.c epoll_create1.c \
-	epoll_ctl.c epoll_pwait.c epoll_wait.c erestartsys.c eventfd.c \
-	execve.c execve-v.c execveat.c execveat-v.c faccessat.c \
-	fadvise64.c fadvise64_64.c fallocate.c fanotify_init.c \
-	fanotify_mark.c fanotify_mark-Xabbrev.c fanotify_mark-Xraw.c \
+	dev--decode-fds-dev.c dev--decode-fds-path.c \
+	dev--decode-fds-socket.c dev-yy.c dup.c dup-P.c dup-y.c \
+	dup-yy.c dup2.c dup2-P.c dup2-y.c dup2-yy.c dup3.c dup3-P.c \
+	dup3-y.c dup3-yy.c epoll_create.c epoll_create1.c epoll_ctl.c \
+	epoll_pwait.c epoll_wait.c erestartsys.c eventfd.c execve.c \
+	execve-v.c execveat.c execveat-v.c faccessat.c faccessat-P.c \
+	faccessat-y.c faccessat-yy.c faccessat2.c faccessat2-P.c \
+	faccessat2-y.c faccessat2-yy.c fadvise64.c fadvise64_64.c \
+	fallocate.c fanotify_init.c fanotify_mark.c \
+	fanotify_mark-Xabbrev.c fanotify_mark-Xraw.c \
 	fanotify_mark-Xverbose.c fchdir.c fchmod.c fchmodat.c fchown.c \
-	fchown32.c fchownat.c fcntl.c fcntl64.c fdatasync.c fflush.c \
+	fchown32.c fchownat.c fcntl.c fcntl--pidns-translation.c \
+	fcntl64.c fcntl64--pidns-translation.c fdatasync.c fflush.c \
 	file_handle.c file_ioctl.c filter-unavailable.c \
 	filter_seccomp-flag.c filter_seccomp-perf.c finit_module.c \
-	flock.c fork-f.c fsconfig.c fsconfig-P.c fsmount.c fsopen.c \
-	fspick.c fspick-P.c fstat.c fstat-Xabbrev.c fstat-Xraw.c \
-	fstat-Xverbose.c fstat64.c fstat64-Xabbrev.c fstat64-Xraw.c \
-	fstat64-Xverbose.c fstatat64.c fstatfs.c fstatfs64.c fsync.c \
-	fsync-y.c ftruncate.c ftruncate64.c futex.c futimesat.c \
-	get_mempolicy.c getcpu.c getcwd.c getdents.c getdents64.c \
-	getegid.c getegid32.c geteuid.c geteuid32.c getgid.c \
-	getgid32.c getgroups.c getgroups32.c getpeername.c getpgrp.c \
-	getpid.c getppid.c getrandom.c getresgid.c getresgid32.c \
-	getresuid.c getresuid32.c getrlimit.c getrusage.c getsid.c \
-	getsockname.c gettid.c getuid.c getuid32.c getxxid.c \
-	group_req.c inet-cmsg.c init_module.c inject-nf.c inotify.c \
-	inotify_init.c inotify_init-y.c inotify_init1.c \
-	inotify_init1-y.c int_0x80.c io_uring_enter.c \
-	io_uring_register.c io_uring_setup.c ioctl.c ioctl_block.c \
-	ioctl_dm.c ioctl_dm-v.c ioctl_evdev.c ioctl_evdev-Xabbrev.c \
+	flock.c fork--pidns-translation.c fork-f.c fsconfig.c \
+	fsconfig-P.c fsmount.c fsopen.c fspick.c fspick-P.c fstat.c \
+	fstat-Xabbrev.c fstat-Xraw.c fstat-Xverbose.c fstat64.c \
+	fstat64-Xabbrev.c fstat64-Xraw.c fstat64-Xverbose.c \
+	fstatat64.c fstatfs.c fstatfs64.c fsync.c fsync-y.c \
+	ftruncate.c ftruncate64.c futex.c futimesat.c get_mempolicy.c \
+	get_process_reaper.c getcpu.c getcwd.c getdents.c getdents-v.c \
+	getdents64.c getdents64-v.c getegid.c getegid32.c geteuid.c \
+	geteuid32.c getgid.c getgid32.c getgroups.c getgroups32.c \
+	getpeername.c getpgrp.c getpgrp--pidns-translation.c getpid.c \
+	getpid--pidns-translation.c getppid.c getrandom.c getresgid.c \
+	getresgid32.c getresuid.c getresuid32.c getrlimit.c \
+	getrusage.c getsid.c getsid--pidns-translation.c getsockname.c \
+	gettid.c gettid--pidns-translation.c getuid.c getuid32.c \
+	getxgid.c getxpid.c getxuid.c group_req.c inet-cmsg.c \
+	init_module.c inject-nf.c inotify.c inotify_init.c \
+	inotify_init-y.c inotify_init1.c inotify_init1-y.c int_0x80.c \
+	io_uring_enter.c io_uring_register.c io_uring_setup.c ioctl.c \
+	ioctl_block.c ioctl_block--pidns-translation.c ioctl_dm.c \
+	ioctl_dm-v.c ioctl_evdev.c ioctl_evdev-Xabbrev.c \
 	ioctl_evdev-Xraw.c ioctl_evdev-Xverbose.c \
 	ioctl_evdev-success.c ioctl_evdev-success-Xabbrev.c \
 	ioctl_evdev-success-Xraw.c ioctl_evdev-success-Xverbose.c \
 	ioctl_evdev-success-v.c ioctl_evdev-success-v-Xabbrev.c \
 	ioctl_evdev-success-v-Xraw.c ioctl_evdev-success-v-Xverbose.c \
 	ioctl_evdev-v.c ioctl_evdev-v-Xabbrev.c ioctl_evdev-v-Xraw.c \
-	ioctl_evdev-v-Xverbose.c ioctl_inotify.c ioctl_kvm_run.c \
+	ioctl_evdev-v-Xverbose.c ioctl_hdio.c ioctl_hdio-Xabbrev.c \
+	ioctl_hdio-Xraw.c ioctl_hdio-Xverbose.c ioctl_hdio-success.c \
+	ioctl_hdio-success-Xabbrev.c ioctl_hdio-success-Xraw.c \
+	ioctl_hdio-success-Xverbose.c ioctl_hdio-success-v.c \
+	ioctl_hdio-success-v-Xabbrev.c ioctl_hdio-success-v-Xraw.c \
+	ioctl_hdio-success-v-Xverbose.c ioctl_hdio-v.c \
+	ioctl_hdio-v-Xabbrev.c ioctl_hdio-v-Xraw.c \
+	ioctl_hdio-v-Xverbose.c ioctl_inotify.c ioctl_kvm_run.c \
 	ioctl_kvm_run-v.c ioctl_kvm_run_auxstr_vcpu.c ioctl_loop.c \
 	ioctl_loop-nv.c ioctl_loop-v.c ioctl_mtd.c ioctl_nbd.c \
 	ioctl_nsfs.c ioctl_perf.c ioctl_perf-success.c ioctl_ptp.c \
 	ioctl_random.c ioctl_rtc.c ioctl_rtc-v.c ioctl_scsi.c \
 	ioctl_sg_io_v3.c ioctl_sg_io_v4.c ioctl_sock_gifconf.c \
-	ioctl_uffdio.c ioctl_v4l2.c ioctl_watchdog.c ioperm.c iopl.c \
-	ioprio.c ioprio-Xabbrev.c ioprio-Xraw.c ioprio-Xverbose.c \
-	ip_mreq.c ipc.c ipc_msg.c ipc_msg-Xabbrev.c ipc_msg-Xraw.c \
-	ipc_msg-Xverbose.c ipc_msgbuf.c ipc_msgbuf-Xabbrev.c \
-	ipc_msgbuf-Xraw.c ipc_msgbuf-Xverbose.c ipc_sem.c \
-	ipc_sem-Xabbrev.c ipc_sem-Xraw.c ipc_sem-Xverbose.c ipc_shm.c \
-	ipc_shm-Xabbrev.c ipc_shm-Xraw.c ipc_shm-Xverbose.c \
-	is_linux_mips_n64.c kcmp.c kcmp-y.c kern_features.c \
+	ioctl_tee.c ioctl_uffdio.c ioctl_v4l2.c ioctl_v4l2-Xabbrev.c \
+	ioctl_v4l2-Xraw.c ioctl_v4l2-Xverbose.c ioctl_v4l2-success.c \
+	ioctl_v4l2-success-Xabbrev.c ioctl_v4l2-success-Xraw.c \
+	ioctl_v4l2-success-Xverbose.c ioctl_v4l2-success-v.c \
+	ioctl_v4l2-success-v-Xabbrev.c ioctl_v4l2-success-v-Xraw.c \
+	ioctl_v4l2-success-v-Xverbose.c ioctl_v4l2-v.c \
+	ioctl_v4l2-v-Xabbrev.c ioctl_v4l2-v-Xraw.c \
+	ioctl_v4l2-v-Xverbose.c ioctl_watchdog.c ioperm.c iopl.c \
+	ioprio.c ioprio--pidns-translation.c ioprio-Xabbrev.c \
+	ioprio-Xraw.c ioprio-Xverbose.c ip_mreq.c ipc.c ipc_msg.c \
+	ipc_msg-Xabbrev.c ipc_msg-Xraw.c ipc_msg-Xverbose.c \
+	ipc_msgbuf.c ipc_msgbuf-Xabbrev.c ipc_msgbuf-Xraw.c \
+	ipc_msgbuf-Xverbose.c ipc_sem.c ipc_sem-Xabbrev.c \
+	ipc_sem-Xraw.c ipc_sem-Xverbose.c ipc_shm.c ipc_shm-Xabbrev.c \
+	ipc_shm-Xraw.c ipc_shm-Xverbose.c is_linux_mips_n64.c kcmp.c \
+	kcmp-y.c kcmp-y--pidns-translation.c kern_features.c \
 	kernel_version.c kernel_version-Xabbrev.c \
 	kernel_version-Xraw.c kernel_version-Xverbose.c \
 	kexec_file_load.c kexec_load.c keyctl.c keyctl-Xabbrev.c \
-	keyctl-Xraw.c keyctl-Xverbose.c kill.c kill_child.c ksysent.c \
-	lchown.c lchown32.c link.c linkat.c list_sigaction_signum.c \
-	llseek.c localtime.c lookup_dcookie.c looping_threads.c \
-	lseek.c lstat.c lstat64.c madvise.c maybe_switch_current_tcp.c \
-	mbind.c mbind-Xabbrev.c mbind-Xraw.c mbind-Xverbose.c \
-	membarrier.c memfd_create.c memfd_create-Xabbrev.c \
-	memfd_create-Xraw.c memfd_create-Xverbose.c migrate_pages.c \
-	mincore.c mkdir.c mkdirat.c mknod.c mknodat.c mlock.c mlock2.c \
-	mlockall.c mmap.c mmap-Xabbrev.c mmap-Xraw.c mmap-Xverbose.c \
-	mmap64.c mmap64-Xabbrev.c mmap64-Xraw.c mmap64-Xverbose.c \
-	mmsg.c mmsg-silent.c mmsg_name.c mmsg_name-v.c modify_ldt.c \
-	mount.c mount-Xabbrev.c mount-Xraw.c mount-Xverbose.c \
-	move_mount.c move_mount-P.c move_pages.c move_pages-Xabbrev.c \
-	move_pages-Xraw.c move_pages-Xverbose.c mq.c mq_sendrecv.c \
-	mq_sendrecv-read.c mq_sendrecv-write.c msg_control.c \
-	msg_control-v.c msg_name.c munlockall.c nanosleep.c \
-	net-accept-connect.c net-icmp_filter.c net-packet_mreq.c \
-	net-packet_mreq-Xabbrev.c net-packet_mreq-Xraw.c \
-	net-packet_mreq-Xverbose.c net-sockaddr.c net-tpacket_req.c \
-	net-tpacket_stats.c net-tpacket_stats-success.c net-y-unix.c \
-	net-yy-inet.c net-yy-inet6.c net-yy-netlink.c net-yy-unix.c \
-	netlink_audit.c netlink_crypto.c netlink_generic.c \
-	netlink_inet_diag.c netlink_kobject_uevent.c \
+	keyctl-Xraw.c keyctl-Xverbose.c kill.c \
+	kill--pidns-translation.c kill_child.c ksysent.c lchown.c \
+	lchown32.c link.c linkat.c list_sigaction_signum.c llseek.c \
+	localtime.c lookup_dcookie.c looping_threads.c lseek.c lstat.c \
+	lstat64.c madvise.c maybe_switch_current_tcp.c \
+	maybe_switch_current_tcp--quiet-thread-execve.c mbind.c \
+	mbind-Xabbrev.c mbind-Xraw.c mbind-Xverbose.c membarrier.c \
+	memfd_create.c memfd_create-Xabbrev.c memfd_create-Xraw.c \
+	memfd_create-Xverbose.c migrate_pages.c \
+	migrate_pages--pidns-translation.c mincore.c mkdir.c mkdirat.c \
+	mknod.c mknodat.c mlock.c mlock2.c mlockall.c mmap.c \
+	mmap-Xabbrev.c mmap-Xraw.c mmap-Xverbose.c mmap64.c \
+	mmap64-Xabbrev.c mmap64-Xraw.c mmap64-Xverbose.c mmsg.c \
+	mmsg-silent.c mmsg_name.c mmsg_name-v.c modify_ldt.c mount.c \
+	mount-Xabbrev.c mount-Xraw.c mount-Xverbose.c move_mount.c \
+	move_mount-P.c move_pages.c move_pages--pidns-translation.c \
+	move_pages-Xabbrev.c move_pages-Xraw.c move_pages-Xverbose.c \
+	mq.c mq_sendrecv.c mq_sendrecv-read.c mq_sendrecv-write.c \
+	msg_control.c msg_control-v.c msg_name.c munlockall.c \
+	nanosleep.c net--decode-fds-dev-netlink.c \
+	net--decode-fds-none-netlink.c net--decode-fds-path-netlink.c \
+	net--decode-fds-socket-netlink.c net-accept-connect.c \
+	net-icmp_filter.c net-packet_mreq.c net-packet_mreq-Xabbrev.c \
+	net-packet_mreq-Xraw.c net-packet_mreq-Xverbose.c \
+	net-sockaddr.c net-sockaddr--pidns-translation.c \
+	net-tpacket_req.c net-tpacket_stats.c \
+	net-tpacket_stats-success.c net-y-unix.c net-yy-inet.c \
+	net-yy-inet6.c net-yy-netlink.c net-yy-unix.c netlink_audit.c \
+	netlink_audit--pidns-translation.c netlink_crypto.c \
+	netlink_generic.c netlink_inet_diag.c netlink_kobject_uevent.c \
 	netlink_netfilter.c netlink_netlink_diag.c netlink_protocol.c \
 	netlink_route.c netlink_selinux.c netlink_sock_diag.c \
 	netlink_unix_diag.c netlink_xfrm.c newfstatat.c \
@@ -3757,56 +4704,71 @@ SOURCES = $(libtests_a_SOURCES) _newsele
 	nlattr_fib_rule_hdr.c nlattr_ifaddrlblmsg.c nlattr_ifaddrmsg.c \
 	nlattr_ifinfomsg.c nlattr_ifla_af_spec.c nlattr_ifla_brport.c \
 	nlattr_ifla_linkinfo.c nlattr_ifla_port.c nlattr_ifla_xdp.c \
-	nlattr_inet_diag_msg.c nlattr_inet_diag_req_compat.c \
-	nlattr_inet_diag_req_v2.c nlattr_mdba_mdb_entry.c \
-	nlattr_mdba_router_port.c nlattr_ndmsg.c nlattr_ndtmsg.c \
-	nlattr_netconfmsg.c nlattr_netlink_diag_msg.c \
-	nlattr_nlmsgerr.c nlattr_packet_diag_msg.c nlattr_rtgenmsg.c \
-	nlattr_rtmsg.c nlattr_smc_diag_msg.c nlattr_tc_stats.c \
-	nlattr_tca_stab.c nlattr_tcamsg.c nlattr_tcmsg.c \
-	nlattr_unix_diag_msg.c nsyscalls.c nsyscalls-d.c old_mmap.c \
-	old_mmap-P.c old_mmap-Xabbrev.c old_mmap-Xraw.c \
-	old_mmap-Xverbose.c old_mmap-v-none.c oldfstat.c oldlstat.c \
-	oldselect.c oldselect-P.c oldselect-efault.c \
-	oldselect-efault-P.c oldstat.c open.c open_tree.c \
-	open_tree-P.c openat.c orphaned_process_group.c osf_utimes.c \
-	pause.c pc.c perf_event_open.c perf_event_open_nonverbose.c \
+	nlattr_ifla_xdp-y.c nlattr_inet_diag_msg.c \
+	nlattr_inet_diag_req_compat.c nlattr_inet_diag_req_v2.c \
+	nlattr_mdba_mdb_entry.c nlattr_mdba_router_port.c \
+	nlattr_ndmsg.c nlattr_ndtmsg.c nlattr_netconfmsg.c \
+	nlattr_netlink_diag_msg.c nlattr_nlmsgerr.c \
+	nlattr_packet_diag_msg.c nlattr_rtgenmsg.c nlattr_rtmsg.c \
+	nlattr_smc_diag_msg.c nlattr_tc_stats.c nlattr_tca_stab.c \
+	nlattr_tcamsg.c nlattr_tcmsg.c nlattr_unix_diag_msg.c \
+	nsyscalls.c nsyscalls-d.c old_mmap.c old_mmap-P.c \
+	old_mmap-Xabbrev.c old_mmap-Xraw.c old_mmap-Xverbose.c \
+	old_mmap-v-none.c oldfstat.c oldlstat.c oldselect.c \
+	oldselect-P.c oldselect-efault.c oldselect-efault-P.c \
+	oldstat.c open.c open_tree.c open_tree-P.c openat.c openat2.c \
+	openat2-Xabbrev.c openat2-Xraw.c openat2-Xverbose.c \
+	openat2-v.c openat2-v-y.c openat2-v-y-Xabbrev.c \
+	openat2-v-y-Xraw.c openat2-v-y-Xverbose.c openat2-y.c \
+	orphaned_process_group.c osf_utimes.c pause.c pc.c \
+	perf_event_open.c perf_event_open_nonverbose.c \
 	perf_event_open_unabbrev.c personality.c personality-Xabbrev.c \
-	personality-Xraw.c personality-Xverbose.c pidfd_open.c \
-	pidfd_open-P.c pidfd_open-y.c pidfd_send_signal.c pipe.c \
-	pipe2.c pkey_alloc.c pkey_free.c pkey_mprotect.c poll.c \
-	poll-P.c ppoll.c ppoll-P.c ppoll-v.c prctl-arg2-intptr.c \
-	prctl-dumpable.c prctl-name.c prctl-no-args.c \
-	prctl-pdeathsig.c prctl-seccomp-filter-v.c \
+	personality-Xraw.c personality-Xverbose.c pidfd_getfd.c \
+	pidfd_getfd-y.c pidfd_getfd-yy.c pidfd_open.c \
+	pidfd_open--decode-fd-path.c pidfd_open--decode-fd-pidfd.c \
+	pidfd_open--decode-fd-socket.c pidfd_open--pidns-translation.c \
+	pidfd_open-P.c pidfd_open-y.c pidfd_open-yy.c \
+	pidfd_send_signal.c pidfd_send_signal--pidns-translation.c \
+	pidns-cache.c pipe.c pipe2.c pkey_alloc.c pkey_free.c \
+	pkey_mprotect.c poll.c poll-P.c ppoll.c ppoll-P.c ppoll-v.c \
+	prctl-arg2-intptr.c prctl-dumpable.c prctl-name.c \
+	prctl-no-args.c prctl-pdeathsig.c prctl-seccomp-filter-v.c \
 	prctl-seccomp-strict.c prctl-securebits.c prctl-spec-inject.c \
 	prctl-tid_address.c prctl-tsc.c pread64-pwrite64.c preadv.c \
 	preadv-pwritev.c preadv2-pwritev2.c print_maxfd.c \
-	printpath-umovestr.c printpath-umovestr-peekdata.c \
-	printpath-umovestr-undumpable.c printsignal-Xabbrev.c \
-	printsignal-Xraw.c printsignal-Xverbose.c printstr.c \
-	printstrn-umoven.c printstrn-umoven-peekdata.c \
-	printstrn-umoven-undumpable.c prlimit64.c process_vm_readv.c \
-	process_vm_writev.c pselect6.c ptrace.c ptrace_syscall_info.c \
-	pwritev.c qual_fault.c qual_inject-error-signal.c \
-	qual_inject-retval.c qual_inject-signal.c qual_signal.c \
-	quotactl.c quotactl-Xabbrev.c quotactl-Xraw.c \
-	quotactl-Xverbose.c quotactl-success.c quotactl-success-v.c \
-	quotactl-v.c quotactl-xfs.c quotactl-xfs-success.c \
-	quotactl-xfs-success-v.c quotactl-xfs-v.c read-write.c \
-	readahead.c readdir.c readlink.c readlinkat.c readv.c reboot.c \
-	recv-MSG_TRUNC.c recvfrom.c recvfrom-MSG_TRUNC.c \
-	recvmmsg-timeout.c recvmsg.c redirect-fds.c remap_file_pages.c \
-	remap_file_pages-Xabbrev.c remap_file_pages-Xraw.c \
-	remap_file_pages-Xverbose.c rename.c renameat.c renameat2.c \
-	request_key.c restart_syscall.c riscv_flush_icache.c rmdir.c \
-	rt_sigaction.c rt_sigpending.c rt_sigprocmask.c \
-	rt_sigqueueinfo.c rt_sigreturn.c rt_sigsuspend.c \
-	rt_sigtimedwait.c rt_tgsigqueueinfo.c run_expect_termsig.c \
+	print_ppid_tracerpid.c printpath-umovestr.c \
+	printpath-umovestr-peekdata.c printpath-umovestr-undumpable.c \
+	printsignal-Xabbrev.c printsignal-Xraw.c \
+	printsignal-Xverbose.c printstr.c printstrn-umoven.c \
+	printstrn-umoven-peekdata.c printstrn-umoven-undumpable.c \
+	prlimit64.c prlimit64--pidns-translation.c process_vm_readv.c \
+	process_vm_readv--pidns-translation.c process_vm_writev.c \
+	process_vm_writev--pidns-translation.c pselect6.c ptrace.c \
+	ptrace_syscall_info.c pwritev.c qual_fault.c \
+	qual_inject-error-signal.c qual_inject-retval.c \
+	qual_inject-signal.c qual_signal.c quotactl.c \
+	quotactl-Xabbrev.c quotactl-Xraw.c quotactl-Xverbose.c \
+	quotactl-success.c quotactl-success-v.c quotactl-v.c \
+	quotactl-xfs.c quotactl-xfs-success.c quotactl-xfs-success-v.c \
+	quotactl-xfs-v.c read-write.c readahead.c readdir.c readlink.c \
+	readlinkat.c readv.c reboot.c recv-MSG_TRUNC.c recvfrom.c \
+	recvfrom-MSG_TRUNC.c recvmmsg-timeout.c recvmsg.c \
+	redirect-fds.c remap_file_pages.c remap_file_pages-Xabbrev.c \
+	remap_file_pages-Xraw.c remap_file_pages-Xverbose.c rename.c \
+	renameat.c renameat2.c request_key.c restart_syscall.c \
+	riscv_flush_icache.c rmdir.c rt_sigaction.c rt_sigpending.c \
+	rt_sigprocmask.c rt_sigqueueinfo.c \
+	rt_sigqueueinfo--pidns-translation.c rt_sigreturn.c \
+	rt_sigsuspend.c rt_sigtimedwait.c rt_tgsigqueueinfo.c \
+	rt_tgsigqueueinfo--pidns-translation.c run_expect_termsig.c \
 	s390_guarded_storage.c s390_guarded_storage-v.c \
 	s390_pci_mmio_read_write.c s390_runtime_instr.c s390_sthyi.c \
 	s390_sthyi-v.c sched_get_priority_mxx.c \
-	sched_rr_get_interval.c sched_xetaffinity.c sched_xetattr.c \
-	sched_xetparam.c sched_xetscheduler.c sched_yield.c \
+	sched_rr_get_interval.c sched_xetaffinity.c \
+	sched_xetaffinity--pidns-translation.c sched_xetattr.c \
+	sched_xetattr--pidns-translation.c sched_xetparam.c \
+	sched_xetparam--pidns-translation.c sched_xetscheduler.c \
+	sched_xetscheduler--pidns-translation.c sched_yield.c \
 	scm_rights.c seccomp-filter.c seccomp-filter-v.c \
 	seccomp-strict.c seccomp_get_action_avail.c select.c \
 	select-P.c semop.c semop-indirect.c semtimedop.c sendfile.c \
@@ -3815,38 +4777,50 @@ SOURCES = $(libtests_a_SOURCES) _newsele
 	set_ptracer_any.c set_sigblock.c set_sigign.c setdomainname.c \
 	setfsgid.c setfsgid32.c setfsuid.c setfsuid32.c setgid.c \
 	setgid32.c setgroups.c setgroups32.c sethostname.c setns.c \
-	setregid.c setregid32.c setresgid.c setresgid32.c setresuid.c \
-	setresuid32.c setreuid.c setreuid32.c setrlimit.c \
-	setrlimit-Xabbrev.c setrlimit-Xraw.c setrlimit-Xverbose.c \
-	setuid.c setuid32.c shmxt.c shutdown.c sigaction.c \
-	sigaltstack.c siginfo.c signal.c signal_receive.c signalfd4.c \
-	sigpending.c sigprocmask.c sigreturn.c sigsuspend.c sleep.c \
-	so_error.c so_linger.c so_peercred.c so_peercred-Xabbrev.c \
-	so_peercred-Xraw.c so_peercred-Xverbose.c sock_filter-v.c \
-	sock_filter-v-Xabbrev.c sock_filter-v-Xraw.c \
-	sock_filter-v-Xverbose.c sockaddr_xlat-Xabbrev.c \
-	sockaddr_xlat-Xraw.c sockaddr_xlat-Xverbose.c socketcall.c \
-	sockopt-sol_netlink.c sockopt-timestamp.c splice.c \
-	$(stack_fcall_SOURCES) $(stack_fcall_attach_SOURCES) \
-	$(stack_fcall_mangled_SOURCES) stat.c stat64.c statfs.c \
-	statfs64.c status-all.c status-failed.c status-none.c \
-	status-none-f.c status-none-threads.c status-successful.c \
-	status-unfinished.c status-unfinished-threads.c statx.c swap.c \
-	sxetmask.c symlink.c symlinkat.c sync.c sync_file_range.c \
-	sync_file_range2.c sysinfo.c syslog.c syslog-success.c tee.c \
-	threads-execve.c time.c timer_create.c timer_xettime.c \
-	timerfd_xettime.c times.c times-fail.c tracer_ppid_pgid_sid.c \
-	truncate.c truncate64.c ugetrlimit.c uio.c umask.c umount.c \
-	umount2.c umoven-illptr.c umovestr.c umovestr-illptr.c \
-	umovestr2.c umovestr3.c umovestr_cached.c uname.c \
-	unblock_reset_raise.c unix-pair-send-recv.c \
+	setpgrp-exec.c setregid.c setregid32.c setresgid.c \
+	setresgid32.c setresuid.c setresuid32.c setreuid.c \
+	setreuid32.c setrlimit.c setrlimit-Xabbrev.c setrlimit-Xraw.c \
+	setrlimit-Xverbose.c setuid.c setuid32.c shmxt.c shutdown.c \
+	sigaction.c sigaltstack.c siginfo.c signal.c signal_receive.c \
+	signal_receive--pidns-translation.c signalfd4.c sigpending.c \
+	sigprocmask.c sigreturn.c sigsuspend.c sleep.c so_error.c \
+	so_linger.c so_peercred.c so_peercred--pidns-translation.c \
+	so_peercred-Xabbrev.c so_peercred-Xraw.c \
+	so_peercred-Xverbose.c sock_filter-v.c sock_filter-v-Xabbrev.c \
+	sock_filter-v-Xraw.c sock_filter-v-Xverbose.c \
+	sockaddr_xlat-Xabbrev.c sockaddr_xlat-Xraw.c \
+	sockaddr_xlat-Xverbose.c socketcall.c sockopt-sol_netlink.c \
+	sockopt-timestamp.c splice.c $(stack_fcall_SOURCES) \
+	$(stack_fcall_attach_SOURCES) $(stack_fcall_mangled_SOURCES) \
+	stat.c stat64.c statfs.c statfs64.c status-all.c \
+	status-failed.c status-failed-long.c status-failed-status.c \
+	status-none.c status-none-f.c status-none-threads.c \
+	status-successful.c status-successful-long.c \
+	status-successful-status.c status-unfinished.c \
+	status-unfinished-threads.c statx.c strace--strings-in-hex.c \
+	strace--strings-in-hex-all.c \
+	strace--strings-in-hex-non-ascii.c strace-n.c strace-x.c \
+	strace-xx.c swap.c sxetmask.c symlink.c symlinkat.c sync.c \
+	sync_file_range.c sync_file_range2.c sysinfo.c syslog.c \
+	syslog-success.c tee.c tgkill.c tgkill--pidns-translation.c \
+	threads-execve.c threads-execve--quiet-thread-execve.c \
+	threads-execve-q.c threads-execve-qq.c threads-execve-qqq.c \
+	time.c timer_create.c timer_xettime.c timerfd_xettime.c \
+	times.c times-fail.c tkill.c tkill--pidns-translation.c \
+	tracer_ppid_pgid_sid.c $(trie_test_SOURCES) truncate.c \
+	truncate64.c ugetrlimit.c uio.c umask.c umount.c umount2.c \
+	umoven-illptr.c umovestr.c umovestr-illptr.c umovestr2.c \
+	umovestr3.c umovestr_cached.c umovestr_cached_adjacent.c \
+	uname.c unblock_reset_raise.c unix-pair-send-recv.c \
 	unix-pair-sendto-recvfrom.c unlink.c unlinkat.c unshare.c \
 	userfaultfd.c ustat.c utime.c utimensat.c utimensat-Xabbrev.c \
 	utimensat-Xraw.c utimensat-Xverbose.c utimes.c vfork-f.c \
 	vhangup.c vmsplice.c wait4.c wait4-v.c waitid.c waitid-v.c \
 	waitpid.c xattr.c xattr-strings.c xet_robust_list.c \
-	xet_thread_area_x86.c xetitimer.c xetpgid.c xetpriority.c \
-	xettimeofday.c zeroargc.c
+	xet_robust_list--pidns-translation.c xet_thread_area_x86.c \
+	xetitimer.c xetpgid.c xetpgid--pidns-translation.c \
+	xetpriority.c xetpriority--pidns-translation.c xettimeofday.c \
+	zeroargc.c
 DIST_SOURCES = $(libtests_a_SOURCES) _newselect.c _newselect-P.c \
 	accept.c accept4.c access.c acct.c add_key.c adjtimex.c aio.c \
 	aio_pgetevents.c alarm.c answer.c attach-f-p.c \
@@ -3854,85 +4828,121 @@ DIST_SOURCES = $(libtests_a_SOURCES) _ne
 	block_reset_raise_run.c block_reset_run.c bpf.c \
 	bpf-obj_get_info_by_fd.c bpf-obj_get_info_by_fd-prog.c \
 	bpf-obj_get_info_by_fd-prog-v.c bpf-obj_get_info_by_fd-v.c \
-	bpf-success.c bpf-success-v.c bpf-v.c brk.c btrfs.c caps.c \
-	caps-abbrev.c check_sigblock.c check_sigign.c chmod.c chown.c \
-	chown32.c chroot.c clock_adjtime.c clock_nanosleep.c \
-	clock_xettime.c clone-flags.c clone3.c clone3-Xabbrev.c \
-	clone3-Xraw.c clone3-Xverbose.c clone3-success.c \
-	clone3-success-Xabbrev.c clone3-success-Xraw.c \
-	clone3-success-Xverbose.c clone_parent.c clone_ptrace.c \
+	bpf-success.c bpf-success-long-y.c bpf-success-v.c bpf-v.c \
+	brk.c btrfs.c caps.c caps-abbrev.c check_sigblock.c \
+	check_sigign.c chmod.c chown.c chown32.c chroot.c \
+	clock_adjtime.c clock_nanosleep.c clock_xettime.c \
+	clone-flags.c clone3.c clone3-Xabbrev.c clone3-Xraw.c \
+	clone3-Xverbose.c clone3-success.c clone3-success-Xabbrev.c \
+	clone3-success-Xraw.c clone3-success-Xverbose.c clone_parent.c \
+	clone_parent--quiet-exit.c clone_parent-q.c clone_parent-qq.c \
+	clone_ptrace.c clone_ptrace--quiet-attach.c \
+	clone_ptrace--quiet-exit.c clone_ptrace-q.c clone_ptrace-qq.c \
+	close_range.c close_range-P.c close_range-y.c close_range-yy.c \
 	copy_file_range.c count-f.c creat.c delay.c delete_module.c \
-	dev-yy.c dup.c dup2.c dup3.c epoll_create.c epoll_create1.c \
-	epoll_ctl.c epoll_pwait.c epoll_wait.c erestartsys.c eventfd.c \
-	execve.c execve-v.c execveat.c execveat-v.c faccessat.c \
-	fadvise64.c fadvise64_64.c fallocate.c fanotify_init.c \
-	fanotify_mark.c fanotify_mark-Xabbrev.c fanotify_mark-Xraw.c \
+	dev--decode-fds-dev.c dev--decode-fds-path.c \
+	dev--decode-fds-socket.c dev-yy.c dup.c dup-P.c dup-y.c \
+	dup-yy.c dup2.c dup2-P.c dup2-y.c dup2-yy.c dup3.c dup3-P.c \
+	dup3-y.c dup3-yy.c epoll_create.c epoll_create1.c epoll_ctl.c \
+	epoll_pwait.c epoll_wait.c erestartsys.c eventfd.c execve.c \
+	execve-v.c execveat.c execveat-v.c faccessat.c faccessat-P.c \
+	faccessat-y.c faccessat-yy.c faccessat2.c faccessat2-P.c \
+	faccessat2-y.c faccessat2-yy.c fadvise64.c fadvise64_64.c \
+	fallocate.c fanotify_init.c fanotify_mark.c \
+	fanotify_mark-Xabbrev.c fanotify_mark-Xraw.c \
 	fanotify_mark-Xverbose.c fchdir.c fchmod.c fchmodat.c fchown.c \
-	fchown32.c fchownat.c fcntl.c fcntl64.c fdatasync.c fflush.c \
+	fchown32.c fchownat.c fcntl.c fcntl--pidns-translation.c \
+	fcntl64.c fcntl64--pidns-translation.c fdatasync.c fflush.c \
 	file_handle.c file_ioctl.c filter-unavailable.c \
 	filter_seccomp-flag.c filter_seccomp-perf.c finit_module.c \
-	flock.c fork-f.c fsconfig.c fsconfig-P.c fsmount.c fsopen.c \
-	fspick.c fspick-P.c fstat.c fstat-Xabbrev.c fstat-Xraw.c \
-	fstat-Xverbose.c fstat64.c fstat64-Xabbrev.c fstat64-Xraw.c \
-	fstat64-Xverbose.c fstatat64.c fstatfs.c fstatfs64.c fsync.c \
-	fsync-y.c ftruncate.c ftruncate64.c futex.c futimesat.c \
-	get_mempolicy.c getcpu.c getcwd.c getdents.c getdents64.c \
-	getegid.c getegid32.c geteuid.c geteuid32.c getgid.c \
-	getgid32.c getgroups.c getgroups32.c getpeername.c getpgrp.c \
-	getpid.c getppid.c getrandom.c getresgid.c getresgid32.c \
-	getresuid.c getresuid32.c getrlimit.c getrusage.c getsid.c \
-	getsockname.c gettid.c getuid.c getuid32.c getxxid.c \
-	group_req.c inet-cmsg.c init_module.c inject-nf.c inotify.c \
-	inotify_init.c inotify_init-y.c inotify_init1.c \
-	inotify_init1-y.c int_0x80.c io_uring_enter.c \
-	io_uring_register.c io_uring_setup.c ioctl.c ioctl_block.c \
-	ioctl_dm.c ioctl_dm-v.c ioctl_evdev.c ioctl_evdev-Xabbrev.c \
+	flock.c fork--pidns-translation.c fork-f.c fsconfig.c \
+	fsconfig-P.c fsmount.c fsopen.c fspick.c fspick-P.c fstat.c \
+	fstat-Xabbrev.c fstat-Xraw.c fstat-Xverbose.c fstat64.c \
+	fstat64-Xabbrev.c fstat64-Xraw.c fstat64-Xverbose.c \
+	fstatat64.c fstatfs.c fstatfs64.c fsync.c fsync-y.c \
+	ftruncate.c ftruncate64.c futex.c futimesat.c get_mempolicy.c \
+	get_process_reaper.c getcpu.c getcwd.c getdents.c getdents-v.c \
+	getdents64.c getdents64-v.c getegid.c getegid32.c geteuid.c \
+	geteuid32.c getgid.c getgid32.c getgroups.c getgroups32.c \
+	getpeername.c getpgrp.c getpgrp--pidns-translation.c getpid.c \
+	getpid--pidns-translation.c getppid.c getrandom.c getresgid.c \
+	getresgid32.c getresuid.c getresuid32.c getrlimit.c \
+	getrusage.c getsid.c getsid--pidns-translation.c getsockname.c \
+	gettid.c gettid--pidns-translation.c getuid.c getuid32.c \
+	getxgid.c getxpid.c getxuid.c group_req.c inet-cmsg.c \
+	init_module.c inject-nf.c inotify.c inotify_init.c \
+	inotify_init-y.c inotify_init1.c inotify_init1-y.c int_0x80.c \
+	io_uring_enter.c io_uring_register.c io_uring_setup.c ioctl.c \
+	ioctl_block.c ioctl_block--pidns-translation.c ioctl_dm.c \
+	ioctl_dm-v.c ioctl_evdev.c ioctl_evdev-Xabbrev.c \
 	ioctl_evdev-Xraw.c ioctl_evdev-Xverbose.c \
 	ioctl_evdev-success.c ioctl_evdev-success-Xabbrev.c \
 	ioctl_evdev-success-Xraw.c ioctl_evdev-success-Xverbose.c \
 	ioctl_evdev-success-v.c ioctl_evdev-success-v-Xabbrev.c \
 	ioctl_evdev-success-v-Xraw.c ioctl_evdev-success-v-Xverbose.c \
 	ioctl_evdev-v.c ioctl_evdev-v-Xabbrev.c ioctl_evdev-v-Xraw.c \
-	ioctl_evdev-v-Xverbose.c ioctl_inotify.c ioctl_kvm_run.c \
+	ioctl_evdev-v-Xverbose.c ioctl_hdio.c ioctl_hdio-Xabbrev.c \
+	ioctl_hdio-Xraw.c ioctl_hdio-Xverbose.c ioctl_hdio-success.c \
+	ioctl_hdio-success-Xabbrev.c ioctl_hdio-success-Xraw.c \
+	ioctl_hdio-success-Xverbose.c ioctl_hdio-success-v.c \
+	ioctl_hdio-success-v-Xabbrev.c ioctl_hdio-success-v-Xraw.c \
+	ioctl_hdio-success-v-Xverbose.c ioctl_hdio-v.c \
+	ioctl_hdio-v-Xabbrev.c ioctl_hdio-v-Xraw.c \
+	ioctl_hdio-v-Xverbose.c ioctl_inotify.c ioctl_kvm_run.c \
 	ioctl_kvm_run-v.c ioctl_kvm_run_auxstr_vcpu.c ioctl_loop.c \
 	ioctl_loop-nv.c ioctl_loop-v.c ioctl_mtd.c ioctl_nbd.c \
 	ioctl_nsfs.c ioctl_perf.c ioctl_perf-success.c ioctl_ptp.c \
 	ioctl_random.c ioctl_rtc.c ioctl_rtc-v.c ioctl_scsi.c \
 	ioctl_sg_io_v3.c ioctl_sg_io_v4.c ioctl_sock_gifconf.c \
-	ioctl_uffdio.c ioctl_v4l2.c ioctl_watchdog.c ioperm.c iopl.c \
-	ioprio.c ioprio-Xabbrev.c ioprio-Xraw.c ioprio-Xverbose.c \
-	ip_mreq.c ipc.c ipc_msg.c ipc_msg-Xabbrev.c ipc_msg-Xraw.c \
-	ipc_msg-Xverbose.c ipc_msgbuf.c ipc_msgbuf-Xabbrev.c \
-	ipc_msgbuf-Xraw.c ipc_msgbuf-Xverbose.c ipc_sem.c \
-	ipc_sem-Xabbrev.c ipc_sem-Xraw.c ipc_sem-Xverbose.c ipc_shm.c \
-	ipc_shm-Xabbrev.c ipc_shm-Xraw.c ipc_shm-Xverbose.c \
-	is_linux_mips_n64.c kcmp.c kcmp-y.c kern_features.c \
+	ioctl_tee.c ioctl_uffdio.c ioctl_v4l2.c ioctl_v4l2-Xabbrev.c \
+	ioctl_v4l2-Xraw.c ioctl_v4l2-Xverbose.c ioctl_v4l2-success.c \
+	ioctl_v4l2-success-Xabbrev.c ioctl_v4l2-success-Xraw.c \
+	ioctl_v4l2-success-Xverbose.c ioctl_v4l2-success-v.c \
+	ioctl_v4l2-success-v-Xabbrev.c ioctl_v4l2-success-v-Xraw.c \
+	ioctl_v4l2-success-v-Xverbose.c ioctl_v4l2-v.c \
+	ioctl_v4l2-v-Xabbrev.c ioctl_v4l2-v-Xraw.c \
+	ioctl_v4l2-v-Xverbose.c ioctl_watchdog.c ioperm.c iopl.c \
+	ioprio.c ioprio--pidns-translation.c ioprio-Xabbrev.c \
+	ioprio-Xraw.c ioprio-Xverbose.c ip_mreq.c ipc.c ipc_msg.c \
+	ipc_msg-Xabbrev.c ipc_msg-Xraw.c ipc_msg-Xverbose.c \
+	ipc_msgbuf.c ipc_msgbuf-Xabbrev.c ipc_msgbuf-Xraw.c \
+	ipc_msgbuf-Xverbose.c ipc_sem.c ipc_sem-Xabbrev.c \
+	ipc_sem-Xraw.c ipc_sem-Xverbose.c ipc_shm.c ipc_shm-Xabbrev.c \
+	ipc_shm-Xraw.c ipc_shm-Xverbose.c is_linux_mips_n64.c kcmp.c \
+	kcmp-y.c kcmp-y--pidns-translation.c kern_features.c \
 	kernel_version.c kernel_version-Xabbrev.c \
 	kernel_version-Xraw.c kernel_version-Xverbose.c \
 	kexec_file_load.c kexec_load.c keyctl.c keyctl-Xabbrev.c \
-	keyctl-Xraw.c keyctl-Xverbose.c kill.c kill_child.c ksysent.c \
-	lchown.c lchown32.c link.c linkat.c list_sigaction_signum.c \
-	llseek.c localtime.c lookup_dcookie.c looping_threads.c \
-	lseek.c lstat.c lstat64.c madvise.c maybe_switch_current_tcp.c \
-	mbind.c mbind-Xabbrev.c mbind-Xraw.c mbind-Xverbose.c \
-	membarrier.c memfd_create.c memfd_create-Xabbrev.c \
-	memfd_create-Xraw.c memfd_create-Xverbose.c migrate_pages.c \
-	mincore.c mkdir.c mkdirat.c mknod.c mknodat.c mlock.c mlock2.c \
-	mlockall.c mmap.c mmap-Xabbrev.c mmap-Xraw.c mmap-Xverbose.c \
-	mmap64.c mmap64-Xabbrev.c mmap64-Xraw.c mmap64-Xverbose.c \
-	mmsg.c mmsg-silent.c mmsg_name.c mmsg_name-v.c modify_ldt.c \
-	mount.c mount-Xabbrev.c mount-Xraw.c mount-Xverbose.c \
-	move_mount.c move_mount-P.c move_pages.c move_pages-Xabbrev.c \
-	move_pages-Xraw.c move_pages-Xverbose.c mq.c mq_sendrecv.c \
-	mq_sendrecv-read.c mq_sendrecv-write.c msg_control.c \
-	msg_control-v.c msg_name.c munlockall.c nanosleep.c \
-	net-accept-connect.c net-icmp_filter.c net-packet_mreq.c \
-	net-packet_mreq-Xabbrev.c net-packet_mreq-Xraw.c \
-	net-packet_mreq-Xverbose.c net-sockaddr.c net-tpacket_req.c \
-	net-tpacket_stats.c net-tpacket_stats-success.c net-y-unix.c \
-	net-yy-inet.c net-yy-inet6.c net-yy-netlink.c net-yy-unix.c \
-	netlink_audit.c netlink_crypto.c netlink_generic.c \
-	netlink_inet_diag.c netlink_kobject_uevent.c \
+	keyctl-Xraw.c keyctl-Xverbose.c kill.c \
+	kill--pidns-translation.c kill_child.c ksysent.c lchown.c \
+	lchown32.c link.c linkat.c list_sigaction_signum.c llseek.c \
+	localtime.c lookup_dcookie.c looping_threads.c lseek.c lstat.c \
+	lstat64.c madvise.c maybe_switch_current_tcp.c \
+	maybe_switch_current_tcp--quiet-thread-execve.c mbind.c \
+	mbind-Xabbrev.c mbind-Xraw.c mbind-Xverbose.c membarrier.c \
+	memfd_create.c memfd_create-Xabbrev.c memfd_create-Xraw.c \
+	memfd_create-Xverbose.c migrate_pages.c \
+	migrate_pages--pidns-translation.c mincore.c mkdir.c mkdirat.c \
+	mknod.c mknodat.c mlock.c mlock2.c mlockall.c mmap.c \
+	mmap-Xabbrev.c mmap-Xraw.c mmap-Xverbose.c mmap64.c \
+	mmap64-Xabbrev.c mmap64-Xraw.c mmap64-Xverbose.c mmsg.c \
+	mmsg-silent.c mmsg_name.c mmsg_name-v.c modify_ldt.c mount.c \
+	mount-Xabbrev.c mount-Xraw.c mount-Xverbose.c move_mount.c \
+	move_mount-P.c move_pages.c move_pages--pidns-translation.c \
+	move_pages-Xabbrev.c move_pages-Xraw.c move_pages-Xverbose.c \
+	mq.c mq_sendrecv.c mq_sendrecv-read.c mq_sendrecv-write.c \
+	msg_control.c msg_control-v.c msg_name.c munlockall.c \
+	nanosleep.c net--decode-fds-dev-netlink.c \
+	net--decode-fds-none-netlink.c net--decode-fds-path-netlink.c \
+	net--decode-fds-socket-netlink.c net-accept-connect.c \
+	net-icmp_filter.c net-packet_mreq.c net-packet_mreq-Xabbrev.c \
+	net-packet_mreq-Xraw.c net-packet_mreq-Xverbose.c \
+	net-sockaddr.c net-sockaddr--pidns-translation.c \
+	net-tpacket_req.c net-tpacket_stats.c \
+	net-tpacket_stats-success.c net-y-unix.c net-yy-inet.c \
+	net-yy-inet6.c net-yy-netlink.c net-yy-unix.c netlink_audit.c \
+	netlink_audit--pidns-translation.c netlink_crypto.c \
+	netlink_generic.c netlink_inet_diag.c netlink_kobject_uevent.c \
 	netlink_netfilter.c netlink_netlink_diag.c netlink_protocol.c \
 	netlink_route.c netlink_selinux.c netlink_sock_diag.c \
 	netlink_unix_diag.c netlink_xfrm.c newfstatat.c \
@@ -3944,56 +4954,71 @@ DIST_SOURCES = $(libtests_a_SOURCES) _ne
 	nlattr_fib_rule_hdr.c nlattr_ifaddrlblmsg.c nlattr_ifaddrmsg.c \
 	nlattr_ifinfomsg.c nlattr_ifla_af_spec.c nlattr_ifla_brport.c \
 	nlattr_ifla_linkinfo.c nlattr_ifla_port.c nlattr_ifla_xdp.c \
-	nlattr_inet_diag_msg.c nlattr_inet_diag_req_compat.c \
-	nlattr_inet_diag_req_v2.c nlattr_mdba_mdb_entry.c \
-	nlattr_mdba_router_port.c nlattr_ndmsg.c nlattr_ndtmsg.c \
-	nlattr_netconfmsg.c nlattr_netlink_diag_msg.c \
-	nlattr_nlmsgerr.c nlattr_packet_diag_msg.c nlattr_rtgenmsg.c \
-	nlattr_rtmsg.c nlattr_smc_diag_msg.c nlattr_tc_stats.c \
-	nlattr_tca_stab.c nlattr_tcamsg.c nlattr_tcmsg.c \
-	nlattr_unix_diag_msg.c nsyscalls.c nsyscalls-d.c old_mmap.c \
-	old_mmap-P.c old_mmap-Xabbrev.c old_mmap-Xraw.c \
-	old_mmap-Xverbose.c old_mmap-v-none.c oldfstat.c oldlstat.c \
-	oldselect.c oldselect-P.c oldselect-efault.c \
-	oldselect-efault-P.c oldstat.c open.c open_tree.c \
-	open_tree-P.c openat.c orphaned_process_group.c osf_utimes.c \
-	pause.c pc.c perf_event_open.c perf_event_open_nonverbose.c \
+	nlattr_ifla_xdp-y.c nlattr_inet_diag_msg.c \
+	nlattr_inet_diag_req_compat.c nlattr_inet_diag_req_v2.c \
+	nlattr_mdba_mdb_entry.c nlattr_mdba_router_port.c \
+	nlattr_ndmsg.c nlattr_ndtmsg.c nlattr_netconfmsg.c \
+	nlattr_netlink_diag_msg.c nlattr_nlmsgerr.c \
+	nlattr_packet_diag_msg.c nlattr_rtgenmsg.c nlattr_rtmsg.c \
+	nlattr_smc_diag_msg.c nlattr_tc_stats.c nlattr_tca_stab.c \
+	nlattr_tcamsg.c nlattr_tcmsg.c nlattr_unix_diag_msg.c \
+	nsyscalls.c nsyscalls-d.c old_mmap.c old_mmap-P.c \
+	old_mmap-Xabbrev.c old_mmap-Xraw.c old_mmap-Xverbose.c \
+	old_mmap-v-none.c oldfstat.c oldlstat.c oldselect.c \
+	oldselect-P.c oldselect-efault.c oldselect-efault-P.c \
+	oldstat.c open.c open_tree.c open_tree-P.c openat.c openat2.c \
+	openat2-Xabbrev.c openat2-Xraw.c openat2-Xverbose.c \
+	openat2-v.c openat2-v-y.c openat2-v-y-Xabbrev.c \
+	openat2-v-y-Xraw.c openat2-v-y-Xverbose.c openat2-y.c \
+	orphaned_process_group.c osf_utimes.c pause.c pc.c \
+	perf_event_open.c perf_event_open_nonverbose.c \
 	perf_event_open_unabbrev.c personality.c personality-Xabbrev.c \
-	personality-Xraw.c personality-Xverbose.c pidfd_open.c \
-	pidfd_open-P.c pidfd_open-y.c pidfd_send_signal.c pipe.c \
-	pipe2.c pkey_alloc.c pkey_free.c pkey_mprotect.c poll.c \
-	poll-P.c ppoll.c ppoll-P.c ppoll-v.c prctl-arg2-intptr.c \
-	prctl-dumpable.c prctl-name.c prctl-no-args.c \
-	prctl-pdeathsig.c prctl-seccomp-filter-v.c \
+	personality-Xraw.c personality-Xverbose.c pidfd_getfd.c \
+	pidfd_getfd-y.c pidfd_getfd-yy.c pidfd_open.c \
+	pidfd_open--decode-fd-path.c pidfd_open--decode-fd-pidfd.c \
+	pidfd_open--decode-fd-socket.c pidfd_open--pidns-translation.c \
+	pidfd_open-P.c pidfd_open-y.c pidfd_open-yy.c \
+	pidfd_send_signal.c pidfd_send_signal--pidns-translation.c \
+	pidns-cache.c pipe.c pipe2.c pkey_alloc.c pkey_free.c \
+	pkey_mprotect.c poll.c poll-P.c ppoll.c ppoll-P.c ppoll-v.c \
+	prctl-arg2-intptr.c prctl-dumpable.c prctl-name.c \
+	prctl-no-args.c prctl-pdeathsig.c prctl-seccomp-filter-v.c \
 	prctl-seccomp-strict.c prctl-securebits.c prctl-spec-inject.c \
 	prctl-tid_address.c prctl-tsc.c pread64-pwrite64.c preadv.c \
 	preadv-pwritev.c preadv2-pwritev2.c print_maxfd.c \
-	printpath-umovestr.c printpath-umovestr-peekdata.c \
-	printpath-umovestr-undumpable.c printsignal-Xabbrev.c \
-	printsignal-Xraw.c printsignal-Xverbose.c printstr.c \
-	printstrn-umoven.c printstrn-umoven-peekdata.c \
-	printstrn-umoven-undumpable.c prlimit64.c process_vm_readv.c \
-	process_vm_writev.c pselect6.c ptrace.c ptrace_syscall_info.c \
-	pwritev.c qual_fault.c qual_inject-error-signal.c \
-	qual_inject-retval.c qual_inject-signal.c qual_signal.c \
-	quotactl.c quotactl-Xabbrev.c quotactl-Xraw.c \
-	quotactl-Xverbose.c quotactl-success.c quotactl-success-v.c \
-	quotactl-v.c quotactl-xfs.c quotactl-xfs-success.c \
-	quotactl-xfs-success-v.c quotactl-xfs-v.c read-write.c \
-	readahead.c readdir.c readlink.c readlinkat.c readv.c reboot.c \
-	recv-MSG_TRUNC.c recvfrom.c recvfrom-MSG_TRUNC.c \
-	recvmmsg-timeout.c recvmsg.c redirect-fds.c remap_file_pages.c \
-	remap_file_pages-Xabbrev.c remap_file_pages-Xraw.c \
-	remap_file_pages-Xverbose.c rename.c renameat.c renameat2.c \
-	request_key.c restart_syscall.c riscv_flush_icache.c rmdir.c \
-	rt_sigaction.c rt_sigpending.c rt_sigprocmask.c \
-	rt_sigqueueinfo.c rt_sigreturn.c rt_sigsuspend.c \
-	rt_sigtimedwait.c rt_tgsigqueueinfo.c run_expect_termsig.c \
+	print_ppid_tracerpid.c printpath-umovestr.c \
+	printpath-umovestr-peekdata.c printpath-umovestr-undumpable.c \
+	printsignal-Xabbrev.c printsignal-Xraw.c \
+	printsignal-Xverbose.c printstr.c printstrn-umoven.c \
+	printstrn-umoven-peekdata.c printstrn-umoven-undumpable.c \
+	prlimit64.c prlimit64--pidns-translation.c process_vm_readv.c \
+	process_vm_readv--pidns-translation.c process_vm_writev.c \
+	process_vm_writev--pidns-translation.c pselect6.c ptrace.c \
+	ptrace_syscall_info.c pwritev.c qual_fault.c \
+	qual_inject-error-signal.c qual_inject-retval.c \
+	qual_inject-signal.c qual_signal.c quotactl.c \
+	quotactl-Xabbrev.c quotactl-Xraw.c quotactl-Xverbose.c \
+	quotactl-success.c quotactl-success-v.c quotactl-v.c \
+	quotactl-xfs.c quotactl-xfs-success.c quotactl-xfs-success-v.c \
+	quotactl-xfs-v.c read-write.c readahead.c readdir.c readlink.c \
+	readlinkat.c readv.c reboot.c recv-MSG_TRUNC.c recvfrom.c \
+	recvfrom-MSG_TRUNC.c recvmmsg-timeout.c recvmsg.c \
+	redirect-fds.c remap_file_pages.c remap_file_pages-Xabbrev.c \
+	remap_file_pages-Xraw.c remap_file_pages-Xverbose.c rename.c \
+	renameat.c renameat2.c request_key.c restart_syscall.c \
+	riscv_flush_icache.c rmdir.c rt_sigaction.c rt_sigpending.c \
+	rt_sigprocmask.c rt_sigqueueinfo.c \
+	rt_sigqueueinfo--pidns-translation.c rt_sigreturn.c \
+	rt_sigsuspend.c rt_sigtimedwait.c rt_tgsigqueueinfo.c \
+	rt_tgsigqueueinfo--pidns-translation.c run_expect_termsig.c \
 	s390_guarded_storage.c s390_guarded_storage-v.c \
 	s390_pci_mmio_read_write.c s390_runtime_instr.c s390_sthyi.c \
 	s390_sthyi-v.c sched_get_priority_mxx.c \
-	sched_rr_get_interval.c sched_xetaffinity.c sched_xetattr.c \
-	sched_xetparam.c sched_xetscheduler.c sched_yield.c \
+	sched_rr_get_interval.c sched_xetaffinity.c \
+	sched_xetaffinity--pidns-translation.c sched_xetattr.c \
+	sched_xetattr--pidns-translation.c sched_xetparam.c \
+	sched_xetparam--pidns-translation.c sched_xetscheduler.c \
+	sched_xetscheduler--pidns-translation.c sched_yield.c \
 	scm_rights.c seccomp-filter.c seccomp-filter-v.c \
 	seccomp-strict.c seccomp_get_action_avail.c select.c \
 	select-P.c semop.c semop-indirect.c semtimedop.c sendfile.c \
@@ -4002,38 +5027,50 @@ DIST_SOURCES = $(libtests_a_SOURCES) _ne
 	set_ptracer_any.c set_sigblock.c set_sigign.c setdomainname.c \
 	setfsgid.c setfsgid32.c setfsuid.c setfsuid32.c setgid.c \
 	setgid32.c setgroups.c setgroups32.c sethostname.c setns.c \
-	setregid.c setregid32.c setresgid.c setresgid32.c setresuid.c \
-	setresuid32.c setreuid.c setreuid32.c setrlimit.c \
-	setrlimit-Xabbrev.c setrlimit-Xraw.c setrlimit-Xverbose.c \
-	setuid.c setuid32.c shmxt.c shutdown.c sigaction.c \
-	sigaltstack.c siginfo.c signal.c signal_receive.c signalfd4.c \
-	sigpending.c sigprocmask.c sigreturn.c sigsuspend.c sleep.c \
-	so_error.c so_linger.c so_peercred.c so_peercred-Xabbrev.c \
-	so_peercred-Xraw.c so_peercred-Xverbose.c sock_filter-v.c \
-	sock_filter-v-Xabbrev.c sock_filter-v-Xraw.c \
-	sock_filter-v-Xverbose.c sockaddr_xlat-Xabbrev.c \
-	sockaddr_xlat-Xraw.c sockaddr_xlat-Xverbose.c socketcall.c \
-	sockopt-sol_netlink.c sockopt-timestamp.c splice.c \
-	$(stack_fcall_SOURCES) $(stack_fcall_attach_SOURCES) \
-	$(stack_fcall_mangled_SOURCES) stat.c stat64.c statfs.c \
-	statfs64.c status-all.c status-failed.c status-none.c \
-	status-none-f.c status-none-threads.c status-successful.c \
-	status-unfinished.c status-unfinished-threads.c statx.c swap.c \
-	sxetmask.c symlink.c symlinkat.c sync.c sync_file_range.c \
-	sync_file_range2.c sysinfo.c syslog.c syslog-success.c tee.c \
-	threads-execve.c time.c timer_create.c timer_xettime.c \
-	timerfd_xettime.c times.c times-fail.c tracer_ppid_pgid_sid.c \
-	truncate.c truncate64.c ugetrlimit.c uio.c umask.c umount.c \
-	umount2.c umoven-illptr.c umovestr.c umovestr-illptr.c \
-	umovestr2.c umovestr3.c umovestr_cached.c uname.c \
-	unblock_reset_raise.c unix-pair-send-recv.c \
+	setpgrp-exec.c setregid.c setregid32.c setresgid.c \
+	setresgid32.c setresuid.c setresuid32.c setreuid.c \
+	setreuid32.c setrlimit.c setrlimit-Xabbrev.c setrlimit-Xraw.c \
+	setrlimit-Xverbose.c setuid.c setuid32.c shmxt.c shutdown.c \
+	sigaction.c sigaltstack.c siginfo.c signal.c signal_receive.c \
+	signal_receive--pidns-translation.c signalfd4.c sigpending.c \
+	sigprocmask.c sigreturn.c sigsuspend.c sleep.c so_error.c \
+	so_linger.c so_peercred.c so_peercred--pidns-translation.c \
+	so_peercred-Xabbrev.c so_peercred-Xraw.c \
+	so_peercred-Xverbose.c sock_filter-v.c sock_filter-v-Xabbrev.c \
+	sock_filter-v-Xraw.c sock_filter-v-Xverbose.c \
+	sockaddr_xlat-Xabbrev.c sockaddr_xlat-Xraw.c \
+	sockaddr_xlat-Xverbose.c socketcall.c sockopt-sol_netlink.c \
+	sockopt-timestamp.c splice.c $(stack_fcall_SOURCES) \
+	$(stack_fcall_attach_SOURCES) $(stack_fcall_mangled_SOURCES) \
+	stat.c stat64.c statfs.c statfs64.c status-all.c \
+	status-failed.c status-failed-long.c status-failed-status.c \
+	status-none.c status-none-f.c status-none-threads.c \
+	status-successful.c status-successful-long.c \
+	status-successful-status.c status-unfinished.c \
+	status-unfinished-threads.c statx.c strace--strings-in-hex.c \
+	strace--strings-in-hex-all.c \
+	strace--strings-in-hex-non-ascii.c strace-n.c strace-x.c \
+	strace-xx.c swap.c sxetmask.c symlink.c symlinkat.c sync.c \
+	sync_file_range.c sync_file_range2.c sysinfo.c syslog.c \
+	syslog-success.c tee.c tgkill.c tgkill--pidns-translation.c \
+	threads-execve.c threads-execve--quiet-thread-execve.c \
+	threads-execve-q.c threads-execve-qq.c threads-execve-qqq.c \
+	time.c timer_create.c timer_xettime.c timerfd_xettime.c \
+	times.c times-fail.c tkill.c tkill--pidns-translation.c \
+	tracer_ppid_pgid_sid.c $(trie_test_SOURCES) truncate.c \
+	truncate64.c ugetrlimit.c uio.c umask.c umount.c umount2.c \
+	umoven-illptr.c umovestr.c umovestr-illptr.c umovestr2.c \
+	umovestr3.c umovestr_cached.c umovestr_cached_adjacent.c \
+	uname.c unblock_reset_raise.c unix-pair-send-recv.c \
 	unix-pair-sendto-recvfrom.c unlink.c unlinkat.c unshare.c \
 	userfaultfd.c ustat.c utime.c utimensat.c utimensat-Xabbrev.c \
 	utimensat-Xraw.c utimensat-Xverbose.c utimes.c vfork-f.c \
 	vhangup.c vmsplice.c wait4.c wait4-v.c waitid.c waitid-v.c \
 	waitpid.c xattr.c xattr-strings.c xet_robust_list.c \
-	xet_thread_area_x86.c xetitimer.c xetpgid.c xetpriority.c \
-	xettimeofday.c zeroargc.c
+	xet_robust_list--pidns-translation.c xet_thread_area_x86.c \
+	xetitimer.c xetpgid.c xetpgid--pidns-translation.c \
+	xetpriority.c xetpriority--pidns-translation.c xettimeofday.c \
+	zeroargc.c
 am__can_run_installinfo = \
   case $$AM_UPDATE_INFO_DIR in \
     n|no|NO) false;; \
@@ -4244,6 +5281,7 @@ am__set_TESTS_bases = \
   bases='$(TEST_LOGS)'; \
   bases=`for i in $$bases; do echo $$i; done | sed 's/\.log$$//'`; \
   bases=`echo $$bases`
+AM_TESTSUITE_SUMMARY_HEADER = ' for $(PACKAGE_STRING)'
 RECHECK_LOGS = $(TEST_LOGS)
 AM_RECURSIVE_TARGETS = check recheck
 @ENABLE_STACKTRACE_TRUE@am__EXEEXT_2 = strace-k.test strace-k-p.test \
@@ -4273,6 +5311,7 @@ DISTFILES = $(DIST_COMMON) $(DIST_SOURCE
 ACLOCAL = @ACLOCAL@
 AMTAR = @AMTAR@
 AM_DEFAULT_VERBOSITY = @AM_DEFAULT_VERBOSITY@
+AR = @AR@
 AUTOCONF = @AUTOCONF@
 AUTOHEADER = @AUTOHEADER@
 AUTOMAKE = @AUTOMAKE@
@@ -4344,7 +5383,6 @@ PACKAGE_TARNAME = @PACKAGE_TARNAME@
 PACKAGE_URL = @PACKAGE_URL@
 PACKAGE_VERSION = @PACKAGE_VERSION@
 PATH_SEPARATOR = @PATH_SEPARATOR@
-PERL = @PERL@
 RANLIB = @RANLIB@
 READELF = @READELF@
 RPM_CHANGELOGTIME = @RPM_CHANGELOGTIME@
@@ -4363,6 +5401,7 @@ abs_builddir = @abs_builddir@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CC_FOR_BUILD = @ac_ct_CC_FOR_BUILD@
 am__include = @am__include@
@@ -4453,6 +5492,7 @@ AM_CPPFLAGS = $(ARCH_MFLAGS) \
 AM_LDFLAGS = $(ARCH_MFLAGS)
 libtests_a_SOURCES = \
 	create_nl_socket.c \
+	create_tmpfile.c \
 	errno2name.c \
 	error_msg.c \
 	fill_memory.c \
@@ -4466,6 +5506,8 @@ libtests_a_SOURCES = \
 	libsocketcall.c \
 	lock_file.c \
 	overflowuid.c \
+	pidns.c \
+	pidns.h \
 	pipe_maxfd.c \
 	print_quoted_string.c \
 	print_time.c \
@@ -4486,6 +5528,7 @@ libtests_a_SOURCES = \
 	test_ucopy.h \
 	tests.h \
 	tprintf.c \
+	xmalloc_for_tests.c \
 	# end of libtests_a_SOURCES
 
 libtests_a_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
@@ -4521,13 +5564,29 @@ PURE_EXECUTABLES = \
   clone3-Xabbrev \
   clone3-Xraw \
   clone3-Xverbose \
+  close_range \
+  close_range-P \
+  close_range-y \
+  close_range-yy \
   copy_file_range \
   creat \
   delete_module \
+  dev--decode-fds-dev \
+  dev--decode-fds-path \
+  dev--decode-fds-socket \
   dev-yy \
   dup \
+  dup-P \
+  dup-y \
+  dup-yy \
   dup2 \
+  dup2-P \
+  dup2-y \
+  dup2-yy \
   dup3 \
+  dup3-P \
+  dup3-y \
+  dup3-yy \
   epoll_create \
   epoll_create1 \
   epoll_ctl \
@@ -4538,6 +5597,13 @@ PURE_EXECUTABLES = \
   execve \
   execveat \
   faccessat \
+  faccessat-P \
+  faccessat-y \
+  faccessat-yy \
+  faccessat2 \
+  faccessat2-P \
+  faccessat2-y \
+  faccessat2-yy \
   fadvise64 \
   fadvise64_64 \
   fallocate \
@@ -4586,7 +5652,9 @@ PURE_EXECUTABLES = \
   getcpu \
   getcwd \
   getdents \
+  getdents-v \
   getdents64 \
+  getdents64-v \
   getegid \
   getegid32 \
   geteuid \
@@ -4610,7 +5678,9 @@ PURE_EXECUTABLES = \
   getsockname \
   getuid \
   getuid32 \
-  getxxid \
+  getxgid \
+  getxpid \
+  getxuid \
   group_req \
   inet-cmsg \
   init_module \
@@ -4633,6 +5703,14 @@ PURE_EXECUTABLES = \
   ioctl_evdev-v-Xabbrev \
   ioctl_evdev-v-Xraw \
   ioctl_evdev-v-Xverbose \
+  ioctl_hdio \
+  ioctl_hdio-Xabbrev \
+  ioctl_hdio-Xraw \
+  ioctl_hdio-Xverbose \
+  ioctl_hdio-v \
+  ioctl_hdio-v-Xabbrev \
+  ioctl_hdio-v-Xraw \
+  ioctl_hdio-v-Xverbose \
   ioctl_inotify \
   ioctl_kvm_run \
   ioctl_kvm_run-v \
@@ -4648,8 +5726,16 @@ PURE_EXECUTABLES = \
   ioctl_sg_io_v3 \
   ioctl_sg_io_v4 \
   ioctl_sock_gifconf \
+  ioctl_tee \
   ioctl_uffdio \
   ioctl_v4l2 \
+  ioctl_v4l2-Xabbrev \
+  ioctl_v4l2-Xraw \
+  ioctl_v4l2-Xverbose \
+  ioctl_v4l2-v \
+  ioctl_v4l2-v-Xabbrev \
+  ioctl_v4l2-v-Xraw \
+  ioctl_v4l2-v-Xverbose \
   ioctl_watchdog \
   ioperm \
   iopl \
@@ -4700,6 +5786,7 @@ PURE_EXECUTABLES = \
   lstat64 \
   madvise \
   maybe_switch_current_tcp \
+  maybe_switch_current_tcp--quiet-thread-execve \
   mbind \
   mbind-Xabbrev \
   mbind-Xraw \
@@ -4747,6 +5834,10 @@ PURE_EXECUTABLES = \
   msg_name \
   munlockall \
   nanosleep \
+  net--decode-fds-dev-netlink \
+  net--decode-fds-none-netlink \
+  net--decode-fds-path-netlink \
+  net--decode-fds-socket-netlink \
   net-icmp_filter \
   net-packet_mreq \
   net-packet_mreq-Xabbrev \
@@ -4829,6 +5920,16 @@ PURE_EXECUTABLES = \
   open_tree \
   open_tree-P \
   openat \
+  openat2 \
+  openat2-Xabbrev \
+  openat2-Xraw \
+  openat2-Xverbose \
+  openat2-v \
+  openat2-v-y \
+  openat2-v-y-Xabbrev \
+  openat2-v-y-Xraw \
+  openat2-v-y-Xverbose \
+  openat2-y \
   osf_utimes \
   pause \
   perf_event_open \
@@ -4836,9 +5937,16 @@ PURE_EXECUTABLES = \
   personality-Xabbrev \
   personality-Xraw \
   personality-Xverbose \
+  pidfd_getfd \
+  pidfd_getfd-y \
+  pidfd_getfd-yy \
   pidfd_open \
+  pidfd_open--decode-fd-path \
+  pidfd_open--decode-fd-pidfd \
+  pidfd_open--decode-fd-socket \
   pidfd_open-P \
   pidfd_open-y \
+  pidfd_open-yy \
   pidfd_send_signal \
   pipe \
   pipe2 \
@@ -4846,9 +5954,7 @@ PURE_EXECUTABLES = \
   pkey_free \
   pkey_mprotect \
   poll \
-  poll-P \
   ppoll \
-  ppoll-P \
   prctl-arg2-intptr \
   prctl-dumpable \
   prctl-name \
@@ -4997,11 +6103,21 @@ PURE_EXECUTABLES = \
   statfs64 \
   status-all \
   status-failed \
+  status-failed-long \
+  status-failed-status \
   status-none \
   status-none-f \
   status-successful \
+  status-successful-long \
+  status-successful-status \
   status-unfinished \
   statx \
+  strace--strings-in-hex \
+  strace--strings-in-hex-all \
+  strace--strings-in-hex-non-ascii \
+  strace-n \
+  strace-x \
+  strace-xx \
   swap \
   sxetmask \
   symlink \
@@ -5012,12 +6128,14 @@ PURE_EXECUTABLES = \
   sysinfo \
   syslog \
   tee \
+  tgkill \
   time \
   timer_create \
   timer_xettime \
   timerfd_xettime \
   times \
   times-fail \
+  tkill \
   truncate \
   truncate64 \
   ugetrlimit \
@@ -5031,6 +6149,7 @@ PURE_EXECUTABLES = \
   umovestr2 \
   umovestr3 \
   umovestr_cached \
+  umovestr_cached_adjacent \
   uname \
   unlink \
   unlinkat \
@@ -5069,6 +6188,7 @@ localtime_LDADD = $(clock_LIBS) $(LDADD)
 looping_threads_LDADD = -lpthread $(LDADD)
 lstat64_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 maybe_switch_current_tcp_LDADD = -lpthread $(LDADD)
+maybe_switch_current_tcp__quiet_thread_execve_LDADD = -lpthread $(LDADD)
 mmap64_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 mmap64_Xabbrev_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 mmap64_Xraw_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
@@ -5085,6 +6205,10 @@ statfs_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE
 status_none_threads_LDADD = -lpthread $(LDADD)
 status_unfinished_threads_LDADD = -lpthread $(LDADD)
 threads_execve_LDADD = -lpthread $(clock_LIBS) $(LDADD)
+threads_execve__quiet_thread_execve_LDADD = -lpthread $(clock_LIBS) $(LDADD)
+threads_execve_q_LDADD = -lpthread $(clock_LIBS) $(LDADD)
+threads_execve_qq_LDADD = -lpthread $(clock_LIBS) $(LDADD)
+threads_execve_qqq_LDADD = -lpthread $(clock_LIBS) $(LDADD)
 times_LDADD = $(clock_LIBS) $(LDADD)
 truncate64_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 uio_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
@@ -5098,6 +6222,10 @@ stack_fcall_mangled_SOURCES = stack-fcal
 	stack-fcall-mangled-0.c stack-fcall-mangled-1.c \
 	stack-fcall-mangled-2.c stack-fcall-mangled-3.c
 
+trie_test_SOURCES = trie_test.c trie_for_tests.c
+trie_test_CPPFLAGS = $(AM_CPPFLAGS) $(CODE_COVERAGE_CPPFLAGS)
+trie_test_CFLAGS = $(AM_CFLAGS) $(CODE_COVERAGE_CFLAGS)
+trie_test_LDADD = $(LDADD) $(CODE_COVERAGE_LIBS)
 
 # Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in; do not edit.
 GEN_TESTS = _newselect.gen.test _newselect-P.gen.test accept.gen.test \
@@ -5114,69 +6242,111 @@ GEN_TESTS = _newselect.gen.test _newsele
 	clone3.gen.test clone3-Xabbrev.gen.test clone3-Xraw.gen.test \
 	clone3-Xverbose.gen.test clone3-success-Xabbrev.gen.test \
 	clone3-success-Xraw.gen.test clone3-success-Xverbose.gen.test \
-	copy_file_range.gen.test creat.gen.test delete_module.gen.test \
-	dev-yy.gen.test dup.gen.test dup2.gen.test dup3.gen.test \
+	clone_parent.gen.test clone_parent--quiet-exit.gen.test \
+	clone_parent-q.gen.test clone_parent-qq.gen.test \
+	clone_ptrace--quiet-attach.gen.test \
+	clone_ptrace--quiet-exit.gen.test clone_ptrace-q.gen.test \
+	clone_ptrace-qq.gen.test close_range.gen.test \
+	close_range-P.gen.test close_range-y.gen.test \
+	close_range-yy.gen.test copy_file_range.gen.test \
+	creat.gen.test delete_module.gen.test \
+	dev--decode-fds-dev.gen.test dev--decode-fds-path.gen.test \
+	dev--decode-fds-socket.gen.test dev-yy.gen.test dup.gen.test \
+	dup-P.gen.test dup-y.gen.test dup-yy.gen.test dup2.gen.test \
+	dup2-P.gen.test dup2-y.gen.test dup2-yy.gen.test dup3.gen.test \
+	dup3-P.gen.test dup3-y.gen.test dup3-yy.gen.test \
 	epoll_create.gen.test epoll_create1.gen.test \
 	epoll_ctl.gen.test epoll_pwait.gen.test epoll_wait.gen.test \
 	erestartsys.gen.test execveat.gen.test execveat-v.gen.test \
-	faccessat.gen.test fadvise64_64.gen.test fallocate.gen.test \
+	faccessat-P.gen.test faccessat-y.gen.test \
+	faccessat-yy.gen.test faccessat2-P.gen.test \
+	faccessat2-y.gen.test faccessat2-yy.gen.test \
+	fadvise64_64.gen.test fallocate.gen.test \
 	fanotify_init.gen.test fanotify_mark.gen.test \
 	fanotify_mark-Xabbrev.gen.test fanotify_mark-Xraw.gen.test \
 	fanotify_mark-Xverbose.gen.test fchdir.gen.test \
 	fchmod.gen.test fchmodat.gen.test fchown.gen.test \
 	fchown32.gen.test fchownat.gen.test fcntl.gen.test \
-	fcntl64.gen.test fdatasync.gen.test file_handle.gen.test \
-	file_ioctl.gen.test filter_seccomp.gen.test \
-	filter_seccomp-flag.gen.test finit_module.gen.test \
-	flock.gen.test fork-f.gen.test fsconfig.gen.test \
-	fsconfig-P.gen.test fsmount.gen.test fsopen.gen.test \
-	fspick.gen.test fspick-P.gen.test fstat.gen.test \
-	fstat-Xabbrev.gen.test fstat-Xraw.gen.test \
+	fcntl--pidns-translation.gen.test fcntl64.gen.test \
+	fcntl64--pidns-translation.gen.test fdatasync.gen.test \
+	file_handle.gen.test file_ioctl.gen.test \
+	filter_seccomp.gen.test filter_seccomp-flag.gen.test \
+	finit_module.gen.test flock.gen.test fork-f.gen.test \
+	fsconfig.gen.test fsconfig-P.gen.test fsmount.gen.test \
+	fsopen.gen.test fspick.gen.test fspick-P.gen.test \
+	fstat.gen.test fstat-Xabbrev.gen.test fstat-Xraw.gen.test \
 	fstat-Xverbose.gen.test fstat64.gen.test \
 	fstat64-Xabbrev.gen.test fstat64-Xraw.gen.test \
 	fstat64-Xverbose.gen.test fstatat64.gen.test fstatfs.gen.test \
 	fstatfs64.gen.test fsync.gen.test fsync-y.gen.test \
 	ftruncate.gen.test ftruncate64.gen.test futimesat.gen.test \
 	get_mempolicy.gen.test getcpu.gen.test getcwd.gen.test \
-	getdents.gen.test getdents64.gen.test getegid.gen.test \
-	getegid-creds.gen.test getegid32.gen.test \
-	getegid32-creds.gen.test geteuid.gen.test \
+	getdents.gen.test getdents-v.gen.test getdents64.gen.test \
+	getdents64-v.gen.test getegid.gen.test getegid-creds.gen.test \
+	getegid32.gen.test getegid32-creds.gen.test geteuid.gen.test \
 	geteuid-creds.gen.test geteuid32.gen.test \
 	geteuid32-creds.gen.test getgid.gen.test getgid-creds.gen.test \
 	getgid32.gen.test getgid32-creds.gen.test getgroups.gen.test \
 	getgroups32.gen.test getpeername.gen.test getpgrp.gen.test \
-	getpid.gen.test getppid.gen.test getrandom.gen.test \
-	getresgid.gen.test getresgid32.gen.test getresuid.gen.test \
-	getresuid32.gen.test getrlimit.gen.test getrusage.gen.test \
-	getsid.gen.test getsockname.gen.test gettid.gen.test \
-	getuid-creds.gen.test getuid32.gen.test \
-	getuid32-creds.gen.test getxxid.gen.test group_req.gen.test \
-	inet-cmsg.gen.test init_module.gen.test inotify.gen.test \
-	inotify_init.gen.test inotify_init1.gen.test \
-	inotify_init1-y.gen.test io_uring_enter.gen.test \
-	io_uring_register.gen.test io_uring_setup.gen.test \
-	ioctl_block.gen.test ioctl_dm.gen.test ioctl_dm-v.gen.test \
-	ioctl_evdev.gen.test ioctl_evdev-Xabbrev.gen.test \
-	ioctl_evdev-Xraw.gen.test ioctl_evdev-Xverbose.gen.test \
-	ioctl_evdev-v.gen.test ioctl_evdev-v-Xabbrev.gen.test \
-	ioctl_evdev-v-Xraw.gen.test ioctl_evdev-v-Xverbose.gen.test \
+	getpgrp--pidns-translation.gen.test getpid.gen.test \
+	getpid--pidns-translation.gen.test getppid.gen.test \
+	getrandom.gen.test getresgid.gen.test getresgid32.gen.test \
+	getresuid.gen.test getresuid32.gen.test getrlimit.gen.test \
+	getrusage.gen.test getsid.gen.test \
+	getsid--pidns-translation.gen.test getsockname.gen.test \
+	gettid.gen.test getuid-creds.gen.test getuid32.gen.test \
+	getuid32-creds.gen.test getxgid.gen.test getxpid.gen.test \
+	getxuid.gen.test group_req.gen.test inet-cmsg.gen.test \
+	init_module.gen.test inotify.gen.test inotify_init.gen.test \
+	inotify_init1.gen.test inotify_init1-y.gen.test \
+	io_uring_enter.gen.test io_uring_register.gen.test \
+	io_uring_setup.gen.test ioctl_block.gen.test ioctl_dm.gen.test \
+	ioctl_dm-v.gen.test ioctl_evdev.gen.test \
+	ioctl_evdev-Xabbrev.gen.test ioctl_evdev-Xraw.gen.test \
+	ioctl_evdev-Xverbose.gen.test ioctl_evdev-v.gen.test \
+	ioctl_evdev-v-Xabbrev.gen.test ioctl_evdev-v-Xraw.gen.test \
+	ioctl_evdev-v-Xverbose.gen.test \
 	ioctl_evdev-success-Xabbrev.gen.test \
 	ioctl_evdev-success-Xraw.gen.test \
 	ioctl_evdev-success-Xverbose.gen.test \
 	ioctl_evdev-success-v.gen.test \
 	ioctl_evdev-success-v-Xabbrev.gen.test \
 	ioctl_evdev-success-v-Xraw.gen.test \
-	ioctl_evdev-success-v-Xverbose.gen.test ioctl_inotify.gen.test \
+	ioctl_evdev-success-v-Xverbose.gen.test ioctl_hdio.gen.test \
+	ioctl_hdio-Xabbrev.gen.test ioctl_hdio-Xraw.gen.test \
+	ioctl_hdio-Xverbose.gen.test ioctl_hdio-v.gen.test \
+	ioctl_hdio-v-Xabbrev.gen.test ioctl_hdio-v-Xraw.gen.test \
+	ioctl_hdio-v-Xverbose.gen.test ioctl_hdio-success.gen.test \
+	ioctl_hdio-success-Xabbrev.gen.test \
+	ioctl_hdio-success-Xraw.gen.test \
+	ioctl_hdio-success-Xverbose.gen.test \
+	ioctl_hdio-success-v.gen.test \
+	ioctl_hdio-success-v-Xabbrev.gen.test \
+	ioctl_hdio-success-v-Xraw.gen.test \
+	ioctl_hdio-success-v-Xverbose.gen.test ioctl_inotify.gen.test \
 	ioctl_kvm_run.gen.test ioctl_kvm_run-v.gen.test \
 	ioctl_kvm_run_auxstr_vcpu.gen.test ioctl_loop.gen.test \
 	ioctl_loop-nv.gen.test ioctl_loop-v.gen.test \
 	ioctl_mtd.gen.test ioctl_nbd.gen.test ioctl_nsfs.gen.test \
-	ioctl_perf.gen.test ioctl_ptp.gen.test ioctl_random.gen.test \
-	ioctl_rtc.gen.test ioctl_rtc-v.gen.test ioctl_scsi.gen.test \
+	ioctl_perf.gen.test ioctl_perf-success.gen.test \
+	ioctl_ptp.gen.test ioctl_random.gen.test ioctl_rtc.gen.test \
+	ioctl_rtc-v.gen.test ioctl_scsi.gen.test \
 	ioctl_sg_io_v3.gen.test ioctl_sg_io_v4.gen.test \
-	ioctl_sock_gifconf.gen.test ioctl_uffdio.gen.test \
-	ioctl_v4l2.gen.test ioctl_watchdog.gen.test ioperm.gen.test \
-	iopl.gen.test ioprio.gen.test ioprio-Xabbrev.gen.test \
+	ioctl_sock_gifconf.gen.test ioctl_tee.gen.test \
+	ioctl_uffdio.gen.test ioctl_v4l2.gen.test \
+	ioctl_v4l2-Xabbrev.gen.test ioctl_v4l2-Xraw.gen.test \
+	ioctl_v4l2-Xverbose.gen.test ioctl_v4l2-v.gen.test \
+	ioctl_v4l2-v-Xabbrev.gen.test ioctl_v4l2-v-Xraw.gen.test \
+	ioctl_v4l2-v-Xverbose.gen.test ioctl_v4l2-success.gen.test \
+	ioctl_v4l2-success-Xabbrev.gen.test \
+	ioctl_v4l2-success-Xraw.gen.test \
+	ioctl_v4l2-success-Xverbose.gen.test \
+	ioctl_v4l2-success-v.gen.test \
+	ioctl_v4l2-success-v-Xabbrev.gen.test \
+	ioctl_v4l2-success-v-Xraw.gen.test \
+	ioctl_v4l2-success-v-Xverbose.gen.test ioctl_watchdog.gen.test \
+	ioperm.gen.test iopl.gen.test ioprio.gen.test \
+	ioprio--pidns-translation.gen.test ioprio-Xabbrev.gen.test \
 	ioprio-Xraw.gen.test ioprio-Xverbose.gen.test ip_mreq.gen.test \
 	ipc.gen.test ipc_msg.gen.test ipc_msg-Xabbrev.gen.test \
 	ipc_msg-Xraw.gen.test ipc_msg-Xverbose.gen.test \
@@ -5186,23 +6356,27 @@ GEN_TESTS = _newselect.gen.test _newsele
 	ipc_sem-Xverbose.gen.test ipc_shm.gen.test \
 	ipc_shm-Xabbrev.gen.test ipc_shm-Xraw.gen.test \
 	ipc_shm-Xverbose.gen.test kcmp.gen.test kcmp-y.gen.test \
-	kern_features.gen.test kernel_version.gen.test \
-	kernel_version-Xabbrev.gen.test kernel_version-Xraw.gen.test \
-	kernel_version-Xverbose.gen.test kexec_file_load.gen.test \
-	kexec_load.gen.test keyctl.gen.test keyctl-Xabbrev.gen.test \
-	keyctl-Xraw.gen.test keyctl-Xverbose.gen.test kill.gen.test \
-	ksysent.gen.test lchown.gen.test lchown32.gen.test \
-	link.gen.test linkat.gen.test lookup_dcookie.gen.test \
-	lstat.gen.test lstat64.gen.test madvise.gen.test \
-	maybe_switch_current_tcp.gen.test mbind.gen.test \
-	mbind-Xabbrev.gen.test mbind-Xraw.gen.test \
+	kcmp-y--pidns-translation.gen.test kern_features.gen.test \
+	kernel_version.gen.test kernel_version-Xabbrev.gen.test \
+	kernel_version-Xraw.gen.test kernel_version-Xverbose.gen.test \
+	kexec_file_load.gen.test kexec_load.gen.test keyctl.gen.test \
+	keyctl-Xabbrev.gen.test keyctl-Xraw.gen.test \
+	keyctl-Xverbose.gen.test kill.gen.test \
+	kill--pidns-translation.gen.test ksysent.gen.test \
+	lchown.gen.test lchown32.gen.test link.gen.test \
+	linkat.gen.test lookup_dcookie.gen.test lstat.gen.test \
+	lstat64.gen.test madvise.gen.test \
+	maybe_switch_current_tcp.gen.test \
+	maybe_switch_current_tcp--quiet-thread-execve.gen.test \
+	mbind.gen.test mbind-Xabbrev.gen.test mbind-Xraw.gen.test \
 	mbind-Xverbose.gen.test membarrier.gen.test \
 	memfd_create.gen.test memfd_create-Xabbrev.gen.test \
 	memfd_create-Xraw.gen.test memfd_create-Xverbose.gen.test \
-	migrate_pages.gen.test mincore.gen.test mkdir.gen.test \
-	mkdirat.gen.test mknod.gen.test mknodat.gen.test \
-	mlock.gen.test mlock2.gen.test mlockall.gen.test \
-	mmap-Xabbrev.gen.test mmap-Xraw.gen.test \
+	migrate_pages.gen.test \
+	migrate_pages--pidns-translation.gen.test mincore.gen.test \
+	mkdir.gen.test mkdirat.gen.test mknod.gen.test \
+	mknodat.gen.test mlock.gen.test mlock2.gen.test \
+	mlockall.gen.test mmap-Xabbrev.gen.test mmap-Xraw.gen.test \
 	mmap-Xverbose.gen.test mmap64.gen.test mmap64-Xabbrev.gen.test \
 	mmap64-Xraw.gen.test mmap64-Xverbose.gen.test mmsg.gen.test \
 	mmsg-silent.gen.test mmsg_name.gen.test mmsg_name-v.gen.test \
@@ -5210,13 +6384,19 @@ GEN_TESTS = _newselect.gen.test _newsele
 	mount-Xraw.gen.test mount-Xverbose.gen.test \
 	move_mount.gen.test move_mount-P.gen.test move_pages.gen.test \
 	move_pages-Xabbrev.gen.test move_pages-Xraw.gen.test \
-	move_pages-Xverbose.gen.test mq.gen.test mq_sendrecv.gen.test \
-	mq_sendrecv-read.gen.test mq_sendrecv-write.gen.test \
-	msg_control.gen.test msg_control-v.gen.test msg_name.gen.test \
-	munlockall.gen.test nanosleep.gen.test \
+	move_pages-Xverbose.gen.test \
+	move_pages--pidns-translation.gen.test mq.gen.test \
+	mq_sendrecv.gen.test mq_sendrecv-read.gen.test \
+	mq_sendrecv-write.gen.test msg_control.gen.test \
+	msg_control-v.gen.test msg_name.gen.test munlockall.gen.test \
+	nanosleep.gen.test net--decode-fds-dev-netlink.gen.test \
+	net--decode-fds-none-netlink.gen.test \
+	net--decode-fds-path-netlink.gen.test \
+	net--decode-fds-socket-netlink.gen.test \
 	net-icmp_filter.gen.test net-packet_mreq.gen.test \
 	net-packet_mreq-Xabbrev.gen.test net-packet_mreq-Xraw.gen.test \
 	net-packet_mreq-Xverbose.gen.test net-sockaddr.gen.test \
+	net-sockaddr--pidns-translation.gen.test \
 	net-tpacket_req.gen.test net-tpacket_stats.gen.test \
 	net-yy-inet6.gen.test netlink_audit.gen.test \
 	netlink_crypto.gen.test netlink_generic.gen.test \
@@ -5235,7 +6415,8 @@ GEN_TESTS = _newselect.gen.test _newsele
 	nlattr_ifaddrmsg.gen.test nlattr_ifinfomsg.gen.test \
 	nlattr_ifla_af_spec.gen.test nlattr_ifla_brport.gen.test \
 	nlattr_ifla_linkinfo.gen.test nlattr_ifla_port.gen.test \
-	nlattr_ifla_xdp.gen.test nlattr_inet_diag_msg.gen.test \
+	nlattr_ifla_xdp.gen.test nlattr_ifla_xdp-y.gen.test \
+	nlattr_inet_diag_msg.gen.test \
 	nlattr_inet_diag_req_compat.gen.test \
 	nlattr_inet_diag_req_v2.gen.test \
 	nlattr_mdba_mdb_entry.gen.test \
@@ -5253,17 +6434,28 @@ GEN_TESTS = _newselect.gen.test _newsele
 	oldselect.gen.test oldselect-P.gen.test \
 	oldselect-efault.gen.test oldselect-efault-P.gen.test \
 	oldstat.gen.test open.gen.test open_tree.gen.test \
-	open_tree-P.gen.test openat.gen.test \
-	orphaned_process_group.gen.test osf_utimes.gen.test \
-	pause.gen.test perf_event_open.gen.test \
+	open_tree-P.gen.test openat.gen.test openat2.gen.test \
+	openat2-Xabbrev.gen.test openat2-Xraw.gen.test \
+	openat2-Xverbose.gen.test openat2-v.gen.test \
+	openat2-v-y.gen.test openat2-v-y-Xabbrev.gen.test \
+	openat2-v-y-Xraw.gen.test openat2-v-y-Xverbose.gen.test \
+	openat2-y.gen.test orphaned_process_group.gen.test \
+	osf_utimes.gen.test pause.gen.test perf_event_open.gen.test \
 	perf_event_open_nonverbose.gen.test \
 	perf_event_open_unabbrev.gen.test personality-Xabbrev.gen.test \
 	personality-Xraw.gen.test personality-Xverbose.gen.test \
-	pidfd_open.gen.test pidfd_open-P.gen.test \
-	pidfd_open-y.gen.test pidfd_send_signal.gen.test \
-	pipe2.gen.test pkey_alloc.gen.test pkey_free.gen.test \
-	pkey_mprotect.gen.test ppoll.gen.test ppoll-P.gen.test \
-	ppoll-v.gen.test pread64-pwrite64.gen.test preadv.gen.test \
+	pidfd_getfd.gen.test pidfd_getfd-y.gen.test \
+	pidfd_getfd-yy.gen.test pidfd_open.gen.test \
+	pidfd_open--decode-fd-path.gen.test \
+	pidfd_open--decode-fd-pidfd.gen.test \
+	pidfd_open--decode-fd-socket.gen.test pidfd_open-P.gen.test \
+	pidfd_open-y.gen.test pidfd_open-yy.gen.test \
+	pidfd_open--pidns-translation.gen.test \
+	pidfd_send_signal.gen.test \
+	pidfd_send_signal--pidns-translation.gen.test pipe2.gen.test \
+	pkey_alloc.gen.test pkey_free.gen.test pkey_mprotect.gen.test \
+	ppoll.gen.test ppoll-P.gen.test ppoll-v.gen.test \
+	pread64-pwrite64.gen.test preadv.gen.test \
 	preadv-pwritev.gen.test preadv2-pwritev2.gen.test \
 	printpath-umovestr.gen.test \
 	printpath-umovestr-peekdata.gen.test \
@@ -5272,7 +6464,11 @@ GEN_TESTS = _newselect.gen.test _newsele
 	printsignal-Xverbose.gen.test printstr.gen.test \
 	printstrn-umoven.gen.test printstrn-umoven-peekdata.gen.test \
 	printstrn-umoven-undumpable.gen.test prlimit64.gen.test \
-	process_vm_readv.gen.test process_vm_writev.gen.test \
+	prlimit64--pidns-translation.gen.test \
+	process_vm_readv.gen.test \
+	process_vm_readv--pidns-translation.gen.test \
+	process_vm_writev.gen.test \
+	process_vm_writev--pidns-translation.gen.test \
 	pselect6.gen.test ptrace.gen.test ptrace_syscall_info.gen.test \
 	pwritev.gen.test quotactl.gen.test quotactl-Xabbrev.gen.test \
 	quotactl-Xraw.gen.test quotactl-Xverbose.gen.test \
@@ -5288,15 +6484,23 @@ GEN_TESTS = _newselect.gen.test _newsele
 	renameat.gen.test renameat2.gen.test request_key.gen.test \
 	riscv_flush_icache.gen.test rmdir.gen.test \
 	rt_sigpending.gen.test rt_sigprocmask.gen.test \
-	rt_sigqueueinfo.gen.test rt_sigreturn.gen.test \
-	rt_sigsuspend.gen.test rt_sigtimedwait.gen.test \
-	rt_tgsigqueueinfo.gen.test s390_guarded_storage.gen.test \
-	s390_guarded_storage-v.gen.test \
+	rt_sigqueueinfo.gen.test \
+	rt_sigqueueinfo--pidns-translation.gen.test \
+	rt_sigreturn.gen.test rt_sigsuspend.gen.test \
+	rt_sigtimedwait.gen.test rt_tgsigqueueinfo.gen.test \
+	rt_tgsigqueueinfo--pidns-translation.gen.test \
+	s390_guarded_storage.gen.test s390_guarded_storage-v.gen.test \
 	s390_pci_mmio_read_write.gen.test s390_runtime_instr.gen.test \
 	s390_sthyi.gen.test s390_sthyi-v.gen.test sched.gen.test \
 	sched_get_priority_mxx.gen.test sched_rr_get_interval.gen.test \
-	sched_xetaffinity.gen.test sched_xetattr.gen.test \
-	sched_xetparam.gen.test sched_xetscheduler.gen.test \
+	sched_xetaffinity.gen.test \
+	sched_xetaffinity--pidns-translation.gen.test \
+	sched_xetattr.gen.test \
+	sched_xetattr--pidns-translation.gen.test \
+	sched_xetparam.gen.test \
+	sched_xetparam--pidns-translation.gen.test \
+	sched_xetscheduler.gen.test \
+	sched_xetscheduler--pidns-translation.gen.test \
 	sched_yield.gen.test seccomp-filter.gen.test \
 	seccomp-filter-v.gen.test seccomp_get_action_avail.gen.test \
 	select.gen.test select-P.gen.test semop.gen.test \
@@ -5314,26 +6518,70 @@ GEN_TESTS = _newselect.gen.test _newsele
 	setrlimit-Xraw.gen.test setrlimit-Xverbose.gen.test \
 	setuid.gen.test setuid32.gen.test shmxt.gen.test \
 	shutdown.gen.test sigaction.gen.test siginfo.gen.test \
-	signal.gen.test signal_receive.gen.test signalfd4.gen.test \
+	signal.gen.test signal_receive.gen.test \
+	signal_receive--pidns-translation.gen.test signalfd4.gen.test \
 	sigpending.gen.test sigprocmask.gen.test sigreturn.gen.test \
 	sigsuspend.gen.test so_error.gen.test so_linger.gen.test \
 	so_peercred.gen.test so_peercred-Xabbrev.gen.test \
 	so_peercred-Xraw.gen.test so_peercred-Xverbose.gen.test \
-	sock_filter-v.gen.test sock_filter-v-Xabbrev.gen.test \
-	sock_filter-v-Xraw.gen.test sock_filter-v-Xverbose.gen.test \
-	sockaddr_xlat-Xabbrev.gen.test sockaddr_xlat-Xraw.gen.test \
-	sockaddr_xlat-Xverbose.gen.test socketcall.gen.test \
-	sockopt-sol_netlink.gen.test sockopt-timestamp.gen.test \
-	splice.gen.test stat.gen.test stat64.gen.test statfs.gen.test \
-	statfs64.gen.test status-all.gen.test status-failed.gen.test \
+	so_peercred--pidns-translation.gen.test sock_filter-v.gen.test \
+	sock_filter-v-Xabbrev.gen.test sock_filter-v-Xraw.gen.test \
+	sock_filter-v-Xverbose.gen.test sockaddr_xlat-Xabbrev.gen.test \
+	sockaddr_xlat-Xraw.gen.test sockaddr_xlat-Xverbose.gen.test \
+	socketcall.gen.test sockopt-sol_netlink.gen.test \
+	sockopt-timestamp.gen.test splice.gen.test stat.gen.test \
+	stat64.gen.test statfs.gen.test statfs64.gen.test \
+	status-all.gen.test status-failed.gen.test \
+	status-failed-long.gen.test status-failed-status.gen.test \
 	status-none.gen.test status-successful.gen.test \
-	status-unfinished.gen.test statx.gen.test swap.gen.test \
+	status-successful-long.gen.test \
+	status-successful-status.gen.test status-unfinished.gen.test \
+	statx.gen.test strace--absolute-timestamps.gen.test \
+	strace--absolute-timestamps-format-time.gen.test \
+	strace--absolute-timestamps-format-time-precision-s.gen.test \
+	strace--absolute-timestamps-format-time-precision-ms.gen.test \
+	strace--absolute-timestamps-format-time-precision-us.gen.test \
+	strace--absolute-timestamps-format-time-precision-ns.gen.test \
+	strace--absolute-timestamps-format-unix-precision-s.gen.test \
+	strace--absolute-timestamps-format-unix-precision-ms.gen.test \
+	strace--absolute-timestamps-format-unix-precision-us.gen.test \
+	strace--absolute-timestamps-format-unix-precision-ns.gen.test \
+	strace--follow-forks-output-separately.gen.test \
+	strace--relative-timestamps.gen.test \
+	strace--relative-timestamps-s.gen.test \
+	strace--relative-timestamps-ms.gen.test \
+	strace--relative-timestamps-us.gen.test \
+	strace--relative-timestamps-ns.gen.test \
+	strace--syscall-times.gen.test \
+	strace--syscall-times-s.gen.test \
+	strace--syscall-times-ms.gen.test \
+	strace--syscall-times-us.gen.test \
+	strace--syscall-times-ns.gen.test \
+	strace--strings-in-hex.gen.test \
+	strace--strings-in-hex-all.gen.test \
+	strace--strings-in-hex-non-ascii.gen.test \
+	strace--timestamps.gen.test strace--timestamps-time.gen.test \
+	strace--timestamps-time-s.gen.test \
+	strace--timestamps-time-ms.gen.test \
+	strace--timestamps-time-us.gen.test \
+	strace--timestamps-time-ns.gen.test \
+	strace--timestamps-unix-s.gen.test \
+	strace--timestamps-unix-ms.gen.test \
+	strace--timestamps-unix-us.gen.test \
+	strace--timestamps-unix-ns.gen.test strace-n.gen.test \
+	strace-x.gen.test strace-xx.gen.test swap.gen.test \
 	sxetmask.gen.test symlink.gen.test symlinkat.gen.test \
 	sync.gen.test sync_file_range.gen.test \
 	sync_file_range2.gen.test sysinfo.gen.test syslog.gen.test \
-	tee.gen.test time.gen.test timer_create.gen.test \
-	timer_xettime.gen.test timerfd_xettime.gen.test times.gen.test \
-	times-fail.gen.test trace_creds.gen.test trace_fstat.gen.test \
+	tee.gen.test tgkill.gen.test \
+	tgkill--pidns-translation.gen.test \
+	threads-execve--quiet-thread-execve.gen.test \
+	threads-execve-q.gen.test threads-execve-qq.gen.test \
+	threads-execve-qqq.gen.test time.gen.test \
+	timer_create.gen.test timer_xettime.gen.test \
+	timerfd_xettime.gen.test times.gen.test times-fail.gen.test \
+	tkill.gen.test tkill--pidns-translation.gen.test \
+	trace_clock.gen.test trace_creds.gen.test trace_fstat.gen.test \
 	trace_fstatfs.gen.test trace_lstat.gen.test \
 	trace_personality_32.gen.test trace_personality_64.gen.test \
 	trace_personality_regex_32.gen.test \
@@ -5342,22 +6590,27 @@ GEN_TESTS = _newselect.gen.test _newsele
 	trace_personality_x32.gen.test trace_question.gen.test \
 	trace_stat.gen.test trace_stat_like.gen.test \
 	trace_statfs.gen.test trace_statfs_like.gen.test \
-	truncate.gen.test truncate64.gen.test ugetrlimit.gen.test \
-	umask.gen.test umoven-illptr.gen.test umovestr-illptr.gen.test \
-	umovestr3.gen.test unlink.gen.test unlinkat.gen.test \
-	unshare.gen.test userfaultfd.gen.test ustat.gen.test \
-	utime.gen.test utimensat.gen.test utimensat-Xabbrev.gen.test \
-	utimensat-Xraw.gen.test utimensat-Xverbose.gen.test \
-	utimes.gen.test vfork-f.gen.test vhangup.gen.test \
-	vmsplice.gen.test wait4.gen.test wait4-v.gen.test \
-	waitid.gen.test waitid-v.gen.test waitpid.gen.test \
-	xattr.gen.test xattr-strings.gen.test xet_robust_list.gen.test \
-	xetitimer.gen.test xetpgid.gen.test xetpriority.gen.test \
+	trie_test.gen.test truncate.gen.test truncate64.gen.test \
+	ugetrlimit.gen.test umask.gen.test umoven-illptr.gen.test \
+	umovestr-illptr.gen.test umovestr3.gen.test \
+	umovestr_cached_adjacent.gen.test unlink.gen.test \
+	unlinkat.gen.test unshare.gen.test userfaultfd.gen.test \
+	ustat.gen.test utime.gen.test utimensat.gen.test \
+	utimensat-Xabbrev.gen.test utimensat-Xraw.gen.test \
+	utimensat-Xverbose.gen.test utimes.gen.test vfork-f.gen.test \
+	vhangup.gen.test vmsplice.gen.test wait4.gen.test \
+	wait4-v.gen.test waitid.gen.test waitid-v.gen.test \
+	waitpid.gen.test xattr.gen.test xattr-strings.gen.test \
+	xet_robust_list.gen.test \
+	xet_robust_list--pidns-translation.gen.test xetitimer.gen.test \
+	xetpgid.gen.test xetpgid--pidns-translation.gen.test \
+	xetpriority.gen.test xetpriority--pidns-translation.gen.test \
 	xettimeofday.gen.test
 @ENABLE_STACKTRACE_FALSE@STACKTRACE_TESTS = 
 @ENABLE_STACKTRACE_TRUE@STACKTRACE_TESTS = strace-k.test \
 @ENABLE_STACKTRACE_TRUE@	strace-k-p.test $(am__append_1)
 DECODER_TESTS = \
+	bpf-success-long-y.test \
 	bpf-success-v.test \
 	bpf-success.test \
 	brk.test \
@@ -5376,13 +6629,15 @@ DECODER_TESTS = \
 	execve-v.test \
 	execve.test \
 	fadvise64.test \
+	faccessat.test \
+	faccessat2.test \
 	futex.test \
 	getuid.test \
 	int_0x80.test \
 	inotify_init-y.test \
 	ioctl.test \
+	ioctl_block--pidns-translation.test \
 	ioctl_evdev-success.test \
-	ioctl_perf-success.test \
 	ipc_msgbuf.test \
 	kern_features-fault.test \
 	llseek.test \
@@ -5440,7 +6695,6 @@ MISC_TESTS = \
 	attach-f-p.test \
 	attach-p-cmd.test \
 	bexecve.test \
-	clone_parent.test \
 	clone_ptrace.test \
 	count-f.test \
 	count.test \
@@ -5454,15 +6708,19 @@ MISC_TESTS = \
 	filtering_fd-syntax.test \
 	filtering_syscall-syntax.test \
 	first_exec_failure.test \
+	fork--pidns-translation.test \
 	get_regs.test \
+	gettid--pidns-translation.test \
 	inject-nf.test \
 	interactive_block.test \
 	kill_child.test \
 	localtime.test \
 	looping_threads.test \
+	netlink_audit--pidns-translation.test \
 	opipe.test \
 	options-syntax.test \
 	pc.test \
+	pidns-cache.test \
 	printpath-umovestr-legacy.test \
 	printstrn-umoven-legacy.test \
 	qual_fault-syntax.test \
@@ -5490,6 +6748,8 @@ MISC_TESTS = \
 	strace-DD.test \
 	strace-DDD.test \
 	strace-E.test \
+	strace-E-override.test \
+	strace-E-unset.test \
 	strace-S.test \
 	strace-T.test \
 	strace-V.test \
@@ -5533,6 +6793,7 @@ EXTRA_DIST = \
 	filter_seccomp.in \
 	filter_seccomp.sh \
 	filter-unavailable.expected \
+	fork--pidns-translation.awk \
 	fstatat.c \
 	fstatx.c \
 	gen_pure_executables.sh \
@@ -5541,6 +6802,7 @@ EXTRA_DIST = \
 	getresugid.c \
 	init.sh \
 	init_delete_module.h \
+	ioctl-success.sh \
 	ioctl_kvm_run_common.c \
 	ipc.sh \
 	kernel_old_timespec.h \
@@ -5549,7 +6811,6 @@ EXTRA_DIST = \
 	lstatx.c \
 	match.awk \
 	net.expected \
-	netlink_sock_diag-v.sh \
 	nlattr_ifla.h \
 	pipe.expected \
 	print_user_desc.c \
@@ -5578,11 +6839,22 @@ EXTRA_DIST = \
 	sockname.c \
 	stack-fcall.h \
 	status-detached.expected \
+	strace--follow-forks-output-separately.expected \
+	strace--relative-timestamps.expected \
+	strace--relative-timestamps-s.expected \
+	strace--relative-timestamps-ms.expected \
+	strace--relative-timestamps-us.expected \
+	strace--relative-timestamps-ns.expected \
+	strace--syscall-times.expected \
+	strace--syscall-times-s.expected \
+	strace--syscall-times-ms.expected \
+	strace--syscall-times-us.expected \
+	strace--syscall-times-ns.expected \
 	strace-C.expected \
 	strace-D.expected \
-	strace-DD.expected \
 	strace-DDD.expected \
 	strace-E.expected \
+	strace-E-unset.expected \
 	strace-T.expected \
 	strace-ff.expected \
 	strace-k-demangle.expected \
@@ -5595,6 +6867,7 @@ EXTRA_DIST = \
 	strace.supp \
 	sun_path.expected \
 	syntax.sh \
+	trace_clock.in \
 	trace_creds.in \
 	trace_fstat.in \
 	trace_fstatfs.in \
@@ -5616,6 +6889,7 @@ EXTRA_DIST = \
 	unix-pair-send-recv.expected \
 	unix-pair-sendto-recvfrom.expected \
 	xchownx.c \
+	xgetdents.c \
 	xgetrlimit.c \
 	xselect.c \
 	xstatfs.c \
@@ -5777,6 +7051,10 @@ bpf-success$(EXEEXT): $(bpf_success_OBJE
 	@rm -f bpf-success$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(bpf_success_OBJECTS) $(bpf_success_LDADD) $(LIBS)
 
+bpf-success-long-y$(EXEEXT): $(bpf_success_long_y_OBJECTS) $(bpf_success_long_y_DEPENDENCIES) $(EXTRA_bpf_success_long_y_DEPENDENCIES) 
+	@rm -f bpf-success-long-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(bpf_success_long_y_OBJECTS) $(bpf_success_long_y_LDADD) $(LIBS)
+
 bpf-success-v$(EXEEXT): $(bpf_success_v_OBJECTS) $(bpf_success_v_DEPENDENCIES) $(EXTRA_bpf_success_v_DEPENDENCIES) 
 	@rm -f bpf-success-v$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(bpf_success_v_OBJECTS) $(bpf_success_v_LDADD) $(LIBS)
@@ -5877,10 +7155,54 @@ clone_parent$(EXEEXT): $(clone_parent_OB
 	@rm -f clone_parent$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(clone_parent_OBJECTS) $(clone_parent_LDADD) $(LIBS)
 
+clone_parent--quiet-exit$(EXEEXT): $(clone_parent__quiet_exit_OBJECTS) $(clone_parent__quiet_exit_DEPENDENCIES) $(EXTRA_clone_parent__quiet_exit_DEPENDENCIES) 
+	@rm -f clone_parent--quiet-exit$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(clone_parent__quiet_exit_OBJECTS) $(clone_parent__quiet_exit_LDADD) $(LIBS)
+
+clone_parent-q$(EXEEXT): $(clone_parent_q_OBJECTS) $(clone_parent_q_DEPENDENCIES) $(EXTRA_clone_parent_q_DEPENDENCIES) 
+	@rm -f clone_parent-q$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(clone_parent_q_OBJECTS) $(clone_parent_q_LDADD) $(LIBS)
+
+clone_parent-qq$(EXEEXT): $(clone_parent_qq_OBJECTS) $(clone_parent_qq_DEPENDENCIES) $(EXTRA_clone_parent_qq_DEPENDENCIES) 
+	@rm -f clone_parent-qq$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(clone_parent_qq_OBJECTS) $(clone_parent_qq_LDADD) $(LIBS)
+
 clone_ptrace$(EXEEXT): $(clone_ptrace_OBJECTS) $(clone_ptrace_DEPENDENCIES) $(EXTRA_clone_ptrace_DEPENDENCIES) 
 	@rm -f clone_ptrace$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(clone_ptrace_OBJECTS) $(clone_ptrace_LDADD) $(LIBS)
 
+clone_ptrace--quiet-attach$(EXEEXT): $(clone_ptrace__quiet_attach_OBJECTS) $(clone_ptrace__quiet_attach_DEPENDENCIES) $(EXTRA_clone_ptrace__quiet_attach_DEPENDENCIES) 
+	@rm -f clone_ptrace--quiet-attach$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(clone_ptrace__quiet_attach_OBJECTS) $(clone_ptrace__quiet_attach_LDADD) $(LIBS)
+
+clone_ptrace--quiet-exit$(EXEEXT): $(clone_ptrace__quiet_exit_OBJECTS) $(clone_ptrace__quiet_exit_DEPENDENCIES) $(EXTRA_clone_ptrace__quiet_exit_DEPENDENCIES) 
+	@rm -f clone_ptrace--quiet-exit$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(clone_ptrace__quiet_exit_OBJECTS) $(clone_ptrace__quiet_exit_LDADD) $(LIBS)
+
+clone_ptrace-q$(EXEEXT): $(clone_ptrace_q_OBJECTS) $(clone_ptrace_q_DEPENDENCIES) $(EXTRA_clone_ptrace_q_DEPENDENCIES) 
+	@rm -f clone_ptrace-q$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(clone_ptrace_q_OBJECTS) $(clone_ptrace_q_LDADD) $(LIBS)
+
+clone_ptrace-qq$(EXEEXT): $(clone_ptrace_qq_OBJECTS) $(clone_ptrace_qq_DEPENDENCIES) $(EXTRA_clone_ptrace_qq_DEPENDENCIES) 
+	@rm -f clone_ptrace-qq$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(clone_ptrace_qq_OBJECTS) $(clone_ptrace_qq_LDADD) $(LIBS)
+
+close_range$(EXEEXT): $(close_range_OBJECTS) $(close_range_DEPENDENCIES) $(EXTRA_close_range_DEPENDENCIES) 
+	@rm -f close_range$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(close_range_OBJECTS) $(close_range_LDADD) $(LIBS)
+
+close_range-P$(EXEEXT): $(close_range_P_OBJECTS) $(close_range_P_DEPENDENCIES) $(EXTRA_close_range_P_DEPENDENCIES) 
+	@rm -f close_range-P$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(close_range_P_OBJECTS) $(close_range_P_LDADD) $(LIBS)
+
+close_range-y$(EXEEXT): $(close_range_y_OBJECTS) $(close_range_y_DEPENDENCIES) $(EXTRA_close_range_y_DEPENDENCIES) 
+	@rm -f close_range-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(close_range_y_OBJECTS) $(close_range_y_LDADD) $(LIBS)
+
+close_range-yy$(EXEEXT): $(close_range_yy_OBJECTS) $(close_range_yy_DEPENDENCIES) $(EXTRA_close_range_yy_DEPENDENCIES) 
+	@rm -f close_range-yy$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(close_range_yy_OBJECTS) $(close_range_yy_LDADD) $(LIBS)
+
 copy_file_range$(EXEEXT): $(copy_file_range_OBJECTS) $(copy_file_range_DEPENDENCIES) $(EXTRA_copy_file_range_DEPENDENCIES) 
 	@rm -f copy_file_range$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(copy_file_range_OBJECTS) $(copy_file_range_LDADD) $(LIBS)
@@ -5901,6 +7223,18 @@ delete_module$(EXEEXT): $(delete_module_
 	@rm -f delete_module$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(delete_module_OBJECTS) $(delete_module_LDADD) $(LIBS)
 
+dev--decode-fds-dev$(EXEEXT): $(dev__decode_fds_dev_OBJECTS) $(dev__decode_fds_dev_DEPENDENCIES) $(EXTRA_dev__decode_fds_dev_DEPENDENCIES) 
+	@rm -f dev--decode-fds-dev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dev__decode_fds_dev_OBJECTS) $(dev__decode_fds_dev_LDADD) $(LIBS)
+
+dev--decode-fds-path$(EXEEXT): $(dev__decode_fds_path_OBJECTS) $(dev__decode_fds_path_DEPENDENCIES) $(EXTRA_dev__decode_fds_path_DEPENDENCIES) 
+	@rm -f dev--decode-fds-path$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dev__decode_fds_path_OBJECTS) $(dev__decode_fds_path_LDADD) $(LIBS)
+
+dev--decode-fds-socket$(EXEEXT): $(dev__decode_fds_socket_OBJECTS) $(dev__decode_fds_socket_DEPENDENCIES) $(EXTRA_dev__decode_fds_socket_DEPENDENCIES) 
+	@rm -f dev--decode-fds-socket$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dev__decode_fds_socket_OBJECTS) $(dev__decode_fds_socket_LDADD) $(LIBS)
+
 dev-yy$(EXEEXT): $(dev_yy_OBJECTS) $(dev_yy_DEPENDENCIES) $(EXTRA_dev_yy_DEPENDENCIES) 
 	@rm -f dev-yy$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(dev_yy_OBJECTS) $(dev_yy_LDADD) $(LIBS)
@@ -5909,14 +7243,50 @@ dup$(EXEEXT): $(dup_OBJECTS) $(dup_DEPEN
 	@rm -f dup$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(dup_OBJECTS) $(dup_LDADD) $(LIBS)
 
+dup-P$(EXEEXT): $(dup_P_OBJECTS) $(dup_P_DEPENDENCIES) $(EXTRA_dup_P_DEPENDENCIES) 
+	@rm -f dup-P$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup_P_OBJECTS) $(dup_P_LDADD) $(LIBS)
+
+dup-y$(EXEEXT): $(dup_y_OBJECTS) $(dup_y_DEPENDENCIES) $(EXTRA_dup_y_DEPENDENCIES) 
+	@rm -f dup-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup_y_OBJECTS) $(dup_y_LDADD) $(LIBS)
+
+dup-yy$(EXEEXT): $(dup_yy_OBJECTS) $(dup_yy_DEPENDENCIES) $(EXTRA_dup_yy_DEPENDENCIES) 
+	@rm -f dup-yy$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup_yy_OBJECTS) $(dup_yy_LDADD) $(LIBS)
+
 dup2$(EXEEXT): $(dup2_OBJECTS) $(dup2_DEPENDENCIES) $(EXTRA_dup2_DEPENDENCIES) 
 	@rm -f dup2$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(dup2_OBJECTS) $(dup2_LDADD) $(LIBS)
 
+dup2-P$(EXEEXT): $(dup2_P_OBJECTS) $(dup2_P_DEPENDENCIES) $(EXTRA_dup2_P_DEPENDENCIES) 
+	@rm -f dup2-P$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup2_P_OBJECTS) $(dup2_P_LDADD) $(LIBS)
+
+dup2-y$(EXEEXT): $(dup2_y_OBJECTS) $(dup2_y_DEPENDENCIES) $(EXTRA_dup2_y_DEPENDENCIES) 
+	@rm -f dup2-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup2_y_OBJECTS) $(dup2_y_LDADD) $(LIBS)
+
+dup2-yy$(EXEEXT): $(dup2_yy_OBJECTS) $(dup2_yy_DEPENDENCIES) $(EXTRA_dup2_yy_DEPENDENCIES) 
+	@rm -f dup2-yy$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup2_yy_OBJECTS) $(dup2_yy_LDADD) $(LIBS)
+
 dup3$(EXEEXT): $(dup3_OBJECTS) $(dup3_DEPENDENCIES) $(EXTRA_dup3_DEPENDENCIES) 
 	@rm -f dup3$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(dup3_OBJECTS) $(dup3_LDADD) $(LIBS)
 
+dup3-P$(EXEEXT): $(dup3_P_OBJECTS) $(dup3_P_DEPENDENCIES) $(EXTRA_dup3_P_DEPENDENCIES) 
+	@rm -f dup3-P$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup3_P_OBJECTS) $(dup3_P_LDADD) $(LIBS)
+
+dup3-y$(EXEEXT): $(dup3_y_OBJECTS) $(dup3_y_DEPENDENCIES) $(EXTRA_dup3_y_DEPENDENCIES) 
+	@rm -f dup3-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup3_y_OBJECTS) $(dup3_y_LDADD) $(LIBS)
+
+dup3-yy$(EXEEXT): $(dup3_yy_OBJECTS) $(dup3_yy_DEPENDENCIES) $(EXTRA_dup3_yy_DEPENDENCIES) 
+	@rm -f dup3-yy$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup3_yy_OBJECTS) $(dup3_yy_LDADD) $(LIBS)
+
 epoll_create$(EXEEXT): $(epoll_create_OBJECTS) $(epoll_create_DEPENDENCIES) $(EXTRA_epoll_create_DEPENDENCIES) 
 	@rm -f epoll_create$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(epoll_create_OBJECTS) $(epoll_create_LDADD) $(LIBS)
@@ -5965,6 +7335,34 @@ faccessat$(EXEEXT): $(faccessat_OBJECTS)
 	@rm -f faccessat$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(faccessat_OBJECTS) $(faccessat_LDADD) $(LIBS)
 
+faccessat-P$(EXEEXT): $(faccessat_P_OBJECTS) $(faccessat_P_DEPENDENCIES) $(EXTRA_faccessat_P_DEPENDENCIES) 
+	@rm -f faccessat-P$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(faccessat_P_OBJECTS) $(faccessat_P_LDADD) $(LIBS)
+
+faccessat-y$(EXEEXT): $(faccessat_y_OBJECTS) $(faccessat_y_DEPENDENCIES) $(EXTRA_faccessat_y_DEPENDENCIES) 
+	@rm -f faccessat-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(faccessat_y_OBJECTS) $(faccessat_y_LDADD) $(LIBS)
+
+faccessat-yy$(EXEEXT): $(faccessat_yy_OBJECTS) $(faccessat_yy_DEPENDENCIES) $(EXTRA_faccessat_yy_DEPENDENCIES) 
+	@rm -f faccessat-yy$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(faccessat_yy_OBJECTS) $(faccessat_yy_LDADD) $(LIBS)
+
+faccessat2$(EXEEXT): $(faccessat2_OBJECTS) $(faccessat2_DEPENDENCIES) $(EXTRA_faccessat2_DEPENDENCIES) 
+	@rm -f faccessat2$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(faccessat2_OBJECTS) $(faccessat2_LDADD) $(LIBS)
+
+faccessat2-P$(EXEEXT): $(faccessat2_P_OBJECTS) $(faccessat2_P_DEPENDENCIES) $(EXTRA_faccessat2_P_DEPENDENCIES) 
+	@rm -f faccessat2-P$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(faccessat2_P_OBJECTS) $(faccessat2_P_LDADD) $(LIBS)
+
+faccessat2-y$(EXEEXT): $(faccessat2_y_OBJECTS) $(faccessat2_y_DEPENDENCIES) $(EXTRA_faccessat2_y_DEPENDENCIES) 
+	@rm -f faccessat2-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(faccessat2_y_OBJECTS) $(faccessat2_y_LDADD) $(LIBS)
+
+faccessat2-yy$(EXEEXT): $(faccessat2_yy_OBJECTS) $(faccessat2_yy_DEPENDENCIES) $(EXTRA_faccessat2_yy_DEPENDENCIES) 
+	@rm -f faccessat2-yy$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(faccessat2_yy_OBJECTS) $(faccessat2_yy_LDADD) $(LIBS)
+
 fadvise64$(EXEEXT): $(fadvise64_OBJECTS) $(fadvise64_DEPENDENCIES) $(EXTRA_fadvise64_DEPENDENCIES) 
 	@rm -f fadvise64$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(fadvise64_OBJECTS) $(fadvise64_LDADD) $(LIBS)
@@ -6025,10 +7423,18 @@ fcntl$(EXEEXT): $(fcntl_OBJECTS) $(fcntl
 	@rm -f fcntl$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(fcntl_OBJECTS) $(fcntl_LDADD) $(LIBS)
 
+fcntl--pidns-translation$(EXEEXT): $(fcntl__pidns_translation_OBJECTS) $(fcntl__pidns_translation_DEPENDENCIES) $(EXTRA_fcntl__pidns_translation_DEPENDENCIES) 
+	@rm -f fcntl--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(fcntl__pidns_translation_OBJECTS) $(fcntl__pidns_translation_LDADD) $(LIBS)
+
 fcntl64$(EXEEXT): $(fcntl64_OBJECTS) $(fcntl64_DEPENDENCIES) $(EXTRA_fcntl64_DEPENDENCIES) 
 	@rm -f fcntl64$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(fcntl64_OBJECTS) $(fcntl64_LDADD) $(LIBS)
 
+fcntl64--pidns-translation$(EXEEXT): $(fcntl64__pidns_translation_OBJECTS) $(fcntl64__pidns_translation_DEPENDENCIES) $(EXTRA_fcntl64__pidns_translation_DEPENDENCIES) 
+	@rm -f fcntl64--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(fcntl64__pidns_translation_OBJECTS) $(fcntl64__pidns_translation_LDADD) $(LIBS)
+
 fdatasync$(EXEEXT): $(fdatasync_OBJECTS) $(fdatasync_DEPENDENCIES) $(EXTRA_fdatasync_DEPENDENCIES) 
 	@rm -f fdatasync$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(fdatasync_OBJECTS) $(fdatasync_LDADD) $(LIBS)
@@ -6065,6 +7471,10 @@ flock$(EXEEXT): $(flock_OBJECTS) $(flock
 	@rm -f flock$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(flock_OBJECTS) $(flock_LDADD) $(LIBS)
 
+fork--pidns-translation$(EXEEXT): $(fork__pidns_translation_OBJECTS) $(fork__pidns_translation_DEPENDENCIES) $(EXTRA_fork__pidns_translation_DEPENDENCIES) 
+	@rm -f fork--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(fork__pidns_translation_OBJECTS) $(fork__pidns_translation_LDADD) $(LIBS)
+
 fork-f$(EXEEXT): $(fork_f_OBJECTS) $(fork_f_DEPENDENCIES) $(EXTRA_fork_f_DEPENDENCIES) 
 	@rm -f fork-f$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(fork_f_OBJECTS) $(fork_f_LDADD) $(LIBS)
@@ -6165,6 +7575,10 @@ get_mempolicy$(EXEEXT): $(get_mempolicy_
 	@rm -f get_mempolicy$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(get_mempolicy_OBJECTS) $(get_mempolicy_LDADD) $(LIBS)
 
+get_process_reaper$(EXEEXT): $(get_process_reaper_OBJECTS) $(get_process_reaper_DEPENDENCIES) $(EXTRA_get_process_reaper_DEPENDENCIES) 
+	@rm -f get_process_reaper$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(get_process_reaper_OBJECTS) $(get_process_reaper_LDADD) $(LIBS)
+
 getcpu$(EXEEXT): $(getcpu_OBJECTS) $(getcpu_DEPENDENCIES) $(EXTRA_getcpu_DEPENDENCIES) 
 	@rm -f getcpu$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getcpu_OBJECTS) $(getcpu_LDADD) $(LIBS)
@@ -6177,10 +7591,18 @@ getdents$(EXEEXT): $(getdents_OBJECTS) $
 	@rm -f getdents$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getdents_OBJECTS) $(getdents_LDADD) $(LIBS)
 
+getdents-v$(EXEEXT): $(getdents_v_OBJECTS) $(getdents_v_DEPENDENCIES) $(EXTRA_getdents_v_DEPENDENCIES) 
+	@rm -f getdents-v$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(getdents_v_OBJECTS) $(getdents_v_LDADD) $(LIBS)
+
 getdents64$(EXEEXT): $(getdents64_OBJECTS) $(getdents64_DEPENDENCIES) $(EXTRA_getdents64_DEPENDENCIES) 
 	@rm -f getdents64$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getdents64_OBJECTS) $(getdents64_LDADD) $(LIBS)
 
+getdents64-v$(EXEEXT): $(getdents64_v_OBJECTS) $(getdents64_v_DEPENDENCIES) $(EXTRA_getdents64_v_DEPENDENCIES) 
+	@rm -f getdents64-v$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(getdents64_v_OBJECTS) $(getdents64_v_LDADD) $(LIBS)
+
 getegid$(EXEEXT): $(getegid_OBJECTS) $(getegid_DEPENDENCIES) $(EXTRA_getegid_DEPENDENCIES) 
 	@rm -f getegid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getegid_OBJECTS) $(getegid_LDADD) $(LIBS)
@@ -6221,10 +7643,18 @@ getpgrp$(EXEEXT): $(getpgrp_OBJECTS) $(g
 	@rm -f getpgrp$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getpgrp_OBJECTS) $(getpgrp_LDADD) $(LIBS)
 
+getpgrp--pidns-translation$(EXEEXT): $(getpgrp__pidns_translation_OBJECTS) $(getpgrp__pidns_translation_DEPENDENCIES) $(EXTRA_getpgrp__pidns_translation_DEPENDENCIES) 
+	@rm -f getpgrp--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(getpgrp__pidns_translation_OBJECTS) $(getpgrp__pidns_translation_LDADD) $(LIBS)
+
 getpid$(EXEEXT): $(getpid_OBJECTS) $(getpid_DEPENDENCIES) $(EXTRA_getpid_DEPENDENCIES) 
 	@rm -f getpid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getpid_OBJECTS) $(getpid_LDADD) $(LIBS)
 
+getpid--pidns-translation$(EXEEXT): $(getpid__pidns_translation_OBJECTS) $(getpid__pidns_translation_DEPENDENCIES) $(EXTRA_getpid__pidns_translation_DEPENDENCIES) 
+	@rm -f getpid--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(getpid__pidns_translation_OBJECTS) $(getpid__pidns_translation_LDADD) $(LIBS)
+
 getppid$(EXEEXT): $(getppid_OBJECTS) $(getppid_DEPENDENCIES) $(EXTRA_getppid_DEPENDENCIES) 
 	@rm -f getppid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getppid_OBJECTS) $(getppid_LDADD) $(LIBS)
@@ -6261,6 +7691,10 @@ getsid$(EXEEXT): $(getsid_OBJECTS) $(get
 	@rm -f getsid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getsid_OBJECTS) $(getsid_LDADD) $(LIBS)
 
+getsid--pidns-translation$(EXEEXT): $(getsid__pidns_translation_OBJECTS) $(getsid__pidns_translation_DEPENDENCIES) $(EXTRA_getsid__pidns_translation_DEPENDENCIES) 
+	@rm -f getsid--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(getsid__pidns_translation_OBJECTS) $(getsid__pidns_translation_LDADD) $(LIBS)
+
 getsockname$(EXEEXT): $(getsockname_OBJECTS) $(getsockname_DEPENDENCIES) $(EXTRA_getsockname_DEPENDENCIES) 
 	@rm -f getsockname$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getsockname_OBJECTS) $(getsockname_LDADD) $(LIBS)
@@ -6269,6 +7703,10 @@ gettid$(EXEEXT): $(gettid_OBJECTS) $(get
 	@rm -f gettid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(gettid_OBJECTS) $(gettid_LDADD) $(LIBS)
 
+gettid--pidns-translation$(EXEEXT): $(gettid__pidns_translation_OBJECTS) $(gettid__pidns_translation_DEPENDENCIES) $(EXTRA_gettid__pidns_translation_DEPENDENCIES) 
+	@rm -f gettid--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(gettid__pidns_translation_OBJECTS) $(gettid__pidns_translation_LDADD) $(LIBS)
+
 getuid$(EXEEXT): $(getuid_OBJECTS) $(getuid_DEPENDENCIES) $(EXTRA_getuid_DEPENDENCIES) 
 	@rm -f getuid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getuid_OBJECTS) $(getuid_LDADD) $(LIBS)
@@ -6277,9 +7715,17 @@ getuid32$(EXEEXT): $(getuid32_OBJECTS) $
 	@rm -f getuid32$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getuid32_OBJECTS) $(getuid32_LDADD) $(LIBS)
 
-getxxid$(EXEEXT): $(getxxid_OBJECTS) $(getxxid_DEPENDENCIES) $(EXTRA_getxxid_DEPENDENCIES) 
-	@rm -f getxxid$(EXEEXT)
-	$(AM_V_CCLD)$(LINK) $(getxxid_OBJECTS) $(getxxid_LDADD) $(LIBS)
+getxgid$(EXEEXT): $(getxgid_OBJECTS) $(getxgid_DEPENDENCIES) $(EXTRA_getxgid_DEPENDENCIES) 
+	@rm -f getxgid$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(getxgid_OBJECTS) $(getxgid_LDADD) $(LIBS)
+
+getxpid$(EXEEXT): $(getxpid_OBJECTS) $(getxpid_DEPENDENCIES) $(EXTRA_getxpid_DEPENDENCIES) 
+	@rm -f getxpid$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(getxpid_OBJECTS) $(getxpid_LDADD) $(LIBS)
+
+getxuid$(EXEEXT): $(getxuid_OBJECTS) $(getxuid_DEPENDENCIES) $(EXTRA_getxuid_DEPENDENCIES) 
+	@rm -f getxuid$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(getxuid_OBJECTS) $(getxuid_LDADD) $(LIBS)
 
 group_req$(EXEEXT): $(group_req_OBJECTS) $(group_req_DEPENDENCIES) $(EXTRA_group_req_DEPENDENCIES) 
 	@rm -f group_req$(EXEEXT)
@@ -6341,6 +7787,10 @@ ioctl_block$(EXEEXT): $(ioctl_block_OBJE
 	@rm -f ioctl_block$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioctl_block_OBJECTS) $(ioctl_block_LDADD) $(LIBS)
 
+ioctl_block--pidns-translation$(EXEEXT): $(ioctl_block__pidns_translation_OBJECTS) $(ioctl_block__pidns_translation_DEPENDENCIES) $(EXTRA_ioctl_block__pidns_translation_DEPENDENCIES) 
+	@rm -f ioctl_block--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_block__pidns_translation_OBJECTS) $(ioctl_block__pidns_translation_LDADD) $(LIBS)
+
 ioctl_dm$(EXEEXT): $(ioctl_dm_OBJECTS) $(ioctl_dm_DEPENDENCIES) $(EXTRA_ioctl_dm_DEPENDENCIES) 
 	@rm -f ioctl_dm$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioctl_dm_OBJECTS) $(ioctl_dm_LDADD) $(LIBS)
@@ -6413,6 +7863,70 @@ ioctl_evdev-v-Xverbose$(EXEEXT): $(ioctl
 	@rm -f ioctl_evdev-v-Xverbose$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioctl_evdev_v_Xverbose_OBJECTS) $(ioctl_evdev_v_Xverbose_LDADD) $(LIBS)
 
+ioctl_hdio$(EXEEXT): $(ioctl_hdio_OBJECTS) $(ioctl_hdio_DEPENDENCIES) $(EXTRA_ioctl_hdio_DEPENDENCIES) 
+	@rm -f ioctl_hdio$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_OBJECTS) $(ioctl_hdio_LDADD) $(LIBS)
+
+ioctl_hdio-Xabbrev$(EXEEXT): $(ioctl_hdio_Xabbrev_OBJECTS) $(ioctl_hdio_Xabbrev_DEPENDENCIES) $(EXTRA_ioctl_hdio_Xabbrev_DEPENDENCIES) 
+	@rm -f ioctl_hdio-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_Xabbrev_OBJECTS) $(ioctl_hdio_Xabbrev_LDADD) $(LIBS)
+
+ioctl_hdio-Xraw$(EXEEXT): $(ioctl_hdio_Xraw_OBJECTS) $(ioctl_hdio_Xraw_DEPENDENCIES) $(EXTRA_ioctl_hdio_Xraw_DEPENDENCIES) 
+	@rm -f ioctl_hdio-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_Xraw_OBJECTS) $(ioctl_hdio_Xraw_LDADD) $(LIBS)
+
+ioctl_hdio-Xverbose$(EXEEXT): $(ioctl_hdio_Xverbose_OBJECTS) $(ioctl_hdio_Xverbose_DEPENDENCIES) $(EXTRA_ioctl_hdio_Xverbose_DEPENDENCIES) 
+	@rm -f ioctl_hdio-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_Xverbose_OBJECTS) $(ioctl_hdio_Xverbose_LDADD) $(LIBS)
+
+ioctl_hdio-success$(EXEEXT): $(ioctl_hdio_success_OBJECTS) $(ioctl_hdio_success_DEPENDENCIES) $(EXTRA_ioctl_hdio_success_DEPENDENCIES) 
+	@rm -f ioctl_hdio-success$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_success_OBJECTS) $(ioctl_hdio_success_LDADD) $(LIBS)
+
+ioctl_hdio-success-Xabbrev$(EXEEXT): $(ioctl_hdio_success_Xabbrev_OBJECTS) $(ioctl_hdio_success_Xabbrev_DEPENDENCIES) $(EXTRA_ioctl_hdio_success_Xabbrev_DEPENDENCIES) 
+	@rm -f ioctl_hdio-success-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_success_Xabbrev_OBJECTS) $(ioctl_hdio_success_Xabbrev_LDADD) $(LIBS)
+
+ioctl_hdio-success-Xraw$(EXEEXT): $(ioctl_hdio_success_Xraw_OBJECTS) $(ioctl_hdio_success_Xraw_DEPENDENCIES) $(EXTRA_ioctl_hdio_success_Xraw_DEPENDENCIES) 
+	@rm -f ioctl_hdio-success-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_success_Xraw_OBJECTS) $(ioctl_hdio_success_Xraw_LDADD) $(LIBS)
+
+ioctl_hdio-success-Xverbose$(EXEEXT): $(ioctl_hdio_success_Xverbose_OBJECTS) $(ioctl_hdio_success_Xverbose_DEPENDENCIES) $(EXTRA_ioctl_hdio_success_Xverbose_DEPENDENCIES) 
+	@rm -f ioctl_hdio-success-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_success_Xverbose_OBJECTS) $(ioctl_hdio_success_Xverbose_LDADD) $(LIBS)
+
+ioctl_hdio-success-v$(EXEEXT): $(ioctl_hdio_success_v_OBJECTS) $(ioctl_hdio_success_v_DEPENDENCIES) $(EXTRA_ioctl_hdio_success_v_DEPENDENCIES) 
+	@rm -f ioctl_hdio-success-v$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_success_v_OBJECTS) $(ioctl_hdio_success_v_LDADD) $(LIBS)
+
+ioctl_hdio-success-v-Xabbrev$(EXEEXT): $(ioctl_hdio_success_v_Xabbrev_OBJECTS) $(ioctl_hdio_success_v_Xabbrev_DEPENDENCIES) $(EXTRA_ioctl_hdio_success_v_Xabbrev_DEPENDENCIES) 
+	@rm -f ioctl_hdio-success-v-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_success_v_Xabbrev_OBJECTS) $(ioctl_hdio_success_v_Xabbrev_LDADD) $(LIBS)
+
+ioctl_hdio-success-v-Xraw$(EXEEXT): $(ioctl_hdio_success_v_Xraw_OBJECTS) $(ioctl_hdio_success_v_Xraw_DEPENDENCIES) $(EXTRA_ioctl_hdio_success_v_Xraw_DEPENDENCIES) 
+	@rm -f ioctl_hdio-success-v-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_success_v_Xraw_OBJECTS) $(ioctl_hdio_success_v_Xraw_LDADD) $(LIBS)
+
+ioctl_hdio-success-v-Xverbose$(EXEEXT): $(ioctl_hdio_success_v_Xverbose_OBJECTS) $(ioctl_hdio_success_v_Xverbose_DEPENDENCIES) $(EXTRA_ioctl_hdio_success_v_Xverbose_DEPENDENCIES) 
+	@rm -f ioctl_hdio-success-v-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_success_v_Xverbose_OBJECTS) $(ioctl_hdio_success_v_Xverbose_LDADD) $(LIBS)
+
+ioctl_hdio-v$(EXEEXT): $(ioctl_hdio_v_OBJECTS) $(ioctl_hdio_v_DEPENDENCIES) $(EXTRA_ioctl_hdio_v_DEPENDENCIES) 
+	@rm -f ioctl_hdio-v$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_v_OBJECTS) $(ioctl_hdio_v_LDADD) $(LIBS)
+
+ioctl_hdio-v-Xabbrev$(EXEEXT): $(ioctl_hdio_v_Xabbrev_OBJECTS) $(ioctl_hdio_v_Xabbrev_DEPENDENCIES) $(EXTRA_ioctl_hdio_v_Xabbrev_DEPENDENCIES) 
+	@rm -f ioctl_hdio-v-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_v_Xabbrev_OBJECTS) $(ioctl_hdio_v_Xabbrev_LDADD) $(LIBS)
+
+ioctl_hdio-v-Xraw$(EXEEXT): $(ioctl_hdio_v_Xraw_OBJECTS) $(ioctl_hdio_v_Xraw_DEPENDENCIES) $(EXTRA_ioctl_hdio_v_Xraw_DEPENDENCIES) 
+	@rm -f ioctl_hdio-v-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_v_Xraw_OBJECTS) $(ioctl_hdio_v_Xraw_LDADD) $(LIBS)
+
+ioctl_hdio-v-Xverbose$(EXEEXT): $(ioctl_hdio_v_Xverbose_OBJECTS) $(ioctl_hdio_v_Xverbose_DEPENDENCIES) $(EXTRA_ioctl_hdio_v_Xverbose_DEPENDENCIES) 
+	@rm -f ioctl_hdio-v-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_v_Xverbose_OBJECTS) $(ioctl_hdio_v_Xverbose_LDADD) $(LIBS)
+
 ioctl_inotify$(EXEEXT): $(ioctl_inotify_OBJECTS) $(ioctl_inotify_DEPENDENCIES) $(EXTRA_ioctl_inotify_DEPENDENCIES) 
 	@rm -f ioctl_inotify$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioctl_inotify_OBJECTS) $(ioctl_inotify_LDADD) $(LIBS)
@@ -6493,6 +8007,10 @@ ioctl_sock_gifconf$(EXEEXT): $(ioctl_soc
 	@rm -f ioctl_sock_gifconf$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioctl_sock_gifconf_OBJECTS) $(ioctl_sock_gifconf_LDADD) $(LIBS)
 
+ioctl_tee$(EXEEXT): $(ioctl_tee_OBJECTS) $(ioctl_tee_DEPENDENCIES) $(EXTRA_ioctl_tee_DEPENDENCIES) 
+	@rm -f ioctl_tee$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_tee_OBJECTS) $(ioctl_tee_LDADD) $(LIBS)
+
 ioctl_uffdio$(EXEEXT): $(ioctl_uffdio_OBJECTS) $(ioctl_uffdio_DEPENDENCIES) $(EXTRA_ioctl_uffdio_DEPENDENCIES) 
 	@rm -f ioctl_uffdio$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioctl_uffdio_OBJECTS) $(ioctl_uffdio_LDADD) $(LIBS)
@@ -6501,6 +8019,66 @@ ioctl_v4l2$(EXEEXT): $(ioctl_v4l2_OBJECT
 	@rm -f ioctl_v4l2$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_OBJECTS) $(ioctl_v4l2_LDADD) $(LIBS)
 
+ioctl_v4l2-Xabbrev$(EXEEXT): $(ioctl_v4l2_Xabbrev_OBJECTS) $(ioctl_v4l2_Xabbrev_DEPENDENCIES) $(EXTRA_ioctl_v4l2_Xabbrev_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_Xabbrev_OBJECTS) $(ioctl_v4l2_Xabbrev_LDADD) $(LIBS)
+
+ioctl_v4l2-Xraw$(EXEEXT): $(ioctl_v4l2_Xraw_OBJECTS) $(ioctl_v4l2_Xraw_DEPENDENCIES) $(EXTRA_ioctl_v4l2_Xraw_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_Xraw_OBJECTS) $(ioctl_v4l2_Xraw_LDADD) $(LIBS)
+
+ioctl_v4l2-Xverbose$(EXEEXT): $(ioctl_v4l2_Xverbose_OBJECTS) $(ioctl_v4l2_Xverbose_DEPENDENCIES) $(EXTRA_ioctl_v4l2_Xverbose_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_Xverbose_OBJECTS) $(ioctl_v4l2_Xverbose_LDADD) $(LIBS)
+
+ioctl_v4l2-success$(EXEEXT): $(ioctl_v4l2_success_OBJECTS) $(ioctl_v4l2_success_DEPENDENCIES) $(EXTRA_ioctl_v4l2_success_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-success$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_success_OBJECTS) $(ioctl_v4l2_success_LDADD) $(LIBS)
+
+ioctl_v4l2-success-Xabbrev$(EXEEXT): $(ioctl_v4l2_success_Xabbrev_OBJECTS) $(ioctl_v4l2_success_Xabbrev_DEPENDENCIES) $(EXTRA_ioctl_v4l2_success_Xabbrev_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-success-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_success_Xabbrev_OBJECTS) $(ioctl_v4l2_success_Xabbrev_LDADD) $(LIBS)
+
+ioctl_v4l2-success-Xraw$(EXEEXT): $(ioctl_v4l2_success_Xraw_OBJECTS) $(ioctl_v4l2_success_Xraw_DEPENDENCIES) $(EXTRA_ioctl_v4l2_success_Xraw_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-success-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_success_Xraw_OBJECTS) $(ioctl_v4l2_success_Xraw_LDADD) $(LIBS)
+
+ioctl_v4l2-success-Xverbose$(EXEEXT): $(ioctl_v4l2_success_Xverbose_OBJECTS) $(ioctl_v4l2_success_Xverbose_DEPENDENCIES) $(EXTRA_ioctl_v4l2_success_Xverbose_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-success-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_success_Xverbose_OBJECTS) $(ioctl_v4l2_success_Xverbose_LDADD) $(LIBS)
+
+ioctl_v4l2-success-v$(EXEEXT): $(ioctl_v4l2_success_v_OBJECTS) $(ioctl_v4l2_success_v_DEPENDENCIES) $(EXTRA_ioctl_v4l2_success_v_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-success-v$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_success_v_OBJECTS) $(ioctl_v4l2_success_v_LDADD) $(LIBS)
+
+ioctl_v4l2-success-v-Xabbrev$(EXEEXT): $(ioctl_v4l2_success_v_Xabbrev_OBJECTS) $(ioctl_v4l2_success_v_Xabbrev_DEPENDENCIES) $(EXTRA_ioctl_v4l2_success_v_Xabbrev_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-success-v-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_success_v_Xabbrev_OBJECTS) $(ioctl_v4l2_success_v_Xabbrev_LDADD) $(LIBS)
+
+ioctl_v4l2-success-v-Xraw$(EXEEXT): $(ioctl_v4l2_success_v_Xraw_OBJECTS) $(ioctl_v4l2_success_v_Xraw_DEPENDENCIES) $(EXTRA_ioctl_v4l2_success_v_Xraw_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-success-v-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_success_v_Xraw_OBJECTS) $(ioctl_v4l2_success_v_Xraw_LDADD) $(LIBS)
+
+ioctl_v4l2-success-v-Xverbose$(EXEEXT): $(ioctl_v4l2_success_v_Xverbose_OBJECTS) $(ioctl_v4l2_success_v_Xverbose_DEPENDENCIES) $(EXTRA_ioctl_v4l2_success_v_Xverbose_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-success-v-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_success_v_Xverbose_OBJECTS) $(ioctl_v4l2_success_v_Xverbose_LDADD) $(LIBS)
+
+ioctl_v4l2-v$(EXEEXT): $(ioctl_v4l2_v_OBJECTS) $(ioctl_v4l2_v_DEPENDENCIES) $(EXTRA_ioctl_v4l2_v_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-v$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_v_OBJECTS) $(ioctl_v4l2_v_LDADD) $(LIBS)
+
+ioctl_v4l2-v-Xabbrev$(EXEEXT): $(ioctl_v4l2_v_Xabbrev_OBJECTS) $(ioctl_v4l2_v_Xabbrev_DEPENDENCIES) $(EXTRA_ioctl_v4l2_v_Xabbrev_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-v-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_v_Xabbrev_OBJECTS) $(ioctl_v4l2_v_Xabbrev_LDADD) $(LIBS)
+
+ioctl_v4l2-v-Xraw$(EXEEXT): $(ioctl_v4l2_v_Xraw_OBJECTS) $(ioctl_v4l2_v_Xraw_DEPENDENCIES) $(EXTRA_ioctl_v4l2_v_Xraw_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-v-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_v_Xraw_OBJECTS) $(ioctl_v4l2_v_Xraw_LDADD) $(LIBS)
+
+ioctl_v4l2-v-Xverbose$(EXEEXT): $(ioctl_v4l2_v_Xverbose_OBJECTS) $(ioctl_v4l2_v_Xverbose_DEPENDENCIES) $(EXTRA_ioctl_v4l2_v_Xverbose_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-v-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_v_Xverbose_OBJECTS) $(ioctl_v4l2_v_Xverbose_LDADD) $(LIBS)
+
 ioctl_watchdog$(EXEEXT): $(ioctl_watchdog_OBJECTS) $(ioctl_watchdog_DEPENDENCIES) $(EXTRA_ioctl_watchdog_DEPENDENCIES) 
 	@rm -f ioctl_watchdog$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioctl_watchdog_OBJECTS) $(ioctl_watchdog_LDADD) $(LIBS)
@@ -6517,6 +8095,10 @@ ioprio$(EXEEXT): $(ioprio_OBJECTS) $(iop
 	@rm -f ioprio$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioprio_OBJECTS) $(ioprio_LDADD) $(LIBS)
 
+ioprio--pidns-translation$(EXEEXT): $(ioprio__pidns_translation_OBJECTS) $(ioprio__pidns_translation_DEPENDENCIES) $(EXTRA_ioprio__pidns_translation_DEPENDENCIES) 
+	@rm -f ioprio--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioprio__pidns_translation_OBJECTS) $(ioprio__pidns_translation_LDADD) $(LIBS)
+
 ioprio-Xabbrev$(EXEEXT): $(ioprio_Xabbrev_OBJECTS) $(ioprio_Xabbrev_DEPENDENCIES) $(EXTRA_ioprio_Xabbrev_DEPENDENCIES) 
 	@rm -f ioprio-Xabbrev$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioprio_Xabbrev_OBJECTS) $(ioprio_Xabbrev_LDADD) $(LIBS)
@@ -6613,6 +8195,10 @@ kcmp-y$(EXEEXT): $(kcmp_y_OBJECTS) $(kcm
 	@rm -f kcmp-y$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(kcmp_y_OBJECTS) $(kcmp_y_LDADD) $(LIBS)
 
+kcmp-y--pidns-translation$(EXEEXT): $(kcmp_y__pidns_translation_OBJECTS) $(kcmp_y__pidns_translation_DEPENDENCIES) $(EXTRA_kcmp_y__pidns_translation_DEPENDENCIES) 
+	@rm -f kcmp-y--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(kcmp_y__pidns_translation_OBJECTS) $(kcmp_y__pidns_translation_LDADD) $(LIBS)
+
 kern_features$(EXEEXT): $(kern_features_OBJECTS) $(kern_features_DEPENDENCIES) $(EXTRA_kern_features_DEPENDENCIES) 
 	@rm -f kern_features$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(kern_features_OBJECTS) $(kern_features_LDADD) $(LIBS)
@@ -6661,6 +8247,10 @@ kill$(EXEEXT): $(kill_OBJECTS) $(kill_DE
 	@rm -f kill$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(kill_OBJECTS) $(kill_LDADD) $(LIBS)
 
+kill--pidns-translation$(EXEEXT): $(kill__pidns_translation_OBJECTS) $(kill__pidns_translation_DEPENDENCIES) $(EXTRA_kill__pidns_translation_DEPENDENCIES) 
+	@rm -f kill--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(kill__pidns_translation_OBJECTS) $(kill__pidns_translation_LDADD) $(LIBS)
+
 kill_child$(EXEEXT): $(kill_child_OBJECTS) $(kill_child_DEPENDENCIES) $(EXTRA_kill_child_DEPENDENCIES) 
 	@rm -f kill_child$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(kill_child_OBJECTS) $(kill_child_LDADD) $(LIBS)
@@ -6725,6 +8315,10 @@ maybe_switch_current_tcp$(EXEEXT): $(may
 	@rm -f maybe_switch_current_tcp$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(maybe_switch_current_tcp_OBJECTS) $(maybe_switch_current_tcp_LDADD) $(LIBS)
 
+maybe_switch_current_tcp--quiet-thread-execve$(EXEEXT): $(maybe_switch_current_tcp__quiet_thread_execve_OBJECTS) $(maybe_switch_current_tcp__quiet_thread_execve_DEPENDENCIES) $(EXTRA_maybe_switch_current_tcp__quiet_thread_execve_DEPENDENCIES) 
+	@rm -f maybe_switch_current_tcp--quiet-thread-execve$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(maybe_switch_current_tcp__quiet_thread_execve_OBJECTS) $(maybe_switch_current_tcp__quiet_thread_execve_LDADD) $(LIBS)
+
 mbind$(EXEEXT): $(mbind_OBJECTS) $(mbind_DEPENDENCIES) $(EXTRA_mbind_DEPENDENCIES) 
 	@rm -f mbind$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(mbind_OBJECTS) $(mbind_LDADD) $(LIBS)
@@ -6765,6 +8359,10 @@ migrate_pages$(EXEEXT): $(migrate_pages_
 	@rm -f migrate_pages$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(migrate_pages_OBJECTS) $(migrate_pages_LDADD) $(LIBS)
 
+migrate_pages--pidns-translation$(EXEEXT): $(migrate_pages__pidns_translation_OBJECTS) $(migrate_pages__pidns_translation_DEPENDENCIES) $(EXTRA_migrate_pages__pidns_translation_DEPENDENCIES) 
+	@rm -f migrate_pages--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(migrate_pages__pidns_translation_OBJECTS) $(migrate_pages__pidns_translation_LDADD) $(LIBS)
+
 mincore$(EXEEXT): $(mincore_OBJECTS) $(mincore_DEPENDENCIES) $(EXTRA_mincore_DEPENDENCIES) 
 	@rm -f mincore$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(mincore_OBJECTS) $(mincore_LDADD) $(LIBS)
@@ -6877,6 +8475,10 @@ move_pages$(EXEEXT): $(move_pages_OBJECT
 	@rm -f move_pages$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(move_pages_OBJECTS) $(move_pages_LDADD) $(LIBS)
 
+move_pages--pidns-translation$(EXEEXT): $(move_pages__pidns_translation_OBJECTS) $(move_pages__pidns_translation_DEPENDENCIES) $(EXTRA_move_pages__pidns_translation_DEPENDENCIES) 
+	@rm -f move_pages--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(move_pages__pidns_translation_OBJECTS) $(move_pages__pidns_translation_LDADD) $(LIBS)
+
 move_pages-Xabbrev$(EXEEXT): $(move_pages_Xabbrev_OBJECTS) $(move_pages_Xabbrev_DEPENDENCIES) $(EXTRA_move_pages_Xabbrev_DEPENDENCIES) 
 	@rm -f move_pages-Xabbrev$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(move_pages_Xabbrev_OBJECTS) $(move_pages_Xabbrev_LDADD) $(LIBS)
@@ -6925,6 +8527,22 @@ nanosleep$(EXEEXT): $(nanosleep_OBJECTS)
 	@rm -f nanosleep$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(nanosleep_OBJECTS) $(nanosleep_LDADD) $(LIBS)
 
+net--decode-fds-dev-netlink$(EXEEXT): $(net__decode_fds_dev_netlink_OBJECTS) $(net__decode_fds_dev_netlink_DEPENDENCIES) $(EXTRA_net__decode_fds_dev_netlink_DEPENDENCIES) 
+	@rm -f net--decode-fds-dev-netlink$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(net__decode_fds_dev_netlink_OBJECTS) $(net__decode_fds_dev_netlink_LDADD) $(LIBS)
+
+net--decode-fds-none-netlink$(EXEEXT): $(net__decode_fds_none_netlink_OBJECTS) $(net__decode_fds_none_netlink_DEPENDENCIES) $(EXTRA_net__decode_fds_none_netlink_DEPENDENCIES) 
+	@rm -f net--decode-fds-none-netlink$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(net__decode_fds_none_netlink_OBJECTS) $(net__decode_fds_none_netlink_LDADD) $(LIBS)
+
+net--decode-fds-path-netlink$(EXEEXT): $(net__decode_fds_path_netlink_OBJECTS) $(net__decode_fds_path_netlink_DEPENDENCIES) $(EXTRA_net__decode_fds_path_netlink_DEPENDENCIES) 
+	@rm -f net--decode-fds-path-netlink$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(net__decode_fds_path_netlink_OBJECTS) $(net__decode_fds_path_netlink_LDADD) $(LIBS)
+
+net--decode-fds-socket-netlink$(EXEEXT): $(net__decode_fds_socket_netlink_OBJECTS) $(net__decode_fds_socket_netlink_DEPENDENCIES) $(EXTRA_net__decode_fds_socket_netlink_DEPENDENCIES) 
+	@rm -f net--decode-fds-socket-netlink$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(net__decode_fds_socket_netlink_OBJECTS) $(net__decode_fds_socket_netlink_LDADD) $(LIBS)
+
 net-accept-connect$(EXEEXT): $(net_accept_connect_OBJECTS) $(net_accept_connect_DEPENDENCIES) $(EXTRA_net_accept_connect_DEPENDENCIES) 
 	@rm -f net-accept-connect$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(net_accept_connect_OBJECTS) $(net_accept_connect_LDADD) $(LIBS)
@@ -6953,6 +8571,10 @@ net-sockaddr$(EXEEXT): $(net_sockaddr_OB
 	@rm -f net-sockaddr$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(net_sockaddr_OBJECTS) $(net_sockaddr_LDADD) $(LIBS)
 
+net-sockaddr--pidns-translation$(EXEEXT): $(net_sockaddr__pidns_translation_OBJECTS) $(net_sockaddr__pidns_translation_DEPENDENCIES) $(EXTRA_net_sockaddr__pidns_translation_DEPENDENCIES) 
+	@rm -f net-sockaddr--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(net_sockaddr__pidns_translation_OBJECTS) $(net_sockaddr__pidns_translation_LDADD) $(LIBS)
+
 net-tpacket_req$(EXEEXT): $(net_tpacket_req_OBJECTS) $(net_tpacket_req_DEPENDENCIES) $(EXTRA_net_tpacket_req_DEPENDENCIES) 
 	@rm -f net-tpacket_req$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(net_tpacket_req_OBJECTS) $(net_tpacket_req_LDADD) $(LIBS)
@@ -6989,6 +8611,10 @@ netlink_audit$(EXEEXT): $(netlink_audit_
 	@rm -f netlink_audit$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(netlink_audit_OBJECTS) $(netlink_audit_LDADD) $(LIBS)
 
+netlink_audit--pidns-translation$(EXEEXT): $(netlink_audit__pidns_translation_OBJECTS) $(netlink_audit__pidns_translation_DEPENDENCIES) $(EXTRA_netlink_audit__pidns_translation_DEPENDENCIES) 
+	@rm -f netlink_audit--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(netlink_audit__pidns_translation_OBJECTS) $(netlink_audit__pidns_translation_LDADD) $(LIBS)
+
 netlink_crypto$(EXEEXT): $(netlink_crypto_OBJECTS) $(netlink_crypto_DEPENDENCIES) $(EXTRA_netlink_crypto_DEPENDENCIES) 
 	@rm -f netlink_crypto$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(netlink_crypto_OBJECTS) $(netlink_crypto_LDADD) $(LIBS)
@@ -7137,6 +8763,10 @@ nlattr_ifla_xdp$(EXEEXT): $(nlattr_ifla_
 	@rm -f nlattr_ifla_xdp$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(nlattr_ifla_xdp_OBJECTS) $(nlattr_ifla_xdp_LDADD) $(LIBS)
 
+nlattr_ifla_xdp-y$(EXEEXT): $(nlattr_ifla_xdp_y_OBJECTS) $(nlattr_ifla_xdp_y_DEPENDENCIES) $(EXTRA_nlattr_ifla_xdp_y_DEPENDENCIES) 
+	@rm -f nlattr_ifla_xdp-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(nlattr_ifla_xdp_y_OBJECTS) $(nlattr_ifla_xdp_y_LDADD) $(LIBS)
+
 nlattr_inet_diag_msg$(EXEEXT): $(nlattr_inet_diag_msg_OBJECTS) $(nlattr_inet_diag_msg_DEPENDENCIES) $(EXTRA_nlattr_inet_diag_msg_DEPENDENCIES) 
 	@rm -f nlattr_inet_diag_msg$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(nlattr_inet_diag_msg_OBJECTS) $(nlattr_inet_diag_msg_LDADD) $(LIBS)
@@ -7289,6 +8919,46 @@ openat$(EXEEXT): $(openat_OBJECTS) $(ope
 	@rm -f openat$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(openat_OBJECTS) $(openat_LDADD) $(LIBS)
 
+openat2$(EXEEXT): $(openat2_OBJECTS) $(openat2_DEPENDENCIES) $(EXTRA_openat2_DEPENDENCIES) 
+	@rm -f openat2$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_OBJECTS) $(openat2_LDADD) $(LIBS)
+
+openat2-Xabbrev$(EXEEXT): $(openat2_Xabbrev_OBJECTS) $(openat2_Xabbrev_DEPENDENCIES) $(EXTRA_openat2_Xabbrev_DEPENDENCIES) 
+	@rm -f openat2-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_Xabbrev_OBJECTS) $(openat2_Xabbrev_LDADD) $(LIBS)
+
+openat2-Xraw$(EXEEXT): $(openat2_Xraw_OBJECTS) $(openat2_Xraw_DEPENDENCIES) $(EXTRA_openat2_Xraw_DEPENDENCIES) 
+	@rm -f openat2-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_Xraw_OBJECTS) $(openat2_Xraw_LDADD) $(LIBS)
+
+openat2-Xverbose$(EXEEXT): $(openat2_Xverbose_OBJECTS) $(openat2_Xverbose_DEPENDENCIES) $(EXTRA_openat2_Xverbose_DEPENDENCIES) 
+	@rm -f openat2-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_Xverbose_OBJECTS) $(openat2_Xverbose_LDADD) $(LIBS)
+
+openat2-v$(EXEEXT): $(openat2_v_OBJECTS) $(openat2_v_DEPENDENCIES) $(EXTRA_openat2_v_DEPENDENCIES) 
+	@rm -f openat2-v$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_v_OBJECTS) $(openat2_v_LDADD) $(LIBS)
+
+openat2-v-y$(EXEEXT): $(openat2_v_y_OBJECTS) $(openat2_v_y_DEPENDENCIES) $(EXTRA_openat2_v_y_DEPENDENCIES) 
+	@rm -f openat2-v-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_v_y_OBJECTS) $(openat2_v_y_LDADD) $(LIBS)
+
+openat2-v-y-Xabbrev$(EXEEXT): $(openat2_v_y_Xabbrev_OBJECTS) $(openat2_v_y_Xabbrev_DEPENDENCIES) $(EXTRA_openat2_v_y_Xabbrev_DEPENDENCIES) 
+	@rm -f openat2-v-y-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_v_y_Xabbrev_OBJECTS) $(openat2_v_y_Xabbrev_LDADD) $(LIBS)
+
+openat2-v-y-Xraw$(EXEEXT): $(openat2_v_y_Xraw_OBJECTS) $(openat2_v_y_Xraw_DEPENDENCIES) $(EXTRA_openat2_v_y_Xraw_DEPENDENCIES) 
+	@rm -f openat2-v-y-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_v_y_Xraw_OBJECTS) $(openat2_v_y_Xraw_LDADD) $(LIBS)
+
+openat2-v-y-Xverbose$(EXEEXT): $(openat2_v_y_Xverbose_OBJECTS) $(openat2_v_y_Xverbose_DEPENDENCIES) $(EXTRA_openat2_v_y_Xverbose_DEPENDENCIES) 
+	@rm -f openat2-v-y-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_v_y_Xverbose_OBJECTS) $(openat2_v_y_Xverbose_LDADD) $(LIBS)
+
+openat2-y$(EXEEXT): $(openat2_y_OBJECTS) $(openat2_y_DEPENDENCIES) $(EXTRA_openat2_y_DEPENDENCIES) 
+	@rm -f openat2-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_y_OBJECTS) $(openat2_y_LDADD) $(LIBS)
+
 orphaned_process_group$(EXEEXT): $(orphaned_process_group_OBJECTS) $(orphaned_process_group_DEPENDENCIES) $(EXTRA_orphaned_process_group_DEPENDENCIES) 
 	@rm -f orphaned_process_group$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(orphaned_process_group_OBJECTS) $(orphaned_process_group_LDADD) $(LIBS)
@@ -7333,10 +9003,38 @@ personality-Xverbose$(EXEEXT): $(persona
 	@rm -f personality-Xverbose$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(personality_Xverbose_OBJECTS) $(personality_Xverbose_LDADD) $(LIBS)
 
+pidfd_getfd$(EXEEXT): $(pidfd_getfd_OBJECTS) $(pidfd_getfd_DEPENDENCIES) $(EXTRA_pidfd_getfd_DEPENDENCIES) 
+	@rm -f pidfd_getfd$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_getfd_OBJECTS) $(pidfd_getfd_LDADD) $(LIBS)
+
+pidfd_getfd-y$(EXEEXT): $(pidfd_getfd_y_OBJECTS) $(pidfd_getfd_y_DEPENDENCIES) $(EXTRA_pidfd_getfd_y_DEPENDENCIES) 
+	@rm -f pidfd_getfd-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_getfd_y_OBJECTS) $(pidfd_getfd_y_LDADD) $(LIBS)
+
+pidfd_getfd-yy$(EXEEXT): $(pidfd_getfd_yy_OBJECTS) $(pidfd_getfd_yy_DEPENDENCIES) $(EXTRA_pidfd_getfd_yy_DEPENDENCIES) 
+	@rm -f pidfd_getfd-yy$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_getfd_yy_OBJECTS) $(pidfd_getfd_yy_LDADD) $(LIBS)
+
 pidfd_open$(EXEEXT): $(pidfd_open_OBJECTS) $(pidfd_open_DEPENDENCIES) $(EXTRA_pidfd_open_DEPENDENCIES) 
 	@rm -f pidfd_open$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(pidfd_open_OBJECTS) $(pidfd_open_LDADD) $(LIBS)
 
+pidfd_open--decode-fd-path$(EXEEXT): $(pidfd_open__decode_fd_path_OBJECTS) $(pidfd_open__decode_fd_path_DEPENDENCIES) $(EXTRA_pidfd_open__decode_fd_path_DEPENDENCIES) 
+	@rm -f pidfd_open--decode-fd-path$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_open__decode_fd_path_OBJECTS) $(pidfd_open__decode_fd_path_LDADD) $(LIBS)
+
+pidfd_open--decode-fd-pidfd$(EXEEXT): $(pidfd_open__decode_fd_pidfd_OBJECTS) $(pidfd_open__decode_fd_pidfd_DEPENDENCIES) $(EXTRA_pidfd_open__decode_fd_pidfd_DEPENDENCIES) 
+	@rm -f pidfd_open--decode-fd-pidfd$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_open__decode_fd_pidfd_OBJECTS) $(pidfd_open__decode_fd_pidfd_LDADD) $(LIBS)
+
+pidfd_open--decode-fd-socket$(EXEEXT): $(pidfd_open__decode_fd_socket_OBJECTS) $(pidfd_open__decode_fd_socket_DEPENDENCIES) $(EXTRA_pidfd_open__decode_fd_socket_DEPENDENCIES) 
+	@rm -f pidfd_open--decode-fd-socket$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_open__decode_fd_socket_OBJECTS) $(pidfd_open__decode_fd_socket_LDADD) $(LIBS)
+
+pidfd_open--pidns-translation$(EXEEXT): $(pidfd_open__pidns_translation_OBJECTS) $(pidfd_open__pidns_translation_DEPENDENCIES) $(EXTRA_pidfd_open__pidns_translation_DEPENDENCIES) 
+	@rm -f pidfd_open--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_open__pidns_translation_OBJECTS) $(pidfd_open__pidns_translation_LDADD) $(LIBS)
+
 pidfd_open-P$(EXEEXT): $(pidfd_open_P_OBJECTS) $(pidfd_open_P_DEPENDENCIES) $(EXTRA_pidfd_open_P_DEPENDENCIES) 
 	@rm -f pidfd_open-P$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(pidfd_open_P_OBJECTS) $(pidfd_open_P_LDADD) $(LIBS)
@@ -7345,10 +9043,22 @@ pidfd_open-y$(EXEEXT): $(pidfd_open_y_OB
 	@rm -f pidfd_open-y$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(pidfd_open_y_OBJECTS) $(pidfd_open_y_LDADD) $(LIBS)
 
+pidfd_open-yy$(EXEEXT): $(pidfd_open_yy_OBJECTS) $(pidfd_open_yy_DEPENDENCIES) $(EXTRA_pidfd_open_yy_DEPENDENCIES) 
+	@rm -f pidfd_open-yy$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_open_yy_OBJECTS) $(pidfd_open_yy_LDADD) $(LIBS)
+
 pidfd_send_signal$(EXEEXT): $(pidfd_send_signal_OBJECTS) $(pidfd_send_signal_DEPENDENCIES) $(EXTRA_pidfd_send_signal_DEPENDENCIES) 
 	@rm -f pidfd_send_signal$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(pidfd_send_signal_OBJECTS) $(pidfd_send_signal_LDADD) $(LIBS)
 
+pidfd_send_signal--pidns-translation$(EXEEXT): $(pidfd_send_signal__pidns_translation_OBJECTS) $(pidfd_send_signal__pidns_translation_DEPENDENCIES) $(EXTRA_pidfd_send_signal__pidns_translation_DEPENDENCIES) 
+	@rm -f pidfd_send_signal--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_send_signal__pidns_translation_OBJECTS) $(pidfd_send_signal__pidns_translation_LDADD) $(LIBS)
+
+pidns-cache$(EXEEXT): $(pidns_cache_OBJECTS) $(pidns_cache_DEPENDENCIES) $(EXTRA_pidns_cache_DEPENDENCIES) 
+	@rm -f pidns-cache$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidns_cache_OBJECTS) $(pidns_cache_LDADD) $(LIBS)
+
 pipe$(EXEEXT): $(pipe_OBJECTS) $(pipe_DEPENDENCIES) $(EXTRA_pipe_DEPENDENCIES) 
 	@rm -f pipe$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(pipe_OBJECTS) $(pipe_LDADD) $(LIBS)
@@ -7453,6 +9163,10 @@ print_maxfd$(EXEEXT): $(print_maxfd_OBJE
 	@rm -f print_maxfd$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(print_maxfd_OBJECTS) $(print_maxfd_LDADD) $(LIBS)
 
+print_ppid_tracerpid$(EXEEXT): $(print_ppid_tracerpid_OBJECTS) $(print_ppid_tracerpid_DEPENDENCIES) $(EXTRA_print_ppid_tracerpid_DEPENDENCIES) 
+	@rm -f print_ppid_tracerpid$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(print_ppid_tracerpid_OBJECTS) $(print_ppid_tracerpid_LDADD) $(LIBS)
+
 printpath-umovestr$(EXEEXT): $(printpath_umovestr_OBJECTS) $(printpath_umovestr_DEPENDENCIES) $(EXTRA_printpath_umovestr_DEPENDENCIES) 
 	@rm -f printpath-umovestr$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(printpath_umovestr_OBJECTS) $(printpath_umovestr_LDADD) $(LIBS)
@@ -7497,14 +9211,26 @@ prlimit64$(EXEEXT): $(prlimit64_OBJECTS)
 	@rm -f prlimit64$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(prlimit64_OBJECTS) $(prlimit64_LDADD) $(LIBS)
 
+prlimit64--pidns-translation$(EXEEXT): $(prlimit64__pidns_translation_OBJECTS) $(prlimit64__pidns_translation_DEPENDENCIES) $(EXTRA_prlimit64__pidns_translation_DEPENDENCIES) 
+	@rm -f prlimit64--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(prlimit64__pidns_translation_OBJECTS) $(prlimit64__pidns_translation_LDADD) $(LIBS)
+
 process_vm_readv$(EXEEXT): $(process_vm_readv_OBJECTS) $(process_vm_readv_DEPENDENCIES) $(EXTRA_process_vm_readv_DEPENDENCIES) 
 	@rm -f process_vm_readv$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(process_vm_readv_OBJECTS) $(process_vm_readv_LDADD) $(LIBS)
 
+process_vm_readv--pidns-translation$(EXEEXT): $(process_vm_readv__pidns_translation_OBJECTS) $(process_vm_readv__pidns_translation_DEPENDENCIES) $(EXTRA_process_vm_readv__pidns_translation_DEPENDENCIES) 
+	@rm -f process_vm_readv--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(process_vm_readv__pidns_translation_OBJECTS) $(process_vm_readv__pidns_translation_LDADD) $(LIBS)
+
 process_vm_writev$(EXEEXT): $(process_vm_writev_OBJECTS) $(process_vm_writev_DEPENDENCIES) $(EXTRA_process_vm_writev_DEPENDENCIES) 
 	@rm -f process_vm_writev$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(process_vm_writev_OBJECTS) $(process_vm_writev_LDADD) $(LIBS)
 
+process_vm_writev--pidns-translation$(EXEEXT): $(process_vm_writev__pidns_translation_OBJECTS) $(process_vm_writev__pidns_translation_DEPENDENCIES) $(EXTRA_process_vm_writev__pidns_translation_DEPENDENCIES) 
+	@rm -f process_vm_writev--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(process_vm_writev__pidns_translation_OBJECTS) $(process_vm_writev__pidns_translation_LDADD) $(LIBS)
+
 pselect6$(EXEEXT): $(pselect6_OBJECTS) $(pselect6_DEPENDENCIES) $(EXTRA_pselect6_DEPENDENCIES) 
 	@rm -f pselect6$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(pselect6_OBJECTS) $(pselect6_LDADD) $(LIBS)
@@ -7697,6 +9423,10 @@ rt_sigqueueinfo$(EXEEXT): $(rt_sigqueuei
 	@rm -f rt_sigqueueinfo$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(rt_sigqueueinfo_OBJECTS) $(rt_sigqueueinfo_LDADD) $(LIBS)
 
+rt_sigqueueinfo--pidns-translation$(EXEEXT): $(rt_sigqueueinfo__pidns_translation_OBJECTS) $(rt_sigqueueinfo__pidns_translation_DEPENDENCIES) $(EXTRA_rt_sigqueueinfo__pidns_translation_DEPENDENCIES) 
+	@rm -f rt_sigqueueinfo--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(rt_sigqueueinfo__pidns_translation_OBJECTS) $(rt_sigqueueinfo__pidns_translation_LDADD) $(LIBS)
+
 rt_sigreturn$(EXEEXT): $(rt_sigreturn_OBJECTS) $(rt_sigreturn_DEPENDENCIES) $(EXTRA_rt_sigreturn_DEPENDENCIES) 
 	@rm -f rt_sigreturn$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(rt_sigreturn_OBJECTS) $(rt_sigreturn_LDADD) $(LIBS)
@@ -7713,6 +9443,10 @@ rt_tgsigqueueinfo$(EXEEXT): $(rt_tgsigqu
 	@rm -f rt_tgsigqueueinfo$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(rt_tgsigqueueinfo_OBJECTS) $(rt_tgsigqueueinfo_LDADD) $(LIBS)
 
+rt_tgsigqueueinfo--pidns-translation$(EXEEXT): $(rt_tgsigqueueinfo__pidns_translation_OBJECTS) $(rt_tgsigqueueinfo__pidns_translation_DEPENDENCIES) $(EXTRA_rt_tgsigqueueinfo__pidns_translation_DEPENDENCIES) 
+	@rm -f rt_tgsigqueueinfo--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(rt_tgsigqueueinfo__pidns_translation_OBJECTS) $(rt_tgsigqueueinfo__pidns_translation_LDADD) $(LIBS)
+
 run_expect_termsig$(EXEEXT): $(run_expect_termsig_OBJECTS) $(run_expect_termsig_DEPENDENCIES) $(EXTRA_run_expect_termsig_DEPENDENCIES) 
 	@rm -f run_expect_termsig$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(run_expect_termsig_OBJECTS) $(run_expect_termsig_LDADD) $(LIBS)
@@ -7753,18 +9487,34 @@ sched_xetaffinity$(EXEEXT): $(sched_xeta
 	@rm -f sched_xetaffinity$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(sched_xetaffinity_OBJECTS) $(sched_xetaffinity_LDADD) $(LIBS)
 
+sched_xetaffinity--pidns-translation$(EXEEXT): $(sched_xetaffinity__pidns_translation_OBJECTS) $(sched_xetaffinity__pidns_translation_DEPENDENCIES) $(EXTRA_sched_xetaffinity__pidns_translation_DEPENDENCIES) 
+	@rm -f sched_xetaffinity--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(sched_xetaffinity__pidns_translation_OBJECTS) $(sched_xetaffinity__pidns_translation_LDADD) $(LIBS)
+
 sched_xetattr$(EXEEXT): $(sched_xetattr_OBJECTS) $(sched_xetattr_DEPENDENCIES) $(EXTRA_sched_xetattr_DEPENDENCIES) 
 	@rm -f sched_xetattr$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(sched_xetattr_OBJECTS) $(sched_xetattr_LDADD) $(LIBS)
 
+sched_xetattr--pidns-translation$(EXEEXT): $(sched_xetattr__pidns_translation_OBJECTS) $(sched_xetattr__pidns_translation_DEPENDENCIES) $(EXTRA_sched_xetattr__pidns_translation_DEPENDENCIES) 
+	@rm -f sched_xetattr--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(sched_xetattr__pidns_translation_OBJECTS) $(sched_xetattr__pidns_translation_LDADD) $(LIBS)
+
 sched_xetparam$(EXEEXT): $(sched_xetparam_OBJECTS) $(sched_xetparam_DEPENDENCIES) $(EXTRA_sched_xetparam_DEPENDENCIES) 
 	@rm -f sched_xetparam$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(sched_xetparam_OBJECTS) $(sched_xetparam_LDADD) $(LIBS)
 
+sched_xetparam--pidns-translation$(EXEEXT): $(sched_xetparam__pidns_translation_OBJECTS) $(sched_xetparam__pidns_translation_DEPENDENCIES) $(EXTRA_sched_xetparam__pidns_translation_DEPENDENCIES) 
+	@rm -f sched_xetparam--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(sched_xetparam__pidns_translation_OBJECTS) $(sched_xetparam__pidns_translation_LDADD) $(LIBS)
+
 sched_xetscheduler$(EXEEXT): $(sched_xetscheduler_OBJECTS) $(sched_xetscheduler_DEPENDENCIES) $(EXTRA_sched_xetscheduler_DEPENDENCIES) 
 	@rm -f sched_xetscheduler$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(sched_xetscheduler_OBJECTS) $(sched_xetscheduler_LDADD) $(LIBS)
 
+sched_xetscheduler--pidns-translation$(EXEEXT): $(sched_xetscheduler__pidns_translation_OBJECTS) $(sched_xetscheduler__pidns_translation_DEPENDENCIES) $(EXTRA_sched_xetscheduler__pidns_translation_DEPENDENCIES) 
+	@rm -f sched_xetscheduler--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(sched_xetscheduler__pidns_translation_OBJECTS) $(sched_xetscheduler__pidns_translation_LDADD) $(LIBS)
+
 sched_yield$(EXEEXT): $(sched_yield_OBJECTS) $(sched_yield_DEPENDENCIES) $(EXTRA_sched_yield_DEPENDENCIES) 
 	@rm -f sched_yield$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(sched_yield_OBJECTS) $(sched_yield_LDADD) $(LIBS)
@@ -7889,6 +9639,10 @@ setns$(EXEEXT): $(setns_OBJECTS) $(setns
 	@rm -f setns$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(setns_OBJECTS) $(setns_LDADD) $(LIBS)
 
+setpgrp-exec$(EXEEXT): $(setpgrp_exec_OBJECTS) $(setpgrp_exec_DEPENDENCIES) $(EXTRA_setpgrp_exec_DEPENDENCIES) 
+	@rm -f setpgrp-exec$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(setpgrp_exec_OBJECTS) $(setpgrp_exec_LDADD) $(LIBS)
+
 setregid$(EXEEXT): $(setregid_OBJECTS) $(setregid_DEPENDENCIES) $(EXTRA_setregid_DEPENDENCIES) 
 	@rm -f setregid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(setregid_OBJECTS) $(setregid_LDADD) $(LIBS)
@@ -7973,6 +9727,10 @@ signal_receive$(EXEEXT): $(signal_receiv
 	@rm -f signal_receive$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(signal_receive_OBJECTS) $(signal_receive_LDADD) $(LIBS)
 
+signal_receive--pidns-translation$(EXEEXT): $(signal_receive__pidns_translation_OBJECTS) $(signal_receive__pidns_translation_DEPENDENCIES) $(EXTRA_signal_receive__pidns_translation_DEPENDENCIES) 
+	@rm -f signal_receive--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(signal_receive__pidns_translation_OBJECTS) $(signal_receive__pidns_translation_LDADD) $(LIBS)
+
 signalfd4$(EXEEXT): $(signalfd4_OBJECTS) $(signalfd4_DEPENDENCIES) $(EXTRA_signalfd4_DEPENDENCIES) 
 	@rm -f signalfd4$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(signalfd4_OBJECTS) $(signalfd4_LDADD) $(LIBS)
@@ -8009,6 +9767,10 @@ so_peercred$(EXEEXT): $(so_peercred_OBJE
 	@rm -f so_peercred$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(so_peercred_OBJECTS) $(so_peercred_LDADD) $(LIBS)
 
+so_peercred--pidns-translation$(EXEEXT): $(so_peercred__pidns_translation_OBJECTS) $(so_peercred__pidns_translation_DEPENDENCIES) $(EXTRA_so_peercred__pidns_translation_DEPENDENCIES) 
+	@rm -f so_peercred--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(so_peercred__pidns_translation_OBJECTS) $(so_peercred__pidns_translation_LDADD) $(LIBS)
+
 so_peercred-Xabbrev$(EXEEXT): $(so_peercred_Xabbrev_OBJECTS) $(so_peercred_Xabbrev_DEPENDENCIES) $(EXTRA_so_peercred_Xabbrev_DEPENDENCIES) 
 	@rm -f so_peercred-Xabbrev$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(so_peercred_Xabbrev_OBJECTS) $(so_peercred_Xabbrev_LDADD) $(LIBS)
@@ -8101,6 +9863,14 @@ status-failed$(EXEEXT): $(status_failed_
 	@rm -f status-failed$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(status_failed_OBJECTS) $(status_failed_LDADD) $(LIBS)
 
+status-failed-long$(EXEEXT): $(status_failed_long_OBJECTS) $(status_failed_long_DEPENDENCIES) $(EXTRA_status_failed_long_DEPENDENCIES) 
+	@rm -f status-failed-long$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(status_failed_long_OBJECTS) $(status_failed_long_LDADD) $(LIBS)
+
+status-failed-status$(EXEEXT): $(status_failed_status_OBJECTS) $(status_failed_status_DEPENDENCIES) $(EXTRA_status_failed_status_DEPENDENCIES) 
+	@rm -f status-failed-status$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(status_failed_status_OBJECTS) $(status_failed_status_LDADD) $(LIBS)
+
 status-none$(EXEEXT): $(status_none_OBJECTS) $(status_none_DEPENDENCIES) $(EXTRA_status_none_DEPENDENCIES) 
 	@rm -f status-none$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(status_none_OBJECTS) $(status_none_LDADD) $(LIBS)
@@ -8117,6 +9887,14 @@ status-successful$(EXEEXT): $(status_suc
 	@rm -f status-successful$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(status_successful_OBJECTS) $(status_successful_LDADD) $(LIBS)
 
+status-successful-long$(EXEEXT): $(status_successful_long_OBJECTS) $(status_successful_long_DEPENDENCIES) $(EXTRA_status_successful_long_DEPENDENCIES) 
+	@rm -f status-successful-long$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(status_successful_long_OBJECTS) $(status_successful_long_LDADD) $(LIBS)
+
+status-successful-status$(EXEEXT): $(status_successful_status_OBJECTS) $(status_successful_status_DEPENDENCIES) $(EXTRA_status_successful_status_DEPENDENCIES) 
+	@rm -f status-successful-status$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(status_successful_status_OBJECTS) $(status_successful_status_LDADD) $(LIBS)
+
 status-unfinished$(EXEEXT): $(status_unfinished_OBJECTS) $(status_unfinished_DEPENDENCIES) $(EXTRA_status_unfinished_DEPENDENCIES) 
 	@rm -f status-unfinished$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(status_unfinished_OBJECTS) $(status_unfinished_LDADD) $(LIBS)
@@ -8129,6 +9907,30 @@ statx$(EXEEXT): $(statx_OBJECTS) $(statx
 	@rm -f statx$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(statx_OBJECTS) $(statx_LDADD) $(LIBS)
 
+strace--strings-in-hex$(EXEEXT): $(strace__strings_in_hex_OBJECTS) $(strace__strings_in_hex_DEPENDENCIES) $(EXTRA_strace__strings_in_hex_DEPENDENCIES) 
+	@rm -f strace--strings-in-hex$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(strace__strings_in_hex_OBJECTS) $(strace__strings_in_hex_LDADD) $(LIBS)
+
+strace--strings-in-hex-all$(EXEEXT): $(strace__strings_in_hex_all_OBJECTS) $(strace__strings_in_hex_all_DEPENDENCIES) $(EXTRA_strace__strings_in_hex_all_DEPENDENCIES) 
+	@rm -f strace--strings-in-hex-all$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(strace__strings_in_hex_all_OBJECTS) $(strace__strings_in_hex_all_LDADD) $(LIBS)
+
+strace--strings-in-hex-non-ascii$(EXEEXT): $(strace__strings_in_hex_non_ascii_OBJECTS) $(strace__strings_in_hex_non_ascii_DEPENDENCIES) $(EXTRA_strace__strings_in_hex_non_ascii_DEPENDENCIES) 
+	@rm -f strace--strings-in-hex-non-ascii$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(strace__strings_in_hex_non_ascii_OBJECTS) $(strace__strings_in_hex_non_ascii_LDADD) $(LIBS)
+
+strace-n$(EXEEXT): $(strace_n_OBJECTS) $(strace_n_DEPENDENCIES) $(EXTRA_strace_n_DEPENDENCIES) 
+	@rm -f strace-n$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(strace_n_OBJECTS) $(strace_n_LDADD) $(LIBS)
+
+strace-x$(EXEEXT): $(strace_x_OBJECTS) $(strace_x_DEPENDENCIES) $(EXTRA_strace_x_DEPENDENCIES) 
+	@rm -f strace-x$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(strace_x_OBJECTS) $(strace_x_LDADD) $(LIBS)
+
+strace-xx$(EXEEXT): $(strace_xx_OBJECTS) $(strace_xx_DEPENDENCIES) $(EXTRA_strace_xx_DEPENDENCIES) 
+	@rm -f strace-xx$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(strace_xx_OBJECTS) $(strace_xx_LDADD) $(LIBS)
+
 swap$(EXEEXT): $(swap_OBJECTS) $(swap_DEPENDENCIES) $(EXTRA_swap_DEPENDENCIES) 
 	@rm -f swap$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(swap_OBJECTS) $(swap_LDADD) $(LIBS)
@@ -8173,10 +9975,34 @@ tee$(EXEEXT): $(tee_OBJECTS) $(tee_DEPEN
 	@rm -f tee$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(tee_OBJECTS) $(tee_LDADD) $(LIBS)
 
+tgkill$(EXEEXT): $(tgkill_OBJECTS) $(tgkill_DEPENDENCIES) $(EXTRA_tgkill_DEPENDENCIES) 
+	@rm -f tgkill$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(tgkill_OBJECTS) $(tgkill_LDADD) $(LIBS)
+
+tgkill--pidns-translation$(EXEEXT): $(tgkill__pidns_translation_OBJECTS) $(tgkill__pidns_translation_DEPENDENCIES) $(EXTRA_tgkill__pidns_translation_DEPENDENCIES) 
+	@rm -f tgkill--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(tgkill__pidns_translation_OBJECTS) $(tgkill__pidns_translation_LDADD) $(LIBS)
+
 threads-execve$(EXEEXT): $(threads_execve_OBJECTS) $(threads_execve_DEPENDENCIES) $(EXTRA_threads_execve_DEPENDENCIES) 
 	@rm -f threads-execve$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(threads_execve_OBJECTS) $(threads_execve_LDADD) $(LIBS)
 
+threads-execve--quiet-thread-execve$(EXEEXT): $(threads_execve__quiet_thread_execve_OBJECTS) $(threads_execve__quiet_thread_execve_DEPENDENCIES) $(EXTRA_threads_execve__quiet_thread_execve_DEPENDENCIES) 
+	@rm -f threads-execve--quiet-thread-execve$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(threads_execve__quiet_thread_execve_OBJECTS) $(threads_execve__quiet_thread_execve_LDADD) $(LIBS)
+
+threads-execve-q$(EXEEXT): $(threads_execve_q_OBJECTS) $(threads_execve_q_DEPENDENCIES) $(EXTRA_threads_execve_q_DEPENDENCIES) 
+	@rm -f threads-execve-q$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(threads_execve_q_OBJECTS) $(threads_execve_q_LDADD) $(LIBS)
+
+threads-execve-qq$(EXEEXT): $(threads_execve_qq_OBJECTS) $(threads_execve_qq_DEPENDENCIES) $(EXTRA_threads_execve_qq_DEPENDENCIES) 
+	@rm -f threads-execve-qq$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(threads_execve_qq_OBJECTS) $(threads_execve_qq_LDADD) $(LIBS)
+
+threads-execve-qqq$(EXEEXT): $(threads_execve_qqq_OBJECTS) $(threads_execve_qqq_DEPENDENCIES) $(EXTRA_threads_execve_qqq_DEPENDENCIES) 
+	@rm -f threads-execve-qqq$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(threads_execve_qqq_OBJECTS) $(threads_execve_qqq_LDADD) $(LIBS)
+
 time$(EXEEXT): $(time_OBJECTS) $(time_DEPENDENCIES) $(EXTRA_time_DEPENDENCIES) 
 	@rm -f time$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(time_OBJECTS) $(time_LDADD) $(LIBS)
@@ -8201,10 +10027,22 @@ times-fail$(EXEEXT): $(times_fail_OBJECT
 	@rm -f times-fail$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(times_fail_OBJECTS) $(times_fail_LDADD) $(LIBS)
 
+tkill$(EXEEXT): $(tkill_OBJECTS) $(tkill_DEPENDENCIES) $(EXTRA_tkill_DEPENDENCIES) 
+	@rm -f tkill$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(tkill_OBJECTS) $(tkill_LDADD) $(LIBS)
+
+tkill--pidns-translation$(EXEEXT): $(tkill__pidns_translation_OBJECTS) $(tkill__pidns_translation_DEPENDENCIES) $(EXTRA_tkill__pidns_translation_DEPENDENCIES) 
+	@rm -f tkill--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(tkill__pidns_translation_OBJECTS) $(tkill__pidns_translation_LDADD) $(LIBS)
+
 tracer_ppid_pgid_sid$(EXEEXT): $(tracer_ppid_pgid_sid_OBJECTS) $(tracer_ppid_pgid_sid_DEPENDENCIES) $(EXTRA_tracer_ppid_pgid_sid_DEPENDENCIES) 
 	@rm -f tracer_ppid_pgid_sid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(tracer_ppid_pgid_sid_OBJECTS) $(tracer_ppid_pgid_sid_LDADD) $(LIBS)
 
+trie_test$(EXEEXT): $(trie_test_OBJECTS) $(trie_test_DEPENDENCIES) $(EXTRA_trie_test_DEPENDENCIES) 
+	@rm -f trie_test$(EXEEXT)
+	$(AM_V_CCLD)$(trie_test_LINK) $(trie_test_OBJECTS) $(trie_test_LDADD) $(LIBS)
+
 truncate$(EXEEXT): $(truncate_OBJECTS) $(truncate_DEPENDENCIES) $(EXTRA_truncate_DEPENDENCIES) 
 	@rm -f truncate$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(truncate_OBJECTS) $(truncate_LDADD) $(LIBS)
@@ -8257,6 +10095,10 @@ umovestr_cached$(EXEEXT): $(umovestr_cac
 	@rm -f umovestr_cached$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(umovestr_cached_OBJECTS) $(umovestr_cached_LDADD) $(LIBS)
 
+umovestr_cached_adjacent$(EXEEXT): $(umovestr_cached_adjacent_OBJECTS) $(umovestr_cached_adjacent_DEPENDENCIES) $(EXTRA_umovestr_cached_adjacent_DEPENDENCIES) 
+	@rm -f umovestr_cached_adjacent$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(umovestr_cached_adjacent_OBJECTS) $(umovestr_cached_adjacent_LDADD) $(LIBS)
+
 uname$(EXEEXT): $(uname_OBJECTS) $(uname_DEPENDENCIES) $(EXTRA_uname_DEPENDENCIES) 
 	@rm -f uname$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(uname_OBJECTS) $(uname_LDADD) $(LIBS)
@@ -8361,6 +10203,10 @@ xet_robust_list$(EXEEXT): $(xet_robust_l
 	@rm -f xet_robust_list$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(xet_robust_list_OBJECTS) $(xet_robust_list_LDADD) $(LIBS)
 
+xet_robust_list--pidns-translation$(EXEEXT): $(xet_robust_list__pidns_translation_OBJECTS) $(xet_robust_list__pidns_translation_DEPENDENCIES) $(EXTRA_xet_robust_list__pidns_translation_DEPENDENCIES) 
+	@rm -f xet_robust_list--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(xet_robust_list__pidns_translation_OBJECTS) $(xet_robust_list__pidns_translation_LDADD) $(LIBS)
+
 xet_thread_area_x86$(EXEEXT): $(xet_thread_area_x86_OBJECTS) $(xet_thread_area_x86_DEPENDENCIES) $(EXTRA_xet_thread_area_x86_DEPENDENCIES) 
 	@rm -f xet_thread_area_x86$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(xet_thread_area_x86_OBJECTS) $(xet_thread_area_x86_LDADD) $(LIBS)
@@ -8373,10 +10219,18 @@ xetpgid$(EXEEXT): $(xetpgid_OBJECTS) $(x
 	@rm -f xetpgid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(xetpgid_OBJECTS) $(xetpgid_LDADD) $(LIBS)
 
+xetpgid--pidns-translation$(EXEEXT): $(xetpgid__pidns_translation_OBJECTS) $(xetpgid__pidns_translation_DEPENDENCIES) $(EXTRA_xetpgid__pidns_translation_DEPENDENCIES) 
+	@rm -f xetpgid--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(xetpgid__pidns_translation_OBJECTS) $(xetpgid__pidns_translation_LDADD) $(LIBS)
+
 xetpriority$(EXEEXT): $(xetpriority_OBJECTS) $(xetpriority_DEPENDENCIES) $(EXTRA_xetpriority_DEPENDENCIES) 
 	@rm -f xetpriority$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(xetpriority_OBJECTS) $(xetpriority_LDADD) $(LIBS)
 
+xetpriority--pidns-translation$(EXEEXT): $(xetpriority__pidns_translation_OBJECTS) $(xetpriority__pidns_translation_DEPENDENCIES) $(EXTRA_xetpriority__pidns_translation_DEPENDENCIES) 
+	@rm -f xetpriority--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(xetpriority__pidns_translation_OBJECTS) $(xetpriority__pidns_translation_LDADD) $(LIBS)
+
 xettimeofday$(EXEEXT): $(xettimeofday_OBJECTS) $(xettimeofday_DEPENDENCIES) $(EXTRA_xettimeofday_DEPENDENCIES) 
 	@rm -f xettimeofday$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(xettimeofday_OBJECTS) $(xettimeofday_LDADD) $(LIBS)
@@ -8413,6 +10267,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/bpf-obj_get_info_by_fd-prog.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/bpf-obj_get_info_by_fd-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/bpf-obj_get_info_by_fd.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/bpf-success-long-y.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/bpf-success-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/bpf-success.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/bpf-v.Po@am__quote@ # am--include-marker
@@ -8439,16 +10294,39 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone3-success-Xverbose.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone3-success.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone3.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_parent--quiet-exit.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_parent-q.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_parent-qq.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_parent.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_ptrace--quiet-attach.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_ptrace--quiet-exit.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_ptrace-q.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_ptrace-qq.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_ptrace.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/close_range-P.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/close_range-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/close_range-yy.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/close_range.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/copy_file_range.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/count-f.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/creat.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/delay.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/delete_module.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dev--decode-fds-dev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dev--decode-fds-path.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dev--decode-fds-socket.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dev-yy.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup-P.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup-yy.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup2-P.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup2-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup2-yy.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup2.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup3-P.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup3-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup3-yy.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup3.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/epoll_create.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/epoll_create1.Po@am__quote@ # am--include-marker
@@ -8461,7 +10339,14 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/execve.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/execveat-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/execveat.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/faccessat-P.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/faccessat-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/faccessat-yy.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/faccessat.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/faccessat2-P.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/faccessat2-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/faccessat2-yy.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/faccessat2.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fadvise64.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fadvise64_64.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fallocate.Po@am__quote@ # am--include-marker
@@ -8476,7 +10361,9 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fchown.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fchown32.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fchownat.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fcntl--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fcntl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fcntl64--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fcntl64.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fdatasync.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fflush.Po@am__quote@ # am--include-marker
@@ -8487,6 +10374,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/filter_seccomp-perf.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/finit_module.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/flock.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fork--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fork-f.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fsconfig-P.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fsconfig.Po@am__quote@ # am--include-marker
@@ -8512,9 +10400,12 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/futex.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/futimesat.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/get_mempolicy.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/get_process_reaper.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getcpu.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getcwd.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getdents-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getdents.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getdents64-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getdents64.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getegid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getegid32.Po@am__quote@ # am--include-marker
@@ -8525,7 +10416,9 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getgroups.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getgroups32.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getpeername.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getpgrp--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getpgrp.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getpid--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getpid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getppid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getrandom.Po@am__quote@ # am--include-marker
@@ -8535,12 +10428,16 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getresuid32.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getrlimit.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getrusage.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getsid--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getsid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getsockname.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/gettid--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/gettid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getuid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getuid32.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getxxid.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getxgid.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getxpid.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getxuid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/group_req.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/inet-cmsg.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/init_module.Po@am__quote@ # am--include-marker
@@ -8555,6 +10452,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/io_uring_register.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/io_uring_setup.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_block--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_block.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_dm-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_dm.Po@am__quote@ # am--include-marker
@@ -8574,6 +10472,22 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_evdev-v-Xverbose.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_evdev-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_evdev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-success-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-success-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-success-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-success-v-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-success-v-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-success-v-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-success-v.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-success.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-v-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-v-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-v-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-v.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_inotify.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_kvm_run-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_kvm_run.Po@am__quote@ # am--include-marker
@@ -8594,11 +10508,28 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_sg_io_v3.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_sg_io_v4.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_sock_gifconf.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_tee.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_uffdio.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-success-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-success-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-success-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-success-v-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-success-v-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-success-v-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-success-v.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-success.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-v-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-v-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-v-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_watchdog.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioperm.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/iopl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioprio--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioprio-Xabbrev.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioprio-Xraw.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioprio-Xverbose.Po@am__quote@ # am--include-marker
@@ -8622,6 +10553,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipc_shm-Xverbose.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipc_shm.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/is_linux_mips_n64.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/kcmp-y--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/kcmp-y.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/kcmp.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/kern_features.Po@am__quote@ # am--include-marker
@@ -8635,12 +10567,14 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/keyctl-Xraw.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/keyctl-Xverbose.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/keyctl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/kill--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/kill.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/kill_child.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ksysent.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/lchown.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/lchown32.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-create_nl_socket.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-create_tmpfile.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-errno2name.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-error_msg.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-fill_memory.Po@am__quote@ # am--include-marker
@@ -8654,6 +10588,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-libsocketcall.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-lock_file.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-overflowuid.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-pidns.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-pipe_maxfd.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-print_quoted_string.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-print_time.Po@am__quote@ # am--include-marker
@@ -8670,6 +10605,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-test_printstrn.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-test_ucopy.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-tprintf.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-xmalloc_for_tests.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/link.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/linkat.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/list_sigaction_signum.Po@am__quote@ # am--include-marker
@@ -8681,6 +10617,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/lstat.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/lstat64-lstat64.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/madvise.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/maybe_switch_current_tcp--quiet-thread-execve.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/maybe_switch_current_tcp.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/mbind-Xabbrev.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/mbind-Xraw.Po@am__quote@ # am--include-marker
@@ -8691,6 +10628,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/memfd_create-Xraw.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/memfd_create-Xverbose.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/memfd_create.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/migrate_pages--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/migrate_pages.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/mincore.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/mkdir.Po@am__quote@ # am--include-marker
@@ -8719,6 +10657,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/mount.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/move_mount-P.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/move_mount.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/move_pages--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/move_pages-Xabbrev.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/move_pages-Xraw.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/move_pages-Xverbose.Po@am__quote@ # am--include-marker
@@ -8732,12 +10671,17 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/msg_name.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/munlockall.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/nanosleep.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net--decode-fds-dev-netlink.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net--decode-fds-none-netlink.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net--decode-fds-path-netlink.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net--decode-fds-socket-netlink.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-accept-connect.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-icmp_filter.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-packet_mreq-Xabbrev.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-packet_mreq-Xraw.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-packet_mreq-Xverbose.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-packet_mreq.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-sockaddr--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-sockaddr.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-tpacket_req.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-tpacket_stats-success.Po@am__quote@ # am--include-marker
@@ -8747,6 +10691,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-yy-inet6.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-yy-netlink.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-yy-unix.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/netlink_audit--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/netlink_audit.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/netlink_crypto.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/netlink_generic.Po@am__quote@ # am--include-marker
@@ -8784,6 +10729,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/nlattr_ifla_brport.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/nlattr_ifla_linkinfo.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/nlattr_ifla_port.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/nlattr_ifla_xdp-y.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/nlattr_ifla_xdp.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/nlattr_inet_diag_msg.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/nlattr_inet_diag_req_compat.Po@am__quote@ # am--include-marker
@@ -8823,6 +10769,16 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/open_tree-P.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/open_tree.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-v-y-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-v-y-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-v-y-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-v-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-v.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/orphaned_process_group.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/osf_utimes.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pause.Po@am__quote@ # am--include-marker
@@ -8834,10 +10790,20 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/personality-Xraw.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/personality-Xverbose.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/personality.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_getfd-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_getfd-yy.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_getfd.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_open--decode-fd-path.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_open--decode-fd-pidfd.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_open--decode-fd-socket.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_open--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_open-P.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_open-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_open-yy.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_open.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_send_signal--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_send_signal.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidns-cache.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pipe.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pipe2.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pkey_alloc.Po@am__quote@ # am--include-marker
@@ -8864,6 +10830,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/preadv2-pwritev2.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/preadv_pwritev-preadv-pwritev.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/print_maxfd.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/print_ppid_tracerpid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/printpath-umovestr-peekdata.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/printpath-umovestr-undumpable.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/printpath-umovestr.Po@am__quote@ # am--include-marker
@@ -8874,8 +10841,11 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/printstrn-umoven-peekdata.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/printstrn-umoven-undumpable.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/printstrn-umoven.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/prlimit64--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/prlimit64.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/process_vm_readv--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/process_vm_readv.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/process_vm_writev--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/process_vm_writev.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pselect6.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ptrace.Po@am__quote@ # am--include-marker
@@ -8924,10 +10894,12 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_sigaction.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_sigpending.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_sigprocmask.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_sigqueueinfo--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_sigqueueinfo.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_sigreturn.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_sigsuspend.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_sigtimedwait.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_tgsigqueueinfo--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_tgsigqueueinfo.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/run_expect_termsig.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/s390_guarded_storage-v.Po@am__quote@ # am--include-marker
@@ -8938,9 +10910,13 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/s390_sthyi.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_get_priority_mxx.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_rr_get_interval.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_xetaffinity--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_xetaffinity.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_xetattr--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_xetattr.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_xetparam--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_xetparam.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_xetscheduler--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_xetscheduler.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_yield.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/scm_rights.Po@am__quote@ # am--include-marker
@@ -8973,6 +10949,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/setgroups32.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sethostname.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/setns.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/setpgrp-exec.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/setregid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/setregid32.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/setresgid.Po@am__quote@ # am--include-marker
@@ -8993,6 +10970,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sigaltstack.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/siginfo.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/signal.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/signal_receive--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/signal_receive.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/signalfd4.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sigpending.Po@am__quote@ # am--include-marker
@@ -9002,6 +10980,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sleep.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/so_error.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/so_linger.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/so_peercred--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/so_peercred-Xabbrev.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/so_peercred-Xraw.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/so_peercred-Xverbose.Po@am__quote@ # am--include-marker
@@ -9033,14 +11012,24 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/statfs-statfs.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/statfs64.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-all.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-failed-long.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-failed-status.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-failed.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-none-f.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-none-threads.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-none.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-successful-long.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-successful-status.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-successful.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-unfinished-threads.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-unfinished.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/statx.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace--strings-in-hex-all.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace--strings-in-hex-non-ascii.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace--strings-in-hex.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-n.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-x.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-xx.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/swap.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sxetmask.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/symlink.Po@am__quote@ # am--include-marker
@@ -9052,6 +11041,12 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/syslog-success.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/syslog.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/tee.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/tgkill--pidns-translation.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/tgkill.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/threads-execve--quiet-thread-execve.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/threads-execve-q.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/threads-execve-qq.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/threads-execve-qqq.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/threads-execve.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/time.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/timer_create.Po@am__quote@ # am--include-marker
@@ -9059,7 +11054,11 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/timerfd_xettime.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/times-fail.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/times.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/tkill--pidns-translation.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/tkill.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/tracer_ppid_pgid_sid.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/trie_test-trie_for_tests.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/trie_test-trie_test.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/truncate.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/truncate64-truncate64.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ugetrlimit.Po@am__quote@ # am--include-marker
@@ -9073,6 +11072,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/umovestr2.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/umovestr3.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/umovestr_cached.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/umovestr_cached_adjacent.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/uname.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/unblock_reset_raise.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/unix-pair-send-recv.Po@am__quote@ # am--include-marker
@@ -9098,10 +11098,13 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/waitpid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xattr-strings.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xattr.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xet_robust_list--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xet_robust_list.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xet_thread_area_x86.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xetitimer.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xetpgid--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xetpgid.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xetpriority--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xetpriority.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xettimeofday.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/zeroargc.Po@am__quote@ # am--include-marker
@@ -9142,6 +11145,20 @@ libtests_a-create_nl_socket.obj: create_
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
 @am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-create_nl_socket.obj `if test -f 'create_nl_socket.c'; then $(CYGPATH_W) 'create_nl_socket.c'; else $(CYGPATH_W) '$(srcdir)/create_nl_socket.c'; fi`
 
+libtests_a-create_tmpfile.o: create_tmpfile.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT libtests_a-create_tmpfile.o -MD -MP -MF $(DEPDIR)/libtests_a-create_tmpfile.Tpo -c -o libtests_a-create_tmpfile.o `test -f 'create_tmpfile.c' || echo '$(srcdir)/'`create_tmpfile.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libtests_a-create_tmpfile.Tpo $(DEPDIR)/libtests_a-create_tmpfile.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='create_tmpfile.c' object='libtests_a-create_tmpfile.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-create_tmpfile.o `test -f 'create_tmpfile.c' || echo '$(srcdir)/'`create_tmpfile.c
+
+libtests_a-create_tmpfile.obj: create_tmpfile.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT libtests_a-create_tmpfile.obj -MD -MP -MF $(DEPDIR)/libtests_a-create_tmpfile.Tpo -c -o libtests_a-create_tmpfile.obj `if test -f 'create_tmpfile.c'; then $(CYGPATH_W) 'create_tmpfile.c'; else $(CYGPATH_W) '$(srcdir)/create_tmpfile.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libtests_a-create_tmpfile.Tpo $(DEPDIR)/libtests_a-create_tmpfile.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='create_tmpfile.c' object='libtests_a-create_tmpfile.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-create_tmpfile.obj `if test -f 'create_tmpfile.c'; then $(CYGPATH_W) 'create_tmpfile.c'; else $(CYGPATH_W) '$(srcdir)/create_tmpfile.c'; fi`
+
 libtests_a-errno2name.o: errno2name.c
 @am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT libtests_a-errno2name.o -MD -MP -MF $(DEPDIR)/libtests_a-errno2name.Tpo -c -o libtests_a-errno2name.o `test -f 'errno2name.c' || echo '$(srcdir)/'`errno2name.c
 @am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libtests_a-errno2name.Tpo $(DEPDIR)/libtests_a-errno2name.Po
@@ -9324,6 +11341,20 @@ libtests_a-overflowuid.obj: overflowuid.
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
 @am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-overflowuid.obj `if test -f 'overflowuid.c'; then $(CYGPATH_W) 'overflowuid.c'; else $(CYGPATH_W) '$(srcdir)/overflowuid.c'; fi`
 
+libtests_a-pidns.o: pidns.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT libtests_a-pidns.o -MD -MP -MF $(DEPDIR)/libtests_a-pidns.Tpo -c -o libtests_a-pidns.o `test -f 'pidns.c' || echo '$(srcdir)/'`pidns.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libtests_a-pidns.Tpo $(DEPDIR)/libtests_a-pidns.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='pidns.c' object='libtests_a-pidns.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-pidns.o `test -f 'pidns.c' || echo '$(srcdir)/'`pidns.c
+
+libtests_a-pidns.obj: pidns.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT libtests_a-pidns.obj -MD -MP -MF $(DEPDIR)/libtests_a-pidns.Tpo -c -o libtests_a-pidns.obj `if test -f 'pidns.c'; then $(CYGPATH_W) 'pidns.c'; else $(CYGPATH_W) '$(srcdir)/pidns.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libtests_a-pidns.Tpo $(DEPDIR)/libtests_a-pidns.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='pidns.c' object='libtests_a-pidns.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-pidns.obj `if test -f 'pidns.c'; then $(CYGPATH_W) 'pidns.c'; else $(CYGPATH_W) '$(srcdir)/pidns.c'; fi`
+
 libtests_a-pipe_maxfd.o: pipe_maxfd.c
 @am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT libtests_a-pipe_maxfd.o -MD -MP -MF $(DEPDIR)/libtests_a-pipe_maxfd.Tpo -c -o libtests_a-pipe_maxfd.o `test -f 'pipe_maxfd.c' || echo '$(srcdir)/'`pipe_maxfd.c
 @am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libtests_a-pipe_maxfd.Tpo $(DEPDIR)/libtests_a-pipe_maxfd.Po
@@ -9548,6 +11579,20 @@ libtests_a-tprintf.obj: tprintf.c
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
 @am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-tprintf.obj `if test -f 'tprintf.c'; then $(CYGPATH_W) 'tprintf.c'; else $(CYGPATH_W) '$(srcdir)/tprintf.c'; fi`
 
+libtests_a-xmalloc_for_tests.o: xmalloc_for_tests.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT libtests_a-xmalloc_for_tests.o -MD -MP -MF $(DEPDIR)/libtests_a-xmalloc_for_tests.Tpo -c -o libtests_a-xmalloc_for_tests.o `test -f 'xmalloc_for_tests.c' || echo '$(srcdir)/'`xmalloc_for_tests.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libtests_a-xmalloc_for_tests.Tpo $(DEPDIR)/libtests_a-xmalloc_for_tests.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='xmalloc_for_tests.c' object='libtests_a-xmalloc_for_tests.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-xmalloc_for_tests.o `test -f 'xmalloc_for_tests.c' || echo '$(srcdir)/'`xmalloc_for_tests.c
+
+libtests_a-xmalloc_for_tests.obj: xmalloc_for_tests.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT libtests_a-xmalloc_for_tests.obj -MD -MP -MF $(DEPDIR)/libtests_a-xmalloc_for_tests.Tpo -c -o libtests_a-xmalloc_for_tests.obj `if test -f 'xmalloc_for_tests.c'; then $(CYGPATH_W) 'xmalloc_for_tests.c'; else $(CYGPATH_W) '$(srcdir)/xmalloc_for_tests.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libtests_a-xmalloc_for_tests.Tpo $(DEPDIR)/libtests_a-xmalloc_for_tests.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='xmalloc_for_tests.c' object='libtests_a-xmalloc_for_tests.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-xmalloc_for_tests.obj `if test -f 'xmalloc_for_tests.c'; then $(CYGPATH_W) 'xmalloc_for_tests.c'; else $(CYGPATH_W) '$(srcdir)/xmalloc_for_tests.c'; fi`
+
 fstat64-fstat64.o: fstat64.c
 @am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(fstat64_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT fstat64-fstat64.o -MD -MP -MF $(DEPDIR)/fstat64-fstat64.Tpo -c -o fstat64-fstat64.o `test -f 'fstat64.c' || echo '$(srcdir)/'`fstat64.c
 @am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/fstat64-fstat64.Tpo $(DEPDIR)/fstat64-fstat64.Po
@@ -9758,6 +11803,34 @@ statfs-statfs.obj: statfs.c
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
 @am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(statfs_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o statfs-statfs.obj `if test -f 'statfs.c'; then $(CYGPATH_W) 'statfs.c'; else $(CYGPATH_W) '$(srcdir)/statfs.c'; fi`
 
+trie_test-trie_test.o: trie_test.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(trie_test_CPPFLAGS) $(CPPFLAGS) $(trie_test_CFLAGS) $(CFLAGS) -MT trie_test-trie_test.o -MD -MP -MF $(DEPDIR)/trie_test-trie_test.Tpo -c -o trie_test-trie_test.o `test -f 'trie_test.c' || echo '$(srcdir)/'`trie_test.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/trie_test-trie_test.Tpo $(DEPDIR)/trie_test-trie_test.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='trie_test.c' object='trie_test-trie_test.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(trie_test_CPPFLAGS) $(CPPFLAGS) $(trie_test_CFLAGS) $(CFLAGS) -c -o trie_test-trie_test.o `test -f 'trie_test.c' || echo '$(srcdir)/'`trie_test.c
+
+trie_test-trie_test.obj: trie_test.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(trie_test_CPPFLAGS) $(CPPFLAGS) $(trie_test_CFLAGS) $(CFLAGS) -MT trie_test-trie_test.obj -MD -MP -MF $(DEPDIR)/trie_test-trie_test.Tpo -c -o trie_test-trie_test.obj `if test -f 'trie_test.c'; then $(CYGPATH_W) 'trie_test.c'; else $(CYGPATH_W) '$(srcdir)/trie_test.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/trie_test-trie_test.Tpo $(DEPDIR)/trie_test-trie_test.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='trie_test.c' object='trie_test-trie_test.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(trie_test_CPPFLAGS) $(CPPFLAGS) $(trie_test_CFLAGS) $(CFLAGS) -c -o trie_test-trie_test.obj `if test -f 'trie_test.c'; then $(CYGPATH_W) 'trie_test.c'; else $(CYGPATH_W) '$(srcdir)/trie_test.c'; fi`
+
+trie_test-trie_for_tests.o: trie_for_tests.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(trie_test_CPPFLAGS) $(CPPFLAGS) $(trie_test_CFLAGS) $(CFLAGS) -MT trie_test-trie_for_tests.o -MD -MP -MF $(DEPDIR)/trie_test-trie_for_tests.Tpo -c -o trie_test-trie_for_tests.o `test -f 'trie_for_tests.c' || echo '$(srcdir)/'`trie_for_tests.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/trie_test-trie_for_tests.Tpo $(DEPDIR)/trie_test-trie_for_tests.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='trie_for_tests.c' object='trie_test-trie_for_tests.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(trie_test_CPPFLAGS) $(CPPFLAGS) $(trie_test_CFLAGS) $(CFLAGS) -c -o trie_test-trie_for_tests.o `test -f 'trie_for_tests.c' || echo '$(srcdir)/'`trie_for_tests.c
+
+trie_test-trie_for_tests.obj: trie_for_tests.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(trie_test_CPPFLAGS) $(CPPFLAGS) $(trie_test_CFLAGS) $(CFLAGS) -MT trie_test-trie_for_tests.obj -MD -MP -MF $(DEPDIR)/trie_test-trie_for_tests.Tpo -c -o trie_test-trie_for_tests.obj `if test -f 'trie_for_tests.c'; then $(CYGPATH_W) 'trie_for_tests.c'; else $(CYGPATH_W) '$(srcdir)/trie_for_tests.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/trie_test-trie_for_tests.Tpo $(DEPDIR)/trie_test-trie_for_tests.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='trie_for_tests.c' object='trie_test-trie_for_tests.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(trie_test_CPPFLAGS) $(CPPFLAGS) $(trie_test_CFLAGS) $(CFLAGS) -c -o trie_test-trie_for_tests.obj `if test -f 'trie_for_tests.c'; then $(CYGPATH_W) 'trie_for_tests.c'; else $(CYGPATH_W) '$(srcdir)/trie_for_tests.c'; fi`
+
 truncate64-truncate64.o: truncate64.c
 @am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(truncate64_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT truncate64-truncate64.o -MD -MP -MF $(DEPDIR)/truncate64-truncate64.Tpo -c -o truncate64-truncate64.o `test -f 'truncate64.c' || echo '$(srcdir)/'`truncate64.c
 @am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/truncate64-truncate64.Tpo $(DEPDIR)/truncate64-truncate64.Po
@@ -9950,7 +12023,7 @@ $(TEST_SUITE_LOG): $(TEST_LOGS)
 	  test x"$$VERBOSE" = x || cat $(TEST_SUITE_LOG);		\
 	fi;								\
 	echo "$${col}$$br$${std}"; 					\
-	echo "$${col}Testsuite summary for $(PACKAGE_STRING)$${std}";	\
+	echo "$${col}Testsuite summary"$(AM_TESTSUITE_SUMMARY_HEADER)"$${std}";	\
 	echo "$${col}$$br$${std}"; 					\
 	create_testsuite_report --maybe-color;				\
 	echo "$$col$$br$$std";						\
@@ -10123,6 +12196,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/bpf-obj_get_info_by_fd-prog.Po
 	-rm -f ./$(DEPDIR)/bpf-obj_get_info_by_fd-v.Po
 	-rm -f ./$(DEPDIR)/bpf-obj_get_info_by_fd.Po
+	-rm -f ./$(DEPDIR)/bpf-success-long-y.Po
 	-rm -f ./$(DEPDIR)/bpf-success-v.Po
 	-rm -f ./$(DEPDIR)/bpf-success.Po
 	-rm -f ./$(DEPDIR)/bpf-v.Po
@@ -10149,16 +12223,39 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/clone3-success-Xverbose.Po
 	-rm -f ./$(DEPDIR)/clone3-success.Po
 	-rm -f ./$(DEPDIR)/clone3.Po
+	-rm -f ./$(DEPDIR)/clone_parent--quiet-exit.Po
+	-rm -f ./$(DEPDIR)/clone_parent-q.Po
+	-rm -f ./$(DEPDIR)/clone_parent-qq.Po
 	-rm -f ./$(DEPDIR)/clone_parent.Po
+	-rm -f ./$(DEPDIR)/clone_ptrace--quiet-attach.Po
+	-rm -f ./$(DEPDIR)/clone_ptrace--quiet-exit.Po
+	-rm -f ./$(DEPDIR)/clone_ptrace-q.Po
+	-rm -f ./$(DEPDIR)/clone_ptrace-qq.Po
 	-rm -f ./$(DEPDIR)/clone_ptrace.Po
+	-rm -f ./$(DEPDIR)/close_range-P.Po
+	-rm -f ./$(DEPDIR)/close_range-y.Po
+	-rm -f ./$(DEPDIR)/close_range-yy.Po
+	-rm -f ./$(DEPDIR)/close_range.Po
 	-rm -f ./$(DEPDIR)/copy_file_range.Po
 	-rm -f ./$(DEPDIR)/count-f.Po
 	-rm -f ./$(DEPDIR)/creat.Po
 	-rm -f ./$(DEPDIR)/delay.Po
 	-rm -f ./$(DEPDIR)/delete_module.Po
+	-rm -f ./$(DEPDIR)/dev--decode-fds-dev.Po
+	-rm -f ./$(DEPDIR)/dev--decode-fds-path.Po
+	-rm -f ./$(DEPDIR)/dev--decode-fds-socket.Po
 	-rm -f ./$(DEPDIR)/dev-yy.Po
+	-rm -f ./$(DEPDIR)/dup-P.Po
+	-rm -f ./$(DEPDIR)/dup-y.Po
+	-rm -f ./$(DEPDIR)/dup-yy.Po
 	-rm -f ./$(DEPDIR)/dup.Po
+	-rm -f ./$(DEPDIR)/dup2-P.Po
+	-rm -f ./$(DEPDIR)/dup2-y.Po
+	-rm -f ./$(DEPDIR)/dup2-yy.Po
 	-rm -f ./$(DEPDIR)/dup2.Po
+	-rm -f ./$(DEPDIR)/dup3-P.Po
+	-rm -f ./$(DEPDIR)/dup3-y.Po
+	-rm -f ./$(DEPDIR)/dup3-yy.Po
 	-rm -f ./$(DEPDIR)/dup3.Po
 	-rm -f ./$(DEPDIR)/epoll_create.Po
 	-rm -f ./$(DEPDIR)/epoll_create1.Po
@@ -10171,7 +12268,14 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/execve.Po
 	-rm -f ./$(DEPDIR)/execveat-v.Po
 	-rm -f ./$(DEPDIR)/execveat.Po
+	-rm -f ./$(DEPDIR)/faccessat-P.Po
+	-rm -f ./$(DEPDIR)/faccessat-y.Po
+	-rm -f ./$(DEPDIR)/faccessat-yy.Po
 	-rm -f ./$(DEPDIR)/faccessat.Po
+	-rm -f ./$(DEPDIR)/faccessat2-P.Po
+	-rm -f ./$(DEPDIR)/faccessat2-y.Po
+	-rm -f ./$(DEPDIR)/faccessat2-yy.Po
+	-rm -f ./$(DEPDIR)/faccessat2.Po
 	-rm -f ./$(DEPDIR)/fadvise64.Po
 	-rm -f ./$(DEPDIR)/fadvise64_64.Po
 	-rm -f ./$(DEPDIR)/fallocate.Po
@@ -10186,7 +12290,9 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/fchown.Po
 	-rm -f ./$(DEPDIR)/fchown32.Po
 	-rm -f ./$(DEPDIR)/fchownat.Po
+	-rm -f ./$(DEPDIR)/fcntl--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/fcntl.Po
+	-rm -f ./$(DEPDIR)/fcntl64--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/fcntl64.Po
 	-rm -f ./$(DEPDIR)/fdatasync.Po
 	-rm -f ./$(DEPDIR)/fflush.Po
@@ -10197,6 +12303,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/filter_seccomp-perf.Po
 	-rm -f ./$(DEPDIR)/finit_module.Po
 	-rm -f ./$(DEPDIR)/flock.Po
+	-rm -f ./$(DEPDIR)/fork--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/fork-f.Po
 	-rm -f ./$(DEPDIR)/fsconfig-P.Po
 	-rm -f ./$(DEPDIR)/fsconfig.Po
@@ -10222,9 +12329,12 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/futex.Po
 	-rm -f ./$(DEPDIR)/futimesat.Po
 	-rm -f ./$(DEPDIR)/get_mempolicy.Po
+	-rm -f ./$(DEPDIR)/get_process_reaper.Po
 	-rm -f ./$(DEPDIR)/getcpu.Po
 	-rm -f ./$(DEPDIR)/getcwd.Po
+	-rm -f ./$(DEPDIR)/getdents-v.Po
 	-rm -f ./$(DEPDIR)/getdents.Po
+	-rm -f ./$(DEPDIR)/getdents64-v.Po
 	-rm -f ./$(DEPDIR)/getdents64.Po
 	-rm -f ./$(DEPDIR)/getegid.Po
 	-rm -f ./$(DEPDIR)/getegid32.Po
@@ -10235,7 +12345,9 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/getgroups.Po
 	-rm -f ./$(DEPDIR)/getgroups32.Po
 	-rm -f ./$(DEPDIR)/getpeername.Po
+	-rm -f ./$(DEPDIR)/getpgrp--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/getpgrp.Po
+	-rm -f ./$(DEPDIR)/getpid--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/getpid.Po
 	-rm -f ./$(DEPDIR)/getppid.Po
 	-rm -f ./$(DEPDIR)/getrandom.Po
@@ -10245,12 +12357,16 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/getresuid32.Po
 	-rm -f ./$(DEPDIR)/getrlimit.Po
 	-rm -f ./$(DEPDIR)/getrusage.Po
+	-rm -f ./$(DEPDIR)/getsid--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/getsid.Po
 	-rm -f ./$(DEPDIR)/getsockname.Po
+	-rm -f ./$(DEPDIR)/gettid--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/gettid.Po
 	-rm -f ./$(DEPDIR)/getuid.Po
 	-rm -f ./$(DEPDIR)/getuid32.Po
-	-rm -f ./$(DEPDIR)/getxxid.Po
+	-rm -f ./$(DEPDIR)/getxgid.Po
+	-rm -f ./$(DEPDIR)/getxpid.Po
+	-rm -f ./$(DEPDIR)/getxuid.Po
 	-rm -f ./$(DEPDIR)/group_req.Po
 	-rm -f ./$(DEPDIR)/inet-cmsg.Po
 	-rm -f ./$(DEPDIR)/init_module.Po
@@ -10265,6 +12381,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/io_uring_register.Po
 	-rm -f ./$(DEPDIR)/io_uring_setup.Po
 	-rm -f ./$(DEPDIR)/ioctl.Po
+	-rm -f ./$(DEPDIR)/ioctl_block--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/ioctl_block.Po
 	-rm -f ./$(DEPDIR)/ioctl_dm-v.Po
 	-rm -f ./$(DEPDIR)/ioctl_dm.Po
@@ -10284,6 +12401,22 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/ioctl_evdev-v-Xverbose.Po
 	-rm -f ./$(DEPDIR)/ioctl_evdev-v.Po
 	-rm -f ./$(DEPDIR)/ioctl_evdev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-v-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-v-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-v-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-v.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-v-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-v-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-v-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-v.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio.Po
 	-rm -f ./$(DEPDIR)/ioctl_inotify.Po
 	-rm -f ./$(DEPDIR)/ioctl_kvm_run-v.Po
 	-rm -f ./$(DEPDIR)/ioctl_kvm_run.Po
@@ -10304,11 +12437,28 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/ioctl_sg_io_v3.Po
 	-rm -f ./$(DEPDIR)/ioctl_sg_io_v4.Po
 	-rm -f ./$(DEPDIR)/ioctl_sock_gifconf.Po
+	-rm -f ./$(DEPDIR)/ioctl_tee.Po
 	-rm -f ./$(DEPDIR)/ioctl_uffdio.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-v-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-v-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-v-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-v.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-v-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-v-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-v-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-v.Po
 	-rm -f ./$(DEPDIR)/ioctl_v4l2.Po
 	-rm -f ./$(DEPDIR)/ioctl_watchdog.Po
 	-rm -f ./$(DEPDIR)/ioperm.Po
 	-rm -f ./$(DEPDIR)/iopl.Po
+	-rm -f ./$(DEPDIR)/ioprio--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/ioprio-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/ioprio-Xraw.Po
 	-rm -f ./$(DEPDIR)/ioprio-Xverbose.Po
@@ -10332,6 +12482,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/ipc_shm-Xverbose.Po
 	-rm -f ./$(DEPDIR)/ipc_shm.Po
 	-rm -f ./$(DEPDIR)/is_linux_mips_n64.Po
+	-rm -f ./$(DEPDIR)/kcmp-y--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/kcmp-y.Po
 	-rm -f ./$(DEPDIR)/kcmp.Po
 	-rm -f ./$(DEPDIR)/kern_features.Po
@@ -10345,12 +12496,14 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/keyctl-Xraw.Po
 	-rm -f ./$(DEPDIR)/keyctl-Xverbose.Po
 	-rm -f ./$(DEPDIR)/keyctl.Po
+	-rm -f ./$(DEPDIR)/kill--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/kill.Po
 	-rm -f ./$(DEPDIR)/kill_child.Po
 	-rm -f ./$(DEPDIR)/ksysent.Po
 	-rm -f ./$(DEPDIR)/lchown.Po
 	-rm -f ./$(DEPDIR)/lchown32.Po
 	-rm -f ./$(DEPDIR)/libtests_a-create_nl_socket.Po
+	-rm -f ./$(DEPDIR)/libtests_a-create_tmpfile.Po
 	-rm -f ./$(DEPDIR)/libtests_a-errno2name.Po
 	-rm -f ./$(DEPDIR)/libtests_a-error_msg.Po
 	-rm -f ./$(DEPDIR)/libtests_a-fill_memory.Po
@@ -10364,6 +12517,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/libtests_a-libsocketcall.Po
 	-rm -f ./$(DEPDIR)/libtests_a-lock_file.Po
 	-rm -f ./$(DEPDIR)/libtests_a-overflowuid.Po
+	-rm -f ./$(DEPDIR)/libtests_a-pidns.Po
 	-rm -f ./$(DEPDIR)/libtests_a-pipe_maxfd.Po
 	-rm -f ./$(DEPDIR)/libtests_a-print_quoted_string.Po
 	-rm -f ./$(DEPDIR)/libtests_a-print_time.Po
@@ -10380,6 +12534,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/libtests_a-test_printstrn.Po
 	-rm -f ./$(DEPDIR)/libtests_a-test_ucopy.Po
 	-rm -f ./$(DEPDIR)/libtests_a-tprintf.Po
+	-rm -f ./$(DEPDIR)/libtests_a-xmalloc_for_tests.Po
 	-rm -f ./$(DEPDIR)/link.Po
 	-rm -f ./$(DEPDIR)/linkat.Po
 	-rm -f ./$(DEPDIR)/list_sigaction_signum.Po
@@ -10391,6 +12546,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/lstat.Po
 	-rm -f ./$(DEPDIR)/lstat64-lstat64.Po
 	-rm -f ./$(DEPDIR)/madvise.Po
+	-rm -f ./$(DEPDIR)/maybe_switch_current_tcp--quiet-thread-execve.Po
 	-rm -f ./$(DEPDIR)/maybe_switch_current_tcp.Po
 	-rm -f ./$(DEPDIR)/mbind-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/mbind-Xraw.Po
@@ -10401,6 +12557,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/memfd_create-Xraw.Po
 	-rm -f ./$(DEPDIR)/memfd_create-Xverbose.Po
 	-rm -f ./$(DEPDIR)/memfd_create.Po
+	-rm -f ./$(DEPDIR)/migrate_pages--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/migrate_pages.Po
 	-rm -f ./$(DEPDIR)/mincore.Po
 	-rm -f ./$(DEPDIR)/mkdir.Po
@@ -10429,6 +12586,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/mount.Po
 	-rm -f ./$(DEPDIR)/move_mount-P.Po
 	-rm -f ./$(DEPDIR)/move_mount.Po
+	-rm -f ./$(DEPDIR)/move_pages--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/move_pages-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/move_pages-Xraw.Po
 	-rm -f ./$(DEPDIR)/move_pages-Xverbose.Po
@@ -10442,12 +12600,17 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/msg_name.Po
 	-rm -f ./$(DEPDIR)/munlockall.Po
 	-rm -f ./$(DEPDIR)/nanosleep.Po
+	-rm -f ./$(DEPDIR)/net--decode-fds-dev-netlink.Po
+	-rm -f ./$(DEPDIR)/net--decode-fds-none-netlink.Po
+	-rm -f ./$(DEPDIR)/net--decode-fds-path-netlink.Po
+	-rm -f ./$(DEPDIR)/net--decode-fds-socket-netlink.Po
 	-rm -f ./$(DEPDIR)/net-accept-connect.Po
 	-rm -f ./$(DEPDIR)/net-icmp_filter.Po
 	-rm -f ./$(DEPDIR)/net-packet_mreq-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/net-packet_mreq-Xraw.Po
 	-rm -f ./$(DEPDIR)/net-packet_mreq-Xverbose.Po
 	-rm -f ./$(DEPDIR)/net-packet_mreq.Po
+	-rm -f ./$(DEPDIR)/net-sockaddr--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/net-sockaddr.Po
 	-rm -f ./$(DEPDIR)/net-tpacket_req.Po
 	-rm -f ./$(DEPDIR)/net-tpacket_stats-success.Po
@@ -10457,6 +12620,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/net-yy-inet6.Po
 	-rm -f ./$(DEPDIR)/net-yy-netlink.Po
 	-rm -f ./$(DEPDIR)/net-yy-unix.Po
+	-rm -f ./$(DEPDIR)/netlink_audit--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/netlink_audit.Po
 	-rm -f ./$(DEPDIR)/netlink_crypto.Po
 	-rm -f ./$(DEPDIR)/netlink_generic.Po
@@ -10494,6 +12658,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/nlattr_ifla_brport.Po
 	-rm -f ./$(DEPDIR)/nlattr_ifla_linkinfo.Po
 	-rm -f ./$(DEPDIR)/nlattr_ifla_port.Po
+	-rm -f ./$(DEPDIR)/nlattr_ifla_xdp-y.Po
 	-rm -f ./$(DEPDIR)/nlattr_ifla_xdp.Po
 	-rm -f ./$(DEPDIR)/nlattr_inet_diag_msg.Po
 	-rm -f ./$(DEPDIR)/nlattr_inet_diag_req_compat.Po
@@ -10533,6 +12698,16 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/open_tree-P.Po
 	-rm -f ./$(DEPDIR)/open_tree.Po
 	-rm -f ./$(DEPDIR)/openat.Po
+	-rm -f ./$(DEPDIR)/openat2-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/openat2-Xraw.Po
+	-rm -f ./$(DEPDIR)/openat2-Xverbose.Po
+	-rm -f ./$(DEPDIR)/openat2-v-y-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/openat2-v-y-Xraw.Po
+	-rm -f ./$(DEPDIR)/openat2-v-y-Xverbose.Po
+	-rm -f ./$(DEPDIR)/openat2-v-y.Po
+	-rm -f ./$(DEPDIR)/openat2-v.Po
+	-rm -f ./$(DEPDIR)/openat2-y.Po
+	-rm -f ./$(DEPDIR)/openat2.Po
 	-rm -f ./$(DEPDIR)/orphaned_process_group.Po
 	-rm -f ./$(DEPDIR)/osf_utimes.Po
 	-rm -f ./$(DEPDIR)/pause.Po
@@ -10544,10 +12719,20 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/personality-Xraw.Po
 	-rm -f ./$(DEPDIR)/personality-Xverbose.Po
 	-rm -f ./$(DEPDIR)/personality.Po
+	-rm -f ./$(DEPDIR)/pidfd_getfd-y.Po
+	-rm -f ./$(DEPDIR)/pidfd_getfd-yy.Po
+	-rm -f ./$(DEPDIR)/pidfd_getfd.Po
+	-rm -f ./$(DEPDIR)/pidfd_open--decode-fd-path.Po
+	-rm -f ./$(DEPDIR)/pidfd_open--decode-fd-pidfd.Po
+	-rm -f ./$(DEPDIR)/pidfd_open--decode-fd-socket.Po
+	-rm -f ./$(DEPDIR)/pidfd_open--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/pidfd_open-P.Po
 	-rm -f ./$(DEPDIR)/pidfd_open-y.Po
+	-rm -f ./$(DEPDIR)/pidfd_open-yy.Po
 	-rm -f ./$(DEPDIR)/pidfd_open.Po
+	-rm -f ./$(DEPDIR)/pidfd_send_signal--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/pidfd_send_signal.Po
+	-rm -f ./$(DEPDIR)/pidns-cache.Po
 	-rm -f ./$(DEPDIR)/pipe.Po
 	-rm -f ./$(DEPDIR)/pipe2.Po
 	-rm -f ./$(DEPDIR)/pkey_alloc.Po
@@ -10574,6 +12759,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/preadv2-pwritev2.Po
 	-rm -f ./$(DEPDIR)/preadv_pwritev-preadv-pwritev.Po
 	-rm -f ./$(DEPDIR)/print_maxfd.Po
+	-rm -f ./$(DEPDIR)/print_ppid_tracerpid.Po
 	-rm -f ./$(DEPDIR)/printpath-umovestr-peekdata.Po
 	-rm -f ./$(DEPDIR)/printpath-umovestr-undumpable.Po
 	-rm -f ./$(DEPDIR)/printpath-umovestr.Po
@@ -10584,8 +12770,11 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/printstrn-umoven-peekdata.Po
 	-rm -f ./$(DEPDIR)/printstrn-umoven-undumpable.Po
 	-rm -f ./$(DEPDIR)/printstrn-umoven.Po
+	-rm -f ./$(DEPDIR)/prlimit64--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/prlimit64.Po
+	-rm -f ./$(DEPDIR)/process_vm_readv--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/process_vm_readv.Po
+	-rm -f ./$(DEPDIR)/process_vm_writev--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/process_vm_writev.Po
 	-rm -f ./$(DEPDIR)/pselect6.Po
 	-rm -f ./$(DEPDIR)/ptrace.Po
@@ -10634,10 +12823,12 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/rt_sigaction.Po
 	-rm -f ./$(DEPDIR)/rt_sigpending.Po
 	-rm -f ./$(DEPDIR)/rt_sigprocmask.Po
+	-rm -f ./$(DEPDIR)/rt_sigqueueinfo--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/rt_sigqueueinfo.Po
 	-rm -f ./$(DEPDIR)/rt_sigreturn.Po
 	-rm -f ./$(DEPDIR)/rt_sigsuspend.Po
 	-rm -f ./$(DEPDIR)/rt_sigtimedwait.Po
+	-rm -f ./$(DEPDIR)/rt_tgsigqueueinfo--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/rt_tgsigqueueinfo.Po
 	-rm -f ./$(DEPDIR)/run_expect_termsig.Po
 	-rm -f ./$(DEPDIR)/s390_guarded_storage-v.Po
@@ -10648,9 +12839,13 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/s390_sthyi.Po
 	-rm -f ./$(DEPDIR)/sched_get_priority_mxx.Po
 	-rm -f ./$(DEPDIR)/sched_rr_get_interval.Po
+	-rm -f ./$(DEPDIR)/sched_xetaffinity--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/sched_xetaffinity.Po
+	-rm -f ./$(DEPDIR)/sched_xetattr--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/sched_xetattr.Po
+	-rm -f ./$(DEPDIR)/sched_xetparam--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/sched_xetparam.Po
+	-rm -f ./$(DEPDIR)/sched_xetscheduler--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/sched_xetscheduler.Po
 	-rm -f ./$(DEPDIR)/sched_yield.Po
 	-rm -f ./$(DEPDIR)/scm_rights.Po
@@ -10683,6 +12878,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/setgroups32.Po
 	-rm -f ./$(DEPDIR)/sethostname.Po
 	-rm -f ./$(DEPDIR)/setns.Po
+	-rm -f ./$(DEPDIR)/setpgrp-exec.Po
 	-rm -f ./$(DEPDIR)/setregid.Po
 	-rm -f ./$(DEPDIR)/setregid32.Po
 	-rm -f ./$(DEPDIR)/setresgid.Po
@@ -10703,6 +12899,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/sigaltstack.Po
 	-rm -f ./$(DEPDIR)/siginfo.Po
 	-rm -f ./$(DEPDIR)/signal.Po
+	-rm -f ./$(DEPDIR)/signal_receive--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/signal_receive.Po
 	-rm -f ./$(DEPDIR)/signalfd4.Po
 	-rm -f ./$(DEPDIR)/sigpending.Po
@@ -10712,6 +12909,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/sleep.Po
 	-rm -f ./$(DEPDIR)/so_error.Po
 	-rm -f ./$(DEPDIR)/so_linger.Po
+	-rm -f ./$(DEPDIR)/so_peercred--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/so_peercred-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/so_peercred-Xraw.Po
 	-rm -f ./$(DEPDIR)/so_peercred-Xverbose.Po
@@ -10743,14 +12941,24 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/statfs-statfs.Po
 	-rm -f ./$(DEPDIR)/statfs64.Po
 	-rm -f ./$(DEPDIR)/status-all.Po
+	-rm -f ./$(DEPDIR)/status-failed-long.Po
+	-rm -f ./$(DEPDIR)/status-failed-status.Po
 	-rm -f ./$(DEPDIR)/status-failed.Po
 	-rm -f ./$(DEPDIR)/status-none-f.Po
 	-rm -f ./$(DEPDIR)/status-none-threads.Po
 	-rm -f ./$(DEPDIR)/status-none.Po
+	-rm -f ./$(DEPDIR)/status-successful-long.Po
+	-rm -f ./$(DEPDIR)/status-successful-status.Po
 	-rm -f ./$(DEPDIR)/status-successful.Po
 	-rm -f ./$(DEPDIR)/status-unfinished-threads.Po
 	-rm -f ./$(DEPDIR)/status-unfinished.Po
 	-rm -f ./$(DEPDIR)/statx.Po
+	-rm -f ./$(DEPDIR)/strace--strings-in-hex-all.Po
+	-rm -f ./$(DEPDIR)/strace--strings-in-hex-non-ascii.Po
+	-rm -f ./$(DEPDIR)/strace--strings-in-hex.Po
+	-rm -f ./$(DEPDIR)/strace-n.Po
+	-rm -f ./$(DEPDIR)/strace-x.Po
+	-rm -f ./$(DEPDIR)/strace-xx.Po
 	-rm -f ./$(DEPDIR)/swap.Po
 	-rm -f ./$(DEPDIR)/sxetmask.Po
 	-rm -f ./$(DEPDIR)/symlink.Po
@@ -10762,6 +12970,12 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/syslog-success.Po
 	-rm -f ./$(DEPDIR)/syslog.Po
 	-rm -f ./$(DEPDIR)/tee.Po
+	-rm -f ./$(DEPDIR)/tgkill--pidns-translation.Po
+	-rm -f ./$(DEPDIR)/tgkill.Po
+	-rm -f ./$(DEPDIR)/threads-execve--quiet-thread-execve.Po
+	-rm -f ./$(DEPDIR)/threads-execve-q.Po
+	-rm -f ./$(DEPDIR)/threads-execve-qq.Po
+	-rm -f ./$(DEPDIR)/threads-execve-qqq.Po
 	-rm -f ./$(DEPDIR)/threads-execve.Po
 	-rm -f ./$(DEPDIR)/time.Po
 	-rm -f ./$(DEPDIR)/timer_create.Po
@@ -10769,7 +12983,11 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/timerfd_xettime.Po
 	-rm -f ./$(DEPDIR)/times-fail.Po
 	-rm -f ./$(DEPDIR)/times.Po
+	-rm -f ./$(DEPDIR)/tkill--pidns-translation.Po
+	-rm -f ./$(DEPDIR)/tkill.Po
 	-rm -f ./$(DEPDIR)/tracer_ppid_pgid_sid.Po
+	-rm -f ./$(DEPDIR)/trie_test-trie_for_tests.Po
+	-rm -f ./$(DEPDIR)/trie_test-trie_test.Po
 	-rm -f ./$(DEPDIR)/truncate.Po
 	-rm -f ./$(DEPDIR)/truncate64-truncate64.Po
 	-rm -f ./$(DEPDIR)/ugetrlimit.Po
@@ -10783,6 +13001,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/umovestr2.Po
 	-rm -f ./$(DEPDIR)/umovestr3.Po
 	-rm -f ./$(DEPDIR)/umovestr_cached.Po
+	-rm -f ./$(DEPDIR)/umovestr_cached_adjacent.Po
 	-rm -f ./$(DEPDIR)/uname.Po
 	-rm -f ./$(DEPDIR)/unblock_reset_raise.Po
 	-rm -f ./$(DEPDIR)/unix-pair-send-recv.Po
@@ -10808,10 +13027,13 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/waitpid.Po
 	-rm -f ./$(DEPDIR)/xattr-strings.Po
 	-rm -f ./$(DEPDIR)/xattr.Po
+	-rm -f ./$(DEPDIR)/xet_robust_list--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/xet_robust_list.Po
 	-rm -f ./$(DEPDIR)/xet_thread_area_x86.Po
 	-rm -f ./$(DEPDIR)/xetitimer.Po
+	-rm -f ./$(DEPDIR)/xetpgid--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/xetpgid.Po
+	-rm -f ./$(DEPDIR)/xetpriority--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/xetpriority.Po
 	-rm -f ./$(DEPDIR)/xettimeofday.Po
 	-rm -f ./$(DEPDIR)/zeroargc.Po
@@ -10882,6 +13104,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/bpf-obj_get_info_by_fd-prog.Po
 	-rm -f ./$(DEPDIR)/bpf-obj_get_info_by_fd-v.Po
 	-rm -f ./$(DEPDIR)/bpf-obj_get_info_by_fd.Po
+	-rm -f ./$(DEPDIR)/bpf-success-long-y.Po
 	-rm -f ./$(DEPDIR)/bpf-success-v.Po
 	-rm -f ./$(DEPDIR)/bpf-success.Po
 	-rm -f ./$(DEPDIR)/bpf-v.Po
@@ -10908,16 +13131,39 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/clone3-success-Xverbose.Po
 	-rm -f ./$(DEPDIR)/clone3-success.Po
 	-rm -f ./$(DEPDIR)/clone3.Po
+	-rm -f ./$(DEPDIR)/clone_parent--quiet-exit.Po
+	-rm -f ./$(DEPDIR)/clone_parent-q.Po
+	-rm -f ./$(DEPDIR)/clone_parent-qq.Po
 	-rm -f ./$(DEPDIR)/clone_parent.Po
+	-rm -f ./$(DEPDIR)/clone_ptrace--quiet-attach.Po
+	-rm -f ./$(DEPDIR)/clone_ptrace--quiet-exit.Po
+	-rm -f ./$(DEPDIR)/clone_ptrace-q.Po
+	-rm -f ./$(DEPDIR)/clone_ptrace-qq.Po
 	-rm -f ./$(DEPDIR)/clone_ptrace.Po
+	-rm -f ./$(DEPDIR)/close_range-P.Po
+	-rm -f ./$(DEPDIR)/close_range-y.Po
+	-rm -f ./$(DEPDIR)/close_range-yy.Po
+	-rm -f ./$(DEPDIR)/close_range.Po
 	-rm -f ./$(DEPDIR)/copy_file_range.Po
 	-rm -f ./$(DEPDIR)/count-f.Po
 	-rm -f ./$(DEPDIR)/creat.Po
 	-rm -f ./$(DEPDIR)/delay.Po
 	-rm -f ./$(DEPDIR)/delete_module.Po
+	-rm -f ./$(DEPDIR)/dev--decode-fds-dev.Po
+	-rm -f ./$(DEPDIR)/dev--decode-fds-path.Po
+	-rm -f ./$(DEPDIR)/dev--decode-fds-socket.Po
 	-rm -f ./$(DEPDIR)/dev-yy.Po
+	-rm -f ./$(DEPDIR)/dup-P.Po
+	-rm -f ./$(DEPDIR)/dup-y.Po
+	-rm -f ./$(DEPDIR)/dup-yy.Po
 	-rm -f ./$(DEPDIR)/dup.Po
+	-rm -f ./$(DEPDIR)/dup2-P.Po
+	-rm -f ./$(DEPDIR)/dup2-y.Po
+	-rm -f ./$(DEPDIR)/dup2-yy.Po
 	-rm -f ./$(DEPDIR)/dup2.Po
+	-rm -f ./$(DEPDIR)/dup3-P.Po
+	-rm -f ./$(DEPDIR)/dup3-y.Po
+	-rm -f ./$(DEPDIR)/dup3-yy.Po
 	-rm -f ./$(DEPDIR)/dup3.Po
 	-rm -f ./$(DEPDIR)/epoll_create.Po
 	-rm -f ./$(DEPDIR)/epoll_create1.Po
@@ -10930,7 +13176,14 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/execve.Po
 	-rm -f ./$(DEPDIR)/execveat-v.Po
 	-rm -f ./$(DEPDIR)/execveat.Po
+	-rm -f ./$(DEPDIR)/faccessat-P.Po
+	-rm -f ./$(DEPDIR)/faccessat-y.Po
+	-rm -f ./$(DEPDIR)/faccessat-yy.Po
 	-rm -f ./$(DEPDIR)/faccessat.Po
+	-rm -f ./$(DEPDIR)/faccessat2-P.Po
+	-rm -f ./$(DEPDIR)/faccessat2-y.Po
+	-rm -f ./$(DEPDIR)/faccessat2-yy.Po
+	-rm -f ./$(DEPDIR)/faccessat2.Po
 	-rm -f ./$(DEPDIR)/fadvise64.Po
 	-rm -f ./$(DEPDIR)/fadvise64_64.Po
 	-rm -f ./$(DEPDIR)/fallocate.Po
@@ -10945,7 +13198,9 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/fchown.Po
 	-rm -f ./$(DEPDIR)/fchown32.Po
 	-rm -f ./$(DEPDIR)/fchownat.Po
+	-rm -f ./$(DEPDIR)/fcntl--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/fcntl.Po
+	-rm -f ./$(DEPDIR)/fcntl64--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/fcntl64.Po
 	-rm -f ./$(DEPDIR)/fdatasync.Po
 	-rm -f ./$(DEPDIR)/fflush.Po
@@ -10956,6 +13211,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/filter_seccomp-perf.Po
 	-rm -f ./$(DEPDIR)/finit_module.Po
 	-rm -f ./$(DEPDIR)/flock.Po
+	-rm -f ./$(DEPDIR)/fork--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/fork-f.Po
 	-rm -f ./$(DEPDIR)/fsconfig-P.Po
 	-rm -f ./$(DEPDIR)/fsconfig.Po
@@ -10981,9 +13237,12 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/futex.Po
 	-rm -f ./$(DEPDIR)/futimesat.Po
 	-rm -f ./$(DEPDIR)/get_mempolicy.Po
+	-rm -f ./$(DEPDIR)/get_process_reaper.Po
 	-rm -f ./$(DEPDIR)/getcpu.Po
 	-rm -f ./$(DEPDIR)/getcwd.Po
+	-rm -f ./$(DEPDIR)/getdents-v.Po
 	-rm -f ./$(DEPDIR)/getdents.Po
+	-rm -f ./$(DEPDIR)/getdents64-v.Po
 	-rm -f ./$(DEPDIR)/getdents64.Po
 	-rm -f ./$(DEPDIR)/getegid.Po
 	-rm -f ./$(DEPDIR)/getegid32.Po
@@ -10994,7 +13253,9 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/getgroups.Po
 	-rm -f ./$(DEPDIR)/getgroups32.Po
 	-rm -f ./$(DEPDIR)/getpeername.Po
+	-rm -f ./$(DEPDIR)/getpgrp--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/getpgrp.Po
+	-rm -f ./$(DEPDIR)/getpid--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/getpid.Po
 	-rm -f ./$(DEPDIR)/getppid.Po
 	-rm -f ./$(DEPDIR)/getrandom.Po
@@ -11004,12 +13265,16 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/getresuid32.Po
 	-rm -f ./$(DEPDIR)/getrlimit.Po
 	-rm -f ./$(DEPDIR)/getrusage.Po
+	-rm -f ./$(DEPDIR)/getsid--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/getsid.Po
 	-rm -f ./$(DEPDIR)/getsockname.Po
+	-rm -f ./$(DEPDIR)/gettid--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/gettid.Po
 	-rm -f ./$(DEPDIR)/getuid.Po
 	-rm -f ./$(DEPDIR)/getuid32.Po
-	-rm -f ./$(DEPDIR)/getxxid.Po
+	-rm -f ./$(DEPDIR)/getxgid.Po
+	-rm -f ./$(DEPDIR)/getxpid.Po
+	-rm -f ./$(DEPDIR)/getxuid.Po
 	-rm -f ./$(DEPDIR)/group_req.Po
 	-rm -f ./$(DEPDIR)/inet-cmsg.Po
 	-rm -f ./$(DEPDIR)/init_module.Po
@@ -11024,6 +13289,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/io_uring_register.Po
 	-rm -f ./$(DEPDIR)/io_uring_setup.Po
 	-rm -f ./$(DEPDIR)/ioctl.Po
+	-rm -f ./$(DEPDIR)/ioctl_block--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/ioctl_block.Po
 	-rm -f ./$(DEPDIR)/ioctl_dm-v.Po
 	-rm -f ./$(DEPDIR)/ioctl_dm.Po
@@ -11043,6 +13309,22 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/ioctl_evdev-v-Xverbose.Po
 	-rm -f ./$(DEPDIR)/ioctl_evdev-v.Po
 	-rm -f ./$(DEPDIR)/ioctl_evdev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-v-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-v-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-v-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-v.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-v-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-v-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-v-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-v.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio.Po
 	-rm -f ./$(DEPDIR)/ioctl_inotify.Po
 	-rm -f ./$(DEPDIR)/ioctl_kvm_run-v.Po
 	-rm -f ./$(DEPDIR)/ioctl_kvm_run.Po
@@ -11063,11 +13345,28 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/ioctl_sg_io_v3.Po
 	-rm -f ./$(DEPDIR)/ioctl_sg_io_v4.Po
 	-rm -f ./$(DEPDIR)/ioctl_sock_gifconf.Po
+	-rm -f ./$(DEPDIR)/ioctl_tee.Po
 	-rm -f ./$(DEPDIR)/ioctl_uffdio.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-v-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-v-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-v-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-v.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-v-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-v-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-v-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-v.Po
 	-rm -f ./$(DEPDIR)/ioctl_v4l2.Po
 	-rm -f ./$(DEPDIR)/ioctl_watchdog.Po
 	-rm -f ./$(DEPDIR)/ioperm.Po
 	-rm -f ./$(DEPDIR)/iopl.Po
+	-rm -f ./$(DEPDIR)/ioprio--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/ioprio-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/ioprio-Xraw.Po
 	-rm -f ./$(DEPDIR)/ioprio-Xverbose.Po
@@ -11091,6 +13390,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/ipc_shm-Xverbose.Po
 	-rm -f ./$(DEPDIR)/ipc_shm.Po
 	-rm -f ./$(DEPDIR)/is_linux_mips_n64.Po
+	-rm -f ./$(DEPDIR)/kcmp-y--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/kcmp-y.Po
 	-rm -f ./$(DEPDIR)/kcmp.Po
 	-rm -f ./$(DEPDIR)/kern_features.Po
@@ -11104,12 +13404,14 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/keyctl-Xraw.Po
 	-rm -f ./$(DEPDIR)/keyctl-Xverbose.Po
 	-rm -f ./$(DEPDIR)/keyctl.Po
+	-rm -f ./$(DEPDIR)/kill--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/kill.Po
 	-rm -f ./$(DEPDIR)/kill_child.Po
 	-rm -f ./$(DEPDIR)/ksysent.Po
 	-rm -f ./$(DEPDIR)/lchown.Po
 	-rm -f ./$(DEPDIR)/lchown32.Po
 	-rm -f ./$(DEPDIR)/libtests_a-create_nl_socket.Po
+	-rm -f ./$(DEPDIR)/libtests_a-create_tmpfile.Po
 	-rm -f ./$(DEPDIR)/libtests_a-errno2name.Po
 	-rm -f ./$(DEPDIR)/libtests_a-error_msg.Po
 	-rm -f ./$(DEPDIR)/libtests_a-fill_memory.Po
@@ -11123,6 +13425,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/libtests_a-libsocketcall.Po
 	-rm -f ./$(DEPDIR)/libtests_a-lock_file.Po
 	-rm -f ./$(DEPDIR)/libtests_a-overflowuid.Po
+	-rm -f ./$(DEPDIR)/libtests_a-pidns.Po
 	-rm -f ./$(DEPDIR)/libtests_a-pipe_maxfd.Po
 	-rm -f ./$(DEPDIR)/libtests_a-print_quoted_string.Po
 	-rm -f ./$(DEPDIR)/libtests_a-print_time.Po
@@ -11139,6 +13442,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/libtests_a-test_printstrn.Po
 	-rm -f ./$(DEPDIR)/libtests_a-test_ucopy.Po
 	-rm -f ./$(DEPDIR)/libtests_a-tprintf.Po
+	-rm -f ./$(DEPDIR)/libtests_a-xmalloc_for_tests.Po
 	-rm -f ./$(DEPDIR)/link.Po
 	-rm -f ./$(DEPDIR)/linkat.Po
 	-rm -f ./$(DEPDIR)/list_sigaction_signum.Po
@@ -11150,6 +13454,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/lstat.Po
 	-rm -f ./$(DEPDIR)/lstat64-lstat64.Po
 	-rm -f ./$(DEPDIR)/madvise.Po
+	-rm -f ./$(DEPDIR)/maybe_switch_current_tcp--quiet-thread-execve.Po
 	-rm -f ./$(DEPDIR)/maybe_switch_current_tcp.Po
 	-rm -f ./$(DEPDIR)/mbind-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/mbind-Xraw.Po
@@ -11160,6 +13465,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/memfd_create-Xraw.Po
 	-rm -f ./$(DEPDIR)/memfd_create-Xverbose.Po
 	-rm -f ./$(DEPDIR)/memfd_create.Po
+	-rm -f ./$(DEPDIR)/migrate_pages--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/migrate_pages.Po
 	-rm -f ./$(DEPDIR)/mincore.Po
 	-rm -f ./$(DEPDIR)/mkdir.Po
@@ -11188,6 +13494,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/mount.Po
 	-rm -f ./$(DEPDIR)/move_mount-P.Po
 	-rm -f ./$(DEPDIR)/move_mount.Po
+	-rm -f ./$(DEPDIR)/move_pages--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/move_pages-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/move_pages-Xraw.Po
 	-rm -f ./$(DEPDIR)/move_pages-Xverbose.Po
@@ -11201,12 +13508,17 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/msg_name.Po
 	-rm -f ./$(DEPDIR)/munlockall.Po
 	-rm -f ./$(DEPDIR)/nanosleep.Po
+	-rm -f ./$(DEPDIR)/net--decode-fds-dev-netlink.Po
+	-rm -f ./$(DEPDIR)/net--decode-fds-none-netlink.Po
+	-rm -f ./$(DEPDIR)/net--decode-fds-path-netlink.Po
+	-rm -f ./$(DEPDIR)/net--decode-fds-socket-netlink.Po
 	-rm -f ./$(DEPDIR)/net-accept-connect.Po
 	-rm -f ./$(DEPDIR)/net-icmp_filter.Po
 	-rm -f ./$(DEPDIR)/net-packet_mreq-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/net-packet_mreq-Xraw.Po
 	-rm -f ./$(DEPDIR)/net-packet_mreq-Xverbose.Po
 	-rm -f ./$(DEPDIR)/net-packet_mreq.Po
+	-rm -f ./$(DEPDIR)/net-sockaddr--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/net-sockaddr.Po
 	-rm -f ./$(DEPDIR)/net-tpacket_req.Po
 	-rm -f ./$(DEPDIR)/net-tpacket_stats-success.Po
@@ -11216,6 +13528,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/net-yy-inet6.Po
 	-rm -f ./$(DEPDIR)/net-yy-netlink.Po
 	-rm -f ./$(DEPDIR)/net-yy-unix.Po
+	-rm -f ./$(DEPDIR)/netlink_audit--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/netlink_audit.Po
 	-rm -f ./$(DEPDIR)/netlink_crypto.Po
 	-rm -f ./$(DEPDIR)/netlink_generic.Po
@@ -11253,6 +13566,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/nlattr_ifla_brport.Po
 	-rm -f ./$(DEPDIR)/nlattr_ifla_linkinfo.Po
 	-rm -f ./$(DEPDIR)/nlattr_ifla_port.Po
+	-rm -f ./$(DEPDIR)/nlattr_ifla_xdp-y.Po
 	-rm -f ./$(DEPDIR)/nlattr_ifla_xdp.Po
 	-rm -f ./$(DEPDIR)/nlattr_inet_diag_msg.Po
 	-rm -f ./$(DEPDIR)/nlattr_inet_diag_req_compat.Po
@@ -11292,6 +13606,16 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/open_tree-P.Po
 	-rm -f ./$(DEPDIR)/open_tree.Po
 	-rm -f ./$(DEPDIR)/openat.Po
+	-rm -f ./$(DEPDIR)/openat2-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/openat2-Xraw.Po
+	-rm -f ./$(DEPDIR)/openat2-Xverbose.Po
+	-rm -f ./$(DEPDIR)/openat2-v-y-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/openat2-v-y-Xraw.Po
+	-rm -f ./$(DEPDIR)/openat2-v-y-Xverbose.Po
+	-rm -f ./$(DEPDIR)/openat2-v-y.Po
+	-rm -f ./$(DEPDIR)/openat2-v.Po
+	-rm -f ./$(DEPDIR)/openat2-y.Po
+	-rm -f ./$(DEPDIR)/openat2.Po
 	-rm -f ./$(DEPDIR)/orphaned_process_group.Po
 	-rm -f ./$(DEPDIR)/osf_utimes.Po
 	-rm -f ./$(DEPDIR)/pause.Po
@@ -11303,10 +13627,20 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/personality-Xraw.Po
 	-rm -f ./$(DEPDIR)/personality-Xverbose.Po
 	-rm -f ./$(DEPDIR)/personality.Po
+	-rm -f ./$(DEPDIR)/pidfd_getfd-y.Po
+	-rm -f ./$(DEPDIR)/pidfd_getfd-yy.Po
+	-rm -f ./$(DEPDIR)/pidfd_getfd.Po
+	-rm -f ./$(DEPDIR)/pidfd_open--decode-fd-path.Po
+	-rm -f ./$(DEPDIR)/pidfd_open--decode-fd-pidfd.Po
+	-rm -f ./$(DEPDIR)/pidfd_open--decode-fd-socket.Po
+	-rm -f ./$(DEPDIR)/pidfd_open--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/pidfd_open-P.Po
 	-rm -f ./$(DEPDIR)/pidfd_open-y.Po
+	-rm -f ./$(DEPDIR)/pidfd_open-yy.Po
 	-rm -f ./$(DEPDIR)/pidfd_open.Po
+	-rm -f ./$(DEPDIR)/pidfd_send_signal--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/pidfd_send_signal.Po
+	-rm -f ./$(DEPDIR)/pidns-cache.Po
 	-rm -f ./$(DEPDIR)/pipe.Po
 	-rm -f ./$(DEPDIR)/pipe2.Po
 	-rm -f ./$(DEPDIR)/pkey_alloc.Po
@@ -11333,6 +13667,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/preadv2-pwritev2.Po
 	-rm -f ./$(DEPDIR)/preadv_pwritev-preadv-pwritev.Po
 	-rm -f ./$(DEPDIR)/print_maxfd.Po
+	-rm -f ./$(DEPDIR)/print_ppid_tracerpid.Po
 	-rm -f ./$(DEPDIR)/printpath-umovestr-peekdata.Po
 	-rm -f ./$(DEPDIR)/printpath-umovestr-undumpable.Po
 	-rm -f ./$(DEPDIR)/printpath-umovestr.Po
@@ -11343,8 +13678,11 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/printstrn-umoven-peekdata.Po
 	-rm -f ./$(DEPDIR)/printstrn-umoven-undumpable.Po
 	-rm -f ./$(DEPDIR)/printstrn-umoven.Po
+	-rm -f ./$(DEPDIR)/prlimit64--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/prlimit64.Po
+	-rm -f ./$(DEPDIR)/process_vm_readv--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/process_vm_readv.Po
+	-rm -f ./$(DEPDIR)/process_vm_writev--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/process_vm_writev.Po
 	-rm -f ./$(DEPDIR)/pselect6.Po
 	-rm -f ./$(DEPDIR)/ptrace.Po
@@ -11393,10 +13731,12 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/rt_sigaction.Po
 	-rm -f ./$(DEPDIR)/rt_sigpending.Po
 	-rm -f ./$(DEPDIR)/rt_sigprocmask.Po
+	-rm -f ./$(DEPDIR)/rt_sigqueueinfo--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/rt_sigqueueinfo.Po
 	-rm -f ./$(DEPDIR)/rt_sigreturn.Po
 	-rm -f ./$(DEPDIR)/rt_sigsuspend.Po
 	-rm -f ./$(DEPDIR)/rt_sigtimedwait.Po
+	-rm -f ./$(DEPDIR)/rt_tgsigqueueinfo--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/rt_tgsigqueueinfo.Po
 	-rm -f ./$(DEPDIR)/run_expect_termsig.Po
 	-rm -f ./$(DEPDIR)/s390_guarded_storage-v.Po
@@ -11407,9 +13747,13 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/s390_sthyi.Po
 	-rm -f ./$(DEPDIR)/sched_get_priority_mxx.Po
 	-rm -f ./$(DEPDIR)/sched_rr_get_interval.Po
+	-rm -f ./$(DEPDIR)/sched_xetaffinity--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/sched_xetaffinity.Po
+	-rm -f ./$(DEPDIR)/sched_xetattr--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/sched_xetattr.Po
+	-rm -f ./$(DEPDIR)/sched_xetparam--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/sched_xetparam.Po
+	-rm -f ./$(DEPDIR)/sched_xetscheduler--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/sched_xetscheduler.Po
 	-rm -f ./$(DEPDIR)/sched_yield.Po
 	-rm -f ./$(DEPDIR)/scm_rights.Po
@@ -11442,6 +13786,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/setgroups32.Po
 	-rm -f ./$(DEPDIR)/sethostname.Po
 	-rm -f ./$(DEPDIR)/setns.Po
+	-rm -f ./$(DEPDIR)/setpgrp-exec.Po
 	-rm -f ./$(DEPDIR)/setregid.Po
 	-rm -f ./$(DEPDIR)/setregid32.Po
 	-rm -f ./$(DEPDIR)/setresgid.Po
@@ -11462,6 +13807,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/sigaltstack.Po
 	-rm -f ./$(DEPDIR)/siginfo.Po
 	-rm -f ./$(DEPDIR)/signal.Po
+	-rm -f ./$(DEPDIR)/signal_receive--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/signal_receive.Po
 	-rm -f ./$(DEPDIR)/signalfd4.Po
 	-rm -f ./$(DEPDIR)/sigpending.Po
@@ -11471,6 +13817,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/sleep.Po
 	-rm -f ./$(DEPDIR)/so_error.Po
 	-rm -f ./$(DEPDIR)/so_linger.Po
+	-rm -f ./$(DEPDIR)/so_peercred--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/so_peercred-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/so_peercred-Xraw.Po
 	-rm -f ./$(DEPDIR)/so_peercred-Xverbose.Po
@@ -11502,14 +13849,24 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/statfs-statfs.Po
 	-rm -f ./$(DEPDIR)/statfs64.Po
 	-rm -f ./$(DEPDIR)/status-all.Po
+	-rm -f ./$(DEPDIR)/status-failed-long.Po
+	-rm -f ./$(DEPDIR)/status-failed-status.Po
 	-rm -f ./$(DEPDIR)/status-failed.Po
 	-rm -f ./$(DEPDIR)/status-none-f.Po
 	-rm -f ./$(DEPDIR)/status-none-threads.Po
 	-rm -f ./$(DEPDIR)/status-none.Po
+	-rm -f ./$(DEPDIR)/status-successful-long.Po
+	-rm -f ./$(DEPDIR)/status-successful-status.Po
 	-rm -f ./$(DEPDIR)/status-successful.Po
 	-rm -f ./$(DEPDIR)/status-unfinished-threads.Po
 	-rm -f ./$(DEPDIR)/status-unfinished.Po
 	-rm -f ./$(DEPDIR)/statx.Po
+	-rm -f ./$(DEPDIR)/strace--strings-in-hex-all.Po
+	-rm -f ./$(DEPDIR)/strace--strings-in-hex-non-ascii.Po
+	-rm -f ./$(DEPDIR)/strace--strings-in-hex.Po
+	-rm -f ./$(DEPDIR)/strace-n.Po
+	-rm -f ./$(DEPDIR)/strace-x.Po
+	-rm -f ./$(DEPDIR)/strace-xx.Po
 	-rm -f ./$(DEPDIR)/swap.Po
 	-rm -f ./$(DEPDIR)/sxetmask.Po
 	-rm -f ./$(DEPDIR)/symlink.Po
@@ -11521,6 +13878,12 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/syslog-success.Po
 	-rm -f ./$(DEPDIR)/syslog.Po
 	-rm -f ./$(DEPDIR)/tee.Po
+	-rm -f ./$(DEPDIR)/tgkill--pidns-translation.Po
+	-rm -f ./$(DEPDIR)/tgkill.Po
+	-rm -f ./$(DEPDIR)/threads-execve--quiet-thread-execve.Po
+	-rm -f ./$(DEPDIR)/threads-execve-q.Po
+	-rm -f ./$(DEPDIR)/threads-execve-qq.Po
+	-rm -f ./$(DEPDIR)/threads-execve-qqq.Po
 	-rm -f ./$(DEPDIR)/threads-execve.Po
 	-rm -f ./$(DEPDIR)/time.Po
 	-rm -f ./$(DEPDIR)/timer_create.Po
@@ -11528,7 +13891,11 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/timerfd_xettime.Po
 	-rm -f ./$(DEPDIR)/times-fail.Po
 	-rm -f ./$(DEPDIR)/times.Po
+	-rm -f ./$(DEPDIR)/tkill--pidns-translation.Po
+	-rm -f ./$(DEPDIR)/tkill.Po
 	-rm -f ./$(DEPDIR)/tracer_ppid_pgid_sid.Po
+	-rm -f ./$(DEPDIR)/trie_test-trie_for_tests.Po
+	-rm -f ./$(DEPDIR)/trie_test-trie_test.Po
 	-rm -f ./$(DEPDIR)/truncate.Po
 	-rm -f ./$(DEPDIR)/truncate64-truncate64.Po
 	-rm -f ./$(DEPDIR)/ugetrlimit.Po
@@ -11542,6 +13909,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/umovestr2.Po
 	-rm -f ./$(DEPDIR)/umovestr3.Po
 	-rm -f ./$(DEPDIR)/umovestr_cached.Po
+	-rm -f ./$(DEPDIR)/umovestr_cached_adjacent.Po
 	-rm -f ./$(DEPDIR)/uname.Po
 	-rm -f ./$(DEPDIR)/unblock_reset_raise.Po
 	-rm -f ./$(DEPDIR)/unix-pair-send-recv.Po
@@ -11567,10 +13935,13 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/waitpid.Po
 	-rm -f ./$(DEPDIR)/xattr-strings.Po
 	-rm -f ./$(DEPDIR)/xattr.Po
+	-rm -f ./$(DEPDIR)/xet_robust_list--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/xet_robust_list.Po
 	-rm -f ./$(DEPDIR)/xet_thread_area_x86.Po
 	-rm -f ./$(DEPDIR)/xetitimer.Po
+	-rm -f ./$(DEPDIR)/xetpgid--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/xetpgid.Po
+	-rm -f ./$(DEPDIR)/xetpriority--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/xetpriority.Po
 	-rm -f ./$(DEPDIR)/xettimeofday.Po
 	-rm -f ./$(DEPDIR)/zeroargc.Po
@@ -11714,6 +14085,42 @@ $(srcdir)/clone3-success-Xraw.gen.test:
 $(srcdir)/clone3-success-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/clone_parent.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_parent--quiet-exit.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_parent-q.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_parent-qq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_ptrace--quiet-attach.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_ptrace--quiet-exit.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_ptrace-q.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_ptrace-qq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/close_range.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/close_range-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/close_range-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/close_range-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/copy_file_range.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -11723,18 +14130,54 @@ $(srcdir)/creat.gen.test: $(abs_srcdir)/
 $(srcdir)/delete_module.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/dev--decode-fds-dev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dev--decode-fds-path.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dev--decode-fds-socket.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/dev-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/dup.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/dup-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/dup2.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/dup2-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup2-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup2-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/dup3.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/dup3-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup3-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup3-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/epoll_create.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -11759,7 +14202,22 @@ $(srcdir)/execveat.gen.test: $(abs_srcdi
 $(srcdir)/execveat-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
-$(srcdir)/faccessat.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+$(srcdir)/faccessat-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat2-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat2-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat2-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/fadvise64_64.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
@@ -11804,9 +14262,15 @@ $(srcdir)/fchownat.gen.test: $(abs_srcdi
 $(srcdir)/fcntl.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/fcntl--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/fcntl64.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/fcntl64--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/fdatasync.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -11909,9 +14373,15 @@ $(srcdir)/getcwd.gen.test: $(abs_srcdir)
 $(srcdir)/getdents.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getdents-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getdents64.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getdents64-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getegid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -11960,9 +14430,15 @@ $(srcdir)/getpeername.gen.test: $(abs_sr
 $(srcdir)/getpgrp.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getpgrp--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getpid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getpid--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getppid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -11990,6 +14466,9 @@ $(srcdir)/getrusage.gen.test: $(abs_srcd
 $(srcdir)/getsid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getsid--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getsockname.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12005,7 +14484,13 @@ $(srcdir)/getuid32.gen.test: $(abs_srcdi
 $(srcdir)/getuid32-creds.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
-$(srcdir)/getxxid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+$(srcdir)/getxgid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/getxpid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/getxuid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/group_req.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
@@ -12092,6 +14577,54 @@ $(srcdir)/ioctl_evdev-success-v-Xraw.gen
 $(srcdir)/ioctl_evdev-success-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioctl_hdio.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-v-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-v-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-v-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-v-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioctl_inotify.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12125,6 +14658,9 @@ $(srcdir)/ioctl_nsfs.gen.test: $(abs_src
 $(srcdir)/ioctl_perf.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioctl_perf-success.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioctl_ptp.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12149,12 +14685,60 @@ $(srcdir)/ioctl_sg_io_v4.gen.test: $(abs
 $(srcdir)/ioctl_sock_gifconf.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioctl_tee.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioctl_uffdio.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/ioctl_v4l2.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioctl_v4l2-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-v-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-v-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-v-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-v-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioctl_watchdog.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12167,6 +14751,9 @@ $(srcdir)/iopl.gen.test: $(abs_srcdir)/g
 $(srcdir)/ioprio.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioprio--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioprio-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12233,6 +14820,9 @@ $(srcdir)/kcmp.gen.test: $(abs_srcdir)/g
 $(srcdir)/kcmp-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/kcmp-y--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/kern_features.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12269,6 +14859,9 @@ $(srcdir)/keyctl-Xverbose.gen.test: $(ab
 $(srcdir)/kill.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/kill--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ksysent.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12299,6 +14892,9 @@ $(srcdir)/madvise.gen.test: $(abs_srcdir
 $(srcdir)/maybe_switch_current_tcp.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/maybe_switch_current_tcp--quiet-thread-execve.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/mbind.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12329,6 +14925,9 @@ $(srcdir)/memfd_create-Xverbose.gen.test
 $(srcdir)/migrate_pages.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/migrate_pages--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/mincore.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12419,6 +15018,9 @@ $(srcdir)/move_pages-Xraw.gen.test: $(ab
 $(srcdir)/move_pages-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/move_pages--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/mq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12446,6 +15048,18 @@ $(srcdir)/munlockall.gen.test: $(abs_src
 $(srcdir)/nanosleep.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/net--decode-fds-dev-netlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/net--decode-fds-none-netlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/net--decode-fds-path-netlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/net--decode-fds-socket-netlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/net-icmp_filter.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12464,6 +15078,9 @@ $(srcdir)/net-packet_mreq-Xverbose.gen.t
 $(srcdir)/net-sockaddr.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/net-sockaddr--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/net-tpacket_req.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12575,6 +15192,9 @@ $(srcdir)/nlattr_ifla_port.gen.test: $(a
 $(srcdir)/nlattr_ifla_xdp.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/nlattr_ifla_xdp-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/nlattr_inet_diag_msg.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12683,6 +15303,36 @@ $(srcdir)/open_tree-P.gen.test: $(abs_sr
 $(srcdir)/openat.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/openat2.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v-y-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v-y-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v-y-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/orphaned_process_group.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12710,18 +15360,45 @@ $(srcdir)/personality-Xraw.gen.test: $(a
 $(srcdir)/personality-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/pidfd_getfd.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_getfd-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_getfd-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pidfd_open.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/pidfd_open--decode-fd-path.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_open--decode-fd-pidfd.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_open--decode-fd-socket.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pidfd_open-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/pidfd_open-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/pidfd_open-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_open--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pidfd_send_signal.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/pidfd_send_signal--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pipe2.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12788,12 +15465,21 @@ $(srcdir)/printstrn-umoven-undumpable.ge
 $(srcdir)/prlimit64.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/prlimit64--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/process_vm_readv.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/process_vm_readv--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/process_vm_writev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/process_vm_writev--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pselect6.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12902,6 +15588,9 @@ $(srcdir)/rt_sigprocmask.gen.test: $(abs
 $(srcdir)/rt_sigqueueinfo.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/rt_sigqueueinfo--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/rt_sigreturn.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12914,6 +15603,9 @@ $(srcdir)/rt_sigtimedwait.gen.test: $(ab
 $(srcdir)/rt_tgsigqueueinfo.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/rt_tgsigqueueinfo--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/s390_guarded_storage.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12944,15 +15636,27 @@ $(srcdir)/sched_rr_get_interval.gen.test
 $(srcdir)/sched_xetaffinity.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/sched_xetaffinity--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sched_xetattr.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/sched_xetattr--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sched_xetparam.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/sched_xetparam--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sched_xetscheduler.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/sched_xetscheduler--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sched_yield.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -13091,6 +15795,9 @@ $(srcdir)/signal.gen.test: $(abs_srcdir)
 $(srcdir)/signal_receive.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/signal_receive--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/signalfd4.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -13124,6 +15831,9 @@ $(srcdir)/so_peercred-Xraw.gen.test: $(a
 $(srcdir)/so_peercred-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/so_peercred--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sock_filter-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -13175,18 +15885,141 @@ $(srcdir)/status-all.gen.test: $(abs_src
 $(srcdir)/status-failed.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/status-failed-long.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/status-failed-status.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/status-none.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/status-successful.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/status-successful-long.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/status-successful-status.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/status-unfinished.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/statx.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/strace--absolute-timestamps.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time-precision-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time-precision-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time-precision-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time-precision-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-unix-precision-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-unix-precision-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-unix-precision-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-unix-precision-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--follow-forks-output-separately.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--strings-in-hex.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--strings-in-hex-all.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--strings-in-hex-non-ascii.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-unix-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-unix-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-unix-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-unix-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace-n.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace-x.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace-xx.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/swap.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -13217,6 +16050,24 @@ $(srcdir)/syslog.gen.test: $(abs_srcdir)
 $(srcdir)/tee.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/tgkill.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/tgkill--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/threads-execve--quiet-thread-execve.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/threads-execve-q.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/threads-execve-qq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/threads-execve-qqq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/time.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -13235,6 +16086,15 @@ $(srcdir)/times.gen.test: $(abs_srcdir)/
 $(srcdir)/times-fail.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/tkill.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/tkill--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/trace_clock.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/trace_creds.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -13280,6 +16140,9 @@ $(srcdir)/trace_statfs.gen.test: $(abs_s
 $(srcdir)/trace_statfs_like.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/trie_test.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/truncate.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -13301,6 +16164,9 @@ $(srcdir)/umovestr-illptr.gen.test: $(ab
 $(srcdir)/umovestr3.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/umovestr_cached_adjacent.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/unlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -13367,15 +16233,24 @@ $(srcdir)/xattr-strings.gen.test: $(abs_
 $(srcdir)/xet_robust_list.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/xet_robust_list--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/xetitimer.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/xetpgid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/xetpgid--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/xetpriority.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/xetpriority--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/xettimeofday.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
diff -pruN 5.5-3/tests/maybe_switch_current_tcp.c 5.9-0ubuntu2/tests/maybe_switch_current_tcp.c
--- 5.5-3/tests/maybe_switch_current_tcp.c	2019-07-16 17:46:47.000000000 +0000
+++ 5.9-0ubuntu2/tests/maybe_switch_current_tcp.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,6 +2,7 @@
  * Check for PTRACE_EVENT_EXEC diagnostics.
  *
  * Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2019-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -14,6 +15,10 @@
 #include <unistd.h>
 #include "scno.h"
 
+#ifndef QUIET_MSG
+# define QUIET_MSG 0
+#endif
+
 static pid_t leader;
 static volatile unsigned int trigger;
 
@@ -25,9 +30,14 @@ thread(void *arg)
 
 	printf("%-5d execveat(AT_FDCWD, \"%s\", [\"%s\", \"%s\", \"%s\"]"
 	       ", NULL, 0 <pid changed to %d ...>\n"
-	       "%-5d +++ superseded by execve in pid %d +++\n",
-	       tid, argv[0], argv[0], argv[1], argv[2], leader,
-	       leader, tid);
+#if !QUIET_MSG
+	       "%-5d +++ superseded by execve in pid %d +++\n"
+#endif
+	       , tid, argv[0], argv[0], argv[1], argv[2], leader
+#if !QUIET_MSG
+	       , leader, tid
+#endif
+	       );
 
 	while (!trigger) {
 		/* Wait for the parent to enter the busy loop.  */
diff -pruN 5.5-3/tests/maybe_switch_current_tcp--quiet-thread-execve.c 5.9-0ubuntu2/tests/maybe_switch_current_tcp--quiet-thread-execve.c
--- 5.5-3/tests/maybe_switch_current_tcp--quiet-thread-execve.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/maybe_switch_current_tcp--quiet-thread-execve.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define QUIET_MSG 1
+#include "maybe_switch_current_tcp.c"
diff -pruN 5.5-3/tests/maybe_switch_current_tcp--quiet-thread-execve.gen.test 5.9-0ubuntu2/tests/maybe_switch_current_tcp--quiet-thread-execve.gen.test
--- 5.5-3/tests/maybe_switch_current_tcp--quiet-thread-execve.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/maybe_switch_current_tcp--quiet-thread-execve.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (maybe_switch_current_tcp--quiet-thread-execve -a30 -s48 -f -e trace=execveat --quiet=personality,thread-execve); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a30 -s48 -f -e trace=execveat --quiet=personality,thread-execve
diff -pruN 5.5-3/tests/migrate_pages.c 5.9-0ubuntu2/tests/migrate_pages.c
--- 5.5-3/tests/migrate_pages.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/migrate_pages.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of migrate_pages syscall.
  *
  * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,6 +10,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #ifdef __NR_migrate_pages
 
@@ -19,11 +20,21 @@
 int
 main(void)
 {
-	const long pid = (long) 0xfacefeedffffffffULL;
+	PIDNS_TEST_INIT;
+
+	const long pid = (long) 0xfacefeed00000000ULL | getpid();
 	long rc = syscall(__NR_migrate_pages, pid, 0, 0, 0);
-	printf("migrate_pages(%d, 0, NULL, NULL) = %ld %s (%m)\n",
-	       (int) pid, rc, errno2name());
 
+	pidns_print_leader();
+	printf("migrate_pages(%d%s, 0, NULL, NULL) = %ld",
+		(int) pid, pidns_pid2str(PT_TGID), rc);
+
+	if (rc < 0)
+		printf(" %s (%m)\n", errno2name());
+	else
+		printf("\n");
+
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests/migrate_pages--pidns-translation.c 5.9-0ubuntu2/tests/migrate_pages--pidns-translation.c
--- 5.5-3/tests/migrate_pages--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/migrate_pages--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "migrate_pages.c"
diff -pruN 5.5-3/tests/migrate_pages--pidns-translation.gen.test 5.9-0ubuntu2/tests/migrate_pages--pidns-translation.gen.test
--- 5.5-3/tests/migrate_pages--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/migrate_pages--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (migrate_pages--pidns-translation test_pidns -a33 -e trace=migrate_pages); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a33 -e trace=migrate_pages
diff -pruN 5.5-3/tests/mknod.c 5.9-0ubuntu2/tests/mknod.c
--- 5.5-3/tests/mknod.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/mknod.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -31,44 +31,44 @@ main(int ac, char **av)
 	sample = av[0];
 
 	long rc = call_mknod(0, dev);
-	printf("mknod(\"%s\", 000) = %ld %s (%m)\n",
-	       sample, rc, errno2name());
+	printf("mknod(\"%s\", 000) = %s\n",
+	       sample, sprintrc(rc));
 
 	rc = call_mknod(0xffff, dev);
-	printf("mknod(\"%s\", %#03ho) = %ld %s (%m)\n",
-	       sample, (unsigned short) -1, rc, errno2name());
+	printf("mknod(\"%s\", %#03ho) = %s\n",
+	       sample, (unsigned short) -1, sprintrc(rc));
 
 	rc = call_mknod(S_IFREG, 0);
-	printf("mknod(\"%s\", S_IFREG|000) = %ld %s (%m)\n",
-	       sample, rc, errno2name());
+	printf("mknod(\"%s\", S_IFREG|000) = %s\n",
+	       sample, sprintrc(rc));
 
 	rc = call_mknod(S_IFDIR | 06, 0);
-	printf("mknod(\"%s\", S_IFDIR|006) = %ld %s (%m)\n",
-	       sample, rc, errno2name());
+	printf("mknod(\"%s\", S_IFDIR|006) = %s\n",
+	       sample, sprintrc(rc));
 
 	rc = call_mknod(S_IFLNK | 060, 0);
-	printf("mknod(\"%s\", S_IFLNK|060) = %ld %s (%m)\n",
-	       sample, rc, errno2name());
+	printf("mknod(\"%s\", S_IFLNK|060) = %s\n",
+	       sample, sprintrc(rc));
 
 	rc = call_mknod(S_IFIFO | 0600, 0);
-	printf("mknod(\"%s\", S_IFIFO|0600) = %ld %s (%m)\n",
-	       sample, rc, errno2name());
+	printf("mknod(\"%s\", S_IFIFO|0600) = %s\n",
+	       sample, sprintrc(rc));
 
 	dev = (unsigned long) 0xdeadbeef00000000ULL | makedev(1, 7);
 
 	rc = call_mknod(S_IFCHR | 024, dev);
-	printf("mknod(\"%s\", S_IFCHR|024, makedev(0x1, 0x7)) = %ld %s (%m)\n",
-	       sample, rc, errno2name());
+	printf("mknod(\"%s\", S_IFCHR|024, makedev(0x1, 0x7)) = %s\n",
+	       sample, sprintrc(rc));
 
 	const unsigned short mode = (0xffff & ~S_IFMT) | S_IFBLK;
 	dev = (unsigned long) 0xdeadbeefbadc0dedULL;
 
 	rc = call_mknod(mode, dev);
 	printf("mknod(\"%s\", S_IFBLK|S_ISUID|S_ISGID|S_ISVTX|%#03ho"
-	       ", makedev(%#x, %#x)) = %ld %s (%m)\n",
+	       ", makedev(%#x, %#x)) = %s\n",
 	       sample, (short) (mode & ~(S_IFMT|S_ISUID|S_ISGID|S_ISVTX)),
 	       major((unsigned) dev), minor((unsigned) dev),
-	       rc, errno2name());
+	       sprintrc(rc));
 
 	puts("+++ exited with 0 +++");
 	return 0;
diff -pruN 5.5-3/tests/move_pages.c 5.9-0ubuntu2/tests/move_pages.c
--- 5.5-3/tests/move_pages.c	2019-07-16 17:46:47.000000000 +0000
+++ 5.9-0ubuntu2/tests/move_pages.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of move_pages syscall.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,6 +10,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #ifdef __NR_move_pages
 
@@ -122,15 +123,20 @@ print_status_array(const int *const stat
 }
 
 static void
-print_stat_pages(const unsigned long pid, const unsigned long count,
-		 const void **const pages, int *const status)
+print_stat_pages(const unsigned long pid,
+		 const char *pid_str,
+		 const unsigned long count,
+		 const void **const pages,
+		 int *const status)
 {
 	const unsigned long flags = (unsigned long) 0xfacefeed00000002ULL;
 
 	long rc = syscall(__NR_move_pages,
 			  pid, count, pages, NULL, status, flags);
 	const char *errstr = sprintrc(rc);
-	printf("move_pages(%d, %lu, ", (int) pid, count);
+	pidns_print_leader();
+	printf("move_pages(%d%s, %lu, ", (int) pid, pid_str,
+		count);
 	print_page_array(pages, count, 0);
 	printf(", NULL, ");
 	if (rc) {
@@ -152,6 +158,7 @@ print_stat_pages(const unsigned long pid
 
 static void
 print_move_pages(const unsigned long pid,
+		 const char *pid_str,
 		 unsigned long count,
 		 const unsigned int offset,
 		 const void **const pages,
@@ -164,7 +171,9 @@ print_move_pages(const unsigned long pid
 	long rc = syscall(__NR_move_pages,
 			  pid, count, pages, nodes, status, flags);
 	const char *errstr = sprintrc(rc);
-	printf("move_pages(%d, %lu, ", (int) pid, count);
+	pidns_print_leader();
+	printf("move_pages(%d%s, %lu, ", (int) pid, pid_str,
+		count);
 	print_page_array(pages, count, offset);
 	printf(", ");
 	print_node_array(nodes, count, offset);
@@ -185,8 +194,11 @@ print_move_pages(const unsigned long pid
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	const unsigned long pid =
 		(unsigned long) 0xfacefeed00000000ULL | getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
 	unsigned long count = 1;
 	const unsigned page_size = get_page_size();
 	const void *const page = tail_alloc(page_size);
@@ -195,40 +207,41 @@ main(void)
 	TAIL_ALLOC_OBJECT_VAR_PTR(int, nodes);
 	TAIL_ALLOC_OBJECT_VAR_PTR(int, status);
 
-	print_stat_pages(pid, 0, pages, status);
-	print_move_pages(pid, 0, 0, pages, nodes, status);
-	print_move_pages(pid, 0, 1, pages + 1, nodes + 1, status + 1);
+	print_stat_pages(pid, pid_str, 0, pages, status);
+	print_move_pages(pid, pid_str, 0, 0, pages, nodes, status);
+	print_move_pages(pid, pid_str, 0, 1, pages + 1, nodes + 1, status + 1);
 
 	*pages = page;
-	print_stat_pages(pid, count, pages, status);
+	print_stat_pages(pid, pid_str, count, pages, status);
 	*nodes = 0xdeadbee1;
-	print_move_pages(pid, count, 0, pages, nodes, status);
-	print_move_pages(pid, count, 1, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 0, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 1, pages, nodes, status);
 
 	++count;
 	--status;
 	*(--pages) = efault;
-	print_stat_pages(pid, count, pages, status);
+	print_stat_pages(pid, pid_str, count, pages, status);
 	*(--nodes) = 0xdeadbee2;
-	print_move_pages(pid, count, 0, pages, nodes, status);
-	print_move_pages(pid, count, 1, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 0, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 1, pages, nodes, status);
 
 	++count;
 	--status;
 	*(--pages) = nodes;
-	print_stat_pages(pid, count, pages, status);
+	print_stat_pages(pid, pid_str, count, pages, status);
 	*(--nodes) = 0xdeadbee3;
-	print_move_pages(pid, count, 0, pages, nodes, status);
-	print_move_pages(pid, count, 1, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 0, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 1, pages, nodes, status);
 
 	++count;
 	--status;
 	*(--pages) = status;
-	print_stat_pages(pid, count, pages, status);
+	print_stat_pages(pid, pid_str, count, pages, status);
 	*(--nodes) = 0xdeadbee4;
-	print_move_pages(pid, count, 0, pages, nodes, status);
-	print_move_pages(pid, count, 1, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 0, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 1, pages, nodes, status);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests/move_pages--pidns-translation.c 5.9-0ubuntu2/tests/move_pages--pidns-translation.c
--- 5.5-3/tests/move_pages--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/move_pages--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "move_pages.c"
diff -pruN 5.5-3/tests/move_pages--pidns-translation.gen.test 5.9-0ubuntu2/tests/move_pages--pidns-translation.gen.test
--- 5.5-3/tests/move_pages--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/move_pages--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (move_pages--pidns-translation test_pidns -s3 -e trace=move_pages); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -s3 -e trace=move_pages
diff -pruN 5.5-3/tests/msg_control.c 5.9-0ubuntu2/tests/msg_control.c
--- 5.5-3/tests/msg_control.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests/msg_control.c	2020-04-19 01:22:29.000000000 +0000
@@ -25,6 +25,9 @@
 # include <linux/time_types.h>
 #endif
 
+#include "kernel_timeval.h"
+#include "kernel_old_timespec.h"
+
 #include "xlat.h"
 #define XLAT_MACROS_ONLY
 #include "xlat/sock_options.h"
@@ -214,7 +217,7 @@ test_scm_rights3(struct msghdr *const mh
 static void
 test_scm_timestamp_old(struct msghdr *const mh, void *const page)
 {
-	static const struct timeval tv = {
+	static const kernel_old_timeval_t tv = {
 		.tv_sec = 123456789,
 		.tv_usec = 987654
 	};
@@ -261,7 +264,7 @@ test_scm_timestamp_old(struct msghdr *co
 static void
 test_scm_timestampns_old(struct msghdr *const mh, void *const page)
 {
-	static const struct timespec ts = {
+	static const kernel_old_timespec_t ts = {
 		.tv_sec = 123456789,
 		.tv_nsec = 987654321
 	};
@@ -309,7 +312,7 @@ test_scm_timestampns_old(struct msghdr *
 static void
 test_scm_timestamping_old(struct msghdr *const mh, void *const page)
 {
-	static const struct timespec ts[] = {
+	static const kernel_old_timespec_t ts[] = {
 		{ .tv_sec = 123456789, .tv_nsec = 987654321 },
 		{ .tv_sec = 123456790, .tv_nsec = 987654320 },
 		{ .tv_sec = 123456791, .tv_nsec = 987654319 }
diff -pruN 5.5-3/tests/net--decode-fds-dev-netlink.c 5.9-0ubuntu2/tests/net--decode-fds-dev-netlink.c
--- 5.5-3/tests/net--decode-fds-dev-netlink.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/net--decode-fds-dev-netlink.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_SOCK 1
+#include "net-yy-netlink.c"
diff -pruN 5.5-3/tests/net--decode-fds-dev-netlink.gen.test 5.9-0ubuntu2/tests/net--decode-fds-dev-netlink.gen.test
--- 5.5-3/tests/net--decode-fds-dev-netlink.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/net--decode-fds-dev-netlink.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (net--decode-fds-dev-netlink +net-yy-netlink.test --decode-fds=dev); do not edit.
+set -- --decode-fds=dev
+. "${srcdir=.}/net-yy-netlink.test"
diff -pruN 5.5-3/tests/net--decode-fds-none-netlink.c 5.9-0ubuntu2/tests/net--decode-fds-none-netlink.c
--- 5.5-3/tests/net--decode-fds-none-netlink.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/net--decode-fds-none-netlink.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_SOCK 0
+#include "net-yy-netlink.c"
diff -pruN 5.5-3/tests/net--decode-fds-none-netlink.gen.test 5.9-0ubuntu2/tests/net--decode-fds-none-netlink.gen.test
--- 5.5-3/tests/net--decode-fds-none-netlink.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/net--decode-fds-none-netlink.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (net--decode-fds-none-netlink +net-yy-netlink.test --decode-fds=none -a9); do not edit.
+set -- --decode-fds=none -a9
+. "${srcdir=.}/net-yy-netlink.test"
diff -pruN 5.5-3/tests/net--decode-fds-path-netlink.c 5.9-0ubuntu2/tests/net--decode-fds-path-netlink.c
--- 5.5-3/tests/net--decode-fds-path-netlink.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/net--decode-fds-path-netlink.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_SOCK 1
+#include "net-yy-netlink.c"
diff -pruN 5.5-3/tests/net--decode-fds-path-netlink.gen.test 5.9-0ubuntu2/tests/net--decode-fds-path-netlink.gen.test
--- 5.5-3/tests/net--decode-fds-path-netlink.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/net--decode-fds-path-netlink.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (net--decode-fds-path-netlink +net-yy-netlink.test --decode-fds=path); do not edit.
+set -- --decode-fds=path
+. "${srcdir=.}/net-yy-netlink.test"
diff -pruN 5.5-3/tests/net--decode-fds-socket-netlink.c 5.9-0ubuntu2/tests/net--decode-fds-socket-netlink.c
--- 5.5-3/tests/net--decode-fds-socket-netlink.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/net--decode-fds-socket-netlink.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_SOCK 2
+#include "net-yy-netlink.c"
diff -pruN 5.5-3/tests/net--decode-fds-socket-netlink.gen.test 5.9-0ubuntu2/tests/net--decode-fds-socket-netlink.gen.test
--- 5.5-3/tests/net--decode-fds-socket-netlink.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/net--decode-fds-socket-netlink.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (net--decode-fds-socket-netlink +net-yy-netlink.test --decode-fds=socket); do not edit.
+set -- --decode-fds=socket
+. "${srcdir=.}/net-yy-netlink.test"
diff -pruN 5.5-3/tests/netlink_audit.c 5.9-0ubuntu2/tests/netlink_audit.c
--- 5.5-3/tests/netlink_audit.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/netlink_audit.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,12 +1,13 @@
 /*
  * Copyright (c) 2017 JingPiao Chen <chenjingpiao@gmail.com>
- * Copyright (c) 2017-2018 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include "pidns.h"
 #include <stdio.h>
 #include <string.h>
 #include <unistd.h>
@@ -17,18 +18,23 @@
 static void
 test_nlmsg_type(const int fd)
 {
+	PIDNS_TEST_INIT;
+
 	long rc;
 	struct nlmsghdr nlh = {
 		.nlmsg_len = sizeof(nlh),
 		.nlmsg_type = AUDIT_GET,
 		.nlmsg_flags = NLM_F_REQUEST,
+		.nlmsg_pid = getpid(),
 	};
 
 	rc = sendto(fd, &nlh, sizeof(nlh), MSG_DONTWAIT, NULL, 0);
+	pidns_print_leader();
 	printf("sendto(%d, {len=%u, type=AUDIT_GET"
-	       ", flags=NLM_F_REQUEST, seq=0, pid=0}"
+	       ", flags=NLM_F_REQUEST, seq=0, pid=%d%s}"
 	       ", %u, MSG_DONTWAIT, NULL, 0) = %s\n",
-	       fd, nlh.nlmsg_len, (unsigned) sizeof(nlh), sprintrc(rc));
+	       fd, nlh.nlmsg_len, nlh.nlmsg_pid, pidns_pid2str(PT_TGID),
+	       (unsigned) sizeof(nlh), sprintrc(rc));
 }
 
 int main(void)
@@ -39,6 +45,7 @@ int main(void)
 
 	test_nlmsg_type(fd);
 
+	pidns_print_leader();
 	printf("+++ exited with 0 +++\n");
 
 	return 0;
diff -pruN 5.5-3/tests/netlink_audit--pidns-translation.c 5.9-0ubuntu2/tests/netlink_audit--pidns-translation.c
--- 5.5-3/tests/netlink_audit--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/netlink_audit--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "netlink_audit.c"
diff -pruN 5.5-3/tests/netlink_audit--pidns-translation.test 5.9-0ubuntu2/tests/netlink_audit--pidns-translation.test
--- 5.5-3/tests/netlink_audit--pidns-translation.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/netlink_audit--pidns-translation.test	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,13 @@
+#!/bin/sh
+#
+# Check pidns translation of NETLINK_SOCK_DIAG protocol decoding
+#
+# Copyright (c) 2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: LGPL-2.1-or-later
+
+. "${srcdir=.}/init.sh"
+
+run_prog ../netlink_netlink_diag
+test_pidns -e trace=sendto "$@"
diff -pruN 5.5-3/tests/netlink_protocol.c 5.9-0ubuntu2/tests/netlink_protocol.c
--- 5.5-3/tests/netlink_protocol.c	2018-12-30 15:35:21.000000000 +0000
+++ 5.9-0ubuntu2/tests/netlink_protocol.c	2020-08-03 08:00:00.000000000 +0000
@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2014-2017 Dmitry V. Levin <ldv@altlinux.org>
  * Copyright (c) 2016 Fabien Siron <fabien.siron@epita.fr>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -264,7 +264,7 @@ test_nlmsgerr(const int fd)
 	printf("sendto(%d, {{len=%u, type=NLMSG_ERROR, flags=NLM_F_REQUEST"
 	       ", seq=0, pid=0}, {error=-EACCES"
 	       ", msg={len=%u, type=NLMSG_NOOP, flags=NLM_F_REQUEST|0x%x"
-	       ", seq=%u, pid=%u}}}, %u, MSG_DONTWAIT, NULL, 0) = %s\n",
+	       ", seq=%u, pid=%d}}}, %u, MSG_DONTWAIT, NULL, 0) = %s\n",
 	       fd, nlh->nlmsg_len, err->msg.nlmsg_len, NLM_F_DUMP,
 	       err->msg.nlmsg_seq, err->msg.nlmsg_pid,
 	       nlh->nlmsg_len, sprintrc(rc));
@@ -289,7 +289,7 @@ test_nlmsgerr(const int fd)
 	printf("sendto(%d, {{len=%u, type=NLMSG_ERROR, flags=NLM_F_REQUEST"
 	       ", seq=0, pid=0}, {error=-EACCES"
 	       ", msg={{len=%u, type=NLMSG_NOOP, flags=NLM_F_REQUEST|0x%x"
-	       ", seq=%u, pid=%u}, \"\\x61\\x62\\x63\\x64\"}}}"
+	       ", seq=%u, pid=%d}, \"\\x61\\x62\\x63\\x64\"}}}"
 	       ", %u, MSG_DONTWAIT, NULL, 0) = %s\n",
 	       fd, nlh->nlmsg_len, err->msg.nlmsg_len, NLM_F_DUMP,
 	       err->msg.nlmsg_seq, err->msg.nlmsg_pid,
diff -pruN 5.5-3/tests/netlink_sock_diag.test 5.9-0ubuntu2/tests/netlink_sock_diag.test
--- 5.5-3/tests/netlink_sock_diag.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/netlink_sock_diag.test	2020-06-01 14:15:16.000000000 +0000
@@ -2,7 +2,7 @@
 #
 # Check decoding of NETLINK_SOCK_DIAG protocol
 #
-# Copyright (c) 2017-2018 The strace developers.
+# Copyright (c) 2017-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,4 +10,4 @@
 . "${srcdir=.}/init.sh"
 
 run_prog ../netlink_netlink_diag
-run_strace_match_diff -e trace=sendto
+run_strace_match_diff -e trace=sendto "$@"
diff -pruN 5.5-3/tests/netlink_sock_diag-v.sh 5.9-0ubuntu2/tests/netlink_sock_diag-v.sh
--- 5.5-3/tests/netlink_sock_diag-v.sh	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/netlink_sock_diag-v.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,13 +0,0 @@
-#!/bin/sh
-#
-# Check verbose decoding of NETLINK_SOCK_DIAG protocol
-#
-# Copyright (c) 2017-2018 The strace developers.
-# All rights reserved.
-#
-# SPDX-License-Identifier: GPL-2.0-or-later
-
-. "${srcdir=.}/init.sh"
-
-run_prog ../netlink_netlink_diag
-run_strace_match_diff -v -e trace=sendto
diff -pruN 5.5-3/tests/net-sockaddr.c 5.9-0ubuntu2/tests/net-sockaddr.c
--- 5.5-3/tests/net-sockaddr.c	2019-08-29 17:20:57.000000000 +0000
+++ 5.9-0ubuntu2/tests/net-sockaddr.c	2020-08-25 14:29:30.000000000 +0000
@@ -2,13 +2,14 @@
  * Check decoding of sockaddr structures
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include "pidns.h"
 #include <stddef.h>
 #include <stdio.h>
 #include <string.h>
@@ -40,18 +41,21 @@ check_un(void)
 	memset(un->sun_path, '0', sizeof(un->sun_path));
 	unsigned int len = sizeof(*un);
 	int ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=\"%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n",
 	       (int) sizeof(un->sun_path), 0, len, ret);
 
 	un->sun_path[1] = 0;
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=\"%u\"}, %u)"
 	       " = %d EBADF (%m)\n", 0, len, ret);
 
 	un->sun_path[0] = 0;
 	un->sun_path[2] = 1;
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=@\"\\0\\001%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n",
 	       (int) sizeof(un->sun_path) - 3, 0, len, ret);
@@ -61,12 +65,14 @@ check_un(void)
 	memset(un->sun_path, '0', sizeof(un->sun_path));
 	len = sizeof(*un) + 2;
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=\"%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n",
 	       (int) sizeof(un->sun_path), 0, len, ret);
 
 	un->sun_path[0] = 0;
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=@\"%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n",
 	       (int) sizeof(un->sun_path) - 1, 0, len, ret);
@@ -75,18 +81,21 @@ check_un(void)
 	un->sun_family = AF_UNIX;
 	len = sizeof(*un) - 2;
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=\"%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n",
 	       (int) sizeof(un->sun_path) - 2, 0, len, ret);
 
 	un->sun_path[0] = 0;
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=@\"%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n",
 	       (int) sizeof(un->sun_path) - 3, 0, len, ret);
 
 	len = sizeof(*un);
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, %p, %u) = %d EBADF (%m)\n", un, len, ret);
 
 	un = tail_alloc(sizeof(struct sockaddr_storage));
@@ -94,12 +103,14 @@ check_un(void)
 	memset(un->sun_path, '0', sizeof(un->sun_path));
 	len = sizeof(struct sockaddr_storage) + 1;
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=\"%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n",
 	       (int) sizeof(un->sun_path), 0, len, ret);
 
 	un->sun_path[0] = 0;
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=@\"%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n",
 	       (int) sizeof(un->sun_path) - 1, 0, len, ret);
@@ -117,6 +128,7 @@ check_in(void)
 	in->sin_addr.s_addr = inet_addr(h_addr);
 	unsigned int len = sizeof(*in);
 	int ret = connect(-1, (void *) in, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_INET, sin_port=htons(%hu)"
 	       ", sin_addr=inet_addr(\"%s\")}, %u) = %d EBADF (%m)\n",
 	       h_port, h_addr, len, ret);
@@ -127,6 +139,7 @@ check_in(void)
 	in->sin_addr.s_addr = inet_addr(h_addr);
 	len = sizeof(*in) + 4;
 	ret = connect(-1, (void *) in, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_INET, sin_port=htons(%hu)"
 	       ", sin_addr=inet_addr(\"%s\")}, %u) = %d EBADF (%m)\n",
 	       h_port, h_addr, len, ret);
@@ -137,6 +150,7 @@ check_in(void)
 	in->sin_addr.s_addr = 0;
 	len = sizeof(*in) - 4;
 	ret = connect(-1, (void *) in, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_INET, sa_data=\"%s\"}, %u)"
 	       " = %d EBADF (%m)\n",
 	       "\\0\\0\\0\\0\\0\\0\\377\\377\\377\\377",
@@ -144,6 +158,7 @@ check_in(void)
 
 	len = sizeof(*in);
 	ret = connect(-1, (void *) in, len);
+	pidns_print_leader();
 	printf("connect(-1, %p, %u) = %d EBADF (%m)\n", in, len, ret);
 }
 
@@ -155,6 +170,7 @@ check_in6_linklocal(struct sockaddr_in6
 	in6->sin6_scope_id = 0xfacefeed;
 	unsigned int len = sizeof(*in6);
 	int ret = connect(-1, (void *) in6, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_INET6, sin6_port=htons(%hu)"
 	       ", sin6_flowinfo=htonl(%u)"
 	       ", inet_pton(AF_INET6, \"%s\", &sin6_addr)"
@@ -166,7 +182,8 @@ check_in6_linklocal(struct sockaddr_in6
 	in6->sin6_scope_id = ifindex_lo();
 	if (in6->sin6_scope_id) {
 		ret = connect(-1, (void *) in6, len);
-		printf("connect(-1, {sa_family=AF_INET6, sin6_port=htons(%hu)"
+		pidns_print_leader();
+	printf("connect(-1, {sa_family=AF_INET6, sin6_port=htons(%hu)"
 		       ", sin6_flowinfo=htonl(%u)"
 		       ", inet_pton(AF_INET6, \"%s\", &sin6_addr)"
 		       ", sin6_scope_id=%s}, %u)"
@@ -191,6 +208,7 @@ check_in6(void)
 	in6->sin6_scope_id = 0xfacefeed;
 	unsigned int len = sizeof(*in6);
 	int ret = connect(-1, (void *) in6, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_INET6, sin6_port=htons(%hu)"
 	       ", sin6_flowinfo=htonl(%u)"
 	       ", inet_pton(AF_INET6, \"%s\", &sin6_addr)"
@@ -209,6 +227,7 @@ check_in6(void)
 	in6->sin6_scope_id = 0xfacefeed;
 	len = sizeof(*in6) + 4;
 	ret = connect(-1, (void *) in6, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_INET6, sin6_port=htons(%hu)"
 	       ", sin6_flowinfo=htonl(%u)"
 	       ", inet_pton(AF_INET6, \"%s\", &sin6_addr)"
@@ -223,6 +242,7 @@ check_in6(void)
 	inet_pton(AF_INET6, h_addr, &in6->sin6_addr);
 	len = sizeof(*in6) - sizeof(in6->sin6_scope_id);
 	ret = connect(-1, (void *) in6, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_INET6, sin6_port=htons(%hu)"
 	       ", sin6_flowinfo=htonl(%u)"
 	       ", inet_pton(AF_INET6, \"%s\", &sin6_addr)}, %u)"
@@ -236,6 +256,7 @@ check_in6(void)
 	memset(&in6->sin6_addr, '0', sizeof(in6->sin6_addr) - 4);
 	len = sizeof(*in6) - sizeof(in6->sin6_scope_id) - 4;
 	ret = connect(-1, (void *) in6, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_INET6"
 	       ", sa_data=\"\\0\\0\\0\\0\\0\\000%.*u\"}, %u)"
 	       " = %d EBADF (%m)\n",
@@ -244,6 +265,7 @@ check_in6(void)
 
 	len = sizeof(*in6) - sizeof(in6->sin6_scope_id);
 	ret = connect(-1, (void *) in6, len);
+	pidns_print_leader();
 	printf("connect(-1, %p, %u) = %d EBADF (%m)\n", in6, len, ret);
 }
 
@@ -262,6 +284,7 @@ check_ipx(void)
 	void *ipx = tail_memdup(&c_ipx, sizeof(c_ipx));
 	unsigned int len = sizeof(c_ipx);
 	int ret = connect(-1, ipx, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_IPX, sipx_port=htons(%u)"
 	       ", sipx_network=htonl(%#x)"
 	       ", sipx_node=[%#02x, %#02x, %#02x, %#02x, %#02x, %#02x]"
@@ -316,18 +339,21 @@ check_ax25(void)
 	fill_memory(sax, size);
 	sax->fsa_ax25.sax25_family = AF_AX25;
 	rc = connect(-1, sax_void, sizeof(struct sockaddr_ax25) - 1);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_AX25, sa_data=\"\\202\\203\\204\\205"
 	       "\\206\\207\\210\\211\\212\\213\\214\\215\\216\"}, %zu) = %s\n",
 	       sizeof(struct sockaddr_ax25) - 1, sprintrc(rc));
 
 	memcpy(sax, &ax25, sizeof(ax25));
 	rc = connect(-1, sax_void, sizeof(struct sockaddr_ax25));
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_AX25, fsa_ax25={sax25_call=VALID-13"
 	       ", sax25_ndigis=8}, fsa_digipeater=[/* ??? */]}, %zu) = %s\n",
 	       sizeof(struct sockaddr_ax25), sprintrc(rc));
 
 	sax->fsa_ax25.sax25_ndigis = 0;
 	rc = connect(-1, sax_void, sizeof(struct sockaddr_ax25));
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_AX25, sax25_call=VALID-13"
 	       ", sax25_ndigis=0}, %zu) = %s\n",
 	       sizeof(struct sockaddr_ax25), sprintrc(rc));
@@ -335,6 +361,7 @@ check_ax25(void)
 	sax->fsa_ax25.sax25_ndigis = 8;
 	size = sizeof(struct sockaddr_ax25) + sizeof(ax25_address) * 3 + 1;
 	rc = connect(-1, sax_void, size);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_AX25, fsa_ax25={sax25_call=VALID-13"
 	       ", sax25_ndigis=8}, fsa_digipeater"
 	       "=[{ax25_call=\"\\xa6\\xa0\\x82\\x40\\x86\\x8a\\x00\""
@@ -348,6 +375,7 @@ check_ax25(void)
 	sax->fsa_digipeater[2].ax25_call[6] = 0x4;
 	size = sizeof(struct sockaddr_ax25) + sizeof(ax25_address) * 4;
 	rc = connect(-1, sax_void, size);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_AX25, fsa_ax25={sax25_call=VALID-13"
 	       ", sax25_ndigis=8}, fsa_digipeater"
 	       "=[{ax25_call=\"\\xa6\\xa0\\x82\\x40\\x86\\x8a\\x00\""
@@ -365,6 +393,7 @@ check_ax25(void)
 	for (size_t i = 0; i < 3; i++) {
 		size = sizeof(ax25) + sizeof(ax25_address) * (i / 2);
 		rc = connect(-1, sax_void, size);
+		pidns_print_leader();
 		printf("connect(-1, {sa_family=AF_AX25"
 		       ", fsa_ax25={sax25_call=VALID-13, sax25_ndigis=%d}"
 		       ", fsa_digipeater=[VALID2-7, OK-15, %s /* FINE-2 */"
@@ -423,25 +452,28 @@ check_x25(void)
 		.sx25_family = AF_X25,
 		.sx25_addr = { "0123456789abcdef" },
 	};
-	void *x25_void = tail_memdup(&c_x25, sizeof(c_x25) + 1);
-	struct sockaddr_x25 *x25 = x25_void;
+	void *const x25_void = tail_memdup(&c_x25, sizeof(c_x25) + 1);
 	long rc;
 
-	rc = connect(-1, x25, sizeof(c_x25) - 1);
+	rc = connect(-1, x25_void, sizeof(c_x25) - 1);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_X25"
 	       ", sa_data=\"0123456789abcde\"}, %zu) = %s\n",
 	       sizeof(c_x25) - 1, sprintrc(rc));
 
 	for (size_t i = 0; i < 2; i++) {
-		rc = connect(-1, x25, sizeof(c_x25) + i);
+		rc = connect(-1, x25_void, sizeof(c_x25) + i);
+		pidns_print_leader();
 		printf("connect(-1, {sa_family=AF_X25"
 		       ", sx25_addr={x25_addr=\"0123456789abcde\"...}"
 		       "}, %zu) = %s\n",
 		       sizeof(c_x25) + i, sprintrc(rc));
 	}
 
+	struct sockaddr_x25 *const x25 = x25_void;
 	x25->sx25_addr.x25_addr[10] = '\0';
-	rc = connect(-1, x25, sizeof(c_x25));
+	rc = connect(-1, x25_void, sizeof(c_x25));
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_X25"
 	       ", sx25_addr={x25_addr=\"0123456789\"}"
 	       "}, %zu) = %s\n",
@@ -457,19 +489,21 @@ check_nl(void)
 	nl->nl_groups = 0xfacefeed;
 	unsigned int len = sizeof(*nl);
 	int ret = connect(-1, (void *) nl, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_NETLINK, nl_pid=%d"
 	       ", nl_groups=%#08x}, %u) = %d EBADF (%m)\n",
 	       nl->nl_pid, nl->nl_groups, len, ret);
 
 	nl = ((void *) nl) - 4;
 	nl->nl_family = AF_NETLINK;
-	nl->nl_pid = 1234567890;
+	nl->nl_pid = getpid();
 	nl->nl_groups = 0xfacefeed;
 	len = sizeof(*nl) + 4;
 	ret = connect(-1, (void *) nl, len);
-	printf("connect(-1, {sa_family=AF_NETLINK, nl_pid=%d"
+	pidns_print_leader();
+	printf("connect(-1, {sa_family=AF_NETLINK, nl_pid=%d%s"
 	       ", nl_groups=%#08x}, %u) = %d EBADF (%m)\n",
-	       nl->nl_pid, nl->nl_groups, len, ret);
+	       nl->nl_pid, pidns_pid2str(PT_TGID), nl->nl_groups, len, ret);
 }
 
 static void
@@ -487,6 +521,7 @@ check_ll(void)
 	void *ll = tail_memdup(&c_ll, sizeof(c_ll));
 	unsigned int len = sizeof(c_ll);
 	int ret = connect(-1, ll, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_PACKET"
 	       ", sll_protocol=htons(ETH_P_ALL)"
 	       ", sll_ifindex=%u, sll_hatype=ARPHRD_ETHER"
@@ -502,6 +537,7 @@ check_ll(void)
 
 	((struct sockaddr_ll *) ll)->sll_halen++;
 	ret = connect(-1, ll, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_PACKET"
 	       ", sll_protocol=htons(ETH_P_ALL)"
 	       ", sll_ifindex=%u, sll_hatype=ARPHRD_ETHER"
@@ -517,6 +553,7 @@ check_ll(void)
 
 	((struct sockaddr_ll *) ll)->sll_halen = 0;
 	ret = connect(-1, ll, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_PACKET"
 	       ", sll_protocol=htons(ETH_P_ALL)"
 	       ", sll_ifindex=%u, sll_hatype=ARPHRD_ETHER"
@@ -526,6 +563,7 @@ check_ll(void)
 	((struct sockaddr_ll *) ll)->sll_ifindex = ifindex_lo();
 	if (((struct sockaddr_ll *) ll)->sll_ifindex) {
 		ret = connect(-1, ll, len);
+	pidns_print_leader();
 		printf("connect(-1, {sa_family=AF_PACKET"
 		       ", sll_protocol=htons(ETH_P_ALL)"
 		       ", sll_ifindex=%s"
@@ -549,11 +587,13 @@ check_hci(void)
 	unsigned int len = sizeof(*hci);
 
 	int ret = connect(-1, (void *) hci, 4);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH, hci_dev=htobs(%hu)"
 	       "}, 4) = %d EBADF (%m)\n",
 	       h_port, ret);
 
 	ret = connect(-1, (void *) hci, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH, hci_dev=htobs(%hu)"
 # ifdef HAVE_STRUCT_SOCKADDR_HCI_HCI_CHANNEL
 	       ", hci_channel=HCI_CHANNEL_RAW"
@@ -572,6 +612,7 @@ check_sco(void)
 	void *sco = tail_memdup(&c_sco, sizeof(c_sco));
 	unsigned int len = sizeof(c_sco);
 	int ret = connect(-1, sco, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH"
 	       ", sco_bdaddr=%02x:%02x:%02x:%02x:%02x:%02x"
 	       "}, %u) = %d EBADF (%m)\n",
@@ -592,6 +633,7 @@ check_rc(void)
 	void *rc = tail_memdup(&c_rc, sizeof(c_rc));
 	unsigned int len = sizeof(c_rc);
 	int ret = connect(-1, rc, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH"
 	       ", rc_bdaddr=%02x:%02x:%02x:%02x:%02x:%02x"
 	       ", rc_channel=%u}, %u) = %d EBADF (%m)\n",
@@ -619,6 +661,7 @@ check_l2(void)
 	unsigned int len = sizeof(c_l2);
 
 	int ret = connect(-1, l2, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH"
 	       ", l2_psm=htobs(L2CAP_PSM_DYN_START + %hu)"
 	       ", l2_bdaddr=%02x:%02x:%02x:%02x:%02x:%02x"
@@ -640,6 +683,7 @@ check_l2(void)
 # endif
 	memcpy(l2, &c_l2, sizeof(c_l2));
 	ret = connect(-1, l2, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH"
 	       ", l2_psm=htobs(L2CAP_PSM_SDP)"
 	       ", l2_bdaddr=%02x:%02x:%02x:%02x:%02x:%02x"
@@ -660,6 +704,7 @@ check_l2(void)
 # endif
 	memcpy(l2, &c_l2, sizeof(c_l2));
 	ret = connect(-1, l2, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH"
 	       ", l2_psm=htobs(0xbad /* L2CAP_PSM_??? */)"
 	       ", l2_bdaddr=%02x:%02x:%02x:%02x:%02x:%02x"
@@ -677,6 +722,7 @@ check_l2(void)
 	c_l2.l2_cid = htobs(0xffff);
 	memcpy(l2, &c_l2, 12);
 	ret = connect(-1, l2, 12);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH"
 	       ", l2_psm=htobs(L2CAP_PSM_AUTO_END)"
 	       ", l2_bdaddr=%02x:%02x:%02x:%02x:%02x:%02x"
@@ -700,6 +746,7 @@ check_raw(void)
 	u.sa->sa_family = 0xff;
 	unsigned int len = sizeof(*u.st) + 8;
 	int ret = connect(-1, (void *) u.st, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=%#x /* AF_??? */, sa_data=\"%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n", u.sa->sa_family,
 	       (int) (sizeof(*u.st) - sizeof(u.sa->sa_family)), 0, len, ret);
@@ -707,11 +754,13 @@ check_raw(void)
 	u.sa->sa_family = 0;
 	len = sizeof(u.sa->sa_family) + 1;
 	ret = connect(-1, (void *) u.st, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNSPEC, sa_data=\"0\"}, %u)"
 	       " = %d EBADF (%m)\n", len, ret);
 
 	u.sa->sa_family = AF_BLUETOOTH;
 	ret = connect(-1, (void *) u.st, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH, sa_data=\"0\"}, %u)"
 	       " = %d EBADF (%m)\n", len, ret);
 }
@@ -719,6 +768,8 @@ check_raw(void)
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	check_un();
 	check_in();
 	check_in6();
@@ -735,6 +786,7 @@ main(void)
 #endif
 	check_raw();
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests/net-sockaddr--pidns-translation.c 5.9-0ubuntu2/tests/net-sockaddr--pidns-translation.c
--- 5.5-3/tests/net-sockaddr--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/net-sockaddr--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "net-sockaddr.c"
diff -pruN 5.5-3/tests/net-sockaddr--pidns-translation.gen.test 5.9-0ubuntu2/tests/net-sockaddr--pidns-translation.gen.test
--- 5.5-3/tests/net-sockaddr--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/net-sockaddr--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (net-sockaddr--pidns-translation test_pidns -a24 -e trace=connect); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a24 -e trace=connect
diff -pruN 5.5-3/tests/net-yy-netlink.c 5.9-0ubuntu2/tests/net-yy-netlink.c
--- 5.5-3/tests/net-yy-netlink.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/net-yy-netlink.c	2020-07-18 08:00:00.000000000 +0000
@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2013-2017 Dmitry V. Levin <ldv@altlinux.org>
  * Copyright (c) 2016 Fabien Siron <fabien.siron@epita.fr>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -21,6 +21,27 @@
 #include <linux/sock_diag.h>
 #include <linux/netlink_diag.h>
 
+#ifndef PRINT_SOCK
+# define PRINT_SOCK 2
+#endif
+
+#if PRINT_SOCK == 2
+# define FMT_UNBOUND "<NETLINK:[%lu]>"
+# define FMT_BOUND   "<NETLINK:[SOCK_DIAG:%u]>"
+# define ARG_UNBOUND inode
+# define ARG_BOUND   addr.nl_pid
+#elif PRINT_SOCK == 1
+# define FMT_UNBOUND "<socket:[%lu]>"
+# define FMT_BOUND   "<socket:[%lu]>"
+# define ARG_UNBOUND inode
+# define ARG_BOUND   inode
+#else
+# define FMT_UNBOUND "%s"
+# define FMT_BOUND   "%s"
+# define ARG_UNBOUND ""
+# define ARG_BOUND   ""
+#endif
+
 int
 main(void)
 {
@@ -37,25 +58,27 @@ main(void)
 	const int fd = socket(AF_NETLINK, SOCK_RAW, NETLINK_SOCK_DIAG);
 	if (fd < 0)
 		perror_msg_and_skip("socket");
+#if PRINT_SOCK
 	const unsigned long inode = inode_of_sockfd(fd);
+#endif
 	printf("socket(AF_NETLINK, SOCK_RAW, NETLINK_SOCK_DIAG) = "
-	       "%d<NETLINK:[%lu]>\n", fd, inode);
+	       "%d" FMT_UNBOUND "\n", fd, ARG_UNBOUND);
 
 	if (bind(fd, sa, *len))
 		perror_msg_and_skip("bind");
-	printf("bind(%d<NETLINK:[%lu]>, {sa_family=AF_NETLINK"
-	       ", nl_pid=%u, nl_groups=00000000}, %u) = 0\n",
-	       fd, inode, addr.nl_pid, (unsigned) *len);
+	printf("bind(%d" FMT_UNBOUND ", {sa_family=AF_NETLINK"
+	       ", nl_pid=%d, nl_groups=00000000}, %u) = 0\n",
+	       fd, ARG_UNBOUND, addr.nl_pid, (unsigned) *len);
 
 	if (getsockname(fd, sa, len))
 		perror_msg_and_fail("getsockname");
-	printf("getsockname(%d<NETLINK:[SOCK_DIAG:%u]>, {sa_family=AF_NETLINK"
-	       ", nl_pid=%u, nl_groups=00000000}, [%u]) = 0\n",
-	       fd, addr.nl_pid, addr.nl_pid, (unsigned) *len);
+	printf("getsockname(%d" FMT_BOUND ", {sa_family=AF_NETLINK"
+	       ", nl_pid=%d, nl_groups=00000000}, [%u]) = 0\n",
+	       fd, ARG_BOUND, addr.nl_pid, (unsigned) *len);
 
 	if (close(fd))
 		perror_msg_and_fail("close");
-	printf("close(%d<NETLINK:[SOCK_DIAG:%u]>) = 0\n", fd, addr.nl_pid);
+	printf("close(%d" FMT_BOUND ") = 0\n", fd, ARG_BOUND);
 
 	puts("+++ exited with 0 +++");
 	return 0;
diff -pruN 5.5-3/tests/net-yy-netlink.test 5.9-0ubuntu2/tests/net-yy-netlink.test
--- 5.5-3/tests/net-yy-netlink.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/net-yy-netlink.test	2020-04-03 22:58:26.000000000 +0000
@@ -6,7 +6,7 @@
 # Copyright (c) 2014 Masatake YAMATO <yamato@redhat.com>
 # Copyright (c) 2014-2016 Dmitry V. Levin <ldv@altlinux.org>
 # Copyright (c) 2016 Fabien Siron <fabien.siron@epita.fr>
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -15,9 +15,11 @@
 
 check_prog sed
 
+opts="${*:--yy}"
+
 run_prog ../netlink_netlink_diag
 run_prog > /dev/null
-run_strace -a22 -yy -eclose,network $args > "$EXP"
+run_strace -a22 ${opts} -eclose,network $args > "$EXP"
 
 # Filter out close() calls made by ld.so and libc.
 sed -n '/socket/,$p' < "$LOG" > "$OUT"
diff -pruN 5.5-3/tests/nlattr_ifinfomsg.c 5.9-0ubuntu2/tests/nlattr_ifinfomsg.c
--- 5.5-3/tests/nlattr_ifinfomsg.c	2019-11-28 19:30:05.000000000 +0000
+++ 5.9-0ubuntu2/tests/nlattr_ifinfomsg.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2017 JingPiao Chen <chenjingpiao@gmail.com>
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -27,6 +27,8 @@
 #endif
 #define IFLA_LINK_NETNSID 37
 #define IFLA_EVENT 44
+#define IFLA_PROP_LIST 52
+#define IFLA_ALT_IFNAME 53
 
 #ifndef IFLA_INFO_KIND
 # define IFLA_INFO_KIND 1
@@ -36,6 +38,8 @@
 # define IFLA_VF_PORT 1
 #endif
 
+static const unsigned int hdrlen = sizeof(struct ifinfomsg);
+
 static void
 init_ifinfomsg(struct nlmsghdr *const nlh, const unsigned int msg_len)
 {
@@ -65,6 +69,27 @@ print_ifinfomsg(const unsigned int msg_l
 	       msg_len);
 }
 
+static void
+init_prop_list_msg(struct nlmsghdr *const nlh,
+		     const unsigned int msg_len)
+{
+	init_ifinfomsg(nlh, msg_len);
+
+	struct nlattr *nla = NLMSG_ATTR(nlh, hdrlen);
+	SET_STRUCT(struct nlattr, nla,
+		.nla_len = msg_len - NLMSG_SPACE(hdrlen),
+		.nla_type = IFLA_PROP_LIST,
+	);
+}
+
+static void
+print_prop_list_msg(const unsigned int msg_len)
+{
+	print_ifinfomsg(msg_len);
+	printf(", {{nla_len=%u, nla_type=IFLA_PROP_LIST}",
+	       msg_len - NLMSG_SPACE(hdrlen));
+}
+
 int
 main(void)
 {
@@ -96,9 +121,8 @@ main(void)
 		.tx_compressed = 0xefdadfab
 	};
 	const int fd = create_nl_socket(NETLINK_ROUTE);
-	const unsigned int hdrlen = sizeof(struct ifinfomsg);
 	void *nlh0 = midtail_alloc(NLMSG_SPACE(hdrlen),
-				   NLA_HDRLEN + sizeof(st));
+				   2 * NLA_HDRLEN + MAX(sizeof(st), 20));
 
 	static char pattern[4096];
 	fill_memory_ex(pattern, sizeof(pattern), 'a', 'z' - 'a' + 1);
@@ -339,6 +363,33 @@ main(void)
 				   printf("%s", ifla_events[i].str));
 	}
 
+	/* IFLA_PROP_LIST */
+	struct {
+		char p1[20];
+	} buf;
+	fill_memory(&buf, sizeof(buf));
+	TEST_NESTED_NLATTR_OBJECT_EX_(fd, nlh0, hdrlen,
+				      init_prop_list_msg, print_prop_list_msg,
+				      IFLA_ALT_IFNAME, "IFLA_ALT_IFNAME",
+				      pattern, buf, print_quoted_stringn, 1,
+				      print_quoted_memory(&buf, sizeof(buf));
+				      printf("..."));
+
+	/* IFLA_ALT_IFNAME */
+	static const char alt_ifname[] = "OH HAI THAR\r\n\t\377\0\v\x7e";
+	TEST_NLATTR(fd, nlh0, hdrlen,
+		    init_ifinfomsg, print_ifinfomsg,
+		    IFLA_ALT_IFNAME,
+		    sizeof(alt_ifname), alt_ifname, sizeof(alt_ifname),
+		    print_quoted_memory(alt_ifname, sizeof(alt_ifname) - 1));
+
+	TEST_NLATTR(fd, nlh0, hdrlen,
+		    init_ifinfomsg, print_ifinfomsg,
+		    IFLA_ALT_IFNAME,
+		    sizeof(alt_ifname) - 1, alt_ifname, sizeof(alt_ifname) - 1,
+		    print_quoted_memory(alt_ifname, sizeof(alt_ifname) - 1);
+		    printf("..."));
+
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests/nlattr_ifla_linkinfo.c 5.9-0ubuntu2/tests/nlattr_ifla_linkinfo.c
--- 5.5-3/tests/nlattr_ifla_linkinfo.c	2019-03-18 02:40:16.000000000 +0000
+++ 5.9-0ubuntu2/tests/nlattr_ifla_linkinfo.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * IFLA_LINKINFO netlink attribute decoding check.
  *
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -347,7 +347,6 @@ main(void)
 	/* bridge attrs */
 	static const struct val_name und_br_attrs[] = {
 		{ 0, "IFLA_BR_UNSPEC" },
-		{ 20, "IFLA_BR_GROUP_ADDR" },
 		{ 21, "IFLA_BR_FDB_FLUSH" },
 		{ 40, "IFLA_BR_PAD" },
 		{ 47, "0x2f /* IFLA_BR_??? */" },
@@ -367,6 +366,21 @@ main(void)
 					"\\x63\\x64\\x65\\x66\"" });
 	}
 
+	static const struct val_name hwa_br_attrs[] = {
+		{ 20, "IFLA_BR_GROUP_ADDR" },
+	};
+
+	for (size_t k = 0; k < ARRAY_SIZE(hwa_br_attrs); k++) {
+		TEST_NESTED_LINKINFO(fd, nlh0, 2, "IFLA_INFO_DATA", "bridge",
+				     hwa_br_attrs[k].val, hwa_br_attrs[k].name,
+				     unknown_msg, pattern,
+				     { 2, "ab:ac" },
+				     { 4, "ab:ac:db:cd" },
+				     { 6, "ab:ac:db:cd:61:62" },
+				     { 8, "ab:ac:db:cd:61:62:63:64" },
+				     { 10, "ab:ac:db:cd:61:62:63:64:65:66" });
+	}
+
 	static const struct val_name u64_br_attrs[] = {
 		{ 16, "IFLA_BR_HELLO_TIMER" },
 		{ 17, "IFLA_BR_TCN_TIMER" },
diff -pruN 5.5-3/tests/nlattr_ifla_xdp.c 5.9-0ubuntu2/tests/nlattr_ifla_xdp.c
--- 5.5-3/tests/nlattr_ifla_xdp.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/nlattr_ifla_xdp.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2017 JingPiao Chen <chenjingpiao@gmail.com>
- * Copyright (c) 2017-2018 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -17,44 +17,28 @@
 #endif
 #include <linux/rtnetlink.h>
 
+#define XLAT_MACROS_ONLY
+# include "xlat/rtnl_ifla_xdp_attrs.h"
+#undef XLAT_MACROS_ONLY
+
 #if !HAVE_DECL_IFLA_XDP
 enum { IFLA_XDP = 43 };
 #endif
-#ifndef IFLA_XDP_FD
-# define IFLA_XDP_FD 1
-#endif
-
-#ifndef IFLA_XDP_ATTACHED
-# define IFLA_XDP_ATTACHED 2
-#endif
-
-#ifndef IFLA_XDP_PROG_ID
-# define IFLA_XDP_PROG_ID 4
-#endif
-
-#ifndef IFLA_XDP_DRV_PROG_ID
-# define IFLA_XDP_DRV_PROG_ID 5
-#endif
 
-#ifndef IFLA_XDP_SKB_PROG_ID
-# define IFLA_XDP_SKB_PROG_ID 6
+#if !HAVE_DECL_XDP_ATTACHED_NONE
+enum { XDP_ATTACHED_NONE = 0 };
 #endif
-
-#ifndef IFLA_XDP_HW_PROG_ID
-# define IFLA_XDP_HW_PROG_ID 7
-#endif
-
-#ifndef XDP_ATTACHED_NONE
-# define XDP_ATTACHED_NONE 0
-#endif
-
-#ifndef XDP_ATTACHED_MULTI
-# define XDP_ATTACHED_MULTI 4
+#if !HAVE_DECL_XDP_ATTACHED_MULTI
+enum { XDP_ATTACHED_MULTI = 4 };
 #endif
 
 #define IFLA_ATTR IFLA_XDP
 #include "nlattr_ifla.h"
 
+#ifndef FD9_PATH
+# define FD9_PATH ""
+#endif
+
 int
 main(void)
 {
@@ -118,6 +102,18 @@ main(void)
 					      printf("%u", num));
 	}
 
+	/* IFLA_XDP_EXPECTED_FD */
+	TEST_NESTED_NLATTR_OBJECT_EX(fd, nlh0, hdrlen,
+				     init_ifinfomsg, print_ifinfomsg,
+				     IFLA_XDP_EXPECTED_FD, pattern, num, 1,
+				     printf("%d", num));
+
+	int exp_fd = 9;
+	TEST_NESTED_NLATTR_OBJECT_EX(fd, nlh0, hdrlen,
+				     init_ifinfomsg, print_ifinfomsg,
+				     IFLA_XDP_EXPECTED_FD, pattern, exp_fd, 1,
+				     printf("9" FD9_PATH));
+
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests/nlattr_ifla_xdp-y.c 5.9-0ubuntu2/tests/nlattr_ifla_xdp-y.c
--- 5.5-3/tests/nlattr_ifla_xdp-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/nlattr_ifla_xdp-y.c	2020-05-30 08:00:00.000000000 +0000
@@ -0,0 +1,3 @@
+#define PRINT_SOCK 1
+#define FD9_PATH "</dev/full>"
+#include "nlattr_ifla_xdp.c"
diff -pruN 5.5-3/tests/nlattr_ifla_xdp-y.gen.test 5.9-0ubuntu2/tests/nlattr_ifla_xdp-y.gen.test
--- 5.5-3/tests/nlattr_ifla_xdp-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/nlattr_ifla_xdp-y.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (nlattr_ifla_xdp-y +netlink_sock_diag.test -y; exec 9</dev/full); do not edit.
+set -- -y; exec 9</dev/full
+. "${srcdir=.}/netlink_sock_diag.test"
diff -pruN 5.5-3/tests/nlattr_inet_diag_req_compat.c 5.9-0ubuntu2/tests/nlattr_inet_diag_req_compat.c
--- 5.5-3/tests/nlattr_inet_diag_req_compat.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/nlattr_inet_diag_req_compat.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2017 JingPiao Chen <chenjingpiao@gmail.com>
- * Copyright (c) 2017-2018 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -73,10 +73,10 @@ main(void)
 
 	char nla_type_str[256];
 	sprintf(nla_type_str, "%#x /* INET_DIAG_REQ_??? */",
-		INET_DIAG_REQ_BYTECODE + 1);
+		INET_DIAG_REQ_PROTOCOL + 1);
 	TEST_NLATTR_(fd, nlh0, hdrlen,
 		     init_inet_diag_req, print_inet_diag_req,
-		     INET_DIAG_REQ_BYTECODE + 1, nla_type_str,
+		     INET_DIAG_REQ_PROTOCOL + 1, nla_type_str,
 		     4, pattern, 4,
 		     print_quoted_hex(pattern, 4));
 
diff -pruN 5.5-3/tests/nlattr_ndmsg.c 5.9-0ubuntu2/tests/nlattr_ndmsg.c
--- 5.5-3/tests/nlattr_ndmsg.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests/nlattr_ndmsg.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2017 JingPiao Chen <chenjingpiao@gmail.com>
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -100,11 +100,15 @@ main(void)
 			   printf("htons(%u)", ntohs(port)));
 
 	static const uint8_t mac[6] = "\xf8\xc2\x49\x13\x57\xbd";
-	TEST_NLATTR_OBJECT(fd, nlh0, hdrlen,
-			   init_ndmsg, print_ndmsg,
-			   NDA_LLADDR, pattern, mac,
-			   for (unsigned int i = 0; i < sizeof(mac); ++i)
-				printf("%s%02x", i ? ":" : "", mac[i]));
+	TEST_NLATTR(fd, nlh0, hdrlen, init_ndmsg, print_ndmsg,
+		    NDA_LLADDR, sizeof(mac) - 1, mac, sizeof(mac) - 1,
+		    for (unsigned int i = 0; i < sizeof(mac) - 1; ++i)
+			printf("%s%02x", i ? ":" : "", mac[i]));
+
+	TEST_NLATTR(fd, nlh0, hdrlen, init_ndmsg, print_ndmsg,
+		    NDA_LLADDR, sizeof(mac), mac, sizeof(mac),
+		    for (unsigned int i = 0; i < sizeof(mac); ++i)
+			printf("%s%02x", i ? ":" : "", mac[i]));
 
 	puts("+++ exited with 0 +++");
 	return 0;
diff -pruN 5.5-3/tests/nlattr_packet_diag_msg.gen.test 5.9-0ubuntu2/tests/nlattr_packet_diag_msg.gen.test
--- 5.5-3/tests/nlattr_packet_diag_msg.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests/nlattr_packet_diag_msg.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -1,4 +1,4 @@
 #!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (nlattr_packet_diag_msg +netlink_sock_diag-v.sh ); do not edit.
-set -- 
-. "${srcdir=.}/netlink_sock_diag-v.sh"
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (nlattr_packet_diag_msg +netlink_sock_diag.test -v); do not edit.
+set -- -v
+. "${srcdir=.}/netlink_sock_diag.test"
diff -pruN 5.5-3/tests/nlattr_tcamsg.c 5.9-0ubuntu2/tests/nlattr_tcamsg.c
--- 5.5-3/tests/nlattr_tcamsg.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests/nlattr_tcamsg.c	2020-05-30 08:00:00.000000000 +0000
@@ -22,6 +22,12 @@ enum { TCA_ACT_COOKIE = 6 };
 #if !HAVE_DECL_TCA_ACT_FLAGS
 enum { TCA_ACT_FLAGS = 7 };
 #endif
+#if !HAVE_DECL_TCA_ACT_HW_STATS
+enum { TCA_ACT_HW_STATS = 8 };
+#endif
+#if !HAVE_DECL_TCA_ACT_USED_HW_STATS
+enum { TCA_ACT_USED_HW_STATS = 9 };
+#endif
 
 
 static void
@@ -60,7 +66,7 @@ main(void)
 	fill_memory_ex(pattern, sizeof(pattern), 'a', 'z' - 'a' + 1);
 
 	/* Invalid */
-	static const unsigned int nla_invalid[] = { 8, 0xffff & NLA_TYPE_MASK };
+	static const unsigned int nla_invalid[] = { 10, 0xffff & NLA_TYPE_MASK };
 	for (size_t i = 0; i < ARRAY_SIZE(nla_invalid); i++) {
 		char nla_type_str[256];
 		sprintf(nla_type_str, "%#x /* TCA_ACT_??? */", nla_invalid[i]);
@@ -111,6 +117,21 @@ main(void)
 		    TCA_ACT_FLAGS, sizeof(flags), &flags, sizeof(flags),
 		    printf("TCA_ACT_FLAGS_NO_PERCPU_STATS|0xfacebeee"));
 
+	/* TCA_ACT_HW_STATS, TCA_ACT_USED_HW_STATS */
+	static const struct strval32 nla_hw_st[] = {
+		{ ARG_STR(TCA_ACT_HW_STATS) },
+		{ ARG_STR(TCA_ACT_USED_HW_STATS) },
+	};
+
+	static uint32_t hw_st = 0xfacebeef;
+	for (size_t i = 0; i < ARRAY_SIZE(nla_hw_st); i++) {
+		TEST_NLATTR_(fd, nlh0, hdrlen, init_tcamsg, print_tcamsg,
+			     nla_hw_st[i].val, nla_hw_st[i].str,
+			     sizeof(hw_st), &hw_st, sizeof(hw_st),
+			     printf("TCA_ACT_HW_STATS_IMMEDIATE|"
+				    "TCA_ACT_HW_STATS_DELAYED|0xfacebeec"));
+	}
+
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests/nlattr_tc_stats.c 5.9-0ubuntu2/tests/nlattr_tc_stats.c
--- 5.5-3/tests/nlattr_tc_stats.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests/nlattr_tc_stats.c	2020-04-03 22:58:26.000000000 +0000
@@ -16,9 +16,9 @@
 # include <linux/gen_stats.h>
 # include <linux/rtnetlink.h>
 
-#if !HAVE_DECL_TCA_STATS_PKT64
+# if !HAVE_DECL_TCA_STATS_PKT64
 enum { TCA_STATS_PKT64 = 8 };
-#endif
+# endif
 
 const unsigned int hdrlen = sizeof(struct tcmsg);
 
diff -pruN 5.5-3/tests/nsyscalls-d.test 5.9-0ubuntu2/tests/nsyscalls-d.test
--- 5.5-3/tests/nsyscalls-d.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/nsyscalls-d.test	2020-04-03 22:58:26.000000000 +0000
@@ -1,8 +1,8 @@
 #!/bin/sh
 #
-# Check decoding of out-of-range syscalls along with debug ouput
+# Check decoding of out-of-range syscalls along with debug output
 #
-# Copyright (c) 2017-2018 The strace developers.
+# Copyright (c) 2017-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
diff -pruN 5.5-3/tests/openat2.c 5.9-0ubuntu2/tests/openat2.c
--- 5.5-3/tests/openat2.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/openat2.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,172 @@
+/*
+ * Check decoding of openat2 syscall.
+ *
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+
+#ifdef __NR_openat2
+
+# include <errno.h>
+# include <stdint.h>
+# include <inttypes.h>
+# include <stdio.h>
+# include <string.h>
+# include <unistd.h>
+# include <asm/fcntl.h>
+
+# ifdef HAVE_LINUX_OPENAT2
+#  include <linux/openat2.h>
+# endif
+
+# ifndef HAVE_LINUX_OPENAT2
+struct open_how {
+	uint64_t flags;
+	uint64_t mode;
+	uint64_t resolve;
+};
+# endif
+
+# ifndef AT_FDCWD
+#  define AT_FDCWD -100
+# endif
+# ifndef RESOLVE_NO_XDEV
+#  define RESOLVE_NO_XDEV 0x01
+# endif
+# ifndef RESOLVE_IN_ROOT
+#  define RESOLVE_IN_ROOT 0x10
+# endif
+
+# ifndef O_TMPFILE
+#  if defined __hppa__
+#   define __O_TMPFILE     040000000
+#  elif defined __alpha__
+#   define __O_TMPFILE     0100000000
+#  elif defined __sparc__
+#   define __O_TMPFILE     0200000000
+#  else
+#   define __O_TMPFILE     020000000
+#  endif
+# endif
+
+# ifndef VERBOSE
+#  define VERBOSE 0
+# endif
+# ifndef FD0_PATH
+#  define FD0_PATH ""
+# endif
+
+static const char sample[] = "openat2.sample";
+
+int
+main(void)
+{
+	long rc;
+	const char *rcstr;
+	struct open_how *how = tail_alloc(sizeof(*how));
+	struct open_how *how_big = tail_alloc(sizeof(*how_big) + 8);
+
+	rc = syscall(__NR_openat2, 0, NULL, NULL,
+		     (kernel_ulong_t) 0xdeadc0debadc0dedULL);
+	printf("openat2(0" FD0_PATH ", NULL, NULL, %llu) = %s\n",
+	       (unsigned long long) (kernel_ulong_t) 0xdeadc0debadc0dedULL,
+	       sprintrc(rc));
+
+	rc = syscall(__NR_openat2, -100, "", how + 1, sizeof(*how));
+	printf("openat2(%s, \"\", %p, %zu) = %s\n",
+	       XLAT_KNOWN(-100, "AT_FDCWD"), how + 1, sizeof(*how),
+	       sprintrc(rc));
+
+	rc = syscall(__NR_openat2, -1, sample, how, 11);
+	printf("openat2(-1, \"%s\", %p, 11) = %s\n", sample, how, sprintrc(rc));
+
+	static struct strval64 flags[] = {
+		{ ARG_STR(O_RDONLY|O_EXCL) },
+		{ ARG_STR(O_WRONLY|O_CREAT) },
+		{ ARG_STR(O_RDWR|O_LARGEFILE) },
+# ifdef O_TMPFILE
+		{ ARG_STR(O_ACCMODE|O_TMPFILE) },
+# else
+		{ ARG_STR(O_ACCMODE|__O_TMPFILE) },
+# endif
+		{ ARG_ULL_STR(O_RDONLY|0xdeadface80000000) },
+	};
+	static uint64_t modes[] = { 0, 0777, 0xbadc0dedfacebeefULL };
+	static struct strval64 resolve[] = {
+		{ 0, NULL },
+		{ ARG_STR(RESOLVE_NO_XDEV) },
+		{ ARG_ULL_STR(RESOLVE_NO_XDEV|RESOLVE_IN_ROOT|0xfeedfacedcaffee0) },
+		{ 0xdec0dedbeefface0, NULL },
+	};
+	const size_t iters = MAX(MAX(ARRAY_SIZE(flags), ARRAY_SIZE(modes)),
+				 ARRAY_SIZE(resolve));
+
+
+	for (size_t i = 0; i < iters * 4; i++) {
+		how->flags = flags[i % ARRAY_SIZE(flags)].val;
+		how->mode = modes[i % ARRAY_SIZE(modes)];
+		how->resolve = resolve[i % ARRAY_SIZE(resolve)].val;
+
+		fill_memory(how_big + 1, 8);
+		memcpy(how_big, how, sizeof(*how));
+
+		for (size_t j = 0; j < 4; j++) {
+			rc = syscall(__NR_openat2, -1, sample,
+				     j > 1 ? how_big : how,
+				     j ? sizeof(*how) + 8 : sizeof(*how));
+			rcstr = sprintrc(rc);
+			printf("openat2(-1, \"%s\", {flags=%s",
+			       sample,
+			       sprintxlat(flags[i % ARRAY_SIZE(flags)].str,
+					  flags[i % ARRAY_SIZE(flags)].val,
+					  NULL));
+
+			if (how->mode || (i % ARRAY_SIZE(flags) == 1)
+				      || (i % ARRAY_SIZE(flags) == 3)) {
+				printf(", mode=%#03" PRIo64,
+				       modes[i % ARRAY_SIZE(modes)]);
+			}
+
+			printf(", resolve=%s",
+			       sprintxlat(resolve[i % ARRAY_SIZE(resolve)].str,
+					  resolve[i % ARRAY_SIZE(resolve)].val,
+					  resolve[i % ARRAY_SIZE(resolve)].val
+						? "RESOLVE_???" : NULL));
+			if (j == 1)
+				printf(", ???");
+			if (j == 2) {
+				printf(", /* bytes %zu..%zu */ \"\\x80\\x81"
+				       "\\x82\\x83\\x84\\x85\\x86\\x87\"",
+				       sizeof(*how), sizeof(*how) + 7);
+			}
+			printf("}, %zu) = %s\n",
+			       j ? sizeof(*how) + 8 : sizeof(*how), rcstr);
+
+			if (j == 2)
+				memset(how_big + 1, 0, 8);
+		}
+	}
+
+	how->flags = O_RDONLY | O_NOCTTY;
+	how->mode = 0;
+	how->resolve = 0;
+	rc = syscall(__NR_openat2, -100, "/dev/full", how, sizeof(*how));
+	printf("openat2(%s, \"/dev/full\", {flags=%s, resolve=0}, %zu)"
+	       " = %s%s\n",
+	       XLAT_KNOWN(-100, "AT_FDCWD"), XLAT_STR(O_RDONLY|O_NOCTTY),
+	       sizeof(*how), sprintrc(rc), rc >= 0 ? FD0_PATH : "");
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_openat2");
+
+#endif
diff -pruN 5.5-3/tests/openat2.gen.test 5.9-0ubuntu2/tests/openat2.gen.test
--- 5.5-3/tests/openat2.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/openat2.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2 -a35 ); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a35 
diff -pruN 5.5-3/tests/openat2-v.c 5.9-0ubuntu2/tests/openat2-v.c
--- 5.5-3/tests/openat2-v.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/openat2-v.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define VERBOSE 1
+#include "openat2.c"
diff -pruN 5.5-3/tests/openat2-v.gen.test 5.9-0ubuntu2/tests/openat2-v.gen.test
--- 5.5-3/tests/openat2-v.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/openat2-v.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-v --trace=openat2 -a35 -v); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a35 -v
diff -pruN 5.5-3/tests/openat2-v-y.c 5.9-0ubuntu2/tests/openat2-v-y.c
--- 5.5-3/tests/openat2-v-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/openat2-v-y.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define FD0_PATH "</dev/full>"
+#include "openat2-v.c"
diff -pruN 5.5-3/tests/openat2-v-y.gen.test 5.9-0ubuntu2/tests/openat2-v-y.gen.test
--- 5.5-3/tests/openat2-v-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/openat2-v-y.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-v-y --trace=openat2 -a36 -v -y </dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a36 -v -y </dev/full
diff -pruN 5.5-3/tests/openat2-v-y-Xabbrev.c 5.9-0ubuntu2/tests/openat2-v-y-Xabbrev.c
--- 5.5-3/tests/openat2-v-y-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/openat2-v-y-Xabbrev.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "openat2-v-y.c"
diff -pruN 5.5-3/tests/openat2-v-y-Xabbrev.gen.test 5.9-0ubuntu2/tests/openat2-v-y-Xabbrev.gen.test
--- 5.5-3/tests/openat2-v-y-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/openat2-v-y-Xabbrev.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-v-y-Xabbrev --trace=openat2 -a35 -v -y -Xabbrev </dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a35 -v -y -Xabbrev </dev/full
diff -pruN 5.5-3/tests/openat2-v-y-Xraw.c 5.9-0ubuntu2/tests/openat2-v-y-Xraw.c
--- 5.5-3/tests/openat2-v-y-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/openat2-v-y-Xraw.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "openat2-v-y.c"
diff -pruN 5.5-3/tests/openat2-v-y-Xraw.gen.test 5.9-0ubuntu2/tests/openat2-v-y-Xraw.gen.test
--- 5.5-3/tests/openat2-v-y-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/openat2-v-y-Xraw.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-v-y-Xraw --trace=openat2 -a32 -v -y -Xraw </dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a32 -v -y -Xraw </dev/full
diff -pruN 5.5-3/tests/openat2-v-y-Xverbose.c 5.9-0ubuntu2/tests/openat2-v-y-Xverbose.c
--- 5.5-3/tests/openat2-v-y-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/openat2-v-y-Xverbose.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "openat2-v-y.c"
diff -pruN 5.5-3/tests/openat2-v-y-Xverbose.gen.test 5.9-0ubuntu2/tests/openat2-v-y-Xverbose.gen.test
--- 5.5-3/tests/openat2-v-y-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/openat2-v-y-Xverbose.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-v-y-Xverbose --trace=openat2 -a44 -v -y -Xverbose </dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a44 -v -y -Xverbose </dev/full
diff -pruN 5.5-3/tests/openat2-Xabbrev.c 5.9-0ubuntu2/tests/openat2-Xabbrev.c
--- 5.5-3/tests/openat2-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/openat2-Xabbrev.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "openat2.c"
diff -pruN 5.5-3/tests/openat2-Xabbrev.gen.test 5.9-0ubuntu2/tests/openat2-Xabbrev.gen.test
--- 5.5-3/tests/openat2-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/openat2-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-Xabbrev --trace=openat2 -a35 -Xabbrev); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a35 -Xabbrev
diff -pruN 5.5-3/tests/openat2-Xraw.c 5.9-0ubuntu2/tests/openat2-Xraw.c
--- 5.5-3/tests/openat2-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/openat2-Xraw.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "openat2.c"
diff -pruN 5.5-3/tests/openat2-Xraw.gen.test 5.9-0ubuntu2/tests/openat2-Xraw.gen.test
--- 5.5-3/tests/openat2-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/openat2-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-Xraw --trace=openat2 -a32 -Xraw); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a32 -Xraw
diff -pruN 5.5-3/tests/openat2-Xverbose.c 5.9-0ubuntu2/tests/openat2-Xverbose.c
--- 5.5-3/tests/openat2-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/openat2-Xverbose.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "openat2.c"
diff -pruN 5.5-3/tests/openat2-Xverbose.gen.test 5.9-0ubuntu2/tests/openat2-Xverbose.gen.test
--- 5.5-3/tests/openat2-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/openat2-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-Xverbose --trace=openat2 -a35 -Xverbose); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a35 -Xverbose
diff -pruN 5.5-3/tests/openat2-y.c 5.9-0ubuntu2/tests/openat2-y.c
--- 5.5-3/tests/openat2-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/openat2-y.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define FD0_PATH "</dev/full>"
+#include "openat2.c"
diff -pruN 5.5-3/tests/openat2-y.gen.test 5.9-0ubuntu2/tests/openat2-y.gen.test
--- 5.5-3/tests/openat2-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/openat2-y.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-y --trace=openat2 -a36 -y </dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a36 -y </dev/full
diff -pruN 5.5-3/tests/open_tree-P.gen.test 5.9-0ubuntu2/tests/open_tree-P.gen.test
--- 5.5-3/tests/open_tree-P.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests/open_tree-P.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -1,4 +1,4 @@
 #!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (open_tree-P -a30 -y -P /dev/full -e trace=open_tree); do not edit.
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (open_tree-P -a30 --decode-fds -P /dev/full -e trace=open_tree); do not edit.
 . "${srcdir=.}/init.sh"
-run_strace_match_diff -a30 -y -P /dev/full -e trace=open_tree
+run_strace_match_diff -a30 --decode-fds -P /dev/full -e trace=open_tree
diff -pruN 5.5-3/tests/options-syntax.test 5.9-0ubuntu2/tests/options-syntax.test
--- 5.5-3/tests/options-syntax.test	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests/options-syntax.test	2020-08-21 16:39:24.000000000 +0000
@@ -30,55 +30,189 @@ check_e_using_grep "$ff_name: File *name
 check_e_using_grep "$ff_name: File *name too long" -ff --output="$ff_name" true
 
 check_h 'must have PROG [ARGS] or -p PID'
-check_h 'PROG [ARGS] must be specified with -D' -D -p $$
-check_h 'PROG [ARGS] must be specified with -D' -DD -p $$
-check_h 'PROG [ARGS] must be specified with -D' -DDD -p $$
-check_h 'PROG [ARGS] must be specified with -D' -DDDD -p $$
+check_h "must have PROG [ARGS] or -p PID" --absolute-timestamps
+check_h "must have PROG [ARGS] or -p PID" --absolute-timestamps=
+check_h "must have PROG [ARGS] or -p PID" --absolute-timestamps=,
+check_h "must have PROG [ARGS] or -p PID" --absolute-timestamps=,s
+check_h "must have PROG [ARGS] or -p PID" --absolute-timestamps=s,
+check_h "must have PROG [ARGS] or -p PID" --absolute-timestamps=,,
+check_h "must have PROG [ARGS] or -p PID" --absolute-timestamps=s,,none
+check_h "must have PROG [ARGS] or -p PID" --timestamps --absolute-timestamps=ns --timestamps=none --absolute-timestamps=format:time,precision:s --timestamps=ns,format:unix --absolute-timestamps=us,precision:ms,unix,precision:ns --timestamps=format:none,time,precision:us
+check_h "invalid --absolute-timestamps argument: 'ss'" --absolute-timestamps=ss
+check_h "invalid --timestamps argument: 'format:s'" --timestamps=format:s
+check_h "invalid --timestamps argument: 's,non'" --timestamps=s,non
+check_h "invalid --timestamps argument: 'precision:none'" --timestamps=precision:none
+check_e '-t and --absolute-timestamps cannot be provided simultaneously' -t --timestamps -p $$
+check_e '-t and --absolute-timestamps cannot be provided simultaneously' --absolute-timestamps -ttt -p $$
+check_e '-t and --absolute-timestamps cannot be provided simultaneously' -t --timestamps=ns -t -p $$
+check_e '-t and --absolute-timestamps cannot be provided simultaneously' --timestamps=ns -t --absolute-timestamps=unix -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' -D -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' -DD -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' -DDD -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' -DDDD -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' --daemonize -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' --daemonize=grandchild -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' --daemonize=pgroup -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' --daemonize=Pgrp -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' --daemonize=SESSION -p $$
 check_h 'Too many -D'\''s (4), maximum supported -D count is 3' -DDDD /bin/true
-check_h '-c and -C are mutually exclusive' -c -C true
-check_h '-c and -C are mutually exclusive' --summary-only --summary true
-check_h '-c and -C are mutually exclusive' -C -c true
-check_h '-c and -C are mutually exclusive' --summary --summary-only true
-check_h '(-c or -C) and -ff are mutually exclusive' -c -ff true
-check_h '(-c or -C) and -ff are mutually exclusive' --summary-only -ff true
-check_h '(-c or -C) and -ff are mutually exclusive' -C -ff true
-check_h '(-c or -C) and -ff are mutually exclusive' --summary -ff true
-check_h '-w must be given with (-c or -C)' -w true
-check_h '-w must be given with (-c or -C)' --summary-wall-clock true
-check_h 'piping the output and -ff are mutually exclusive' -o '|' -ff true
-check_h 'piping the output and -ff are mutually exclusive' --output='|' -ff true
-check_h 'piping the output and -ff are mutually exclusive' -o '!' -ff true
-check_h 'piping the output and -ff are mutually exclusive' --output='!' -ff true
+check_e '-D and --daemonize cannot be provided simultaneously' -D --daemonize -p $$
+check_e '-D and --daemonize cannot be provided simultaneously' --daemonize -D -p $$
+check_e '-D and --daemonize cannot be provided simultaneously' --daemonize -v -D /bit/true
+check_h "invalid --daemonize argument: 'pgr'" --daemonize=pgr
+check_h '-c/--summary-only and -C/--summary are mutually exclusive' -c -C true
+check_h '-c/--summary-only and -C/--summary are mutually exclusive' --summary-only --summary true
+check_h '-c/--summary-only and -C/--summary are mutually exclusive' -C -c true
+check_h '-c/--summary-only and -C/--summary are mutually exclusive' --summary --summary-only true
+check_h '(-c/--summary-only or -C/--summary) and -ff/--output-separately are mutually exclusive' -c -ff true
+check_h '(-c/--summary-only or -C/--summary) and -ff/--output-separately are mutually exclusive' --summary-only -ff true
+check_h '(-c/--summary-only or -C/--summary) and -ff/--output-separately are mutually exclusive' -C -ff true
+check_h '(-c/--summary-only or -C/--summary) and -ff/--output-separately are mutually exclusive' --summary -ff true
+check_h '-w/--summary-wall-clock must be given with (-c/--summary-only or -C/--summary)' -w true
+check_h '-w/--summary-wall-clock must be given with (-c/--summary-only or -C/--summary)' --summary-wall-clock true
+check_h '-U/--summary-columns must be given with (-c/--summary-only or -C/--summary)' -U name,time,count,errors true
+check_h '-U/--summary-columns must be given with (-c/--summary-only or -C/--summary)' --summary-columns=name,time,count,errors true
+check_h 'piping the output and -ff/--output-separately are mutually exclusive' -o '|' -ff true
+check_h 'piping the output and -ff/--output-separately are mutually exclusive' --output='|' -ff true
+check_h 'piping the output and -ff/--output-separately are mutually exclusive' -o '!' -ff true
+check_h 'piping the output and -ff/--output-separately are mutually exclusive' --output='!' -ff true
 check_h "invalid -a argument: '-42'" -a -42
 check_h "invalid -O argument: '-42'" -O -42
 check_h "invalid -s argument: '-42'" -s -42
-check_h "invalid -s argument: '-42'" --string-limit=-42
+check_h "invalid --string-limit argument: '-42'" --string-limit=-42
 check_h "invalid -s argument: '1073741824'" -s 1073741824
-check_h "invalid -s argument: '1073741824'" --string-limit=1073741824
+check_h "invalid --string-limit argument: '1073741824'" --string-limit=1073741824
+check_h "must have PROG [ARGS] or -p PID" --follow-forks
+check_h "must have PROG [ARGS] or -p PID" --follow-forks --output-separately
+check_h "must have PROG [ARGS] or -p PID" -f --output-separately
+check_h "must have PROG [ARGS] or -p PID" --output-separately
+check_e '-f and --follow-forks cannot be provided simultaneously' -f --follow-forks -p $$
+check_e '-ff and --output-separately cannot be provided simultaneously' --output-separately -ff -p $$
+check_h "invalid -I argument: '0x1'" -I 0x1
+check_h "invalid -I argument: '0'" -I 0
+check_h "must have PROG [ARGS] or -p PID" -I1
+check_h "must have PROG [ARGS] or -p PID" -I 2
+check_h "must have PROG [ARGS] or -p PID" -I3
+check_h "must have PROG [ARGS] or -p PID" -I 4
 check_h "invalid -I argument: '5'" -I 5
+check_h "must have PROG [ARGS] or -p PID" -I always
+check_h "must have PROG [ARGS] or -p PID" -I anywhere
+check_h "must have PROG [ARGS] or -p PID" -Iwaiting
+check_h "must have PROG [ARGS] or -p PID" -I never
+check_h "must have PROG [ARGS] or -p PID" -Inever_tstp
+check_h "invalid -I argument: '=never'" -I=never
+check_h "invalid -I argument: 'nevertheless'" -Inevertheless
+check_h "invalid -I argument: 'nev'" -Inev
+check_h "invalid --interruptible argument: '0x1'" --interruptible=0x1
+check_h "invalid --interruptible argument: '0'" --interruptible=0
+check_h "must have PROG [ARGS] or -p PID" --interruptible 1
+check_h "must have PROG [ARGS] or -p PID" --interruptible=2
+check_h "invalid --interruptible argument: '5'" --interruptible=5
+check_h "must have PROG [ARGS] or -p PID" --interruptible=anywhere
+check_h "must have PROG [ARGS] or -p PID" --interruptible=waiting
+check_h "must have PROG [ARGS] or -p PID" --interruptible=never
+check_h "must have PROG [ARGS] or -p PID" --interruptible=never_tstp
+check_h "invalid --interruptible argument: 'nevertheless'" --interruptible=nevertheless
+check_h "invalid --interruptible argument: 'nev'" --interruptible=nev
+check_h "must have PROG [ARGS] or -p PID" --relative-timestamps
+check_h "must have PROG [ARGS] or -p PID" --relative-timestamps=s
+check_h "must have PROG [ARGS] or -p PID" --relative-timestamps=ms
+check_h "must have PROG [ARGS] or -p PID" --relative-timestamps=us
+check_h "must have PROG [ARGS] or -p PID" --relative-timestamps=ns
+check_h "invalid --relative-timestamps argument: 'n'" --relative-timestamps=n
+check_h "invalid --relative-timestamps argument: 'ss'" --relative-timestamps=ss
+check_h "must have PROG [ARGS] or -p PID" --syscall-times
+check_h "must have PROG [ARGS] or -p PID" --syscall-times=s
+check_h "must have PROG [ARGS] or -p PID" --syscall-times=ms
+check_h "must have PROG [ARGS] or -p PID" --syscall-times=us
+check_h "must have PROG [ARGS] or -p PID" --syscall-times=ns
+check_h "invalid --syscall-times argument: 'n'" --syscall-times=n
+check_h "invalid --syscall-times argument: 'ss'" --syscall-times=ss
+check_h "must have PROG [ARGS] or -p PID" --strings-in-hex
+check_h "must have PROG [ARGS] or -p PID" --strings-in-hex=all
+check_h "must have PROG [ARGS] or -p PID" --strings-in-hex=non-ascii
+check_h "invalid --strings-in-hex argument: 'al'" --strings-in-hex=al
+check_h "invalid --strings-in-hex argument: 'alll'" --strings-in-hex=alll
+check_h "invalid --strings-in-hex argument: 'ascii'" --strings-in-hex=ascii
+check_h "must have PROG [ARGS] or -p PID" --quiet=all
+check_h "must have PROG [ARGS] or -p PID" --quiet=none
+check_h "must have PROG [ARGS] or -p PID" --quiet=\!attach
+check_h "must have PROG [ARGS] or -p PID" --quiet=exit,exits,personality
+check_e "invalid quiet 'detach'" --quiet=detach -p $$
+check_e "invalid quiet 'fds'" -q --quiet=fds -p $$
+check_e "invalid quiet 'detach'" --quiet=detach -p $$
+check_e '-q and -e quiet/--quiet cannot be provided simultaneously' -q --quiet -p $$
+check_e '-q and -e quiet/--quiet cannot be provided simultaneously' -q -e q=none -p $$
+check_e '-q and -e quiet/--quiet cannot be provided simultaneously' -q -e silent=attach,personality -p $$
+
+check_h 'must have PROG [ARGS] or -p PID' -P .
+check_h 'must have PROG [ARGS] or -p PID' -P . -P..
+check_h 'must have PROG [ARGS] or -p PID' --trace-path=.
+check_h 'must have PROG [ARGS] or -p PID' --trace-path=. --trace-path ..
+check_e "Requested path \"///\" resolved into \"/\"
+$STRACE_EXE: Requested path \"/.\" resolved into \"/\"
+$STRACE_EXE: -q and -e quiet/--quiet cannot be provided simultaneously" -q --quiet -P /// -P/. .
+
+for i in time time_percent time-percent time_total time-total total_time total-time min_time min-time time_min time-min shortest max_time max-time time_max time-max longest avg_time avg-time time_avg time-avg calls count error errors name syscall syscall_name syscall-name none nothing; do
+	check_h "must have PROG [ARGS] or -p PID" -S "$i"
+	check_h "must have PROG [ARGS] or -p PID" --summary-sort-by="$i"
+	if [ "x$i" != xnone -a "x$i" != xnothing ]; then
+		check_h "must have PROG [ARGS] or -p PID" -c -U "$i"
+		check_h "must have PROG [ARGS] or -p PID" --summary-only --summary-columns="$i"
+	fi
+done
+for i in time,time_total,avg_time,calls,errors,name time_percent,total_time,time_avg,count,error,syscall_name; do
+	check_h "must have PROG [ARGS] or -p PID" -c -U "$i"
+	check_h "must have PROG [ARGS] or -p PID" --summary-only --summary-columns="$i"
+done
+for i in non syscall_names; do
+	check_h "invalid sortby: '$i'" -S "$i"
+	check_h "invalid sortby: '$i'" --summary-sort-by="$i"
+	check_h "unknown column name: '$i'" -U "$i"
+	check_h "unknown column name: '$i'" --summary-columns="$i"
+done
+check_h "unknown column name: ''" -U time,,name
+check_h "call summary column has been provided more than once: 'time_percent' (-U option residual: 'time_percent,time_total')" -U time,time_percent,time_total
+
+check_e '-x and --strings-in-hex cannot be provided simultaneously' -x --strings-in-hex -p $$
+check_e '-x and --strings-in-hex cannot be provided simultaneously' --strings-in-hex -p $$ -xx
 check_h "invalid -X argument: 'test'" -Xtest
-check_h "invalid -X argument: 'test'" --const-print-style=test
+check_h "invalid --const-print-style argument: 'test'" --const-print-style=test
 check_h "invalid -X argument: 'a'" -Xa
-check_h "invalid -X argument: 'a'" --const-print-style=a
+check_h "invalid --const-print-style argument: 'a'" --const-print-style=a
 check_h "invalid -X argument: 'abbreviated'" -X abbreviated
-check_h "invalid -X argument: 'abbreviated'" --const-print-style=abbreviated
+check_h "invalid --const-print-style argument: 'abbreviated'" --const-print-style=abbreviated
+check_h "must have PROG [ARGS] or -p PID" --decode-fds
+check_h "must have PROG [ARGS] or -p PID" --decode-fds=all
+check_h "must have PROG [ARGS] or -p PID" --decode-fds=none
+check_h "must have PROG [ARGS] or -p PID" --decode-fds=path
+check_h "must have PROG [ARGS] or -p PID" --decode-fds=socket,dev
+check_h "must have PROG [ARGS] or -p PID" --decode-fds=\!path
+check_h "must have PROG [ARGS] or -p PID" --decode-fds=socket,path,dev
+check_e "invalid decode-fds 'p'" --decode-fds=p -p $$
+check_e "invalid decode-fds 'device'" -y --decode-fds=device -p $$
+check_e "invalid decode-fds 'name'" --decode-fds=path,name -p $$
+check_e "invalid decode-fds 'sock'" -e decode-fd=sock -y -p $$
+check_e '-y and --decode-fds cannot be provided simultaneously' -y --decode-fds -p $$
+check_e '-y and --decode-fds cannot be provided simultaneously' -e decode-fd=all -yy -p $$
+check_e '-y and --decode-fds cannot be provided simultaneously' --decode-fds=none -y -p $$
 
 check_h "incorrect personality designator '' in qualification 'getcwd@'" -e trace=getcwd@
 check_h "incorrect personality designator '42' in qualification 'getcwd@42'" -e trace=getcwd@42
 check_h "incorrect personality designator '42' in qualification 'getcwd@42'" -e trace=gettid,getcwd@42
 check_h "incorrect personality designator '42' in qualification '23@42'" -e trace=23@42,123
 
-check_h '--seccomp-bpf implies -f
--w must be given with (-c or -C)' --seccomp-bpf -w /
+check_h '--seccomp-bpf cannot be used without -f/--follow-forks, disabling
+-w/--summary-wall-clock must be given with (-c/--summary-only or -C/--summary)' --seccomp-bpf -w /
 check_h '--seccomp-bpf is not enabled for processes attached with -p
--w must be given with (-c or -C)' --seccomp-bpf -f -p 1 -w
+-w/--summary-wall-clock must be given with (-c/--summary-only or -C/--summary)' --seccomp-bpf -f -p 1 -w
 
-check_h 'option -F is deprecated, please use -f instead
--w must be given with (-c or -C)' -F -w /
-check_h 'option -F is deprecated, please use -f instead
--w must be given with (-c or -C)' -FF -w /
+check_h 'option -F is deprecated, please use -f/--follow-forks instead
+-w/--summary-wall-clock must be given with (-c/--summary-only or -C/--summary)' -F -w /
+check_h 'option -F is deprecated, please use -f/--follow-forks instead
+-w/--summary-wall-clock must be given with (-c/--summary-only or -C/--summary)' -FF -w /
 check_h 'deprecated option -F ignored
--w must be given with (-c or -C)' -fF -w /
+-w/--summary-wall-clock must be given with (-c/--summary-only or -C/--summary)' -fF -w /
 
 check_e "invalid system call '/getcwd@ohmy'" -e trace=/getcwd@ohmy
 check_e "invalid -e kvm= argument: 'chdir'" -e kvm=chdir
@@ -129,25 +263,51 @@ if [ "$uid" -ge 0 ]; then
 	if [ "$uid" -eq 0 ]; then
 		umsg="Cannot find user ':nosuchuser:'"
 	else
-		umsg='You must be root to use the -u option'
+		umsg='You must be root to use the -u/--username option'
 	fi
 
 	check_e "$umsg" -u :nosuchuser: true
 
-	for c in i r t T y; do
-		check_e "-$c has no effect with -c
-$STRACE_EXE: $umsg" -u :nosuchuser: -c -$c true
+	for c in i/--instruction-pointer n/--syscall-number r/--relative-timestamps t/--absolute-timestamps T/--syscall-times y/--decode-fds; do
+		check_e "-$c has no effect with -c/--summary-only
+$STRACE_EXE: $umsg" -u :nosuchuser: -c -${c%%/*} true
+	done
+
+	check_e "-i/--instruction-pointer has no effect with -c/--summary-only
+$STRACE_EXE: -n/--syscall-number has no effect with -c/--summary-only
+$STRACE_EXE: -r/--relative-timestamps has no effect with -c/--summary-only
+$STRACE_EXE: -t/--absolute-timestamps has no effect with -c/--summary-only
+$STRACE_EXE: -T/--syscall-times has no effect with -c/--summary-only
+$STRACE_EXE: -y/--decode-fds has no effect with -c/--summary-only
+$STRACE_EXE: Only the last of -z/--successful-only/-Z/--failed-only options will take effect. See status qualifier for more complex filters.
+$STRACE_EXE: $umsg" -u :nosuchuser: -cinrtTyzZ true
+
+	for c in --output-separately -A/--output-append-mode; do
+		check_e "$c has no effect without -o/--output
+$STRACE_EXE: $umsg" -u :nosuchuser: ${c%%/*} true
 	done
 
-	check_e "-i has no effect with -c
-$STRACE_EXE: -r has no effect with -c
-$STRACE_EXE: -t has no effect with -c
-$STRACE_EXE: -T has no effect with -c
-$STRACE_EXE: -y has no effect with -c
-$STRACE_EXE: Only the last of -z/-Z options will take effect. See status qualifier for more complex filters.
-$STRACE_EXE: $umsg" -u :nosuchuser: -cirtTyzZ true
+	check_e "-S/--summary-sort-by has no effect without (-c/--summary-only or -C/--summary)
+$STRACE_EXE: $umsg" -u :nosuchuser: --summary-sort-by errors true
+
+	check_e "--output-separately has no effect without -o/--output
+$STRACE_EXE: -A/--output-append-mode has no effect without -o/--output
+$STRACE_EXE: $umsg" -u :nosuchuser: --output-separately --output-append-mode true
+
+	check_e "$umsg" -u :nosuchuser: -ff true
+	check_e "$umsg" -u :nosuchuser: --output-separately --follow-forks true
+
+	check_e "Only the last of -z/--successful-only/-Z/--failed-only options will take effect. See status qualifier for more complex filters.
+$STRACE_EXE: $umsg" -u :nosuchuser: -z --successful-only true
+	check_e "Only the last of -z/--successful-only/-Z/--failed-only options will take effect. See status qualifier for more complex filters.
+$STRACE_EXE: $umsg" -u :nosuchuser: --successful-only -Z true
+	check_e "Only the last of -z/--successful-only/-Z/--failed-only options will take effect. See status qualifier for more complex filters.
+$STRACE_EXE: $umsg" -u :nosuchuser: --successful-only --failed-only true
+
+	check_e "-n/--syscall-number has no effect with -c/--summary-only
+$STRACE_EXE: $umsg" --user=:nosuchuser: --syscall-number --summary-only true
 
-	check_e "-i has no effect with -c
+	check_e "-i/--instruction-pointer has no effect with -c/--summary-only
 $STRACE_EXE: $umsg" --user=:nosuchuser: --instruction-pointer --summary-only true
 fi
 
diff -pruN 5.5-3/tests/orphaned_process_group.c 5.9-0ubuntu2/tests/orphaned_process_group.c
--- 5.5-3/tests/orphaned_process_group.c	2019-03-06 16:02:38.000000000 +0000
+++ 5.9-0ubuntu2/tests/orphaned_process_group.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check tracing of orphaned process group.
  *
- * Copyright (c) 2019 The strace developers.
+ * Copyright (c) 2019-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -139,7 +139,7 @@ main(void)
 	 */
 	leader = getpid();
 	printf("%-5d --- %s {si_signo=%s, si_code=SI_TKILL"
-	       ", si_pid=%d, si_uid=%u} ---\n",
+	       ", si_pid=%d, si_uid=%d} ---\n",
 	       stopped, "SIGSTOP", "SIGSTOP", stopped, geteuid());
 	printf("%-5d --- stopped by SIGSTOP ---\n", stopped);
 	printf("%-5d +++ exited with 0 +++\n", leader);
diff -pruN 5.5-3/tests/pc.c 5.9-0ubuntu2/tests/pc.c
--- 5.5-3/tests/pc.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/pc.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2015-2020 Dmitry V. Levin <ldv@altlinux.org>
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -27,7 +27,7 @@ int main(void)
 #endif
 
 	/* write instruction pointer length to the log */
-	assert(write(-1, NULL, 2 * sizeof(void *)) < 0);
+	assert(write(-1, (void *) 8UL, 2 * sizeof(void *)) < 0);
 
 	/* just a noticeable line in the log */
 	assert(munmap(&main, 0) < 0);
diff -pruN 5.5-3/tests/pc.test 5.9-0ubuntu2/tests/pc.test
--- 5.5-3/tests/pc.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/pc.test	2020-06-01 14:15:16.000000000 +0000
@@ -3,7 +3,7 @@
 # Check -i option.
 #
 # Copyright (c) 2015 Dmitry V. Levin <ldv@altlinux.org>
-# Copyright (c) 2015-2018 The strace developers.
+# Copyright (c) 2015-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -14,11 +14,11 @@ check_prog sed
 
 run_prog > /dev/null
 
-args="-if $args"
+args="--quiet=attach,personality -if $args"
 $STRACE $args 2> "$LOG" ||
 	dump_log_and_fail_with "$STRACE $args failed"
 
-len="$(sed -r -n 's/^\[[[:xdigit:]]+\] write\(-1, NULL, ([[:digit:]]{1,2})\)[[:space:]]+= -1 .*/\1/p' "$LOG")" &&
+len="$(sed -r -n 's/^\[[[:xdigit:]]+\] write\(-1, 0x8, ([[:digit:]]{1,2})\)[[:space:]]+= -1 .*/\1/p' "$LOG")" &&
 [ -n "$len" ] &&
 pid="$(sed -r -n 's/^\[[[:xdigit:]]{'"$len"'}\] --- SIGCHLD \{si_signo=SIGCHLD, si_code=CLD_(KILLED|DUMPED), si_pid=([[:digit:]]+), .*/\2/p' "$LOG")" &&
 [ -n "$pid" ] &&
diff -pruN 5.5-3/tests/perf_event_open.c 5.9-0ubuntu2/tests/perf_event_open.c
--- 5.5-3/tests/perf_event_open.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests/perf_event_open.c	2020-06-02 08:00:00.000000000 +0000
@@ -511,7 +511,7 @@ end:
 }
 
 /* These require aligned access, so no byte-grain checks possible */
-# if defined SPARC || defined SPARC64 || defined POWERPC || defined POWERPC64
+# if defined SPARC || defined SPARC64 || defined POWERPC || defined POWERPC64 || defined ARM
 #  define ATTR_REC(sz) { tail_alloc((sz + 7) & ~7), sz }
 # else
 #  define ATTR_REC(sz) { tail_alloc(sz), sz }
@@ -534,7 +534,8 @@ end:
 	"PERF_SAMPLE_BRANCH_CALL|" \
 	"PERF_SAMPLE_BRANCH_NO_FLAGS|" \
 	"PERF_SAMPLE_BRANCH_NO_CYCLES|" \
-	"PERF_SAMPLE_BRANCH_TYPE_SAVE"
+	"PERF_SAMPLE_BRANCH_TYPE_SAVE|" \
+	"PERF_SAMPLE_BRANCH_HW_INDEX"
 
 int
 main(void)
@@ -667,11 +668,11 @@ main(void)
 	static const struct u64_val_str branch_sample_types[] = {
 		{ ARG_STR(0) },
 		{ 0x80, "PERF_SAMPLE_BRANCH_ABORT_TX" },
-		{ 0x1ffff, BRANCH_TYPE_ALL },
+		{ 0x3ffff, BRANCH_TYPE_ALL },
 		{ ARG_ULL_STR(0xdeadcaffeeec0000)
 			" /* PERF_SAMPLE_BRANCH_??? */" },
 		{ 0xffffffffffffffffULL,
-			BRANCH_TYPE_ALL "|0xfffffffffffe0000" }
+			BRANCH_TYPE_ALL "|0xfffffffffffc0000" }
 	};
 	static const struct s32_val_str clockids[] = {
 		{ 11, "CLOCK_TAI" },
diff -pruN 5.5-3/tests/pidfd_getfd.c 5.9-0ubuntu2/tests/pidfd_getfd.c
--- 5.5-3/tests/pidfd_getfd.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/pidfd_getfd.c	2020-09-23 16:29:35.000000000 +0000
@@ -0,0 +1,103 @@
+/*
+ * Check decoding of pidfd_getfd syscall.
+ *
+ * Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+
+#ifdef __NR_pidfd_getfd
+
+# include <assert.h>
+# include <signal.h>
+# include <stdio.h>
+# include <stdlib.h>
+# include <unistd.h>
+# include <sys/wait.h>
+
+# ifndef PIDFD_PATH
+#  define PIDFD_PATH ""
+# endif
+# ifndef FD0_PATH
+#  define FD0_PATH ""
+# endif
+# ifndef PRINT_PIDFD
+#  define PRINT_PIDFD 0
+# endif
+
+static const char *errstr;
+
+static long
+k_pidfd_getfd(const unsigned int pidfd, const unsigned int fd,
+	      const unsigned int flags)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+	const kernel_ulong_t arg1 = fill | pidfd;
+	const kernel_ulong_t arg2 = fill | fd;
+	const kernel_ulong_t arg3 = fill | flags;
+	const long rc = syscall(__NR_pidfd_getfd,
+				arg1, arg2, arg3, bad, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
+
+int
+main(void)
+{
+	long rc;
+
+	rc = k_pidfd_getfd(-1U, -1U, 0);
+	printf("pidfd_getfd(-1, -1, 0) = %s\n", errstr);
+
+	rc = k_pidfd_getfd(0, 0, 0xbadc0ded);
+	printf("pidfd_getfd(0" FD0_PATH ", 0, 0xbadc0ded) = %s\n", errstr);
+
+	int child_wait_fds[2];
+	if (pipe(child_wait_fds))
+		perror_msg_and_fail("pipe");
+
+	int dupfd = dup(0);
+	int pid = fork();
+	if (pid == 0) {
+		close(0);
+		close(child_wait_fds[1]);
+		if (read(child_wait_fds[0], &child_wait_fds[1], sizeof(int)))
+			_exit(2);
+		_exit(0);
+	}
+	close(dupfd);
+
+	int pidfd = syscall(__NR_pidfd_open, pid, 0);
+# if PRINT_PIDFD
+	char pidfd_str[sizeof("<pid:>") + 3 * sizeof(int)];
+	snprintf(pidfd_str, sizeof(pidfd_str), "<pid:%d>", pid);
+# else
+	const char *pidfd_str = PIDFD_PATH;
+# endif
+	rc = k_pidfd_getfd(pidfd, dupfd, 0);
+	printf("pidfd_getfd(%d%s, %d%s, 0) = %s%s\n",
+	       pidfd, pidfd >= 0 ? pidfd_str : "",
+	       dupfd, pidfd >= 0 ? FD0_PATH : "",
+	       errstr, rc >= 0 ? FD0_PATH : "");
+
+	puts("+++ exited with 0 +++");
+
+	close(child_wait_fds[1]);
+	int status;
+	assert(wait(&status) == pid);
+	assert(status == 0);
+
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_pidfd_getfd");
+
+#endif
diff -pruN 5.5-3/tests/pidfd_getfd.gen.test 5.9-0ubuntu2/tests/pidfd_getfd.gen.test
--- 5.5-3/tests/pidfd_getfd.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/pidfd_getfd.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_getfd -a18 -Xverbose -e signal=none </dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a18 -Xverbose -e signal=none </dev/full
diff -pruN 5.5-3/tests/pidfd_getfd-y.c 5.9-0ubuntu2/tests/pidfd_getfd-y.c
--- 5.5-3/tests/pidfd_getfd-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/pidfd_getfd-y.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,3 @@
+#define PIDFD_PATH "<anon_inode:[pidfd]>"
+#define FD0_PATH "</dev/full>"
+#include "pidfd_getfd.c"
diff -pruN 5.5-3/tests/pidfd_getfd-y.gen.test 5.9-0ubuntu2/tests/pidfd_getfd-y.gen.test
--- 5.5-3/tests/pidfd_getfd-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/pidfd_getfd-y.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_getfd-y --trace=pidfd_getfd -a18 -e signal=none -y </dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=pidfd_getfd -a18 -e signal=none -y </dev/full
diff -pruN 5.5-3/tests/pidfd_getfd-yy.c 5.9-0ubuntu2/tests/pidfd_getfd-yy.c
--- 5.5-3/tests/pidfd_getfd-yy.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/pidfd_getfd-yy.c	2020-04-05 13:28:30.000000000 +0000
@@ -0,0 +1,3 @@
+#define PRINT_PIDFD 1
+#define FD0_PATH "</dev/full<char 1:7>>"
+#include "pidfd_getfd.c"
diff -pruN 5.5-3/tests/pidfd_getfd-yy.gen.test 5.9-0ubuntu2/tests/pidfd_getfd-yy.gen.test
--- 5.5-3/tests/pidfd_getfd-yy.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/pidfd_getfd-yy.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_getfd-yy --trace=pidfd_getfd -a18 -e signal=none -yy </dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=pidfd_getfd -a18 -e signal=none -yy </dev/full
diff -pruN 5.5-3/tests/pidfd_open.c 5.9-0ubuntu2/tests/pidfd_open.c
--- 5.5-3/tests/pidfd_open.c	2019-08-15 11:54:22.000000000 +0000
+++ 5.9-0ubuntu2/tests/pidfd_open.c	2020-08-25 14:29:30.000000000 +0000
@@ -2,6 +2,7 @@
  * Check decoding of pidfd_open syscall.
  *
  * Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2019-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -9,6 +10,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #ifdef __NR_pidfd_open
 
@@ -36,6 +38,8 @@ k_pidfd_open(const unsigned int pid, con
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 # if defined PATH_TRACING || defined PRINT_PATHS
 	skip_if_unavailable("/proc/self/fd/");
 # endif
@@ -49,16 +53,19 @@ main(void)
 
 	k_pidfd_open(0, 0);
 # ifndef PATH_TRACING
+	pidns_print_leader();
 	printf("pidfd_open(0, 0) = %s\n", errstr);
 # endif
 
 	k_pidfd_open(-1U, 0);
 # ifndef PATH_TRACING
+	pidns_print_leader();
 	printf("pidfd_open(-1, 0) = %s\n", errstr);
 # endif
 
 	k_pidfd_open(0, -1U);
 # ifndef PATH_TRACING
+	pidns_print_leader();
 	printf("pidfd_open(0, %#x) = %s\n", -1U, errstr);
 # endif
 
@@ -67,7 +74,10 @@ main(void)
 
 	k_pidfd_open(pid, flags);
 # ifndef PATH_TRACING
-	printf("pidfd_open(%d, %#x) = %s\n", pid, flags, errstr);
+	const char *pid_str = pidns_pid2str(PT_TGID);
+	pidns_print_leader();
+	printf("pidfd_open(%d%s, %#x) = %s\n",
+		pid, pid_str, flags, errstr);
 # endif
 
 # ifdef PRINT_PATHS
@@ -79,15 +89,19 @@ main(void)
 # endif
 
 # ifndef PATH_TRACING
-	printf("pidfd_open(%d, 0) = "
-#  ifdef PRINT_PATHS
-	       "%ld<anon_inode:[pidfd]>\n", pid, rc
+	pidns_print_leader();
+	printf("pidfd_open(%d%s, 0) = "
+#  if defined PRINT_PIDFD
+	       "%ld<pid:%d>\n", pid, pid_str, rc, pid
+#  elif defined PRINT_PATHS
+	       "%ld<anon_inode:[pidfd]>\n", pid, pid_str, rc
 #  else
-	       "%s\n", pid, errstr
+	       "%s\n", pid, pid_str, errstr
 #  endif
 	       );
 # endif
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests/pidfd_open--decode-fd-path.c 5.9-0ubuntu2/tests/pidfd_open--decode-fd-path.c
--- 5.5-3/tests/pidfd_open--decode-fd-path.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/pidfd_open--decode-fd-path.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1 @@
+#include "pidfd_open-y.c"
diff -pruN 5.5-3/tests/pidfd_open--decode-fd-path.gen.test 5.9-0ubuntu2/tests/pidfd_open--decode-fd-path.gen.test
--- 5.5-3/tests/pidfd_open--decode-fd-path.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/pidfd_open--decode-fd-path.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_open--decode-fd-path -a17 -e decode-fd=path -e trace=pidfd_open); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a17 -e decode-fd=path -e trace=pidfd_open
diff -pruN 5.5-3/tests/pidfd_open--decode-fd-pidfd.c 5.9-0ubuntu2/tests/pidfd_open--decode-fd-pidfd.c
--- 5.5-3/tests/pidfd_open--decode-fd-pidfd.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/pidfd_open--decode-fd-pidfd.c	2020-04-05 13:28:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_PIDFD 1
+#include "pidfd_open-y.c"
diff -pruN 5.5-3/tests/pidfd_open--decode-fd-pidfd.gen.test 5.9-0ubuntu2/tests/pidfd_open--decode-fd-pidfd.gen.test
--- 5.5-3/tests/pidfd_open--decode-fd-pidfd.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/pidfd_open--decode-fd-pidfd.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_open--decode-fd-pidfd -a17 -e decode-fd=pidfd -e trace=pidfd_open); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a17 -e decode-fd=pidfd -e trace=pidfd_open
diff -pruN 5.5-3/tests/pidfd_open--decode-fd-socket.c 5.9-0ubuntu2/tests/pidfd_open--decode-fd-socket.c
--- 5.5-3/tests/pidfd_open--decode-fd-socket.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/pidfd_open--decode-fd-socket.c	2020-04-05 13:28:30.000000000 +0000
@@ -0,0 +1 @@
+#include "pidfd_open-y.c"
diff -pruN 5.5-3/tests/pidfd_open--decode-fd-socket.gen.test 5.9-0ubuntu2/tests/pidfd_open--decode-fd-socket.gen.test
--- 5.5-3/tests/pidfd_open--decode-fd-socket.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/pidfd_open--decode-fd-socket.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_open--decode-fd-socket -a17 -e decode-fd=socket -e trace=pidfd_open); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a17 -e decode-fd=socket -e trace=pidfd_open
diff -pruN 5.5-3/tests/pidfd_open--pidns-translation.c 5.9-0ubuntu2/tests/pidfd_open--pidns-translation.c
--- 5.5-3/tests/pidfd_open--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/pidfd_open--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "pidfd_open.c"
diff -pruN 5.5-3/tests/pidfd_open--pidns-translation.gen.test 5.9-0ubuntu2/tests/pidfd_open--pidns-translation.gen.test
--- 5.5-3/tests/pidfd_open--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/pidfd_open--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_open--pidns-translation test_pidns -a17 -e trace=pidfd_open); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a17 -e trace=pidfd_open
diff -pruN 5.5-3/tests/pidfd_open-yy.c 5.9-0ubuntu2/tests/pidfd_open-yy.c
--- 5.5-3/tests/pidfd_open-yy.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/pidfd_open-yy.c	2020-04-05 13:28:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_PIDFD 1
+#include "pidfd_open-y.c"
diff -pruN 5.5-3/tests/pidfd_open-yy.gen.test 5.9-0ubuntu2/tests/pidfd_open-yy.gen.test
--- 5.5-3/tests/pidfd_open-yy.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/pidfd_open-yy.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_open-yy -a17 -yy -e trace=pidfd_open); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a17 -yy -e trace=pidfd_open
diff -pruN 5.5-3/tests/pidfd_send_signal.c 5.9-0ubuntu2/tests/pidfd_send_signal.c
--- 5.5-3/tests/pidfd_send_signal.c	2019-08-14 11:22:32.000000000 +0000
+++ 5.9-0ubuntu2/tests/pidfd_send_signal.c	2020-08-25 14:29:30.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check decoding of pidfd_send_signal syscall.
  *
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,6 +10,7 @@
 #include "tests.h"
 #include <unistd.h>
 #include "scno.h"
+#include "pidns.h"
 
 #ifdef __NR_pidfd_send_signal
 
@@ -36,6 +37,8 @@ sys_pidfd_send_signal(int pidfd, int sig
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	static const char null_path[] = "/dev/null";
 
 	int fd = open(null_path, O_RDONLY);
@@ -46,19 +49,23 @@ main(void)
 	const void *esi = (const void *) si + 1;
 
 	sys_pidfd_send_signal(fd, SIGUSR1, esi, 0);
+	pidns_print_leader();
 	printf("pidfd_send_signal(%d, SIGUSR1, %p, 0) = %s\n",
 	       fd, esi, errstr);
 
 	si->si_signo = SIGUSR1;
 	si->si_code = SI_QUEUE;
+	si->si_pid = getpid();
 
 	sys_pidfd_send_signal(fd, SIGUSR2, si, -1);
+	pidns_print_leader();
 	printf("pidfd_send_signal(%d, SIGUSR2, {si_signo=SIGUSR1"
-	       ", si_code=SI_QUEUE, si_errno=%u, si_pid=%u, si_uid=%u"
+	       ", si_code=SI_QUEUE, si_errno=%u, si_pid=%d%s, si_uid=%d"
 	       ", si_value={int=%d, ptr=%p}}, %#x) = %s\n",
-	       fd, si->si_errno, si->si_pid, si->si_uid, si->si_int, si->si_ptr,
-	       -1U, errstr);
+	       fd, si->si_errno, si->si_pid, pidns_pid2str(PT_TGID), si->si_uid,
+	       si->si_int, si->si_ptr, -1U, errstr);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests/pidfd_send_signal--pidns-translation.c 5.9-0ubuntu2/tests/pidfd_send_signal--pidns-translation.c
--- 5.5-3/tests/pidfd_send_signal--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/pidfd_send_signal--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "pidfd_send_signal.c"
diff -pruN 5.5-3/tests/pidfd_send_signal--pidns-translation.gen.test 5.9-0ubuntu2/tests/pidfd_send_signal--pidns-translation.gen.test
--- 5.5-3/tests/pidfd_send_signal--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/pidfd_send_signal--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_send_signal--pidns-translation test_pidns -e trace=pidfd_send_signal); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -e trace=pidfd_send_signal
diff -pruN 5.5-3/tests/pidns.c 5.9-0ubuntu2/tests/pidns.c
--- 5.5-3/tests/pidns.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/pidns.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,237 @@
+/*
+ * Testing framework for PID namespace translation
+ *
+ * Copyright (c) 2020 Ákos Uzonyi <uzonyi.akos@gmail.com>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+#include "tests.h"
+#include "pidns.h"
+#include "nsfs.h"
+
+#include <errno.h>
+#include <stdio.h>
+#include <string.h>
+#include <sys/types.h>
+#include <signal.h>
+#include <stdlib.h>
+#include <sched.h>
+#include <unistd.h>
+#include <sys/wait.h>
+#include <linux/sched.h>
+#include <fcntl.h>
+#include <sys/ioctl.h>
+
+#ifndef CLONE_NEWUSER
+# define CLONE_NEWUSER 0x10000000
+#endif
+
+#ifndef CLONE_NEWPID
+# define CLONE_NEWPID 0x20000000
+#endif
+
+static bool pidns_translation = false;
+static bool pidns_unshared = false;
+
+/* Our PIDs in strace's namespace */
+static pid_t pidns_strace_ids[PT_COUNT];
+
+void
+pidns_print_leader(void)
+{
+	if (pidns_translation)
+		printf("%-5d ", pidns_strace_ids[PT_TID]);
+}
+
+const char *
+pidns_pid2str(enum pid_type type)
+{
+	static const char format[] = " /* %d in strace's PID NS */";
+	static char buf[PT_COUNT][sizeof(format) + sizeof(int) * 3];
+
+	if (type < 0 || type >= PT_COUNT)
+		return "";
+
+	if (!pidns_unshared || !pidns_strace_ids[type])
+		return "";
+
+	snprintf(buf[type], sizeof(buf[type]), format, pidns_strace_ids[type]);
+	return buf[type];
+}
+
+/**
+ * This function is like fork, but does a few more things. It sets up the
+ * child's PGID and SID according to the parameters. Also it fills the
+ * pidns_strace_ids array in the child's memory with the PIDs of the child in
+ * parent's PID namespace. In the parent it waits for the child to terminate
+ * (but leaves the zombie to use it later as a process group). If the child
+ * terminates with nonzero exit status, the test is failed.
+ *
+ * @param pgid     The process group the child should be moved to. It's expected
+ *                 to be a PID of a zombie process (will be reaped). If
+ *                 negative, leave the child in the process group of the parent.
+ *                 If 0, move the process to its own process group.
+ * @param new_sid  Wheather child should be moved to a new session.
+ */
+static pid_t
+pidns_fork(pid_t pgid, bool new_sid)
+{
+	int strace_ids_pipe[2];
+	if (pipe(strace_ids_pipe) < 0)
+		perror_msg_and_fail("pipe");
+
+	fflush(stdout);
+	pid_t pid = fork();
+	if (pid < 0)
+		perror_msg_and_fail("fork");
+
+	if (!pid) {
+		close(strace_ids_pipe[1]);
+
+		ssize_t len = read(strace_ids_pipe[0], pidns_strace_ids,
+				sizeof(pidns_strace_ids));
+		if (len < 0)
+			perror_msg_and_fail("read");
+		if (len != sizeof(pidns_strace_ids))
+			error_msg_and_fail("read returned < sizeof(pidns_strace_ids)");
+
+		close(strace_ids_pipe[0]);
+
+		if (pidns_strace_ids[PT_SID])
+			setsid();
+
+		return 0;
+	}
+
+	pidns_strace_ids[PT_TID] = pid;
+	pidns_strace_ids[PT_TGID] = pid;
+	pidns_strace_ids[PT_PGID] = 0;
+	pidns_strace_ids[PT_SID] = 0;
+
+	if (!pgid)
+		pgid = pid;
+
+	if (pgid > 0) {
+		if (setpgid(pid, pgid) < 0)
+			perror_msg_and_fail("setpgid");
+
+		pidns_strace_ids[PT_PGID] = pgid;
+	}
+
+	/* Reap group leader to test PGID decoding */
+	if (pgid > 0 && pgid != pid) {
+		int ret = waitpid(pgid, NULL, WNOHANG);
+		if (ret < 0)
+			perror_msg_and_fail("wait");
+		if (!ret)
+			error_msg_and_fail("could not reap group leader");
+	}
+
+	if (new_sid) {
+		pidns_strace_ids[PT_SID] = pid;
+		pidns_strace_ids[PT_PGID] = pid;
+	}
+
+	ssize_t len = write(strace_ids_pipe[1], pidns_strace_ids,
+	                     sizeof(pidns_strace_ids));
+	if (len < 0)
+		perror_msg_and_fail("write");
+	if (len != sizeof(pidns_strace_ids))
+		error_msg_and_fail("write returned < sizeof(pidns_strace_ids)");
+
+	close(strace_ids_pipe[0]);
+	close(strace_ids_pipe[1]);
+
+	/* WNOWAIT: leave the zombie, to be able to use it as a process group */
+	siginfo_t siginfo;
+	if (waitid(P_PID, pid, &siginfo, WEXITED | WNOWAIT) < 0)
+		perror_msg_and_fail("wait");
+	if (siginfo.si_code != CLD_EXITED || siginfo.si_status)
+		error_msg_and_fail("child terminated with nonzero exit status");
+
+	return pid;
+}
+
+static void
+create_init_process(void)
+{
+	int child_pipe[2];
+	if (pipe(child_pipe) < 0)
+		perror_msg_and_fail("pipe");
+
+	pid_t pid = fork();
+	if (pid < 0)
+		perror_msg_and_fail("fork");
+
+	if (!pid) {
+		close(child_pipe[1]);
+		if (read(child_pipe[0], &child_pipe[1], sizeof(int)) != 0)
+			_exit(1);
+		_exit(0);
+	}
+
+	close(child_pipe[0]);
+}
+
+void
+check_ns_ioctl(void)
+{
+	int fd = open("/proc/self/ns/pid", O_RDONLY);
+	if (fd < 0) {
+		if (errno == ENOENT)
+			perror_msg_and_skip("opening /proc/self/ns/pid");
+		else
+			perror_msg_and_fail("opening /proc/self/ns/pid");
+	}
+
+	int userns_fd = ioctl(fd, NS_GET_USERNS);
+	if (userns_fd < 0) {
+		if (errno == ENOTTY)
+			error_msg_and_skip("NS_* ioctl commands are not "
+			                   "supported by the kernel");
+		else
+			perror_msg_and_fail("ioctl(NS_GET_USERNS)");
+	}
+
+	close(userns_fd);
+	close(fd);
+}
+
+void
+pidns_test_init(void)
+{
+	pidns_translation = true;
+
+	check_ns_ioctl();
+
+	if (!pidns_fork(-1, false))
+		return;
+
+	/* Unshare user namespace too, so we do not need to be root */
+	if (unshare(CLONE_NEWUSER | CLONE_NEWPID) < 0) {
+		if (errno == EPERM)
+			perror_msg_and_skip("unshare");
+
+		perror_msg_and_fail("unshare");
+	}
+
+	pidns_unshared = true;
+
+	create_init_process();
+
+	if (!pidns_fork(-1, false))
+		return;
+
+	if (!pidns_fork(-1, true))
+		return;
+
+	pid_t pgid;
+	if (!(pgid = pidns_fork(0, false)))
+		return;
+
+	if (!pidns_fork(pgid, false))
+		return;
+
+	exit(0);
+}
diff -pruN 5.5-3/tests/pidns-cache.c 5.9-0ubuntu2/tests/pidns-cache.c
--- 5.5-3/tests/pidns-cache.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/pidns-cache.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,62 @@
+/*
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+#include "pidns.h"
+
+#if defined __NR_getpid && (!defined __NR_getxpid || __NR_getxpid != __NR_getpid)
+
+# include <stdio.h>
+# include <unistd.h>
+# include <sys/time.h>
+
+# define SYSCALL_COUNT 1000
+
+/**
+ * Max ratio of the execution time with and without pidns translation.
+ */
+# define MAX_TIME_RATIO 20
+
+static long
+execute_syscalls(void)
+{
+	/* Load our PID in the cache */
+	syscall(__NR_getpid);
+
+	struct timeval stop, start;
+	gettimeofday(&start, NULL);
+
+	for (int i = 0; i < SYSCALL_COUNT; i++)
+	       syscall(__NR_getpid);
+
+	gettimeofday(&stop, NULL);
+
+	return (stop.tv_usec - start.tv_usec) +
+		(stop.tv_sec - start.tv_sec) * 1000000;
+}
+
+int
+main(void)
+{
+	long max_us = execute_syscalls() * MAX_TIME_RATIO;
+
+	pidns_test_init();
+
+	long us = execute_syscalls();
+	if (us > max_us)
+		error_msg_and_fail("pidns translation took too long: %ld us "
+		                   "(max: %ld us)", us, max_us);
+
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_getpid")
+
+#endif
diff -pruN 5.5-3/tests/pidns-cache.test 5.9-0ubuntu2/tests/pidns-cache.test
--- 5.5-3/tests/pidns-cache.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/pidns-cache.test	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,15 @@
+#!/bin/sh
+#
+# Test pidns translation cache.
+#
+# Copyright (c) 2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: GPL-2.0-or-later
+
+. "${srcdir=.}/init.sh"
+
+check_prog timeout
+
+run_prog > /dev/null
+run_strace --pidns-translation -f -e trace=getpid $args
diff -pruN 5.5-3/tests/pidns.h 5.9-0ubuntu2/tests/pidns.h
--- 5.5-3/tests/pidns.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/pidns.h	2020-09-23 16:29:35.000000000 +0000
@@ -0,0 +1,56 @@
+/*
+ * Test PID namespace translation
+ *
+ * Copyright (c) 2020 Ákos Uzonyi <uzonyi.akos@gmail.com>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+#ifndef STRACE_PIDNS_H
+# define STRACE_PIDNS_H
+
+# ifdef PIDNS_TRANSLATION
+#  define PIDNS_TEST_INIT pidns_test_init()
+# else
+#  define PIDNS_TEST_INIT
+# endif
+
+# include <sys/types.h>
+
+enum pid_type {
+	PT_TID,
+	PT_TGID,
+	PT_PGID,
+	PT_SID,
+
+	PT_COUNT,
+	PT_NONE = -1
+};
+
+/* Prints leader (process tid) if pidns_test_init was called */
+void pidns_print_leader(void);
+
+/*
+ * Returns a static buffer containing the translation string of our PID.
+ */
+const char *pidns_pid2str(enum pid_type type);
+
+/**
+ * Skips the test if NS_* ioctl commands are not supported by the kernel.
+ */
+void check_ns_ioctl(void);
+
+/**
+ * Init pidns testing.
+ *
+ * Should be called at the beginning of the test's main function
+ *
+ * This function calls fork a couple of times, and returns in the child
+ * processes. These child processes are in a new PID namespace with different
+ * PID configurations (group leader, session leader, ...). If any child
+ * terminates with nonzero exit status the test is failed. Otherwise the test is
+ * succesful, and the parent process exits with 0.
+ */
+void pidns_test_init(void);
+
+#endif
\ No newline at end of file
diff -pruN 5.5-3/tests/poll-P.test 5.9-0ubuntu2/tests/poll-P.test
--- 5.5-3/tests/poll-P.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/poll-P.test	2020-04-06 16:22:20.000000000 +0000
@@ -2,20 +2,20 @@
 #
 # Check path tracing of poll syscall.
 #
-# Copyright (c) 2018 The strace developers.
+# Copyright (c) 2018-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/init.sh"
 
-run_prog > /dev/null
+run_prog > /dev/null 9>>/dev/full
 run_strace -a16 -vepoll -P /dev/full 9>>/dev/full \
 	$args > "$EXP"
 match_diff "$LOG" "$EXP"
 
 for abbrev in 0 1 2 3 4 5; do
-	run_prog "../$NAME" $abbrev > /dev/null
+	run_prog "../$NAME" $abbrev > /dev/null 9>>/dev/full
 	run_strace -a16 -epoll -s$abbrev -P /dev/full 9>>/dev/full \
 		$args > "$EXP"
 	match_diff "$LOG" "$EXP"
diff -pruN 5.5-3/tests/prctl-name.c 5.9-0ubuntu2/tests/prctl-name.c
--- 5.5-3/tests/prctl-name.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/prctl-name.c	2020-04-03 22:58:26.000000000 +0000
@@ -3,19 +3,16 @@
  *
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include <sys/prctl.h>
 
-#ifdef HAVE_PRCTL
-# include <sys/prctl.h>
-#endif
-
-#if defined HAVE_PRCTL && defined PR_GET_NAME && defined PR_SET_NAME
+#if defined PR_GET_NAME && defined PR_SET_NAME
 
 # include <stdio.h>
 # include <string.h>
@@ -79,6 +76,6 @@ main(void)
 
 #else
 
-SKIP_MAIN_UNDEFINED("HAVE_PRCTL && PR_GET_NAME && PR_SET_NAME")
+SKIP_MAIN_UNDEFINED("PR_GET_NAME && PR_SET_NAME")
 
 #endif
diff -pruN 5.5-3/tests/prctl-pdeathsig.c 5.9-0ubuntu2/tests/prctl-pdeathsig.c
--- 5.5-3/tests/prctl-pdeathsig.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/prctl-pdeathsig.c	2020-04-03 22:58:26.000000000 +0000
@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2016 JingPiao Chen <chenjingpiao@foxmail.com>
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -17,7 +17,7 @@
 
 # include <stdio.h>
 # include <unistd.h>
-# include <sys/signal.h>
+# include <signal.h>
 
 int
 main(void)
diff -pruN 5.5-3/tests/prctl-seccomp-filter-v.c 5.9-0ubuntu2/tests/prctl-seccomp-filter-v.c
--- 5.5-3/tests/prctl-seccomp-filter-v.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/prctl-seccomp-filter-v.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
  * Check verbose decoding of prctl PR_SET_SECCOMP SECCOMP_MODE_FILTER.
  *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -13,18 +13,14 @@
 #include <unistd.h>
 #include <stdio.h>
 #include <errno.h>
-#include "scno.h"
-
-#ifdef HAVE_PRCTL
-# include <sys/prctl.h>
-#endif
+#include <sys/prctl.h>
 #ifdef HAVE_LINUX_SECCOMP_H
 # include <linux/seccomp.h>
 #endif
 #include <linux/filter.h>
+#include "scno.h"
 
-#if defined HAVE_PRCTL \
- && defined PR_SET_NO_NEW_PRIVS \
+#if defined PR_SET_NO_NEW_PRIVS \
  && defined PR_SET_SECCOMP \
  && defined SECCOMP_MODE_FILTER \
  && defined SECCOMP_RET_ERRNO \
@@ -117,7 +113,7 @@ main(void)
 
 #else
 
-SKIP_MAIN_UNDEFINED("HAVE_PRCTL && PR_SET_NO_NEW_PRIVS && PR_SET_SECCOMP"
+SKIP_MAIN_UNDEFINED("PR_SET_NO_NEW_PRIVS && PR_SET_SECCOMP"
 		    " && SECCOMP_MODE_FILTER && SECCOMP_RET_ERRNO"
 		    " && BPF_JUMP && BPF_STMT")
 
diff -pruN 5.5-3/tests/prctl-seccomp-strict.c 5.9-0ubuntu2/tests/prctl-seccomp-strict.c
--- 5.5-3/tests/prctl-seccomp-strict.c	2019-12-15 16:29:06.000000000 +0000
+++ 5.9-0ubuntu2/tests/prctl-seccomp-strict.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,18 +1,16 @@
 /*
  * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include <sys/prctl.h>
 #include "scno.h"
-#ifdef HAVE_PRCTL
-# include <sys/prctl.h>
-#endif
 
-#if defined HAVE_PRCTL && defined PR_SET_SECCOMP && defined __NR_exit
+#if defined PR_SET_SECCOMP && defined __NR_exit
 
 # include <stdio.h>
 # include <unistd.h>
@@ -49,6 +47,6 @@ main(void)
 
 #else
 
-SKIP_MAIN_UNDEFINED("HAVE_PRCTL && PR_SET_SECCOMP && __NR_exit")
+SKIP_MAIN_UNDEFINED("PR_SET_SECCOMP && __NR_exit")
 
 #endif
diff -pruN 5.5-3/tests/preadv.c 5.9-0ubuntu2/tests/preadv.c
--- 5.5-3/tests/preadv.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/preadv.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2014-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -74,12 +74,7 @@ main(void)
 		perror_msg_and_fail("preadv");
 	printf("preadv(0, [], 0, -3) = -1 EINVAL (%m)\n");
 
-	static const char tmp[] = "preadv-tmpfile";
-	int fd = open(tmp, O_RDWR | O_CREAT | O_TRUNC, 0600);
-	if (fd < 0)
-		perror_msg_and_fail("open");
-	if (unlink(tmp))
-		perror_msg_and_fail("unlink");
+	int fd = create_tmpfile(O_RDWR);
 
 	static const char w[] = "0123456789abcde";
 	if (write(fd, w, LENGTH_OF(w)) != LENGTH_OF(w))
diff -pruN 5.5-3/tests/printpath-umovestr-undumpable.c 5.9-0ubuntu2/tests/printpath-umovestr-undumpable.c
--- 5.5-3/tests/printpath-umovestr-undumpable.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/printpath-umovestr-undumpable.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,19 +1,16 @@
 /*
  * Force legacy printpath/umovestr using PR_SET_DUMPABLE.
  *
- * Copyright (c) 2017-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2017-2020 Dmitry V. Levin <ldv@altlinux.org>
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include <sys/prctl.h>
 
-#ifdef HAVE_PRCTL
-# include <sys/prctl.h>
-#endif
-
-#if defined HAVE_PRCTL && defined PR_SET_DUMPABLE
+#ifdef PR_SET_DUMPABLE
 
 # include <stdio.h>
 # include <unistd.h>
@@ -46,6 +43,6 @@ main(void)
 
 #else
 
-SKIP_MAIN_UNDEFINED("HAVE_PRCTL && PR_SET_DUMPABLE")
+SKIP_MAIN_UNDEFINED("PR_SET_DUMPABLE")
 
 #endif
diff -pruN 5.5-3/tests/print_ppid_tracerpid.c 5.9-0ubuntu2/tests/print_ppid_tracerpid.c
--- 5.5-3/tests/print_ppid_tracerpid.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/print_ppid_tracerpid.c	2020-05-27 08:00:00.000000000 +0000
@@ -0,0 +1,42 @@
+/*
+ * Helper program for strace-D.test
+ *
+ * Copyright (c) 2019-2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <unistd.h>
+
+int
+main(void)
+{
+	static const char status[] = "/proc/self/status";
+	FILE *fp = fopen(status, "r");
+	if (!fp)
+		perror_msg_and_fail("fopen: %s", status);
+
+	static const char prefix1[] = "PPid:";
+	static const char prefix2[] = "TracerPid:";
+	char *line = NULL;
+	size_t n = 0;
+
+	while (getline(&line, &n, fp) > 0) {
+		if (strncmp(line, prefix1, sizeof(prefix1) - 1) == 0 ||
+		    strncmp(line, prefix2, sizeof(prefix2) - 1) == 0)
+			fputs(line, stdout);
+	}
+
+	if (!line)
+		perror_msg_and_fail("getline");
+
+	free(line);
+	fclose(fp);
+
+	return 0;
+}
diff -pruN 5.5-3/tests/printstrn-umoven-undumpable.c 5.9-0ubuntu2/tests/printstrn-umoven-undumpable.c
--- 5.5-3/tests/printstrn-umoven-undumpable.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/printstrn-umoven-undumpable.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,19 +1,16 @@
 /*
  * Force legacy printpath/umovestr using PR_SET_DUMPABLE.
  *
- * Copyright (c) 2017-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2017-2020 Dmitry V. Levin <ldv@altlinux.org>
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include <sys/prctl.h>
 
-#ifdef HAVE_PRCTL
-# include <sys/prctl.h>
-#endif
-
-#if defined HAVE_PRCTL && defined PR_SET_DUMPABLE
+#ifdef PR_SET_DUMPABLE
 
 # include <stdio.h>
 # include <unistd.h>
@@ -46,6 +43,6 @@ main(void)
 
 #else
 
-SKIP_MAIN_UNDEFINED("HAVE_PRCTL && PR_SET_DUMPABLE")
+SKIP_MAIN_UNDEFINED("PR_SET_DUMPABLE")
 
 #endif
diff -pruN 5.5-3/tests/prlimit64.c 5.9-0ubuntu2/tests/prlimit64.c
--- 5.5-3/tests/prlimit64.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/prlimit64.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of prlimit64 syscall.
  *
  * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -19,6 +19,7 @@
 # include <sys/resource.h>
 # include <unistd.h>
 
+# include "pidns.h"
 # include "xlat.h"
 # include "xlat/resources.h"
 
@@ -42,8 +43,11 @@ sprint_rlim(uint64_t lim)
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	unsigned long pid =
 		(unsigned long) 0xdefaced00000000ULL | (unsigned) getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
 	uint64_t *const rlimit = tail_alloc(sizeof(*rlimit) * 2);
 	const struct xlat_data *xlat;
 	size_t i = 0;
@@ -54,18 +58,23 @@ main(void)
 
 		unsigned long res = 0xfacefeed00000000ULL | xlat->val;
 		long rc = syscall(__NR_prlimit64, pid, res, 0, rlimit);
+		pidns_print_leader();
 		if (rc)
-			printf("prlimit64(%d, %s, NULL, %p) = %ld %s (%m)\n",
-			       (unsigned) pid, xlat->str, rlimit,
+			printf("prlimit64(%d%s, %s, NULL, %p) ="
+				     " %ld %s (%m)\n",
+			       (unsigned) pid, pid_str,
+			       xlat->str, rlimit,
 			       rc, errno2name());
 		else
-			printf("prlimit64(%d, %s, NULL"
+			printf("prlimit64(%d%s, %s, NULL"
 			       ", {rlim_cur=%s, rlim_max=%s}) = 0\n",
-			       (unsigned) pid, xlat->str,
+			       (unsigned) pid, pid_str,
+			       xlat->str,
 			       sprint_rlim(rlimit[0]),
 			       sprint_rlim(rlimit[1]));
 	}
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests/prlimit64--pidns-translation.c 5.9-0ubuntu2/tests/prlimit64--pidns-translation.c
--- 5.5-3/tests/prlimit64--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/prlimit64--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "prlimit64.c"
diff -pruN 5.5-3/tests/prlimit64--pidns-translation.gen.test 5.9-0ubuntu2/tests/prlimit64--pidns-translation.gen.test
--- 5.5-3/tests/prlimit64--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/prlimit64--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (prlimit64--pidns-translation test_pidns -e trace=prlimit64); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -e trace=prlimit64
diff -pruN 5.5-3/tests/process_vm_readv--pidns-translation.c 5.9-0ubuntu2/tests/process_vm_readv--pidns-translation.c
--- 5.5-3/tests/process_vm_readv--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/process_vm_readv--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "process_vm_readv.c"
diff -pruN 5.5-3/tests/process_vm_readv--pidns-translation.gen.test 5.9-0ubuntu2/tests/process_vm_readv--pidns-translation.gen.test
--- 5.5-3/tests/process_vm_readv--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/process_vm_readv--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (process_vm_readv--pidns-translation test_pidns -s5 -a37 -e trace=process_vm_readv); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -s5 -a37 -e trace=process_vm_readv
diff -pruN 5.5-3/tests/process_vm_readv_writev.c 5.9-0ubuntu2/tests/process_vm_readv_writev.c
--- 5.5-3/tests/process_vm_readv_writev.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/process_vm_readv_writev.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of process_vm_readv/process_vm_writev syscall.
  *
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -12,6 +12,7 @@
 #include <stdio.h>
 #include <unistd.h>
 #include <sys/uio.h>
+#include "pidns.h"
 
 #if OP_WR
 # define in_iovec  rmt_iovec
@@ -121,7 +122,7 @@ print_iov(const struct iovec *iov, const
 }
 
 static void
-do_call(kernel_ulong_t pid,
+do_call(kernel_ulong_t pid, enum pid_type pid_type,
 	kernel_ulong_t local_iov, const char *local_arg,
 	kernel_ulong_t liovcnt,
 	kernel_ulong_t remote_iov, const char *remote_arg,
@@ -135,7 +136,8 @@ do_call(kernel_ulong_t pid,
 		flags);
 	errstr = sprintrc(rc);
 
-	printf("%s(%d, ", OP_STR, (int) pid);
+	pidns_print_leader();
+	printf("%s(%d%s, ", OP_STR, (int) pid, pidns_pid2str(pid_type));
 
 	if (pr_iov)
 		pr_iov((const struct iovec *) (uintptr_t) local_iov, local_arg,
@@ -164,6 +166,8 @@ ptr_cast(void *ptr)
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	enum {
 		SIZE_11 = 2,
 		SIZE_12 = 3,
@@ -243,18 +247,18 @@ main(void)
 	fill_memory_ex(data2_out, SIZE_2, SEGM2_BASE, SIZE_2);
 
 
-	do_call(bogus_pid, (kernel_ulong_t) (uintptr_t) ARG_STR(NULL),
+	do_call(bogus_pid, PT_NONE, (kernel_ulong_t) (uintptr_t) ARG_STR(NULL),
 		bogus_iovcnt1, (kernel_ulong_t) (uintptr_t) ARG_STR(NULL),
 		bogus_iovcnt2, bogus_flags, NULL);
 
-	do_call(my_pid, ptr_cast(bogus_iov + ARRAY_SIZE(bogus_iovec)),
+	do_call(my_pid, PT_TGID, ptr_cast(bogus_iov + ARRAY_SIZE(bogus_iovec)),
 		"[]", 0, ptr_cast(in_iov + ARRAY_SIZE(in_iovec)), "[]",
 		0, 0, NULL);
-	do_call(my_pid, ptr_cast(bogus_iov + ARRAY_SIZE(bogus_iovec)), NULL,
-		bogus_iovcnt1, ptr_cast(in_iov + ARRAY_SIZE(in_iovec)), NULL,
-		bogus_iovcnt2, 0, print_iov);
+	do_call(my_pid, PT_TGID, ptr_cast(bogus_iov + ARRAY_SIZE(bogus_iovec)),
+		NULL, bogus_iovcnt1, ptr_cast(in_iov + ARRAY_SIZE(in_iovec)),
+		NULL, bogus_iovcnt2, 0, print_iov);
 
-	do_call(my_pid, ptr_cast(bogus_iov), (char *) &bogus_arg,
+	do_call(my_pid, PT_TGID, ptr_cast(bogus_iov), (char *) &bogus_arg,
 		ARRAY_SIZE(bogus_iovec), ptr_cast(rmt_iov + 2),
 		(char *) &rmt_arg_cut, ARRAY_SIZE(rmt_iovec) - 2, 0, print_iov);
 
@@ -263,7 +267,7 @@ main(void)
 	lcl_arg_cut.check_rc = 1;
 #endif
 
-	do_call(my_pid, ptr_cast(lcl_iov + 2), (char *) &lcl_arg_cut,
+	do_call(my_pid, PT_TGID, ptr_cast(lcl_iov + 2), (char *) &lcl_arg_cut,
 		ARRAY_SIZE(lcl_iovec) - 1, ptr_cast(bogus_iov + 2),
 		(char *) &bogus_arg_cut, ARRAY_SIZE(bogus_iovec) - 1, 0,
 		print_iov);
@@ -273,15 +277,16 @@ main(void)
 	rmt_arg_cut.addr_term = 1;
 	rmt_arg_cut.count = 5;
 
-	do_call(my_pid, ptr_cast(lcl_iov + 2), (char *) &lcl_arg_cut,
+	do_call(my_pid, PT_TGID, ptr_cast(lcl_iov + 2), (char *) &lcl_arg_cut,
 		ARRAY_SIZE(lcl_iovec) - 2, ptr_cast(rmt_iov + 1),
 		(char *) &rmt_arg_cut, ARRAY_SIZE(rmt_iovec), 0, print_iov);
 
 	/* Correct call */
-	do_call(my_pid, ptr_cast(lcl_iov), (char *) &lcl_arg,
+	do_call(my_pid, PT_TGID, ptr_cast(lcl_iov), (char *) &lcl_arg,
 		ARRAY_SIZE(lcl_iovec), ptr_cast(rmt_iov), (char *) &rmt_arg,
 		ARRAY_SIZE(rmt_iovec), 0, print_iov);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 
 	return 0;
diff -pruN 5.5-3/tests/process_vm_writev--pidns-translation.c 5.9-0ubuntu2/tests/process_vm_writev--pidns-translation.c
--- 5.5-3/tests/process_vm_writev--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/process_vm_writev--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "process_vm_writev.c"
diff -pruN 5.5-3/tests/process_vm_writev--pidns-translation.gen.test 5.9-0ubuntu2/tests/process_vm_writev--pidns-translation.gen.test
--- 5.5-3/tests/process_vm_writev--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/process_vm_writev--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (process_vm_writev--pidns-translation test_pidns -s5 -a38 -e trace=process_vm_writev); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -s5 -a38 -e trace=process_vm_writev
diff -pruN 5.5-3/tests/ptrace.c 5.9-0ubuntu2/tests/ptrace.c
--- 5.5-3/tests/ptrace.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/ptrace.c	2020-08-03 08:00:00.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of ptrace syscall.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -127,16 +127,16 @@ test_peeksiginfo(unsigned long pid, cons
 			printf("ptrace(PTRACE_PEEKSIGINFO, %u"
 			       ", {off=%llu, flags=0, nr=%u}"
 			       ", [{si_signo=SIGUSR1, si_code=SI_TKILL"
-			       ", si_pid=%u, si_uid=%u}"
+			       ", si_pid=%d, si_uid=%d}"
 			       ", {si_signo=SIGUSR2, si_code=SI_TKILL"
-			       ", si_pid=%u, si_uid=%u}"
+			       ", si_pid=%d, si_uid=%d}"
 			       ", {si_signo=SIGALRM, si_code=SI_TKILL"
-			       ", si_pid=%u, si_uid=%u}"
+			       ", si_pid=%d, si_uid=%d}"
 			       "]) = %s\n",
 			       (unsigned) pid, psi->off, psi->nr,
-			       (unsigned) pid, (unsigned) uid,
-			       (unsigned) pid, (unsigned) uid,
-			       (unsigned) pid, (unsigned) uid,
+			       (int) pid, (int) uid,
+			       (int) pid, (int) uid,
+			       (int) pid, (int) uid,
 			       errstr);
 		}
 
diff -pruN 5.5-3/tests/ptrace_syscall_info.c 5.9-0ubuntu2/tests/ptrace_syscall_info.c
--- 5.5-3/tests/ptrace_syscall_info.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests/ptrace_syscall_info.c	2020-05-27 08:00:00.000000000 +0000
@@ -247,7 +247,12 @@ test_entry(void)
 					break;
 				goto printed_entry_nr;
 			}
-			if (info.entry.args[i] != exp_args[i + 1])
+#if SIZEOF_KERNEL_LONG_T > SIZEOF_LONG
+# define CAST (unsigned long)
+#else
+# define CAST
+#endif
+			if (CAST info.entry.args[i] != exp_args[i + 1])
 				FAIL("#%d: entry stop mismatch", ptrace_stop);
 			printf("%s%#llx", (i ? ", " : ", arg=["),
 			       (unsigned long long) info.entry.args[i]);
diff -pruN 5.5-3/tests/pure_executables.am 5.9-0ubuntu2/tests/pure_executables.am
--- 5.5-3/tests/pure_executables.am	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/tests/pure_executables.am	2020-09-24 09:18:49.000000000 +0000
@@ -27,13 +27,29 @@ PURE_EXECUTABLES = \
   clone3-Xabbrev \
   clone3-Xraw \
   clone3-Xverbose \
+  close_range \
+  close_range-P \
+  close_range-y \
+  close_range-yy \
   copy_file_range \
   creat \
   delete_module \
+  dev--decode-fds-dev \
+  dev--decode-fds-path \
+  dev--decode-fds-socket \
   dev-yy \
   dup \
+  dup-P \
+  dup-y \
+  dup-yy \
   dup2 \
+  dup2-P \
+  dup2-y \
+  dup2-yy \
   dup3 \
+  dup3-P \
+  dup3-y \
+  dup3-yy \
   epoll_create \
   epoll_create1 \
   epoll_ctl \
@@ -44,6 +60,13 @@ PURE_EXECUTABLES = \
   execve \
   execveat \
   faccessat \
+  faccessat-P \
+  faccessat-y \
+  faccessat-yy \
+  faccessat2 \
+  faccessat2-P \
+  faccessat2-y \
+  faccessat2-yy \
   fadvise64 \
   fadvise64_64 \
   fallocate \
@@ -92,7 +115,9 @@ PURE_EXECUTABLES = \
   getcpu \
   getcwd \
   getdents \
+  getdents-v \
   getdents64 \
+  getdents64-v \
   getegid \
   getegid32 \
   geteuid \
@@ -116,7 +141,9 @@ PURE_EXECUTABLES = \
   getsockname \
   getuid \
   getuid32 \
-  getxxid \
+  getxgid \
+  getxpid \
+  getxuid \
   group_req \
   inet-cmsg \
   init_module \
@@ -139,6 +166,14 @@ PURE_EXECUTABLES = \
   ioctl_evdev-v-Xabbrev \
   ioctl_evdev-v-Xraw \
   ioctl_evdev-v-Xverbose \
+  ioctl_hdio \
+  ioctl_hdio-Xabbrev \
+  ioctl_hdio-Xraw \
+  ioctl_hdio-Xverbose \
+  ioctl_hdio-v \
+  ioctl_hdio-v-Xabbrev \
+  ioctl_hdio-v-Xraw \
+  ioctl_hdio-v-Xverbose \
   ioctl_inotify \
   ioctl_kvm_run \
   ioctl_kvm_run-v \
@@ -154,8 +189,16 @@ PURE_EXECUTABLES = \
   ioctl_sg_io_v3 \
   ioctl_sg_io_v4 \
   ioctl_sock_gifconf \
+  ioctl_tee \
   ioctl_uffdio \
   ioctl_v4l2 \
+  ioctl_v4l2-Xabbrev \
+  ioctl_v4l2-Xraw \
+  ioctl_v4l2-Xverbose \
+  ioctl_v4l2-v \
+  ioctl_v4l2-v-Xabbrev \
+  ioctl_v4l2-v-Xraw \
+  ioctl_v4l2-v-Xverbose \
   ioctl_watchdog \
   ioperm \
   iopl \
@@ -206,6 +249,7 @@ PURE_EXECUTABLES = \
   lstat64 \
   madvise \
   maybe_switch_current_tcp \
+  maybe_switch_current_tcp--quiet-thread-execve \
   mbind \
   mbind-Xabbrev \
   mbind-Xraw \
@@ -253,6 +297,10 @@ PURE_EXECUTABLES = \
   msg_name \
   munlockall \
   nanosleep \
+  net--decode-fds-dev-netlink \
+  net--decode-fds-none-netlink \
+  net--decode-fds-path-netlink \
+  net--decode-fds-socket-netlink \
   net-icmp_filter \
   net-packet_mreq \
   net-packet_mreq-Xabbrev \
@@ -335,6 +383,16 @@ PURE_EXECUTABLES = \
   open_tree \
   open_tree-P \
   openat \
+  openat2 \
+  openat2-Xabbrev \
+  openat2-Xraw \
+  openat2-Xverbose \
+  openat2-v \
+  openat2-v-y \
+  openat2-v-y-Xabbrev \
+  openat2-v-y-Xraw \
+  openat2-v-y-Xverbose \
+  openat2-y \
   osf_utimes \
   pause \
   perf_event_open \
@@ -342,9 +400,16 @@ PURE_EXECUTABLES = \
   personality-Xabbrev \
   personality-Xraw \
   personality-Xverbose \
+  pidfd_getfd \
+  pidfd_getfd-y \
+  pidfd_getfd-yy \
   pidfd_open \
+  pidfd_open--decode-fd-path \
+  pidfd_open--decode-fd-pidfd \
+  pidfd_open--decode-fd-socket \
   pidfd_open-P \
   pidfd_open-y \
+  pidfd_open-yy \
   pidfd_send_signal \
   pipe \
   pipe2 \
@@ -352,9 +417,7 @@ PURE_EXECUTABLES = \
   pkey_free \
   pkey_mprotect \
   poll \
-  poll-P \
   ppoll \
-  ppoll-P \
   prctl-arg2-intptr \
   prctl-dumpable \
   prctl-name \
@@ -503,11 +566,21 @@ PURE_EXECUTABLES = \
   statfs64 \
   status-all \
   status-failed \
+  status-failed-long \
+  status-failed-status \
   status-none \
   status-none-f \
   status-successful \
+  status-successful-long \
+  status-successful-status \
   status-unfinished \
   statx \
+  strace--strings-in-hex \
+  strace--strings-in-hex-all \
+  strace--strings-in-hex-non-ascii \
+  strace-n \
+  strace-x \
+  strace-xx \
   swap \
   sxetmask \
   symlink \
@@ -518,12 +591,14 @@ PURE_EXECUTABLES = \
   sysinfo \
   syslog \
   tee \
+  tgkill \
   time \
   timer_create \
   timer_xettime \
   timerfd_xettime \
   times \
   times-fail \
+  tkill \
   truncate \
   truncate64 \
   ugetrlimit \
@@ -537,6 +612,7 @@ PURE_EXECUTABLES = \
   umovestr2 \
   umovestr3 \
   umovestr_cached \
+  umovestr_cached_adjacent \
   uname \
   unlink \
   unlinkat \
diff -pruN 5.5-3/tests/pure_executables.list 5.9-0ubuntu2/tests/pure_executables.list
--- 5.5-3/tests/pure_executables.list	2019-12-11 22:44:53.000000000 +0000
+++ 5.9-0ubuntu2/tests/pure_executables.list	2020-09-23 12:56:26.000000000 +0000
@@ -1,6 +1,6 @@
 # Executables without side effects.
 #
-# Copyright (c) 2017-2019 The strace developers.
+# Copyright (c) 2017-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -32,13 +32,29 @@ clone3
 clone3-Xabbrev
 clone3-Xraw
 clone3-Xverbose
+close_range
+close_range-P
+close_range-y
+close_range-yy
 copy_file_range
 creat
 delete_module
+dev--decode-fds-dev
+dev--decode-fds-path
+dev--decode-fds-socket
 dev-yy
 dup
+dup-P
+dup-y
+dup-yy
 dup2
+dup2-P
+dup2-y
+dup2-yy
 dup3
+dup3-P
+dup3-y
+dup3-yy
 epoll_create
 epoll_create1
 epoll_ctl
@@ -49,6 +65,13 @@ eventfd
 execve
 execveat
 faccessat
+faccessat-P
+faccessat-y
+faccessat-yy
+faccessat2
+faccessat2-P
+faccessat2-y
+faccessat2-yy
 fadvise64
 fadvise64_64
 fallocate
@@ -97,7 +120,9 @@ get_mempolicy
 getcpu
 getcwd
 getdents
+getdents-v
 getdents64
+getdents64-v
 getegid
 getegid32
 geteuid
@@ -121,7 +146,9 @@ getsid
 getsockname
 getuid
 getuid32
-getxxid
+getxgid
+getxpid
+getxuid
 group_req
 inet-cmsg
 init_module
@@ -144,6 +171,14 @@ ioctl_evdev-v
 ioctl_evdev-v-Xabbrev
 ioctl_evdev-v-Xraw
 ioctl_evdev-v-Xverbose
+ioctl_hdio
+ioctl_hdio-Xabbrev
+ioctl_hdio-Xraw
+ioctl_hdio-Xverbose
+ioctl_hdio-v
+ioctl_hdio-v-Xabbrev
+ioctl_hdio-v-Xraw
+ioctl_hdio-v-Xverbose
 ioctl_inotify
 ioctl_kvm_run
 ioctl_kvm_run-v
@@ -159,8 +194,16 @@ ioctl_scsi
 ioctl_sg_io_v3
 ioctl_sg_io_v4
 ioctl_sock_gifconf
+ioctl_tee
 ioctl_uffdio
 ioctl_v4l2
+ioctl_v4l2-Xabbrev
+ioctl_v4l2-Xraw
+ioctl_v4l2-Xverbose
+ioctl_v4l2-v
+ioctl_v4l2-v-Xabbrev
+ioctl_v4l2-v-Xraw
+ioctl_v4l2-v-Xverbose
 ioctl_watchdog
 ioperm
 iopl
@@ -211,6 +254,7 @@ lstat
 lstat64
 madvise
 maybe_switch_current_tcp
+maybe_switch_current_tcp--quiet-thread-execve
 mbind
 mbind-Xabbrev
 mbind-Xraw
@@ -258,6 +302,10 @@ msg_control
 msg_name
 munlockall
 nanosleep
+net--decode-fds-dev-netlink
+net--decode-fds-none-netlink
+net--decode-fds-path-netlink
+net--decode-fds-socket-netlink
 net-icmp_filter
 net-packet_mreq
 net-packet_mreq-Xabbrev
@@ -340,6 +388,16 @@ open
 open_tree
 open_tree-P
 openat
+openat2
+openat2-Xabbrev
+openat2-Xraw
+openat2-Xverbose
+openat2-v
+openat2-v-y
+openat2-v-y-Xabbrev
+openat2-v-y-Xraw
+openat2-v-y-Xverbose
+openat2-y
 osf_utimes
 pause
 perf_event_open
@@ -347,9 +405,16 @@ personality
 personality-Xabbrev
 personality-Xraw
 personality-Xverbose
+pidfd_getfd
+pidfd_getfd-y
+pidfd_getfd-yy
 pidfd_open
+pidfd_open--decode-fd-path
+pidfd_open--decode-fd-pidfd
+pidfd_open--decode-fd-socket
 pidfd_open-P
 pidfd_open-y
+pidfd_open-yy
 pidfd_send_signal
 pipe
 pipe2
@@ -357,9 +422,7 @@ pkey_alloc
 pkey_free
 pkey_mprotect
 poll
-poll-P
 ppoll
-ppoll-P
 prctl-arg2-intptr
 prctl-dumpable
 prctl-name
@@ -508,11 +571,21 @@ statfs
 statfs64
 status-all
 status-failed
+status-failed-long
+status-failed-status
 status-none
 status-none-f
 status-successful
+status-successful-long
+status-successful-status
 status-unfinished
 statx
+strace--strings-in-hex
+strace--strings-in-hex-all
+strace--strings-in-hex-non-ascii
+strace-n
+strace-x
+strace-xx
 swap
 sxetmask
 symlink
@@ -523,12 +596,14 @@ sync_file_range2
 sysinfo
 syslog
 tee
+tgkill
 time
 timer_create
 timer_xettime
 timerfd_xettime
 times
 times-fail
+tkill
 truncate
 truncate64
 ugetrlimit
@@ -542,6 +617,7 @@ umovestr-illptr
 umovestr2
 umovestr3
 umovestr_cached
+umovestr_cached_adjacent
 uname
 unlink
 unlinkat
diff -pruN 5.5-3/tests/qual_fault.c 5.9-0ubuntu2/tests/qual_fault.c
--- 5.5-3/tests/qual_fault.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/qual_fault.c	2020-06-01 14:15:16.000000000 +0000
@@ -2,7 +2,7 @@
  * Check that fault injection works properly.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -29,7 +29,7 @@ static int out_fd;
 #define DEFAULT_ERRNO ENOSYS
 
 static const char *errstr;
-static int is_raw, err, first, step, iter, try;
+static int is_raw, err, first, last, step, iter, try;
 
 static void
 invoke(int fail)
@@ -99,7 +99,7 @@ open_file(const char *prefix, int proc)
 int
 main(int argc, char *argv[])
 {
-	assert(argc == 11);
+	assert(argc == 12);
 
 	is_raw = !strcmp("raw", argv[1]);
 
@@ -120,13 +120,14 @@ main(int argc, char *argv[])
 	errstr = errno2name();
 
 	first = atoi(argv[3]);
-	step = atoi(argv[4]);
-	iter = atoi(argv[5]);
-	int num_procs = atoi(argv[6]);
-	char *exp_prefix = argv[7];
-	char *got_prefix = argv[8];
-	char *out_prefix = argv[9];
-	char *pid_prefix = argv[10];
+	last = atoi(argv[4]);
+	step = atoi(argv[5]);
+	iter = atoi(argv[6]);
+	int num_procs = atoi(argv[7]);
+	char *exp_prefix = argv[8];
+	char *got_prefix = argv[9];
+	char *out_prefix = argv[10];
+	char *pid_prefix = argv[11];
 
 	assert(first > 0);
 	assert(step >= 0);
@@ -164,8 +165,10 @@ main(int argc, char *argv[])
 		int i;
 		for (i = 1; i <= iter; ++i) {
 			int fail = 0;
-			if (first > 0) {
+			if (last != 0) {
 				--first;
+				if (last != -1)
+					--last;
 				if (first == 0) {
 					fail = 1;
 					first = step;
diff -pruN 5.5-3/tests/qual_fault-syntax.test 5.9-0ubuntu2/tests/qual_fault-syntax.test
--- 5.5-3/tests/qual_fault-syntax.test	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/qual_fault-syntax.test	2020-06-01 14:15:16.000000000 +0000
@@ -3,6 +3,7 @@
 # Check -e fault= syntax.
 #
 # Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
+# Copyright (c) 2017-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -72,6 +73,27 @@ for arg in chdir:42 \!chdir:42 \
 	   chdir:syscall=-42 \
 	   chdir:syscall=42 \
 	   chdir:syscall=gettid:syscall=gettid \
+	   chdir:when=. \
+	   chdir:when=.+ \
+	   chdir:when=..+ \
+	   chdir:when=+ \
+	   chdir:when=++ \
+	   chdir:when=10. \
+	   chdir:when=11.12 \
+	   chdir:when=13.14+ \
+	   chdir:when=15.. \
+	   chdir:when=16... \
+	   chdir:when=17...18 \
+	   chdir:when=.19 \
+	   chdir:when=..20 \
+	   chdir:when=..21+ \
+	   chdir:when=..22+3 \
+	   chdir:when=24..23 \
+	   chdir:when=25..26+0 \
+	   chdir:when=27..65535 \
+	   chdir:when=28..65535+ \
+	   chdir:when=65535..65535 \
+	   chdir:when=65535..65535+ \
 	   ; do
 	$STRACE -e fault="$arg" true 2> "$LOG" &&
 		fail_with "$arg"
diff -pruN 5.5-3/tests/qual_fault.test 5.9-0ubuntu2/tests/qual_fault.test
--- 5.5-3/tests/qual_fault.test	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/qual_fault.test	2020-06-01 14:15:16.000000000 +0000
@@ -3,7 +3,7 @@
 # Check that fault injection works properly.
 #
 # Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -22,24 +22,32 @@ N=100
 
 check_fault_injection()
 {
-	local trace fault err first step procs extra
+	local trace fault err first last step procs extra
 	trace=$1; shift
 	fault=$1; shift
 	err=$1; shift
 	first=$1; shift
+	last=$1; shift
 	step=$1; shift
 	procs=$1; shift
 	extra="$*"
 
 	local when=
-	if [ -z "$first$step" ]; then
+	if [ -z "$first$last$step" ]; then
 		first=1
+		last=-1
 		step=1
+	elif [ -z "$last" ]; then
+		case "$step" in
+			'') when=":when=$first"; step=1; last=$first ;;
+			+) when=":when=$first+"; step=1; last=-1 ;;
+			*) when=":when=$first+$step"; last=-1; ;;
+		esac
 	else
 		case "$step" in
-			'') when=":when=$first"; step=0 ;;
-			+) when=":when=$first+"; step=1 ;;
-			*) when=":when=$first+$step" ;;
+			'') when=":when=${first}..${last}"; step=1 ;;
+			+) when=":when=${first}..${last}+"; step=1 ;;
+			*) when=":when=${first}..${last}+${step}" ;;
 		esac
 	fi
 
@@ -63,7 +71,7 @@ check_fault_injection()
 
 	run_strace -a11 -ff -e trace=$trace \
 		"$@" -e fault=$fault$when$error$suffix $extra \
-		../$NAME $raw "$err" "$first" "$step" $N \
+		../$NAME $raw "$err" "$first" "$last" "$step" $N \
 		"$procs" "$outexp" "$outgot" "$outout" "$outpid"
 
 	for i in $(seq 0 $((procs - 1)) )
@@ -78,19 +86,37 @@ check_fault_injection()
 for err in '' ENOSYS 22 einval; do
 	for fault in writev desc,51; do
 		check_fault_injection \
-			writev $fault "$err" '' '' 1 -efault=chdir
+			writev $fault "$err" '' '' '' 1 -efault=chdir
 		check_fault_injection \
-			writev $fault "$err" '' '' 1 -efault=chdir -efault=none
+			writev $fault "$err" '' '' '' 1 -efault=chdir -efault=none
 		for F in 1 2 3 5 7 11; do
 			check_fault_injection \
-				writev $fault "$err" $F '' 1
+				writev $fault "$err" $F '' '' 1
 			check_fault_injection \
-				writev $fault "$err" $F + 1
+				writev $fault "$err" $F '' + 1
+
+			for L in 1 2 3 5 7 11; do
+				[ "$L" -ge "$F" ] ||
+					continue
+				check_fault_injection \
+					writev $fault "$err" $F $L '' 1
+				check_fault_injection \
+					writev $fault "$err" $F $L + 1
+			done
+
 			for S in 1 2 3 5 7 11; do
 				check_fault_injection \
-					writev $fault "$err" $F $S 1
+					writev $fault "$err" $F '' $S 1
 				check_fault_injection \
-					writev $fault "$err" $F $S 4
+					writev $fault "$err" $F '' $S 4
+				for L in 1 2 3 5 7 11; do
+					[ "$L" -ge "$F" ] ||
+						continue
+					check_fault_injection \
+						writev $fault "$err" $F $L $S 1
+					check_fault_injection \
+						writev $fault "$err" $F $L $S 4
+				done
 			done
 		done
 	done
diff -pruN 5.5-3/tests/qual_inject-syntax.test 5.9-0ubuntu2/tests/qual_inject-syntax.test
--- 5.5-3/tests/qual_inject-syntax.test	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/qual_inject-syntax.test	2020-06-01 14:15:16.000000000 +0000
@@ -3,6 +3,7 @@
 # Check -e inject= syntax.
 #
 # Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
+# Copyright (c) 2017-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -88,6 +89,27 @@ for arg in 42 chdir \
 	   chdir:syscall=-42 \
 	   chdir:syscall=42 \
 	   chdir:syscall=gettid:syscall=gettid \
+	   chdir:when=. \
+	   chdir:when=.+ \
+	   chdir:when=..+ \
+	   chdir:when=+ \
+	   chdir:when=++ \
+	   chdir:when=10. \
+	   chdir:when=11.12 \
+	   chdir:when=13.14+ \
+	   chdir:when=15.. \
+	   chdir:when=16... \
+	   chdir:when=17...18 \
+	   chdir:when=.19 \
+	   chdir:when=..20 \
+	   chdir:when=..21+ \
+	   chdir:when=..22+3 \
+	   chdir:when=24..23 \
+	   chdir:when=25..26+0 \
+	   chdir:when=27..65535 \
+	   chdir:when=28..65535+ \
+	   chdir:when=65535..65535 \
+	   chdir:when=65535..65535+ \
 	   ; do
 	$STRACE -e inject="$arg" true 2> "$LOG" &&
 		fail_with "$arg"
diff -pruN 5.5-3/tests/readahead.c 5.9-0ubuntu2/tests/readahead.c
--- 5.5-3/tests/readahead.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/readahead.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -11,24 +11,20 @@
 
 #ifdef HAVE_READAHEAD
 /* Check for glibc readahead argument passing bugs. */
-# ifdef __GLIBC__
 /*
  * glibc < 2.8 had an incorrect order of higher and lower parts of offset,
  * see https://sourceware.org/bugzilla/show_bug.cgi?id=5208
  */
-#  if !(defined __GLIBC_MINOR__ && \
-	(__GLIBC__ << 16) + __GLIBC_MINOR__ >= (2 << 16) + 8)
-#   undef HAVE_READAHEAD
-#  endif /* glibc < 2.8 */
+# if GLIBC_PREREQ_LT(2, 8)
+#  undef HAVE_READAHEAD
+# endif /* glibc < 2.8 */
 /*
  * glibc < 2.25 had an incorrect implementation on mips n64,
  * see https://sourceware.org/bugzilla/show_bug.cgi?id=21026
  */
-#  if defined LINUX_MIPSN64 && !(defined __GLIBC_MINOR__ && \
-	(__GLIBC__ << 16) + __GLIBC_MINOR__ >= (2 << 16) + 25)
-#   undef HAVE_READAHEAD
-#  endif /* LINUX_MIPSN64 && glibc < 2.25 */
-# endif /* __GLIBC__ */
+# if GLIBC_PREREQ_LT(2, 25) && defined LINUX_MIPSN64
+#  undef HAVE_READAHEAD
+# endif /* LINUX_MIPSN64 && glibc < 2.25 */
 #endif /* HAVE_READAHEAD */
 
 #ifdef HAVE_READAHEAD
diff -pruN 5.5-3/tests/read-write.c 5.9-0ubuntu2/tests/read-write.c
--- 5.5-3/tests/read-write.c	2019-07-16 17:46:47.000000000 +0000
+++ 5.9-0ubuntu2/tests/read-write.c	2020-04-07 00:57:01.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding and dumping of read and write syscalls.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -153,9 +153,17 @@ main(void)
 	skip_if_unavailable("/proc/self/fd/");
 
 	static const char tmp[] = "read-write-tmpfile";
-	if (open(tmp, O_CREAT|O_RDONLY|O_TRUNC, 0600) != 0)
+	bool need_cleanup = true;
+	long rc;
+
+	rc = open(tmp, O_RDONLY, 0600);
+	if (rc < 0) {
+		rc = open(tmp, O_CREAT|O_EXCL|O_RDONLY, 0600);
+		need_cleanup = false;
+	}
+	if (rc != 0)
 		perror_msg_and_fail("creat: %s", tmp);
-	if (open(tmp, O_WRONLY) != 1)
+	if (open(tmp, O_TRUNC|O_WRONLY) != 1)
 		perror_msg_and_fail("open: %s", tmp);
 
 	static const char w_c[] = "0123456789abcde";
@@ -175,8 +183,6 @@ main(void)
 
 	void *efault = r1 - get_page_size();
 
-	long rc;
-
 	rc = k_write(1, w, 0);
 	if (rc)
 		perror_msg_and_fail("write: expected 0, returned %ld", rc);
@@ -270,9 +276,11 @@ main(void)
 	if (open("/dev/null", O_WRONLY) != 1)
 		perror_msg_and_fail("open");
 
+	(void) close(4);
 	if (open("/dev/zero", O_RDONLY) != 4)
 		perror_msg_and_fail("open");
 
+	(void) close(5);
 	if (open("/dev/null", O_WRONLY) != 5)
 		perror_msg_and_fail("open");
 
@@ -282,6 +290,9 @@ main(void)
 
 	test_dump(256, true);
 
+	if (need_cleanup && unlink(tmp))
+		perror_msg_and_fail("unlink: %s", tmp);
+
 	tprintf("+++ exited with 0 +++\n");
 	return 0;
 }
diff -pruN 5.5-3/tests/redirect.test 5.9-0ubuntu2/tests/redirect.test
--- 5.5-3/tests/redirect.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/redirect.test	2020-04-07 00:57:01.000000000 +0000
@@ -3,7 +3,7 @@
 # Ensure that strace does not retain stdin and stdout descriptors.
 #
 # Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -16,42 +16,34 @@ run_prog_skip_if_failed \
 check_prog sleep
 check_prog yes
 
+SLEEP_3_BITS="$SLEEP_A_BIT; $SLEEP_A_BIT; $SLEEP_A_BIT"
 > "$OUT"
-> "$LOG"
+
+> lock1
+> lock2
 (
-	while [ -f "$LOG" ]; do
-		:
+	while [ -f lock1 ]; do
+		$SLEEP_A_BIT
 	done
-	$SLEEP_A_BIT &
 	yes
-	if kill -0 $! 2> /dev/null; then
-		wait
-	else
-		echo TIMEOUT >> "$OUT"
-	fi
+	[ -f lock2 ] ||
+		printf ' input' >> "$OUT"
 ) | $STRACE -qq -enone -esignal=none \
-	sh -c "exec <&- >&-; rm -f -- $LOG; $SLEEP_A_BIT; $SLEEP_A_BIT"
-
-if [ -s "$OUT" ]; then
-	fail_ "$STRACE failed to redirect standard input"
-fi
+	sh -c "exec <&- >&-; rm -f lock1; $SLEEP_3_BITS; rm -f lock2"
 
-> "$LOG"
+> lock1
+> lock2
 $STRACE -qq -enone -esignal=none \
-	sh -c "exec <&- >&-; rm -f -- $LOG; $SLEEP_A_BIT; $SLEEP_A_BIT" |
+	sh -c "exec <&- >&-; rm -f lock1; $SLEEP_3_BITS; rm -f lock2" |
 (
-	while [ -f "$LOG" ]; do
-		:
+	while [ -f lock1 ]; do
+		$SLEEP_A_BIT
 	done
-	$SLEEP_A_BIT &
 	cat > /dev/null
-	if kill -0 $! 2> /dev/null; then
-		wait
-	else
-		echo TIMEOUT >> "$OUT"
-	fi
+	[ -f lock2 ] ||
+		printf ' output' >> "$OUT"
 )
 
 if [ -s "$OUT" ]; then
-	fail_ "$STRACE failed to redirect standard output"
+	fail_ "$STRACE failed to redirect standard descriptors:$(cat "$OUT")"
 fi
diff -pruN 5.5-3/tests/rt_sigqueueinfo.c 5.9-0ubuntu2/tests/rt_sigqueueinfo.c
--- 5.5-3/tests/rt_sigqueueinfo.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/rt_sigqueueinfo.c	2020-08-25 14:29:30.000000000 +0000
@@ -1,12 +1,13 @@
 /*
  * Copyright (c) 2015 Elvira Khabirova <lineprinter0@gmail.com>
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include "pidns.h"
 #include <assert.h>
 #include <stdio.h>
 #include <signal.h>
@@ -15,6 +16,8 @@
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	struct sigaction sa = {
 		.sa_handler = SIG_IGN
 	};
@@ -22,15 +25,19 @@ main(void)
 		.sival_ptr = (void *) (unsigned long) 0xdeadbeefbadc0dedULL
 	};
 	pid_t pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
 
 	assert(sigaction(SIGUSR1, &sa, NULL) == 0);
 	if (sigqueue(pid, SIGUSR1, value))
 		perror_msg_and_skip("sigqueue");
-	printf("rt_sigqueueinfo(%u, SIGUSR1, {si_signo=SIGUSR1, "
-		"si_code=SI_QUEUE, si_pid=%u, si_uid=%u, "
+	pidns_print_leader();
+	printf("rt_sigqueueinfo(%d%s, SIGUSR1, {si_signo=SIGUSR1, "
+		"si_code=SI_QUEUE, si_pid=%d%s, si_uid=%u, "
 		"si_value={int=%d, ptr=%p}}) = 0\n",
-		pid, pid, getuid(), value.sival_int, value.sival_ptr);
-	printf("+++ exited with 0 +++\n");
+		pid, pid_str, pid, pid_str,
+		getuid(), value.sival_int, value.sival_ptr);
+	pidns_print_leader();
+	puts("+++ exited with 0 +++");
 
 	return 0;
 }
diff -pruN 5.5-3/tests/rt_sigqueueinfo--pidns-translation.c 5.9-0ubuntu2/tests/rt_sigqueueinfo--pidns-translation.c
--- 5.5-3/tests/rt_sigqueueinfo--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/rt_sigqueueinfo--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "rt_sigqueueinfo.c"
diff -pruN 5.5-3/tests/rt_sigqueueinfo--pidns-translation.gen.test 5.9-0ubuntu2/tests/rt_sigqueueinfo--pidns-translation.gen.test
--- 5.5-3/tests/rt_sigqueueinfo--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/rt_sigqueueinfo--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (rt_sigqueueinfo--pidns-translation test_pidns -esignal=none -e trace=rt_sigqueueinfo); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -esignal=none -e trace=rt_sigqueueinfo
diff -pruN 5.5-3/tests/rt_tgsigqueueinfo.c 5.9-0ubuntu2/tests/rt_tgsigqueueinfo.c
--- 5.5-3/tests/rt_tgsigqueueinfo.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/rt_tgsigqueueinfo.c	2020-08-25 14:29:30.000000000 +0000
@@ -2,7 +2,7 @@
  * This file is part of rt_tgsigqueueinfo strace test.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,8 +10,9 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
-#ifdef __NR_rt_tgsigqueueinfo
+#if defined __NR_rt_tgsigqueueinfo && defined __NR_gettid
 
 # include <errno.h>
 # include <signal.h>
@@ -20,11 +21,11 @@
 # include <unistd.h>
 
 static long
-k_tgsigqueueinfo(const pid_t pid, const int sig, const void *const info)
+k_tgsigqueueinfo(const pid_t tgid, const int tid, const int sig, const void *const info)
 {
 	return syscall(__NR_rt_tgsigqueueinfo,
-		       F8ILL_KULONG_MASK | pid,
-		       F8ILL_KULONG_MASK | pid,
+		       F8ILL_KULONG_MASK | tgid,
+		       F8ILL_KULONG_MASK | tid,
 		       F8ILL_KULONG_MASK | sig,
 		       info);
 }
@@ -32,6 +33,8 @@ k_tgsigqueueinfo(const pid_t pid, const
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	const struct sigaction sa = {
 		.sa_handler = SIG_IGN
 	};
@@ -48,17 +51,22 @@ main(void)
 	info->si_value.sival_ptr =
 		(void *) (unsigned long) 0xdeadbeeffacefeedULL;
 
-	if (k_tgsigqueueinfo(info->si_pid, SIGUSR1, info))
+	if (k_tgsigqueueinfo(getpid(), syscall(__NR_gettid), SIGUSR1, info))
 		(errno == ENOSYS ? perror_msg_and_skip : perror_msg_and_fail)(
 			"rt_tgsigqueueinfo");
 
-	printf("rt_tgsigqueueinfo(%u, %u, %s, {si_signo=%s"
-		", si_code=SI_QUEUE, si_errno=ENOENT, si_pid=%u"
-		", si_uid=%u, si_value={int=%d, ptr=%p}}) = 0\n",
-		info->si_pid, info->si_pid, "SIGUSR1", "SIGUSR1",
-		info->si_pid, info->si_uid, info->si_value.sival_int,
+	pidns_print_leader();
+	printf("rt_tgsigqueueinfo(%d%s, %d%s, %s, {si_signo=%s"
+		", si_code=SI_QUEUE, si_errno=ENOENT, si_pid=%d%s"
+		", si_uid=%d, si_value={int=%d, ptr=%p}}) = 0\n",
+		info->si_pid, pidns_pid2str(PT_TGID),
+		info->si_pid, pidns_pid2str(PT_TID),
+		"SIGUSR1", "SIGUSR1",
+		info->si_pid, pidns_pid2str(PT_TGID),
+		info->si_uid, info->si_value.sival_int,
 		info->si_value.sival_ptr);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests/rt_tgsigqueueinfo--pidns-translation.c 5.9-0ubuntu2/tests/rt_tgsigqueueinfo--pidns-translation.c
--- 5.5-3/tests/rt_tgsigqueueinfo--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/rt_tgsigqueueinfo--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "rt_tgsigqueueinfo.c"
diff -pruN 5.5-3/tests/rt_tgsigqueueinfo--pidns-translation.gen.test 5.9-0ubuntu2/tests/rt_tgsigqueueinfo--pidns-translation.gen.test
--- 5.5-3/tests/rt_tgsigqueueinfo--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/rt_tgsigqueueinfo--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (rt_tgsigqueueinfo--pidns-translation test_pidns -esignal=none -e trace=rt_tgsigqueueinfo); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -esignal=none -e trace=rt_tgsigqueueinfo
diff -pruN 5.5-3/tests/s390_sthyi.c 5.9-0ubuntu2/tests/s390_sthyi.c
--- 5.5-3/tests/s390_sthyi.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/s390_sthyi.c	2020-07-24 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check decoding of s390_sthyi syscall.
  *
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -113,7 +113,7 @@ ebcdic2ascii(unsigned char *ebcdic, size
 				   size, sizeof(ascii_buf));
 	if (cd == (iconv_t) -1)
 		perror_msg_and_fail("ebcdic2ascii: unable to allocate a "
-				    "conversion descriptior for converting "
+				    "conversion descriptor for converting "
 				    "EBCDIC to ASCII");
 
 	while ((ret = iconv(cd, &ebcdic_pos, &ebcdic_left,
@@ -509,7 +509,7 @@ print_sthyi(unsigned char *buf)
 	hdr_size = *(uint16_t *) (buf + 10);
 	if (hdr_size < 44)
 		error_msg_and_fail("sthyi: header section is too small "
-			           "(got %hu, 44 expected)", hdr_size);
+				   "(got %hu, >=44 expected)", hdr_size);
 
 	/* INFHFLG1 */
 	print_0x8("{/* header */ {infhflg1", buf, 0, true);
@@ -598,7 +598,7 @@ print_sthyi(unsigned char *buf)
 	hdr_size = *(uint16_t *) (buf + 14);
 	if (hdr_size < 60)
 		error_msg_and_fail("sthyi: machine section is too small "
-			           "(got %hu, 60 expected)", hdr_size);
+				   "(got %hu, >=60 expected)", hdr_size);
 
 	cur = buf + offs;
 
@@ -670,9 +670,9 @@ partition_hdr:
 		goto hv_hdr;
 
 	hdr_size = *(uint16_t *) (buf + 18);
-	if (hdr_size < 56)
+	if (hdr_size < 40)
 		error_msg_and_fail("sthyi: partition section is too small "
-			           "(got %hu, 56 expected)", hdr_size);
+				   "(got %hu, >=40 expected)", hdr_size);
 
 	cur = buf + offs;
 
@@ -741,18 +741,18 @@ partition_hdr:
 	print_weight(", infpwbif", cur, 32, pwcap_valid);
 	print_weight(", infpabif", cur, 36, pacap_valid);
 
-	if (print_ebcdic(", infplgnm", cur, 40, 8, false, false)) {
-
-		print_weight(", infplgcp", cur, 48, false);
-		print_weight(", infplgif", cur, 52, false);
-	} else {
-		if (lpar_valid) {
-			printf(", infplgnm=");
-			print_quoted_hex((char *) (cur + 40), 8);
+	if (hdr_size >= 56) {
+		if (print_ebcdic(", infplgnm", cur, 40, 8, false, false)) {
+			print_weight(", infplgcp", cur, 48, false);
+			print_weight(", infplgif", cur, 52, false);
+		} else {
+			if (lpar_valid) {
+				printf(", infplgnm=");
+				print_quoted_hex((char *) (cur + 40), 8);
+			}
+			print_x32(", infplgcp", cur, 48, false);
+			print_x32(", infplgif", cur, 52, false);
 		}
-
-		print_x32(", infplgcp", cur, 48, false);
-		print_x32(", infplgif", cur, 52, false);
 	}
 
 	if (hdr_size >= 64) {
diff -pruN 5.5-3/tests/sched_xetaffinity.c 5.9-0ubuntu2/tests/sched_xetaffinity.c
--- 5.5-3/tests/sched_xetaffinity.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/sched_xetaffinity.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,7 +2,7 @@
  * This file is part of sched_xetaffinity strace test.
  *
  * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,6 +10,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 #include <sched.h>
 
 #if defined __NR_sched_getaffinity && defined __NR_sched_setaffinity \
@@ -41,8 +42,11 @@ setaffinity(unsigned long pid, unsigned
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	unsigned int cpuset_size = 1;
 	const pid_t pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
 
 	while (cpuset_size) {
 		assert(getaffinity(pid, cpuset_size, NULL) == -1);
@@ -50,18 +54,21 @@ main(void)
 			break;
 		if (EINVAL != errno)
 			perror_msg_and_skip("sched_getaffinity");
-		printf("sched_getaffinity(%d, %u, NULL) = %s\n",
-		       pid, cpuset_size, errstr);
+		pidns_print_leader();
+		printf("sched_getaffinity(%d%s, %u, NULL) = %s\n",
+		       pid, pid_str, cpuset_size, errstr);
 		cpuset_size <<= 1;
 	}
 	assert(cpuset_size);
-	printf("sched_getaffinity(%d, %u, NULL) = %s\n",
-	       pid, cpuset_size, errstr);
+	pidns_print_leader();
+	printf("sched_getaffinity(%d%s, %u, NULL) = %s\n",
+	       pid, pid_str, cpuset_size, errstr);
 
 	cpu_set_t *cpuset = tail_alloc(cpuset_size);
 	getaffinity(pid, cpuset_size, cpuset + 1);
-	printf("sched_getaffinity(%d, %u, %p) = %s\n",
-	       pid, cpuset_size, cpuset + 1, errstr);
+	pidns_print_leader();
+	printf("sched_getaffinity(%d%s, %u, %p) = %s\n",
+	       pid, pid_str, cpuset_size, cpuset + 1, errstr);
 
 	int ret_size = getaffinity(pid, cpuset_size, cpuset);
 	if (ret_size < 0)
@@ -69,7 +76,8 @@ main(void)
 				    pid, (unsigned) cpuset_size, cpuset, errstr);
 	assert(ret_size <= (int) cpuset_size);
 
-	printf("sched_getaffinity(%d, %u, [", pid, cpuset_size);
+	pidns_print_leader();
+	printf("sched_getaffinity(%d%s, %u, [", pid, pid_str, cpuset_size);
 	const char *sep;
 	unsigned int i, cpu;
 	for (i = 0, cpu = 0, sep = ""; i < (unsigned) ret_size * 8; ++i) {
@@ -85,8 +93,9 @@ main(void)
 	CPU_SET_S(cpu, cpuset_size, cpuset);
 	if (setaffinity(pid, cpuset_size, cpuset))
 		perror_msg_and_skip("sched_setaffinity");
-	printf("sched_setaffinity(%d, %u, [%u]) = 0\n",
-	       pid, cpuset_size, cpu);
+	pidns_print_leader();
+	printf("sched_setaffinity(%d%s, %u, [%u]) = 0\n",
+	       pid, pid_str, cpuset_size, cpu);
 
 	const unsigned int big_size = cpuset_size < 128 ? 128 : cpuset_size * 2;
 	cpuset = tail_alloc(big_size);
@@ -95,7 +104,8 @@ main(void)
 		perror_msg_and_fail("sched_getaffinity(%d, %u, %p) = %s\n",
 				    pid, big_size, cpuset, errstr);
 	assert(ret_size <= (int) big_size);
-	printf("sched_getaffinity(%d, %u, [", pid, big_size);
+	pidns_print_leader();
+	printf("sched_getaffinity(%d%s, %u, [", pid, pid_str, big_size);
 	for (i = 0, sep = ""; i < (unsigned) ret_size * 8; ++i) {
 		if (CPU_ISSET_S(i, (unsigned) ret_size, cpuset)) {
 			printf("%s%u", sep, i);
@@ -104,6 +114,7 @@ main(void)
 	}
 	printf("]) = %s\n", errstr);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests/sched_xetaffinity--pidns-translation.c 5.9-0ubuntu2/tests/sched_xetaffinity--pidns-translation.c
--- 5.5-3/tests/sched_xetaffinity--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/sched_xetaffinity--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "sched_xetaffinity.c"
diff -pruN 5.5-3/tests/sched_xetaffinity--pidns-translation.gen.test 5.9-0ubuntu2/tests/sched_xetaffinity--pidns-translation.gen.test
--- 5.5-3/tests/sched_xetaffinity--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/sched_xetaffinity--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (sched_xetaffinity--pidns-translation test_pidns -a28 -e trace=sched_getaffinity,sched_setaffinity); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a28 -e trace=sched_getaffinity,sched_setaffinity
diff -pruN 5.5-3/tests/sched_xetattr.c 5.9-0ubuntu2/tests/sched_xetattr.c
--- 5.5-3/tests/sched_xetattr.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/sched_xetattr.c	2020-08-25 14:29:30.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2017 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -15,6 +15,7 @@
 # include <stdio.h>
 # include <sched.h>
 # include <unistd.h>
+# include "pidns.h"
 # include "sched_attr.h"
 # include "xlat.h"
 # include "xlat/schedulers.h"
@@ -41,6 +42,8 @@ sys_sched_setattr(kernel_ulong_t pid, ke
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	static const kernel_ulong_t bogus_pid =
 		(kernel_ulong_t) 0xdefacedfacefeedULL;
 	static const kernel_ulong_t bogus_size =
@@ -48,20 +51,28 @@ main(void)
 	static const kernel_ulong_t bogus_flags =
 		(kernel_ulong_t) 0xdefaceddeadc0deULL;
 
+	const int pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
+
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct sched_attr, attr);
 	TAIL_ALLOC_OBJECT_CONST_PTR(unsigned int, psize);
 	void *const efault = attr + 1;
 
-	sys_sched_getattr(0, 0, 0, 0);
-	printf("sched_getattr(0, NULL, 0, 0) = %s\n", errstr);
+	sys_sched_getattr(pid, 0, 0, 0);
+	pidns_print_leader();
+	printf("sched_getattr(%d%s, NULL, 0, 0) = %s\n",
+		pid, pid_str, errstr);
 
 	sys_sched_getattr(0, (unsigned long) attr, 0, 0);
+	pidns_print_leader();
 	printf("sched_getattr(0, %p, 0, 0) = %s\n", attr, errstr);
 
 	sys_sched_getattr(bogus_pid, 0, 0, 0);
+	pidns_print_leader();
 	printf("sched_getattr(%d, NULL, 0, 0) = %s\n", (int) bogus_pid, errstr);
 
 	sys_sched_getattr(-1U, (unsigned long) attr, bogus_size, bogus_flags);
+	pidns_print_leader();
 	printf("sched_getattr(-1, %p, %s%u, %u) = %s\n",
 	       attr,
 # if defined __arm64__ || defined __aarch64__
@@ -71,24 +82,52 @@ main(void)
 # endif
 	       (unsigned) bogus_size, (unsigned) bogus_flags, errstr);
 
+	sys_sched_getattr(0, (unsigned long) efault, SCHED_ATTR_MIN_SIZE, 0);
+	pidns_print_leader();
+	printf("sched_getattr(0, %p, %u, 0) = %s\n",
+	       efault, (unsigned) SCHED_ATTR_MIN_SIZE, errstr);
+
+	if (sys_sched_getattr(0, (unsigned long) attr, SCHED_ATTR_MIN_SIZE, 0))
+		perror_msg_and_skip("sched_getattr");
+	pidns_print_leader();
+	printf("sched_getattr(0, {size=%u, sched_policy=", attr->size);
+	printxval(schedulers, attr->sched_policy, NULL);
+	printf(", sched_flags=%s, sched_nice=%d, sched_priority=%u"
+	       ", sched_runtime=%" PRIu64 ", sched_deadline=%" PRIu64
+	       ", sched_period=%" PRIu64 "}, %u, 0) = 0\n",
+	       attr->sched_flags ? "SCHED_FLAG_RESET_ON_FORK" : "0",
+	       attr->sched_nice,
+	       attr->sched_priority,
+	       attr->sched_runtime,
+	       attr->sched_deadline,
+	       attr->sched_period,
+	       (unsigned) SCHED_ATTR_MIN_SIZE);
+
 	sys_sched_getattr(0, (unsigned long) efault, sizeof(*attr), 0);
+	pidns_print_leader();
 	printf("sched_getattr(0, %p, %u, 0) = %s\n",
 	       efault, (unsigned) sizeof(*attr), errstr);
 
 	if (sys_sched_getattr(0, (unsigned long) attr, sizeof(*attr), 0))
 		perror_msg_and_skip("sched_getattr");
+	pidns_print_leader();
 	printf("sched_getattr(0, {size=%u, sched_policy=", attr->size);
 	printxval(schedulers, attr->sched_policy, NULL);
 	printf(", sched_flags=%s, sched_nice=%d, sched_priority=%u"
 	       ", sched_runtime=%" PRIu64 ", sched_deadline=%" PRIu64
-	       ", sched_period=%" PRIu64 "}, %u, 0) = 0\n",
+	       ", sched_period=%" PRIu64,
 	       attr->sched_flags ? "SCHED_FLAG_RESET_ON_FORK" : "0",
 	       attr->sched_nice,
 	       attr->sched_priority,
 	       attr->sched_runtime,
 	       attr->sched_deadline,
-	       attr->sched_period,
-	       (unsigned) sizeof(*attr));
+	       attr->sched_period);
+	if (attr->size >= SCHED_ATTR_SIZE_VER1) {
+		printf(", sched_util_min=%u, sched_util_max=%u",
+		       attr->sched_util_min,
+		       attr->sched_util_max);
+	}
+	printf("}, %u, 0) = 0\n", (unsigned) sizeof(*attr));
 
 # if defined __arm64__ || defined __aarch64__
 	long rc =
@@ -97,66 +136,91 @@ main(void)
 			  F8ILL_KULONG_MASK | sizeof(*attr), F8ILL_KULONG_MASK);
 # if defined __arm64__ || defined __aarch64__
 	if (rc) {
+		pidns_print_leader();
 		printf("sched_getattr(0, %p, 0xffffffff<<32|%u, 0) = %s\n",
 		       attr, (unsigned) sizeof(*attr), errstr);
 	} else
 # endif
 	{
+		pidns_print_leader();
 		printf("sched_getattr(0, {size=%u, sched_policy=", attr->size);
 		printxval(schedulers, attr->sched_policy, NULL);
 		printf(", sched_flags=%s, sched_nice=%d, sched_priority=%u"
 		       ", sched_runtime=%" PRIu64 ", sched_deadline=%" PRIu64
-		       ", sched_period=%" PRIu64 "}, %u, 0) = 0\n",
+		       ", sched_period=%" PRIu64,
 		       attr->sched_flags ? "SCHED_FLAG_RESET_ON_FORK" : "0",
 		       attr->sched_nice,
 		       attr->sched_priority,
 		       attr->sched_runtime,
 		       attr->sched_deadline,
-		       attr->sched_period,
-		       (unsigned) sizeof(*attr));
+		       attr->sched_period);
+		if (attr->size >= SCHED_ATTR_SIZE_VER1) {
+			printf(", sched_util_min=%u, sched_util_max=%u",
+			       attr->sched_util_min,
+			       attr->sched_util_max);
+		}
+		printf("}, %u, 0) = 0\n", (unsigned) sizeof(*attr));
 	}
 
 	sys_sched_setattr(bogus_pid, 0, 0);
+	pidns_print_leader();
 	printf("sched_setattr(%d, NULL, 0) = %s\n", (int) bogus_pid, errstr);
 
 	attr->sched_flags |= 1;
 
-	if (sys_sched_setattr(0, (unsigned long) attr, 0))
+	if (sys_sched_setattr(pid, (unsigned long) attr, 0))
 		perror_msg_and_skip("sched_setattr");
-	printf("sched_setattr(0, {size=%u, sched_policy=", attr->size);
+	pidns_print_leader();
+	printf("sched_setattr(%d%s, {size=%u, sched_policy=",
+		pid, pid_str, attr->size);
 	printxval(schedulers, attr->sched_policy, NULL);
 	printf(", sched_flags=%s, sched_nice=%d, sched_priority=%u"
 	       ", sched_runtime=%" PRIu64 ", sched_deadline=%" PRIu64
-	       ", sched_period=%" PRIu64 "}, 0) = 0\n",
+	       ", sched_period=%" PRIu64,
 	       "SCHED_FLAG_RESET_ON_FORK",
 	       attr->sched_nice,
 	       attr->sched_priority,
 	       attr->sched_runtime,
 	       attr->sched_deadline,
 	       attr->sched_period);
+	if (attr->size >= SCHED_ATTR_SIZE_VER1) {
+		printf(", sched_util_min=%u, sched_util_max=%u",
+		       attr->sched_util_min,
+		       attr->sched_util_max);
+	}
+	printf("}, 0) = 0\n");
 
 	sys_sched_setattr(F8ILL_KULONG_MASK, (unsigned long) attr,
 			  F8ILL_KULONG_MASK);
+	pidns_print_leader();
 	printf("sched_setattr(0, {size=%u, sched_policy=", attr->size);
 	printxval(schedulers, attr->sched_policy, NULL);
 	printf(", sched_flags=%s, sched_nice=%d, sched_priority=%u"
 	       ", sched_runtime=%" PRIu64 ", sched_deadline=%" PRIu64
-	       ", sched_period=%" PRIu64 "}, 0) = 0\n",
+	       ", sched_period=%" PRIu64,
 	       "SCHED_FLAG_RESET_ON_FORK",
 	       attr->sched_nice,
 	       attr->sched_priority,
 	       attr->sched_runtime,
 	       attr->sched_deadline,
 	       attr->sched_period);
+	if (attr->size >= SCHED_ATTR_SIZE_VER1) {
+		printf(", sched_util_min=%u, sched_util_max=%u",
+		       attr->sched_util_min,
+		       attr->sched_util_max);
+	}
+	printf("}, 0) = 0\n");
 
 	*psize = attr->size;
 
 	sys_sched_setattr(0, (unsigned long) psize, 0);
+	pidns_print_leader();
 	printf("sched_setattr(0, %p, 0) = %s\n", psize, errstr);
 
 	attr->size = 0;
 
 	sys_sched_setattr(0, (unsigned long) attr, 0);
+	pidns_print_leader();
 	printf("sched_setattr(0, {size=%u, sched_policy=", attr->size);
 	printxval(schedulers, attr->sched_policy, NULL);
 	printf(", sched_flags=%s, sched_nice=%d, sched_priority=%u"
@@ -172,18 +236,20 @@ main(void)
 	attr->size = 1;
 
 	sys_sched_setattr(0, (unsigned long) attr, 0);
+	pidns_print_leader();
 	printf("sched_setattr(0, {size=%u} => {size=%u}, 0) = %s\n",
 	       1, attr->size, errstr);
 
 	attr->size = SCHED_ATTR_MIN_SIZE - 1;
 
 	sys_sched_setattr(0, (unsigned long) attr, 0);
+	pidns_print_leader();
 	printf("sched_setattr(0, {size=%u} => {size=%u}, 0) = %s\n",
 	       SCHED_ATTR_MIN_SIZE - 1, attr->size, errstr);
 
 	attr->size = 0x90807060;
 	attr->sched_policy = 0xca7faced;
-	attr->sched_flags = 0xbadc0ded1057da78ULL;
+	attr->sched_flags = 0xbadc0ded1057da80ULL;
 	attr->sched_nice = 0xafbfcfdf;
 	attr->sched_priority = 0xb8c8d8e8;
 	attr->sched_runtime = 0xbadcaffedeadf157ULL;
@@ -191,11 +257,12 @@ main(void)
 	attr->sched_period = 0xded1ca7edda7aca7ULL;
 
 	sys_sched_setattr(bogus_pid, (unsigned long) attr, bogus_flags);
+	pidns_print_leader();
 	printf("sched_setattr(%d, {size=%u, sched_policy=%#x /* SCHED_??? */, "
 	       "sched_flags=%#" PRIx64 " /* SCHED_FLAG_??? */, "
 	       "sched_nice=%d, sched_priority=%u, sched_runtime=%" PRIu64 ", "
-	       "sched_deadline=%" PRIu64 ", sched_period=%" PRIu64 ", ...}, %u)"
-	       " = %s\n",
+	       "sched_deadline=%" PRIu64 ", sched_period=%" PRIu64 ", "
+	       "sched_util_min=%u, sched_util_max=%u, ...}, %u) = %s\n",
 	       (int) bogus_pid,
 	       attr->size,
 	       attr->sched_policy,
@@ -205,6 +272,8 @@ main(void)
 	       attr->sched_runtime,
 	       attr->sched_deadline,
 	       attr->sched_period,
+	       attr->sched_util_min,
+	       attr->sched_util_max,
 	       (unsigned) bogus_flags, errstr);
 
 	if (F8ILL_KULONG_SUPPORTED) {
@@ -223,7 +292,7 @@ main(void)
 
 	attr->size = 0x90807060;
 	attr->sched_policy = 0xca7faced;
-	attr->sched_flags = 0xfULL;
+	attr->sched_flags = 0x87ULL;
 	attr->sched_nice = 0xafbfcfdf;
 	attr->sched_priority = 0xb8c8d8e8;
 	attr->sched_runtime = 0xbadcaffedeadf157ULL;
@@ -231,35 +300,143 @@ main(void)
 	attr->sched_period = 0xded1ca7edda7aca7ULL;
 
 	sys_sched_setattr(bogus_pid, (unsigned long) attr, bogus_flags);
+	pidns_print_leader();
 	printf("sched_setattr(%d, {size=%u, sched_policy=%#x /* SCHED_??? */, "
 	       "sched_flags=SCHED_FLAG_RESET_ON_FORK|SCHED_FLAG_RECLAIM|"
-	       "SCHED_FLAG_DL_OVERRUN|0x8, "
+	       "SCHED_FLAG_DL_OVERRUN|0x80, "
+	       "sched_nice=%d, sched_priority=%u, sched_runtime=%" PRIu64 ", "
+	       "sched_deadline=%" PRIu64 ", sched_period=%" PRIu64 ", "
+	       "sched_util_min=%u, sched_util_max=%u, ...}, %u) = %s\n",
+	       (int) bogus_pid,
+	       attr->size,
+	       attr->sched_policy,
+	       attr->sched_nice,
+	       attr->sched_priority,
+	       attr->sched_runtime,
+	       attr->sched_deadline,
+	       attr->sched_period,
+	       attr->sched_util_min,
+	       attr->sched_util_max,
+	       (unsigned) bogus_flags, errstr);
+
+	if (F8ILL_KULONG_SUPPORTED) {
+		const kernel_ulong_t ill = f8ill_ptr_to_kulong(attr);
+
+		sys_sched_getattr(0, ill, sizeof(*attr), 0);
+		pidns_print_leader();
+		printf("sched_getattr(0, %#llx, %u, 0) = %s\n",
+		       (unsigned long long) ill, (unsigned) sizeof(*attr),
+		       errstr);
+
+		sys_sched_setattr(0, ill, 0);
+		pidns_print_leader();
+		printf("sched_setattr(0, %#llx, 0) = %s\n",
+		       (unsigned long long) ill, errstr);
+	}
+
+	attr->size = SCHED_ATTR_MIN_SIZE;
+	attr->sched_policy = 0xdefaced;
+	attr->sched_flags = 0x8fULL;
+
+	sys_sched_setattr(bogus_pid, (unsigned long) attr, bogus_flags);
+	pidns_print_leader();
+	printf("sched_setattr(%d, {size=%u, "
+	       "sched_flags=SCHED_FLAG_RESET_ON_FORK|SCHED_FLAG_RECLAIM|"
+	       "SCHED_FLAG_DL_OVERRUN|SCHED_FLAG_KEEP_POLICY|0x80, "
 	       "sched_nice=%d, sched_priority=%u, sched_runtime=%" PRIu64 ", "
-	       "sched_deadline=%" PRIu64 ", sched_period=%" PRIu64 ", ...}, %u)"
+	       "sched_deadline=%" PRIu64 ", sched_period=%" PRIu64 "}, %u)"
 	       " = %s\n",
 	       (int) bogus_pid,
 	       attr->size,
+	       attr->sched_nice,
+	       attr->sched_priority,
+	       attr->sched_runtime,
+	       attr->sched_deadline,
+	       attr->sched_period,
+	       (unsigned) bogus_flags, errstr);
+
+	if (F8ILL_KULONG_SUPPORTED) {
+		const kernel_ulong_t ill = f8ill_ptr_to_kulong(attr);
+
+		sys_sched_getattr(0, ill, sizeof(*attr), 0);
+		pidns_print_leader();
+		printf("sched_getattr(0, %#llx, %u, 0) = %s\n",
+		       (unsigned long long) ill, (unsigned) sizeof(*attr),
+		       errstr);
+
+		sys_sched_setattr(0, ill, 0);
+		pidns_print_leader();
+		printf("sched_setattr(0, %#llx, 0) = %s\n",
+		       (unsigned long long) ill, errstr);
+	}
+
+	attr->size = SCHED_ATTR_SIZE_VER1;
+	attr->sched_flags = 0xe7ULL;
+
+	sys_sched_setattr(bogus_pid, (unsigned long) attr, bogus_flags);
+	pidns_print_leader();
+	printf("sched_setattr(%d, {size=%u, sched_policy=%#x /* SCHED_??? */, "
+	       "sched_flags=SCHED_FLAG_RESET_ON_FORK|SCHED_FLAG_RECLAIM|"
+	       "SCHED_FLAG_DL_OVERRUN|SCHED_FLAG_UTIL_CLAMP_MIN"
+	       "|SCHED_FLAG_UTIL_CLAMP_MAX|0x80, "
+	       "sched_nice=%d, sched_priority=%u, sched_runtime=%" PRIu64 ", "
+	       "sched_deadline=%" PRIu64 ", sched_period=%" PRIu64 ", "
+	       "sched_util_min=%u, sched_util_max=%u}, %u) = %s\n",
+	       (int) bogus_pid,
+	       attr->size,
 	       attr->sched_policy,
 	       attr->sched_nice,
 	       attr->sched_priority,
 	       attr->sched_runtime,
 	       attr->sched_deadline,
 	       attr->sched_period,
+	       attr->sched_util_min,
+	       attr->sched_util_max,
+	       (unsigned) bogus_flags, errstr);
+
+	if (F8ILL_KULONG_SUPPORTED) {
+		const kernel_ulong_t ill = f8ill_ptr_to_kulong(attr);
+
+		sys_sched_getattr(0, ill, sizeof(*attr), 0);
+		pidns_print_leader();
+		printf("sched_getattr(0, %#llx, %u, 0) = %s\n",
+		       (unsigned long long) ill, (unsigned) sizeof(*attr),
+		       errstr);
+
+		sys_sched_setattr(0, ill, 0);
+		pidns_print_leader();
+		printf("sched_setattr(0, %#llx, 0) = %s\n",
+		       (unsigned long long) ill, errstr);
+	}
+
+	attr->sched_flags = 0xcaffee90LL;
+
+	sys_sched_setattr(bogus_pid, (unsigned long) attr, bogus_flags);
+	pidns_print_leader();
+	printf("sched_setattr(%d, {size=%u, sched_flags=SCHED_FLAG_KEEP_PARAMS"
+	       "|0xcaffee80, sched_util_min=%u, sched_util_max=%u}, %u) = %s\n",
+	       (int) bogus_pid,
+	       attr->size,
+	       attr->sched_util_min,
+	       attr->sched_util_max,
 	       (unsigned) bogus_flags, errstr);
 
 	if (F8ILL_KULONG_SUPPORTED) {
 		const kernel_ulong_t ill = f8ill_ptr_to_kulong(attr);
 
 		sys_sched_getattr(0, ill, sizeof(*attr), 0);
+		pidns_print_leader();
 		printf("sched_getattr(0, %#llx, %u, 0) = %s\n",
 		       (unsigned long long) ill, (unsigned) sizeof(*attr),
 		       errstr);
 
 		sys_sched_setattr(0, ill, 0);
+		pidns_print_leader();
 		printf("sched_setattr(0, %#llx, 0) = %s\n",
 		       (unsigned long long) ill, errstr);
 	}
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests/sched_xetattr--pidns-translation.c 5.9-0ubuntu2/tests/sched_xetattr--pidns-translation.c
--- 5.5-3/tests/sched_xetattr--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/sched_xetattr--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "sched_xetattr.c"
diff -pruN 5.5-3/tests/sched_xetattr--pidns-translation.gen.test 5.9-0ubuntu2/tests/sched_xetattr--pidns-translation.gen.test
--- 5.5-3/tests/sched_xetattr--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/sched_xetattr--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (sched_xetattr--pidns-translation test_pidns -a29 -e trace=sched_getattr,sched_setattr); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a29 -e trace=sched_getattr,sched_setattr
diff -pruN 5.5-3/tests/sched_xetparam.c 5.9-0ubuntu2/tests/sched_xetparam.c
--- 5.5-3/tests/sched_xetparam.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/sched_xetparam.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -7,6 +7,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #if defined __NR_sched_getparam && defined __NR_sched_setparam
 
@@ -17,18 +18,27 @@
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	struct sched_param *const param =
 		tail_alloc(sizeof(struct sched_param));
 
-	long rc = syscall(__NR_sched_getparam, 0, param);
-	printf("sched_getparam(0, [%d]) = %ld\n",
-	       param->sched_priority, rc);
+	const int pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
+
+	long rc = syscall(__NR_sched_getparam, pid, param);
+	pidns_print_leader();
+	printf("sched_getparam(%d%s, [%d]) = %ld\n",
+	       pid, pid_str, param->sched_priority, rc);
 
 	param->sched_priority = -1;
-	rc = syscall(__NR_sched_setparam, 0, param);
-	printf("sched_setparam(0, [%d]) = %ld %s (%m)\n",
+	rc = syscall(__NR_sched_setparam, pid, param);
+	pidns_print_leader();
+	printf("sched_setparam(%d%s, [%d]) = %ld %s (%m)\n",
+	       pid, pid_str,
 	       param->sched_priority, rc, errno2name());
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests/sched_xetparam--pidns-translation.c 5.9-0ubuntu2/tests/sched_xetparam--pidns-translation.c
--- 5.5-3/tests/sched_xetparam--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/sched_xetparam--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "sched_xetparam.c"
diff -pruN 5.5-3/tests/sched_xetparam--pidns-translation.gen.test 5.9-0ubuntu2/tests/sched_xetparam--pidns-translation.gen.test
--- 5.5-3/tests/sched_xetparam--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/sched_xetparam--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (sched_xetparam--pidns-translation test_pidns -a23 -e trace=sched_getparam,sched_setparam); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a23 -e trace=sched_getparam,sched_setparam
diff -pruN 5.5-3/tests/sched_xetscheduler.c 5.9-0ubuntu2/tests/sched_xetscheduler.c
--- 5.5-3/tests/sched_xetscheduler.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/sched_xetscheduler.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -7,6 +7,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #if defined __NR_sched_getscheduler && defined __NR_sched_setscheduler
 
@@ -17,8 +18,13 @@
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct sched_param, param);
-	long rc = syscall(__NR_sched_getscheduler, 0);
+	const int pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
+
+	long rc = syscall(__NR_sched_getscheduler, pid);
 	const char *scheduler;
 	switch (rc) {
 		case SCHED_FIFO:
@@ -50,33 +56,43 @@ main(void)
 		default:
 			scheduler = "SCHED_OTHER";
 	}
-	printf("sched_getscheduler(0) = %ld (%s)\n",
-	       rc, scheduler);
+	pidns_print_leader();
+	printf("sched_getscheduler(%d%s) = %ld (%s)\n",
+	       pid, pid_str, rc, scheduler);
 
 	rc = syscall(__NR_sched_getscheduler, -1);
+	pidns_print_leader();
 	printf("sched_getscheduler(-1) = %s\n", sprintrc(rc));
 
 	param->sched_priority = -1;
 
-	rc = syscall(__NR_sched_setscheduler, 0, SCHED_FIFO, NULL);
-	printf("sched_setscheduler(0, SCHED_FIFO, NULL) = %s\n", sprintrc(rc));
-
-	rc = syscall(__NR_sched_setscheduler, 0, SCHED_FIFO, param + 1);
-	printf("sched_setscheduler(0, SCHED_FIFO, %p) = %s\n", param + 1,
-	       sprintrc(rc));
-
-	rc = syscall(__NR_sched_setscheduler, 0, 0xfaceda7a, param);
-	printf("sched_setscheduler(0, %#x /* SCHED_??? */, [%d]) = %s\n",
-	       0xfaceda7a, param->sched_priority, sprintrc(rc));
+	rc = syscall(__NR_sched_setscheduler, pid, SCHED_FIFO, NULL);
+	pidns_print_leader();
+	printf("sched_setscheduler(%d%s, SCHED_FIFO, NULL) = %s\n",
+	       pid, pid_str, sprintrc(rc));
+
+	rc = syscall(__NR_sched_setscheduler, pid, SCHED_FIFO, param + 1);
+	pidns_print_leader();
+	printf("sched_setscheduler(%d%s, SCHED_FIFO, %p) = %s\n",
+	       pid, pid_str, param + 1, sprintrc(rc));
+
+	rc = syscall(__NR_sched_setscheduler, pid, 0xfaceda7a, param);
+	pidns_print_leader();
+	printf("sched_setscheduler(%d%s, %#x /* SCHED_??? */, [%d]) = %s\n",
+	       pid, pid_str, 0xfaceda7a,
+	       param->sched_priority, sprintrc(rc));
 
 	rc = syscall(__NR_sched_setscheduler, -1, SCHED_FIFO, param);
+	pidns_print_leader();
 	printf("sched_setscheduler(-1, SCHED_FIFO, [%d]) = %s\n",
 	       param->sched_priority, sprintrc(rc));
 
-	rc = syscall(__NR_sched_setscheduler, 0, SCHED_FIFO, param);
-	printf("sched_setscheduler(0, SCHED_FIFO, [%d]) = %s\n",
-	       param->sched_priority, sprintrc(rc));
+	rc = syscall(__NR_sched_setscheduler, pid, SCHED_FIFO, param);
+	pidns_print_leader();
+	printf("sched_setscheduler(%d%s, SCHED_FIFO, [%d]) = %s\n",
+	       pid, pid_str, param->sched_priority, sprintrc(rc));
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests/sched_xetscheduler--pidns-translation.c 5.9-0ubuntu2/tests/sched_xetscheduler--pidns-translation.c
--- 5.5-3/tests/sched_xetscheduler--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/sched_xetscheduler--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "sched_xetscheduler.c"
diff -pruN 5.5-3/tests/sched_xetscheduler--pidns-translation.gen.test 5.9-0ubuntu2/tests/sched_xetscheduler--pidns-translation.gen.test
--- 5.5-3/tests/sched_xetscheduler--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/sched_xetscheduler--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (sched_xetscheduler--pidns-translation test_pidns -a22 -e trace=sched_getscheduler,sched_setscheduler); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a22 -e trace=sched_getscheduler,sched_setscheduler
diff -pruN 5.5-3/tests/seccomp-filter.c 5.9-0ubuntu2/tests/seccomp-filter.c
--- 5.5-3/tests/seccomp-filter.c	2019-07-16 17:46:47.000000000 +0000
+++ 5.9-0ubuntu2/tests/seccomp-filter.c	2020-06-01 14:15:16.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of seccomp SECCOMP_SET_MODE_FILTER.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -38,12 +38,13 @@ main(void)
 	       " = %ld %s (%m)\n",
 	       "SECCOMP_FILTER_FLAG_TSYNC|SECCOMP_FILTER_FLAG_LOG|"
 	       "SECCOMP_FILTER_FLAG_SPEC_ALLOW|"
-	       "SECCOMP_FILTER_FLAG_NEW_LISTENER|0xfffffff0",
+	       "SECCOMP_FILTER_FLAG_NEW_LISTENER|"
+	       "SECCOMP_FILTER_FLAG_TSYNC_ESRCH|0xffffffe0",
 	       prog->len, prog->filter, rc, errno2name());
 
-	rc = syscall(__NR_seccomp, SECCOMP_SET_MODE_FILTER, -16L, efault);
+	rc = syscall(__NR_seccomp, SECCOMP_SET_MODE_FILTER, -32L, efault);
 	printf("seccomp(SECCOMP_SET_MODE_FILTER, %s, %p) = %ld %s (%m)\n",
-	       "0xfffffff0 /* SECCOMP_FILTER_FLAG_??? */",
+	       "0xffffffe0 /* SECCOMP_FILTER_FLAG_??? */",
 	       efault, rc, errno2name());
 
 	puts("+++ exited with 0 +++");
diff -pruN 5.5-3/tests/seccomp-filter-v.c 5.9-0ubuntu2/tests/seccomp-filter-v.c
--- 5.5-3/tests/seccomp-filter-v.c	2019-09-15 15:47:01.000000000 +0000
+++ 5.9-0ubuntu2/tests/seccomp-filter-v.c	2020-04-15 13:39:57.000000000 +0000
@@ -2,7 +2,7 @@
  * Check verbose decoding of seccomp SECCOMP_SET_MODE_FILTER.
  *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -13,16 +13,13 @@
 #include <errno.h>
 #include <stddef.h>
 #include <stdio.h>
-#include "scno.h"
 #include <unistd.h>
-
-#ifdef HAVE_PRCTL
-# include <sys/prctl.h>
-#endif
+#include <sys/prctl.h>
 #ifdef HAVE_LINUX_SECCOMP_H
 # include <linux/seccomp.h>
 #endif
 #include <linux/filter.h>
+#include "scno.h"
 
 #if defined __NR_seccomp \
  && defined PR_SET_NO_NEW_PRIVS \
@@ -118,7 +115,8 @@ main(void)
 	tprintf("seccomp(SECCOMP_SET_MODE_FILTER, %s, {len=%u, filter=[",
 		"SECCOMP_FILTER_FLAG_TSYNC|SECCOMP_FILTER_FLAG_LOG|"
 		"SECCOMP_FILTER_FLAG_SPEC_ALLOW|"
-		"SECCOMP_FILTER_FLAG_NEW_LISTENER|0xfffffff0",
+		"SECCOMP_FILTER_FLAG_NEW_LISTENER|"
+		"SECCOMP_FILTER_FLAG_TSYNC_ESRCH|0xffffffe0",
 		prog->len);
 	for (i = 0; i < BPF_MAXINSNS; ++i) {
 		if (i)
diff -pruN 5.5-3/tests/semtimedop.c 5.9-0ubuntu2/tests/semtimedop.c
--- 5.5-3/tests/semtimedop.c	2019-11-18 13:31:57.000000000 +0000
+++ 5.9-0ubuntu2/tests/semtimedop.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,21 +1,25 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-#include <sys/ipc.h>
-#include <sys/sem.h>
-#include <stdint.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-
-#define XLAT_MACROS_ONLY
-#include "xlat/semop_flags.h"
-#undef XLAT_MACROS_ONLY
+#include "scno.h"
+
+#if defined __NR_semtimedop || defined __NR_socketcall
+
+# include <sys/ipc.h>
+# include <sys/sem.h>
+# include <stdint.h>
+# include <stdio.h>
+# include <stdlib.h>
+# include <unistd.h>
+
+# define XLAT_MACROS_ONLY
+#  include "xlat/semop_flags.h"
+# undef XLAT_MACROS_ONLY
 
 union semun {
 	int val;
@@ -143,3 +147,9 @@ main(void)
 	puts("+++ exited with 0 +++");
 	return 0;
 }
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_semtimedop || __NR_socketcall")
+
+#endif
diff -pruN 5.5-3/tests/sendfile64.c 5.9-0ubuntu2/tests/sendfile64.c
--- 5.5-3/tests/sendfile64.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/sendfile64.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -50,14 +50,9 @@ main(void)
 	const unsigned int blen = file_size / 3;
 	const unsigned int alen = file_size - blen;
 
-	static const char fname[] = "sendfile64-tmpfile";
-	int reg_in = open(fname, O_RDWR | O_CREAT | O_TRUNC, 0600);
-	if (reg_in < 0)
-		perror_msg_and_fail("open: %s", fname);
-	if (unlink(fname))
-		perror_msg_and_fail("unlink: %s", fname);
+	int reg_in = create_tmpfile(O_RDWR);
 	if (ftruncate(reg_in, file_size))
-		perror_msg_and_fail("ftruncate: %s", fname);
+		perror_msg_and_fail("ftruncate(%d, %u)", reg_in, file_size);
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(uint64_t, p_off);
 	void *p = p_off + 1;
diff -pruN 5.5-3/tests/sendfile.c 5.9-0ubuntu2/tests/sendfile.c
--- 5.5-3/tests/sendfile.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/sendfile.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -50,14 +50,9 @@ main(void)
 	const unsigned int blen = file_size / 3;
 	const unsigned int alen = file_size - blen;
 
-	static const char fname[] = "sendfile-tmpfile";
-	int reg_in = open(fname, O_RDWR | O_CREAT | O_TRUNC, 0600);
-	if (reg_in < 0)
-		perror_msg_and_fail("open: %s", fname);
-	if (unlink(fname))
-		perror_msg_and_fail("unlink: %s", fname);
+	int reg_in = create_tmpfile(O_RDWR);
 	if (ftruncate(reg_in, file_size))
-		perror_msg_and_fail("ftruncate: %s", fname);
+		perror_msg_and_fail("ftruncate(%d, %u)", reg_in, file_size);
 
 	TAIL_ALLOC_OBJECT_VAR_PTR(uint32_t, p_off);
 	void *p = p_off + 1;
diff -pruN 5.5-3/tests/setpgrp-exec.c 5.9-0ubuntu2/tests/setpgrp-exec.c
--- 5.5-3/tests/setpgrp-exec.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/setpgrp-exec.c	2020-04-02 11:10:14.000000000 +0000
@@ -0,0 +1,22 @@
+/*
+ * Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include <unistd.h>
+
+int main(int argc, char **argv)
+{
+	if (argc < 2)
+		error_msg_and_fail("argc < 2");
+
+	if (setpgid(0, 0))
+		perror_msg_and_fail("setpgid");
+
+	(void) execvp(argv[1], argv + 1);
+
+	perror_msg_and_fail("execvp: %s", argv[1]);
+}
diff -pruN 5.5-3/tests/set_ptracer_any.c 5.9-0ubuntu2/tests/set_ptracer_any.c
--- 5.5-3/tests/set_ptracer_any.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/set_ptracer_any.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2013-2015 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2013-2018 The strace developers.
+ * Copyright (c) 2013-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -9,25 +9,21 @@
 #include "tests.h"
 #include <stdio.h>
 #include <unistd.h>
-#ifdef HAVE_PRCTL
-# include <sys/prctl.h>
-#endif
+#include <sys/prctl.h>
 
 int main(int argc, char **argv)
 {
 	if (argc < 2)
 		return 99;
-#ifdef HAVE_PRCTL
 	/* Turn off restrictions on tracing if applicable.  If the command
 	 * aren't available on this system, that's OK too.  */
-# ifndef PR_SET_PTRACER
-#  define PR_SET_PTRACER 0x59616d61
-# endif
-# ifndef PR_SET_PTRACER_ANY
-#  define PR_SET_PTRACER_ANY -1UL
-# endif
-	(void) prctl(PR_SET_PTRACER, PR_SET_PTRACER_ANY, 0, 0, 0);
+#ifndef PR_SET_PTRACER
+# define PR_SET_PTRACER 0x59616d61
 #endif
+#ifndef PR_SET_PTRACER_ANY
+# define PR_SET_PTRACER_ANY -1UL
+#endif
+	(void) prctl(PR_SET_PTRACER, PR_SET_PTRACER_ANY, 0, 0, 0);
 	if (write(1, "\n", 1) != 1) {
 		perror("write");
 		return 99;
diff -pruN 5.5-3/tests/sigblock.test 5.9-0ubuntu2/tests/sigblock.test
--- 5.5-3/tests/sigblock.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/sigblock.test	2020-04-03 22:58:26.000000000 +0000
@@ -4,7 +4,7 @@
 # Starting with commit v4.17-5-gf83b49b strace is expected
 # to forward the signal mask to tracees unchanged.
 #
-# Copyright (c) 2017-2018 The strace developers.
+# Copyright (c) 2017-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -20,7 +20,7 @@ for sig in $(../list_sigaction_signum);
 		check_cmd="../check_sigblock $block $sig"
 		run_prog $set_cmd $check_cmd
 		STRACE="$set_cmd $saved_STRACE"
-		for i in '' -I1 -I2 -I3 -I4; do
+		for i in '' -I1 -Iwaiting --interruptible=3 --interruptible=never_tstp; do
 			run_strace $i -enone $check_cmd
 		done
 	done
diff -pruN 5.5-3/tests/sigign.test 5.9-0ubuntu2/tests/sigign.test
--- 5.5-3/tests/sigign.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/sigign.test	2020-04-03 22:58:26.000000000 +0000
@@ -4,7 +4,7 @@
 # Starting with commit v4.17-8-ge97a66f strace is expected
 # to forward the signal disposition to tracees unchanged.
 #
-# Copyright (c) 2017-2018 The strace developers.
+# Copyright (c) 2017-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -20,7 +20,7 @@ for sig in $(../list_sigaction_signum);
 		check_cmd="../check_sigign $ign $sig"
 		run_prog $set_cmd $check_cmd
 		STRACE="$set_cmd $saved_STRACE"
-		for i in '' -I1 -I2 -I3 -I4; do
+		for i in '' --interruptible=always --interruptible=2 -Inever -I4; do
 			run_strace $i -enone $check_cmd
 		done
 	done
diff -pruN 5.5-3/tests/siginfo.c 5.9-0ubuntu2/tests/siginfo.c
--- 5.5-3/tests/siginfo.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/siginfo.c	2020-08-03 08:00:00.000000000 +0000
@@ -2,6 +2,7 @@
  * Check SIGCHLD siginfo_t decoding.
  *
  * Copyright (c) 2015-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -63,7 +64,7 @@ main(void)
 
 	sigsuspend(&unblock_mask);
 	tprintf("--- SIGCHLD {si_signo=SIGCHLD, si_code=CLD_EXITED"
-		", si_pid=%d, si_uid=%u, si_status=%d"
+		", si_pid=%d, si_uid=%d, si_status=%d"
 		", si_utime=%llu, si_stime=%llu} ---\n",
 		sinfo.si_pid, sinfo.si_uid, sinfo.si_status,
 		zero_extend_signed_to_ull(sinfo.si_utime),
@@ -94,7 +95,7 @@ main(void)
 
 	sigsuspend(&unblock_mask);
 	tprintf("--- SIGCHLD {si_signo=SIGCHLD, si_code=CLD_KILLED"
-		", si_pid=%d, si_uid=%u, si_status=SIGUSR1"
+		", si_pid=%d, si_uid=%d, si_status=SIGUSR1"
 		", si_utime=%llu, si_stime=%llu} ---\n",
 		sinfo.si_pid, sinfo.si_uid,
 		zero_extend_signed_to_ull(sinfo.si_utime),
@@ -121,7 +122,7 @@ main(void)
 
 	sigsuspend(&unblock_mask);
 	tprintf("--- SIGCHLD {si_signo=SIGCHLD, si_code=CLD_STOPPED"
-		", si_pid=%d, si_uid=%u, si_status=SIGSTOP"
+		", si_pid=%d, si_uid=%d, si_status=SIGSTOP"
 		", si_utime=%llu, si_stime=%llu} ---\n",
 		sinfo.si_pid, sinfo.si_uid,
 		zero_extend_signed_to_ull(sinfo.si_utime),
@@ -131,7 +132,7 @@ main(void)
 
 	sigsuspend(&unblock_mask);
 	tprintf("--- SIGCHLD {si_signo=SIGCHLD, si_code=CLD_CONTINUED"
-		", si_pid=%d, si_uid=%u, si_status=SIGCONT"
+		", si_pid=%d, si_uid=%d, si_status=SIGCONT"
 		", si_utime=%llu, si_stime=%llu} ---\n",
 		sinfo.si_pid, sinfo.si_uid,
 		zero_extend_signed_to_ull(sinfo.si_utime),
@@ -142,7 +143,7 @@ main(void)
 
 	sigsuspend(&unblock_mask);
 	tprintf("--- SIGCHLD {si_signo=SIGCHLD, si_code=CLD_EXITED"
-		", si_pid=%d, si_uid=%u, si_status=0"
+		", si_pid=%d, si_uid=%d, si_status=0"
 		", si_utime=%llu, si_stime=%llu} ---\n",
 		sinfo.si_pid, sinfo.si_uid,
 		zero_extend_signed_to_ull(sinfo.si_utime),
diff -pruN 5.5-3/tests/signal_receive.c 5.9-0ubuntu2/tests/signal_receive.c
--- 5.5-3/tests/signal_receive.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/signal_receive.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,13 +1,14 @@
 /*
  * Check decoding of signal delivery.
  *
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include "pidns.h"
 #include <signal.h>
 #include <stdio.h>
 #include <unistd.h>
@@ -26,10 +27,13 @@ handler(int sig, siginfo_t *info, void *
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	static const char prefix[] = "KERNEL BUG";
 	int printed = 0;
 
 	const int pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
 	const int uid = geteuid();
 
 	for (int sig = 1; sig <= 31; ++sig) {
@@ -73,10 +77,13 @@ main(void)
 		const int e_pid = s_pid;
 		const int e_uid = s_uid;
 #endif
-		printf("kill(%d, %s) = 0\n", pid, signal2name(sig));
-		printf("--- %s {si_signo=%s, si_code=SI_USER, si_pid=%d"
+		pidns_print_leader();
+		printf("kill(%d%s, %s) = 0\n", pid, pid_str, signal2name(sig));
+		pidns_print_leader();
+		printf("--- %s {si_signo=%s, si_code=SI_USER, si_pid=%d%s"
 		       ", si_uid=%d} ---\n",
-		       signal2name(sig), signal2name(e_sig), e_pid, e_uid);
+		       signal2name(sig), signal2name(e_sig),
+		       e_pid, pid_str, e_uid);
 
 		if (s_code || sig != s_sig || pid != s_pid || uid != s_uid) {
 			/*
@@ -91,11 +98,11 @@ main(void)
 			}
 			fprintf(stderr,
 				"%s: expected: si_signo=%d, si_code=%d"
-				", si_pid=%d, si_uid=%d\n"
+				", si_pid=%d%s, si_uid=%d\n"
 				"%s: received: si_signo=%d, si_code=%d"
-				", si_pid=%d, si_uid=%d\n",
-				prefix, sig, SI_USER, pid, uid,
-				prefix, sig, s_code, s_pid, s_uid);
+				", si_pid=%d%s, si_uid=%d\n",
+				prefix, sig, SI_USER, pid, pid_str, uid,
+				prefix, sig, s_code, s_pid, pid_str, s_uid);
 		}
 	}
 
@@ -104,6 +111,7 @@ main(void)
 			"*** PLEASE FIX THE KERNEL ***\n", prefix);
 	}
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests/signal_receive--pidns-translation.c 5.9-0ubuntu2/tests/signal_receive--pidns-translation.c
--- 5.5-3/tests/signal_receive--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/signal_receive--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "signal_receive.c"
diff -pruN 5.5-3/tests/signal_receive--pidns-translation.gen.test 5.9-0ubuntu2/tests/signal_receive--pidns-translation.gen.test
--- 5.5-3/tests/signal_receive--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/signal_receive--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (signal_receive--pidns-translation test_pidns -a16 -e trace=kill); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a16 -e trace=kill
diff -pruN 5.5-3/tests/sock_filter-v.c 5.9-0ubuntu2/tests/sock_filter-v.c
--- 5.5-3/tests/sock_filter-v.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/sock_filter-v.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of socket filters.
  *
  * Copyright (c) 2017 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2017-2018 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -23,17 +23,6 @@
 
 #define HEX_FMT "%#x"
 
-#if XLAT_RAW
-# define XLAT_FMT HEX_FMT
-# define XLAT_ARGS(a_) (a_)
-#elif XLAT_VERBOSE
-# define XLAT_FMT HEX_FMT " /* %s */"
-# define XLAT_ARGS(a_) (a_), #a_
-#else
-# define XLAT_FMT "%s"
-# define XLAT_ARGS(a_) #a_
-#endif
-
 #define PRINT_STMT(pfx, code_fmt, k_fmt, ...)	\
 	printf("%sBPF_STMT(" code_fmt ", " k_fmt ")", pfx, __VA_ARGS__)
 
diff -pruN 5.5-3/tests/sockopt-timestamp.c 5.9-0ubuntu2/tests/sockopt-timestamp.c
--- 5.5-3/tests/sockopt-timestamp.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests/sockopt-timestamp.c	2020-09-23 16:29:35.000000000 +0000
@@ -19,6 +19,9 @@
 # include <linux/time_types.h>
 #endif
 
+#include "kernel_timeval.h"
+#include "kernel_old_timespec.h"
+
 #define XLAT_MACROS_ONLY
 #include "xlat/sock_options.h"
 #undef XLAT_MACROS_ONLY
@@ -28,7 +31,7 @@ print_timestamp_old(const struct cmsghdr
 {
 	const void *cmsg_header = c;
 	const void *cmsg_data = CMSG_DATA(c);
-	struct timeval tv;
+	kernel_old_timeval_t tv;
 	const unsigned int expected_len = sizeof(tv);
 	const unsigned int data_len = c->cmsg_len - (cmsg_data - cmsg_header);
 
@@ -47,7 +50,7 @@ print_timestampns_old(const struct cmsgh
 {
 	const void *cmsg_header = c;
 	const void *cmsg_data = CMSG_DATA(c);
-	struct timespec ts;
+	kernel_old_timespec_t ts;
 	const unsigned int expected_len = sizeof(ts);
 	const unsigned int data_len = c->cmsg_len - (cmsg_data - cmsg_header);
 
diff -pruN 5.5-3/tests/so_error.c 5.9-0ubuntu2/tests/so_error.c
--- 5.5-3/tests/so_error.c	2018-12-17 19:19:23.000000000 +0000
+++ 5.9-0ubuntu2/tests/so_error.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,6 +2,7 @@
  * Check decoding of SO_ERROR socket option.
  *
  * Copyright (c) 2018 Masatake YAMATO <yamato@redhat.com>
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -37,7 +38,7 @@ reserve_ephemeral_port(void)
 	for (in_port_t port = 49152; port < 61000; port++) {
 		/* Just bind here. No listen. */
 		addr.sin_port = htons(port);
-		if (bind(sd, &addr, sizeof(addr)) == 0)
+		if (bind(sd, (void *) &addr, sizeof(addr)) == 0)
 			return port;
 	}
 	error_msg_and_skip("no ephemeral port available for test purposes");
@@ -69,7 +70,7 @@ main(void)
 		.sin_addr.s_addr = htonl(INADDR_LOOPBACK),
 		.sin_port = htons(port),
 	};
-	if (connect(fd, &addr, sizeof(addr)) == 0)
+	if (connect(fd, (void *) &addr, sizeof(addr)) == 0)
 		error_msg_and_skip("connect unexpectedly succeeded");
 	if (errno != EINPROGRESS)
 		perror_msg_and_skip("connect failed for unexpected reason");
diff -pruN 5.5-3/tests/so_peercred.c 5.9-0ubuntu2/tests/so_peercred.c
--- 5.5-3/tests/so_peercred.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/so_peercred.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,13 +2,14 @@
  * Check decoding of SO_PEERCRED socket option.
  *
  * Copyright (c) 2017 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2017-2018 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include "pidns.h"
 
 #include <stddef.h>
 #include <stdio.h>
@@ -53,6 +54,8 @@ so_str(void)
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct ucred, peercred);
 	TAIL_ALLOC_OBJECT_CONST_PTR(socklen_t, len);
 
@@ -75,6 +78,8 @@ main(void)
 	struct ucred *const gid_truncated =
 		tail_alloc(sizeof_gid_truncated);
 
+	const char *pid_str = pidns_pid2str(PT_TGID);
+
 	int sv[2];
 	if (socketpair(AF_UNIX, SOCK_STREAM, 0, sv))
                 perror_msg_and_skip("socketpair AF_UNIX SOCK_STREAM");
@@ -82,8 +87,10 @@ main(void)
 	/* classic getsockopt */
 	*len = sizeof(*peercred);
 	get_peercred(sv[0], peercred, len);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s", sv[0], so_str());
 	PRINT_FIELD_D(", {", *peercred, pid);
+	printf("%s", pid_str);
 	PRINT_FIELD_UID(", ", *peercred, uid);
 	PRINT_FIELD_UID(", ", *peercred, gid);
 	printf("}, [%d]) = %s\n", *len, errstr);
@@ -91,14 +98,17 @@ main(void)
 	/* getsockopt with zero optlen */
 	*len = 0;
 	get_peercred(sv[0], peercred, len);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s, %p, [0]) = %s\n",
 	       sv[0], so_str(), peercred, errstr);
 
 	/* getsockopt with optlen larger than necessary - shortened */
 	*len = sizeof(*peercred) + 1;
 	get_peercred(sv[0], peercred, len);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s", sv[0], so_str());
 	PRINT_FIELD_D(", {", *peercred, pid);
+	printf("%s", pid_str);
 	PRINT_FIELD_UID(", ", *peercred, uid);
 	PRINT_FIELD_UID(", ", *peercred, gid);
 	printf("}, [%u->%d]) = %s\n",
@@ -110,6 +120,7 @@ main(void)
 	 */
 	*len = sizeof_pid_truncated;
 	get_peercred(sv[0], pid_truncated, len);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s, {pid=", sv[0], so_str());
 	print_quoted_hex(pid_truncated, *len);
 	printf("}, [%d]) = %s\n", *len, errstr);
@@ -120,8 +131,10 @@ main(void)
 	 */
 	*len = sizeof_pid;
 	get_peercred(sv[0], pid, len);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s", sv[0], so_str());
 	PRINT_FIELD_D(", {", *pid, pid);
+	printf("%s", pid_str);
 	printf("}, [%d]) = %s\n", *len, errstr);
 
 	/*
@@ -136,8 +149,10 @@ main(void)
 	 * to struct ucred.pid field.
 	 */
 	memcpy(uid, uid_truncated, sizeof_uid_truncated);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s", sv[0], so_str());
 	PRINT_FIELD_D(", {", *uid, pid);
+	printf("%s", pid_str);
 	printf(", uid=");
 	print_quoted_hex(&uid->uid, sizeof_uid_truncated -
 				    offsetof(struct ucred, uid));
@@ -149,8 +164,10 @@ main(void)
 	 */
 	*len = sizeof_uid;
 	get_peercred(sv[0], uid, len);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s", sv[0], so_str());
 	PRINT_FIELD_D(", {", *uid, pid);
+	printf("%s", pid_str);
 	PRINT_FIELD_UID(", ", *uid, uid);
 	printf("}, [%d]) = %s\n", *len, errstr);
 
@@ -166,8 +183,10 @@ main(void)
 	 * to struct ucred.pid and struct ucred.uid fields.
 	 */
 	memcpy(peercred, gid_truncated, sizeof_gid_truncated);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s", sv[0], so_str());
 	PRINT_FIELD_D(", {", *peercred, pid);
+	printf("%s", pid_str);
 	PRINT_FIELD_UID(", ", *peercred, uid);
 	printf(", gid=");
 	print_quoted_hex(&peercred->gid, sizeof_gid_truncated -
@@ -177,14 +196,17 @@ main(void)
 	/* getsockopt optval EFAULT */
 	*len = sizeof(*peercred);
 	get_peercred(sv[0], &peercred->uid, len);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s, %p, [%d]) = %s\n",
 	       sv[0], so_str(), &peercred->uid, *len, errstr);
 
 	/* getsockopt optlen EFAULT */
 	get_peercred(sv[0], peercred, len + 1);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s, %p, %p) = %s\n",
 	       sv[0], so_str(), peercred, len + 1, errstr);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests/so_peercred--pidns-translation.c 5.9-0ubuntu2/tests/so_peercred--pidns-translation.c
--- 5.5-3/tests/so_peercred--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/so_peercred--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "so_peercred.c"
diff -pruN 5.5-3/tests/so_peercred--pidns-translation.gen.test 5.9-0ubuntu2/tests/so_peercred--pidns-translation.gen.test
--- 5.5-3/tests/so_peercred--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/so_peercred--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (so_peercred--pidns-translation test_pidns -e trace=getsockopt); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -e trace=getsockopt
diff -pruN 5.5-3/tests/stack-fcall-0.c 5.9-0ubuntu2/tests/stack-fcall-0.c
--- 5.5-3/tests/stack-fcall-0.c	2019-07-11 17:51:22.000000000 +0000
+++ 5.9-0ubuntu2/tests/stack-fcall-0.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2019 The strace developers.
+ * Copyright (c) 2014-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -7,7 +7,10 @@
 
 #include "stack-fcall.h"
 
-int f0(int i, unsigned long f)
+int
+f0(int i, unsigned long f)
 {
-	return f1(i, f ^ (unsigned long) (void *) f0) - i;
+	f ^= (unsigned long) (void *) f0;
+	COMPLEX_BODY(i, f);
+	return f1(i, f) - i;
 }
diff -pruN 5.5-3/tests/stack-fcall-1.c 5.9-0ubuntu2/tests/stack-fcall-1.c
--- 5.5-3/tests/stack-fcall-1.c	2019-07-11 17:51:22.000000000 +0000
+++ 5.9-0ubuntu2/tests/stack-fcall-1.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2019 The strace developers.
+ * Copyright (c) 2014-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -7,7 +7,10 @@
 
 #include "stack-fcall.h"
 
-int f1(int i, unsigned long f)
+int
+f1(int i, unsigned long f)
 {
-	return f2(i, f ^ (unsigned long) (void *) f1) + i;
+	f ^= (unsigned long) (void *) f1;
+	COMPLEX_BODY(i, f);
+	return f2(i, f) + i;
 }
diff -pruN 5.5-3/tests/stack-fcall-2.c 5.9-0ubuntu2/tests/stack-fcall-2.c
--- 5.5-3/tests/stack-fcall-2.c	2019-07-11 17:51:22.000000000 +0000
+++ 5.9-0ubuntu2/tests/stack-fcall-2.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2019 The strace developers.
+ * Copyright (c) 2014-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -7,7 +7,10 @@
 
 #include "stack-fcall.h"
 
-int f2(int i, unsigned long f)
+int
+f2(int i, unsigned long f)
 {
-	return f3(i, f ^ (unsigned long) (void *) f2) - i;
+	f ^= (unsigned long) (void *) f2;
+	COMPLEX_BODY(i, f);
+	return f3(i, f) - i;
 }
diff -pruN 5.5-3/tests/stack-fcall-3.c 5.9-0ubuntu2/tests/stack-fcall-3.c
--- 5.5-3/tests/stack-fcall-3.c	2019-07-16 17:46:47.000000000 +0000
+++ 5.9-0ubuntu2/tests/stack-fcall-3.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,25 +1,28 @@
 /*
- * Copyright (c) 2014-2019 The strace developers.
+ * Copyright (c) 2014-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include <signal.h>
-#include <unistd.h>
-#include "scno.h"
-
 #include "stack-fcall.h"
 
-int f3(int i, unsigned long f)
+int
+f3(int i, unsigned long f)
 {
-	syscall(__NR_gettid, f ^ (unsigned long) (void *) f3);
+	f ^= (unsigned long) (void *) f3;
+	COMPLEX_BODY(i, f);
 	switch (i) {
 	case 1:
-		return kill(getpid(), SIGURG);
-
+		i -= chdir("");
+		break;
+	case 2:
+		i -= kill(getpid(), SIGURG) - 1;
+		break;
 	default:
-		return chdir("") + i;
+		i -= syscall(__NR_exit, i - 3);
+		break;
 	}
-
+	return i;
 }
diff -pruN 5.5-3/tests/stack-fcall.c 5.9-0ubuntu2/tests/stack-fcall.c
--- 5.5-3/tests/stack-fcall.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests/stack-fcall.c	2020-06-27 08:00:00.000000000 +0000
@@ -13,14 +13,14 @@
 # define ATTACH_MODE 0
 #endif
 
-int main(void)
+int
+main(int ac, char **av)
 {
 #if ATTACH_MODE
 	/* sleep a bit to let the tracer time to catch up */
 	sleep(1);
 #endif
 
-	f0(0, (unsigned long) (void *) main);
-	f0(1, (unsigned long) (void *) main);
-	return 0;
+	for (;;)
+		ac += f0(ac, (unsigned long) (void *) main);
 }
diff -pruN 5.5-3/tests/stack-fcall.h 5.9-0ubuntu2/tests/stack-fcall.h
--- 5.5-3/tests/stack-fcall.h	2019-07-11 17:51:22.000000000 +0000
+++ 5.9-0ubuntu2/tests/stack-fcall.h	2020-08-03 08:00:00.000000000 +0000
@@ -1,10 +1,13 @@
 /*
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
+#include <unistd.h>
+#include "scno.h"
+
 #ifdef MANGLE
 
 # define f0 _ZN2ns2f0Ei
@@ -18,3 +21,24 @@ int f0(int i, unsigned long);
 int f1(int i, unsigned long);
 int f2(int i, unsigned long);
 int f3(int i, unsigned long);
+
+#define COMPLEX_BODY(i, f)				\
+	do {						\
+		int tid = syscall(__NR_gettid, f);	\
+		if (i == tid)				\
+			return 0;			\
+		switch ((unsigned int) tid & 3) {	\
+			case 0:				\
+				i += f0(tid, f);	\
+				break;			\
+			case 1:				\
+				i += f1(tid, f);	\
+				break;			\
+			case 2:				\
+				i += f2(tid, f);	\
+				break;			\
+			case 3:				\
+				i += f3(tid, f);	\
+				break;			\
+		}					\
+	} while (0)
diff -pruN 5.5-3/tests/status-failed-long.c 5.9-0ubuntu2/tests/status-failed-long.c
--- 5.5-3/tests/status-failed-long.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/status-failed-long.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1 @@
+#include "status-failed.c"
diff -pruN 5.5-3/tests/status-failed-long.gen.test 5.9-0ubuntu2/tests/status-failed-long.gen.test
--- 5.5-3/tests/status-failed-long.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/status-failed-long.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (status-failed-long -a10 -e trace=chdir --failed-only); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a10 -e trace=chdir --failed-only
diff -pruN 5.5-3/tests/status-failed-status.c 5.9-0ubuntu2/tests/status-failed-status.c
--- 5.5-3/tests/status-failed-status.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/status-failed-status.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1 @@
+#include "status-failed.c"
diff -pruN 5.5-3/tests/status-failed-status.gen.test 5.9-0ubuntu2/tests/status-failed-status.gen.test
--- 5.5-3/tests/status-failed-status.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/status-failed-status.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (status-failed-status -a10 -e trace=chdir -e status=failed); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a10 -e trace=chdir -e status=failed
diff -pruN 5.5-3/tests/status-successful-long.c 5.9-0ubuntu2/tests/status-successful-long.c
--- 5.5-3/tests/status-successful-long.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/status-successful-long.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1 @@
+#include "status-successful.c"
diff -pruN 5.5-3/tests/status-successful-long.gen.test 5.9-0ubuntu2/tests/status-successful-long.gen.test
--- 5.5-3/tests/status-successful-long.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/status-successful-long.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (status-successful-long -a10 -e trace=chdir --successful-only); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a10 -e trace=chdir --successful-only
diff -pruN 5.5-3/tests/status-successful-status.c 5.9-0ubuntu2/tests/status-successful-status.c
--- 5.5-3/tests/status-successful-status.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/status-successful-status.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1 @@
+#include "status-successful.c"
diff -pruN 5.5-3/tests/status-successful-status.gen.test 5.9-0ubuntu2/tests/status-successful-status.gen.test
--- 5.5-3/tests/status-successful-status.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/status-successful-status.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (status-successful-status -a10 -e trace=chdir --status=successful); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a10 -e trace=chdir --status=successful
diff -pruN 5.5-3/tests/strace--absolute-timestamps-format-time.gen.test 5.9-0ubuntu2/tests/strace--absolute-timestamps-format-time.gen.test
--- 5.5-3/tests/strace--absolute-timestamps-format-time.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--absolute-timestamps-format-time.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-time +strace-t.test --absolute-timestamps=format:time); do not edit.
+set -- --absolute-timestamps=format:time
+. "${srcdir=.}/strace-t.test"
diff -pruN 5.5-3/tests/strace--absolute-timestamps-format-time-precision-ms.gen.test 5.9-0ubuntu2/tests/strace--absolute-timestamps-format-time-precision-ms.gen.test
--- 5.5-3/tests/strace--absolute-timestamps-format-time-precision-ms.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--absolute-timestamps-format-time-precision-ms.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-time-precision-ms +strace-tt.test 3 --absolute-timestamps=format:time --absolute-timestamps=precision:ms); do not edit.
+set -- 3 --absolute-timestamps=format:time --absolute-timestamps=precision:ms
+. "${srcdir=.}/strace-tt.test"
diff -pruN 5.5-3/tests/strace--absolute-timestamps-format-time-precision-ns.gen.test 5.9-0ubuntu2/tests/strace--absolute-timestamps-format-time-precision-ns.gen.test
--- 5.5-3/tests/strace--absolute-timestamps-format-time-precision-ns.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--absolute-timestamps-format-time-precision-ns.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-time-precision-ns +strace-tt.test 9 --absolute-timestamps=format:time --absolute-timestamps=precision:ns); do not edit.
+set -- 9 --absolute-timestamps=format:time --absolute-timestamps=precision:ns
+. "${srcdir=.}/strace-tt.test"
diff -pruN 5.5-3/tests/strace--absolute-timestamps-format-time-precision-s.gen.test 5.9-0ubuntu2/tests/strace--absolute-timestamps-format-time-precision-s.gen.test
--- 5.5-3/tests/strace--absolute-timestamps-format-time-precision-s.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--absolute-timestamps-format-time-precision-s.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-time-precision-s +strace-t.test --absolute-timestamps=format:time --absolute-timestamps=precision:s); do not edit.
+set -- --absolute-timestamps=format:time --absolute-timestamps=precision:s
+. "${srcdir=.}/strace-t.test"
diff -pruN 5.5-3/tests/strace--absolute-timestamps-format-time-precision-us.gen.test 5.9-0ubuntu2/tests/strace--absolute-timestamps-format-time-precision-us.gen.test
--- 5.5-3/tests/strace--absolute-timestamps-format-time-precision-us.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--absolute-timestamps-format-time-precision-us.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-time-precision-us +strace-tt.test 6 --absolute-timestamps=format:time --absolute-timestamps=precision:us); do not edit.
+set -- 6 --absolute-timestamps=format:time --absolute-timestamps=precision:us
+. "${srcdir=.}/strace-tt.test"
diff -pruN 5.5-3/tests/strace--absolute-timestamps-format-unix-precision-ms.gen.test 5.9-0ubuntu2/tests/strace--absolute-timestamps-format-unix-precision-ms.gen.test
--- 5.5-3/tests/strace--absolute-timestamps-format-unix-precision-ms.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--absolute-timestamps-format-unix-precision-ms.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-unix-precision-ms +strace-ttt.test 3 --absolute-timestamps=precision:ms --absolute-timestamps=format:unix); do not edit.
+set -- 3 --absolute-timestamps=precision:ms --absolute-timestamps=format:unix
+. "${srcdir=.}/strace-ttt.test"
diff -pruN 5.5-3/tests/strace--absolute-timestamps-format-unix-precision-ns.gen.test 5.9-0ubuntu2/tests/strace--absolute-timestamps-format-unix-precision-ns.gen.test
--- 5.5-3/tests/strace--absolute-timestamps-format-unix-precision-ns.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--absolute-timestamps-format-unix-precision-ns.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-unix-precision-ns +strace-ttt.test 9 --absolute-timestamps=format:unix --absolute-timestamps=precision:ns); do not edit.
+set -- 9 --absolute-timestamps=format:unix --absolute-timestamps=precision:ns
+. "${srcdir=.}/strace-ttt.test"
diff -pruN 5.5-3/tests/strace--absolute-timestamps-format-unix-precision-s.gen.test 5.9-0ubuntu2/tests/strace--absolute-timestamps-format-unix-precision-s.gen.test
--- 5.5-3/tests/strace--absolute-timestamps-format-unix-precision-s.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--absolute-timestamps-format-unix-precision-s.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-unix-precision-s +strace-ttt.test 0 --absolute-timestamps=format:unix --absolute-timestamps=precision:s); do not edit.
+set -- 0 --absolute-timestamps=format:unix --absolute-timestamps=precision:s
+. "${srcdir=.}/strace-ttt.test"
diff -pruN 5.5-3/tests/strace--absolute-timestamps-format-unix-precision-us.gen.test 5.9-0ubuntu2/tests/strace--absolute-timestamps-format-unix-precision-us.gen.test
--- 5.5-3/tests/strace--absolute-timestamps-format-unix-precision-us.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--absolute-timestamps-format-unix-precision-us.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-unix-precision-us +strace-ttt.test 6 --absolute-timestamps=precision:us --absolute-timestamps=format:unix); do not edit.
+set -- 6 --absolute-timestamps=precision:us --absolute-timestamps=format:unix
+. "${srcdir=.}/strace-ttt.test"
diff -pruN 5.5-3/tests/strace--absolute-timestamps.gen.test 5.9-0ubuntu2/tests/strace--absolute-timestamps.gen.test
--- 5.5-3/tests/strace--absolute-timestamps.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--absolute-timestamps.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps +strace-t.test --absolute-timestamps); do not edit.
+set -- --absolute-timestamps
+. "${srcdir=.}/strace-t.test"
diff -pruN 5.5-3/tests/strace-DDD.test 5.9-0ubuntu2/tests/strace-DDD.test
--- 5.5-3/tests/strace-DDD.test	2019-11-07 19:58:36.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace-DDD.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
 #
 # Check -DDD option.
 #
-# Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
+# Copyright (c) 2019-2020 Dmitry V. Levin <ldv@altlinux.org>
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,6 +10,8 @@
 . "${srcdir=.}/init.sh"
 
 check_prog sed
+run_prog_skip_if_failed \
+	kill -0 $$
 
 status_file=/proc/self/status
 [ -f "$status_file" ] ||
@@ -19,10 +21,16 @@ stat_file=/proc/self/stat
 [ -f "$stat_file" ] ||
 	framework_skip_ "$stat_file is not available"
 
+reapid="$(../get_process_reaper)" && [ "$reapid" -ge 1 ] ||
+	fail_ 'get_process_reaper failed'
+
 set -- -enone -esignal=none ../tracer_ppid_pgid_sid
 run_strace "$@" > "$OUT"
-read -r ppid pgid sid < "$OUT" &&
+read -r tracer_pid ppid pgid sid < "$OUT" &&
+[ "$tracer_pid" -gt 1 ] &&
+[ "$tracer_pid" -ne "$reapid" ] &&
 [ "$ppid" -gt 1 ] &&
+[ "$ppid" -ne "$reapid" ] &&
 [ "$pgid" -ge 0 ] &&
 [ "$sid" -ge 0 ] || {
 	cat < "$OUT" > "$LOG"
@@ -34,35 +42,52 @@ pgid0="$pgid"
 sid0="$sid"
 
 run_strace -D "$@" > "$OUT"
-read -r ppid pgid sid < "$OUT" &&
-[ "$ppid" -eq 1 ] &&
+read -r tracer_pid ppid pgid sid < "$OUT" &&
+[ "$tracer_pid" -gt 1 ] &&
+[ "$tracer_pid" -ne "$reapid" ] &&
+[ "$ppid" -eq "$reapid" ] &&
 [ "$pgid" = "$pgid0" ] &&
 [ "$sid" = "$sid0" ] || {
 	cat < "$OUT" > "$LOG"
 	dump_log_and_fail_with "$STRACE $args: unexpected output"
 }
+while kill -0 "$tracer_pid" 2> /dev/null; do
+	$SLEEP_A_BIT
+done
 match_diff
 
 run_strace -DD "$@" > "$OUT"
-read -r ppid pgid sid < "$OUT" &&
-[ "$ppid" -eq 1 ] &&
+read -r tracer_pid ppid pgid sid < "$OUT" &&
+[ "$tracer_pid" -gt 1 ] &&
+[ "$tracer_pid" -ne "$reapid" ] &&
+[ "$ppid" -eq "$reapid" ] &&
 [ "$pgid" -gt 1 ] &&
+[ "$pgid" -ne "$reapid" ] &&
 [ "$pgid" != "$pgid0" ] &&
 [ "$pgid" != "$sid" ] &&
 [ "$sid" = "$sid0" ] || {
 	cat < "$OUT" > "$LOG"
 	dump_log_and_fail_with "$STRACE $args: unexpected output"
 }
+while kill -0 "$tracer_pid" 2> /dev/null; do
+	$SLEEP_A_BIT
+done
 match_diff
 
 run_strace -DDD "$@" > "$OUT"
-read -r ppid pgid sid < "$OUT" &&
-[ "$ppid" -eq 1 ] &&
+read -r tracer_pid ppid pgid sid < "$OUT" &&
+[ "$tracer_pid" -gt 1 ] &&
+[ "$tracer_pid" -ne "$reapid" ] &&
+[ "$ppid" -eq "$reapid" ] &&
 [ "$pgid" -gt 1 ] &&
+[ "$pgid" -ne "$reapid" ] &&
 [ "$pgid" != "$pgid0" ] &&
 [ "$sid" = "$pgid" ] &&
 [ "$sid" != "$sid0" ] || {
 	cat < "$OUT" > "$LOG"
 	dump_log_and_fail_with "$STRACE $args: unexpected output"
 }
+while kill -0 "$tracer_pid" 2> /dev/null; do
+	$SLEEP_A_BIT
+done
 match_diff
diff -pruN 5.5-3/tests/strace-DD.expected 5.9-0ubuntu2/tests/strace-DD.expected
--- 5.5-3/tests/strace-DD.expected	2019-10-07 11:33:37.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace-DD.expected	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-nanosleep({tv_sec=2, tv_nsec=0}, NULL)  = ? ERESTART_RESTARTBLOCK (Interrupted by signal)
diff -pruN 5.5-3/tests/strace-DD.test 5.9-0ubuntu2/tests/strace-DD.test
--- 5.5-3/tests/strace-DD.test	2019-11-19 23:17:53.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace-DD.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
 #
 # Check -DD option.
 #
-# Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
+# Copyright (c) 2019-2020 Dmitry V. Levin <ldv@altlinux.org>
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -12,27 +12,62 @@
 [ "$STRACE" = "$STRACE_EXE" ] ||
 	skip_ 'Not applicable: $STRACE != $STRACE_EXE'
 
-check_prog timeout
+run_prog_skip_if_failed \
+        kill -0 $$
+
+status_file=/proc/self/status
+get_tracer_pid()
+{
+	sed '/^TracerPid:[[:space:]]*/!d;s///' "$@"
+}
+[ "$(get_tracer_pid "$status_file")" -ge 0 ] ||
+        framework_skip_ "$status_file is not available"
+
 run_prog ../sleep 0
 
+sleep_duration="$(($TIMEOUT_DURATION/2))"
+
 test_D()
 {
-	local exp args
-	exp="$1"; shift
+	local tracee_pid tracer_pid rc sig=15
 
-	set -- -e signal=none -e trace=nanosleep "$@" ../sleep 2
-	args="$*"
-	set -- timeout -s XCPU 1 $STRACE -o "$LOG" "$@"
+	set -- $STRACE --output="$LOG" --columns=39 \
+		--interruptible=anywhere --trace=nanosleep "$@" -- \
+		../sleep "$sleep_duration"
 	> "$LOG"
-	"$@" && rc=0 || rc=$?
-	[ "$rc" = 124 ] ||
-		dump_log_and_fail_with \
-			"$* failed with unexpected exit code $rc"
+
+	../setpgrp-exec "$@" &
+	tracee_pid=$!
+
+	while tracer_pid="$(get_tracer_pid "/proc/$tracee_pid/status")"; do
+		[ "$tracer_pid" = 0 ] ||
+			break
+		$SLEEP_A_BIT
+	done
+
 	$SLEEP_A_BIT
-	match_diff "$LOG" "$exp"
+	kill -$sig -$tracee_pid
+
+	wait $tracee_pid && rc=0 || rc=$?
+	[ "$rc" -eq $((128 + $sig)) ] ||
+		dump_log_and_fail_with \
+			"$* failed with unexpected exit status $rc"
+
+	while kill -0 "$tracer_pid" 2> /dev/null; do
+		$SLEEP_A_BIT
+	done
+	match_diff "$LOG" "$EXP"
 }
 
-printf %s 'nanosleep({tv_sec=2, tv_nsec=0}, ' > "$EXP"
-test_D "$EXP" -D
-test_D "$srcdir/$NAME.expected" -DD
-test_D "$srcdir/$NAME.expected" -DDD
+printf 'nanosleep({tv_sec=%s, tv_nsec=0}, ' "$sleep_duration" > "$EXP"
+test_D -D
+
+uid="${UID:-`id -u`}"
+cat > "$EXP" <<__EOF__
+nanosleep({tv_sec=$sleep_duration, tv_nsec=0}, NULL) = ? ERESTART_RESTARTBLOCK (Interrupted by signal)
+--- SIGTERM {si_signo=SIGTERM, si_code=SI_USER, si_pid=$$, si_uid=$uid} ---
++++ killed by SIGTERM +++
+__EOF__
+
+test_D -DD
+test_D -DDD
diff -pruN 5.5-3/tests/strace-D.test 5.9-0ubuntu2/tests/strace-D.test
--- 5.5-3/tests/strace-D.test	2019-10-21 00:07:20.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace-D.test	2020-05-27 08:00:00.000000000 +0000
@@ -3,6 +3,7 @@
 # Check -D option.
 #
 # Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
+# Copyright (c) 2019-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,6 +11,8 @@
 . "${srcdir=.}/init.sh"
 
 check_prog sed
+run_prog_skip_if_failed \
+	kill -0 $$
 
 get_parent_pid()
 {
@@ -21,11 +24,7 @@ get_tracer_pid()
 	sed '/^TracerPid:[[:space:]]*/!d;s///'
 }
 
-status_file=/proc/self/status
-[ -f "$status_file" ] ||
-	framework_skip_ "$status_file is not available"
-
-set -- sed -r -n '/^(P|Tracer)Pid:/p' "$status_file"
+set -- ../print_ppid_tracerpid
 "$@" > "$LOG" ||
 	framework_skip_ "$* does not work"
 
@@ -35,7 +34,7 @@ set -- sed -r -n '/^(P|Tracer)Pid:/p' "$
 	dump_log_and_fail_with "$*: unexpected output"
 
 # !-D: PPid > 0, TracerPid > 0, PPid == TracerPid
-run_strace -q -enone "$@" > "$OUT"
+run_strace -e q=attach,personality -enone "$@" > "$OUT"
 [ "$(get_parent_pid < "$OUT")" -gt 0 ] &&
 [ "$(get_tracer_pid < "$OUT")" -gt 0 ] &&
 [ "$(get_parent_pid < "$OUT")" = "$(get_tracer_pid < "$OUT")" ] || {
@@ -46,17 +45,25 @@ match_diff
 
 test_parent_tracer_pid()
 {
-	local d
+	local d parent_pid tracer_pid
 	d="$1"; shift
 
 	# -D/-DD/-DDD: PPid > 0, TracerPid > 0, PPid != TracerPid
 	run_strace $d -q -enone "$@" > "$OUT"
-	[ "$(get_parent_pid < "$OUT")" -gt 0 ] &&
-	[ "$(get_tracer_pid < "$OUT")" -gt 0 ] &&
-	[ "$(get_parent_pid < "$OUT")" != "$(get_tracer_pid < "$OUT")" ] || {
+
+	parent_pid="$(get_parent_pid < "$OUT")" &&
+	[ "$parent_pid" -gt 0 ] &&
+	tracer_pid="$(get_tracer_pid < "$OUT")" &&
+	[ "$tracer_pid" -gt 0 ] &&
+	[ "$parent_pid" != "$tracer_pid" ] || {
 		cat < "$OUT" > "$LOG"
 		dump_log_and_fail_with "$STRACE $args: unexpected output"
 	}
+
+	while kill -0 "$tracer_pid" 2> /dev/null; do
+		$SLEEP_A_BIT
+	done
+
 	match_diff
 }
 
diff -pruN 5.5-3/tests/strace-E-override.test 5.9-0ubuntu2/tests/strace-E-override.test
--- 5.5-3/tests/strace-E-override.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace-E-override.test	2020-08-03 08:00:00.000000000 +0000
@@ -0,0 +1,14 @@
+#!/bin/sh
+#
+# Check that --env option does not affect strace's own environment.
+#
+# Copyright (c) 2019-2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: GPL-2.0-or-later
+
+. "${srcdir=.}/init.sh"
+
+check_prog true
+run_prog true
+run_strace --quiet=all --trace=none --signal=none --env=PATH=/ $args
diff -pruN 5.5-3/tests/strace-E-unset.expected 5.9-0ubuntu2/tests/strace-E-unset.expected
--- 5.5-3/tests/strace-E-unset.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace-E-unset.expected	2020-04-09 12:00:00.000000000 +0000
@@ -0,0 +1,5 @@
+execve\("\.\./sleep", \["\.\./sleep", "0"\], \[.*"option_E_var=OPTION_E_VAL".*\]\) = 0
+execve\("\.\./sleep", \["\.\./sleep", "0"\], \[.*"option_E_unsets=OPTION_E_UNSETS".*\]\) = 0
+execve\("\.\./sleep", \["\.\./sleep", "0"\], \[.*"option_E_mod=OPTION_E_NEW".*\]\) = 0
+execve\("\.\./sleep", \["\.\./sleep", "0"\], \[.*"option_E_mods=OPTION_E_MODS".*\]\) = 0
+!execve\("\.\./sleep", \["\.\./sleep", "0"\], \[.*"option_E_unset=.*\]\) = 0
diff -pruN 5.5-3/tests/strace-E-unset.test 5.9-0ubuntu2/tests/strace-E-unset.test
--- 5.5-3/tests/strace-E-unset.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace-E-unset.test	2020-08-03 08:00:00.000000000 +0000
@@ -0,0 +1,32 @@
+#!/bin/sh
+#
+# Check modify/unset behaviour of -E/--env option.
+#
+# Copyright (c) 2016-2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: GPL-2.0-or-later
+
+. "${srcdir=.}/init.sh"
+
+export option_E_var=OPTION_E_VAL
+export option_E_mod=OPTION_E_MOD
+export option_E_mods=OPTION_E_MODS
+export option_E_unset=OPTION_E_UNSET
+export option_E_unsets=OPTION_E_UNSETS
+
+run_prog ../sleep 0
+run_strace -qqq -e signal=none -e trace=execve -v \
+	-E option_E_mod=OPTION_E_NEW \
+	-E option_E_unset \
+	-E option_E_missing \
+	$args
+match_grep
+
+run_prog ../sleep 0
+run_strace --quiet=all --signal=none --trace=execve --no-abbrev \
+	--env=option_E_mod=OPTION_E_NEW \
+	--env=option_E_unset \
+	--env=option_E_missing \
+	$args
+match_grep
diff -pruN 5.5-3/tests/strace-ff.test 5.9-0ubuntu2/tests/strace-ff.test
--- 5.5-3/tests/strace-ff.test	2019-11-28 19:30:05.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace-ff.test	2020-04-03 22:58:26.000000000 +0000
@@ -1,14 +1,16 @@
-#!/bin/sh
+#!/bin/sh -efu
 #
 # Check -ff option.
 #
-# Copyright (c) 2016-2019 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/init.sh"
 
+ff_opt="${*:--ff}"
+
 run_prog_skip_if_failed \
 	kill -0 $$
 
@@ -22,12 +24,13 @@ while ! [ -s "$OUT" ]; do
 		fail_ 'set_ptracer_any sleep failed'
 done
 
-run_strace -a14 -eexit_group -ff -p $tracee_pid
+run_strace --quiet=personality -a14 -eexit_group ${ff_opt} -p $tracee_pid
 
 # check that output matches
 match_diff "$LOG.$tracee_pid"
 
 # check that no other output files have been created
+set +f
 set -- "$LOG".*
 [ "$LOG.$tracee_pid" = "$*" ] ||
 	fail_ "too many output files: $*"
diff -pruN 5.5-3/tests/strace--follow-forks-output-separately.expected 5.9-0ubuntu2/tests/strace--follow-forks-output-separately.expected
--- 5.5-3/tests/strace--follow-forks-output-separately.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--follow-forks-output-separately.expected	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+exit_group(0) = ?
++++ exited with 0 +++
diff -pruN 5.5-3/tests/strace--follow-forks-output-separately.gen.test 5.9-0ubuntu2/tests/strace--follow-forks-output-separately.gen.test
--- 5.5-3/tests/strace--follow-forks-output-separately.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--follow-forks-output-separately.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--follow-forks-output-separately +strace-ff.test --follow-forks --output-separately); do not edit.
+set -- --follow-forks --output-separately
+. "${srcdir=.}/strace-ff.test"
diff -pruN 5.5-3/tests/strace-n.c 5.9-0ubuntu2/tests/strace-n.c
--- 5.5-3/tests/strace-n.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace-n.c	2020-08-21 16:39:53.000000000 +0000
@@ -0,0 +1,40 @@
+/*
+ * Test strace's -n option.
+ *
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+
+#include <stdio.h>
+#include <unistd.h>
+#include <errno.h>
+
+#define SC_listen 4
+
+int
+main(void)
+{
+	int rc;
+
+#if defined __NR_socketcall
+	if (syscall(__NR_socketcall, 0L, 0L, 0L, 0L, 0L) < 0
+		&& EINVAL == errno)
+	{
+		const long args[] = { 0, 0 };
+		rc = syscall(__NR_socketcall, SC_listen, args);
+		printf("[%4u] listen(0, 0) = %s\n", __NR_socketcall, sprintrc(rc));
+	}
+#endif
+
+#if defined __NR_listen
+	rc = syscall(__NR_listen, 0, 0);
+	printf("[%4u] listen(0, 0) = %s\n", __NR_listen, sprintrc(rc));
+#endif
+
+	return 0;
+}
diff -pruN 5.5-3/tests/strace-n.gen.test 5.9-0ubuntu2/tests/strace-n.gen.test
--- 5.5-3/tests/strace-n.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace-n.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace-n -e trace=listen -n -qq -a 12); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -e trace=listen -n -qq -a 12
diff -pruN 5.5-3/tests/strace--relative-timestamps.expected 5.9-0ubuntu2/tests/strace--relative-timestamps.expected
--- 5.5-3/tests/strace--relative-timestamps.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--relative-timestamps.expected	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+[ ]{5}0\.0{6} execve\("\.\./sleep", \["\.\./sleep", "1"\], 0x[[:xdigit:]]* /\* [[:digit:]]* vars \*/\) = 0
+[ ]{5}(1\.[01]|0\.9)[[:digit:]]{5} \+\+\+ exited with 0 \+\+\+
diff -pruN 5.5-3/tests/strace--relative-timestamps.gen.test 5.9-0ubuntu2/tests/strace--relative-timestamps.gen.test
--- 5.5-3/tests/strace--relative-timestamps.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--relative-timestamps.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--relative-timestamps +strace-r.test --relative-timestamps); do not edit.
+set -- --relative-timestamps
+. "${srcdir=.}/strace-r.test"
diff -pruN 5.5-3/tests/strace--relative-timestamps-ms.expected 5.9-0ubuntu2/tests/strace--relative-timestamps-ms.expected
--- 5.5-3/tests/strace--relative-timestamps-ms.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--relative-timestamps-ms.expected	2020-02-19 17:26:58.000000000 +0000
@@ -0,0 +1,2 @@
+[ ]{5}0\.0{3} execve\("\.\./sleep", \["\.\./sleep", "1"\], 0x[[:xdigit:]]* /\* [[:digit:]]* vars \*/\) = 0
+[ ]{5}(1\.[01]|0\.9)[[:digit:]]{2} \+\+\+ exited with 0 \+\+\+
diff -pruN 5.5-3/tests/strace--relative-timestamps-ms.gen.test 5.9-0ubuntu2/tests/strace--relative-timestamps-ms.gen.test
--- 5.5-3/tests/strace--relative-timestamps-ms.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--relative-timestamps-ms.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--relative-timestamps-ms +strace-r.test --relative-timestamps=ms); do not edit.
+set -- --relative-timestamps=ms
+. "${srcdir=.}/strace-r.test"
diff -pruN 5.5-3/tests/strace--relative-timestamps-ns.expected 5.9-0ubuntu2/tests/strace--relative-timestamps-ns.expected
--- 5.5-3/tests/strace--relative-timestamps-ns.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--relative-timestamps-ns.expected	2020-02-19 17:26:58.000000000 +0000
@@ -0,0 +1,2 @@
+[ ]{5}0\.0{9} execve\("\.\./sleep", \["\.\./sleep", "1"\], 0x[[:xdigit:]]* /\* [[:digit:]]* vars \*/\) = 0
+[ ]{5}(1\.[01]|0\.9)[[:digit:]]{8} \+\+\+ exited with 0 \+\+\+
diff -pruN 5.5-3/tests/strace--relative-timestamps-ns.gen.test 5.9-0ubuntu2/tests/strace--relative-timestamps-ns.gen.test
--- 5.5-3/tests/strace--relative-timestamps-ns.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--relative-timestamps-ns.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--relative-timestamps-ns +strace-r.test --relative-timestamps=ns); do not edit.
+set -- --relative-timestamps=ns
+. "${srcdir=.}/strace-r.test"
diff -pruN 5.5-3/tests/strace--relative-timestamps-s.expected 5.9-0ubuntu2/tests/strace--relative-timestamps-s.expected
--- 5.5-3/tests/strace--relative-timestamps-s.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--relative-timestamps-s.expected	2020-02-19 17:26:58.000000000 +0000
@@ -0,0 +1,2 @@
+[ ]{5}0 execve\("\.\./sleep", \["\.\./sleep", "1"\], 0x[[:xdigit:]]* /\* [[:digit:]]* vars \*/\) = 0
+[ ]{5}[01] \+\+\+ exited with 0 \+\+\+
diff -pruN 5.5-3/tests/strace--relative-timestamps-s.gen.test 5.9-0ubuntu2/tests/strace--relative-timestamps-s.gen.test
--- 5.5-3/tests/strace--relative-timestamps-s.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--relative-timestamps-s.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--relative-timestamps-s +strace-r.test --relative-timestamps=s); do not edit.
+set -- --relative-timestamps=s
+. "${srcdir=.}/strace-r.test"
diff -pruN 5.5-3/tests/strace--relative-timestamps-us.expected 5.9-0ubuntu2/tests/strace--relative-timestamps-us.expected
--- 5.5-3/tests/strace--relative-timestamps-us.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--relative-timestamps-us.expected	2020-02-19 17:26:58.000000000 +0000
@@ -0,0 +1,2 @@
+[ ]{5}0\.0{6} execve\("\.\./sleep", \["\.\./sleep", "1"\], 0x[[:xdigit:]]* /\* [[:digit:]]* vars \*/\) = 0
+[ ]{5}(1\.[01]|0\.9)[[:digit:]]{5} \+\+\+ exited with 0 \+\+\+
diff -pruN 5.5-3/tests/strace--relative-timestamps-us.gen.test 5.9-0ubuntu2/tests/strace--relative-timestamps-us.gen.test
--- 5.5-3/tests/strace--relative-timestamps-us.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--relative-timestamps-us.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--relative-timestamps-us +strace-r.test --relative-timestamps=us); do not edit.
+set -- --relative-timestamps=us
+. "${srcdir=.}/strace-r.test"
diff -pruN 5.5-3/tests/strace-r.test 5.9-0ubuntu2/tests/strace-r.test
--- 5.5-3/tests/strace-r.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace-r.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,13 +2,15 @@
 #
 # Check -r option.
 #
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/init.sh"
 
+r_opt="${1:--r}"
+
 run_prog ../sleep 0
-run_strace -r -eexecve ../sleep 1
+run_strace "${r_opt}" -eexecve ../sleep 1
 match_grep
diff -pruN 5.5-3/tests/strace-S.test 5.9-0ubuntu2/tests/strace-S.test
--- 5.5-3/tests/strace-S.test	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace-S.test	2020-03-23 03:19:09.000000000 +0000
@@ -35,6 +35,10 @@ for s in '' '-S time' --summary-sort-by=
 	test_c "$s" '-n -r' \
 		's/^[[:space:]]+([0-9]+)[.,]([0-9]+)[[:space:]].*/\1\t\2/p'
 done
+for s in '-S avg_time' --summary-sort-by=time_avg; do
+	test_c "$s" '-n -r' \
+		'/^[[:space:]]+[0-9]/ s/^'"$c$c$c$c"'[[:space:]].*/\3/p'
+done
 for s in '-S calls' --summary-sort-by=count; do
 	test_c "$s" '-n -r' \
 		'/^[[:space:]]+[0-9]/ s/^'"$c$c$c$c"'[[:space:]].*/\4/p'
@@ -47,3 +51,11 @@ for s in '-S error' --summary-sort-by=er
 	test_c "$s" '-n -r' \
 		'/^[[:space:]]+[0-9]/ s/^'"$c$c$c$c"'([[:space:]]+([0-9]+))?'"$c"'$/\6/p'
 done
+for s in '--summary-columns=time,time-max,name -S max_time' '-U time-percent,max_time,syscall_name --summary-sort-by=longest'; do
+	test_c "$s" '-n -r' \
+		'/^[[:space:]]+[0-9]/ s/^'"$c$c"'[[:space:]].*/\2/p'
+done
+for s in '--summary-columns=time,time_min,name -S min-time' '-U time_percent,min_time,syscall-name --summary-sort-by=shortest'; do
+	test_c "$s" '-n -r' \
+		'/^[[:space:]]+[0-9]/ s/^'"$c$c"'[[:space:]].*/\2/p'
+done
diff -pruN 5.5-3/tests/strace--strings-in-hex-all.c 5.9-0ubuntu2/tests/strace--strings-in-hex-all.c
--- 5.5-3/tests/strace--strings-in-hex-all.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--strings-in-hex-all.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define STRACE_XX 1
+#include "strace-x.c"
diff -pruN 5.5-3/tests/strace--strings-in-hex-all.gen.test 5.9-0ubuntu2/tests/strace--strings-in-hex-all.gen.test
--- 5.5-3/tests/strace--strings-in-hex-all.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--strings-in-hex-all.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--strings-in-hex-all --trace=chdir --strings-in-hex=all --columns=18); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=chdir --strings-in-hex=all --columns=18
diff -pruN 5.5-3/tests/strace--strings-in-hex.c 5.9-0ubuntu2/tests/strace--strings-in-hex.c
--- 5.5-3/tests/strace--strings-in-hex.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--strings-in-hex.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define STRACE_XX 1
+#include "strace-x.c"
diff -pruN 5.5-3/tests/strace--strings-in-hex.gen.test 5.9-0ubuntu2/tests/strace--strings-in-hex.gen.test
--- 5.5-3/tests/strace--strings-in-hex.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--strings-in-hex.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--strings-in-hex --trace=chdir --strings-in-hex --columns=18); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=chdir --strings-in-hex --columns=18
diff -pruN 5.5-3/tests/strace--strings-in-hex-non-ascii.c 5.9-0ubuntu2/tests/strace--strings-in-hex-non-ascii.c
--- 5.5-3/tests/strace--strings-in-hex-non-ascii.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--strings-in-hex-non-ascii.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define STRACE_XX 0
+#include "strace-x.c"
diff -pruN 5.5-3/tests/strace--strings-in-hex-non-ascii.gen.test 5.9-0ubuntu2/tests/strace--strings-in-hex-non-ascii.gen.test
--- 5.5-3/tests/strace--strings-in-hex-non-ascii.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--strings-in-hex-non-ascii.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--strings-in-hex-non-ascii --trace=chdir --strings-in-hex=non-ascii --columns=12); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=chdir --strings-in-hex=non-ascii --columns=12
diff -pruN 5.5-3/tests/strace--syscall-times.expected 5.9-0ubuntu2/tests/strace--syscall-times.expected
--- 5.5-3/tests/strace--syscall-times.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--syscall-times.expected	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1 @@
+nanosleep\(\{tv_sec=1, tv_nsec=0\}, NULL\) = 0 <(1\.[01]|0\.9)[[:digit:]]{5}>
diff -pruN 5.5-3/tests/strace--syscall-times.gen.test 5.9-0ubuntu2/tests/strace--syscall-times.gen.test
--- 5.5-3/tests/strace--syscall-times.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--syscall-times.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--syscall-times +strace-T.test --syscall-times); do not edit.
+set -- --syscall-times
+. "${srcdir=.}/strace-T.test"
diff -pruN 5.5-3/tests/strace--syscall-times-ms.expected 5.9-0ubuntu2/tests/strace--syscall-times-ms.expected
--- 5.5-3/tests/strace--syscall-times-ms.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--syscall-times-ms.expected	2020-02-19 17:26:58.000000000 +0000
@@ -0,0 +1 @@
+nanosleep\(\{tv_sec=1, tv_nsec=0\}, NULL\) = 0 <(1\.[01]|0\.9)[[:digit:]]{2}>
diff -pruN 5.5-3/tests/strace--syscall-times-ms.gen.test 5.9-0ubuntu2/tests/strace--syscall-times-ms.gen.test
--- 5.5-3/tests/strace--syscall-times-ms.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--syscall-times-ms.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--syscall-times-ms +strace-T.test --syscall-times=ms); do not edit.
+set -- --syscall-times=ms
+. "${srcdir=.}/strace-T.test"
diff -pruN 5.5-3/tests/strace--syscall-times-ns.expected 5.9-0ubuntu2/tests/strace--syscall-times-ns.expected
--- 5.5-3/tests/strace--syscall-times-ns.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--syscall-times-ns.expected	2020-02-19 17:26:58.000000000 +0000
@@ -0,0 +1 @@
+nanosleep\(\{tv_sec=1, tv_nsec=0\}, NULL\) = 0 <(1\.[01]|0\.9)[[:digit:]]{8}>
diff -pruN 5.5-3/tests/strace--syscall-times-ns.gen.test 5.9-0ubuntu2/tests/strace--syscall-times-ns.gen.test
--- 5.5-3/tests/strace--syscall-times-ns.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--syscall-times-ns.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--syscall-times-ns +strace-T.test --syscall-times=ns); do not edit.
+set -- --syscall-times=ns
+. "${srcdir=.}/strace-T.test"
diff -pruN 5.5-3/tests/strace--syscall-times-s.expected 5.9-0ubuntu2/tests/strace--syscall-times-s.expected
--- 5.5-3/tests/strace--syscall-times-s.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--syscall-times-s.expected	2020-02-19 17:26:58.000000000 +0000
@@ -0,0 +1 @@
+nanosleep\(\{tv_sec=1, tv_nsec=0\}, NULL\) = 0 <[01]>
diff -pruN 5.5-3/tests/strace--syscall-times-s.gen.test 5.9-0ubuntu2/tests/strace--syscall-times-s.gen.test
--- 5.5-3/tests/strace--syscall-times-s.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--syscall-times-s.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--syscall-times-s +strace-T.test --syscall-times=s); do not edit.
+set -- --syscall-times=s
+. "${srcdir=.}/strace-T.test"
diff -pruN 5.5-3/tests/strace--syscall-times-us.expected 5.9-0ubuntu2/tests/strace--syscall-times-us.expected
--- 5.5-3/tests/strace--syscall-times-us.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--syscall-times-us.expected	2020-02-19 17:26:58.000000000 +0000
@@ -0,0 +1 @@
+nanosleep\(\{tv_sec=1, tv_nsec=0\}, NULL\) = 0 <(1\.[01]|0\.9)[[:digit:]]{5}>
diff -pruN 5.5-3/tests/strace--syscall-times-us.gen.test 5.9-0ubuntu2/tests/strace--syscall-times-us.gen.test
--- 5.5-3/tests/strace--syscall-times-us.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--syscall-times-us.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--syscall-times-us +strace-T.test --syscall-times=us); do not edit.
+set -- --syscall-times=us
+. "${srcdir=.}/strace-T.test"
diff -pruN 5.5-3/tests/strace--timestamps.gen.test 5.9-0ubuntu2/tests/strace--timestamps.gen.test
--- 5.5-3/tests/strace--timestamps.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--timestamps.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps +strace-t.test --timestamps); do not edit.
+set -- --timestamps
+. "${srcdir=.}/strace-t.test"
diff -pruN 5.5-3/tests/strace--timestamps-time.gen.test 5.9-0ubuntu2/tests/strace--timestamps-time.gen.test
--- 5.5-3/tests/strace--timestamps-time.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--timestamps-time.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-time +strace-t.test --timestamps=time); do not edit.
+set -- --timestamps=time
+. "${srcdir=.}/strace-t.test"
diff -pruN 5.5-3/tests/strace--timestamps-time-ms.gen.test 5.9-0ubuntu2/tests/strace--timestamps-time-ms.gen.test
--- 5.5-3/tests/strace--timestamps-time-ms.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--timestamps-time-ms.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-time-ms +strace-tt.test 3 --timestamps=time,ms); do not edit.
+set -- 3 --timestamps=time,ms
+. "${srcdir=.}/strace-tt.test"
diff -pruN 5.5-3/tests/strace--timestamps-time-ns.gen.test 5.9-0ubuntu2/tests/strace--timestamps-time-ns.gen.test
--- 5.5-3/tests/strace--timestamps-time-ns.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--timestamps-time-ns.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-time-ns +strace-tt.test 9 --timestamps=time,ns); do not edit.
+set -- 9 --timestamps=time,ns
+. "${srcdir=.}/strace-tt.test"
diff -pruN 5.5-3/tests/strace--timestamps-time-s.gen.test 5.9-0ubuntu2/tests/strace--timestamps-time-s.gen.test
--- 5.5-3/tests/strace--timestamps-time-s.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--timestamps-time-s.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-time-s +strace-t.test --timestamps=time,s); do not edit.
+set -- --timestamps=time,s
+. "${srcdir=.}/strace-t.test"
diff -pruN 5.5-3/tests/strace--timestamps-time-us.gen.test 5.9-0ubuntu2/tests/strace--timestamps-time-us.gen.test
--- 5.5-3/tests/strace--timestamps-time-us.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--timestamps-time-us.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-time-us +strace-tt.test 6 --timestamps=time,us); do not edit.
+set -- 6 --timestamps=time,us
+. "${srcdir=.}/strace-tt.test"
diff -pruN 5.5-3/tests/strace--timestamps-unix-ms.gen.test 5.9-0ubuntu2/tests/strace--timestamps-unix-ms.gen.test
--- 5.5-3/tests/strace--timestamps-unix-ms.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--timestamps-unix-ms.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-unix-ms +strace-ttt.test 3 --timestamps=unix,ms); do not edit.
+set -- 3 --timestamps=unix,ms
+. "${srcdir=.}/strace-ttt.test"
diff -pruN 5.5-3/tests/strace--timestamps-unix-ns.gen.test 5.9-0ubuntu2/tests/strace--timestamps-unix-ns.gen.test
--- 5.5-3/tests/strace--timestamps-unix-ns.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--timestamps-unix-ns.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-unix-ns +strace-ttt.test 9 --timestamps=unix,ns); do not edit.
+set -- 9 --timestamps=unix,ns
+. "${srcdir=.}/strace-ttt.test"
diff -pruN 5.5-3/tests/strace--timestamps-unix-s.gen.test 5.9-0ubuntu2/tests/strace--timestamps-unix-s.gen.test
--- 5.5-3/tests/strace--timestamps-unix-s.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--timestamps-unix-s.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-unix-s +strace-ttt.test 0 --timestamps=unix,s); do not edit.
+set -- 0 --timestamps=unix,s
+. "${srcdir=.}/strace-ttt.test"
diff -pruN 5.5-3/tests/strace--timestamps-unix-us.gen.test 5.9-0ubuntu2/tests/strace--timestamps-unix-us.gen.test
--- 5.5-3/tests/strace--timestamps-unix-us.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace--timestamps-unix-us.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-unix-us +strace-ttt.test 6 --timestamps=unix,us); do not edit.
+set -- 6 --timestamps=unix,us
+. "${srcdir=.}/strace-ttt.test"
diff -pruN 5.5-3/tests/strace-t.test 5.9-0ubuntu2/tests/strace-t.test
--- 5.5-3/tests/strace-t.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace-t.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,19 +2,21 @@
 #
 # Check -t option.
 #
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/init.sh"
 
+opts="${*:--t}"
+
 run_prog_skip_if_failed date +%s > "$LOG"
 run_prog_skip_if_failed date +%T --date "@$(cat "$LOG")" > /dev/null
 run_prog ../sleep 0
 
 s0="$(date +%s)"
-run_strace -t -eexecve $args
+run_strace $opts -eexecve $args
 s1="$(date +%s)"
 
 s="$s0"
diff -pruN 5.5-3/tests/strace-T.test 5.9-0ubuntu2/tests/strace-T.test
--- 5.5-3/tests/strace-T.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace-T.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,13 +2,15 @@
 #
 # Check -T option.
 #
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/init.sh"
 
+T_opt="${1:--T}"
+
 run_prog ../sleep 0
-run_strace -a24 -T -enanosleep ../sleep 1
+run_strace -a24 "${T_opt}" -enanosleep ../sleep 1
 match_grep
diff -pruN 5.5-3/tests/strace-tt.test 5.9-0ubuntu2/tests/strace-tt.test
--- 5.5-3/tests/strace-tt.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace-tt.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,19 +2,23 @@
 #
 # Check -tt option.
 #
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/init.sh"
 
+precision="${1:-6}"
+[ x0 = "x$#" ] || shift
+opts="${*:--tt}"
+
 run_prog_skip_if_failed date +%s > "$LOG"
 run_prog_skip_if_failed date +%T --date "@$(cat "$LOG")" > /dev/null
 run_prog ../sleep 0
 
 s0="$(date +%s)"
-run_strace -tt -eexecve $args
+run_strace $opts -eexecve $args
 s1="$(date +%s)"
 
 s="$s0"
@@ -26,7 +30,7 @@ while [ "$s" -le "$s1" ]; do
 done
 
 cat > "$EXP" << __EOF__
-($t_reg)\\.[[:digit:]]{6} execve\\("\\.\\./sleep", \\["\\.\\./sleep", "0"\\], 0x[[:xdigit:]]* /\\* [[:digit:]]* vars \\*/\\) = 0
+($t_reg)\\.[[:digit:]]{${precision}} execve\\("\\.\\./sleep", \\["\\.\\./sleep", "0"\\], 0x[[:xdigit:]]* /\\* [[:digit:]]* vars \\*/\\) = 0
 __EOF__
 
 match_grep "$LOG" "$EXP"
diff -pruN 5.5-3/tests/strace-ttt.test 5.9-0ubuntu2/tests/strace-ttt.test
--- 5.5-3/tests/strace-ttt.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace-ttt.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,18 +2,22 @@
 #
 # Check -ttt option.
 #
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/init.sh"
 
+precision="${1:-6}"
+[ x0 = "x$#" ] || shift
+opts="${*:--ttt}"
+
 run_prog_skip_if_failed date +%s > /dev/null
 run_prog ../sleep 0
 
 s0="$(date +%s)"
-run_strace -ttt -eexecve $args
+run_strace $opts -eexecve $args
 s1="$(date +%s)"
 
 s="$s0"
@@ -23,8 +27,14 @@ while [ "$s" -le "$s1" ]; do
 	s=$(($s + 1))
 done
 
+if [ x0 = "x${precision}" ]; then
+	subsec_re=""
+else
+	subsec_re="\\.[[:digit:]]{${precision}}"
+fi
+
 cat > "$EXP" << __EOF__
-($t_reg)\\.[[:digit:]]{6} execve\\("\\.\\./sleep", \\["\\.\\./sleep", "0"\\], 0x[[:xdigit:]]* /\\* [[:digit:]]+ vars \\*/\\) = 0
+($t_reg)${subsec_re} execve\\("\\.\\./sleep", \\["\\.\\./sleep", "0"\\], 0x[[:xdigit:]]* /\\* [[:digit:]]+ vars \\*/\\) = 0
 __EOF__
 
 match_grep "$LOG" "$EXP"
diff -pruN 5.5-3/tests/strace-x.c 5.9-0ubuntu2/tests/strace-x.c
--- 5.5-3/tests/strace-x.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace-x.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,82 @@
+/*
+ * Test strace's -x option.
+ *
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+
+#include <stdio.h>
+#include <unistd.h>
+
+#ifndef STRACE_XX
+# define STRACE_XX 0
+#endif
+
+#if STRACE_XX
+# define XOUT(x_, xx_) xx_
+#else
+# define XOUT(x_, xx_) x_
+#endif
+
+int
+main(void)
+{
+	static const struct {
+		const char *path;
+		const char *out;
+	} test_vecs[] = {
+		{ "test", XOUT("test", "\\x74\\x65\\x73\\x74") },
+		{ "\t\n\v\f\r hi~", XOUT("\\t\\n\\v\\f\\r hi~",
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e") },
+		{ "\t\n\v\f\r\16 hi~", XOUT(
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x0e\\x20\\x68\\x69\\x7e",
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x0e\\x20\\x68\\x69\\x7e") },
+		{ "\10\t\n\v\f\r hi~", XOUT(
+		  "\\x08\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e",
+		  "\\x08\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e") },
+		{ "\t\n\v\f\r\37 hi~", XOUT(
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x1f\\x20\\x68\\x69\\x7e",
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x1f\\x20\\x68\\x69\\x7e") },
+		{ "\t\n\v\f\r hi~\177", XOUT(
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e\\x7f",
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e\\x7f") },
+		{ "\t\n\v\f\r hi~\222", XOUT(
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e\\x92",
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e\\x92") },
+		{ "\t\n\v\f\r hi~\377", XOUT(
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e\\xff",
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e\\xff") },
+	};
+	static char path[] = "  ";
+
+	const char *rc_str;
+
+	for (size_t i = 0; i < ARRAY_SIZE(test_vecs); i++) {
+		rc_str = sprintrc(chdir(test_vecs[i].path));
+		printf("chdir(\"%s\") = %s\n", test_vecs[i].out, rc_str);
+	}
+
+	for (unsigned char c = 1; c < 255; c++) {
+		path[1] = c;
+		rc_str = sprintrc(chdir(path));
+
+		printf("chdir(");
+#if STRACE_XX
+		print_quoted_hex(path, sizeof(path) - 1);
+#else
+		if (((c < ' ') || (c >= 0x7f)) && (c != '\t') && (c != '\n') &&
+		    (c != '\v') && (c != '\f') && (c != '\r'))
+			print_quoted_hex(path, sizeof(path) - 1);
+		else
+			print_quoted_string(path);
+#endif
+		printf(") = %s\n", rc_str);
+	}
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
diff -pruN 5.5-3/tests/strace-x.gen.test 5.9-0ubuntu2/tests/strace-x.gen.test
--- 5.5-3/tests/strace-x.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace-x.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace-x -e trace=chdir -x -a 12); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -e trace=chdir -x -a 12
diff -pruN 5.5-3/tests/strace-xx.c 5.9-0ubuntu2/tests/strace-xx.c
--- 5.5-3/tests/strace-xx.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace-xx.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define STRACE_XX 1
+#include "strace-x.c"
diff -pruN 5.5-3/tests/strace-xx.gen.test 5.9-0ubuntu2/tests/strace-xx.gen.test
--- 5.5-3/tests/strace-xx.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/strace-xx.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace-xx -e trace=chdir -xx -a 18); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -e trace=chdir -xx -a 18
diff -pruN 5.5-3/tests/syntax.sh 5.9-0ubuntu2/tests/syntax.sh
--- 5.5-3/tests/syntax.sh	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests/syntax.sh	2020-02-24 13:08:32.000000000 +0000
@@ -10,45 +10,62 @@
 
 . "${srcdir=.}/init.sh"
 
+log_sfx()
+{
+	printf "%.128s" "$*" | tr -c '0-9A-Za-z-=,' '_'
+}
+
 check_exit_status_and_stderr()
 {
-	$STRACE "$@" 2> "$LOG" &&
-		dump_log_and_fail_with \
-			"strace $* failed to handle the error properly"
-	match_diff "$LOG" "$EXP" \
+	local sfx
+	sfx="$1"; shift
+	$STRACE "$@" 2> "$LOG.$sfx" && {
+		cat "$LOG.$sfx" >&2
+		fail_ "strace $* failed to handle the error properly"
+	}
+	match_diff "$LOG.$sfx" "$EXP.$sfx" \
 		"strace $* failed to print expected diagnostics"
 }
 
 check_exit_status_and_stderr_using_grep()
 {
-	$STRACE "$@" 2> "$LOG" &&
-		dump_log_and_fail_with \
-			"strace $* failed to handle the error properly"
-	match_grep "$LOG" "$EXP" \
+	local sfx
+	sfx="$1"; shift
+	$STRACE "$@" 2> "$LOG.$sfx" && {
+		cat "$LOG.$sfx" >&2
+		fail_ "strace $* failed to handle the error properly"
+	}
+	match_grep "$LOG.$sfx" "$EXP.$sfx" \
 		"strace $* failed to print expected diagnostics"
 }
 
 check_e()
 {
-	local pattern="$1"; shift
-	cat > "$EXP" << __EOF__
+	local pattern sfx
+	pattern="$1"; shift
+	sfx="$(log_sfx "$*")"
+	cat > "$EXP.$sfx" << __EOF__
 $STRACE_EXE: $pattern
 __EOF__
-	check_exit_status_and_stderr "$@"
+	check_exit_status_and_stderr "$sfx" "$@"
 }
 
 check_e_using_grep()
 {
-	local pattern="$1"; shift
-	cat > "$EXP" << __EOF__
+	local pattern sfx
+	pattern="$1"; shift
+	sfx="$(log_sfx "$*")"
+	cat > "$EXP.$sfx" << __EOF__
 $STRACE_EXE: $pattern
 __EOF__
-	check_exit_status_and_stderr_using_grep "$@"
+	check_exit_status_and_stderr_using_grep "$sfx" "$@"
 }
 
 check_h()
 {
-	local patterns="$1"; shift
+	local patterns sfx
+	patterns="$1"; shift
+	sfx="$(log_sfx "$*")"
 	{
 		local pattern
 		printf '%s\n' "$patterns" |
@@ -56,6 +73,6 @@ check_h()
 				printf '%s: %s\n' "$STRACE_EXE" "$pattern"
 			done
 		printf "Try '%s -h' for more information.\\n" "$STRACE_EXE"
-	} > "$EXP"
-	check_exit_status_and_stderr "$@"
+	} > "$EXP.$sfx"
+	check_exit_status_and_stderr "$sfx" "$@"
 }
diff -pruN 5.5-3/tests/test_nlattr.h 5.9-0ubuntu2/tests/test_nlattr.h
--- 5.5-3/tests/test_nlattr.h	2019-11-28 19:30:05.000000000 +0000
+++ 5.9-0ubuntu2/tests/test_nlattr.h	2020-06-01 14:15:16.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -15,6 +15,10 @@
 #include "netlink.h"
 #include <linux/rtnetlink.h>
 
+#ifndef PRINT_SOCK
+# define PRINT_SOCK 0
+#endif
+
 static void
 init_nlattr(struct nlattr *const nla,
 	    const uint16_t nla_len,
@@ -37,6 +41,29 @@ print_nlattr(const unsigned int nla_len,
 	       add_data ? "[" : "", nla_len, nla_type);
 }
 
+static void
+print_sockfd(int sockfd, const char *pfx, const char *sfx)
+{
+#if PRINT_SOCK
+	static int fd = -1;
+	static unsigned long inode;
+
+	if (sockfd < 0) {
+		printf("%s%d%s", pfx, sockfd, sfx);
+		return;
+	}
+
+	if (sockfd != fd) {
+		fd = sockfd;
+		inode = inode_of_sockfd(fd);
+	}
+
+	printf("%s%d<socket:[%lu]>%s", pfx, sockfd, inode, sfx);
+#else
+	printf("%s%d%s", pfx, sockfd, sfx);
+#endif
+}
+
 #define TEST_NLATTR_EX_(fd_, nlh0_, hdrlen_,				\
 		     init_msg_, print_msg_,				\
 		     nla_type_, nla_type_str_,				\
@@ -60,7 +87,7 @@ print_nlattr(const unsigned int nla_len,
 			sprintrc(sendto((fd_), nlh, msg_len,		\
 					MSG_DONTWAIT, NULL, 0));	\
 									\
-		printf("sendto(%d, {", (fd_));				\
+		print_sockfd((fd_), "sendto(", ", {");			\
 		(print_msg_)(msg_len);					\
 		print_nlattr(nla_len, (nla_type_str_),			\
 			     (nla_total_len_) > (nla_data_len_));	\
diff -pruN 5.5-3/tests/tests.h 5.9-0ubuntu2/tests/tests.h
--- 5.5-3/tests/tests.h	2019-12-15 16:29:06.000000000 +0000
+++ 5.9-0ubuntu2/tests/tests.h	2020-04-17 20:43:15.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -24,6 +24,7 @@
 # endif
 
 # include <stdbool.h>
+# include <stdint.h>
 # include <sys/types.h>
 # include "kernel_types.h"
 # include "gcc_compat.h"
@@ -55,21 +56,67 @@
 # if XLAT_RAW
 #  define XLAT_KNOWN(val_, str_) STRINGIFY_VAL(val_)
 #  define XLAT_UNKNOWN(val_, dflt_) STRINGIFY_VAL(val_)
+
+#  define XLAT_FMT "%#x"
+#  define XLAT_ARGS(a_) (a_)
+#  define XLAT_SEL(v_, s_) v_
+
+#  define ABBR(s_) ""
+#  define RAW(s_) s_
+#  define VERB(s_) ""
+#  define NABBR(s_) s_
+#  define NRAW(s_) ""
+#  define NVERB(s_) s_
 # elif XLAT_VERBOSE
 #  define XLAT_KNOWN(val_, str_) STRINGIFY_VAL(val_) " /* " str_ " */"
 #  define XLAT_UNKNOWN(val_, dflt_) STRINGIFY_VAL(val_) " /* " dflt_ " */"
-# else
+
+#  define XLAT_FMT "%#x /* %s */"
+#  define XLAT_ARGS(a_) a_, #a_
+#  define XLAT_SEL(v_, s_) v_, s_
+
+#  define ABBR(s_) ""
+#  define RAW(s_) ""
+#  define VERB(s_) s_
+#  define NABBR(s_) s_
+#  define NRAW(s_) s_
+#  define NVERB(s_) ""
+# else /* !XLAT_RAW && !XLAT_VERBOSE */
 #  define XLAT_KNOWN(val_, str_) str_
 #  define XLAT_UNKNOWN(val_, dflt_) STRINGIFY_VAL(val_) " /* " dflt_ " */"
-# endif
+
+#  define XLAT_FMT "%s"
+#  define XLAT_ARGS(a_) #a_
+#  define XLAT_SEL(v_, s_) s_
+
+#  define ABBR(s_) s_
+#  define RAW(s_) ""
+#  define VERB(s_) ""
+#  define NABBR(s_) ""
+#  define NRAW(s_) s_
+#  define NVERB(s_) s_
+# endif /* XLAT_RAW, XLAT_VERBOSE */
 
 # define XLAT_STR(v_) sprintxlat(#v_, v_, NULL)
 
+# define ARG_XLAT_KNOWN(val_, str_) val_, XLAT_KNOWN(val_, str_)
+# define ARG_XLAT_UNKNOWN(val_, str_) val_, XLAT_UNKNOWN(val_, str_)
+
 # ifndef DEFAULT_STRLEN
 /* Default maximum # of bytes printed in printstr et al. */
 #  define DEFAULT_STRLEN 32
 # endif
 
+struct strval32 {
+	uint32_t val;
+	const char *str;
+};
+
+struct strval64 {
+	uint64_t val;
+	const char *str;
+};
+
 /* Cached sysconf(_SC_PAGESIZE). */
 size_t get_page_size(void);
 
@@ -137,15 +184,26 @@ void *tail_memdup(const void *, const si
 # define TAIL_ALLOC_OBJECT_VAR_PTR(type_name, type_ptr)		\
 	type_name *type_ptr = tail_alloc(sizeof(*type_ptr))
 
-/*
+/**
  * Fill memory (pointed by ptr, having size bytes) with different bytes (with
  * values starting with start and resetting every period) in order to catch
  * sign, byte order and/or alignment errors.
  */
 void fill_memory_ex(void *ptr, size_t size, unsigned char start,
 		    unsigned int period);
-/* Shortcut for fill_memory_ex(ptr, size, 0x80, 0x80) */
+/** Shortcut for fill_memory_ex(ptr, size, 0x80, 0x80) */
 void fill_memory(void *ptr, size_t size);
+/** Variant of fill_memory_ex for arrays of 16-bit (2-byte) values. */
+void fill_memory16_ex(void *ptr, size_t size, uint16_t start,
+		      unsigned int period);
+/** Shortcut for fill_memory16_ex(ptr, size, 0x80c0, 0x8000) */
+void fill_memory16(void *ptr, size_t size);
+/** Variant of fill_memory_ex for arrays of 32-bit (4-byte) values. */
+void fill_memory32_ex(void *ptr, size_t size, uint32_t start,
+		      unsigned int period);
+/** Shortcut for fill_memory32_ex(ptr, size, 0x80a0c0e0, 0x80000000) */
+void fill_memory32(void *ptr, size_t size);
+
 
 /* Close stdin, move stdout to a non-standard descriptor, and print. */
 void tprintf(const char *, ...)
@@ -276,6 +334,9 @@ int send_mmsg(int, struct mmsghdr *, uns
 int create_nl_socket_ext(int proto, const char *name);
 # define create_nl_socket(proto)	create_nl_socket_ext((proto), #proto)
 
+/* Create a temporary file in the current directory. */
+int create_tmpfile(unsigned int flags);
+
 /* Create a pipe with maximized descriptor numbers. */
 void pipe_maxfd(int pipefd[2]);
 
diff -pruN 5.5-3/tests/tgkill.c 5.9-0ubuntu2/tests/tgkill.c
--- 5.5-3/tests/tgkill.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/tgkill.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,88 @@
+/*
+ * Check decoding of tgkill syscall.
+ *
+ * Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+#include "pidns.h"
+
+#ifdef __NR_tgkill
+
+# include <signal.h>
+# include <stdio.h>
+# include <unistd.h>
+
+static const char *errstr;
+
+static long
+k_tgkill(const unsigned int tgid,
+	 const unsigned int tid,
+	 const unsigned int sig)
+{
+        const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+        const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+        const kernel_ulong_t arg1 = fill | tgid;
+        const kernel_ulong_t arg2 = fill | tid;
+        const kernel_ulong_t arg3 = fill | sig;
+        const long rc = syscall(__NR_tgkill, arg1, arg2, arg3, bad, bad, bad);
+        errstr = sprintrc(rc);
+        return rc;
+}
+
+int
+main(void)
+{
+	PIDNS_TEST_INIT;
+
+	const int pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
+	const int tid = syscall(__NR_gettid);
+	const char *tid_str = pidns_pid2str(PT_TID);
+	const int bad_pid = -1;
+	const int bad_sig = 0xface;
+
+	k_tgkill(pid, tid, 0);
+	pidns_print_leader();
+	printf("tgkill(%d%s, %d%s, 0) = %s\n",
+		pid, pid_str, tid, tid_str, errstr);
+
+	k_tgkill(pid, bad_pid, 0);
+	pidns_print_leader();
+	printf("tgkill(%d%s, %d, 0) = %s\n",
+		pid, pid_str, bad_pid, errstr);
+
+	k_tgkill(bad_pid, tid, 0);
+	pidns_print_leader();
+	printf("tgkill(%d, %d%s, 0) = %s\n",
+		bad_pid, tid, tid_str, errstr);
+
+	k_tgkill(pid, tid, SIGCONT);
+	pidns_print_leader();
+	printf("tgkill(%d%s, %d%s, SIGCONT) = %s\n",
+		pid, pid_str, tid, tid_str, errstr);
+
+	k_tgkill(pid, tid, bad_sig);
+	pidns_print_leader();
+	printf("tgkill(%d%s, %d%s, %d) = %s\n",
+		pid, pid_str, tid, tid_str, bad_sig, errstr);
+
+	k_tgkill(pid, tid, -bad_sig);
+	pidns_print_leader();
+	printf("tgkill(%d%s, %d%s, %d) = %s\n",
+		pid, pid_str, tid, tid_str, -bad_sig, errstr);
+
+	pidns_print_leader();
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_tgkill")
+
+#endif
diff -pruN 5.5-3/tests/tgkill.gen.test 5.9-0ubuntu2/tests/tgkill.gen.test
--- 5.5-3/tests/tgkill.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/tgkill.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (tgkill -a15 --signal='!cont'); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a15 --signal='!cont'
diff -pruN 5.5-3/tests/tgkill--pidns-translation.c 5.9-0ubuntu2/tests/tgkill--pidns-translation.c
--- 5.5-3/tests/tgkill--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/tgkill--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "tgkill.c"
diff -pruN 5.5-3/tests/tgkill--pidns-translation.gen.test 5.9-0ubuntu2/tests/tgkill--pidns-translation.gen.test
--- 5.5-3/tests/tgkill--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/tgkill--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (tgkill--pidns-translation test_pidns -a15 --signal='!cont' -e trace=tgkill); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a15 --signal='!cont' -e trace=tgkill
diff -pruN 5.5-3/tests/threads-execve.c 5.9-0ubuntu2/tests/threads-execve.c
--- 5.5-3/tests/threads-execve.c	2019-11-19 23:17:53.000000000 +0000
+++ 5.9-0ubuntu2/tests/threads-execve.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of threads when a non-leader thread invokes execve.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -23,6 +23,13 @@
 
 # include "kernel_old_timespec.h"
 
+# ifndef PRINT_EXITED
+#  define PRINT_EXITED 1
+# endif
+# ifndef PRINT_SUPERSEDED
+#  define PRINT_SUPERSEDED 1
+# endif
+
 static pid_t leader;
 static pid_t tid;
 
@@ -145,10 +152,10 @@ thread(void *arg)
 			break;
 	}
 
-	printf("%-5d +++ superseded by execve in pid %u +++\n"
-	       "%-5d <... execve resumed>) = 0\n",
-	       leader, tid,
-	       leader);
+# if PRINT_SUPERSEDED
+	printf("%-5d +++ superseded by execve in pid %u +++\n", leader, tid);
+# endif
+	printf("%-5d <... execve resumed>) = 0\n", leader);
 
 	(void) syscall(__NR_nanosleep, (unsigned long) &ots, 0UL);
 	execve(argv[0], argv, environ);
@@ -183,7 +190,9 @@ main(int ac, char **av)
 	action = atoi(av[2]);
 
 	if (action >= NUMBER_OF_ACTIONS * NUMBER_OF_ITERATIONS) {
+# if PRINT_EXITED
 		printf("%-5d +++ exited with 0 +++\n", leader);
+# endif
 		return 0;
 	}
 
diff -pruN 5.5-3/tests/threads-execve-q.c 5.9-0ubuntu2/tests/threads-execve-q.c
--- 5.5-3/tests/threads-execve-q.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/threads-execve-q.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1 @@
+#include "threads-execve.c"
diff -pruN 5.5-3/tests/threads-execve-q.gen.test 5.9-0ubuntu2/tests/threads-execve-q.gen.test
--- 5.5-3/tests/threads-execve-q.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/threads-execve-q.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (threads-execve-q +threads-execve.test -q); do not edit.
+set -- -q
+. "${srcdir=.}/threads-execve.test"
diff -pruN 5.5-3/tests/threads-execve-qq.c 5.9-0ubuntu2/tests/threads-execve-qq.c
--- 5.5-3/tests/threads-execve-qq.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/threads-execve-qq.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_EXITED 0
+#include "threads-execve.c"
diff -pruN 5.5-3/tests/threads-execve-qq.gen.test 5.9-0ubuntu2/tests/threads-execve-qq.gen.test
--- 5.5-3/tests/threads-execve-qq.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/threads-execve-qq.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (threads-execve-qq +threads-execve.test -qq); do not edit.
+set -- -qq
+. "${srcdir=.}/threads-execve.test"
diff -pruN 5.5-3/tests/threads-execve-qqq.c 5.9-0ubuntu2/tests/threads-execve-qqq.c
--- 5.5-3/tests/threads-execve-qqq.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/threads-execve-qqq.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,3 @@
+#define PRINT_SUPERSEDED 0
+#define PRINT_EXITED 0
+#include "threads-execve.c"
diff -pruN 5.5-3/tests/threads-execve-qqq.gen.test 5.9-0ubuntu2/tests/threads-execve-qqq.gen.test
--- 5.5-3/tests/threads-execve-qqq.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/threads-execve-qqq.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (threads-execve-qqq +threads-execve.test -qqq); do not edit.
+set -- -qqq
+. "${srcdir=.}/threads-execve.test"
diff -pruN 5.5-3/tests/threads-execve--quiet-thread-execve.c 5.9-0ubuntu2/tests/threads-execve--quiet-thread-execve.c
--- 5.5-3/tests/threads-execve--quiet-thread-execve.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/threads-execve--quiet-thread-execve.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_SUPERSEDED 0
+#include "threads-execve.c"
diff -pruN 5.5-3/tests/threads-execve--quiet-thread-execve.gen.test 5.9-0ubuntu2/tests/threads-execve--quiet-thread-execve.gen.test
--- 5.5-3/tests/threads-execve--quiet-thread-execve.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/threads-execve--quiet-thread-execve.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (threads-execve--quiet-thread-execve +threads-execve.test -s40 --quiet=personality,thread-execve); do not edit.
+set -- -s40 --quiet=personality,thread-execve
+. "${srcdir=.}/threads-execve.test"
diff -pruN 5.5-3/tests/threads-execve.test 5.9-0ubuntu2/tests/threads-execve.test
--- 5.5-3/tests/threads-execve.test	2019-10-28 19:52:59.000000000 +0000
+++ 5.9-0ubuntu2/tests/threads-execve.test	2020-04-03 22:58:26.000000000 +0000
@@ -3,7 +3,7 @@
 # Check decoding of threads when a non-leader thread invokes execve.
 #
 # Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
-# Copyright (c) 2016-2019 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -17,13 +17,15 @@ require_min_kernel_version_or_skip 3.1
 # This test requires some concurrency between threads.
 require_min_nproc 2
 
+opts="${*:-}"
+
 check_prog diff
 run_prog_skip_if_failed date +%s > /dev/null
 s0="$(date +%s)"
 
 run_prog > /dev/null
 
-set -- -a21 -f -esignal=none -e trace=execve,exit,nanosleep,rt_sigsuspend $args
+set -- -a21 -f -esignal=none -e trace=execve,exit,nanosleep,rt_sigsuspend $opts $args
 
 # Due to probabilistic nature of the test, try it several times.
 while :; do
diff -pruN 5.5-3/tests/tkill.c 5.9-0ubuntu2/tests/tkill.c
--- 5.5-3/tests/tkill.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/tkill.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,69 @@
+/*
+ * Check decoding of tkill syscall.
+ *
+ * Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+#include "pidns.h"
+
+#ifdef __NR_tkill
+
+# include <signal.h>
+# include <stdio.h>
+# include <unistd.h>
+
+static const char *errstr;
+
+static long
+k_tkill(const unsigned int tid, const unsigned int sig)
+{
+        const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+        const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+        const kernel_ulong_t arg1 = fill | tid;
+        const kernel_ulong_t arg2 = fill | sig;
+        const long rc = syscall(__NR_tkill, arg1, arg2, bad, bad, bad, bad);
+        errstr = sprintrc(rc);
+        return rc;
+}
+
+int
+main(void)
+{
+	PIDNS_TEST_INIT;
+
+	const int tid = syscall(__NR_gettid);
+	const char *tid_str = pidns_pid2str(PT_TID);
+	const int bad_pid = -1;
+	const int bad_sig = 0xface;
+
+	k_tkill(tid, 0);
+	pidns_print_leader();
+	printf("tkill(%d%s, 0) = %s\n", tid, tid_str, errstr);
+
+	k_tkill(tid, SIGCONT);
+	pidns_print_leader();
+	printf("tkill(%d%s, SIGCONT) = %s\n", tid, tid_str, errstr);
+
+	k_tkill(bad_pid, bad_sig);
+	pidns_print_leader();
+	printf("tkill(%d, %d) = %s\n", bad_pid, bad_sig, errstr);
+
+	k_tkill(bad_pid, -bad_sig);
+	pidns_print_leader();
+	printf("tkill(%d, %d) = %s\n", bad_pid, -bad_sig, errstr);
+
+	pidns_print_leader();
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_tkill")
+
+#endif
diff -pruN 5.5-3/tests/tkill.gen.test 5.9-0ubuntu2/tests/tkill.gen.test
--- 5.5-3/tests/tkill.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/tkill.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (tkill -a12 --signal='!cont'); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a12 --signal='!cont'
diff -pruN 5.5-3/tests/tkill--pidns-translation.c 5.9-0ubuntu2/tests/tkill--pidns-translation.c
--- 5.5-3/tests/tkill--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/tkill--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "tkill.c"
diff -pruN 5.5-3/tests/tkill--pidns-translation.gen.test 5.9-0ubuntu2/tests/tkill--pidns-translation.gen.test
--- 5.5-3/tests/tkill--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/tkill--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (tkill--pidns-translation test_pidns --signal='!cont' -a12 -e trace=tkill); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns --signal='!cont' -a12 -e trace=tkill
diff -pruN 5.5-3/tests/trace_clock.gen.test 5.9-0ubuntu2/tests/trace_clock.gen.test
--- 5.5-3/tests/trace_clock.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/trace_clock.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (trace_clock test_trace_expr 'clock_nanosleep|times' -e%clock); do not edit.
+. "${srcdir=.}/init.sh"
+test_trace_expr 'clock_nanosleep|times' -e%clock
diff -pruN 5.5-3/tests/trace_clock.in 5.9-0ubuntu2/tests/trace_clock.in
--- 5.5-3/tests/trace_clock.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/trace_clock.in	2020-04-17 20:43:15.000000000 +0000
@@ -0,0 +1,5 @@
+adjtimex -a13
+clock_adjtime -a21
+clock_xettime -a21
+xettimeofday -a20
+time -a9
diff -pruN 5.5-3/tests/trace_fstat.in 5.9-0ubuntu2/tests/trace_fstat.in
--- 5.5-3/tests/trace_fstat.in	2018-12-10 23:45:11.000000000 +0000
+++ 5.9-0ubuntu2/tests/trace_fstat.in	2020-06-14 08:00:00.000000000 +0000
@@ -9,3 +9,4 @@ fstat64-Xverbose	-a17 -Xverbose
 fstatat64	-a32
 newfstatat	-a32
 oldfstat	-a21
+statx	-a32
diff -pruN 5.5-3/tests/tracer_ppid_pgid_sid.c 5.9-0ubuntu2/tests/tracer_ppid_pgid_sid.c
--- 5.5-3/tests/tracer_ppid_pgid_sid.c	2019-10-07 11:33:37.000000000 +0000
+++ 5.9-0ubuntu2/tests/tracer_ppid_pgid_sid.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Helper program for strace-DDD.test
  *
- * Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2019-2020 Dmitry V. Levin <ldv@altlinux.org>
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -86,7 +86,7 @@ main(void)
 
 	int ppid = 0, pgid = 0, sid = 0;
 	get_ppid_pgid_sid(tracer_pid, &ppid, &pgid, &sid);
-	printf("%d %d %d\n", ppid, pgid, sid);
+	printf("%d %d %d %d\n", tracer_pid, ppid, pgid, sid);
 
 	return 0;
 }
diff -pruN 5.5-3/tests/trie_for_tests.c 5.9-0ubuntu2/tests/trie_for_tests.c
--- 5.5-3/tests/trie_for_tests.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/trie_for_tests.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1 @@
+#include "trie.c"
diff -pruN 5.5-3/tests/trie_test.c 5.9-0ubuntu2/tests/trie_test.c
--- 5.5-3/tests/trie_test.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/trie_test.c	2020-09-23 16:29:35.000000000 +0000
@@ -0,0 +1,121 @@
+/*
+ * Copyright (c) 2017-2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "trie.h"
+
+#include <stdio.h>
+#include <inttypes.h>
+
+static void
+assert_equals(const char *msg, uint64_t expected, uint64_t actual) {
+	if (actual != expected)
+		error_msg_and_fail("%s: expected: %" PRIu64
+		                   ", actual: %" PRIu64, msg, expected, actual);
+}
+
+static void
+iterate_fn(void *data, uint64_t key, uint64_t value)
+{
+	uint64_t expected = key < 256 && key % 10 == 0 ? key + 42 : -1ULL;
+	assert_equals("iterate_fn", expected, value);
+
+	int *count = (int *) data;
+	if (value != -1ULL)
+		(*count)++;
+}
+
+static void
+test_trie_iterate_fn(void)
+{
+	struct trie *t = trie_create(8, 6, 3, 3, -1);
+	for (int i = 0; i < 26; i++)
+		trie_set(t, i * 10, i * 10 + 42);
+
+	static const struct {
+		uint64_t start;
+		uint64_t end;
+		int expected_count;
+	} iterate_params[] = {
+		{0, 256, 26},
+		{0, UINT64_MAX, 26},
+		{20, 90, 8},
+		{99, 999, 16},
+		{10000, 100000, 0},
+		{200, 100, 0},
+	};
+
+	for (size_t i = 0; i < ARRAY_SIZE(iterate_params); i++) {
+		int count = 0;
+		trie_iterate_keys(t, iterate_params[i].start, iterate_params[i].end, iterate_fn, &count);
+		assert_equals("iteration count", iterate_params[i].expected_count, count);
+	}
+}
+
+struct key_value_pair {
+	uint64_t key, value;
+};
+
+static void
+test_trie_get(void)
+{
+	static const struct {
+		uint8_t key_size;
+		uint8_t item_size_lg;
+		uint8_t node_key_bits;
+		uint8_t data_block_key_bits;
+		uint64_t empty_value;
+
+		struct key_value_pair set_values[3], get_values[3];
+	} params[] = {
+		{64, 6, 10, 10, 0,
+			{{300, 1}, {0xfacefeed, 0xabcdef123456}, {-1ULL, -1ULL}},
+			{{301, 0}, {0xfacefeed, 0xabcdef123456}, {-1ULL, -1ULL}}},
+		{8, 2, 4, 4, 10,
+			{{0xab, 0xcd}, {0xface, 2}, {0, 3}},
+			{{0xab, 0xd}, {0xface, 10}, {0, 3}}},
+		{30, 0, 6, 3, -1,
+			{{0xaaaa, 127}, {0xface, 0}, {0, 0}},
+			{{0xaaaa, 1}, {0xface, 0}, {1, 1}}},
+		{16, 4, 5, 11, 0xffffff,
+			{{0xabcdef, 42}, {0xabcd, 42}, {0xffff, 0}},
+			{{0xabcdef, 0xffff}, {0xabcd, 42}, {0xffff, 0}}},
+		{41, 5, 1, 1, -1,
+			{{0xabcdef01, 0x22222222}, {-1, 0x33333333}, {10, 10}},
+			{{0xabcdef01, 0x22222222}, {-1, 0xffffffff}, {10, 10}}},
+	};
+
+	for (size_t i = 0; i < ARRAY_SIZE(params); i++) {
+		struct trie *t = trie_create(params[i].key_size,
+		                             params[i].item_size_lg,
+					     params[i].node_key_bits,
+					     params[i].data_block_key_bits,
+					     params[i].empty_value);
+
+		if (!t)
+			error_msg_and_fail("trie creation failed");
+
+		for (size_t j = 0; j < ARRAY_SIZE(params[i].set_values); j++) {
+			struct key_value_pair kv = params[i].set_values[j];
+			trie_set(t, kv.key, kv.value);
+		}
+		for (size_t j = 0; j < ARRAY_SIZE(params[i].get_values); j++) {
+			struct key_value_pair kv = params[i].get_values[j];
+			assert_equals("trie_get", kv.value, trie_get(t, kv.key));
+		}
+
+		trie_free(t);
+	}
+}
+
+int
+main(void)
+{
+	test_trie_get();
+	test_trie_iterate_fn();
+	return 0;
+}
diff -pruN 5.5-3/tests/trie_test.gen.test 5.9-0ubuntu2/tests/trie_test.gen.test
--- 5.5-3/tests/trie_test.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/trie_test.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (trie_test run_prog ); do not edit.
+. "${srcdir=.}/init.sh"
+run_prog 
diff -pruN 5.5-3/tests/umovestr_cached_adjacent.c 5.9-0ubuntu2/tests/umovestr_cached_adjacent.c
--- 5.5-3/tests/umovestr_cached_adjacent.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/umovestr_cached_adjacent.c	2020-04-16 00:04:10.000000000 +0000
@@ -0,0 +1,48 @@
+/*
+ * Check effectiveness of umovestr memory caching.
+ *
+ * Copyright (c) 2019-2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+
+#include <stdio.h>
+#include <string.h>
+#include <unistd.h>
+#include <sys/uio.h>
+
+int
+main(void)
+{
+	const size_t size = get_page_size() + (DEFAULT_STRLEN - 1);
+	char *const buf = tail_alloc(size);
+	fill_memory_ex(buf, DEFAULT_STRLEN * 2, 'a', 'z' - 'a' + 1);
+
+	struct iovec *const io = tail_alloc(sizeof(*io) * DEFAULT_STRLEN);
+	for (unsigned int i = 0; i < DEFAULT_STRLEN; ++i) {
+		io[i].iov_base = buf + i;
+		io[i].iov_len = DEFAULT_STRLEN;
+	}
+
+	tprintf("%s", "");
+
+	int rc = writev(-1, io, DEFAULT_STRLEN);
+	const char *errstr = sprintrc(rc);
+
+	tprintf("writev(-1, [");
+	for (unsigned int i = 0; i < DEFAULT_STRLEN; ++i) {
+		if (i)
+			tprintf(", ");
+		tprintf("{iov_base=\"%.*s\", iov_len=%u}",
+			(int) io[i].iov_len,
+			(char *) io[i].iov_base,
+			(unsigned int) io[i].iov_len);
+	}
+	tprintf("], %u) = %s\n", DEFAULT_STRLEN, errstr);
+
+	tprintf("+++ exited with 0 +++\n");
+	return 0;
+}
diff -pruN 5.5-3/tests/umovestr_cached_adjacent.gen.test 5.9-0ubuntu2/tests/umovestr_cached_adjacent.gen.test
--- 5.5-3/tests/umovestr_cached_adjacent.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/umovestr_cached_adjacent.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (umovestr_cached_adjacent +umovestr_cached.test 3); do not edit.
+set -- 3
+. "${srcdir=.}/umovestr_cached.test"
diff -pruN 5.5-3/tests/umovestr_cached.test 5.9-0ubuntu2/tests/umovestr_cached.test
--- 5.5-3/tests/umovestr_cached.test	2019-09-23 10:19:22.000000000 +0000
+++ 5.9-0ubuntu2/tests/umovestr_cached.test	2020-04-16 00:04:10.000000000 +0000
@@ -2,22 +2,32 @@
 #
 # Check effectiveness of umovestr memory caching.
 #
-# Copyright (c) 2017-2019 Dmitry V. Levin <ldv@altlinux.org>
+# Copyright (c) 2017-2020 Dmitry V. Levin <ldv@altlinux.org>
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/init.sh"
 
-run_strace_match_diff -e trace=writev
-
-if [ "$STRACE_ARCH" = ia64 ]; then
-	# ia64 invokes extra process_vm_readv syscalls to obtain syscall
-	# arguments, see linux/ia64/get_syscall_args.c for details.
-	skip_ "the test is not supported on $STRACE_ARCH yet"
-fi
+expected_count="${1:-2}"
 
 check_prog grep
+$STRACE -d -enone / > /dev/null 2> "$LOG" ||:
+grep -x "[^:]*strace: PTRACE_GET_SYSCALL_INFO works" "$LOG" > /dev/null || {
+	# PTRACE_GET_SYSCALL_INFO does not work
+	case "$STRACE_ARCH:$MIPS_ABI" in
+		ia64:|mips:o32)
+		# ia64 invokes extra process_vm_readv syscalls to obtain syscall
+		# arguments, see linux/ia64/get_syscall_args.c for details.
+		# mips o32 obtains the first four syscalls arguments from registers
+		# and invokes extra process_vm_readv syscalls to obtain remaining
+		# syscall arguments, see linux/mips/get_syscall_args.c for details.
+		skip_ "the test is not supported on $STRACE_ARCH yet"
+		;;
+	esac
+}
+
+run_strace_match_diff -e trace=writev
 
 run_strace -qq -esignal=none -eprocess_vm_readv -z \
 	-o '|grep -c ^process_vm_readv > count' \
@@ -26,6 +36,6 @@ run_strace -qq -esignal=none -eprocess_v
 count="$(cat count)"
 case "$count" in
 	0) skip_ "$STRACE $args made no process_vm_readv syscall invocations" ;;
-	2) ;;
-	*) fail_ "$STRACE $args made $count != 2 process_vm_readv syscall invocations" ;;
+	$expected_count) ;;
+	*) fail_ "$STRACE $args made $count != $expected_count process_vm_readv syscall invocations" ;;
 esac
diff -pruN 5.5-3/tests/unshare.c 5.9-0ubuntu2/tests/unshare.c
--- 5.5-3/tests/unshare.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/unshare.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of unshare syscall.
  *
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -28,12 +28,12 @@ main(void)
 		const char *str;
 	} unshare_flags[] = {
 		{ ARG_STR(0) },
-		{ 0xdeadca75,
-			"CLONE_THREAD|CLONE_FS|CLONE_SIGHAND|CLONE_SYSVSEM|"
-			"CLONE_NEWUTS|CLONE_NEWIPC|CLONE_NEWNET|CLONE_NEWUSER|"
-			"CLONE_NEWCGROUP|0x80a8c075" },
+		{ 0xdeadcaf5,
+			"CLONE_NEWTIME|CLONE_FS|CLONE_SIGHAND|CLONE_THREAD"
+			"|CLONE_SYSVSEM|CLONE_NEWCGROUP|CLONE_NEWUTS"
+			"|CLONE_NEWIPC|CLONE_NEWUSER|CLONE_NEWNET|0x80a8c075" },
 		{ 0x2000000, "CLONE_NEWCGROUP" },
-		{ ARG_STR(0x81f8f0ff) " /* CLONE_??? */" },
+		{ ARG_STR(0x81f8f07f) " /* CLONE_??? */" },
 	};
 
 	long rc;
diff -pruN 5.5-3/tests/wait4.c 5.9-0ubuntu2/tests/wait4.c
--- 5.5-3/tests/wait4.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests/wait4.c	2020-06-02 08:00:00.000000000 +0000
@@ -2,77 +2,98 @@
  * Check decoding of wait4 syscall.
  *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-#include <assert.h>
-#include <signal.h>
-#include <stdio.h>
-#include <unistd.h>
-#include <sys/wait.h>
-#include <sys/resource.h>
+#include "scno.h"
+
+#ifdef __NR_wait4
+
+# include <assert.h>
+# include <signal.h>
+# include <stdio.h>
+# include <unistd.h>
+# include <sys/wait.h>
+# include "kernel_rusage.h"
 
 static const char *
-sprint_rusage(const struct rusage *const ru)
+sprint_rusage(const kernel_rusage_t *const ru)
 {
 	static char buf[1024];
 	snprintf(buf, sizeof(buf),
-		 "{ru_utime={tv_sec=%lld, tv_usec=%llu}"
-		 ", ru_stime={tv_sec=%lld, tv_usec=%llu}"
-#if VERBOSE
-		 ", ru_maxrss=%lu"
-		 ", ru_ixrss=%lu"
-		 ", ru_idrss=%lu"
-		 ", ru_isrss=%lu"
-		 ", ru_minflt=%lu"
-		 ", ru_majflt=%lu"
-		 ", ru_nswap=%lu"
-		 ", ru_inblock=%lu"
-		 ", ru_oublock=%lu"
-		 ", ru_msgsnd=%lu"
-		 ", ru_msgrcv=%lu"
-		 ", ru_nsignals=%lu"
-		 ", ru_nvcsw=%lu"
-		 ", ru_nivcsw=%lu}"
-#else
+		 "{ru_utime={tv_sec=%llu, tv_usec=%llu}"
+		 ", ru_stime={tv_sec=%llu, tv_usec=%llu}"
+# if VERBOSE
+		 ", ru_maxrss=%llu"
+		 ", ru_ixrss=%llu"
+		 ", ru_idrss=%llu"
+		 ", ru_isrss=%llu"
+		 ", ru_minflt=%llu"
+		 ", ru_majflt=%llu"
+		 ", ru_nswap=%llu"
+		 ", ru_inblock=%llu"
+		 ", ru_oublock=%llu"
+		 ", ru_msgsnd=%llu"
+		 ", ru_msgrcv=%llu"
+		 ", ru_nsignals=%llu"
+		 ", ru_nvcsw=%llu"
+		 ", ru_nivcsw=%llu}"
+# else
 		 ", ...}"
-#endif
-		 , (long long) ru->ru_utime.tv_sec
+# endif
+		 , zero_extend_signed_to_ull(ru->ru_utime.tv_sec)
 		 , zero_extend_signed_to_ull(ru->ru_utime.tv_usec)
-		 , (long long) ru->ru_stime.tv_sec
+		 , zero_extend_signed_to_ull(ru->ru_stime.tv_sec)
 		 , zero_extend_signed_to_ull(ru->ru_stime.tv_usec)
-#if VERBOSE
-		 , (long) ru->ru_maxrss
-		 , (long) ru->ru_ixrss
-		 , (long) ru->ru_idrss
-		 , (long) ru->ru_isrss
-		 , (long) ru->ru_minflt
-		 , (long) ru->ru_majflt
-		 , (long) ru->ru_nswap
-		 , (long) ru->ru_inblock
-		 , (long) ru->ru_oublock
-		 , (long) ru->ru_msgsnd
-		 , (long) ru->ru_msgrcv
-		 , (long) ru->ru_nsignals
-		 , (long) ru->ru_nvcsw
-		 , (long) ru->ru_nivcsw
-#endif
+# if VERBOSE
+		 , zero_extend_signed_to_ull(ru->ru_maxrss)
+		 , zero_extend_signed_to_ull(ru->ru_ixrss)
+		 , zero_extend_signed_to_ull(ru->ru_idrss)
+		 , zero_extend_signed_to_ull(ru->ru_isrss)
+		 , zero_extend_signed_to_ull(ru->ru_minflt)
+		 , zero_extend_signed_to_ull(ru->ru_majflt)
+		 , zero_extend_signed_to_ull(ru->ru_nswap)
+		 , zero_extend_signed_to_ull(ru->ru_inblock)
+		 , zero_extend_signed_to_ull(ru->ru_oublock)
+		 , zero_extend_signed_to_ull(ru->ru_msgsnd)
+		 , zero_extend_signed_to_ull(ru->ru_msgrcv)
+		 , zero_extend_signed_to_ull(ru->ru_nsignals)
+		 , zero_extend_signed_to_ull(ru->ru_nvcsw)
+		 , zero_extend_signed_to_ull(ru->ru_nivcsw)
+# endif
 		 );
 	return buf;
 }
 
+static const char *errstr;
+
+static long
+k_wait4(const unsigned int pid, void const *wstatus,
+	const unsigned int options, void const *ru)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+	const kernel_ulong_t arg1 = fill | pid;
+	const kernel_ulong_t arg2 = (uintptr_t) wstatus;
+	const kernel_ulong_t arg3 = fill | options;
+	const kernel_ulong_t arg4 = (uintptr_t) ru;
+	const long rc = syscall(__NR_wait4, arg1, arg2, arg3, arg4, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
+
 static pid_t
-do_wait4(pid_t pid, int *wstatus, int options, struct rusage *ru)
+do_wait4(pid_t pid, int *wstatus, int options, kernel_rusage_t *ru)
 {
 	sigset_t mask = {};
 	sigaddset(&mask, SIGCHLD);
 
 	assert(sigprocmask(SIG_BLOCK, &mask, NULL) == 0);
-	pid_t rc = wait4(pid, wstatus, options, ru);
+	pid_t rc = k_wait4(pid, wstatus, options, ru);
 	assert(sigprocmask(SIG_UNBLOCK, &mask, NULL) == 0);
 	return rc;
 }
@@ -101,12 +122,12 @@ main(void)
 	(void) close(0);
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(int, s);
-	if (wait4(pid, s, WNOHANG|__WALL, NULL))
+	if (k_wait4(pid, s, WNOHANG|__WALL, NULL))
 		perror_msg_and_fail("wait4 #1");
 	tprintf("wait4(%d, %p, WNOHANG|__WALL, NULL) = 0\n", pid, s);
 
-	TAIL_ALLOC_OBJECT_CONST_PTR(struct rusage, rusage);
-	if (wait4(pid, s, WNOHANG|__WALL, rusage))
+	TAIL_ALLOC_OBJECT_CONST_PTR(kernel_rusage_t, rusage);
+	if (k_wait4(pid, s, WNOHANG|__WALL, rusage))
 		perror_msg_and_fail("wait4 #2");
 	tprintf("wait4(%d, %p, WNOHANG|__WALL, %p) = 0\n", pid, s, rusage);
 
@@ -156,12 +177,12 @@ main(void)
 	if (kill(pid, SIGCONT))
 		perror_msg_and_fail("kill(SIGCONT)");
 
-#if defined WCONTINUED && defined WIFCONTINUED
+# if defined WCONTINUED && defined WIFCONTINUED
 	assert(do_wait4(pid, s, WCONTINUED, rusage) == pid);
 	assert(WIFCONTINUED(*s));
 	tprintf("wait4(%d, [{WIFCONTINUED(s)}], WCONTINUED"
 		", %s) = %d\n", pid, sprint_rusage(rusage), pid);
-#endif /* WCONTINUED && WIFCONTINUED */
+# endif /* WCONTINUED && WIFCONTINUED */
 
 	assert(write(1, "", 1) == 1);
 	(void) close(1);
@@ -171,10 +192,16 @@ main(void)
 	tprintf("wait4(%d, [{WIFEXITED(s) && WEXITSTATUS(s) == 0}], 0"
 		", %s) = %d\n", pid, sprint_rusage(rusage), pid);
 
-	assert(wait4(-1, s, WNOHANG|WSTOPPED|__WALL, rusage) == -1);
-	tprintf("wait4(-1, %p, WNOHANG|WSTOPPED|__WALL, %p) = -1 %s (%m)\n",
-		s, rusage, errno2name());
+	assert(k_wait4(-1, s, WNOHANG|WSTOPPED|__WALL, rusage) == -1);
+	tprintf("wait4(-1, %p, WNOHANG|WSTOPPED|__WALL, %p) = %s\n",
+		s, rusage, errstr);
 
 	tprintf("%s\n", "+++ exited with 0 +++");
 	return 0;
 }
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_wait4")
+
+#endif /* __NR_wait4 */
diff -pruN 5.5-3/tests/waitid.c 5.9-0ubuntu2/tests/waitid.c
--- 5.5-3/tests/waitid.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/waitid.c	2020-07-17 08:00:00.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of waitid syscall.
  *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -15,11 +15,11 @@
 #include <string.h>
 #include <unistd.h>
 #include <sys/wait.h>
-#include <sys/resource.h>
+#include "kernel_rusage.h"
 #include "scno.h"
 
 static const char *
-sprint_rusage(const struct rusage *const ru)
+sprint_rusage(const kernel_rusage_t *const ru)
 {
 	static char buf[1024];
 	snprintf(buf, sizeof(buf),
@@ -103,8 +103,8 @@ sprint_siginfo(const siginfo_t *const si
 	snprintf(buf, sizeof(buf),
 		 "{si_signo=SIGCHLD"
 		 ", si_code=%s"
-		 ", si_pid=%u"
-		 ", si_uid=%u"
+		 ", si_pid=%d"
+		 ", si_uid=%d"
 		 ", si_status=%s"
 		 ", si_utime=%llu"
 		 ", si_stime=%llu}",
@@ -128,7 +128,7 @@ do_waitid(const unsigned int idtype,
 	  const unsigned int id,
 	  const siginfo_t *const infop,
 	  const unsigned int options,
-	  const struct rusage *const rusage)
+	  const kernel_rusage_t *const rusage)
 {
 	sigset_t mask = {};
 	sigaddset(&mask, SIGCHLD);
@@ -169,7 +169,7 @@ main(void)
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(siginfo_t, sinfo);
 	memset(sinfo, 0, sizeof(*sinfo));
-	TAIL_ALLOC_OBJECT_CONST_PTR(struct rusage, rusage);
+	TAIL_ALLOC_OBJECT_CONST_PTR(kernel_rusage_t, rusage);
 	if (do_waitid(P_PID, pid, sinfo, WNOHANG|WEXITED|WSTOPPED, rusage))
 		perror_msg_and_fail("waitid #2");
 	tprintf("waitid(P_PID, %d, {}, WNOHANG|WEXITED|WSTOPPED, %s) = 0\n",
diff -pruN 5.5-3/tests/xetitimer.c 5.9-0ubuntu2/tests/xetitimer.c
--- 5.5-3/tests/xetitimer.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/xetitimer.c	2020-06-01 14:15:16.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of setitimer and getitimer syscalls.
  *
  * Copyright (c) 2015-2018 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -14,11 +14,17 @@
 #include <sys/time.h>
 #include <unistd.h>
 #include "scno.h"
+#include "kernel_timeval.h"
+
+typedef struct {
+	kernel_old_timeval_t it_interval;
+	kernel_old_timeval_t it_value;
+} kernel_old_itimerval_t;
 
 int
 main(void)
 {
-	static const struct itimerval new = {
+	static const kernel_old_itimerval_t new = {
 		.it_interval = { 0xc0de1, 0xc0de2 },
 		.it_value = { 0xc0de3, 0xc0de4 }
 	};
@@ -27,12 +33,12 @@ main(void)
 	static const kernel_ulong_t bogus_timer =
 		(kernel_ulong_t) 0xfacefeeddeadbeefULL;
 
-	TAIL_ALLOC_OBJECT_CONST_PTR(struct itimerval, p_old);
-	struct itimerval *const p_new = tail_memdup(&new, sizeof(new));
+	TAIL_ALLOC_OBJECT_CONST_PTR(kernel_old_itimerval_t, p_old);
+	kernel_old_itimerval_t *const p_new = tail_memdup(&new, sizeof(new));
 	void *const efault = tail_alloc(sizeof(new) - 8);
 	long rc;
 
-	if (setitimer(ITIMER_REAL, p_new, NULL))
+	if (syscall(__NR_setitimer, ITIMER_REAL, p_new, NULL))
 		perror_msg_and_skip("setitimer");
 	printf("setitimer(ITIMER_REAL"
 	       ", {it_interval={tv_sec=%lld, tv_usec=%llu}"
@@ -44,7 +50,7 @@ main(void)
 	       zero_extend_signed_to_ull(new.it_value.tv_usec));
 
 	fill_memory(p_old, sizeof(*p_old));
-	if (getitimer(ITIMER_REAL, p_old))
+	if (syscall(__NR_getitimer, ITIMER_REAL, p_old))
 		perror_msg_and_skip("getitimer");
 	printf("getitimer(ITIMER_REAL"
 	       ", {it_interval={tv_sec=%lld, tv_usec=%llu}"
@@ -55,7 +61,7 @@ main(void)
 	       zero_extend_signed_to_ull(p_old->it_value.tv_usec));
 
 	fill_memory(p_old, sizeof(*p_old));
-	setitimer(ITIMER_REAL, p_new, p_old);
+	syscall(__NR_setitimer, ITIMER_REAL, p_new, p_old);
 	printf("setitimer(ITIMER_REAL"
 	       ", {it_interval={tv_sec=%lld, tv_usec=%llu}"
 	       ", it_value={tv_sec=%lld, tv_usec=%llu}}"
@@ -70,10 +76,10 @@ main(void)
 	       (long long) p_old->it_value.tv_sec,
 	       zero_extend_signed_to_ull(p_old->it_value.tv_usec));
 
-	rc = getitimer(ITIMER_REAL, efault);
+	rc = syscall(__NR_getitimer, ITIMER_REAL, efault);
 	printf("getitimer(ITIMER_REAL, %p) = %s\n", efault, sprintrc(rc));
 
-	rc = setitimer(ITIMER_REAL, p_new, efault);
+	rc = syscall(__NR_setitimer, ITIMER_REAL, p_new, efault);
 	printf("setitimer(ITIMER_REAL"
 	       ", {it_interval={tv_sec=%lld, tv_usec=%llu}"
 	       ", it_value={tv_sec=%lld, tv_usec=%llu}}, %p) = %s\n",
@@ -83,7 +89,7 @@ main(void)
 	       zero_extend_signed_to_ull(new.it_value.tv_usec),
 	       efault, sprintrc(rc));
 
-	rc = setitimer(ITIMER_REAL, efault, p_old);
+	rc = syscall(__NR_setitimer, ITIMER_REAL, efault, p_old);
 	printf("setitimer(ITIMER_REAL, %p, %p) = %s\n",
 	       efault, p_old, sprintrc(rc));
 
@@ -147,10 +153,12 @@ main(void)
 
 	p_new->it_interval.tv_sec = 0xdeadbeefU;
 	p_new->it_interval.tv_usec = 0xfacefeedU;
-	p_new->it_value.tv_sec = (time_t) 0xcafef00ddeadbeefLL;
-	p_new->it_value.tv_usec = (suseconds_t) 0xbadc0dedfacefeedLL;
+	p_new->it_value.tv_sec =
+		(typeof(p_new->it_value.tv_sec)) 0xcafef00ddeadbeefLL;
+	p_new->it_value.tv_usec =
+		(typeof(p_new->it_value.tv_usec)) 0xbadc0dedfacefeedLL;
 
-	rc = setitimer(ITIMER_REAL, p_new, p_old);
+	rc = syscall(__NR_setitimer, ITIMER_REAL, p_new, p_old);
 	printf("setitimer(ITIMER_REAL"
 	       ", {it_interval={tv_sec=%lld, tv_usec=%llu}"
 	       ", it_value={tv_sec=%lld, tv_usec=%llu}}, %p) = %s\n",
diff -pruN 5.5-3/tests/xetpgid.c 5.9-0ubuntu2/tests/xetpgid.c
--- 5.5-3/tests/xetpgid.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/xetpgid.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,7 +2,7 @@
  * This file is part of xetpgid strace test.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,6 +10,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #if defined __NR_getpgid && defined __NR_setpgid
 
@@ -19,13 +20,21 @@
 int
 main(void)
 {
-	const int pid = getpid();
-	long rc = syscall(__NR_getpgid, F8ILL_KULONG_MASK | pid);
-	printf("getpgid(%d) = %ld\n", pid, rc);
+	PIDNS_TEST_INIT;
 
-	rc = syscall(__NR_setpgid, F8ILL_KULONG_MASK, F8ILL_KULONG_MASK | pid);
-	printf("setpgid(0, %d) = %ld\n", pid, rc);
+	const int pid = getpid();
+	long pgid = syscall(__NR_getpgid, F8ILL_KULONG_MASK | pid);
+	pidns_print_leader();
+	printf("getpgid(%d%s) = %ld%s\n", pid, pidns_pid2str(PT_TGID),
+		pgid, pidns_pid2str(PT_PGID));
+
+	long rc = syscall(__NR_setpgid, F8ILL_KULONG_MASK,
+		F8ILL_KULONG_MASK | pgid);
+	pidns_print_leader();
+	printf("setpgid(0, %ld%s) = %s\n", pgid, pidns_pid2str(PT_PGID),
+		sprintrc(rc));
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests/xetpgid--pidns-translation.c 5.9-0ubuntu2/tests/xetpgid--pidns-translation.c
--- 5.5-3/tests/xetpgid--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/xetpgid--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "xetpgid.c"
diff -pruN 5.5-3/tests/xetpgid--pidns-translation.gen.test 5.9-0ubuntu2/tests/xetpgid--pidns-translation.gen.test
--- 5.5-3/tests/xetpgid--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/xetpgid--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (xetpgid--pidns-translation test_pidns -a11 -e trace=getpgid,setpgid); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a11 -e trace=getpgid,setpgid
diff -pruN 5.5-3/tests/xetpriority.c 5.9-0ubuntu2/tests/xetpriority.c
--- 5.5-3/tests/xetpriority.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/xetpriority.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -7,6 +7,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #if defined __NR_getpriority && defined __NR_setpriority
 
@@ -17,15 +18,30 @@
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	const int pid = getpid();
+	const int pgid = getpgid(0);
+
 	long rc = syscall(__NR_getpriority, PRIO_PROCESS,
 			  F8ILL_KULONG_MASK | pid);
-	printf("getpriority(PRIO_PROCESS, %d) = %ld\n", pid, rc);
+	pidns_print_leader();
+	printf("getpriority(PRIO_PROCESS, %d%s) = %ld\n",
+		pid, pidns_pid2str(PT_TGID), rc);
 
 	rc = syscall(__NR_setpriority, PRIO_PROCESS,
 		     F8ILL_KULONG_MASK | pid, F8ILL_KULONG_MASK);
-	printf("setpriority(PRIO_PROCESS, %d, 0) = %s\n", pid, sprintrc(rc));
+	pidns_print_leader();
+	printf("setpriority(PRIO_PROCESS, %d%s, 0) = %s\n",
+		pid, pidns_pid2str(PT_TGID), sprintrc(rc));
+
+	rc = syscall(__NR_getpriority, PRIO_PGRP,
+			  F8ILL_KULONG_MASK | pgid);
+	pidns_print_leader();
+	printf("getpriority(PRIO_PGRP, %d%s) = %ld\n",
+		pgid, pidns_pid2str(PT_PGID), rc);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests/xetpriority.gen.test 5.9-0ubuntu2/tests/xetpriority.gen.test
--- 5.5-3/tests/xetpriority.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests/xetpriority.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -1,4 +1,4 @@
 #!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (xetpriority -a29 -e trace=getpriority,setpriority); do not edit.
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (xetpriority -a27 -e trace=getpriority,setpriority); do not edit.
 . "${srcdir=.}/init.sh"
-run_strace_match_diff -a29 -e trace=getpriority,setpriority
+run_strace_match_diff -a27 -e trace=getpriority,setpriority
diff -pruN 5.5-3/tests/xetpriority--pidns-translation.c 5.9-0ubuntu2/tests/xetpriority--pidns-translation.c
--- 5.5-3/tests/xetpriority--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/xetpriority--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "xetpriority.c"
diff -pruN 5.5-3/tests/xetpriority--pidns-translation.gen.test 5.9-0ubuntu2/tests/xetpriority--pidns-translation.gen.test
--- 5.5-3/tests/xetpriority--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/xetpriority--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (xetpriority--pidns-translation test_pidns -a27 -e trace=getpriority,setpriority); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a27 -e trace=getpriority,setpriority
diff -pruN 5.5-3/tests/xet_robust_list.c 5.9-0ubuntu2/tests/xet_robust_list.c
--- 5.5-3/tests/xet_robust_list.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/xet_robust_list.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -8,6 +8,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #if defined __NR_get_robust_list && defined __NR_set_robust_list
 
@@ -30,27 +31,36 @@ sprintaddr(void *addr)
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	const pid_t pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
 	const long long_pid = (unsigned long) (0xdeadbeef00000000LL | pid);
 	TAIL_ALLOC_OBJECT_CONST_PTR(void *, p_head);
 	TAIL_ALLOC_OBJECT_CONST_PTR(size_t, p_len);
 
 	if (syscall(__NR_get_robust_list, long_pid, p_head, p_len))
 		perror_msg_and_skip("get_robust_list");
-	printf("get_robust_list(%d, [%s], [%lu]) = 0\n",
-	       (int) pid, sprintaddr(*p_head), (unsigned long) *p_len);
+	pidns_print_leader();
+	printf("get_robust_list(%d%s, [%s], [%lu]) = 0\n",
+	       pid, pid_str, sprintaddr(*p_head),
+	       (unsigned long) *p_len);
 
 	void *head = tail_alloc(*p_len);
 	if (syscall(__NR_set_robust_list, head, *p_len))
 		perror_msg_and_skip("set_robust_list");
+	pidns_print_leader();
 	printf("set_robust_list(%p, %lu) = 0\n",
 	       head, (unsigned long) *p_len);
 
 	if (syscall(__NR_get_robust_list, long_pid, p_head, p_len))
 		perror_msg_and_skip("get_robust_list");
-	printf("get_robust_list(%d, [%s], [%lu]) = 0\n",
-	       (int) pid, sprintaddr(*p_head), (unsigned long) *p_len);
+	pidns_print_leader();
+	printf("get_robust_list(%d%s, [%s], [%lu]) = 0\n",
+	       pid, pid_str, sprintaddr(*p_head),
+	       (unsigned long) *p_len);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests/xet_robust_list--pidns-translation.c 5.9-0ubuntu2/tests/xet_robust_list--pidns-translation.c
--- 5.5-3/tests/xet_robust_list--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/xet_robust_list--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "xet_robust_list.c"
diff -pruN 5.5-3/tests/xet_robust_list--pidns-translation.gen.test 5.9-0ubuntu2/tests/xet_robust_list--pidns-translation.gen.test
--- 5.5-3/tests/xet_robust_list--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/xet_robust_list--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (xet_robust_list--pidns-translation test_pidns -a24 -e trace=get_robust_list,set_robust_list); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a24 -e trace=get_robust_list,set_robust_list
diff -pruN 5.5-3/tests/xettimeofday.c 5.9-0ubuntu2/tests/xettimeofday.c
--- 5.5-3/tests/xettimeofday.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests/xettimeofday.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,19 +1,23 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-#include <assert.h>
-#include <stdio.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <sys/time.h>
 #include "scno.h"
 
+#ifdef __NR_gettimeofday
+
+# include <assert.h>
+# include <stdio.h>
+# include <stdint.h>
+# include <unistd.h>
+# include <sys/time.h>
+# include "scno.h"
+
 int
 main(void)
 {
@@ -64,3 +68,9 @@ main(void)
 	puts("+++ exited with 0 +++");
 	return 0;
 }
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_gettimeofday")
+
+#endif /* __NR_gettimeofday */
diff -pruN 5.5-3/tests/xgetdents.c 5.9-0ubuntu2/tests/xgetdents.c
--- 5.5-3/tests/xgetdents.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/xgetdents.c	2020-04-11 18:09:11.000000000 +0000
@@ -0,0 +1,141 @@
+/*
+ * Check decoding of getdents and getdents64 syscalls.
+ *
+ * Copyright (c) 2015-2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include <dirent.h>
+#include <fcntl.h>
+#include <stdio.h>
+#include <unistd.h>
+#include <sys/stat.h>
+#include "kernel_dirent.h"
+#include "print_fields.h"
+
+#if VERBOSE
+static const char *
+str_d_type(const unsigned char d_type)
+{
+	switch (d_type) {
+		case DT_DIR:
+			return "DT_DIR";
+		case DT_REG:
+			return "DT_REG";
+		default:
+			return "DT_UNKNOWN";
+	}
+}
+
+static void
+print_dirent(const kernel_dirent_type *d);
+#endif
+
+static const char *errstr;
+
+static long
+k_getdents(const unsigned int fd,
+	   const void *dirp,
+	   const unsigned int count)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+	const kernel_ulong_t arg1 = fill | fd;
+	const kernel_ulong_t arg2 = (uintptr_t) dirp;
+	const kernel_ulong_t arg3 = fill | count;
+	const long rc = syscall(NR_getdents, arg1, arg2, arg3, bad, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
+
+static void
+ls(int fd, char *buf, unsigned int size)
+{
+	long rc;
+	while ((rc = k_getdents(fd, buf, size))) {
+		if (rc < 0)
+			perror_msg_and_skip(STR_getdents);
+		printf("%s(%d, ", STR_getdents, fd);
+#if VERBOSE
+		printf("[");
+#else
+		unsigned long entries = 0;
+#endif
+		kernel_dirent_type *d;
+		for (long i = 0; i < rc; i += d->d_reclen) {
+			d = (kernel_dirent_type *) &buf[i];
+#if VERBOSE
+			if (i)
+				printf(", ");
+			print_dirent(d);
+#else
+			++entries;
+#endif
+		}
+#if VERBOSE
+		printf("]");
+#else
+		printf("%p /* %lu entries */", buf, entries);
+#endif
+		printf(", %u) = %ld\n", size, rc);
+	}
+#if VERBOSE
+	printf("%s(%d, [], %u) = 0\n", STR_getdents, fd, size);
+#else
+	printf("%s(%d, %p /* 0 entries */, %u) = 0\n",
+	       STR_getdents, fd, buf, size);
+#endif
+}
+
+int
+main(void)
+{
+	static const char dot[] = ".";
+	static const char dot_dot[] = "..";
+	static const char dname[] = STR_getdents
+#if VERBOSE
+		"-v"
+#endif
+		".test.tmp.dir";
+	static const char fname[] =
+		"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
+		"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
+		"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
+		"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
+		"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
+		"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
+		"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
+		"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nZ";
+
+	if (mkdir(dname, 0700))
+		perror_msg_and_fail("mkdir: %s", dname);
+	if (chdir(dname))
+		perror_msg_and_fail("chdir: %s", dname);
+	int fd = creat(fname, 0600);
+	if (fd < 0)
+		perror_msg_and_fail("creat: %s", fname);
+	if (close(fd))
+		perror_msg_and_fail("close: %s", fname);
+	fd = open(dot, O_RDONLY | O_DIRECTORY);
+	if (fd < 0)
+		perror_msg_and_fail("open: %s", dot);
+
+	unsigned int count = 0xdeadbeefU;
+	k_getdents(-1U, NULL, count);
+	printf("%s(-1, NULL, %u) = %s\n", STR_getdents, count, errstr);
+
+	static char buf[8192];
+	ls(fd, buf, sizeof(buf));
+
+	if (unlink(fname))
+		perror_msg_and_fail("unlink: %s", fname);
+	if (chdir(dot_dot))
+		perror_msg_and_fail("chdir: %s", dot_dot);
+	if (rmdir(dname))
+		perror_msg_and_fail("rmdir: %s", dname);
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
diff -pruN 5.5-3/tests/xmalloc_for_tests.c 5.9-0ubuntu2/tests/xmalloc_for_tests.c
--- 5.5-3/tests/xmalloc_for_tests.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests/xmalloc_for_tests.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define error_msg_and_die error_msg_and_fail
+#include "xmalloc.c"
diff -pruN 5.5-3/tests/xstatx.c 5.9-0ubuntu2/tests/xstatx.c
--- 5.5-3/tests/xstatx.c	2019-07-11 17:51:22.000000000 +0000
+++ 5.9-0ubuntu2/tests/xstatx.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -468,12 +468,12 @@ main(void)
 	TEST_SYSCALL_STATX_FLAGS_STR = old_flags_str;
 
 	SET_MASK_INVOKE(0, "0");
-	SET_MASK_INVOKE(0xfffff000U, "0xfffff000 /* STATX_??? */");
+	SET_MASK_INVOKE(0xffffe000U, "0xffffe000 /* STATX_??? */");
 
 	SET_MASK_INVOKE(0xfffffffbU,
 		"STATX_TYPE|STATX_MODE|STATX_UID|STATX_GID|STATX_ATIME|"
 		"STATX_MTIME|STATX_CTIME|STATX_INO|STATX_SIZE|STATX_BLOCKS|"
-		"STATX_BTIME|0xfffff000");
+		"STATX_BTIME|STATX_MNT_ID|0xffffe000");
 
 	SET_MASK_INVOKE(STATX_UID, "STATX_UID");
 
diff -pruN 5.5-3/tests/zeroargc.c 5.9-0ubuntu2/tests/zeroargc.c
--- 5.5-3/tests/zeroargc.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests/zeroargc.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
  * Execute an executable with zero argc and specified environment.
  *
  * Copyright (c) 2017-2018 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
diff -pruN 5.5-3/tests-m32/bexecve.test 5.9-0ubuntu2/tests-m32/bexecve.test
--- 5.5-3/tests-m32/bexecve.test	2019-11-28 19:30:05.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/bexecve.test	2020-04-03 22:58:26.000000000 +0000
@@ -3,7 +3,7 @@
 # Check -bexecve behavior.
 #
 # Copyright (c) 2015 Dmitry V. Levin <ldv@altlinux.org>
-# Copyright (c) 2015-2019 The strace developers.
+# Copyright (c) 2015-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -16,27 +16,26 @@ run_strace_redir()
 	$STRACE "$@" 2> "$LOG"
 }
 
-run_strace_redir -enone ../set_ptracer_any true ||
+run_strace_redir --quiet=personality -enone ../set_ptracer_any true ||
 	dump_log_and_fail_with "$STRACE $args: unexpected exit status"
 
-run_strace_redir -enone ../set_ptracer_any false
+run_strace_redir --quiet=personality -enone ../set_ptracer_any false
 [ $? -eq 1 ] ||
 	dump_log_and_fail_with "$STRACE $args: unexpected exit status"
 
-run_strace_redir -bexecve -enone ../set_ptracer_any false ||
+run_strace_redir --quiet=personality -bexecve -enone ../set_ptracer_any false ||
 	dump_log_and_fail_with "$STRACE $args: unexpected exit status"
 
 pattern_detached='[^:]*strace: Process [1-9][0-9]* detached'
-pattern_personality='[^:]*strace: \[ Process PID=[1-9][0-9]* runs in .* mode. \]'
 
 LC_ALL=C grep -x "$pattern_detached" "$LOG" > /dev/null ||
 	dump_log_and_fail_with "$STRACE $args: output mismatch"
 
-if LC_ALL=C grep -E -v -x "($pattern_detached|$pattern_personality)" "$LOG" > /dev/null; then
+if LC_ALL=C grep -E -v -x "$pattern_detached" "$LOG" > /dev/null; then
 	dump_log_and_fail_with "$STRACE $args: unexpected output"
 fi
 
-run_strace_redir --seccomp-bpf -bexecve -enone ../set_ptracer_any false ||
+run_strace_redir --quiet=personality --seccomp-bpf -bexecve -enone ../set_ptracer_any false ||
 	dump_log_and_fail_with "$STRACE $args: unexpected exit status"
 
 pattern_seccomp='[^:]*strace: --seccomp-bpf is not enabled because it is not compatible with -b'
@@ -45,7 +44,7 @@ LC_ALL=C grep -x "$pattern_detached" "$L
 LC_ALL=C grep -x "$pattern_seccomp" "$LOG" > /dev/null ||
 	dump_log_and_fail_with "$STRACE $args: output mismatch"
 
-pattern_all="$pattern_detached|$pattern_seccomp|$pattern_personality"
+pattern_all="$pattern_detached|$pattern_seccomp"
 if LC_ALL=C grep -E -v -x "$pattern_all" "$LOG" > /dev/null; then
 	dump_log_and_fail_with "$STRACE $args: unexpected output"
 fi
diff -pruN 5.5-3/tests-m32/bpf.c 5.9-0ubuntu2/tests-m32/bpf.c
--- 5.5-3/tests-m32/bpf.c	2019-12-10 09:44:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/bpf.c	2020-09-06 08:00:00.000000000 +0000
@@ -2,7 +2,7 @@
  * Check bpf syscall decoding.
  *
  * Copyright (c) 2015-2017 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -27,6 +27,7 @@
 
 #include "xlat.h"
 #include "xlat/bpf_commands.h"
+#include "xlat/bpf_map_types.h"
 #include "xlat/bpf_prog_types.h"
 
 #if defined MPERS_IS_m32 || SIZEOF_KERNEL_LONG_T > 4
@@ -42,6 +43,10 @@
 # define BIG_ADDR_MAYBE(addr_)
 #endif
 
+#ifndef FD0_PATH
+# define FD0_PATH ""
+#endif
+
 #ifndef HAVE_STRUCT_BPF_INSN
 struct bpf_insn {
 	uint8_t	code;
@@ -75,6 +80,11 @@ union bpf_attr_data {
 	BPF_ATTR_DATA_FIELD(BPF_BTF_GET_FD_BY_ID);
 	BPF_ATTR_DATA_FIELD(BPF_TASK_FD_QUERY);
 	BPF_ATTR_DATA_FIELD(BPF_MAP_FREEZE);
+	BPF_ATTR_DATA_FIELD(BPF_MAP_LOOKUP_BATCH);
+	BPF_ATTR_DATA_FIELD(BPF_MAP_UPDATE_BATCH);
+	BPF_ATTR_DATA_FIELD(BPF_MAP_DELETE_BATCH);
+	BPF_ATTR_DATA_FIELD(BPF_LINK_CREATE);
+	BPF_ATTR_DATA_FIELD(BPF_LINK_UPDATE);
 	char char_data[256];
 };
 
@@ -109,8 +119,8 @@ sys_bpf(kernel_ulong_t cmd, kernel_ulong
 
 #ifdef INJECT_RETVAL
 	if (rc != INJECT_RETVAL)
-		error_msg_and_fail("Got a return value of %ld != %d",
-				   rc, INJECT_RETVAL);
+		error_msg_and_fail("Got a return value of %ld != %ld",
+				   rc, (long) INJECT_RETVAL);
 
 	static char inj_errstr[4096];
 
@@ -251,6 +261,8 @@ init_BPF_MAP_CREATE_attr7(struct bpf_att
 	attr->map_ifindex = ifindex_lo();
 }
 
+static_assert(ARRAY_SIZE(bpf_map_types_xdata) == 28,
+	      "The map_type for tests 1 and 2 below needs to be updated");
 static struct bpf_attr_check BPF_MAP_CREATE_checks[] = {
 	{
 		.data = { .BPF_MAP_CREATE_data = { .map_type = 2 } },
@@ -260,7 +272,7 @@ static struct bpf_attr_check BPF_MAP_CRE
 	},
 	{ /* 1 */
 		.data = { .BPF_MAP_CREATE_data = {
-			.map_type = 20,
+			.map_type = 27,
 			.key_size = 4,
 			.value_size = 8,
 			.max_entries = 256,
@@ -270,7 +282,7 @@ static struct bpf_attr_check BPF_MAP_CRE
 			.map_name = "0123456789abcde",
 		} },
 		.size = offsetof(struct BPF_MAP_CREATE_struct, map_name) + 8,
-		.str = "map_type=BPF_MAP_TYPE_REUSEPORT_SOCKARRAY, key_size=4"
+		.str = "map_type=BPF_MAP_TYPE_RINGBUF, key_size=4"
 		       ", value_size=8, max_entries=256"
 		       ", map_flags=BPF_F_NO_PREALLOC|BPF_F_NO_COMMON_LRU"
 				   "|BPF_F_NUMA_NODE|BPF_F_RDONLY|BPF_F_WRONLY"
@@ -282,7 +294,7 @@ static struct bpf_attr_check BPF_MAP_CRE
 	},
 	{ /* 2 */
 		.data = { .BPF_MAP_CREATE_data = {
-			.map_type = 26,
+			.map_type = 28,
 			.key_size = 0xface1e55,
 			.value_size = 0xbadc0ded,
 			.max_entries = 0xbeefcafe,
@@ -293,7 +305,7 @@ static struct bpf_attr_check BPF_MAP_CRE
 			.map_ifindex = 3141592653,
 		} },
 		.size = offsetofend(struct BPF_MAP_CREATE_struct, map_ifindex),
-		.str = "map_type=0x1a /* BPF_MAP_TYPE_??? */"
+		.str = "map_type=0x1c /* BPF_MAP_TYPE_??? */"
 		       ", key_size=4207812181, value_size=3134983661"
 		       ", max_entries=3203386110"
 		       ", map_flags=0xfffff800 /* BPF_F_??? */"
@@ -422,13 +434,35 @@ static struct bpf_attr_check BPF_MAP_CRE
 		       ", value_size=0"
 		       ", max_entries=0"
 		       ", map_flags=0"
-		       ", inner_map_fd=0"
+		       ", inner_map_fd=0" FD0_PATH
 		       ", map_name=\"\""
 		       ", map_ifindex=0"
 		       ", btf_fd=-1159983635"
 		       ", btf_key_type_id=4207869677"
 		       ", btf_value_type_id=3405705229"
 	},
+	{ /* 9 */
+		.data = { .BPF_MAP_CREATE_data = {
+			.btf_fd = 0xbadc0ded,
+			.btf_key_type_id = 0xfacefeed,
+			.btf_value_type_id = 0xcafef00d,
+			.btf_vmlinux_value_type_id = 0xdeadc0de,
+		} },
+		.size = offsetofend(struct BPF_MAP_CREATE_struct,
+				    btf_vmlinux_value_type_id),
+		.str = "map_type=BPF_MAP_TYPE_UNSPEC"
+		       ", key_size=0"
+		       ", value_size=0"
+		       ", max_entries=0"
+		       ", map_flags=0"
+		       ", inner_map_fd=0" FD0_PATH
+		       ", map_name=\"\""
+		       ", map_ifindex=0"
+		       ", btf_fd=-1159983635"
+		       ", btf_key_type_id=4207869677"
+		       ", btf_value_type_id=3405705229"
+		       ", btf_vmlinux_value_type_id=3735929054"
+	},
 };
 
 static const struct bpf_attr_check BPF_MAP_LOOKUP_ELEM_checks[] = {
@@ -606,7 +640,7 @@ print_BPF_PROG_LOAD_attr4(const struct b
 	       license, IFINDEX_LO_STR);
 }
 
-static_assert(ARRAY_SIZE(bpf_prog_types_xdata) == 27,
+static_assert(ARRAY_SIZE(bpf_prog_types_xdata) == 31,
 	      "The prog_type for test 5 below needs to be updated");
 static struct bpf_attr_check BPF_PROG_LOAD_checks[] = {
 	{
@@ -617,7 +651,7 @@ static struct bpf_attr_check BPF_PROG_LO
 	},
 	{ /* 1 */
 		.data = { .BPF_PROG_LOAD_data = {
-			.prog_type = 27,
+			.prog_type = 31,
 			.insn_cnt = 0xbadc0ded,
 			.insns = 0,
 			.license = 0,
@@ -628,7 +662,7 @@ static struct bpf_attr_check BPF_PROG_LO
 			.prog_flags = 0,
 		} },
 		.size = offsetofend(struct BPF_PROG_LOAD_struct, prog_flags),
-		.str = "prog_type=0x1b /* BPF_PROG_TYPE_??? */"
+		.str = "prog_type=0x1f /* BPF_PROG_TYPE_??? */"
 		       ", insn_cnt=3134983661, insns=NULL, license=NULL"
 		       ", log_level=42, log_size=3141592653, log_buf=NULL"
 		       ", kern_version=KERNEL_VERSION(51966, 240, 13)"
@@ -691,7 +725,7 @@ static struct bpf_attr_check BPF_PROG_LO
 	},
 	{ /* 5 */
 		.data = { .BPF_PROG_LOAD_data = {
-			.prog_type = 26,
+			.prog_type = 30,
 			.insn_cnt = 0xbadc0ded,
 			.insns = 0xffffffff00000000,
 			.license = 0xffffffff00000000,
@@ -703,7 +737,7 @@ static struct bpf_attr_check BPF_PROG_LO
 			.prog_name = "fedcba987654321",
 		} },
 		.size = offsetofend(struct BPF_PROG_LOAD_struct, prog_name),
-		.str = "prog_type=BPF_PROG_TYPE_TRACING"
+		.str = "prog_type=BPF_PROG_TYPE_SK_LOOKUP"
 		       ", insn_cnt=3134983661"
 		       ", insns=" BIG_ADDR("0xffffffff00000000", "NULL")
 		       ", license=" BIG_ADDR("0xffffffff00000000", "NULL")
@@ -764,7 +798,7 @@ static struct bpf_attr_check BPF_OBJ_PIN
 	{
 		.data = { .BPF_OBJ_PIN_data = { .pathname = 0 } },
 		.size = offsetofend(struct BPF_OBJ_PIN_struct, pathname),
-		.str = "pathname=NULL, bpf_fd=0"
+		.str = "pathname=NULL, bpf_fd=0" FD0_PATH
 	},
 	{
 		.data = { .BPF_OBJ_PIN_data = {
@@ -772,7 +806,7 @@ static struct bpf_attr_check BPF_OBJ_PIN
 		} },
 		.size = offsetofend(struct BPF_OBJ_PIN_struct, pathname),
 		.str = "pathname=" BIG_ADDR("0xffffffffffffffff", "0xffffffff")
-		       ", bpf_fd=0",
+		       ", bpf_fd=0" FD0_PATH,
 	},
 	{
 		.data = { .BPF_OBJ_PIN_data = { .bpf_fd = -1 } },
@@ -798,7 +832,7 @@ static const struct bpf_attr_check BPF_P
 	{
 		.data = { .BPF_PROG_ATTACH_data = { .target_fd = -1 } },
 		.size = offsetofend(struct BPF_PROG_ATTACH_struct, target_fd),
-		.str = "target_fd=-1, attach_bpf_fd=0"
+		.str = "target_fd=-1, attach_bpf_fd=0" FD0_PATH
 		       ", attach_type=BPF_CGROUP_INET_INGRESS, attach_flags=0"
 	},
 	{
@@ -806,13 +840,28 @@ static const struct bpf_attr_check BPF_P
 			.target_fd = -1,
 			.attach_bpf_fd = -2,
 			.attach_type = 2,
-			.attach_flags = 1
+			.attach_flags = 7
 		} },
 		.size = offsetofend(struct BPF_PROG_ATTACH_struct, attach_flags),
 		.str = "target_fd=-1, attach_bpf_fd=-2"
 		       ", attach_type=BPF_CGROUP_INET_SOCK_CREATE"
-		       ", attach_flags=BPF_F_ALLOW_OVERRIDE"
-	}
+		       ", attach_flags=BPF_F_ALLOW_OVERRIDE|BPF_F_ALLOW_MULTI"
+				       "|BPF_F_REPLACE"
+	},
+	{
+		.data = { .BPF_PROG_ATTACH_data = {
+			.target_fd = -1,
+			.attach_bpf_fd = -2,
+			.attach_type = 2,
+			.attach_flags = 0xf8,
+			.replace_bpf_fd = -3,
+		} },
+		.size = offsetofend(struct BPF_PROG_ATTACH_struct, replace_bpf_fd),
+		.str = "target_fd=-1, attach_bpf_fd=-2"
+		       ", attach_type=BPF_CGROUP_INET_SOCK_CREATE"
+		       ", attach_flags=0xf8 /* BPF_F_??? */"
+		       ", replace_bpf_fd=-3"
+	},
 };
 
 
@@ -1028,8 +1077,8 @@ print_BPF_PROG_QUERY_attr4(const struct
 	printf("query={target_fd=-1153374643"
 	       ", attach_type=0xfeedface /* BPF_??? */"
 	       ", query_flags=BPF_F_QUERY_EFFECTIVE|0xdeadf00c"
-	       ", attach_flags=BPF_F_ALLOW_MULTI|0xbeefcafc"
-#if defined(INJECT_RETVAL) && INJECT_RETVAL > 0
+	       ", attach_flags=BPF_F_ALLOW_MULTI|BPF_F_REPLACE|0xbeefcaf8"
+#if defined(INJECT_RETVAL)
 	       ", prog_ids=[0, 1, 4294967295, 2718281828], prog_cnt=4}"
 #else
 	       ", prog_ids=%p, prog_cnt=4}", prog_load_ids_ptr
@@ -1056,8 +1105,8 @@ print_BPF_PROG_QUERY_attr5(const struct
 	printf("query={target_fd=-1153374643"
 	       ", attach_type=0xfeedface /* BPF_??? */"
 	       ", query_flags=BPF_F_QUERY_EFFECTIVE|0xdeadf00c"
-	       ", attach_flags=BPF_F_ALLOW_MULTI|0xbeefcafc"
-#if defined(INJECT_RETVAL) && INJECT_RETVAL > 0
+	       ", attach_flags=BPF_F_ALLOW_MULTI|BPF_F_REPLACE|0xbeefcaf8"
+#if defined(INJECT_RETVAL)
 	       ", prog_ids=[0, 1, 4294967295, 2718281828, ... /* %p */]"
 	       ", prog_cnt=5}",
 	       prog_load_ids_ptr + ARRAY_SIZE(prog_load_ids)
@@ -1078,13 +1127,13 @@ static struct bpf_attr_check BPF_PROG_QU
 	{ /* 1 */
 		.data = { .BPF_PROG_QUERY_data = {
 			.target_fd = 3141592653U,
-			.attach_type = 16,
+			.attach_type = 37,
 			.query_flags = 1,
 			.attach_flags = 3,
 		} },
 		.size = offsetofend(struct BPF_PROG_QUERY_struct, attach_flags),
 		.str = "query={target_fd=-1153374643"
-		       ", attach_type=BPF_LIRC_MODE2"
+		       ", attach_type=BPF_XDP"
 		       ", query_flags=BPF_F_QUERY_EFFECTIVE"
 		       ", attach_flags=BPF_F_ALLOW_OVERRIDE|BPF_F_ALLOW_MULTI"
 		       ", prog_ids=NULL, prog_cnt=0}",
@@ -1092,17 +1141,17 @@ static struct bpf_attr_check BPF_PROG_QU
 	{ /* 2 */
 		.data = { .BPF_PROG_QUERY_data = {
 			.target_fd = 3141592653U,
-			.attach_type = 26,
+			.attach_type = 38,
 			.query_flags = 0xfffffffe,
-			.attach_flags = 0xfffffffc,
+			.attach_flags = 0xfffffff8,
 			.prog_ids = 0xffffffffffffffffULL,
 			.prog_cnt = 2718281828,
 		} },
 		.size = offsetofend(struct BPF_PROG_QUERY_struct, prog_cnt),
 		.str = "query={target_fd=-1153374643"
-		       ", attach_type=0x1a /* BPF_??? */"
+		       ", attach_type=0x26 /* BPF_??? */"
 		       ", query_flags=0xfffffffe /* BPF_F_QUERY_??? */"
-		       ", attach_flags=0xfffffffc /* BPF_F_??? */"
+		       ", attach_flags=0xfffffff8 /* BPF_F_??? */"
 		       ", prog_ids="
 		       BIG_ADDR("0xffffffffffffffff", "0xffffffff")
 		       ", prog_cnt=2718281828}",
@@ -1120,7 +1169,7 @@ static struct bpf_attr_check BPF_PROG_QU
 		.str = "query={target_fd=-1153374643"
 		       ", attach_type=0xfeedface /* BPF_??? */"
 		       ", query_flags=BPF_F_QUERY_EFFECTIVE|0xdeadf00c"
-		       ", attach_flags=BPF_F_ALLOW_MULTI|0xbeefcafc"
+		       ", attach_flags=BPF_F_ALLOW_MULTI|BPF_F_REPLACE|0xbeefcaf8"
 		       ", prog_ids=" BIG_ADDR_MAYBE("0xffffffffffffffff") "[]"
 		       ", prog_cnt=0}",
 	},
@@ -1166,7 +1215,7 @@ static struct bpf_attr_check BPF_RAW_TRA
 		.data = { .BPF_RAW_TRACEPOINT_OPEN_data = { .name = 0 } },
 		.size = offsetofend(struct BPF_RAW_TRACEPOINT_OPEN_struct,
 				    name),
-		.str = "raw_tracepoint={name=NULL, prog_fd=0}",
+		.str = "raw_tracepoint={name=NULL, prog_fd=0" FD0_PATH "}",
 	},
 	{ /* 1 */
 		.data = { .BPF_RAW_TRACEPOINT_OPEN_data = {
@@ -1240,16 +1289,16 @@ static const struct bpf_attr_check BPF_B
 
 static const struct bpf_attr_check BPF_TASK_FD_QUERY_checks[] = {
 	{
-		.data = { .BPF_TASK_FD_QUERY_data = { .pid = 0xdeadbeef } },
+		.data = { .BPF_TASK_FD_QUERY_data = { .pid = 1735928559 } },
 		.size = offsetofend(struct BPF_TASK_FD_QUERY_struct, pid),
-		.str = "task_fd_query={pid=3735928559, fd=0, flags=0"
-		       ", buf_len=0, buf=NULL, prog_id=0"
+		.str = "task_fd_query={pid=1735928559, fd=0" FD0_PATH
+		       ", flags=0, buf_len=0, buf=NULL, prog_id=0"
 		       ", fd_type=BPF_FD_TYPE_RAW_TRACEPOINT"
 		       ", probe_offset=0, probe_addr=0}"
 	},
 	{ /* 1 */
 		.data = { .BPF_TASK_FD_QUERY_data = {
-			.pid = 0xcafef00d,
+			.pid = 1405705229,
 			.fd = 0xdeadbeef,
 			.flags = 0xfacefeed,
 			.buf_len = 0xdefaced,
@@ -1260,7 +1309,7 @@ static const struct bpf_attr_check BPF_T
 			.probe_addr = 0xfac5fed5fac7fed8
 		} },
 		.size = offsetofend(struct BPF_TASK_FD_QUERY_struct, probe_addr),
-		.str = "task_fd_query={pid=3405705229"
+		.str = "task_fd_query={pid=1405705229"
 		       ", fd=-559038737"
 		       ", flags=4207869677"
 		       ", buf_len=233811181"
@@ -1272,6 +1321,117 @@ static const struct bpf_attr_check BPF_T
 	}
 };
 
+static const struct bpf_attr_check BPF_MAP_LOOKUP_BATCH_checks[] = {
+	{
+		.data = { .BPF_MAP_LOOKUP_BATCH_data = { .map_fd = -1 } },
+		.size = offsetofend(struct BPF_MAP_LOOKUP_BATCH_struct, map_fd ),
+		.str = "batch={in_batch=NULL, out_batch=NULL, keys=NULL"
+		       ", values=NULL, count=0, map_fd=-1, elem_flags=BPF_ANY"
+		       ", flags=0}"
+	},
+	{
+		.data = { .BPF_MAP_LOOKUP_BATCH_data = {
+			.in_batch = 0xfacefeed,
+			.out_batch = 0xbadc0ded,
+			.keys = 0xdeadf00d,
+			.values = 0xfffffffe,
+			.count = 3,
+			.map_fd = -1,
+			.elem_flags = 4,
+			.flags = 4
+		} },
+		.size = offsetofend(struct BPF_MAP_LOOKUP_BATCH_struct, flags),
+		.str = "batch={in_batch=0xfacefeed, out_batch=0xbadc0ded"
+		       ", keys=0xdeadf00d, values=0xfffffffe, count=3"
+		       ", map_fd=-1, elem_flags=BPF_F_LOCK, flags=0x4}"
+	}
+};
+
+static const struct bpf_attr_check BPF_MAP_UPDATE_BATCH_checks[] = {
+	{
+		.data = { .BPF_MAP_UPDATE_BATCH_data = { .map_fd = -1 } },
+		.size = offsetofend(struct BPF_MAP_UPDATE_BATCH_struct, map_fd ),
+		.str = "batch={keys=NULL, values=NULL, count=0, map_fd=-1"
+		       ", elem_flags=BPF_ANY, flags=0}"
+	},
+	{
+		.data = { .BPF_MAP_UPDATE_BATCH_data = {
+			.keys = 0xdeadf00d,
+			.values = 0xfffffffe,
+			.count = 3,
+			.map_fd = -1,
+			.elem_flags = 4,
+			.flags = 4
+		} },
+		.size = offsetofend(struct BPF_MAP_UPDATE_BATCH_struct, flags),
+		.str = "batch={keys=0xdeadf00d, values=0xfffffffe, count=3"
+		       ", map_fd=-1, elem_flags=BPF_F_LOCK, flags=0x4}"
+	}
+};
+
+static const struct bpf_attr_check BPF_MAP_DELETE_BATCH_checks[] = {
+	{
+		.data = { .BPF_MAP_DELETE_BATCH_data = { .map_fd = -1 } },
+		.size = offsetofend(struct BPF_MAP_DELETE_BATCH_struct, map_fd ),
+		.str = "batch={keys=NULL, count=0, map_fd=-1"
+		       ", elem_flags=BPF_ANY, flags=0}"
+	},
+	{
+		.data = { .BPF_MAP_DELETE_BATCH_data = {
+			.keys = 0xdeadf00d,
+			.count = 3,
+			.map_fd = -1,
+			.elem_flags = 4,
+			.flags = 4
+		} },
+		.size = offsetofend(struct BPF_MAP_DELETE_BATCH_struct, flags),
+		.str = "batch={keys=0xdeadf00d, count=3, map_fd=-1"
+		       ", elem_flags=BPF_F_LOCK, flags=0x4}"
+	}
+};
+
+static const struct bpf_attr_check BPF_LINK_CREATE_checks[] = {
+	{
+		.data = { .BPF_LINK_CREATE_data = { .prog_fd = -1, .target_fd = -2 } },
+		.size = offsetofend(struct BPF_LINK_CREATE_struct, flags),
+		.str = "link_create={prog_fd=-1, target_fd=-2"
+		       ", attach_type=BPF_CGROUP_INET_INGRESS, flags=0}"
+	},
+	{
+		.data = { .BPF_LINK_CREATE_data = {
+			.prog_fd = -1,
+			.target_fd = 0xdeadbeef,
+			.attach_type = 5,
+			.flags = 4
+		} },
+		.size = offsetofend(struct BPF_LINK_CREATE_struct, flags),
+		.str = "link_create={prog_fd=-1, target_fd=-559038737"
+		       ", attach_type=BPF_SK_SKB_STREAM_VERDICT, flags=0x4}"
+	}
+};
+
+static const struct bpf_attr_check BPF_LINK_UPDATE_checks[] = {
+	{
+		.data = { .BPF_LINK_UPDATE_data = {
+			.link_fd = -1,
+			.new_prog_fd = -2
+		} },
+		.size = offsetofend(struct BPF_LINK_UPDATE_struct, old_prog_fd),
+		.str = "link_update={link_fd=-1, new_prog_fd=-2, flags=0}"
+	},
+	{
+		.data = { .BPF_LINK_UPDATE_data = {
+			.link_fd = -1,
+			.new_prog_fd = 0xdeadbeef,
+			.flags = 4,
+			.old_prog_fd = 0xdeadf00d
+		} },
+		.size = offsetofend(struct BPF_LINK_UPDATE_struct, old_prog_fd),
+		.str = "link_update={link_fd=-1, new_prog_fd=-559038737"
+		       ", flags=BPF_F_REPLACE, old_prog_fd=-559026163}"
+	}
+};
+
 
 #define CHK(cmd_) \
 	{ \
@@ -1308,6 +1468,11 @@ main(void)
 		CHK(BPF_MAP_LOOKUP_AND_DELETE_ELEM),
 		CHK(BPF_MAP_FREEZE),
 		CHK(BPF_BTF_GET_NEXT_ID),
+		CHK(BPF_MAP_LOOKUP_BATCH),
+		CHK(BPF_MAP_UPDATE_BATCH),
+		CHK(BPF_MAP_DELETE_BATCH),
+		CHK(BPF_LINK_CREATE),
+		CHK(BPF_LINK_UPDATE),
 	};
 
 	page_size = get_page_size();
diff -pruN 5.5-3/tests-m32/bpf-obj_get_info_by_fd.c 5.9-0ubuntu2/tests-m32/bpf-obj_get_info_by_fd.c
--- 5.5-3/tests-m32/bpf-obj_get_info_by_fd.c	2019-12-11 22:44:53.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/bpf-obj_get_info_by_fd.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check bpf(BPF_OBJ_GET_INFO_BY_FD) decoding.
  *
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -87,6 +87,10 @@ print_map_create(void *attr_void, size_t
 		printf(", btf_fd=0</dev/null>"
 		       ", btf_key_type_id=0, btf_value_type_id=0");
 	}
+	if (size > offsetof(struct BPF_MAP_CREATE_struct,
+			    btf_vmlinux_value_type_id)) {
+		printf(", btf_vmlinux_value_type_id=0");
+	}
 	printf("}, %zu) = ", size);
 	if (rc >= 0)
 		printf("%ld<anon_inode:bpf-map>\n", rc);
@@ -353,6 +357,10 @@ main(int ac, char **av)
 	    offsetof(struct bpf_map_info_struct, ifindex))
 		printf(", ifindex=%u", map_info->ifindex);
 	if (bpf_map_get_info_attr.info_len >
+	    offsetof(struct bpf_map_info_struct, btf_vmlinux_value_type_id))
+		printf(", btf_vmlinux_value_type_id=%u",
+		       map_info->btf_vmlinux_value_type_id);
+	if (bpf_map_get_info_attr.info_len >
 	    offsetof(struct bpf_map_info_struct, netns_dev))
 		printf(", netns_dev=makedev(%#x, %#x)",
 		       major(map_info->netns_dev), minor(map_info->netns_dev));
diff -pruN 5.5-3/tests-m32/bpf-success-long-y.c 5.9-0ubuntu2/tests-m32/bpf-success-long-y.c
--- 5.5-3/tests-m32/bpf-success-long-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/bpf-success-long-y.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,3 @@
+#define INJECT_RETVAL ((long) 0xbadc0de1e55beefULL)
+#define FD0_PATH "</dev/full>"
+#include "bpf.c"
diff -pruN 5.5-3/tests-m32/bpf-success-long-y.test 5.9-0ubuntu2/tests-m32/bpf-success-long-y.test
--- 5.5-3/tests-m32/bpf-success-long-y.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/bpf-success-long-y.test	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,16 @@
+:#!/bin/sh -efu
+#
+# Copyright (c) 2018-2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: GPL-2.0-or-later
+
+. "${srcdir=.}/scno_tampering.sh"
+
+case "$SIZEOF_LONG" in
+	4) rval=508935919;;
+	8) rval=841540765612359407;;
+esac
+
+run_strace -a20 -y -e trace=bpf -e inject=bpf:retval="${rval}" ../bpf-success-long-y < /dev/full > "$EXP"
+match_diff "$LOG" "$EXP"
diff -pruN 5.5-3/tests-m32/btrfs.c 5.9-0ubuntu2/tests-m32/btrfs.c
--- 5.5-3/tests-m32/btrfs.c	2019-07-24 17:12:18.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/btrfs.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -815,7 +815,7 @@ btrfs_test_clone_ioctls(void)
 		args.dest_offset);
 }
 
-# define BTRFS_COMPRESS_TYPES 2
+# define BTRFS_COMPRESS_TYPES 3
 # define BTRFS_INVALID_COMPRESS (BTRFS_COMPRESS_TYPES + 1)
 
 static void
diff -pruN 5.5-3/tests-m32/caps-abbrev.awk 5.9-0ubuntu2/tests-m32/caps-abbrev.awk
--- 5.5-3/tests-m32/caps-abbrev.awk	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/caps-abbrev.awk	2020-09-06 08:00:00.000000000 +0000
@@ -3,12 +3,13 @@
 # This file is part of caps strace test.
 #
 # Copyright (c) 2014-2018 Dmitry V. Levin <ldv@altlinux.org>
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 BEGIN {
-	cap = "(0|1<<CAP_[A-Z_]+(\\|1<<CAP_[A-Z_]+)*|1<<CAP_[A-Z_]+(\\|1<<CAP_[A-Z_]+){37}\\|0xffffffc0)"
+	cap = "(0|1<<CAP_[A-Z_]+(\\|1<<CAP_[A-Z_]+)*|1<<CAP_[A-Z_]+(\\|1<<CAP_[A-Z_]+){40}\\|0xfffffe00)"
 	s_efault = "-1 EFAULT (Bad address)"
 	r_efault = "-1 EFAULT \\(Bad address\\)"
 	r_einval = "-1 EINVAL \\(Invalid argument\\)"
diff -pruN 5.5-3/tests-m32/caps.awk 5.9-0ubuntu2/tests-m32/caps.awk
--- 5.5-3/tests-m32/caps.awk	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/caps.awk	2020-09-06 08:00:00.000000000 +0000
@@ -2,13 +2,13 @@
 #
 # This file is part of caps strace test.
 #
-# Copyright (c) 2014-2018 Dmitry V. Levin <ldv@altlinux.org>
+# Copyright (c) 2014-2020 Dmitry V. Levin <ldv@altlinux.org>
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 BEGIN {
-	cap = "(0|1<<CAP_[A-Z_]+(\\|1<<CAP_[A-Z_]+)*|1<<CAP_[A-Z_]+(\\|1<<CAP_[A-Z_]+){37}\\|0xffffffc0)"
+	cap = "(0|1<<CAP_[A-Z_]+(\\|1<<CAP_[A-Z_]+)*|1<<CAP_[A-Z_]+(\\|1<<CAP_[A-Z_]+){40}\\|0xfffffe00)"
 	s_efault = "-1 EFAULT (Bad address)"
 	r_efault = "-1 EFAULT \\(Bad address\\)"
 	r_einval = "-1 EINVAL \\(Invalid argument\\)"
diff -pruN 5.5-3/tests-m32/clock_nanosleep.c 5.9-0ubuntu2/tests-m32/clock_nanosleep.c
--- 5.5-3/tests-m32/clock_nanosleep.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/clock_nanosleep.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,22 +2,25 @@
  * Check decoding of clock_nanosleep and clock_gettime syscalls.
  *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-#include <assert.h>
-#include <stdio.h>
-#include <stdint.h>
-#include <signal.h>
-#include <time.h>
-#include <unistd.h>
-#include <sys/time.h>
 #include "scno.h"
 
+#ifdef __NR_clock_nanosleep
+
+# include <assert.h>
+# include <stdio.h>
+# include <stdint.h>
+# include <signal.h>
+# include <time.h>
+# include <unistd.h>
+# include <sys/time.h>
+
 static void
 handler(int signo)
 {
@@ -127,3 +130,9 @@ main(void)
 	puts("+++ exited with 0 +++");
 	return 0;
 }
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_clock_nanosleep")
+
+#endif
diff -pruN 5.5-3/tests-m32/clone3.c 5.9-0ubuntu2/tests-m32/clone3.c
--- 5.5-3/tests-m32/clone3.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/clone3.c	2020-06-07 08:00:00.000000000 +0000
@@ -50,9 +50,10 @@ struct test_clone_args {
 	uint64_t tls;
 	uint64_t set_tid;
 	uint64_t set_tid_size;
+	uint64_t cgroup;
 };
 
-#ifdef HAVE_STRUCT_CLONE_ARGS_SET_TID_SIZE
+#ifdef HAVE_STRUCT_CLONE_ARGS_CGROUP
 typedef struct clone_args struct_clone_args;
 #else
 typedef struct test_clone_args struct_clone_args;
@@ -66,18 +67,14 @@ enum validity_flag_bits {
 	TLS_VALID_BIT,
 };
 
-#define _(x_) x_ = 1 << x_##_BIT
-
 enum validity_flags {
-	_(STRUCT_VALID),
-	_(PIDFD_VALID),
-	_(CHILD_TID_VALID),
-	_(PARENT_TID_VALID),
-	_(TLS_VALID),
+	FLAG(STRUCT_VALID),
+	FLAG(PIDFD_VALID),
+	FLAG(CHILD_TID_VALID),
+	FLAG(PARENT_TID_VALID),
+	FLAG(TLS_VALID),
 };
 
-#undef _
-
 #define MAX_SET_TID_SIZE 32
 
 static const int child_exit_status = 42;
@@ -267,6 +264,10 @@ print_clone3(struct_clone_args *const ar
 	    (arg->set_tid || arg->set_tid_size))
 		print_set_tid(arg->set_tid, arg->set_tid_size);
 
+	if (sz > offsetof(struct_clone_args, cgroup) &&
+	    (arg->cgroup || arg->flags & CLONE_INTO_CGROUP))
+		printf(", cgroup=%" PRIu64, (uint64_t) arg->cgroup);
+
 	printf("}");
 
 	if (rc < 0)
@@ -405,6 +406,19 @@ main(int argc, char *argv[])
 	printf(", %zu) = %s" INJ_STR, sizeof(*arg), sprintrc(rc));
 	memset(arg, 0, sizeof(*arg));
 
+	arg->cgroup = 0xfacefeedbadc0ded;
+	rc = do_clone3(arg, sizeof(*arg), ERR(0) | ERR(E2BIG));
+	print_clone3(arg, rc, sizeof(*arg), STRUCT_VALID, "0", "0");
+	printf(", %zu) = %s" INJ_STR, sizeof(*arg), sprintrc(rc));
+	memset(arg, 0, sizeof(*arg));
+
+	arg->flags = CLONE_INTO_CGROUP;
+	rc = do_clone3(arg, sizeof(*arg), ERR(0) | ERR(EINVAL) | ERR(EBADF));
+	print_clone3(arg, rc, sizeof(*arg), STRUCT_VALID,
+		     "CLONE_INTO_CGROUP", "0");
+	printf(", %zu) = %s" INJ_STR, sizeof(*arg), sprintrc(rc));
+	memset(arg, 0, sizeof(*arg));
+
 	/*
 	 * NB: the following check is purposefully fragile (it will break
 	 *     when system's struct clone_args has additional fields,
@@ -446,18 +460,20 @@ main(int argc, char *argv[])
 	       ", %zu) = %s" INJ_STR,
 	       sizeof(*arg) + 16, sprintrc(rc));
 
-	arg->flags = 0xfacefeedbeefc0de;
+	arg->flags = 0xface3eefbeefc0de;
 	arg->exit_signal = 0x1e55c0de;
 	rc = do_clone3(arg, 64, ERR(EINVAL));
 	printf("clone3({flags=%s, child_tid=NULL, exit_signal=508936414"
 	       ", stack=NULL, stack_size=0, tls=NULL}, 64) = %s" INJ_STR,
-	       XLAT_KNOWN(0xfacefeedbeefc0de, "CLONE_VFORK|CLONE_PARENT"
+	       XLAT_KNOWN(0xface3eefbeefc0de, "CLONE_VFORK|CLONE_PARENT"
 	       "|CLONE_THREAD|CLONE_NEWNS|CLONE_SYSVSEM|CLONE_SETTLS"
 	       "|CLONE_CHILD_CLEARTID|CLONE_UNTRACED|CLONE_NEWCGROUP"
 	       "|CLONE_NEWUTS|CLONE_NEWIPC|CLONE_NEWUSER|CLONE_NEWPID|CLONE_IO"
-	       "|CLONE_CLEAR_SIGHAND|0xfacefeec004000de"), sprintrc(rc));
+	       "|CLONE_NEWTIME|CLONE_CLEAR_SIGHAND|CLONE_INTO_CGROUP"
+	       "|0xface3eec0040005e"),
+	       sprintrc(rc));
 
-	arg->flags = 0xdec0deac004000ffULL;
+	arg->flags = 0xdec0deac0040007fULL;
 	arg->exit_signal = 250;
 	arg->stack = 0xface1e55beeff00dULL;
 	arg->stack_size = 0xcaffeedefacedca7ULL;
@@ -465,7 +481,7 @@ main(int argc, char *argv[])
 	printf("clone3({flags=%s, exit_signal=250"
 	       ", stack=0xface1e55beeff00d, stack_size=0xcaffeedefacedca7}, 64)"
 	       " = %s" INJ_STR,
-	       XLAT_UNKNOWN(0xdec0deac004000ff, "CLONE_???"),
+	       XLAT_UNKNOWN(0xdec0deac0040007f, "CLONE_???"),
 	       sprintrc(rc));
 
 	arg->exit_signal = SIGCHLD;
diff -pruN 5.5-3/tests-m32/clone-flags.test 5.9-0ubuntu2/tests-m32/clone-flags.test
--- 5.5-3/tests-m32/clone-flags.test	2019-06-20 09:49:27.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/clone-flags.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
 #
 # Check decoding of clone flags.
 #
-# Copyright (c) 2019 The strace developers.
+# Copyright (c) 2019-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -15,10 +15,10 @@ case "$STRACE_ARCH" in
 esac
 
 # Find out the expected and reported child stack addresses.
-run_strace_match_grep -qq -e signal=none -e trace=$syscall
+run_strace_match_grep --silence=exits -e signal=none -e trace=$syscall
 CHILD_STACK_EXPECTED="$(sed -n 's/^clone[^(]*(child_stack=(\(0x[[:xdigit:]]\+\)|.*/\1/p' "$EXP")000"
 CHILD_STACK_REPORTED="$(sed -n 's/^clone[^(]*(child_stack=\(0x[[:xdigit:]]\+\),.*/\1/p' "$LOG")"
 export CHILD_STACK_EXPECTED CHILD_STACK_REPORTED
 
 # Use child stack addresses to check decoding.
-run_strace_match_diff -a35 -qq -y -e signal=none -e trace=$syscall
+run_strace_match_diff -a35 --silence=exits,personality -y -e signal=none -e trace=$syscall
diff -pruN 5.5-3/tests-m32/clone_parent.c 5.9-0ubuntu2/tests-m32/clone_parent.c
--- 5.5-3/tests-m32/clone_parent.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/clone_parent.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check handling of CLONE_PARENT'ed processes.
  *
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -17,6 +17,10 @@
 #include <sys/wait.h>
 #include <unistd.h>
 
+#ifndef QUIET_MSG
+# define QUIET_MSG 0
+#endif
+
 static int
 child(void *const arg)
 {
@@ -56,10 +60,14 @@ main(void)
 	FILE *const fp = fdopen(3, "a");
 	if (!fp)
 		perror_msg_and_fail("fdopen");
+#if !QUIET_MSG
 	if (fprintf(fp, "%s: Exit of unknown pid %d ignored\n",
 		    getenv("STRACE_EXE") ?: "strace", pid) < 0)
 		perror_msg_and_fail("fprintf");
+#endif
 
+#if !QUIET_MSG
 	puts("+++ exited with 0 +++");
+#endif
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/clone_parent.gen.test 5.9-0ubuntu2/tests-m32/clone_parent.gen.test
--- 5.5-3/tests-m32/clone_parent.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/clone_parent.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (clone_parent +clone_ptrace.test ); do not edit.
+set -- 
+. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests-m32/clone_parent-q.c 5.9-0ubuntu2/tests-m32/clone_parent-q.c
--- 5.5-3/tests-m32/clone_parent-q.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/clone_parent-q.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define QUIET_MSG 0
+#include "clone_parent.c"
diff -pruN 5.5-3/tests-m32/clone_parent-q.gen.test 5.9-0ubuntu2/tests-m32/clone_parent-q.gen.test
--- 5.5-3/tests-m32/clone_parent-q.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/clone_parent-q.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (clone_parent-q +clone_ptrace.test -q); do not edit.
+set -- -q
+. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests-m32/clone_parent-qq.c 5.9-0ubuntu2/tests-m32/clone_parent-qq.c
--- 5.5-3/tests-m32/clone_parent-qq.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/clone_parent-qq.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define QUIET_MSG 1
+#include "clone_parent.c"
diff -pruN 5.5-3/tests-m32/clone_parent-qq.gen.test 5.9-0ubuntu2/tests-m32/clone_parent-qq.gen.test
--- 5.5-3/tests-m32/clone_parent-qq.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/clone_parent-qq.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (clone_parent-qq +clone_ptrace.test -qq); do not edit.
+set -- -qq
+. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests-m32/clone_parent--quiet-exit.c 5.9-0ubuntu2/tests-m32/clone_parent--quiet-exit.c
--- 5.5-3/tests-m32/clone_parent--quiet-exit.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/clone_parent--quiet-exit.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define QUIET_MSG 1
+#include "clone_parent.c"
diff -pruN 5.5-3/tests-m32/clone_parent--quiet-exit.gen.test 5.9-0ubuntu2/tests-m32/clone_parent--quiet-exit.gen.test
--- 5.5-3/tests-m32/clone_parent--quiet-exit.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/clone_parent--quiet-exit.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (clone_parent--quiet-exit +clone_ptrace.test --quiet=exit,personality); do not edit.
+set -- --quiet=exit,personality
+. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests-m32/clone_parent.test 5.9-0ubuntu2/tests-m32/clone_parent.test
--- 5.5-3/tests-m32/clone_parent.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/clone_parent.test	1970-01-01 00:00:00.000000000 +0000
@@ -1,10 +0,0 @@
-#!/bin/sh -efu
-#
-# Check handling of CLONE_PARENT'ed processes.
-#
-# Copyright (c) 2017-2018 The strace developers.
-# All rights reserved.
-#
-# SPDX-License-Identifier: GPL-2.0-or-later
-
-. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests-m32/clone_ptrace.c 5.9-0ubuntu2/tests-m32/clone_ptrace.c
--- 5.5-3/tests-m32/clone_ptrace.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/clone_ptrace.c	2020-07-17 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check handling of CLONE_PTRACE'ed processes.
  *
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -20,6 +20,13 @@
 
 static siginfo_t sinfo;
 
+#ifndef QUIET_ATTACH
+# define QUIET_ATTACH 0
+#endif
+#ifndef QUIET_EXIT
+# define QUIET_EXIT 0
+#endif
+
 static void
 handler(const int no, siginfo_t *const si, void *const uc)
 {
@@ -74,9 +81,11 @@ main(void)
 	FILE *const fp = fdopen(3, "a");
 	if (!fp)
 		perror_msg_and_fail("fdopen");
+#if !QUIET_ATTACH
 	if (fprintf(fp, "%s: Detached unknown pid %d\n",
 		    getenv("STRACE_EXE") ?: "strace", pid) < 0)
 		perror_msg_and_fail("fprintf");
+#endif
 
 	int status;
 	while (wait(&status) != pid) {
@@ -87,8 +96,11 @@ main(void)
 		error_msg_and_fail("unexpected child exit status %d", status);
 
 	printf("--- SIGCHLD {si_signo=SIGCHLD, si_code=CLD_KILLED, si_pid=%d"
-	       ", si_uid=%u, si_status=%s, si_utime=%u, si_stime=%u} ---\n"
-	       "+++ exited with 0 +++\n", pid, geteuid(), "SIGUSR1",
+	       ", si_uid=%d, si_status=%s, si_utime=%u, si_stime=%u} ---\n"
+#if !QUIET_EXIT
+	       "+++ exited with 0 +++\n"
+#endif
+	       , pid, geteuid(), "SIGUSR1",
 	       (unsigned int) sinfo.si_utime, (unsigned int) sinfo.si_stime);
 
 	return 0;
diff -pruN 5.5-3/tests-m32/clone_ptrace-q.c 5.9-0ubuntu2/tests-m32/clone_ptrace-q.c
--- 5.5-3/tests-m32/clone_ptrace-q.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/clone_ptrace-q.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define QUIET_ATTACH 1
+#include "clone_ptrace.c"
diff -pruN 5.5-3/tests-m32/clone_ptrace-q.gen.test 5.9-0ubuntu2/tests-m32/clone_ptrace-q.gen.test
--- 5.5-3/tests-m32/clone_ptrace-q.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/clone_ptrace-q.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (clone_ptrace-q +clone_ptrace.test -q); do not edit.
+set -- -q
+. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests-m32/clone_ptrace-qq.c 5.9-0ubuntu2/tests-m32/clone_ptrace-qq.c
--- 5.5-3/tests-m32/clone_ptrace-qq.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/clone_ptrace-qq.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,3 @@
+#define QUIET_ATTACH 1
+#define QUIET_EXIT 1
+#include "clone_ptrace.c"
diff -pruN 5.5-3/tests-m32/clone_ptrace-qq.gen.test 5.9-0ubuntu2/tests-m32/clone_ptrace-qq.gen.test
--- 5.5-3/tests-m32/clone_ptrace-qq.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/clone_ptrace-qq.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (clone_ptrace-qq +clone_ptrace.test -qq); do not edit.
+set -- -qq
+. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests-m32/clone_ptrace--quiet-attach.c 5.9-0ubuntu2/tests-m32/clone_ptrace--quiet-attach.c
--- 5.5-3/tests-m32/clone_ptrace--quiet-attach.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/clone_ptrace--quiet-attach.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define QUIET_ATTACH 1
+#include "clone_ptrace.c"
diff -pruN 5.5-3/tests-m32/clone_ptrace--quiet-attach.gen.test 5.9-0ubuntu2/tests-m32/clone_ptrace--quiet-attach.gen.test
--- 5.5-3/tests-m32/clone_ptrace--quiet-attach.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/clone_ptrace--quiet-attach.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (clone_ptrace--quiet-attach +clone_ptrace.test --quiet=attach,personality); do not edit.
+set -- --quiet=attach,personality
+. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests-m32/clone_ptrace--quiet-exit.c 5.9-0ubuntu2/tests-m32/clone_ptrace--quiet-exit.c
--- 5.5-3/tests-m32/clone_ptrace--quiet-exit.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/clone_ptrace--quiet-exit.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define QUIET_EXIT 1
+#include "clone_ptrace.c"
diff -pruN 5.5-3/tests-m32/clone_ptrace--quiet-exit.gen.test 5.9-0ubuntu2/tests-m32/clone_ptrace--quiet-exit.gen.test
--- 5.5-3/tests-m32/clone_ptrace--quiet-exit.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/clone_ptrace--quiet-exit.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (clone_ptrace--quiet-exit +clone_ptrace.test --quiet=exit,personality); do not edit.
+set -- --quiet=exit,personality
+. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests-m32/clone_ptrace.test 5.9-0ubuntu2/tests-m32/clone_ptrace.test
--- 5.5-3/tests-m32/clone_ptrace.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/clone_ptrace.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
 #
 # Check handling of CLONE_PTRACE'ed processes.
 #
-# Copyright (c) 2017-2018 The strace developers.
+# Copyright (c) 2017-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,7 +10,7 @@
 . "${srcdir=.}/init.sh"
 
 run_prog > /dev/null 3>&1
-args="-e trace=none $args"
+args="-e trace=none ${1:---quiet=personality} $args"
 > "$LOG" || fail_ "failed to write $LOG"
 
 $STRACE -o "$LOG" $args > "$EXP" 2> "$OUT"-err 3> "$EXP"-err || {
diff -pruN 5.5-3/tests-m32/close_range.c 5.9-0ubuntu2/tests-m32/close_range.c
--- 5.5-3/tests-m32/close_range.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/close_range.c	2020-09-23 16:29:35.000000000 +0000
@@ -0,0 +1,147 @@
+/*
+ * Check decoding of close_range syscall.
+ *
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+
+#ifdef __NR_close_range
+
+# include <fcntl.h>
+# include <stdio.h>
+# include <unistd.h>
+
+# ifdef HAVE_LINUX_CLOSE_RANGE_H
+#  include <linux/close_range.h>
+# else
+#  define CLOSE_RANGE_UNSHARE	(1U << 1)
+# endif
+
+# ifndef FD0_PATH
+#  define FD0_PATH ""
+# endif
+# ifndef FD7_PATH
+#  define FD7_PATH ""
+# endif
+# ifndef SKIP_IF_PROC_IS_UNAVAILABLE
+#  define SKIP_IF_PROC_IS_UNAVAILABLE
+# endif
+
+static const char *errstr;
+
+static long
+k_close_range(const unsigned int fd1, const unsigned int fd2, const unsigned int flags)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+	const kernel_ulong_t arg1 = fill | fd1;
+	const kernel_ulong_t arg2 = fill | fd2;
+	const kernel_ulong_t arg3 = fill | flags;
+	const long rc = syscall(__NR_close_range, arg1, arg2, arg3, bad, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
+
+static void
+xdup2(int fd1, int fd2)
+{
+	if (dup2(fd1, fd2) != fd2)
+		perror_msg_and_fail("dup2(%d, %d)", fd1, fd2);
+}
+
+int
+main(void)
+{
+	SKIP_IF_PROC_IS_UNAVAILABLE;
+
+	const int fd0 = dup(0);
+	const int fd7 = dup(7);
+	const int fd7_min = MIN(7, fd7);
+	const int fd7_max = MAX(7, fd7);
+
+	k_close_range(-2, -1, 1);
+# ifndef PATH_TRACING
+	printf("close_range(-2, -1, 0x1 /* CLOSE_RANGE_??? */) = %s\n", errstr);
+# endif
+
+	k_close_range(-1, -2, 2);
+# ifndef PATH_TRACING
+	printf("close_range(-1, -2, CLOSE_RANGE_UNSHARE) = %s\n", errstr);
+# endif
+
+	k_close_range(-3, 0, 4);
+# ifndef PATH_TRACING
+	printf("close_range(-3, 0" FD0_PATH ", 0x4 /* CLOSE_RANGE_??? */)"
+	       " = %s\n", errstr);
+# endif
+
+	k_close_range(0, -4, -1);
+# ifndef PATH_TRACING
+	printf("close_range(0" FD0_PATH ", -4, CLOSE_RANGE_UNSHARE|%#x) = %s\n",
+	       (-1U & ~CLOSE_RANGE_UNSHARE), errstr);
+# endif
+
+	k_close_range(-5, 7, 0);
+	printf("close_range(-5, 7" FD7_PATH ", 0) = %s\n", errstr);
+
+	k_close_range(7, -6, 1);
+	printf("close_range(7" FD7_PATH ", -6, 0x1 /* CLOSE_RANGE_??? */)"
+	       " = %s\n", errstr);
+
+	k_close_range(7, 7, 4);
+	printf("close_range(7" FD7_PATH ", 7" FD7_PATH
+	       ", 0x4 /* CLOSE_RANGE_??? */) = %s\n", errstr);
+
+	k_close_range(-7, -7, 7);
+# ifndef PATH_TRACING
+	printf("close_range(-7, -7, CLOSE_RANGE_UNSHARE|0x5) = %s\n", errstr);
+# endif
+
+	k_close_range(7, 0, 0);
+	printf("close_range(7" FD7_PATH ", 0" FD0_PATH ", 0) = %s\n", errstr);
+
+	k_close_range(fd7, fd0, 0);
+	printf("close_range(%d" FD7_PATH ", %d" FD0_PATH ", 0) = %s\n",
+	       fd7, fd0, errstr);
+
+	if (k_close_range(0, 0, 0) == 0)
+		xdup2(fd0, 0);
+# ifndef PATH_TRACING
+	printf("close_range(0" FD0_PATH ", 0" FD0_PATH ", 0) = %s\n", errstr);
+# endif
+
+	if (k_close_range(fd0, fd0, 0) == 0)
+		xdup2(0, fd0);
+# ifndef PATH_TRACING
+	printf("close_range(%d" FD0_PATH ", %d" FD0_PATH ", 0) = %s\n",
+	       fd0, fd0, errstr);
+# endif
+
+	if (k_close_range(7, 7, 0) == 0)
+		xdup2(fd7, 7);
+	printf("close_range(7" FD7_PATH ", 7" FD7_PATH ", 0) = %s\n", errstr);
+
+	if (k_close_range(fd7, fd7, 0) == 0)
+		xdup2(7, fd7);
+	printf("close_range(%d" FD7_PATH ", %d" FD7_PATH ", 0) = %s\n",
+	       fd7, fd7, errstr);
+
+	if (k_close_range(fd7_max, -1, 0) == 0)
+		xdup2(fd7_min, fd7_max);
+	printf("close_range(%d" FD7_PATH ", -1, 0) = %s\n",
+	       fd7_max, errstr);
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_close_range")
+
+#endif
diff -pruN 5.5-3/tests-m32/close_range.gen.test 5.9-0ubuntu2/tests-m32/close_range.gen.test
--- 5.5-3/tests-m32/close_range.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/close_range.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (close_range -a21 7>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a21 7>>/dev/full
diff -pruN 5.5-3/tests-m32/close_range-P.c 5.9-0ubuntu2/tests-m32/close_range-P.c
--- 5.5-3/tests-m32/close_range-P.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/close_range-P.c	2020-09-06 08:00:00.000000000 +0000
@@ -0,0 +1,4 @@
+#define PATH_TRACING
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "close_range.c"
diff -pruN 5.5-3/tests-m32/close_range-P.gen.test 5.9-0ubuntu2/tests-m32/close_range-P.gen.test
--- 5.5-3/tests-m32/close_range-P.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/close_range-P.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (close_range-P -a21 --trace=close_range -P /dev/full 7>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a21 --trace=close_range -P /dev/full 7>>/dev/full
diff -pruN 5.5-3/tests-m32/close_range-y.c 5.9-0ubuntu2/tests-m32/close_range-y.c
--- 5.5-3/tests-m32/close_range-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/close_range-y.c	2020-09-06 08:00:00.000000000 +0000
@@ -0,0 +1,5 @@
+#define FD0_PATH "</dev/null>"
+#define FD7_PATH "</dev/full>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "close_range.c"
diff -pruN 5.5-3/tests-m32/close_range-y.gen.test 5.9-0ubuntu2/tests-m32/close_range-y.gen.test
--- 5.5-3/tests-m32/close_range-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/close_range-y.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (close_range-y -a33 --trace=close_range -y 7>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a33 --trace=close_range -y 7>>/dev/full
diff -pruN 5.5-3/tests-m32/close_range-yy.c 5.9-0ubuntu2/tests-m32/close_range-yy.c
--- 5.5-3/tests-m32/close_range-yy.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/close_range-yy.c	2020-09-06 08:00:00.000000000 +0000
@@ -0,0 +1,5 @@
+#define FD0_PATH "</dev/null<char 1:3>>"
+#define FD7_PATH "</dev/full<char 1:7>>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "close_range.c"
diff -pruN 5.5-3/tests-m32/close_range-yy.gen.test 5.9-0ubuntu2/tests-m32/close_range-yy.gen.test
--- 5.5-3/tests-m32/close_range-yy.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/close_range-yy.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (close_range-yy -a33 --trace=close_range -yy 7>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a33 --trace=close_range -yy 7>>/dev/full
diff -pruN 5.5-3/tests-m32/count-f.test 5.9-0ubuntu2/tests-m32/count-f.test
--- 5.5-3/tests-m32/count-f.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/count-f.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
 #
 # Check whether -c counts through forks and clones properly.
 #
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,7 +10,7 @@
 . "${srcdir=.}/init.sh"
 
 run_prog
-run_strace -q -f -c $args
+run_strace -e silent=attach -f -c $args
 match_grep
 
 exit 0
diff -pruN 5.5-3/tests-m32/count.test 5.9-0ubuntu2/tests-m32/count.test
--- 5.5-3/tests-m32/count.test	2019-08-06 13:38:20.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/count.test	2020-04-03 22:58:26.000000000 +0000
@@ -3,7 +3,7 @@
 # Check whether -c and -w options work.
 #
 # Copyright (c) 2014-2016 Dmitry V. Levin <ldv@altlinux.org>
-# Copyright (c) 2014-2018 The strace developers.
+# Copyright (c) 2014-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -36,6 +36,7 @@ HALFCLOCK=' *[^ ]+ +0\.[567][^n]*nanosle
 
 grep_log "$GENERIC"	-c
 grep_log "$GENERIC"	-c -O1
+grep_log "$GENERIC"	-c --summary-syscall-overhead=1
 grep_log "$GENERIC"	-c -enanosleep
 grep_log "$GENERIC"	-c -O1 -enanosleep
 grep_log "$WALLCLOCK"	-cw
@@ -43,7 +44,10 @@ grep_log "$WALLCLOCK"	-cw -O1
 grep_log "$WALLCLOCK1"	-cw -enanosleep
 grep_log "$WALLCLOCK1"	-cw -O1 -enanosleep
 grep_log "$HALFCLOCK"	-cw -O4.5e2ms -enanosleep
+grep_log "$HALFCLOCK"	-cw --summary-syscall-overhead=4.5e2ms -enanosleep
 grep_log "$HALFCLOCK"	-cw -O4.5e-1s -enanosleep
+grep_log "$HALFCLOCK"	-cw --summary-syscall-overhead=4.5e-1s -enanosleep
 grep_log "$HALFCLOCK"	-cw -O456789012ns -enanosleep
+grep_log "$HALFCLOCK"	-cw --summary-syscall-overhead=456789012ns -enanosleep
 
 exit 0
diff -pruN 5.5-3/tests-m32/create_tmpfile.c 5.9-0ubuntu2/tests-m32/create_tmpfile.c
--- 5.5-3/tests-m32/create_tmpfile.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/create_tmpfile.c	2020-04-17 20:43:15.000000000 +0000
@@ -0,0 +1,46 @@
+/*
+ * Create a temporary file in the current directory.
+ *
+ * Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include <fcntl.h>
+#include <unistd.h>
+
+#ifndef O_TMPFILE
+# if defined __hppa__
+#  define O_TMPFILE	040000000
+# elif defined __alpha__
+#  define O_TMPFILE	0100000000
+# elif defined __sparc__
+#  define O_TMPFILE	0200000000
+# else
+#  define O_TMPFILE	020000000
+# endif
+#endif
+
+int
+create_tmpfile(unsigned int flags)
+{
+	int fd = open(".", O_TMPFILE | O_DIRECTORY | O_EXCL | flags, 0600);
+
+	if (fd < 0) {
+		/*
+		 * Since every test is executed in a separate directory,
+		 * there is no need to protect from race conditions.
+		 */
+		static const char fname[] = "create_tmpfile";
+
+		fd = open(fname, O_CREAT | O_EXCL | flags, 0600);
+		if (fd < 0)
+			perror_msg_and_fail("open: %s", fname);
+		if (unlink(fname))
+			perror_msg_and_fail("unlink: %s", fname);
+	}
+
+	return fd;
+}
diff -pruN 5.5-3/tests-m32/delay.test 5.9-0ubuntu2/tests-m32/delay.test
--- 5.5-3/tests-m32/delay.test	2019-08-06 13:38:20.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/delay.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
 #
 # Check delay injection.
 #
-# Copyright (c) 2018 The strace developers.
+# Copyright (c) 2018-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -12,7 +12,7 @@
 while read -r denter dexit denter_us dexit_us; do
 	[ -n "$denter" ] || continue
 
-	run_strace -f -r -egettimeofday \
+	run_strace --follow-forks -r -egettimeofday \
 		-einject=gettimeofday:delay_enter=$denter:delay_exit=$dexit \
 		../delay 4 $denter_us $dexit_us
 done <<-EOF
diff -pruN 5.5-3/tests-m32/dev--decode-fds-dev.c 5.9-0ubuntu2/tests-m32/dev--decode-fds-dev.c
--- 5.5-3/tests-m32/dev--decode-fds-dev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dev--decode-fds-dev.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_DEVNUM 1
+#include "dev-yy.c"
diff -pruN 5.5-3/tests-m32/dev--decode-fds-dev.gen.test 5.9-0ubuntu2/tests-m32/dev--decode-fds-dev.gen.test
--- 5.5-3/tests-m32/dev--decode-fds-dev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dev--decode-fds-dev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dev--decode-fds-dev -a30 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" -e decode-fds=dev); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a30 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" -e decode-fds=dev
diff -pruN 5.5-3/tests-m32/dev--decode-fds-path.c 5.9-0ubuntu2/tests-m32/dev--decode-fds-path.c
--- 5.5-3/tests-m32/dev--decode-fds-path.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dev--decode-fds-path.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_DEVNUM 0
+#include "dev-yy.c"
diff -pruN 5.5-3/tests-m32/dev--decode-fds-path.gen.test 5.9-0ubuntu2/tests-m32/dev--decode-fds-path.gen.test
--- 5.5-3/tests-m32/dev--decode-fds-path.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dev--decode-fds-path.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dev--decode-fds-path -a19 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" -e decode-fds=path); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a19 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" -e decode-fds=path
diff -pruN 5.5-3/tests-m32/dev--decode-fds-socket.c 5.9-0ubuntu2/tests-m32/dev--decode-fds-socket.c
--- 5.5-3/tests-m32/dev--decode-fds-socket.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dev--decode-fds-socket.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_DEVNUM 0
+#include "dev-yy.c"
diff -pruN 5.5-3/tests-m32/dev--decode-fds-socket.gen.test 5.9-0ubuntu2/tests-m32/dev--decode-fds-socket.gen.test
--- 5.5-3/tests-m32/dev--decode-fds-socket.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dev--decode-fds-socket.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dev--decode-fds-socket -a19 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" --decode-fds=socket); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a19 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" --decode-fds=socket
diff -pruN 5.5-3/tests-m32/dev-yy.c 5.9-0ubuntu2/tests-m32/dev-yy.c
--- 5.5-3/tests-m32/dev-yy.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dev-yy.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check printing of character/block device numbers in -yy mode.
  *
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -18,6 +18,16 @@
 
 #include <sys/sysmacros.h>
 
+#ifndef PRINT_DEVNUM
+# define PRINT_DEVNUM 1
+#endif
+
+#if PRINT_DEVNUM
+# define DEV_FMT "<%s<%s %u:%u>>"
+#else
+# define DEV_FMT "<%s>"
+#endif
+
 #if defined __NR_openat && defined O_PATH
 
 int
@@ -47,10 +57,13 @@ main(void)
 		printf("openat(AT_FDCWD, \"%s\", O_RDONLY|O_PATH) = %s",
 		       checks[i].path, sprintrc(fd));
 		if (fd >= 0)
-			printf("<%s<%s %u:%u>>",
-			       checks[i].path,
-			       checks[i].blk ? "block" : "char",
-			       checks[i].major, checks[i].minor);
+			printf(DEV_FMT,
+			       checks[i].path
+# if PRINT_DEVNUM
+			       , checks[i].blk ? "block" : "char",
+			       checks[i].major, checks[i].minor
+# endif
+			       );
 		puts("");
 
 		if (fd < 0) {
@@ -63,9 +76,13 @@ main(void)
 
 		int rc = fsync(fd);
 
-		printf("fsync(%ld<%s<%s %u:%u>>) = %s\n",
-		       fd, checks[i].path, checks[i].blk ? "block" : "char",
-		       checks[i].major, checks[i].minor, sprintrc(rc));
+		printf("fsync(%ld" DEV_FMT ") = %s\n",
+		       fd, checks[i].path,
+# if PRINT_DEVNUM
+		       checks[i].blk ? "block" : "char",
+		       checks[i].major, checks[i].minor,
+# endif
+		       sprintrc(rc));
 
 		close(fd);
 	}
diff -pruN 5.5-3/tests-m32/dup2.c 5.9-0ubuntu2/tests-m32/dup2.c
--- 5.5-3/tests-m32/dup2.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dup2.c	2020-04-24 23:03:14.000000000 +0000
@@ -1,5 +1,7 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Check decoding of dup2 syscall.
+ *
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -13,15 +15,103 @@
 # include <stdio.h>
 # include <unistd.h>
 
+# ifndef FD0_PATH
+#  define FD0_PATH ""
+# endif
+# ifndef FD9_PATH
+#  define FD9_PATH ""
+# endif
+# ifndef SKIP_IF_PROC_IS_UNAVAILABLE
+#  define SKIP_IF_PROC_IS_UNAVAILABLE
+# endif
+
+static const char *errstr;
+
+static long
+k_dup2(const unsigned int fd1, const unsigned int fd2)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+	const kernel_ulong_t arg1 = fill | fd1;
+	const kernel_ulong_t arg2 = fill | fd2;
+	const long rc = syscall(__NR_dup2, arg1, arg2, bad, bad, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
+
 int
 main(void)
 {
-	const long int fd_old = (long int) 0xdeadbeefffffffffULL;
-	const long int fd_new = (long int) 0xdeadbeeffffffffeULL;
+	SKIP_IF_PROC_IS_UNAVAILABLE;
+
+	int fd0 = dup(0);
+	int fd9 = dup(9);
 
-	long rc = syscall(__NR_dup2, fd_old, fd_new);
-	printf("dup2(%d, %d) = %ld %s (%m)\n",
-	       (int) fd_old, (int) fd_new, rc, errno2name());
+	if (k_dup2(0, 0))
+		perror_msg_and_skip("dup2");
+# ifndef PATH_TRACING
+	printf("dup2(0" FD0_PATH ", 0" FD0_PATH ") = 0" FD0_PATH "\n");
+# endif
+
+	k_dup2(-1, -2);
+# ifndef PATH_TRACING
+	printf("dup2(-1, -2) = %s\n", errstr);
+# endif
+
+	k_dup2(-2, -1);
+# ifndef PATH_TRACING
+	printf("dup2(-2, -1) = %s\n", errstr);
+# endif
+
+	k_dup2(-3, 0);
+# ifndef PATH_TRACING
+	printf("dup2(-3, 0" FD0_PATH ") = %s\n", errstr);
+# endif
+
+	k_dup2(0, -4);
+# ifndef PATH_TRACING
+	printf("dup2(0" FD0_PATH ", -4) = %s\n", errstr);
+# endif
+
+	k_dup2(-5, 9);
+	printf("dup2(-5, 9" FD9_PATH ") = %s\n", errstr);
+
+	k_dup2(9, -6);
+	printf("dup2(9" FD9_PATH ", -6) = %s\n", errstr);
+
+	k_dup2(9, 9);
+	printf("dup2(9" FD9_PATH ", 9" FD9_PATH ") = 9" FD9_PATH "\n");
+
+	k_dup2(0, fd0);
+# ifndef PATH_TRACING
+	printf("dup2(0" FD0_PATH ", %d" FD0_PATH ") = %d" FD0_PATH "\n",
+	       fd0, fd0);
+# endif
+
+	k_dup2(9, fd9);
+	printf("dup2(9" FD9_PATH ", %d" FD9_PATH ") = %d" FD9_PATH "\n",
+	       fd9, fd9);
+
+	k_dup2(0, fd9);
+	printf("dup2(0" FD0_PATH ", %d" FD9_PATH ") = %d" FD0_PATH "\n",
+	       fd9, fd9);
+
+	k_dup2(9, fd0);
+	printf("dup2(9" FD9_PATH ", %d" FD0_PATH ") = %d" FD9_PATH "\n",
+	       fd0, fd0);
+
+	close(fd0);
+	close(fd9);
+
+	k_dup2(0, fd0);
+# ifndef PATH_TRACING
+	printf("dup2(0" FD0_PATH ", %d) = %d" FD0_PATH "\n",
+	       fd0, fd0);
+# endif
+
+	k_dup2(9, fd9);
+	printf("dup2(9" FD9_PATH ", %d) = %d" FD9_PATH "\n",
+	       fd9, fd9);
 
 	puts("+++ exited with 0 +++");
 	return 0;
diff -pruN 5.5-3/tests-m32/dup2.gen.test 5.9-0ubuntu2/tests-m32/dup2.gen.test
--- 5.5-3/tests-m32/dup2.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dup2.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -1,4 +1,4 @@
 #!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup2 -a13 ); do not edit.
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup2 -a11 9>>/dev/full); do not edit.
 . "${srcdir=.}/init.sh"
-run_strace_match_diff -a13 
+run_strace_match_diff -a11 9>>/dev/full
diff -pruN 5.5-3/tests-m32/dup2-P.c 5.9-0ubuntu2/tests-m32/dup2-P.c
--- 5.5-3/tests-m32/dup2-P.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dup2-P.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,4 @@
+#define PATH_TRACING
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup2.c"
diff -pruN 5.5-3/tests-m32/dup2-P.gen.test 5.9-0ubuntu2/tests-m32/dup2-P.gen.test
--- 5.5-3/tests-m32/dup2-P.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dup2-P.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup2-P -a11 --trace=dup2 -P /dev/full 9>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a11 --trace=dup2 -P /dev/full 9>>/dev/full
diff -pruN 5.5-3/tests-m32/dup2-y.c 5.9-0ubuntu2/tests-m32/dup2-y.c
--- 5.5-3/tests-m32/dup2-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dup2-y.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,5 @@
+#define FD0_PATH "</dev/null>"
+#define FD9_PATH "</dev/full>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup2.c"
diff -pruN 5.5-3/tests-m32/dup2-y.gen.test 5.9-0ubuntu2/tests-m32/dup2-y.gen.test
--- 5.5-3/tests-m32/dup2-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dup2-y.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup2-y -a13 --trace=dup2 -y 9>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a13 --trace=dup2 -y 9>>/dev/full
diff -pruN 5.5-3/tests-m32/dup2-yy.c 5.9-0ubuntu2/tests-m32/dup2-yy.c
--- 5.5-3/tests-m32/dup2-yy.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dup2-yy.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,5 @@
+#define FD0_PATH "</dev/null<char 1:3>>"
+#define FD9_PATH "</dev/full<char 1:7>>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup2.c"
diff -pruN 5.5-3/tests-m32/dup2-yy.gen.test 5.9-0ubuntu2/tests-m32/dup2-yy.gen.test
--- 5.5-3/tests-m32/dup2-yy.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dup2-yy.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup2-yy -a13 --trace=dup2 -yy 9>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a13 --trace=dup2 -yy 9>>/dev/full
diff -pruN 5.5-3/tests-m32/dup3.c 5.9-0ubuntu2/tests-m32/dup3.c
--- 5.5-3/tests-m32/dup3.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dup3.c	2020-04-24 23:03:14.000000000 +0000
@@ -1,28 +1,140 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Check decoding of dup3 syscall.
+ *
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-#include <fcntl.h>
 #include "scno.h"
 
-#if defined __NR_dup3 && defined O_CLOEXEC
+#ifdef __NR_dup3
 
+# include <fcntl.h>
 # include <stdio.h>
 # include <unistd.h>
 
+# ifndef O_CLOEXEC
+#  if defined __alpha__ || defined __hppa__
+#   define O_CLOEXEC	010000000
+#  elif defined __sparc__
+#   define O_CLOEXEC	020000000
+#  else
+#   define O_CLOEXEC	02000000
+#  endif
+# endif /* !O_CLOEXEC */
+
+# ifndef FD0_PATH
+#  define FD0_PATH ""
+# endif
+# ifndef FD7_PATH
+#  define FD7_PATH ""
+# endif
+# ifndef SKIP_IF_PROC_IS_UNAVAILABLE
+#  define SKIP_IF_PROC_IS_UNAVAILABLE
+# endif
+
+static const char *errstr;
+
+static long
+k_dup3(const unsigned int fd1, const unsigned int fd2, const unsigned int flags)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+	const kernel_ulong_t arg1 = fill | fd1;
+	const kernel_ulong_t arg2 = fill | fd2;
+	const kernel_ulong_t arg3 = fill | flags;
+	const long rc = syscall(__NR_dup3, arg1, arg2, arg3, bad, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
+
 int
 main(void)
 {
-	const long int fd_old = (long int) 0xdeadbeefffffffffULL;
-	const long int fd_new = (long int) 0xdeadbeeffffffffeULL;
+	SKIP_IF_PROC_IS_UNAVAILABLE;
+
+	int fd0 = dup(0);
+	int fd7 = dup(7);
 
-	long rc = syscall(__NR_dup3, fd_old, fd_new, O_CLOEXEC);
-	printf("dup3(%d, %d, O_CLOEXEC) = %ld %s (%m)\n",
-	       (int) fd_old, (int) fd_new, rc, errno2name());
+	k_dup3(0, 0, 0);
+# ifndef PATH_TRACING
+	printf("dup3(0" FD0_PATH ", 0" FD0_PATH ", 0) = %s\n", errstr);
+# endif
+
+	k_dup3(-1, -2, O_CLOEXEC);
+# ifndef PATH_TRACING
+	printf("dup3(-1, -2, O_CLOEXEC) = %s\n", errstr);
+# endif
+
+	k_dup3(-2, -1, O_TRUNC);
+# ifndef PATH_TRACING
+	printf("dup3(-2, -1, O_TRUNC) = %s\n", errstr);
+# endif
+
+	k_dup3(-3, 0, O_TRUNC | O_CLOEXEC);
+# ifndef PATH_TRACING
+	printf("dup3(-3, 0" FD0_PATH ", O_TRUNC|O_CLOEXEC) = %s\n", errstr);
+# endif
+
+	k_dup3(0, -4, O_RDONLY);
+# ifndef PATH_TRACING
+	printf("dup3(0" FD0_PATH ", -4, 0) = %s\n", errstr);
+# endif
+
+	k_dup3(-5, 7, O_WRONLY);
+	printf("dup3(-5, 7" FD7_PATH ", 0x1 /* O_??? */) = %s\n", errstr);
+
+	k_dup3(7, -6, O_RDWR);
+	printf("dup3(7" FD7_PATH ", -6, 0x2 /* O_??? */) = %s\n", errstr);
+
+	k_dup3(7, 7, O_CLOEXEC);
+	printf("dup3(7" FD7_PATH ", 7" FD7_PATH ", O_CLOEXEC) = %s\n", errstr);
+
+	k_dup3(-7, -7, 7);
+# ifndef PATH_TRACING
+	printf("dup3(-7, -7, %s) = %s\n",
+#  ifdef __sparc__
+	       "O_NDELAY|0x3"
+#  else
+	       "0x7 /* O_??? */"
+#  endif
+	       , errstr);
+# endif
+
+	if (k_dup3(0, fd0, O_CLOEXEC) != fd0)
+		perror_msg_and_skip("dup3");
+# ifndef PATH_TRACING
+	printf("dup3(0" FD0_PATH ", %d" FD0_PATH ", O_CLOEXEC) = %d" FD0_PATH
+	       "\n", fd0, fd0);
+# endif
+
+	k_dup3(7, fd7, 0);
+	printf("dup3(7" FD7_PATH ", %d" FD7_PATH ", 0) = %d" FD7_PATH
+	       "\n", fd7, fd7);
+
+	k_dup3(0, fd7, O_CLOEXEC);
+	printf("dup3(0" FD0_PATH ", %d" FD7_PATH ", O_CLOEXEC) = %d" FD0_PATH
+	       "\n", fd7, fd7);
+
+	k_dup3(7, fd0, 0);
+	printf("dup3(7" FD7_PATH ", %d" FD0_PATH ", 0) = %d" FD7_PATH
+	       "\n", fd0, fd0);
+
+	close(fd0);
+	close(fd7);
+
+	k_dup3(0, fd0, O_CLOEXEC);
+# ifndef PATH_TRACING
+	printf("dup3(0" FD0_PATH ", %d, O_CLOEXEC) = %d" FD0_PATH "\n",
+	       fd0, fd0);
+# endif
+
+	k_dup3(7, fd7, 0);
+	printf("dup3(7" FD7_PATH ", %d, 0) = %d" FD7_PATH "\n",
+	       fd7, fd7);
 
 	puts("+++ exited with 0 +++");
 	return 0;
@@ -30,6 +142,6 @@ main(void)
 
 #else
 
-SKIP_MAIN_UNDEFINED("__NR_dup3 && O_CLOEXEC")
+SKIP_MAIN_UNDEFINED("__NR_dup3")
 
 #endif
diff -pruN 5.5-3/tests-m32/dup3.gen.test 5.9-0ubuntu2/tests-m32/dup3.gen.test
--- 5.5-3/tests-m32/dup3.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dup3.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -1,4 +1,4 @@
 #!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup3 -a24 ); do not edit.
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup3 -a13 7>>/dev/full); do not edit.
 . "${srcdir=.}/init.sh"
-run_strace_match_diff -a24 
+run_strace_match_diff -a13 7>>/dev/full
diff -pruN 5.5-3/tests-m32/dup3-P.c 5.9-0ubuntu2/tests-m32/dup3-P.c
--- 5.5-3/tests-m32/dup3-P.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dup3-P.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,4 @@
+#define PATH_TRACING
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup3.c"
diff -pruN 5.5-3/tests-m32/dup3-P.gen.test 5.9-0ubuntu2/tests-m32/dup3-P.gen.test
--- 5.5-3/tests-m32/dup3-P.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dup3-P.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup3-P -a13 --trace=dup3 -P /dev/full 7>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a13 --trace=dup3 -P /dev/full 7>>/dev/full
diff -pruN 5.5-3/tests-m32/dup3-y.c 5.9-0ubuntu2/tests-m32/dup3-y.c
--- 5.5-3/tests-m32/dup3-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dup3-y.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,5 @@
+#define FD0_PATH "</dev/null>"
+#define FD7_PATH "</dev/full>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup3.c"
diff -pruN 5.5-3/tests-m32/dup3-y.gen.test 5.9-0ubuntu2/tests-m32/dup3-y.gen.test
--- 5.5-3/tests-m32/dup3-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dup3-y.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup3-y -a15 --trace=dup3 -y 7>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a15 --trace=dup3 -y 7>>/dev/full
diff -pruN 5.5-3/tests-m32/dup3-yy.c 5.9-0ubuntu2/tests-m32/dup3-yy.c
--- 5.5-3/tests-m32/dup3-yy.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dup3-yy.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,5 @@
+#define FD0_PATH "</dev/null<char 1:3>>"
+#define FD7_PATH "</dev/full<char 1:7>>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup3.c"
diff -pruN 5.5-3/tests-m32/dup3-yy.gen.test 5.9-0ubuntu2/tests-m32/dup3-yy.gen.test
--- 5.5-3/tests-m32/dup3-yy.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dup3-yy.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup3-yy -a15 --trace=dup3 -yy 7>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a15 --trace=dup3 -yy 7>>/dev/full
diff -pruN 5.5-3/tests-m32/dup.c 5.9-0ubuntu2/tests-m32/dup.c
--- 5.5-3/tests-m32/dup.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dup.c	2020-04-24 23:03:14.000000000 +0000
@@ -1,20 +1,72 @@
 /*
- * Copyright (c) 2016-2018 The strace developers.
+ * Check decoding of dup syscall.
+ *
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-#include <stdio.h>
-#include <unistd.h>
+#include "scno.h"
+
+#ifdef __NR_dup
+
+# include <stdio.h>
+# include <unistd.h>
+
+# ifndef FD0_PATH
+#  define FD0_PATH ""
+# endif
+# ifndef FD9_PATH
+#  define FD9_PATH ""
+# endif
+# ifndef SKIP_IF_PROC_IS_UNAVAILABLE
+#  define SKIP_IF_PROC_IS_UNAVAILABLE
+# endif
+
+static const char *errstr;
+
+static long
+k_dup(const unsigned int fd)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+	const kernel_ulong_t arg1 = fill | fd;
+	const long rc = syscall(__NR_dup, arg1, bad, bad, bad, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
 
 int
 main(void)
 {
-	int rc = dup(-1);
-	printf("dup(-1) = %d %s (%m)\n", rc, errno2name());
+	SKIP_IF_PROC_IS_UNAVAILABLE;
+
+	k_dup(-1);
+# ifndef PATH_TRACING
+	printf("dup(-1) = %s\n", errstr);
+# endif
+
+	int d1 = k_dup(0);
+# ifndef PATH_TRACING
+	printf("dup(0" FD0_PATH ") = %d" FD0_PATH "\n", d1);
+# endif
+
+	int d2 = k_dup(d1);
+# ifndef PATH_TRACING
+	printf("dup(%d" FD0_PATH ") = %d" FD0_PATH "\n", d1, d2);
+# endif
+
+	d2 = k_dup(9);
+	printf("dup(9" FD9_PATH ") = %d" FD9_PATH "\n", d2);
 
 	puts("+++ exited with 0 +++");
 	return 0;
 }
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_dup")
+
+#endif
diff -pruN 5.5-3/tests-m32/dup.gen.test 5.9-0ubuntu2/tests-m32/dup.gen.test
--- 5.5-3/tests-m32/dup.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dup.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -1,4 +1,4 @@
 #!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup -a8 ); do not edit.
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup -a7 9>>/dev/full); do not edit.
 . "${srcdir=.}/init.sh"
-run_strace_match_diff -a8 
+run_strace_match_diff -a7 9>>/dev/full
diff -pruN 5.5-3/tests-m32/dup-P.c 5.9-0ubuntu2/tests-m32/dup-P.c
--- 5.5-3/tests-m32/dup-P.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dup-P.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,4 @@
+#define PATH_TRACING
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup.c"
diff -pruN 5.5-3/tests-m32/dup-P.gen.test 5.9-0ubuntu2/tests-m32/dup-P.gen.test
--- 5.5-3/tests-m32/dup-P.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dup-P.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup-P -a7 --trace=dup -P /dev/full 9>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a7 --trace=dup -P /dev/full 9>>/dev/full
diff -pruN 5.5-3/tests-m32/dup-y.c 5.9-0ubuntu2/tests-m32/dup-y.c
--- 5.5-3/tests-m32/dup-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dup-y.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,5 @@
+#define FD0_PATH "</dev/null>"
+#define FD9_PATH "</dev/full>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup.c"
diff -pruN 5.5-3/tests-m32/dup-y.gen.test 5.9-0ubuntu2/tests-m32/dup-y.gen.test
--- 5.5-3/tests-m32/dup-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dup-y.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup-y -a8 --trace=dup -y 9>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a8 --trace=dup -y 9>>/dev/full
diff -pruN 5.5-3/tests-m32/dup-yy.c 5.9-0ubuntu2/tests-m32/dup-yy.c
--- 5.5-3/tests-m32/dup-yy.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dup-yy.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,5 @@
+#define FD0_PATH "</dev/null<char 1:3>>"
+#define FD9_PATH "</dev/full<char 1:7>>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup.c"
diff -pruN 5.5-3/tests-m32/dup-yy.gen.test 5.9-0ubuntu2/tests-m32/dup-yy.gen.test
--- 5.5-3/tests-m32/dup-yy.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/dup-yy.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup-yy -a8 --trace=dup -yy 9>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a8 --trace=dup -yy 9>>/dev/full
diff -pruN 5.5-3/tests-m32/faccessat2.c 5.9-0ubuntu2/tests-m32/faccessat2.c
--- 5.5-3/tests-m32/faccessat2.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/faccessat2.c	2020-09-23 16:29:35.000000000 +0000
@@ -0,0 +1,174 @@
+/*
+ * Check decoding of faccessat2 syscall.
+ *
+ * Copyright (c) 2016-2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+
+#ifdef __NR_faccessat2
+
+# include <fcntl.h>
+# include <stdio.h>
+# include <unistd.h>
+
+# define XLAT_MACROS_ONLY
+#  include "xlat/faccessat_flags.h"
+# undef XLAT_MACROS_ONLY
+
+# ifndef FD_PATH
+#  define FD_PATH ""
+# endif
+# ifndef SKIP_IF_PROC_IS_UNAVAILABLE
+#  define SKIP_IF_PROC_IS_UNAVAILABLE
+# endif
+
+static const char *errstr;
+
+static long
+k_faccessat2(const unsigned int dirfd,
+	     const void *const pathname,
+	     const unsigned int mode,
+	     const unsigned int flags)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+
+	const kernel_ulong_t arg1 = fill | dirfd;
+	const kernel_ulong_t arg2 = (uintptr_t) pathname;
+	const kernel_ulong_t arg3 = fill | mode;
+	const kernel_ulong_t arg4 = fill | flags;
+	const long rc = syscall(__NR_faccessat2,
+				arg1, arg2, arg3, arg4, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
+
+int
+main(void)
+{
+	SKIP_IF_PROC_IS_UNAVAILABLE;
+
+	TAIL_ALLOC_OBJECT_CONST_PTR(const char, unterminated);
+	char *unterminated_str;
+	if (asprintf(&unterminated_str, "%p", unterminated) < 0)
+                perror_msg_and_fail("asprintf");
+	const void *const efault = unterminated + 1;
+	char *efault_str;
+	if (asprintf(&efault_str, "%p", efault) < 0)
+                perror_msg_and_fail("asprintf");
+
+	typedef struct {
+		char sym;
+		char null;
+	} sym_null;
+
+	TAIL_ALLOC_OBJECT_CONST_PTR(sym_null, dot);
+	dot->sym = '.';
+	dot->null = '\0';
+	const char *const null = &dot->null;
+
+	TAIL_ALLOC_OBJECT_CONST_PTR(sym_null, slash);
+	slash->sym = '/';
+	slash->null = '\0';
+
+	static const char path[] = "/dev/full";
+	const char *const fd_path = tail_memdup(path, sizeof(path));
+        int fd = open(path, O_WRONLY);
+        if (fd < 0)
+                perror_msg_and_fail("open: %s", path);
+	char *fd_str;
+	if (asprintf(&fd_str, "%d%s", fd, FD_PATH) < 0)
+                perror_msg_and_fail("asprintf");
+	char *path_quoted;
+	if (asprintf(&path_quoted, "\"%s\"", path) < 0)
+                perror_msg_and_fail("asprintf");
+
+	struct {
+		int val;
+		const char *str;
+	} dirfds[] = {
+		{ ARG_STR(-1) },
+		{ -100, "AT_FDCWD" },
+		{ fd, fd_str },
+	}, modes[] = {
+		{ ARG_STR(F_OK) },
+		{ ARG_STR(R_OK) },
+		{ ARG_STR(W_OK) },
+		{ ARG_STR(X_OK) },
+		{ ARG_STR(R_OK|W_OK) },
+		{ ARG_STR(R_OK|X_OK) },
+		{ ARG_STR(W_OK|X_OK) },
+		{ ARG_STR(R_OK|W_OK|X_OK) },
+		{ 8, "0x8 /* ?_OK */" },
+		{ -1, "R_OK|W_OK|X_OK|0xfffffff8" },
+	}, flags[] = {
+		{ ARG_STR(0) },
+		{ ARG_STR(AT_SYMLINK_NOFOLLOW) },
+		{ ARG_STR(AT_EACCESS) },
+		{ ARG_STR(AT_EMPTY_PATH) },
+		{ ARG_STR(AT_SYMLINK_NOFOLLOW|AT_EACCESS) },
+		{ ARG_STR(AT_SYMLINK_NOFOLLOW|AT_EMPTY_PATH) },
+		{ ARG_STR(AT_EACCESS|AT_EMPTY_PATH) },
+		{ ARG_STR(AT_SYMLINK_NOFOLLOW|AT_EACCESS|AT_EMPTY_PATH) },
+		{ 1, "0x1 /* AT_??? */" },
+		{ -1, "AT_SYMLINK_NOFOLLOW|AT_EACCESS|AT_EMPTY_PATH|0xffffecff" },
+	};
+
+	struct {
+		const void *val;
+		const char *str;
+	} paths[] = {
+		{ 0, "NULL" },
+		{ efault, efault_str },
+		{ unterminated, unterminated_str },
+		{ null, "\"\"" },
+		{ &dot->sym, "\".\"" },
+		{ &slash->sym, "\"/\"" },
+		{ fd_path, path_quoted },
+	};
+
+	for (unsigned int dirfd_i = 0;
+	     dirfd_i < ARRAY_SIZE(dirfds);
+	     ++dirfd_i) {
+		for (unsigned int path_i = 0;
+		     path_i < ARRAY_SIZE(paths);
+		     ++path_i) {
+			for (unsigned int mode_i = 0;
+			     mode_i < ARRAY_SIZE(modes);
+			     ++mode_i) {
+				for (unsigned int flag_i = 0;
+				     flag_i < ARRAY_SIZE(flags);
+				     ++flag_i) {
+					k_faccessat2(dirfds[dirfd_i].val,
+						    paths[path_i].val,
+						    modes[mode_i].val,
+						    flags[flag_i].val);
+# ifdef PATH_TRACING
+					if (dirfds[dirfd_i].val == fd ||
+					    paths[path_i].val == fd_path)
+# endif
+					printf("faccessat2(%s, %s, %s, %s) = %s\n",
+					       dirfds[dirfd_i].str,
+					       paths[path_i].str,
+					       modes[mode_i].str,
+					       flags[flag_i].str,
+					       errstr);
+				}
+			}
+		}
+	}
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_faccessat2")
+
+#endif
diff -pruN 5.5-3/tests-m32/faccessat2-P.c 5.9-0ubuntu2/tests-m32/faccessat2-P.c
--- 5.5-3/tests-m32/faccessat2-P.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/faccessat2-P.c	2020-07-04 08:00:00.000000000 +0000
@@ -0,0 +1,4 @@
+#define PATH_TRACING
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "faccessat2.c"
diff -pruN 5.5-3/tests-m32/faccessat2-P.gen.test 5.9-0ubuntu2/tests-m32/faccessat2-P.gen.test
--- 5.5-3/tests-m32/faccessat2-P.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/faccessat2-P.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (faccessat2-P -a27 --trace=faccessat2 -P /dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a27 --trace=faccessat2 -P /dev/full
diff -pruN 5.5-3/tests-m32/faccessat2.test 5.9-0ubuntu2/tests-m32/faccessat2.test
--- 5.5-3/tests-m32/faccessat2.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/faccessat2.test	2020-07-04 08:00:00.000000000 +0000
@@ -0,0 +1,19 @@
+#!/bin/sh
+#
+# Check decoding of faccessat2 syscall.
+#
+# Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
+# All rights reserved.
+#
+# SPDX-License-Identifier: GPL-2.0-or-later
+
+. "${srcdir=.}/init.sh"
+
+check_prog sed
+
+run_prog > /dev/null
+run_strace -a27 --trace=faccessat2 "$@" $args > "$EXP"
+
+# Filter out faccessat2() calls made by ld.so and libc.
+sed -n '/^faccessat2(-1, NULL,/,$p' < "$LOG" > "$OUT"
+match_diff "$OUT" "$EXP"
diff -pruN 5.5-3/tests-m32/faccessat2-y.c 5.9-0ubuntu2/tests-m32/faccessat2-y.c
--- 5.5-3/tests-m32/faccessat2-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/faccessat2-y.c	2020-07-04 08:00:00.000000000 +0000
@@ -0,0 +1,4 @@
+#define FD_PATH "</dev/full>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "faccessat2.c"
diff -pruN 5.5-3/tests-m32/faccessat2-y.gen.test 5.9-0ubuntu2/tests-m32/faccessat2-y.gen.test
--- 5.5-3/tests-m32/faccessat2-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/faccessat2-y.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (faccessat2-y +faccessat2.test -a28 -y); do not edit.
+set -- -a28 -y
+. "${srcdir=.}/faccessat2.test"
diff -pruN 5.5-3/tests-m32/faccessat2-yy.c 5.9-0ubuntu2/tests-m32/faccessat2-yy.c
--- 5.5-3/tests-m32/faccessat2-yy.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/faccessat2-yy.c	2020-07-04 08:00:00.000000000 +0000
@@ -0,0 +1,4 @@
+#define FD_PATH "</dev/full<char 1:7>>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "faccessat2.c"
diff -pruN 5.5-3/tests-m32/faccessat2-yy.gen.test 5.9-0ubuntu2/tests-m32/faccessat2-yy.gen.test
--- 5.5-3/tests-m32/faccessat2-yy.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/faccessat2-yy.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (faccessat2-yy +faccessat2.test -a28 -yy); do not edit.
+set -- -a28 -yy
+. "${srcdir=.}/faccessat2.test"
diff -pruN 5.5-3/tests-m32/faccessat.c 5.9-0ubuntu2/tests-m32/faccessat.c
--- 5.5-3/tests-m32/faccessat.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/faccessat.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,5 +1,7 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Check decoding of faccessat syscall.
+ *
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,18 +12,133 @@
 
 #ifdef __NR_faccessat
 
+# include <fcntl.h>
 # include <stdio.h>
 # include <unistd.h>
 
+# ifndef FD_PATH
+#  define FD_PATH ""
+# endif
+# ifndef SKIP_IF_PROC_IS_UNAVAILABLE
+#  define SKIP_IF_PROC_IS_UNAVAILABLE
+# endif
+
+static const char *errstr;
+
+static long
+k_faccessat(const unsigned int dirfd,
+	    const void *const pathname,
+	    const unsigned int mode)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+
+	const kernel_ulong_t arg1 = fill | dirfd;
+	const kernel_ulong_t arg2 = (uintptr_t) pathname;
+	const kernel_ulong_t arg3 = fill | mode;
+	const long rc = syscall(__NR_faccessat,
+				arg1, arg2, arg3, bad, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
+
 int
 main(void)
 {
-	static const char sample[] = "faccessat.sample";
-	const long int fd = (long int) 0xdeadbeefffffffffULL;
+	SKIP_IF_PROC_IS_UNAVAILABLE;
 
-	long rc = syscall(__NR_faccessat, fd, sample, F_OK);
-	printf("faccessat(%d, \"%s\", F_OK) = %ld %s (%m)\n",
-	       (int) fd, sample, rc, errno2name());
+	TAIL_ALLOC_OBJECT_CONST_PTR(const char, unterminated);
+	char *unterminated_str;
+	if (asprintf(&unterminated_str, "%p", unterminated) < 0)
+                perror_msg_and_fail("asprintf");
+	const void *const efault = unterminated + 1;
+	char *efault_str;
+	if (asprintf(&efault_str, "%p", efault) < 0)
+                perror_msg_and_fail("asprintf");
+
+	typedef struct {
+		char sym;
+		char null;
+	} sym_null;
+
+	TAIL_ALLOC_OBJECT_CONST_PTR(sym_null, dot);
+	dot->sym = '.';
+	dot->null = '\0';
+	const char *const null = &dot->null;
+
+	TAIL_ALLOC_OBJECT_CONST_PTR(sym_null, slash);
+	slash->sym = '/';
+	slash->null = '\0';
+
+	static const char path[] = "/dev/full";
+	const char *const fd_path = tail_memdup(path, sizeof(path));
+        int fd = open(path, O_WRONLY);
+        if (fd < 0)
+                perror_msg_and_fail("open: %s", path);
+	char *fd_str;
+	if (asprintf(&fd_str, "%d%s", fd, FD_PATH) < 0)
+                perror_msg_and_fail("asprintf");
+	char *path_quoted;
+	if (asprintf(&path_quoted, "\"%s\"", path) < 0)
+                perror_msg_and_fail("asprintf");
+
+	struct {
+		int val;
+		const char *str;
+	} dirfds[] = {
+		{ ARG_STR(-1) },
+		{ -100, "AT_FDCWD" },
+		{ fd, fd_str },
+	}, modes[] = {
+		{ ARG_STR(F_OK) },
+		{ ARG_STR(R_OK) },
+		{ ARG_STR(W_OK) },
+		{ ARG_STR(X_OK) },
+		{ ARG_STR(R_OK|W_OK) },
+		{ ARG_STR(R_OK|X_OK) },
+		{ ARG_STR(W_OK|X_OK) },
+		{ ARG_STR(R_OK|W_OK|X_OK) },
+		{ 8, "0x8 /* ?_OK */" },
+		{ -1, "R_OK|W_OK|X_OK|0xfffffff8" },
+	};
+
+	struct {
+		const void *val;
+		const char *str;
+	} paths[] = {
+		{ 0, "NULL" },
+		{ efault, efault_str },
+		{ unterminated, unterminated_str },
+		{ null, "\"\"" },
+		{ &dot->sym, "\".\"" },
+		{ &slash->sym, "\"/\"" },
+		{ fd_path, path_quoted },
+	};
+
+	for (unsigned int dirfd_i = 0;
+	     dirfd_i < ARRAY_SIZE(dirfds);
+	     ++dirfd_i) {
+		for (unsigned int path_i = 0;
+		     path_i < ARRAY_SIZE(paths);
+		     ++path_i) {
+			for (unsigned int mode_i = 0;
+			     mode_i < ARRAY_SIZE(modes);
+			     ++mode_i) {
+				k_faccessat(dirfds[dirfd_i].val,
+					    paths[path_i].val,
+					    modes[mode_i].val);
+# ifdef PATH_TRACING
+				if (dirfds[dirfd_i].val == fd ||
+				    paths[path_i].val == fd_path)
+# endif
+				printf("faccessat(%s, %s, %s) = %s\n",
+				       dirfds[dirfd_i].str,
+				       paths[path_i].str,
+				       modes[mode_i].str,
+				       errstr);
+			}
+		}
+	}
 
 	puts("+++ exited with 0 +++");
 	return 0;
diff -pruN 5.5-3/tests-m32/faccessat.gen.test 5.9-0ubuntu2/tests-m32/faccessat.gen.test
--- 5.5-3/tests-m32/faccessat.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/faccessat.gen.test	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-#!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (faccessat -P $NAME.sample); do not edit.
-. "${srcdir=.}/init.sh"
-run_strace_match_diff -P $NAME.sample
diff -pruN 5.5-3/tests-m32/faccessat-P.c 5.9-0ubuntu2/tests-m32/faccessat-P.c
--- 5.5-3/tests-m32/faccessat-P.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/faccessat-P.c	2020-07-04 08:00:00.000000000 +0000
@@ -0,0 +1,4 @@
+#define PATH_TRACING
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "faccessat.c"
diff -pruN 5.5-3/tests-m32/faccessat-P.gen.test 5.9-0ubuntu2/tests-m32/faccessat-P.gen.test
--- 5.5-3/tests-m32/faccessat-P.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/faccessat-P.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (faccessat-P -a23 --trace=faccessat -P /dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a23 --trace=faccessat -P /dev/full
diff -pruN 5.5-3/tests-m32/faccessat.test 5.9-0ubuntu2/tests-m32/faccessat.test
--- 5.5-3/tests-m32/faccessat.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/faccessat.test	2020-07-04 08:00:00.000000000 +0000
@@ -0,0 +1,19 @@
+#!/bin/sh
+#
+# Check decoding of faccessat syscall.
+#
+# Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
+# All rights reserved.
+#
+# SPDX-License-Identifier: GPL-2.0-or-later
+
+. "${srcdir=.}/init.sh"
+
+check_prog sed
+
+run_prog > /dev/null
+run_strace -a23 --trace=faccessat "$@" $args > "$EXP"
+
+# Filter out faccessat() calls made by ld.so and libc.
+sed -n '/^faccessat(-1, NULL,/,$p' < "$LOG" > "$OUT"
+match_diff "$OUT" "$EXP"
diff -pruN 5.5-3/tests-m32/faccessat-y.c 5.9-0ubuntu2/tests-m32/faccessat-y.c
--- 5.5-3/tests-m32/faccessat-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/faccessat-y.c	2020-07-04 08:00:00.000000000 +0000
@@ -0,0 +1,4 @@
+#define FD_PATH "</dev/full>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "faccessat.c"
diff -pruN 5.5-3/tests-m32/faccessat-y.gen.test 5.9-0ubuntu2/tests-m32/faccessat-y.gen.test
--- 5.5-3/tests-m32/faccessat-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/faccessat-y.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (faccessat-y +faccessat.test -a24 -y); do not edit.
+set -- -a24 -y
+. "${srcdir=.}/faccessat.test"
diff -pruN 5.5-3/tests-m32/faccessat-yy.c 5.9-0ubuntu2/tests-m32/faccessat-yy.c
--- 5.5-3/tests-m32/faccessat-yy.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/faccessat-yy.c	2020-07-04 08:00:00.000000000 +0000
@@ -0,0 +1,4 @@
+#define FD_PATH "</dev/full<char 1:7>>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "faccessat.c"
diff -pruN 5.5-3/tests-m32/faccessat-yy.gen.test 5.9-0ubuntu2/tests-m32/faccessat-yy.gen.test
--- 5.5-3/tests-m32/faccessat-yy.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/faccessat-yy.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (faccessat-yy +faccessat.test -a24 -yy); do not edit.
+set -- -a24 -yy
+. "${srcdir=.}/faccessat.test"
diff -pruN 5.5-3/tests-m32/fanotify_init.c 5.9-0ubuntu2/tests-m32/fanotify_init.c
--- 5.5-3/tests-m32/fanotify_init.c	2019-07-16 17:46:47.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/fanotify_init.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of fanotify_init syscall.
  *
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -44,13 +44,14 @@ main(void)
 		{ F8ILL_KULONG_MASK, "FAN_CLASS_NOTIF" },
 		{ (kernel_ulong_t) 0xffffffff0000000cULL,
 			"0xc /* FAN_CLASS_??? */" },
-		{ (kernel_ulong_t) 0xdec0deddefacec04ULL,
-			"FAN_CLASS_CONTENT|0xefacec00 /* FAN_??? */" },
+		{ (kernel_ulong_t) 0xdec0deddeface004ULL,
+			"FAN_CLASS_CONTENT|0xeface000 /* FAN_??? */" },
 		{ (kernel_ulong_t) 0xffffffffffffffffULL,
 			"0xc /* FAN_CLASS_??? */|FAN_CLOEXEC|FAN_NONBLOCK|"
 			"FAN_UNLIMITED_QUEUE|FAN_UNLIMITED_MARKS|"
 			"FAN_ENABLE_AUDIT|FAN_REPORT_TID|FAN_REPORT_FID|"
-			"0xfffffc80" },
+			"FAN_REPORT_DIR_FID|FAN_REPORT_NAME|"
+			"0xfffff080" },
 	};
 	static const struct strval event_f_flags[] = {
 		{ F8ILL_KULONG_MASK, "O_RDONLY" },
diff -pruN 5.5-3/tests-m32/fanotify_mark.c 5.9-0ubuntu2/tests-m32/fanotify_mark.c
--- 5.5-3/tests-m32/fanotify_mark.c	2019-07-16 17:46:47.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/fanotify_mark.c	2020-04-15 13:39:57.000000000 +0000
@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -68,11 +68,6 @@ struct strval {
 	const char *str;
 };
 
-struct strval64 {
-	uint64_t val;
-	const char *str;
-};
-
 # define STR16 "0123456789abcdef"
 # define STR64 STR16 STR16 STR16 STR16
 
@@ -150,15 +145,16 @@ main(void)
 			"FAN_OPEN_PERM|"
 			"FAN_ACCESS_PERM|"
 			"FAN_OPEN_EXEC_PERM|"
+			"FAN_DIR_MODIFY|"
 			"FAN_ONDIR|"
 			"FAN_EVENT_ON_CHILD|"
-			"0xdeadfeedb7f8a000"
+			"0xdeadfeedb7f0a000"
 # endif
 # if XLAT_VERBOSE
 			" */"
 # endif
 			},
-		{ ARG_ULL_STR(0xffffffffb7f8a000)
+		{ ARG_ULL_STR(0xffffffffb7f0a000)
 # if !XLAT_RAW
 			" /* FAN_??? */"
 # endif
diff -pruN 5.5-3/tests-m32/fchmod.c 5.9-0ubuntu2/tests-m32/fchmod.c
--- 5.5-3/tests-m32/fchmod.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/fchmod.c	2020-06-01 14:15:16.000000000 +0000
@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2016 Fabien Siron <fabien.siron@epita.fr>
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -22,14 +22,7 @@
 int
 main(void)
 {
-	static const char fname[] = "fchmod_test_file";
-
-	int fd = open(fname, O_CREAT|O_RDONLY, 0400);
-	if (fd < 0)
-		perror_msg_and_fail("open");
-
-	if (unlink(fname))
-		perror_msg_and_fail("unlink");
+	int fd = create_tmpfile(O_RDWR);
 
 	long rc = syscall(__NR_fchmod, fd, 0600);
 	printf("fchmod(%d, 0600) = %s\n", fd, sprintrc(rc));
diff -pruN 5.5-3/tests-m32/fcntl64.c 5.9-0ubuntu2/tests-m32/fcntl64.c
--- 5.5-3/tests-m32/fcntl64.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/fcntl64.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -27,6 +27,7 @@ test_flock64_lk64(void)
 	fl->l_len = FILE_LEN;
 
 	long rc = invoke_test_syscall(0, F_SETLK64, fl);
+	pidns_print_leader();
 	printf("%s(0, F_SETLK64, {l_type=F_RDLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d}) = %s\n",
 	       TEST_SYSCALL_STR, FILE_LEN, errstr);
@@ -35,11 +36,13 @@ test_flock64_lk64(void)
 		return;
 
 	invoke_test_syscall(0, F_GETLK64, fl);
+	pidns_print_leader();
 	printf("%s(0, F_GETLK64, {l_type=F_UNLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d, l_pid=0}) = 0\n",
 	       TEST_SYSCALL_STR, FILE_LEN);
 
 	invoke_test_syscall(0, F_SETLKW64, fl);
+	pidns_print_leader();
 	printf("%s(0, F_SETLKW64, {l_type=F_UNLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d}) = 0\n",
 	       TEST_SYSCALL_STR, FILE_LEN);
diff -pruN 5.5-3/tests-m32/fcntl64--pidns-translation.c 5.9-0ubuntu2/tests-m32/fcntl64--pidns-translation.c
--- 5.5-3/tests-m32/fcntl64--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/fcntl64--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "fcntl64.c"
diff -pruN 5.5-3/tests-m32/fcntl64--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/fcntl64--pidns-translation.gen.test
--- 5.5-3/tests-m32/fcntl64--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/fcntl64--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (fcntl64--pidns-translation test_pidns -a8 -e trace=fcntl64); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a8 -e trace=fcntl64
diff -pruN 5.5-3/tests-m32/fcntl.c 5.9-0ubuntu2/tests-m32/fcntl.c
--- 5.5-3/tests-m32/fcntl.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/fcntl.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -24,6 +24,7 @@ test_flock64_undecoded(const int cmd, co
 		.l_len = 0xdefaced2cafef00dULL
 	};
 	invoke_test_syscall(0, cmd, &fl);
+	pidns_print_leader();
 	printf("%s(0, %s, %p) = %s\n",
 	       TEST_SYSCALL_STR, name, &fl, errstr);
 }
diff -pruN 5.5-3/tests-m32/fcntl-common.c 5.9-0ubuntu2/tests-m32/fcntl-common.c
--- 5.5-3/tests-m32/fcntl-common.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/fcntl-common.c	2020-08-25 14:29:30.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -13,6 +13,8 @@
 #include <unistd.h>
 #include <assert.h>
 #include "flock.h"
+#include "pidns.h"
+#include "scno.h"
 
 #define FILE_LEN 4096
 
@@ -48,12 +50,14 @@ test_flock_einval(const int cmd, const c
 	fl->l_len = (TYPEOF_FLOCK_OFF_T) 0xdefaced2cafef00dULL;
 
 	invoke_test_syscall(0, cmd, fl);
+	pidns_print_leader();
 	printf("%s(0, %s, {l_type=F_RDLCK, l_whence=SEEK_SET"
 	       ", l_start=%jd, l_len=%jd}) = %s\n", TEST_SYSCALL_STR, name,
 	       (intmax_t) fl->l_start, (intmax_t) fl->l_len, errstr);
 
 	void *const bad_addr = (void *) fl + 1;
 	invoke_test_syscall(0, cmd, bad_addr);
+	pidns_print_leader();
 	printf("%s(0, %s, %p) = %s\n",
 	       TEST_SYSCALL_STR, name, bad_addr, errstr);
 }
@@ -72,12 +76,14 @@ test_flock64_einval(const int cmd, const
 	fl->l_len = (TYPEOF_FLOCK_OFF_T) 0xdefaced2cafef00dULL;
 
 	invoke_test_syscall(0, cmd, fl);
+	pidns_print_leader();
 	printf("%s(0, %s, {l_type=F_RDLCK, l_whence=SEEK_SET"
 	       ", l_start=%jd, l_len=%jd}) = %s\n", TEST_SYSCALL_STR, name,
 	       (intmax_t) fl->l_start, (intmax_t) fl->l_len, errstr);
 
 	void *const bad_addr = (void *) fl + 1;
 	invoke_test_syscall(0, cmd, bad_addr);
+	pidns_print_leader();
 	printf("%s(0, %s, %p) = %s\n",
 	       TEST_SYSCALL_STR, name, bad_addr, errstr);
 }
@@ -94,6 +100,7 @@ test_flock(void)
 	fl->l_len = FILE_LEN;
 
 	long rc = invoke_test_syscall(0, F_SETLK, fl);
+	pidns_print_leader();
 	printf("%s(0, F_SETLK, {l_type=F_RDLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d}) = %s\n",
 	       TEST_SYSCALL_STR, FILE_LEN, errstr);
@@ -101,11 +108,13 @@ test_flock(void)
 		return;
 
 	invoke_test_syscall(0, F_GETLK, fl);
+	pidns_print_leader();
 	printf("%s(0, F_GETLK, {l_type=F_UNLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d, l_pid=0}) = 0\n",
 	       TEST_SYSCALL_STR, FILE_LEN);
 
 	invoke_test_syscall(0, F_SETLKW, fl);
+	pidns_print_leader();
 	printf("%s(0, F_SETLKW, {l_type=F_UNLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d}) = 0\n",
 	       TEST_SYSCALL_STR, FILE_LEN);
@@ -124,6 +133,7 @@ test_flock64_ofd(void)
 	fl->l_len = FILE_LEN;
 
 	long rc = invoke_test_syscall(0, F_OFD_SETLK, fl);
+	pidns_print_leader();
 	printf("%s(0, F_OFD_SETLK, {l_type=F_RDLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d}) = %s\n",
 	       TEST_SYSCALL_STR, FILE_LEN, errstr);
@@ -131,11 +141,13 @@ test_flock64_ofd(void)
 		return;
 
 	invoke_test_syscall(0, F_OFD_GETLK, fl);
+	pidns_print_leader();
 	printf("%s(0, F_OFD_GETLK, {l_type=F_UNLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d, l_pid=0}) = 0\n",
 	       TEST_SYSCALL_STR, FILE_LEN);
 
 	invoke_test_syscall(0, F_OFD_SETLKW, fl);
+	pidns_print_leader();
 	printf("%s(0, F_OFD_SETLKW, {l_type=F_UNLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d}) = 0\n",
 	       TEST_SYSCALL_STR, FILE_LEN);
@@ -167,18 +179,21 @@ test_flock64(void)
 static long
 test_f_owner_ex_type_pid(const int cmd, const char *const cmd_name,
 			 const int type, const char *const type_name,
-			 pid_t pid)
+			 enum pid_type pid_type, pid_t pid)
 {
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct_kernel_f_owner_ex, fo);
 
 	fo->type = type;
 	fo->pid = pid;
 	long rc = invoke_test_syscall(0, cmd, fo);
-	printf("%s(0, %s, {type=%s, pid=%d}) = %s\n",
-	       TEST_SYSCALL_STR, cmd_name, type_name, fo->pid, errstr);
+	pidns_print_leader();
+	printf("%s(0, %s, {type=%s, pid=%d%s}) = %s\n",
+	       TEST_SYSCALL_STR, cmd_name, type_name,
+	       fo->pid, pidns_pid2str(pid_type), errstr);
 
 	void *bad_addr = (void *) fo + 1;
 	invoke_test_syscall(0, cmd, bad_addr);
+	pidns_print_leader();
 	printf("%s(0, %s, %p) = %s\n",
 	       TEST_SYSCALL_STR, cmd_name, bad_addr, errstr);
 
@@ -187,35 +202,35 @@ test_f_owner_ex_type_pid(const int cmd,
 
 static void
 test_f_owner_ex_umove_or_printaddr(const int type, const char *const type_name,
-				   pid_t pid)
+				   enum pid_type pid_type, pid_t pid)
 {
 	long rc = test_f_owner_ex_type_pid(ARG_STR(F_SETOWN_EX),
-					   type, type_name, pid);
+					   type, type_name, pid_type, pid);
 	if (!rc)
 		test_f_owner_ex_type_pid(ARG_STR(F_GETOWN_EX),
-					 type, type_name, pid);
+					 type, type_name, pid_type, pid);
 }
 
 static void
 test_f_owner_ex(void)
 {
-	static const struct {
+	struct {
 		int type;
 		const char *type_name;
-		pid_t pid[2];
+		enum pid_type pid_type;
+		pid_t pid;
 	} a[] = {
-		{ ARG_STR(F_OWNER_TID), { 1234567890, 20 } },
-		{ ARG_STR(F_OWNER_PID), { 1298126790, 30 } },
-		{ ARG_STR(F_OWNER_PGRP), { 1294567890, 40 } }
+		{ ARG_STR(F_OWNER_TID), PT_NONE, 1234567890 },
+		{ ARG_STR(F_OWNER_PID), PT_NONE, 1234567890 },
+		{ ARG_STR(F_OWNER_PGRP), PT_NONE, 1234567890 },
+		{ ARG_STR(F_OWNER_TID), PT_TID, syscall(__NR_gettid) },
+		{ ARG_STR(F_OWNER_PID), PT_TGID, getpid() },
+		{ ARG_STR(F_OWNER_PGRP), PT_PGID, getpgid(0) },
 	};
 
-	for (unsigned int i = 0; i < ARRAY_SIZE(a); i++) {
-		for (unsigned int j = 0; j < ARRAY_SIZE(a[0].pid); j++) {
-			test_f_owner_ex_umove_or_printaddr(a[i].type,
-							   a[i].type_name,
-							   a[i].pid[j]);
-		}
-	}
+	for (unsigned int i = 0; i < ARRAY_SIZE(a); i++)
+		test_f_owner_ex_umove_or_printaddr(a[i].type, a[i].type_name,
+			a[i].pid_type, a[i].pid);
 }
 #endif /* TEST_F_OWNER_EX */
 
@@ -229,6 +244,23 @@ struct fcntl_cmd_check {
 };
 
 static void
+test_xetown(void)
+{
+	const int pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
+
+	invoke_test_syscall(0, F_SETOWN, (void *) (intptr_t) pid);
+	pidns_print_leader();
+	printf("%s(0, F_SETOWN, %d%s) = %s\n",
+		TEST_SYSCALL_STR, pid, pid_str, errstr);
+
+	invoke_test_syscall(0, F_GETOWN, NULL);
+	pidns_print_leader();
+	printf("%s(0, F_GETOWN) = %d%s\n",
+		TEST_SYSCALL_STR, pid, pid_str);
+}
+
+static void
 print_retval_flags(const struct fcntl_cmd_check *check, long rc)
 {
 	if (check->print_flags) {
@@ -243,12 +275,14 @@ static void
 test_other_set_cmd(const struct fcntl_cmd_check *check)
 {
 	invoke_test_syscall(check->fd, check->cmd, (void *) check->arg);
+	pidns_print_leader();
 	printf("%s(%d, %s, %s) = %s\n",
 	       TEST_SYSCALL_STR, check->fd,
 	       check->cmd_str, check->arg_str, errstr);
 
 	/* bad file fd */
 	invoke_test_syscall(-1, check->cmd, (void *) check->arg);
+	pidns_print_leader();
 	printf("%s(-1, %s, %s) = %s\n",
 	       TEST_SYSCALL_STR, check->cmd_str,
 	       check->arg_str, errstr);
@@ -258,12 +292,14 @@ static void
 test_other_get_cmd(const struct fcntl_cmd_check *check)
 {
 	long rc = invoke_test_syscall(check->fd, check->cmd, NULL);
+	pidns_print_leader();
 	printf("%s(%d, %s) = ",
 	       TEST_SYSCALL_STR, check->fd, check->cmd_str);
 	print_retval_flags(check, rc);
 
 	/* bad file fd */
 	invoke_test_syscall(-1, check->cmd, NULL);
+	pidns_print_leader();
 	printf("%s(-1, %s) = %s\n",
 	       TEST_SYSCALL_STR, check->cmd_str, errstr);
 }
@@ -315,7 +351,6 @@ test_fcntl_others(void)
 {
 	static const struct fcntl_cmd_check set_checks[] = {
 		{ 0, ARG_STR(F_SETFD), ARG_STR(FD_CLOEXEC) },
-		{ 0, ARG_STR(F_SETOWN), ARG_STR(20) },
 #ifdef F_SETPIPE_SZ
 		{ 0, ARG_STR(F_SETPIPE_SZ), ARG_STR(4097) },
 #endif
@@ -336,7 +371,6 @@ test_fcntl_others(void)
 	static const struct fcntl_cmd_check get_checks[] = {
 		{ 0, ARG_STR(F_GETFD), .print_flags = print_flags_getfd },
 		{ 1, ARG_STR(F_GETFD), .print_flags = print_flags_getfd },
-		{ 0, ARG_STR(F_GETOWN) },
 #ifdef F_GETPIPE_SZ
 		{ 0, ARG_STR(F_GETPIPE_SZ) },
 #endif
@@ -352,20 +386,16 @@ test_fcntl_others(void)
 static void
 create_sample(void)
 {
-	char fname[] = TEST_SYSCALL_STR "_XXXXXX";
-
 	(void) close(0);
-	if (mkstemp(fname))
-		perror_msg_and_fail("mkstemp: %s", fname);
-	if (unlink(fname))
-		perror_msg_and_fail("unlink: %s", fname);
-	if (ftruncate(0, FILE_LEN))
+	if (ftruncate(create_tmpfile(O_RDWR), FILE_LEN))
 		perror_msg_and_fail("ftruncate");
 }
 
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	create_sample();
 	test_flock();
 	test_flock64();
@@ -373,7 +403,9 @@ main(void)
 	test_f_owner_ex();
 #endif
 	test_fcntl_others();
+	test_xetown();
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/fcntl--pidns-translation.c 5.9-0ubuntu2/tests-m32/fcntl--pidns-translation.c
--- 5.5-3/tests-m32/fcntl--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/fcntl--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "fcntl.c"
diff -pruN 5.5-3/tests-m32/fcntl--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/fcntl--pidns-translation.gen.test
--- 5.5-3/tests-m32/fcntl--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/fcntl--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (fcntl--pidns-translation test_pidns -a8 -e trace=fcntl); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a8 -e trace=fcntl
diff -pruN 5.5-3/tests-m32/file_ioctl.c 5.9-0ubuntu2/tests-m32/file_ioctl.c
--- 5.5-3/tests-m32/file_ioctl.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/file_ioctl.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -11,6 +11,7 @@
 
 # include <stdio.h>
 # include <sys/ioctl.h>
+# include <linux/types.h>
 # include <linux/fiemap.h>
 # include <linux/fs.h>
 # include "xlat.h"
diff -pruN 5.5-3/tests-m32/fill_memory.c 5.9-0ubuntu2/tests-m32/fill_memory.c
--- 5.5-3/tests-m32/fill_memory.c	2019-03-18 02:40:16.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/fill_memory.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -24,3 +24,39 @@ fill_memory(void *ptr, size_t size)
 {
 	fill_memory_ex(ptr, size, 0x80, 0x80);
 }
+
+void
+fill_memory16_ex(void *ptr, size_t size, uint16_t start,
+	         unsigned int period)
+{
+	uint16_t *p = ptr;
+	size_t i;
+
+	for (i = 0; i < size / sizeof(uint16_t); i++) {
+		p[i] = start + i % period;
+	}
+}
+
+void
+fill_memory16(void *ptr, size_t size)
+{
+	fill_memory16_ex(ptr, size, 0x80c0, 0x8000);
+}
+
+void
+fill_memory32_ex(void *ptr, size_t size, uint32_t start,
+	         unsigned int period)
+{
+	uint32_t *p = ptr;
+	size_t i;
+
+	for (i = 0; i < size / sizeof(uint32_t); i++) {
+		p[i] = start + i % period;
+	}
+}
+
+void
+fill_memory32(void *ptr, size_t size)
+{
+	fill_memory32_ex(ptr, size, 0x80a0c0e0, 0x80000000);
+}
diff -pruN 5.5-3/tests-m32/filter_seccomp-flag.c 5.9-0ubuntu2/tests-m32/filter_seccomp-flag.c
--- 5.5-3/tests-m32/filter_seccomp-flag.c	2019-11-15 22:33:53.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/filter_seccomp-flag.c	2020-04-15 13:39:57.000000000 +0000
@@ -2,7 +2,7 @@
  * Check that syscall numbers do not conflict with seccomp filter flags.
  *
  * Copyright (c) 2019 Paul Chaignon <paul.chaignon@gmail.com>
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -22,12 +22,6 @@
 # undef XLAT_MACROS_ONLY
 #endif
 
-#ifdef __x86_64__
-# ifndef __X32_SYSCALL_BIT
-#  define __X32_SYSCALL_BIT     0x40000000
-# endif
-#endif
-
 /* Define these shorthand notations to simplify the syscallent files. */
 #include "sysent_shorthand_defs.h"
 
@@ -36,13 +30,13 @@ const struct_sysent sysent0[] = {
 };
 
 #if SUPPORTED_PERSONALITIES > 1
-static const struct_sysent sysent1[] = {
+const struct_sysent sysent1[] = {
 # include "syscallent1.h"
 };
 #endif
 
 #if SUPPORTED_PERSONALITIES > 2
-static const struct_sysent sysent2[] = {
+const struct_sysent sysent2[] = {
 # include "syscallent2.h"
 };
 #endif
diff -pruN 5.5-3/tests-m32/fork--pidns-translation.awk 5.9-0ubuntu2/tests-m32/fork--pidns-translation.awk
--- 5.5-3/tests-m32/fork--pidns-translation.awk	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/fork--pidns-translation.awk	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,15 @@
+/fork/ {
+        match($0, "([0-9]+) in strace\x27s PID NS", a);
+        if (a[1])
+                fork_pid = a[1]
+}
+
+/exited with 0/ {
+        if (!exit_pid)
+                exit_pid = $1
+}
+
+END {
+        if (!fork_pid || !exit_pid || fork_pid != exit_pid)
+                exit 1
+}
diff -pruN 5.5-3/tests-m32/fork--pidns-translation.c 5.9-0ubuntu2/tests-m32/fork--pidns-translation.c
--- 5.5-3/tests-m32/fork--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/fork--pidns-translation.c	2020-09-23 16:29:35.000000000 +0000
@@ -0,0 +1,78 @@
+/*
+ * Test PID namespace translation
+ *
+ * Copyright (c) 2020 Ákos Uzonyi <uzonyi.akos@gmail.com>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+#include "pidns.h"
+
+#ifdef __NR_fork
+
+# include <errno.h>
+# include <limits.h>
+# include <sched.h>
+# include <signal.h>
+# include <stdio.h>
+# include <stdlib.h>
+# include <sys/wait.h>
+# include <unistd.h>
+# include <linux/sched.h>
+# include "nsfs.h"
+
+# ifndef CLONE_NEWUSER
+#  define CLONE_NEWUSER 0x10000000
+# endif
+
+# ifndef CLONE_NEWPID
+#  define CLONE_NEWPID 0x20000000
+# endif
+
+static int
+fork_chain(int depth)
+{
+	if (!depth)
+		return 0;
+
+	int pid = syscall(__NR_fork);
+	if (pid < 0)
+		return errno;
+
+	if (!pid)
+		_exit(fork_chain(depth - 1));
+
+	int status;
+	if (wait(&status) < 0)
+		return errno;
+
+	if (!WIFEXITED(status))
+		return -1;
+
+	return WEXITSTATUS(status);
+}
+
+int main(void)
+{
+	check_ns_ioctl();
+
+	if (unshare(CLONE_NEWPID | CLONE_NEWUSER) < 0) {
+		if (errno == EPERM)
+			perror_msg_and_skip("unshare");
+
+		perror_msg_and_fail("unshare");
+	}
+
+	errno = fork_chain(2);
+	if (errno)
+		perror("fork_chain");
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_fork")
+
+#endif
diff -pruN 5.5-3/tests-m32/fork--pidns-translation.test 5.9-0ubuntu2/tests-m32/fork--pidns-translation.test
--- 5.5-3/tests-m32/fork--pidns-translation.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/fork--pidns-translation.test	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,14 @@
+#!/bin/sh
+#
+# Check pidns translation of fork's return value.
+#
+# Copyright (c) 2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: LGPL-2.1-or-later
+
+. "${srcdir=.}/init.sh"
+
+run_prog
+run_strace -a6 --pidns-translation -f -e trace=fork $args
+match_awk
diff -pruN 5.5-3/tests-m32/futex.c 5.9-0ubuntu2/tests-m32/futex.c
--- 5.5-3/tests-m32/futex.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/futex.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -495,7 +495,7 @@ main(int argc, char *argv[])
 	 *                 wake val2 processes waiting for uaddr2 in case
 	 *                 operation encoded in val3 (change of value at uaddr2
 	 *                 and comparison of previous value against provided
-	 *                 constant) succeedes with value at uaddr2. Operation
+	 *                 constant) succeeds with value at uaddr2. Operation
 	 *                 result is written to value of uaddr2 (in any case).
 	 * 1. uaddr   - futex address
 	 * 2. op      - FUTEX_WAKE_OP
diff -pruN 5.5-3/tests-m32/gen_tests.am 5.9-0ubuntu2/tests-m32/gen_tests.am
--- 5.5-3/tests-m32/gen_tests.am	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/gen_tests.am	2020-09-24 09:18:50.000000000 +0000
@@ -1,5 +1,5 @@
 # Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in; do not edit.
-GEN_TESTS = _newselect.gen.test _newselect-P.gen.test accept.gen.test accept4.gen.test access.gen.test acct.gen.test add_key.gen.test adjtimex.gen.test aio.gen.test aio_pgetevents.gen.test alarm.gen.test bpf.gen.test bpf-obj_get_info_by_fd.gen.test bpf-obj_get_info_by_fd-prog.gen.test bpf-obj_get_info_by_fd-prog-v.gen.test bpf-obj_get_info_by_fd-v.gen.test bpf-v.gen.test btrfs.gen.test chmod.gen.test chown.gen.test chown32.gen.test chroot.gen.test clock.gen.test clock_adjtime.gen.test clock_nanosleep.gen.test clock_xettime.gen.test clone3.gen.test clone3-Xabbrev.gen.test clone3-Xraw.gen.test clone3-Xverbose.gen.test clone3-success-Xabbrev.gen.test clone3-success-Xraw.gen.test clone3-success-Xverbose.gen.test copy_file_range.gen.test creat.gen.test delete_module.gen.test dev-yy.gen.test dup.gen.test dup2.gen.test dup3.gen.test epoll_create.gen.test epoll_create1.gen.test epoll_ctl.gen.test epoll_pwait.gen.test epoll_wait.gen.test erestartsys.gen.test execveat.gen.test execveat-v.gen.test faccessat.gen.test fadvise64_64.gen.test fallocate.gen.test fanotify_init.gen.test fanotify_mark.gen.test fanotify_mark-Xabbrev.gen.test fanotify_mark-Xraw.gen.test fanotify_mark-Xverbose.gen.test fchdir.gen.test fchmod.gen.test fchmodat.gen.test fchown.gen.test fchown32.gen.test fchownat.gen.test fcntl.gen.test fcntl64.gen.test fdatasync.gen.test file_handle.gen.test file_ioctl.gen.test filter_seccomp.gen.test filter_seccomp-flag.gen.test finit_module.gen.test flock.gen.test fork-f.gen.test fsconfig.gen.test fsconfig-P.gen.test fsmount.gen.test fsopen.gen.test fspick.gen.test fspick-P.gen.test fstat.gen.test fstat-Xabbrev.gen.test fstat-Xraw.gen.test fstat-Xverbose.gen.test fstat64.gen.test fstat64-Xabbrev.gen.test fstat64-Xraw.gen.test fstat64-Xverbose.gen.test fstatat64.gen.test fstatfs.gen.test fstatfs64.gen.test fsync.gen.test fsync-y.gen.test ftruncate.gen.test ftruncate64.gen.test futimesat.gen.test get_mempolicy.gen.test getcpu.gen.test getcwd.gen.test getdents.gen.test getdents64.gen.test getegid.gen.test getegid-creds.gen.test getegid32.gen.test getegid32-creds.gen.test geteuid.gen.test geteuid-creds.gen.test geteuid32.gen.test geteuid32-creds.gen.test getgid.gen.test getgid-creds.gen.test getgid32.gen.test getgid32-creds.gen.test getgroups.gen.test getgroups32.gen.test getpeername.gen.test getpgrp.gen.test getpid.gen.test getppid.gen.test getrandom.gen.test getresgid.gen.test getresgid32.gen.test getresuid.gen.test getresuid32.gen.test getrlimit.gen.test getrusage.gen.test getsid.gen.test getsockname.gen.test gettid.gen.test getuid-creds.gen.test getuid32.gen.test getuid32-creds.gen.test getxxid.gen.test group_req.gen.test inet-cmsg.gen.test init_module.gen.test inotify.gen.test inotify_init.gen.test inotify_init1.gen.test inotify_init1-y.gen.test io_uring_enter.gen.test io_uring_register.gen.test io_uring_setup.gen.test ioctl_block.gen.test ioctl_dm.gen.test ioctl_dm-v.gen.test ioctl_evdev.gen.test ioctl_evdev-Xabbrev.gen.test ioctl_evdev-Xraw.gen.test ioctl_evdev-Xverbose.gen.test ioctl_evdev-v.gen.test ioctl_evdev-v-Xabbrev.gen.test ioctl_evdev-v-Xraw.gen.test ioctl_evdev-v-Xverbose.gen.test ioctl_evdev-success-Xabbrev.gen.test ioctl_evdev-success-Xraw.gen.test ioctl_evdev-success-Xverbose.gen.test ioctl_evdev-success-v.gen.test ioctl_evdev-success-v-Xabbrev.gen.test ioctl_evdev-success-v-Xraw.gen.test ioctl_evdev-success-v-Xverbose.gen.test ioctl_inotify.gen.test ioctl_kvm_run.gen.test ioctl_kvm_run-v.gen.test ioctl_kvm_run_auxstr_vcpu.gen.test ioctl_loop.gen.test ioctl_loop-nv.gen.test ioctl_loop-v.gen.test ioctl_mtd.gen.test ioctl_nbd.gen.test ioctl_nsfs.gen.test ioctl_perf.gen.test ioctl_ptp.gen.test ioctl_random.gen.test ioctl_rtc.gen.test ioctl_rtc-v.gen.test ioctl_scsi.gen.test ioctl_sg_io_v3.gen.test ioctl_sg_io_v4.gen.test ioctl_sock_gifconf.gen.test ioctl_uffdio.gen.test ioctl_v4l2.gen.test ioctl_watchdog.gen.test ioperm.gen.test iopl.gen.test ioprio.gen.test ioprio-Xabbrev.gen.test ioprio-Xraw.gen.test ioprio-Xverbose.gen.test ip_mreq.gen.test ipc.gen.test ipc_msg.gen.test ipc_msg-Xabbrev.gen.test ipc_msg-Xraw.gen.test ipc_msg-Xverbose.gen.test ipc_msgbuf-Xabbrev.gen.test ipc_msgbuf-Xraw.gen.test ipc_msgbuf-Xverbose.gen.test ipc_sem.gen.test ipc_sem-Xabbrev.gen.test ipc_sem-Xraw.gen.test ipc_sem-Xverbose.gen.test ipc_shm.gen.test ipc_shm-Xabbrev.gen.test ipc_shm-Xraw.gen.test ipc_shm-Xverbose.gen.test kcmp.gen.test kcmp-y.gen.test kern_features.gen.test kernel_version.gen.test kernel_version-Xabbrev.gen.test kernel_version-Xraw.gen.test kernel_version-Xverbose.gen.test kexec_file_load.gen.test kexec_load.gen.test keyctl.gen.test keyctl-Xabbrev.gen.test keyctl-Xraw.gen.test keyctl-Xverbose.gen.test kill.gen.test ksysent.gen.test lchown.gen.test lchown32.gen.test link.gen.test linkat.gen.test lookup_dcookie.gen.test lstat.gen.test lstat64.gen.test madvise.gen.test maybe_switch_current_tcp.gen.test mbind.gen.test mbind-Xabbrev.gen.test mbind-Xraw.gen.test mbind-Xverbose.gen.test membarrier.gen.test memfd_create.gen.test memfd_create-Xabbrev.gen.test memfd_create-Xraw.gen.test memfd_create-Xverbose.gen.test migrate_pages.gen.test mincore.gen.test mkdir.gen.test mkdirat.gen.test mknod.gen.test mknodat.gen.test mlock.gen.test mlock2.gen.test mlockall.gen.test mmap-Xabbrev.gen.test mmap-Xraw.gen.test mmap-Xverbose.gen.test mmap64.gen.test mmap64-Xabbrev.gen.test mmap64-Xraw.gen.test mmap64-Xverbose.gen.test mmsg.gen.test mmsg-silent.gen.test mmsg_name.gen.test mmsg_name-v.gen.test modify_ldt.gen.test mount.gen.test mount-Xabbrev.gen.test mount-Xraw.gen.test mount-Xverbose.gen.test move_mount.gen.test move_mount-P.gen.test move_pages.gen.test move_pages-Xabbrev.gen.test move_pages-Xraw.gen.test move_pages-Xverbose.gen.test mq.gen.test mq_sendrecv.gen.test mq_sendrecv-read.gen.test mq_sendrecv-write.gen.test msg_control.gen.test msg_control-v.gen.test msg_name.gen.test munlockall.gen.test nanosleep.gen.test net-icmp_filter.gen.test net-packet_mreq.gen.test net-packet_mreq-Xabbrev.gen.test net-packet_mreq-Xraw.gen.test net-packet_mreq-Xverbose.gen.test net-sockaddr.gen.test net-tpacket_req.gen.test net-tpacket_stats.gen.test net-yy-inet6.gen.test netlink_audit.gen.test netlink_crypto.gen.test netlink_generic.gen.test netlink_kobject_uevent.gen.test netlink_netfilter.gen.test netlink_protocol.gen.test netlink_route.gen.test netlink_selinux.gen.test netlink_xfrm.gen.test newfstatat.gen.test nfnetlink_acct.gen.test nfnetlink_cthelper.gen.test nfnetlink_ctnetlink.gen.test nfnetlink_ctnetlink_exp.gen.test nfnetlink_cttimeout.gen.test nfnetlink_ipset.gen.test nfnetlink_nft_compat.gen.test nfnetlink_nftables.gen.test nfnetlink_osf.gen.test nfnetlink_queue.gen.test nfnetlink_ulog.gen.test nlattr.gen.test nlattr_br_port_msg.gen.test nlattr_crypto_user_alg.gen.test nlattr_dcbmsg.gen.test nlattr_fib_rule_hdr.gen.test nlattr_ifaddrlblmsg.gen.test nlattr_ifaddrmsg.gen.test nlattr_ifinfomsg.gen.test nlattr_ifla_af_spec.gen.test nlattr_ifla_brport.gen.test nlattr_ifla_linkinfo.gen.test nlattr_ifla_port.gen.test nlattr_ifla_xdp.gen.test nlattr_inet_diag_msg.gen.test nlattr_inet_diag_req_compat.gen.test nlattr_inet_diag_req_v2.gen.test nlattr_mdba_mdb_entry.gen.test nlattr_mdba_router_port.gen.test nlattr_ndmsg.gen.test nlattr_ndtmsg.gen.test nlattr_netconfmsg.gen.test nlattr_netlink_diag_msg.gen.test nlattr_nlmsgerr.gen.test nlattr_packet_diag_msg.gen.test nlattr_rtgenmsg.gen.test nlattr_rtmsg.gen.test nlattr_smc_diag_msg.gen.test nlattr_tc_stats.gen.test nlattr_tca_stab.gen.test nlattr_tcamsg.gen.test nlattr_tcmsg.gen.test nlattr_unix_diag_msg.gen.test old_mmap.gen.test old_mmap-P.gen.test old_mmap-Xabbrev.gen.test old_mmap-Xraw.gen.test old_mmap-Xverbose.gen.test old_mmap-v-none.gen.test oldfstat.gen.test oldlstat.gen.test oldselect.gen.test oldselect-P.gen.test oldselect-efault.gen.test oldselect-efault-P.gen.test oldstat.gen.test open.gen.test open_tree.gen.test open_tree-P.gen.test openat.gen.test orphaned_process_group.gen.test osf_utimes.gen.test pause.gen.test perf_event_open.gen.test perf_event_open_nonverbose.gen.test perf_event_open_unabbrev.gen.test personality-Xabbrev.gen.test personality-Xraw.gen.test personality-Xverbose.gen.test pidfd_open.gen.test pidfd_open-P.gen.test pidfd_open-y.gen.test pidfd_send_signal.gen.test pipe2.gen.test pkey_alloc.gen.test pkey_free.gen.test pkey_mprotect.gen.test ppoll.gen.test ppoll-P.gen.test ppoll-v.gen.test pread64-pwrite64.gen.test preadv.gen.test preadv-pwritev.gen.test preadv2-pwritev2.gen.test printpath-umovestr.gen.test printpath-umovestr-peekdata.gen.test printpath-umovestr-undumpable.gen.test printsignal-Xabbrev.gen.test printsignal-Xraw.gen.test printsignal-Xverbose.gen.test printstr.gen.test printstrn-umoven.gen.test printstrn-umoven-peekdata.gen.test printstrn-umoven-undumpable.gen.test prlimit64.gen.test process_vm_readv.gen.test process_vm_writev.gen.test pselect6.gen.test ptrace.gen.test ptrace_syscall_info.gen.test pwritev.gen.test quotactl.gen.test quotactl-Xabbrev.gen.test quotactl-Xraw.gen.test quotactl-Xverbose.gen.test quotactl-v.gen.test quotactl-xfs.gen.test quotactl-xfs-v.gen.test read-write.gen.test readahead.gen.test readdir.gen.test readlink.gen.test readlinkat.gen.test reboot.gen.test recv-MSG_TRUNC.gen.test recvfrom.gen.test recvfrom-MSG_TRUNC.gen.test recvmmsg-timeout.gen.test recvmsg.gen.test regex.gen.test remap_file_pages.gen.test remap_file_pages-Xabbrev.gen.test remap_file_pages-Xraw.gen.test remap_file_pages-Xverbose.gen.test rename.gen.test renameat.gen.test renameat2.gen.test request_key.gen.test riscv_flush_icache.gen.test rmdir.gen.test rt_sigpending.gen.test rt_sigprocmask.gen.test rt_sigqueueinfo.gen.test rt_sigreturn.gen.test rt_sigsuspend.gen.test rt_sigtimedwait.gen.test rt_tgsigqueueinfo.gen.test s390_guarded_storage.gen.test s390_guarded_storage-v.gen.test s390_pci_mmio_read_write.gen.test s390_runtime_instr.gen.test s390_sthyi.gen.test s390_sthyi-v.gen.test sched.gen.test sched_get_priority_mxx.gen.test sched_rr_get_interval.gen.test sched_xetaffinity.gen.test sched_xetattr.gen.test sched_xetparam.gen.test sched_xetscheduler.gen.test sched_yield.gen.test seccomp-filter.gen.test seccomp-filter-v.gen.test seccomp_get_action_avail.gen.test select.gen.test select-P.gen.test semop.gen.test semop-indirect.gen.test semtimedop.gen.test sendfile.gen.test sendfile64.gen.test set_mempolicy.gen.test set_mempolicy-Xabbrev.gen.test set_mempolicy-Xraw.gen.test set_mempolicy-Xverbose.gen.test setdomainname.gen.test setfsgid.gen.test setfsgid32.gen.test setfsuid.gen.test setfsuid32.gen.test setgid.gen.test setgid32.gen.test setgroups.gen.test setgroups32.gen.test sethostname.gen.test setns.gen.test setregid.gen.test setregid32.gen.test setresgid.gen.test setresgid32.gen.test setresuid.gen.test setresuid32.gen.test setreuid.gen.test setreuid32.gen.test setrlimit.gen.test setrlimit-Xabbrev.gen.test setrlimit-Xraw.gen.test setrlimit-Xverbose.gen.test setuid.gen.test setuid32.gen.test shmxt.gen.test shutdown.gen.test sigaction.gen.test siginfo.gen.test signal.gen.test signal_receive.gen.test signalfd4.gen.test sigpending.gen.test sigprocmask.gen.test sigreturn.gen.test sigsuspend.gen.test so_error.gen.test so_linger.gen.test so_peercred.gen.test so_peercred-Xabbrev.gen.test so_peercred-Xraw.gen.test so_peercred-Xverbose.gen.test sock_filter-v.gen.test sock_filter-v-Xabbrev.gen.test sock_filter-v-Xraw.gen.test sock_filter-v-Xverbose.gen.test sockaddr_xlat-Xabbrev.gen.test sockaddr_xlat-Xraw.gen.test sockaddr_xlat-Xverbose.gen.test socketcall.gen.test sockopt-sol_netlink.gen.test sockopt-timestamp.gen.test splice.gen.test stat.gen.test stat64.gen.test statfs.gen.test statfs64.gen.test status-all.gen.test status-failed.gen.test status-none.gen.test status-successful.gen.test status-unfinished.gen.test statx.gen.test swap.gen.test sxetmask.gen.test symlink.gen.test symlinkat.gen.test sync.gen.test sync_file_range.gen.test sync_file_range2.gen.test sysinfo.gen.test syslog.gen.test tee.gen.test time.gen.test timer_create.gen.test timer_xettime.gen.test timerfd_xettime.gen.test times.gen.test times-fail.gen.test trace_creds.gen.test trace_fstat.gen.test trace_fstatfs.gen.test trace_lstat.gen.test trace_personality_32.gen.test trace_personality_64.gen.test trace_personality_regex_32.gen.test trace_personality_regex_64.gen.test trace_personality_regex_x32.gen.test trace_personality_x32.gen.test trace_question.gen.test trace_stat.gen.test trace_stat_like.gen.test trace_statfs.gen.test trace_statfs_like.gen.test truncate.gen.test truncate64.gen.test ugetrlimit.gen.test umask.gen.test umoven-illptr.gen.test umovestr-illptr.gen.test umovestr3.gen.test unlink.gen.test unlinkat.gen.test unshare.gen.test userfaultfd.gen.test ustat.gen.test utime.gen.test utimensat.gen.test utimensat-Xabbrev.gen.test utimensat-Xraw.gen.test utimensat-Xverbose.gen.test utimes.gen.test vfork-f.gen.test vhangup.gen.test vmsplice.gen.test wait4.gen.test wait4-v.gen.test waitid.gen.test waitid-v.gen.test waitpid.gen.test xattr.gen.test xattr-strings.gen.test xet_robust_list.gen.test xetitimer.gen.test xetpgid.gen.test xetpriority.gen.test xettimeofday.gen.test
+GEN_TESTS = _newselect.gen.test _newselect-P.gen.test accept.gen.test accept4.gen.test access.gen.test acct.gen.test add_key.gen.test adjtimex.gen.test aio.gen.test aio_pgetevents.gen.test alarm.gen.test bpf.gen.test bpf-obj_get_info_by_fd.gen.test bpf-obj_get_info_by_fd-prog.gen.test bpf-obj_get_info_by_fd-prog-v.gen.test bpf-obj_get_info_by_fd-v.gen.test bpf-v.gen.test btrfs.gen.test chmod.gen.test chown.gen.test chown32.gen.test chroot.gen.test clock.gen.test clock_adjtime.gen.test clock_nanosleep.gen.test clock_xettime.gen.test clone3.gen.test clone3-Xabbrev.gen.test clone3-Xraw.gen.test clone3-Xverbose.gen.test clone3-success-Xabbrev.gen.test clone3-success-Xraw.gen.test clone3-success-Xverbose.gen.test clone_parent.gen.test clone_parent--quiet-exit.gen.test clone_parent-q.gen.test clone_parent-qq.gen.test clone_ptrace--quiet-attach.gen.test clone_ptrace--quiet-exit.gen.test clone_ptrace-q.gen.test clone_ptrace-qq.gen.test close_range.gen.test close_range-P.gen.test close_range-y.gen.test close_range-yy.gen.test copy_file_range.gen.test creat.gen.test delete_module.gen.test dev--decode-fds-dev.gen.test dev--decode-fds-path.gen.test dev--decode-fds-socket.gen.test dev-yy.gen.test dup.gen.test dup-P.gen.test dup-y.gen.test dup-yy.gen.test dup2.gen.test dup2-P.gen.test dup2-y.gen.test dup2-yy.gen.test dup3.gen.test dup3-P.gen.test dup3-y.gen.test dup3-yy.gen.test epoll_create.gen.test epoll_create1.gen.test epoll_ctl.gen.test epoll_pwait.gen.test epoll_wait.gen.test erestartsys.gen.test execveat.gen.test execveat-v.gen.test faccessat-P.gen.test faccessat-y.gen.test faccessat-yy.gen.test faccessat2-P.gen.test faccessat2-y.gen.test faccessat2-yy.gen.test fadvise64_64.gen.test fallocate.gen.test fanotify_init.gen.test fanotify_mark.gen.test fanotify_mark-Xabbrev.gen.test fanotify_mark-Xraw.gen.test fanotify_mark-Xverbose.gen.test fchdir.gen.test fchmod.gen.test fchmodat.gen.test fchown.gen.test fchown32.gen.test fchownat.gen.test fcntl.gen.test fcntl--pidns-translation.gen.test fcntl64.gen.test fcntl64--pidns-translation.gen.test fdatasync.gen.test file_handle.gen.test file_ioctl.gen.test filter_seccomp.gen.test filter_seccomp-flag.gen.test finit_module.gen.test flock.gen.test fork-f.gen.test fsconfig.gen.test fsconfig-P.gen.test fsmount.gen.test fsopen.gen.test fspick.gen.test fspick-P.gen.test fstat.gen.test fstat-Xabbrev.gen.test fstat-Xraw.gen.test fstat-Xverbose.gen.test fstat64.gen.test fstat64-Xabbrev.gen.test fstat64-Xraw.gen.test fstat64-Xverbose.gen.test fstatat64.gen.test fstatfs.gen.test fstatfs64.gen.test fsync.gen.test fsync-y.gen.test ftruncate.gen.test ftruncate64.gen.test futimesat.gen.test get_mempolicy.gen.test getcpu.gen.test getcwd.gen.test getdents.gen.test getdents-v.gen.test getdents64.gen.test getdents64-v.gen.test getegid.gen.test getegid-creds.gen.test getegid32.gen.test getegid32-creds.gen.test geteuid.gen.test geteuid-creds.gen.test geteuid32.gen.test geteuid32-creds.gen.test getgid.gen.test getgid-creds.gen.test getgid32.gen.test getgid32-creds.gen.test getgroups.gen.test getgroups32.gen.test getpeername.gen.test getpgrp.gen.test getpgrp--pidns-translation.gen.test getpid.gen.test getpid--pidns-translation.gen.test getppid.gen.test getrandom.gen.test getresgid.gen.test getresgid32.gen.test getresuid.gen.test getresuid32.gen.test getrlimit.gen.test getrusage.gen.test getsid.gen.test getsid--pidns-translation.gen.test getsockname.gen.test gettid.gen.test getuid-creds.gen.test getuid32.gen.test getuid32-creds.gen.test getxgid.gen.test getxpid.gen.test getxuid.gen.test group_req.gen.test inet-cmsg.gen.test init_module.gen.test inotify.gen.test inotify_init.gen.test inotify_init1.gen.test inotify_init1-y.gen.test io_uring_enter.gen.test io_uring_register.gen.test io_uring_setup.gen.test ioctl_block.gen.test ioctl_dm.gen.test ioctl_dm-v.gen.test ioctl_evdev.gen.test ioctl_evdev-Xabbrev.gen.test ioctl_evdev-Xraw.gen.test ioctl_evdev-Xverbose.gen.test ioctl_evdev-v.gen.test ioctl_evdev-v-Xabbrev.gen.test ioctl_evdev-v-Xraw.gen.test ioctl_evdev-v-Xverbose.gen.test ioctl_evdev-success-Xabbrev.gen.test ioctl_evdev-success-Xraw.gen.test ioctl_evdev-success-Xverbose.gen.test ioctl_evdev-success-v.gen.test ioctl_evdev-success-v-Xabbrev.gen.test ioctl_evdev-success-v-Xraw.gen.test ioctl_evdev-success-v-Xverbose.gen.test ioctl_hdio.gen.test ioctl_hdio-Xabbrev.gen.test ioctl_hdio-Xraw.gen.test ioctl_hdio-Xverbose.gen.test ioctl_hdio-v.gen.test ioctl_hdio-v-Xabbrev.gen.test ioctl_hdio-v-Xraw.gen.test ioctl_hdio-v-Xverbose.gen.test ioctl_hdio-success.gen.test ioctl_hdio-success-Xabbrev.gen.test ioctl_hdio-success-Xraw.gen.test ioctl_hdio-success-Xverbose.gen.test ioctl_hdio-success-v.gen.test ioctl_hdio-success-v-Xabbrev.gen.test ioctl_hdio-success-v-Xraw.gen.test ioctl_hdio-success-v-Xverbose.gen.test ioctl_inotify.gen.test ioctl_kvm_run.gen.test ioctl_kvm_run-v.gen.test ioctl_kvm_run_auxstr_vcpu.gen.test ioctl_loop.gen.test ioctl_loop-nv.gen.test ioctl_loop-v.gen.test ioctl_mtd.gen.test ioctl_nbd.gen.test ioctl_nsfs.gen.test ioctl_perf.gen.test ioctl_perf-success.gen.test ioctl_ptp.gen.test ioctl_random.gen.test ioctl_rtc.gen.test ioctl_rtc-v.gen.test ioctl_scsi.gen.test ioctl_sg_io_v3.gen.test ioctl_sg_io_v4.gen.test ioctl_sock_gifconf.gen.test ioctl_tee.gen.test ioctl_uffdio.gen.test ioctl_v4l2.gen.test ioctl_v4l2-Xabbrev.gen.test ioctl_v4l2-Xraw.gen.test ioctl_v4l2-Xverbose.gen.test ioctl_v4l2-v.gen.test ioctl_v4l2-v-Xabbrev.gen.test ioctl_v4l2-v-Xraw.gen.test ioctl_v4l2-v-Xverbose.gen.test ioctl_v4l2-success.gen.test ioctl_v4l2-success-Xabbrev.gen.test ioctl_v4l2-success-Xraw.gen.test ioctl_v4l2-success-Xverbose.gen.test ioctl_v4l2-success-v.gen.test ioctl_v4l2-success-v-Xabbrev.gen.test ioctl_v4l2-success-v-Xraw.gen.test ioctl_v4l2-success-v-Xverbose.gen.test ioctl_watchdog.gen.test ioperm.gen.test iopl.gen.test ioprio.gen.test ioprio--pidns-translation.gen.test ioprio-Xabbrev.gen.test ioprio-Xraw.gen.test ioprio-Xverbose.gen.test ip_mreq.gen.test ipc.gen.test ipc_msg.gen.test ipc_msg-Xabbrev.gen.test ipc_msg-Xraw.gen.test ipc_msg-Xverbose.gen.test ipc_msgbuf-Xabbrev.gen.test ipc_msgbuf-Xraw.gen.test ipc_msgbuf-Xverbose.gen.test ipc_sem.gen.test ipc_sem-Xabbrev.gen.test ipc_sem-Xraw.gen.test ipc_sem-Xverbose.gen.test ipc_shm.gen.test ipc_shm-Xabbrev.gen.test ipc_shm-Xraw.gen.test ipc_shm-Xverbose.gen.test kcmp.gen.test kcmp-y.gen.test kcmp-y--pidns-translation.gen.test kern_features.gen.test kernel_version.gen.test kernel_version-Xabbrev.gen.test kernel_version-Xraw.gen.test kernel_version-Xverbose.gen.test kexec_file_load.gen.test kexec_load.gen.test keyctl.gen.test keyctl-Xabbrev.gen.test keyctl-Xraw.gen.test keyctl-Xverbose.gen.test kill.gen.test kill--pidns-translation.gen.test ksysent.gen.test lchown.gen.test lchown32.gen.test link.gen.test linkat.gen.test lookup_dcookie.gen.test lstat.gen.test lstat64.gen.test madvise.gen.test maybe_switch_current_tcp.gen.test maybe_switch_current_tcp--quiet-thread-execve.gen.test mbind.gen.test mbind-Xabbrev.gen.test mbind-Xraw.gen.test mbind-Xverbose.gen.test membarrier.gen.test memfd_create.gen.test memfd_create-Xabbrev.gen.test memfd_create-Xraw.gen.test memfd_create-Xverbose.gen.test migrate_pages.gen.test migrate_pages--pidns-translation.gen.test mincore.gen.test mkdir.gen.test mkdirat.gen.test mknod.gen.test mknodat.gen.test mlock.gen.test mlock2.gen.test mlockall.gen.test mmap-Xabbrev.gen.test mmap-Xraw.gen.test mmap-Xverbose.gen.test mmap64.gen.test mmap64-Xabbrev.gen.test mmap64-Xraw.gen.test mmap64-Xverbose.gen.test mmsg.gen.test mmsg-silent.gen.test mmsg_name.gen.test mmsg_name-v.gen.test modify_ldt.gen.test mount.gen.test mount-Xabbrev.gen.test mount-Xraw.gen.test mount-Xverbose.gen.test move_mount.gen.test move_mount-P.gen.test move_pages.gen.test move_pages-Xabbrev.gen.test move_pages-Xraw.gen.test move_pages-Xverbose.gen.test move_pages--pidns-translation.gen.test mq.gen.test mq_sendrecv.gen.test mq_sendrecv-read.gen.test mq_sendrecv-write.gen.test msg_control.gen.test msg_control-v.gen.test msg_name.gen.test munlockall.gen.test nanosleep.gen.test net--decode-fds-dev-netlink.gen.test net--decode-fds-none-netlink.gen.test net--decode-fds-path-netlink.gen.test net--decode-fds-socket-netlink.gen.test net-icmp_filter.gen.test net-packet_mreq.gen.test net-packet_mreq-Xabbrev.gen.test net-packet_mreq-Xraw.gen.test net-packet_mreq-Xverbose.gen.test net-sockaddr.gen.test net-sockaddr--pidns-translation.gen.test net-tpacket_req.gen.test net-tpacket_stats.gen.test net-yy-inet6.gen.test netlink_audit.gen.test netlink_crypto.gen.test netlink_generic.gen.test netlink_kobject_uevent.gen.test netlink_netfilter.gen.test netlink_protocol.gen.test netlink_route.gen.test netlink_selinux.gen.test netlink_xfrm.gen.test newfstatat.gen.test nfnetlink_acct.gen.test nfnetlink_cthelper.gen.test nfnetlink_ctnetlink.gen.test nfnetlink_ctnetlink_exp.gen.test nfnetlink_cttimeout.gen.test nfnetlink_ipset.gen.test nfnetlink_nft_compat.gen.test nfnetlink_nftables.gen.test nfnetlink_osf.gen.test nfnetlink_queue.gen.test nfnetlink_ulog.gen.test nlattr.gen.test nlattr_br_port_msg.gen.test nlattr_crypto_user_alg.gen.test nlattr_dcbmsg.gen.test nlattr_fib_rule_hdr.gen.test nlattr_ifaddrlblmsg.gen.test nlattr_ifaddrmsg.gen.test nlattr_ifinfomsg.gen.test nlattr_ifla_af_spec.gen.test nlattr_ifla_brport.gen.test nlattr_ifla_linkinfo.gen.test nlattr_ifla_port.gen.test nlattr_ifla_xdp.gen.test nlattr_ifla_xdp-y.gen.test nlattr_inet_diag_msg.gen.test nlattr_inet_diag_req_compat.gen.test nlattr_inet_diag_req_v2.gen.test nlattr_mdba_mdb_entry.gen.test nlattr_mdba_router_port.gen.test nlattr_ndmsg.gen.test nlattr_ndtmsg.gen.test nlattr_netconfmsg.gen.test nlattr_netlink_diag_msg.gen.test nlattr_nlmsgerr.gen.test nlattr_packet_diag_msg.gen.test nlattr_rtgenmsg.gen.test nlattr_rtmsg.gen.test nlattr_smc_diag_msg.gen.test nlattr_tc_stats.gen.test nlattr_tca_stab.gen.test nlattr_tcamsg.gen.test nlattr_tcmsg.gen.test nlattr_unix_diag_msg.gen.test old_mmap.gen.test old_mmap-P.gen.test old_mmap-Xabbrev.gen.test old_mmap-Xraw.gen.test old_mmap-Xverbose.gen.test old_mmap-v-none.gen.test oldfstat.gen.test oldlstat.gen.test oldselect.gen.test oldselect-P.gen.test oldselect-efault.gen.test oldselect-efault-P.gen.test oldstat.gen.test open.gen.test open_tree.gen.test open_tree-P.gen.test openat.gen.test openat2.gen.test openat2-Xabbrev.gen.test openat2-Xraw.gen.test openat2-Xverbose.gen.test openat2-v.gen.test openat2-v-y.gen.test openat2-v-y-Xabbrev.gen.test openat2-v-y-Xraw.gen.test openat2-v-y-Xverbose.gen.test openat2-y.gen.test orphaned_process_group.gen.test osf_utimes.gen.test pause.gen.test perf_event_open.gen.test perf_event_open_nonverbose.gen.test perf_event_open_unabbrev.gen.test personality-Xabbrev.gen.test personality-Xraw.gen.test personality-Xverbose.gen.test pidfd_getfd.gen.test pidfd_getfd-y.gen.test pidfd_getfd-yy.gen.test pidfd_open.gen.test pidfd_open--decode-fd-path.gen.test pidfd_open--decode-fd-pidfd.gen.test pidfd_open--decode-fd-socket.gen.test pidfd_open-P.gen.test pidfd_open-y.gen.test pidfd_open-yy.gen.test pidfd_open--pidns-translation.gen.test pidfd_send_signal.gen.test pidfd_send_signal--pidns-translation.gen.test pipe2.gen.test pkey_alloc.gen.test pkey_free.gen.test pkey_mprotect.gen.test ppoll.gen.test ppoll-P.gen.test ppoll-v.gen.test pread64-pwrite64.gen.test preadv.gen.test preadv-pwritev.gen.test preadv2-pwritev2.gen.test printpath-umovestr.gen.test printpath-umovestr-peekdata.gen.test printpath-umovestr-undumpable.gen.test printsignal-Xabbrev.gen.test printsignal-Xraw.gen.test printsignal-Xverbose.gen.test printstr.gen.test printstrn-umoven.gen.test printstrn-umoven-peekdata.gen.test printstrn-umoven-undumpable.gen.test prlimit64.gen.test prlimit64--pidns-translation.gen.test process_vm_readv.gen.test process_vm_readv--pidns-translation.gen.test process_vm_writev.gen.test process_vm_writev--pidns-translation.gen.test pselect6.gen.test ptrace.gen.test ptrace_syscall_info.gen.test pwritev.gen.test quotactl.gen.test quotactl-Xabbrev.gen.test quotactl-Xraw.gen.test quotactl-Xverbose.gen.test quotactl-v.gen.test quotactl-xfs.gen.test quotactl-xfs-v.gen.test read-write.gen.test readahead.gen.test readdir.gen.test readlink.gen.test readlinkat.gen.test reboot.gen.test recv-MSG_TRUNC.gen.test recvfrom.gen.test recvfrom-MSG_TRUNC.gen.test recvmmsg-timeout.gen.test recvmsg.gen.test regex.gen.test remap_file_pages.gen.test remap_file_pages-Xabbrev.gen.test remap_file_pages-Xraw.gen.test remap_file_pages-Xverbose.gen.test rename.gen.test renameat.gen.test renameat2.gen.test request_key.gen.test riscv_flush_icache.gen.test rmdir.gen.test rt_sigpending.gen.test rt_sigprocmask.gen.test rt_sigqueueinfo.gen.test rt_sigqueueinfo--pidns-translation.gen.test rt_sigreturn.gen.test rt_sigsuspend.gen.test rt_sigtimedwait.gen.test rt_tgsigqueueinfo.gen.test rt_tgsigqueueinfo--pidns-translation.gen.test s390_guarded_storage.gen.test s390_guarded_storage-v.gen.test s390_pci_mmio_read_write.gen.test s390_runtime_instr.gen.test s390_sthyi.gen.test s390_sthyi-v.gen.test sched.gen.test sched_get_priority_mxx.gen.test sched_rr_get_interval.gen.test sched_xetaffinity.gen.test sched_xetaffinity--pidns-translation.gen.test sched_xetattr.gen.test sched_xetattr--pidns-translation.gen.test sched_xetparam.gen.test sched_xetparam--pidns-translation.gen.test sched_xetscheduler.gen.test sched_xetscheduler--pidns-translation.gen.test sched_yield.gen.test seccomp-filter.gen.test seccomp-filter-v.gen.test seccomp_get_action_avail.gen.test select.gen.test select-P.gen.test semop.gen.test semop-indirect.gen.test semtimedop.gen.test sendfile.gen.test sendfile64.gen.test set_mempolicy.gen.test set_mempolicy-Xabbrev.gen.test set_mempolicy-Xraw.gen.test set_mempolicy-Xverbose.gen.test setdomainname.gen.test setfsgid.gen.test setfsgid32.gen.test setfsuid.gen.test setfsuid32.gen.test setgid.gen.test setgid32.gen.test setgroups.gen.test setgroups32.gen.test sethostname.gen.test setns.gen.test setregid.gen.test setregid32.gen.test setresgid.gen.test setresgid32.gen.test setresuid.gen.test setresuid32.gen.test setreuid.gen.test setreuid32.gen.test setrlimit.gen.test setrlimit-Xabbrev.gen.test setrlimit-Xraw.gen.test setrlimit-Xverbose.gen.test setuid.gen.test setuid32.gen.test shmxt.gen.test shutdown.gen.test sigaction.gen.test siginfo.gen.test signal.gen.test signal_receive.gen.test signal_receive--pidns-translation.gen.test signalfd4.gen.test sigpending.gen.test sigprocmask.gen.test sigreturn.gen.test sigsuspend.gen.test so_error.gen.test so_linger.gen.test so_peercred.gen.test so_peercred-Xabbrev.gen.test so_peercred-Xraw.gen.test so_peercred-Xverbose.gen.test so_peercred--pidns-translation.gen.test sock_filter-v.gen.test sock_filter-v-Xabbrev.gen.test sock_filter-v-Xraw.gen.test sock_filter-v-Xverbose.gen.test sockaddr_xlat-Xabbrev.gen.test sockaddr_xlat-Xraw.gen.test sockaddr_xlat-Xverbose.gen.test socketcall.gen.test sockopt-sol_netlink.gen.test sockopt-timestamp.gen.test splice.gen.test stat.gen.test stat64.gen.test statfs.gen.test statfs64.gen.test status-all.gen.test status-failed.gen.test status-failed-long.gen.test status-failed-status.gen.test status-none.gen.test status-successful.gen.test status-successful-long.gen.test status-successful-status.gen.test status-unfinished.gen.test statx.gen.test strace--absolute-timestamps.gen.test strace--absolute-timestamps-format-time.gen.test strace--absolute-timestamps-format-time-precision-s.gen.test strace--absolute-timestamps-format-time-precision-ms.gen.test strace--absolute-timestamps-format-time-precision-us.gen.test strace--absolute-timestamps-format-time-precision-ns.gen.test strace--absolute-timestamps-format-unix-precision-s.gen.test strace--absolute-timestamps-format-unix-precision-ms.gen.test strace--absolute-timestamps-format-unix-precision-us.gen.test strace--absolute-timestamps-format-unix-precision-ns.gen.test strace--follow-forks-output-separately.gen.test strace--relative-timestamps.gen.test strace--relative-timestamps-s.gen.test strace--relative-timestamps-ms.gen.test strace--relative-timestamps-us.gen.test strace--relative-timestamps-ns.gen.test strace--syscall-times.gen.test strace--syscall-times-s.gen.test strace--syscall-times-ms.gen.test strace--syscall-times-us.gen.test strace--syscall-times-ns.gen.test strace--strings-in-hex.gen.test strace--strings-in-hex-all.gen.test strace--strings-in-hex-non-ascii.gen.test strace--timestamps.gen.test strace--timestamps-time.gen.test strace--timestamps-time-s.gen.test strace--timestamps-time-ms.gen.test strace--timestamps-time-us.gen.test strace--timestamps-time-ns.gen.test strace--timestamps-unix-s.gen.test strace--timestamps-unix-ms.gen.test strace--timestamps-unix-us.gen.test strace--timestamps-unix-ns.gen.test strace-n.gen.test strace-x.gen.test strace-xx.gen.test swap.gen.test sxetmask.gen.test symlink.gen.test symlinkat.gen.test sync.gen.test sync_file_range.gen.test sync_file_range2.gen.test sysinfo.gen.test syslog.gen.test tee.gen.test tgkill.gen.test tgkill--pidns-translation.gen.test threads-execve--quiet-thread-execve.gen.test threads-execve-q.gen.test threads-execve-qq.gen.test threads-execve-qqq.gen.test time.gen.test timer_create.gen.test timer_xettime.gen.test timerfd_xettime.gen.test times.gen.test times-fail.gen.test tkill.gen.test tkill--pidns-translation.gen.test trace_clock.gen.test trace_creds.gen.test trace_fstat.gen.test trace_fstatfs.gen.test trace_lstat.gen.test trace_personality_32.gen.test trace_personality_64.gen.test trace_personality_regex_32.gen.test trace_personality_regex_64.gen.test trace_personality_regex_x32.gen.test trace_personality_x32.gen.test trace_question.gen.test trace_stat.gen.test trace_stat_like.gen.test trace_statfs.gen.test trace_statfs_like.gen.test trie_test.gen.test truncate.gen.test truncate64.gen.test ugetrlimit.gen.test umask.gen.test umoven-illptr.gen.test umovestr-illptr.gen.test umovestr3.gen.test umovestr_cached_adjacent.gen.test unlink.gen.test unlinkat.gen.test unshare.gen.test userfaultfd.gen.test ustat.gen.test utime.gen.test utimensat.gen.test utimensat-Xabbrev.gen.test utimensat-Xraw.gen.test utimensat-Xverbose.gen.test utimes.gen.test vfork-f.gen.test vhangup.gen.test vmsplice.gen.test wait4.gen.test wait4-v.gen.test waitid.gen.test waitid-v.gen.test waitpid.gen.test xattr.gen.test xattr-strings.gen.test xet_robust_list.gen.test xet_robust_list--pidns-translation.gen.test xetitimer.gen.test xetpgid.gen.test xetpgid--pidns-translation.gen.test xetpriority.gen.test xetpriority--pidns-translation.gen.test xettimeofday.gen.test
 
 $(srcdir)/_newselect.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
@@ -100,6 +100,42 @@ $(srcdir)/clone3-success-Xraw.gen.test:
 $(srcdir)/clone3-success-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/clone_parent.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_parent--quiet-exit.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_parent-q.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_parent-qq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_ptrace--quiet-attach.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_ptrace--quiet-exit.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_ptrace-q.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_ptrace-qq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/close_range.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/close_range-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/close_range-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/close_range-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/copy_file_range.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -109,18 +145,54 @@ $(srcdir)/creat.gen.test: $(abs_srcdir)/
 $(srcdir)/delete_module.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/dev--decode-fds-dev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dev--decode-fds-path.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dev--decode-fds-socket.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/dev-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/dup.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/dup-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/dup2.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/dup2-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup2-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup2-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/dup3.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/dup3-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup3-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup3-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/epoll_create.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -145,7 +217,22 @@ $(srcdir)/execveat.gen.test: $(abs_srcdi
 $(srcdir)/execveat-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
-$(srcdir)/faccessat.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+$(srcdir)/faccessat-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat2-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat2-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat2-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/fadvise64_64.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
@@ -190,9 +277,15 @@ $(srcdir)/fchownat.gen.test: $(abs_srcdi
 $(srcdir)/fcntl.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/fcntl--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/fcntl64.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/fcntl64--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/fdatasync.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -295,9 +388,15 @@ $(srcdir)/getcwd.gen.test: $(abs_srcdir)
 $(srcdir)/getdents.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getdents-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getdents64.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getdents64-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getegid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -346,9 +445,15 @@ $(srcdir)/getpeername.gen.test: $(abs_sr
 $(srcdir)/getpgrp.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getpgrp--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getpid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getpid--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getppid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -376,6 +481,9 @@ $(srcdir)/getrusage.gen.test: $(abs_srcd
 $(srcdir)/getsid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getsid--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getsockname.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -391,7 +499,13 @@ $(srcdir)/getuid32.gen.test: $(abs_srcdi
 $(srcdir)/getuid32-creds.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
-$(srcdir)/getxxid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+$(srcdir)/getxgid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/getxpid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/getxuid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/group_req.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
@@ -478,6 +592,54 @@ $(srcdir)/ioctl_evdev-success-v-Xraw.gen
 $(srcdir)/ioctl_evdev-success-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioctl_hdio.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-v-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-v-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-v-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-v-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioctl_inotify.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -511,6 +673,9 @@ $(srcdir)/ioctl_nsfs.gen.test: $(abs_src
 $(srcdir)/ioctl_perf.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioctl_perf-success.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioctl_ptp.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -535,12 +700,60 @@ $(srcdir)/ioctl_sg_io_v4.gen.test: $(abs
 $(srcdir)/ioctl_sock_gifconf.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioctl_tee.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioctl_uffdio.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/ioctl_v4l2.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioctl_v4l2-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-v-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-v-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-v-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-v-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioctl_watchdog.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -553,6 +766,9 @@ $(srcdir)/iopl.gen.test: $(abs_srcdir)/g
 $(srcdir)/ioprio.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioprio--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioprio-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -619,6 +835,9 @@ $(srcdir)/kcmp.gen.test: $(abs_srcdir)/g
 $(srcdir)/kcmp-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/kcmp-y--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/kern_features.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -655,6 +874,9 @@ $(srcdir)/keyctl-Xverbose.gen.test: $(ab
 $(srcdir)/kill.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/kill--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ksysent.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -685,6 +907,9 @@ $(srcdir)/madvise.gen.test: $(abs_srcdir
 $(srcdir)/maybe_switch_current_tcp.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/maybe_switch_current_tcp--quiet-thread-execve.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/mbind.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -715,6 +940,9 @@ $(srcdir)/memfd_create-Xverbose.gen.test
 $(srcdir)/migrate_pages.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/migrate_pages--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/mincore.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -805,6 +1033,9 @@ $(srcdir)/move_pages-Xraw.gen.test: $(ab
 $(srcdir)/move_pages-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/move_pages--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/mq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -832,6 +1063,18 @@ $(srcdir)/munlockall.gen.test: $(abs_src
 $(srcdir)/nanosleep.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/net--decode-fds-dev-netlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/net--decode-fds-none-netlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/net--decode-fds-path-netlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/net--decode-fds-socket-netlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/net-icmp_filter.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -850,6 +1093,9 @@ $(srcdir)/net-packet_mreq-Xverbose.gen.t
 $(srcdir)/net-sockaddr.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/net-sockaddr--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/net-tpacket_req.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -961,6 +1207,9 @@ $(srcdir)/nlattr_ifla_port.gen.test: $(a
 $(srcdir)/nlattr_ifla_xdp.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/nlattr_ifla_xdp-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/nlattr_inet_diag_msg.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1069,6 +1318,36 @@ $(srcdir)/open_tree-P.gen.test: $(abs_sr
 $(srcdir)/openat.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/openat2.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v-y-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v-y-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v-y-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/orphaned_process_group.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1096,18 +1375,45 @@ $(srcdir)/personality-Xraw.gen.test: $(a
 $(srcdir)/personality-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/pidfd_getfd.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_getfd-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_getfd-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pidfd_open.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/pidfd_open--decode-fd-path.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_open--decode-fd-pidfd.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_open--decode-fd-socket.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pidfd_open-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/pidfd_open-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/pidfd_open-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_open--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pidfd_send_signal.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/pidfd_send_signal--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pipe2.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1174,12 +1480,21 @@ $(srcdir)/printstrn-umoven-undumpable.ge
 $(srcdir)/prlimit64.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/prlimit64--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/process_vm_readv.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/process_vm_readv--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/process_vm_writev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/process_vm_writev--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pselect6.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1288,6 +1603,9 @@ $(srcdir)/rt_sigprocmask.gen.test: $(abs
 $(srcdir)/rt_sigqueueinfo.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/rt_sigqueueinfo--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/rt_sigreturn.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1300,6 +1618,9 @@ $(srcdir)/rt_sigtimedwait.gen.test: $(ab
 $(srcdir)/rt_tgsigqueueinfo.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/rt_tgsigqueueinfo--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/s390_guarded_storage.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1330,15 +1651,27 @@ $(srcdir)/sched_rr_get_interval.gen.test
 $(srcdir)/sched_xetaffinity.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/sched_xetaffinity--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sched_xetattr.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/sched_xetattr--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sched_xetparam.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/sched_xetparam--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sched_xetscheduler.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/sched_xetscheduler--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sched_yield.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1477,6 +1810,9 @@ $(srcdir)/signal.gen.test: $(abs_srcdir)
 $(srcdir)/signal_receive.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/signal_receive--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/signalfd4.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1510,6 +1846,9 @@ $(srcdir)/so_peercred-Xraw.gen.test: $(a
 $(srcdir)/so_peercred-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/so_peercred--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sock_filter-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1561,18 +1900,141 @@ $(srcdir)/status-all.gen.test: $(abs_src
 $(srcdir)/status-failed.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/status-failed-long.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/status-failed-status.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/status-none.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/status-successful.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/status-successful-long.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/status-successful-status.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/status-unfinished.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/statx.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/strace--absolute-timestamps.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time-precision-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time-precision-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time-precision-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time-precision-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-unix-precision-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-unix-precision-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-unix-precision-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-unix-precision-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--follow-forks-output-separately.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--strings-in-hex.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--strings-in-hex-all.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--strings-in-hex-non-ascii.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-unix-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-unix-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-unix-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-unix-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace-n.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace-x.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace-xx.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/swap.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1603,6 +2065,24 @@ $(srcdir)/syslog.gen.test: $(abs_srcdir)
 $(srcdir)/tee.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/tgkill.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/tgkill--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/threads-execve--quiet-thread-execve.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/threads-execve-q.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/threads-execve-qq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/threads-execve-qqq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/time.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1621,6 +2101,15 @@ $(srcdir)/times.gen.test: $(abs_srcdir)/
 $(srcdir)/times-fail.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/tkill.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/tkill--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/trace_clock.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/trace_creds.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1666,6 +2155,9 @@ $(srcdir)/trace_statfs.gen.test: $(abs_s
 $(srcdir)/trace_statfs_like.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/trie_test.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/truncate.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1687,6 +2179,9 @@ $(srcdir)/umovestr-illptr.gen.test: $(ab
 $(srcdir)/umovestr3.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/umovestr_cached_adjacent.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/unlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1753,14 +2248,23 @@ $(srcdir)/xattr-strings.gen.test: $(abs_
 $(srcdir)/xet_robust_list.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/xet_robust_list--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/xetitimer.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/xetpgid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/xetpgid--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/xetpriority.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/xetpriority--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/xettimeofday.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
diff -pruN 5.5-3/tests-m32/gen_tests.in 5.9-0ubuntu2/tests-m32/gen_tests.in
--- 5.5-3/tests-m32/gen_tests.in	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/gen_tests.in	2020-09-23 12:56:26.000000000 +0000
@@ -38,13 +38,37 @@ clone3-Xverbose	-a16 -Xverbose -e trace=
 clone3-success-Xabbrev	+clone3-success.test -a16 -Xabbrev
 clone3-success-Xraw	+clone3-success.test -a16 -Xraw
 clone3-success-Xverbose	+clone3-success.test -a16 -Xverbose
+clone_parent +clone_ptrace.test
+clone_parent--quiet-exit +clone_ptrace.test --quiet=exit,personality
+clone_parent-q +clone_ptrace.test -q
+clone_parent-qq +clone_ptrace.test -qq
+clone_ptrace--quiet-attach +clone_ptrace.test --quiet=attach,personality
+clone_ptrace--quiet-exit +clone_ptrace.test --quiet=exit,personality
+clone_ptrace-q +clone_ptrace.test -q
+clone_ptrace-qq +clone_ptrace.test -qq
+close_range	-a21 7>>/dev/full
+close_range-P	-a21 --trace=close_range -P /dev/full 7>>/dev/full
+close_range-y	-a33 --trace=close_range -y 7>>/dev/full
+close_range-yy	-a33 --trace=close_range -yy 7>>/dev/full
 copy_file_range
 creat	-a20
 delete_module	-a23
+dev--decode-fds-dev	-a30 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" -e decode-fds=dev
+dev--decode-fds-path	-a19 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" -e decode-fds=path
+dev--decode-fds-socket	-a19 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" --decode-fds=socket
 dev-yy	-a30 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" -yy
-dup	-a8
-dup2	-a13
-dup3	-a24
+dup	-a7 9>>/dev/full
+dup-P	-a7 --trace=dup -P /dev/full 9>>/dev/full
+dup-y	-a8 --trace=dup -y 9>>/dev/full
+dup-yy	-a8 --trace=dup -yy 9>>/dev/full
+dup2	-a11 9>>/dev/full
+dup2-P	-a11 --trace=dup2 -P /dev/full 9>>/dev/full
+dup2-y	-a13 --trace=dup2 -y 9>>/dev/full
+dup2-yy	-a13 --trace=dup2 -yy 9>>/dev/full
+dup3	-a13 7>>/dev/full
+dup3-P	-a13 --trace=dup3 -P /dev/full 7>>/dev/full
+dup3-y	-a15 --trace=dup3 -y 7>>/dev/full
+dup3-yy	-a15 --trace=dup3 -yy 7>>/dev/full
 epoll_create	-a17
 epoll_create1	-a28
 epoll_ctl
@@ -53,7 +77,12 @@ epoll_wait	-a26
 erestartsys	-a34 -e signal=none -e trace=recvfrom
 execveat
 execveat-v	-v -e trace=execveat
-faccessat	-P $NAME.sample
+faccessat-P	-a23 --trace=faccessat -P /dev/full
+faccessat-y	+faccessat.test -a24 -y
+faccessat-yy	+faccessat.test -a24 -yy
+faccessat2-P	-a27 --trace=faccessat2 -P /dev/full
+faccessat2-y	+faccessat2.test -a28 -y
+faccessat2-yy	+faccessat2.test -a28 -yy
 fadvise64_64	+fadvise64.test
 fallocate	-a18
 fanotify_init
@@ -68,7 +97,9 @@ fchown	-a16
 fchown32	-a18
 fchownat
 fcntl	-a8
+fcntl--pidns-translation	test_pidns -a8 -e trace=fcntl
 fcntl64	-a8
+fcntl64--pidns-translation	test_pidns -a8 -e trace=fcntl64
 fdatasync	-a14
 file_handle	-e trace=name_to_handle_at,open_by_handle_at
 file_ioctl	+ioctl.test
@@ -102,8 +133,10 @@ futimesat	-a28
 get_mempolicy	-s3 -a38
 getcpu	-a25
 getcwd	-a18
-getdents	-a22 -v
-getdents64	-a24 -v
+getdents	-a31
+getdents-v	-a22 -v --trace=getdents
+getdents64	-a33
+getdents64-v	-a24 -v --trace=getdents64
 getegid	+getuid.test
 getegid-creds	+getuid.test
 getegid32	+getuid.test
@@ -120,7 +153,9 @@ getgroups	-a17
 getgroups32	-a19
 getpeername	-a27
 getpgrp	-a10
+getpgrp--pidns-translation	test_pidns -e trace=getpgrp -a10
 getpid	-a9
+getpid--pidns-translation	test_pidns -e trace=getpid -a9
 getppid	-a10
 getrandom	-a32 -s3
 getresgid	-a25
@@ -130,12 +165,15 @@ getresuid32	-a27
 getrlimit	-a27
 getrusage	-v
 getsid	-a10
+getsid--pidns-translation	test_pidns -e trace=getsid -a10
 getsockname	-a27
 gettid	-a9
 getuid-creds	+getuid.test
 getuid32	+getuid.test
 getuid32-creds	+getuid.test
-getxxid	-a10 -e trace=getxpid,getxuid,getxgid
+getxgid	-a10
+getxpid	-a10
+getxuid	-a10
 group_req	-e trace=setsockopt
 inet-cmsg	-e trace=recvmsg
 init_module	-a27
@@ -164,6 +202,22 @@ ioctl_evdev-success-v	+ioctl_evdev-succe
 ioctl_evdev-success-v-Xabbrev	+ioctl_evdev-success.test -v -Xabbrev
 ioctl_evdev-success-v-Xraw	+ioctl_evdev-success.test -a27 -v -Xraw
 ioctl_evdev-success-v-Xverbose	+ioctl_evdev-success.test -a43 -v -Xverbose
+ioctl_hdio	+ioctl.test -a27
+ioctl_hdio-Xabbrev	+ioctl.test -a27 -Xabbrev
+ioctl_hdio-Xraw	+ioctl.test -a20 -Xraw
+ioctl_hdio-Xverbose	+ioctl.test -a39 -Xverbose
+ioctl_hdio-v	+ioctl.test -a27 -v
+ioctl_hdio-v-Xabbrev	+ioctl.test -a27 -v -Xabbrev
+ioctl_hdio-v-Xraw	+ioctl.test -a20 -v -Xraw
+ioctl_hdio-v-Xverbose	+ioctl.test -a39 -v -Xverbose
+ioctl_hdio-success	+ioctl-success.sh -a27
+ioctl_hdio-success-Xabbrev	+ioctl-success.sh -a27 -Xabbrev
+ioctl_hdio-success-Xraw	+ioctl-success.sh -a20 -Xraw
+ioctl_hdio-success-Xverbose	+ioctl-success.sh -a39 -Xverbose
+ioctl_hdio-success-v	+ioctl-success.sh -a27 -v
+ioctl_hdio-success-v-Xabbrev	+ioctl-success.sh -a27 -v -Xabbrev
+ioctl_hdio-success-v-Xraw	+ioctl-success.sh -a20 -v -Xraw
+ioctl_hdio-success-v-Xverbose	+ioctl-success.sh -a39 -v -Xverbose
 ioctl_inotify	+ioctl.test
 ioctl_kvm_run	+ioctl.test -a36 -y
 ioctl_kvm_run-v	+ioctl.test -v -a36 -y
@@ -175,6 +229,7 @@ ioctl_mtd	+ioctl.test
 ioctl_nbd	+ioctl.test -y
 ioctl_nsfs	+ioctl.test -esignal=none
 ioctl_perf	+ioctl.test
+ioctl_perf-success +ioctl-success.sh -a35
 ioctl_ptp	+ioctl.test
 ioctl_random	+ioctl.test
 ioctl_rtc	+ioctl.test
@@ -183,12 +238,29 @@ ioctl_scsi	+ioctl.test
 ioctl_sg_io_v3	+ioctl.test
 ioctl_sg_io_v4	+ioctl.test
 ioctl_sock_gifconf	+ioctl.test -a28 -s1
+ioctl_tee	+ioctl.test
 ioctl_uffdio	+ioctl.test
 ioctl_v4l2	+ioctl.test
+ioctl_v4l2-Xabbrev	+ioctl.test -Xabbrev
+ioctl_v4l2-Xraw	+ioctl.test -Xraw
+ioctl_v4l2-Xverbose	+ioctl.test -Xverbose
+ioctl_v4l2-v	+ioctl.test -v
+ioctl_v4l2-v-Xabbrev	+ioctl.test -v -Xabbrev
+ioctl_v4l2-v-Xraw	+ioctl.test -v -Xraw
+ioctl_v4l2-v-Xverbose	+ioctl.test -v -Xverbose
+ioctl_v4l2-success	+ioctl-success.sh -a29
+ioctl_v4l2-success-Xabbrev	+ioctl-success.sh -a29 -Xabbrev
+ioctl_v4l2-success-Xraw	+ioctl-success.sh -a27 -Xraw
+ioctl_v4l2-success-Xverbose	+ioctl-success.sh -a30 -Xverbose
+ioctl_v4l2-success-v	+ioctl-success.sh -a29 -v
+ioctl_v4l2-success-v-Xabbrev	+ioctl-success.sh -a29 -v -Xabbrev
+ioctl_v4l2-success-v-Xraw	+ioctl-success.sh -a27 -v -Xraw
+ioctl_v4l2-success-v-Xverbose	+ioctl-success.sh -a29 -v -Xverbose
 ioctl_watchdog	+ioctl.test
 ioperm	-a27
 iopl	-a8
 ioprio	-a18 -e trace=ioprio_get,ioprio_set
+ioprio--pidns-translation	test_pidns -a18 -e trace=ioprio_get,ioprio_set
 ioprio-Xabbrev	-a18 -e trace=ioprio_get,ioprio_set -Xabbrev
 ioprio-Xraw	-a18 -e trace=ioprio_get,ioprio_set -Xraw
 ioprio-Xverbose	-a18 -e trace=ioprio_get,ioprio_set -Xverbose
@@ -211,6 +283,7 @@ ipc_shm-Xraw	+ipc.sh -Xraw -a19
 ipc_shm-Xverbose	+ipc.sh -Xverbose -a34
 kcmp	-a22
 kcmp-y	-a22 -y -e trace=kcmp
+kcmp-y--pidns-translation	test_pidns -a22 -y -e trace=kcmp
 kern_features -a16
 kernel_version	-a16 -v -e trace=bpf
 kernel_version-Xabbrev	-a16 -Xabbrev -v -e trace=bpf
@@ -223,6 +296,7 @@ keyctl-Xabbrev	-a31 -s10 -e trace=keyctl
 keyctl-Xraw	-a13 -s10 -e trace=keyctl -Xraw
 keyctl-Xverbose	-a41 -s10 -e trace=keyctl -Xverbose
 kill	-a12 -esignal=none
+kill--pidns-translation	test_pidns -a12 -e trace=kill -esignal=none
 ksysent	../$NAME
 lchown	-a30
 lchown32	-a32
@@ -233,6 +307,7 @@ lstat	-a31 --no-abbrev --trace-path=stat
 lstat64	-a32 --no-abbrev --trace-path=stat.sample --trace-path=/dev/full
 madvise	-a33
 maybe_switch_current_tcp	-a30 -f -e trace=execveat
+maybe_switch_current_tcp--quiet-thread-execve	-a30 -s48 -f -e trace=execveat --quiet=personality,thread-execve
 mbind
 mbind-Xabbrev	-Xabbrev -e trace=mbind
 mbind-Xraw	-a33 -Xraw -e trace=mbind
@@ -243,6 +318,7 @@ memfd_create-Xabbrev	-Xabbrev -e trace=m
 memfd_create-Xraw	-a30 -Xraw -e trace=memfd_create
 memfd_create-Xverbose	-Xverbose -e trace=memfd_create
 migrate_pages	-a33
+migrate_pages--pidns-translation	test_pidns -a33 -e trace=migrate_pages
 mincore	-a22
 mkdir	-a20
 mkdirat	-a28
@@ -273,6 +349,7 @@ move_pages	-s3
 move_pages-Xabbrev	-s3 -e trace=move_pages -Xabbrev
 move_pages-Xraw	-s3 -a36 -e trace=move_pages -Xraw
 move_pages-Xverbose	-s3 -e trace=move_pages -Xverbose
+move_pages--pidns-translation	test_pidns -s3 -e trace=move_pages
 mq	-a32 -e trace=mq_getsetattr,mq_open,mq_unlink
 mq_sendrecv	-a14 -e trace=mq_open,mq_notify,mq_timedsend,mq_timedreceive,mq_unlink
 mq_sendrecv-read	-eread=0 -a14 -e trace=mq_open,mq_notify,mq_timedsend,mq_timedreceive,mq_unlink
@@ -282,12 +359,17 @@ msg_control-v	-v -a21 -e trace=sendmsg
 msg_name	-a20 -e trace=recvmsg
 munlockall	-a13
 nanosleep	-a20
+net--decode-fds-dev-netlink	+net-yy-netlink.test --decode-fds=dev
+net--decode-fds-none-netlink	+net-yy-netlink.test --decode-fds=none -a9
+net--decode-fds-path-netlink	+net-yy-netlink.test --decode-fds=path
+net--decode-fds-socket-netlink	+net-yy-netlink.test --decode-fds=socket
 net-icmp_filter	-e trace=getsockopt,setsockopt
 net-packet_mreq -e trace=setsockopt
 net-packet_mreq-Xabbrev	-e trace=setsockopt -Xabbrev
 net-packet_mreq-Xraw	-e trace=setsockopt -Xraw
 net-packet_mreq-Xverbose	-e trace=setsockopt -Xverbose
 net-sockaddr	-a24 -e trace=connect
+net-sockaddr--pidns-translation	test_pidns -a24 -e trace=connect
 net-tpacket_req -e trace=setsockopt
 net-tpacket_stats -e trace=getsockopt
 net-yy-inet6	+net-yy-inet.test
@@ -325,6 +407,7 @@ nlattr_ifla_brport		+netlink_sock_diag.t
 nlattr_ifla_linkinfo		+netlink_sock_diag.test
 nlattr_ifla_port		+netlink_sock_diag.test
 nlattr_ifla_xdp			+netlink_sock_diag.test
+nlattr_ifla_xdp-y		+netlink_sock_diag.test -y; exec 9</dev/full
 nlattr_inet_diag_msg		+netlink_sock_diag.test
 nlattr_inet_diag_req_compat	+netlink_sock_diag.test
 nlattr_inet_diag_req_v2		+netlink_sock_diag.test
@@ -335,7 +418,7 @@ nlattr_ndtmsg			+netlink_sock_diag.test
 nlattr_netconfmsg		+netlink_sock_diag.test
 nlattr_netlink_diag_msg		+netlink_sock_diag.test
 nlattr_nlmsgerr			+netlink_sock_diag.test
-nlattr_packet_diag_msg		+netlink_sock_diag-v.sh
+nlattr_packet_diag_msg		+netlink_sock_diag.test -v
 nlattr_rtgenmsg			+netlink_sock_diag.test
 nlattr_rtmsg			+netlink_sock_diag.test
 nlattr_smc_diag_msg		+netlink_sock_diag.test
@@ -359,8 +442,18 @@ oldselect-efault-P	-a13 -e trace=select
 oldstat	-a32 -v -P stat.sample -P /dev/full
 open	-a30 -P $NAME.sample
 open_tree -a30 -y
-open_tree-P -a30 -y -P /dev/full -e trace=open_tree
+open_tree-P -a30 --decode-fds -P /dev/full -e trace=open_tree
 openat	-a36 -P $NAME.sample
+openat2	-a35
+openat2-Xabbrev	--trace=openat2 -a35 -Xabbrev
+openat2-Xraw	--trace=openat2 -a32 -Xraw
+openat2-Xverbose	--trace=openat2 -a35 -Xverbose
+openat2-v	--trace=openat2 -a35 -v
+openat2-v-y	--trace=openat2 -a36 -v -y </dev/full
+openat2-v-y-Xabbrev	--trace=openat2 -a35 -v -y -Xabbrev </dev/full
+openat2-v-y-Xraw	--trace=openat2 -a32 -v -y -Xraw </dev/full
+openat2-v-y-Xverbose	--trace=openat2 -a44 -v -y -Xverbose </dev/full
+openat2-y	--trace=openat2 -a36 -y </dev/full
 orphaned_process_group	. "${srcdir=.}/PTRACE_SEIZE.sh"; run_strace_match_diff -f -e trace=none -e signal='!chld'
 osf_utimes	-a21
 pause	-a8 -esignal=none
@@ -370,10 +463,19 @@ perf_event_open_unabbrev	-a1 -v -e trace
 personality-Xabbrev	+personality.test -Xabbrev
 personality-Xraw	+personality.test -a15 -Xraw
 personality-Xverbose	+personality.test -Xverbose
+pidfd_getfd	-a18 -Xverbose -e signal=none </dev/full
+pidfd_getfd-y	--trace=pidfd_getfd -a18 -e signal=none -y </dev/full
+pidfd_getfd-yy	--trace=pidfd_getfd -a18 -e signal=none -yy </dev/full
 pidfd_open	-a17
+pidfd_open--decode-fd-path	-a17 -e decode-fd=path -e trace=pidfd_open
+pidfd_open--decode-fd-pidfd	-a17 -e decode-fd=pidfd -e trace=pidfd_open
+pidfd_open--decode-fd-socket	-a17 -e decode-fd=socket -e trace=pidfd_open
 pidfd_open-P	-a17 -P /dev/full -e trace=pidfd_open
 pidfd_open-y	-a17 -y -e trace=pidfd_open
+pidfd_open-yy	-a17 -yy -e trace=pidfd_open
+pidfd_open--pidns-translation	test_pidns -a17 -e trace=pidfd_open
 pidfd_send_signal
+pidfd_send_signal--pidns-translation test_pidns -e trace=pidfd_send_signal
 pipe2	-a15
 pkey_alloc	-a17
 pkey_free	-a13
@@ -396,8 +498,11 @@ printstrn-umoven	-s4096 -e signal=none -
 printstrn-umoven-peekdata	-e signal=none -e trace=add_key
 printstrn-umoven-undumpable	-e signal=none -e trace=add_key
 prlimit64
+prlimit64--pidns-translation     test_pidns -e trace=prlimit64
 process_vm_readv	-s5 -a37
+process_vm_readv--pidns-translation	test_pidns -s5 -a37 -e trace=process_vm_readv
 process_vm_writev	-s5 -a38
+process_vm_writev--pidns-translation	test_pidns -s5 -a38 -e trace=process_vm_writev
 pselect6
 ptrace	-a23 -e signal=none
 ptrace_syscall_info	-a35 -e signal=none -e trace=ptrace
@@ -434,10 +539,12 @@ rmdir	-a22
 rt_sigpending	-a20
 rt_sigprocmask
 rt_sigqueueinfo	-esignal=none
+rt_sigqueueinfo--pidns-translation	test_pidns -esignal=none -e trace=rt_sigqueueinfo
 rt_sigreturn	-esignal='!USR1'
 rt_sigsuspend	-a20 -esignal=none
 rt_sigtimedwait	-a38
 rt_tgsigqueueinfo	-esignal=none
+rt_tgsigqueueinfo--pidns-translation	test_pidns -esignal=none -e trace=rt_tgsigqueueinfo
 s390_guarded_storage	-a32
 s390_guarded_storage-v	-e trace=s390_guarded_storage -a32 -v
 s390_pci_mmio_read_write	-e trace=s390_pci_mmio_read,s390_pci_mmio_write -a30
@@ -448,9 +555,13 @@ sched	test_trace_expr times -e/sched
 sched_get_priority_mxx	-a33 -e trace=sched_get_priority_min,sched_get_priority_max
 sched_rr_get_interval	-a31
 sched_xetaffinity	-a28 -e trace=sched_getaffinity,sched_setaffinity
+sched_xetaffinity--pidns-translation	test_pidns -a28 -e trace=sched_getaffinity,sched_setaffinity
 sched_xetattr	-a29 -e trace=sched_getattr,sched_setattr
+sched_xetattr--pidns-translation	test_pidns -a29 -e trace=sched_getattr,sched_setattr
 sched_xetparam	-a23 -e trace=sched_getparam,sched_setparam
+sched_xetparam--pidns-translation	test_pidns -a23 -e trace=sched_getparam,sched_setparam
 sched_xetscheduler	-a22 -e trace=sched_getscheduler,sched_setscheduler
+sched_xetscheduler--pidns-translation	test_pidns -a22 -e trace=sched_getscheduler,sched_setscheduler
 sched_yield	-a14
 seccomp-filter	-e trace=seccomp
 seccomp-filter-v	-v -e trace=seccomp
@@ -497,6 +608,7 @@ sigaction	-a31
 siginfo	-e trace=none
 signal	-a25 -e signal=none -e trace='/^signal$'
 signal_receive	-a16 -e trace=kill
+signal_receive--pidns-translation	test_pidns -a16 -e trace=kill
 signalfd4
 sigpending	-a15
 sigprocmask	-a34
@@ -508,6 +620,7 @@ so_peercred	-e trace=getsockopt
 so_peercred-Xabbrev	-e trace=getsockopt -Xabbrev
 so_peercred-Xraw	-e trace=getsockopt -Xraw -a39
 so_peercred-Xverbose	-e trace=getsockopt -Xverbose
+so_peercred--pidns-translation	test_pidns -e trace=getsockopt
 sock_filter-v	-v -e trace=getsockopt,setsockopt
 sock_filter-v-Xabbrev	-v -e trace=getsockopt,setsockopt -X abbrev
 sock_filter-v-Xraw	-a 37 -v -e trace=getsockopt,setsockopt -X raw
@@ -525,10 +638,51 @@ statfs	-a17
 statfs64	-a23
 status-all	-a10 -e trace=chdir --status=detached,failed,successful,unavailable,unfinished
 status-failed	-a10 -e trace=chdir -Z
+status-failed-long	-a10 -e trace=chdir --failed-only
+status-failed-status	-a10 -e trace=chdir -e status=failed
 status-none	-e trace=all --status=none
 status-successful	-a10 -e trace=chdir -z
+status-successful-long	-a10 -e trace=chdir --successful-only
+status-successful-status	-a10 -e trace=chdir --status=successful
 status-unfinished	-a10 -e trace=all --status=unfinished
 statx	-a32 --no-abbrev --trace-path=stat.sample --trace-path=/dev/full
+strace--absolute-timestamps +strace-t.test --absolute-timestamps
+strace--absolute-timestamps-format-time +strace-t.test --absolute-timestamps=format:time
+strace--absolute-timestamps-format-time-precision-s +strace-t.test --absolute-timestamps=format:time --absolute-timestamps=precision:s
+strace--absolute-timestamps-format-time-precision-ms +strace-tt.test 3 --absolute-timestamps=format:time --absolute-timestamps=precision:ms
+strace--absolute-timestamps-format-time-precision-us +strace-tt.test 6 --absolute-timestamps=format:time --absolute-timestamps=precision:us
+strace--absolute-timestamps-format-time-precision-ns +strace-tt.test 9 --absolute-timestamps=format:time --absolute-timestamps=precision:ns
+strace--absolute-timestamps-format-unix-precision-s +strace-ttt.test 0 --absolute-timestamps=format:unix --absolute-timestamps=precision:s
+strace--absolute-timestamps-format-unix-precision-ms +strace-ttt.test 3 --absolute-timestamps=precision:ms --absolute-timestamps=format:unix
+strace--absolute-timestamps-format-unix-precision-us +strace-ttt.test 6 --absolute-timestamps=precision:us --absolute-timestamps=format:unix
+strace--absolute-timestamps-format-unix-precision-ns +strace-ttt.test 9 --absolute-timestamps=format:unix --absolute-timestamps=precision:ns
+strace--follow-forks-output-separately +strace-ff.test --follow-forks --output-separately
+strace--relative-timestamps +strace-r.test --relative-timestamps
+strace--relative-timestamps-s +strace-r.test --relative-timestamps=s
+strace--relative-timestamps-ms +strace-r.test --relative-timestamps=ms
+strace--relative-timestamps-us +strace-r.test --relative-timestamps=us
+strace--relative-timestamps-ns +strace-r.test --relative-timestamps=ns
+strace--syscall-times +strace-T.test --syscall-times
+strace--syscall-times-s +strace-T.test --syscall-times=s
+strace--syscall-times-ms +strace-T.test --syscall-times=ms
+strace--syscall-times-us +strace-T.test --syscall-times=us
+strace--syscall-times-ns +strace-T.test --syscall-times=ns
+strace--strings-in-hex	--trace=chdir --strings-in-hex --columns=18
+strace--strings-in-hex-all	--trace=chdir --strings-in-hex=all --columns=18
+strace--strings-in-hex-non-ascii	--trace=chdir --strings-in-hex=non-ascii --columns=12
+strace--timestamps +strace-t.test --timestamps
+strace--timestamps-time +strace-t.test --timestamps=time
+strace--timestamps-time-s +strace-t.test --timestamps=time,s
+strace--timestamps-time-ms +strace-tt.test 3 --timestamps=time,ms
+strace--timestamps-time-us +strace-tt.test 6 --timestamps=time,us
+strace--timestamps-time-ns +strace-tt.test 9 --timestamps=time,ns
+strace--timestamps-unix-s +strace-ttt.test 0 --timestamps=unix,s
+strace--timestamps-unix-ms +strace-ttt.test 3 --timestamps=unix,ms
+strace--timestamps-unix-us +strace-ttt.test 6 --timestamps=unix,us
+strace--timestamps-unix-ns +strace-ttt.test 9 --timestamps=unix,ns
+strace-n	-e trace=listen -n -qq -a 12
+strace-x	-e trace=chdir -x -a 12
+strace-xx	-e trace=chdir -xx -a 18
 swap	-a23 -e trace=swapon,swapoff
 sxetmask	-a11 -e trace=sgetmask,ssetmask
 symlink	-a34
@@ -539,12 +693,21 @@ sync_file_range2
 sysinfo	-a14
 syslog	-a35
 tee
+tgkill	-a15 --signal='!cont'
+tgkill--pidns-translation       test_pidns -a15 --signal='!cont' -e trace=tgkill
+threads-execve--quiet-thread-execve +threads-execve.test -s40 --quiet=personality,thread-execve
+threads-execve-q +threads-execve.test -q
+threads-execve-qq +threads-execve.test -qq
+threads-execve-qqq +threads-execve.test -qqq
 time	-a10
 timer_create
 timer_xettime	-e trace=timer_create,timer_settime,timer_gettime
 timerfd_xettime	-e trace=timerfd_create,timerfd_settime,timerfd_gettime
 times	-esignal=none
 times-fail	-a12 -e trace=times
+tkill	-a12 --signal='!cont'
+tkill--pidns-translation       test_pidns --signal='!cont' -a12 -e trace=tkill
+trace_clock	test_trace_expr 'clock_nanosleep|times' -e%clock
 trace_creds	test_trace_expr '([gs]et[^p]*([gu]id|groups)|caps|prctl|[fl]?chown|print(path-umovestr|strn-umoven)-undumpable|ptrace|quotactl|rt_sigtimedwait|rt_(tg)?sigqueueinfo).*' -e%creds
 trace_fstat	test_trace_expr '' -e%fstat -v -P stat.sample -P /dev/full
 trace_fstatfs	test_trace_expr '' -e%fstatfs
@@ -560,6 +723,7 @@ trace_stat	test_trace_expr '' -e%stat -v
 trace_stat_like	test_trace_expr '' -e%%stat -v -P stat.sample -P /dev/full
 trace_statfs	test_trace_expr '' -e%statfs
 trace_statfs_like	test_trace_expr '' -e%%statfs
+trie_test    run_prog
 truncate
 truncate64
 ugetrlimit	-a28
@@ -567,6 +731,7 @@ umask	-a11
 umoven-illptr	-a36 -e trace=nanosleep
 umovestr-illptr	-a11 -e trace=chdir
 umovestr3	-a14 -e trace=chdir
+umovestr_cached_adjacent	+umovestr_cached.test 3
 unlink	-a24
 unlinkat	-a35
 unshare	-a11
@@ -589,7 +754,10 @@ waitpid	-a28
 xattr	-a22 -e trace=getxattr,fgetxattr,lgetxattr,setxattr,fsetxattr,lsetxattr,listxattr,flistxattr,llistxattr,removexattr,fremovexattr,lremovexattr
 xattr-strings	-a22 -s 4 -e trace=fsetxattr
 xet_robust_list	-a24 -e trace=get_robust_list,set_robust_list
+xet_robust_list--pidns-translation	test_pidns -a24 -e trace=get_robust_list,set_robust_list
 xetitimer	-a29 -e trace=setitimer,getitimer
 xetpgid	-a11 -e trace=getpgid,setpgid
-xetpriority	-a29 -e trace=getpriority,setpriority
+xetpgid--pidns-translation	test_pidns -a11 -e trace=getpgid,setpgid
+xetpriority	-a27 -e trace=getpriority,setpriority
+xetpriority--pidns-translation	test_pidns -a27 -e trace=getpriority,setpriority
 xettimeofday	-a20 -e trace=gettimeofday,settimeofday
diff -pruN 5.5-3/tests-m32/getdents64.c 5.9-0ubuntu2/tests-m32/getdents64.c
--- 5.5-3/tests-m32/getdents64.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getdents64.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,6 +1,8 @@
 /*
+ * Check decoding of getdents64 syscall.
+ *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -11,115 +13,29 @@
 
 #ifdef __NR_getdents64
 
-# include <assert.h>
-# include <dirent.h>
-# include <fcntl.h>
-# include <inttypes.h>
-# include <stddef.h>
-# include <stdio.h>
-# include <sys/stat.h>
-# include <unistd.h>
-
-static const char fname[] =
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nZ";
-static const char qname[] =
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nZ";
-
-typedef struct {
-		uint64_t d_ino;
-		uint64_t d_off;
-		unsigned short d_reclen;
-		unsigned char d_type;
-		char d_name[256];
-} kernel_dirent64;
+# define kernel_dirent_type kernel_dirent64_t
+# define NR_getdents	__NR_getdents64
+# define STR_getdents	"getdents64"
 
-static char buf[8192];
+# include "xgetdents.c"
 
-static const char *
-str_d_type(const unsigned char d_type)
-{
-	switch (d_type) {
-		case DT_DIR:
-			return "DT_DIR";
-		case DT_REG:
-			return "DT_REG";
-		default:
-			return "DT_UNKNOWN";
-	}
-}
+# if VERBOSE
 static void
-print_dirent(const kernel_dirent64 *d)
-{
-	const unsigned int d_name_offset = offsetof(kernel_dirent64, d_name);
-	int d_name_len = d->d_reclen - d_name_offset;
-	assert(d_name_len > 0);
-
-	printf("{d_ino=%" PRIu64 ", d_off=%" PRId64
-	       ", d_reclen=%u, d_type=%s, d_name=",
-	       d->d_ino, d->d_off, d->d_reclen, str_d_type(d->d_type));
-
-	if (d->d_name[0] == '.')
-		printf("\"%.*s\"}", d_name_len, d->d_name);
-	else
-		printf("\"%s\"}", qname);
-}
-
-int
-main(void)
+print_dirent(const kernel_dirent_type *d)
 {
-	static const char dname[] = "getdents64.test.tmp.dir";
-
-	assert(!mkdir(dname, 0700));
-	assert(!chdir(dname));
-	(void) close(0);
-	assert(!creat(fname, 0600));
-	assert(!close(0));
-	assert(!open(".", O_RDONLY | O_DIRECTORY));
-
-	unsigned long count = (unsigned long) 0xfacefeeddeadbeefULL;
-	long rc = syscall(__NR_getdents64, (long) 0xdefacedffffffffULL, NULL,
-			  count);
-	printf("getdents64(-1, NULL, %u) = %ld %s (%m)\n",
-	       (unsigned) count, rc, errno2name());
-
-	count = (unsigned long) 0xfacefeed00000000ULL | sizeof(buf);
-	while ((rc = syscall(__NR_getdents64, 0, buf, count))) {
-		kernel_dirent64 *d;
-		long i;
-
-		if (rc < 0)
-			perror_msg_and_skip("getdents64");
-		printf("getdents64(0, [");
-		for (i = 0; i < rc; i += d->d_reclen) {
-			d = (kernel_dirent64 *) &buf[i];
-			if (i)
-				printf(", ");
-			print_dirent(d);
-		}
-		printf("], %u) = %ld\n", (unsigned) count, rc);
-	}
-	printf("getdents64(0, [], %u) = 0\n", (unsigned) count);
-	puts("+++ exited with 0 +++");
-	assert(!unlink(fname));
-	assert(!chdir(".."));
-	assert(!rmdir(dname));
-
-	return 0;
+	const unsigned int d_name_offset = offsetof(kernel_dirent_type, d_name);
+	int d_name_len = (int) d->d_reclen - d_name_offset;
+	if (d_name_len <= 0)
+		error_msg_and_fail("d_name_len = %d", d_name_len);
+
+	PRINT_FIELD_U("{", *d, d_ino);
+	PRINT_FIELD_U(", ", *d, d_off);
+	PRINT_FIELD_U(", ", *d, d_reclen);
+	printf(", d_type=%s, d_name=", str_d_type(d->d_type));
+	print_quoted_cstring(d->d_name, d_name_len);
+	printf("}");
 }
+# endif
 
 #else
 
diff -pruN 5.5-3/tests-m32/getdents64.gen.test 5.9-0ubuntu2/tests-m32/getdents64.gen.test
--- 5.5-3/tests-m32/getdents64.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getdents64.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -1,4 +1,4 @@
 #!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getdents64 -a24 -v); do not edit.
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getdents64 -a33 ); do not edit.
 . "${srcdir=.}/init.sh"
-run_strace_match_diff -a24 -v
+run_strace_match_diff -a33 
diff -pruN 5.5-3/tests-m32/getdents64-v.c 5.9-0ubuntu2/tests-m32/getdents64-v.c
--- 5.5-3/tests-m32/getdents64-v.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getdents64-v.c	2020-04-11 01:01:47.000000000 +0000
@@ -0,0 +1,3 @@
+/* Check --no-abbrev decoding of getdents64 syscall.  */
+#define VERBOSE 1
+#include "getdents64.c"
diff -pruN 5.5-3/tests-m32/getdents64-v.gen.test 5.9-0ubuntu2/tests-m32/getdents64-v.gen.test
--- 5.5-3/tests-m32/getdents64-v.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getdents64-v.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getdents64-v -a24 -v --trace=getdents64); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a24 -v --trace=getdents64
diff -pruN 5.5-3/tests-m32/getdents.c 5.9-0ubuntu2/tests-m32/getdents.c
--- 5.5-3/tests-m32/getdents.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getdents.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,6 +1,8 @@
 /*
+ * Check decoding of getdents syscall.
+ *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -11,109 +13,30 @@
 
 #ifdef __NR_getdents
 
-# include <assert.h>
-# include <dirent.h>
-# include <fcntl.h>
-# include <stddef.h>
-# include <stdio.h>
-# include <sys/stat.h>
-# include <unistd.h>
-
-static const char fname[] =
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nZ";
-static const char qname[] =
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nZ";
+# define kernel_dirent_type kernel_dirent_t
+# define NR_getdents	__NR_getdents
+# define STR_getdents	"getdents"
 
-static char buf[8192];
+# include "xgetdents.c"
 
-static const char *
-str_d_type(const unsigned char d_type)
-{
-	switch (d_type) {
-		case DT_DIR:
-			return "DT_DIR";
-		case DT_REG:
-			return "DT_REG";
-		default:
-			return "DT_UNKNOWN";
-	}
-}
+# if VERBOSE
 static void
-print_dirent(const kernel_dirent *d)
+print_dirent(const kernel_dirent_type *d)
 {
-	const unsigned int d_name_offset = offsetof(kernel_dirent, d_name);
-	int d_name_len = d->d_reclen - d_name_offset - 1;
-	assert(d_name_len > 0);
-
-	printf("{d_ino=%llu, d_off=%llu, d_reclen=%u, d_name=",
-	       (unsigned long long) d->d_ino,
-	       (unsigned long long) d->d_off, d->d_reclen);
-
-	if (d->d_name[0] == '.')
-		printf("\"%.*s\"", d_name_len, d->d_name);
-	else
-		printf("\"%s\"", qname);
-
+	const unsigned int d_name_offset = offsetof(kernel_dirent_type, d_name);
+	int d_name_len = (int) d->d_reclen - d_name_offset - 1;
+	if (d_name_len <= 0)
+		error_msg_and_fail("d_name_len = %d", d_name_len);
+
+	PRINT_FIELD_U("{", *d, d_ino);
+	PRINT_FIELD_U(", ", *d, d_off);
+	PRINT_FIELD_U(", ", *d, d_reclen);
+	printf(", d_name=");
+	print_quoted_cstring(d->d_name, d_name_len);
 	printf(", d_type=%s}",
 	       str_d_type(*((const char *) d + d->d_reclen - 1)));
 }
-
-int
-main(void)
-{
-	static const char dname[] = "getdents.test.tmp.dir";
-
-	assert(!mkdir(dname, 0700));
-	assert(!chdir(dname));
-	(void) close(0);
-	assert(!creat(fname, 0600));
-	assert(!close(0));
-	assert(!open(".", O_RDONLY | O_DIRECTORY));
-
-	unsigned long count = (unsigned long) 0xfacefeeddeadbeefULL;
-	long rc = syscall(__NR_getdents, (long) 0xdefacedffffffffULL, NULL,
-			  count);
-	printf("getdents(-1, NULL, %u) = %ld %s (%m)\n",
-	       (unsigned) count, rc, errno2name());
-
-	count = (unsigned long) 0xfacefeed00000000ULL | sizeof(buf);
-	while ((rc = syscall(__NR_getdents, 0, buf, count))) {
-		kernel_dirent *d;
-		long i;
-
-		if (rc < 0)
-			perror_msg_and_skip("getdents");
-		printf("getdents(0, [");
-		for (i = 0; i < rc; i += d->d_reclen) {
-			d = (kernel_dirent *) &buf[i];
-			if (i)
-				printf(", ");
-			print_dirent(d);
-		}
-		printf("], %u) = %ld\n", (unsigned) count, rc);
-	}
-	printf("getdents(0, [], %u) = 0\n", (unsigned) count);
-	puts("+++ exited with 0 +++");
-	assert(!unlink(fname));
-	assert(!chdir(".."));
-	assert(!rmdir(dname));
-
-	return 0;
-}
+# endif
 
 #else
 
diff -pruN 5.5-3/tests-m32/getdents.gen.test 5.9-0ubuntu2/tests-m32/getdents.gen.test
--- 5.5-3/tests-m32/getdents.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getdents.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -1,4 +1,4 @@
 #!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getdents -a22 -v); do not edit.
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getdents -a31 ); do not edit.
 . "${srcdir=.}/init.sh"
-run_strace_match_diff -a22 -v
+run_strace_match_diff -a31 
diff -pruN 5.5-3/tests-m32/getdents-v.c 5.9-0ubuntu2/tests-m32/getdents-v.c
--- 5.5-3/tests-m32/getdents-v.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getdents-v.c	2020-04-11 01:01:47.000000000 +0000
@@ -0,0 +1,3 @@
+/* Check --no-abbrev decoding of getdents syscall.  */
+#define VERBOSE 1
+#include "getdents.c"
diff -pruN 5.5-3/tests-m32/getdents-v.gen.test 5.9-0ubuntu2/tests-m32/getdents-v.gen.test
--- 5.5-3/tests-m32/getdents-v.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getdents-v.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getdents-v -a22 -v --trace=getdents); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a22 -v --trace=getdents
diff -pruN 5.5-3/tests-m32/getpgrp.c 5.9-0ubuntu2/tests-m32/getpgrp.c
--- 5.5-3/tests-m32/getpgrp.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getpgrp.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -7,6 +7,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #ifdef __NR_getpgrp
 
@@ -16,8 +17,13 @@
 int
 main(void)
 {
-	printf("getpgrp() = %ld\n", syscall(__NR_getpgrp));
+	PIDNS_TEST_INIT;
 
+	pidns_print_leader();
+	printf("getpgrp() = %d%s\n", (int) syscall(__NR_getpgrp),
+		pidns_pid2str(PT_PGID));
+
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/getpgrp--pidns-translation.c 5.9-0ubuntu2/tests-m32/getpgrp--pidns-translation.c
--- 5.5-3/tests-m32/getpgrp--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getpgrp--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "getpgrp.c"
diff -pruN 5.5-3/tests-m32/getpgrp--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/getpgrp--pidns-translation.gen.test
--- 5.5-3/tests-m32/getpgrp--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getpgrp--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getpgrp--pidns-translation test_pidns -e trace=getpgrp -a10); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -e trace=getpgrp -a10
diff -pruN 5.5-3/tests-m32/getpid.c 5.9-0ubuntu2/tests-m32/getpid.c
--- 5.5-3/tests-m32/getpid.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getpid.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -7,6 +7,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #if defined __NR_getpid && (!defined __NR_getxpid || __NR_getxpid != __NR_getpid)
 
@@ -16,7 +17,12 @@
 int
 main(void)
 {
-	printf("getpid() = %ld\n", syscall(__NR_getpid));
+	PIDNS_TEST_INIT;
+
+	pidns_print_leader();
+	printf("getpid() = %d%s\n", (int) syscall(__NR_getpid),
+		pidns_pid2str(PT_TGID));
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/getpid--pidns-translation.c 5.9-0ubuntu2/tests-m32/getpid--pidns-translation.c
--- 5.5-3/tests-m32/getpid--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getpid--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "getpid.c"
diff -pruN 5.5-3/tests-m32/getpid--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/getpid--pidns-translation.gen.test
--- 5.5-3/tests-m32/getpid--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getpid--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getpid--pidns-translation test_pidns -e trace=getpid -a9); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -e trace=getpid -a9
diff -pruN 5.5-3/tests-m32/get_process_reaper.c 5.9-0ubuntu2/tests-m32/get_process_reaper.c
--- 5.5-3/tests-m32/get_process_reaper.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/get_process_reaper.c	2020-04-03 22:58:26.000000000 +0000
@@ -0,0 +1,108 @@
+/*
+ * Print the process reaper id.
+ *
+ * Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include <stdio.h>
+#include <unistd.h>
+#include <sys/wait.h>
+
+/* PARENT - CHILD - GRANDCHILD */
+
+static int
+grandchild(int read_fd, int write_fd)
+{
+	/* wait for notification from PARENT about CHILD completion */
+	pid_t pid;
+	if (read(read_fd, &pid, sizeof(pid)) != 0)
+		perror_msg_and_fail("read");
+
+	/* write ppid to PARENT */
+	pid = getppid();
+	if (write(write_fd, &pid, sizeof(pid)) != sizeof(pid))
+		perror_msg_and_fail("write");
+
+	_exit(0);
+}
+
+static int
+child(int read_fd, int write_fd)
+{
+	pid_t pid = fork();
+	if (pid < 0)
+		perror_msg_and_fail("fork");
+
+	if (!pid)
+		return grandchild(read_fd, write_fd);
+	else
+		_exit(0);
+}
+
+static int
+parent(pid_t pid, int read_fd, int write_fd)
+{
+	/* wait for CHILD completion */
+	int status;
+	if (waitpid(pid, &status, 0) != pid)
+		perror_msg_and_fail("waitpid");
+	if (status != 0)
+		error_msg_and_fail("status %x", status);
+
+	/* notify GRANDCHILD about CHILD completion */
+	close(write_fd),
+	      write_fd = -1;
+
+	/* read ppid of GRANDCHILD */
+	if (read(read_fd, &pid, sizeof(pid)) != sizeof(pid))
+		perror_msg_and_fail("read");
+
+	printf("%d\n", pid);
+	return 0;
+}
+
+int
+main(void)
+{
+	int parent_grandchild_fds[2];
+#define parent_read_fd		parent_grandchild_fds[0]
+#define grandchild_write_fd	parent_grandchild_fds[1]
+
+	int grandchild_parent_fds[2];
+#define grandchild_read_fd	grandchild_parent_fds[0]
+#define parent_write_fd		grandchild_parent_fds[1]
+
+	if (pipe(parent_grandchild_fds) ||
+	    pipe(grandchild_parent_fds))
+		perror_msg_and_fail("pipe");
+
+	pid_t pid = fork();
+	if (pid < 0)
+		perror_msg_and_fail("fork");
+
+	if (!pid) {
+		/* CHILD */
+		close(parent_read_fd),
+		      parent_read_fd = -1;
+
+		close(parent_write_fd),
+		      parent_write_fd = -1;
+
+		return child(grandchild_read_fd,
+			     grandchild_write_fd);
+	} else {
+		/* PARENT */
+		close(grandchild_read_fd),
+		      grandchild_read_fd = -1;
+
+		close(grandchild_write_fd),
+		      grandchild_write_fd = -1;
+
+		return parent(pid, parent_read_fd,
+				   parent_write_fd);
+	}
+}
diff -pruN 5.5-3/tests-m32/getrusage.c 5.9-0ubuntu2/tests-m32/getrusage.c
--- 5.5-3/tests-m32/getrusage.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getrusage.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2016 Fei Jie <feij.fnst@cn.fujitsu.com>
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -18,30 +18,41 @@
 # include <unistd.h>
 # include <errno.h>
 
+# include "kernel_rusage.h"
 # include "xlat.h"
 # include "xlat/usagewho.h"
 
 int
-invoke_print(int who, const char *who_str, struct rusage *usage)
+invoke_print(int who, const char *who_str, kernel_rusage_t *usage)
 {
 	int rc = syscall(__NR_getrusage, who, usage);
 	int saved_errno = errno;
 	printf("getrusage(%s, {ru_utime={tv_sec=%lld, tv_usec=%llu}"
-	       ", ru_stime={tv_sec=%lld, tv_usec=%llu}, ru_maxrss=%lu"
-	       ", ru_ixrss=%lu, ru_idrss=%lu, ru_isrss=%lu, ru_minflt=%lu"
-	       ", ru_majflt=%lu, ru_nswap=%lu, ru_inblock=%lu"
-	       ", ru_oublock=%lu, ru_msgsnd=%lu, ru_msgrcv=%lu"
-	       ", ru_nsignals=%lu, ru_nvcsw=%lu, ru_nivcsw=%lu}) = %s\n",
+	       ", ru_stime={tv_sec=%lld, tv_usec=%llu}, ru_maxrss=%llu"
+	       ", ru_ixrss=%llu, ru_idrss=%llu, ru_isrss=%llu, ru_minflt=%llu"
+	       ", ru_majflt=%llu, ru_nswap=%llu, ru_inblock=%llu"
+	       ", ru_oublock=%llu, ru_msgsnd=%llu, ru_msgrcv=%llu"
+	       ", ru_nsignals=%llu, ru_nvcsw=%llu, ru_nivcsw=%llu}) = %s\n",
 	       who_str,
 	       (long long) usage->ru_utime.tv_sec,
 	       zero_extend_signed_to_ull(usage->ru_utime.tv_usec),
 	       (long long) usage->ru_stime.tv_sec,
 	       zero_extend_signed_to_ull(usage->ru_stime.tv_usec),
-	       usage->ru_maxrss, usage->ru_ixrss, usage->ru_idrss,
-	       usage->ru_isrss, usage->ru_minflt, usage->ru_majflt,
-	       usage->ru_nswap, usage->ru_inblock, usage->ru_oublock,
-	       usage->ru_msgsnd, usage->ru_msgrcv, usage->ru_nsignals,
-	       usage->ru_nvcsw, usage->ru_nivcsw, sprintrc(rc));
+	       zero_extend_signed_to_ull(usage->ru_maxrss),
+	       zero_extend_signed_to_ull(usage->ru_ixrss),
+	       zero_extend_signed_to_ull(usage->ru_idrss),
+	       zero_extend_signed_to_ull(usage->ru_isrss),
+	       zero_extend_signed_to_ull(usage->ru_minflt),
+	       zero_extend_signed_to_ull(usage->ru_majflt),
+	       zero_extend_signed_to_ull(usage->ru_nswap),
+	       zero_extend_signed_to_ull(usage->ru_inblock),
+	       zero_extend_signed_to_ull(usage->ru_oublock),
+	       zero_extend_signed_to_ull(usage->ru_msgsnd),
+	       zero_extend_signed_to_ull(usage->ru_msgrcv),
+	       zero_extend_signed_to_ull(usage->ru_nsignals),
+	       zero_extend_signed_to_ull(usage->ru_nvcsw),
+	       zero_extend_signed_to_ull(usage->ru_nivcsw),
+	       sprintrc(rc));
 	errno = saved_errno;
 	return rc;
 }
@@ -49,7 +60,7 @@ invoke_print(int who, const char *who_st
 int
 main(void)
 {
-	TAIL_ALLOC_OBJECT_CONST_PTR(struct rusage, usage);
+	TAIL_ALLOC_OBJECT_CONST_PTR(kernel_rusage_t, usage);
 	if (invoke_print(ARG_STR(RUSAGE_SELF), usage)) {
 		perror_msg_and_fail("RUSAGE_SELF");
 	}
diff -pruN 5.5-3/tests-m32/getsid.c 5.9-0ubuntu2/tests-m32/getsid.c
--- 5.5-3/tests-m32/getsid.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getsid.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,20 +1,27 @@
 /*
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include "pidns.h"
+
 #include <stdio.h>
 #include <unistd.h>
 
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	pid_t pid = getpid();
-	printf("getsid(%d) = %d\n", pid, getsid(pid));
+	pidns_print_leader();
+	printf("getsid(%d%s) = %d%s\n", pid, pidns_pid2str(PT_TGID),
+		getsid(pid), pidns_pid2str(PT_SID));
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/getsid--pidns-translation.c 5.9-0ubuntu2/tests-m32/getsid--pidns-translation.c
--- 5.5-3/tests-m32/getsid--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getsid--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "getsid.c"
diff -pruN 5.5-3/tests-m32/getsid--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/getsid--pidns-translation.gen.test
--- 5.5-3/tests-m32/getsid--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getsid--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getsid--pidns-translation test_pidns -e trace=getsid -a10); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -e trace=getsid -a10
diff -pruN 5.5-3/tests-m32/gettid.c 5.9-0ubuntu2/tests-m32/gettid.c
--- 5.5-3/tests-m32/gettid.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/gettid.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -9,11 +9,17 @@
 #include <stdio.h>
 #include <unistd.h>
 #include "scno.h"
+#include "pidns.h"
 
 int
 main(void)
 {
-	printf("gettid() = %ld\n", syscall(__NR_gettid));
+	PIDNS_TEST_INIT;
+
+	pidns_print_leader();
+	printf("gettid() = %d%s\n", (int) syscall(__NR_gettid),
+		pidns_pid2str(PT_TID));
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/gettid--pidns-translation.c 5.9-0ubuntu2/tests-m32/gettid--pidns-translation.c
--- 5.5-3/tests-m32/gettid--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/gettid--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "gettid.c"
diff -pruN 5.5-3/tests-m32/gettid--pidns-translation.test 5.9-0ubuntu2/tests-m32/gettid--pidns-translation.test
--- 5.5-3/tests-m32/gettid--pidns-translation.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/gettid--pidns-translation.test	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,18 @@
+#!/bin/sh
+#
+# Check pidns translation of gettid's return value.
+#
+# Copyright (c) 2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: LGPL-2.1-or-later
+
+. "${srcdir=.}/init.sh"
+
+run_prog > /dev/null
+run_strace -a9 --pidns-translation -f -e trace=gettid $args > "$EXP"
+parent_pid="$(tail -n 2 $LOG | head -n 1 | cut -d' ' -f1)"
+init_pid="$(tail -n 1 $LOG | cut -d' ' -f1)"
+# uniq: filter out extra gettid calls made by musl libc
+grep -E -v "^($parent_pid|$init_pid) |unfinished|resumed" "$LOG" | uniq > "$OUT"
+match_diff "$OUT" "$EXP"
diff -pruN 5.5-3/tests-m32/getuid.test 5.9-0ubuntu2/tests-m32/getuid.test
--- 5.5-3/tests-m32/getuid.test	2020-01-05 21:09:51.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getuid.test	2020-03-31 22:57:10.000000000 +0000
@@ -9,14 +9,25 @@
 
 . "${srcdir=.}/init.sh"
 
+check_prog grep
 check_prog uniq
+
 if [ "${NAME%-creds}" = "$NAME" ]; then
 	syscall="$NAME"
 else
 	NAME="${NAME%-creds}"
 	syscall='%creds'
 fi
+
 run_prog > /dev/null
 run_strace -qq -a9 -e"$syscall" $args > "$EXP"
-uniq < "$LOG" > "$OUT"
+
+case "$STRACE_ARCH:$syscall" in
+	mips:%creds)
+		grep -Fxv 'prctl(PR_GET_FP_MODE) = 0' < "$LOG" | uniq > "$OUT"
+		;;
+	*)	uniq < "$LOG" > "$OUT"
+		;;
+esac
+
 match_diff "$OUT" "$EXP"
diff -pruN 5.5-3/tests-m32/getxgid.c 5.9-0ubuntu2/tests-m32/getxgid.c
--- 5.5-3/tests-m32/getxgid.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getxgid.c	2020-04-03 22:58:26.000000000 +0000
@@ -0,0 +1,31 @@
+/*
+ * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2016-2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+
+#ifdef __NR_getxgid
+
+# include <stdio.h>
+# include <unistd.h>
+
+int
+main(void)
+{
+	long id = syscall(__NR_getxgid);
+	printf("getxgid() = %ld (egid %ld)\n", id, id);
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_getxgid")
+
+#endif
diff -pruN 5.5-3/tests-m32/getxgid.gen.test 5.9-0ubuntu2/tests-m32/getxgid.gen.test
--- 5.5-3/tests-m32/getxgid.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getxgid.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getxgid -a10 ); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a10 
diff -pruN 5.5-3/tests-m32/getxpid.c 5.9-0ubuntu2/tests-m32/getxpid.c
--- 5.5-3/tests-m32/getxpid.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getxpid.c	2020-04-03 22:58:26.000000000 +0000
@@ -0,0 +1,34 @@
+/*
+ * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2016-2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+
+#ifdef __NR_getxpid
+
+# include <stdio.h>
+# include <unistd.h>
+
+int
+main(void)
+{
+	long id = syscall(__NR_getxpid);
+	pid_t ppid = getppid();
+
+	printf("getxpid() = %ld (ppid %ld)\n", id, (long) ppid);
+	printf("getxpid() = %ld (ppid %ld)\n", id, (long) ppid);
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_getxpid")
+
+#endif
diff -pruN 5.5-3/tests-m32/getxpid.gen.test 5.9-0ubuntu2/tests-m32/getxpid.gen.test
--- 5.5-3/tests-m32/getxpid.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getxpid.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getxpid -a10 ); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a10 
diff -pruN 5.5-3/tests-m32/getxuid.c 5.9-0ubuntu2/tests-m32/getxuid.c
--- 5.5-3/tests-m32/getxuid.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getxuid.c	2020-04-03 22:58:26.000000000 +0000
@@ -0,0 +1,31 @@
+/*
+ * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2016-2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+
+#ifdef __NR_getxuid
+
+# include <stdio.h>
+# include <unistd.h>
+
+int
+main(void)
+{
+	long id = syscall(__NR_getxuid);
+	printf("getxuid() = %ld (euid %ld)\n", id, id);
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_getxuid")
+
+#endif
diff -pruN 5.5-3/tests-m32/getxuid.gen.test 5.9-0ubuntu2/tests-m32/getxuid.gen.test
--- 5.5-3/tests-m32/getxuid.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getxuid.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getxuid -a10 ); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a10 
diff -pruN 5.5-3/tests-m32/getxxid.c 5.9-0ubuntu2/tests-m32/getxxid.c
--- 5.5-3/tests-m32/getxxid.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getxxid.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,42 +0,0 @@
-/*
- * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
- * All rights reserved.
- *
- * SPDX-License-Identifier: GPL-2.0-or-later
- */
-
-#include "tests.h"
-#include "scno.h"
-
-#if defined __NR_getxpid && defined __NR_getxuid && defined __NR_getxgid
-
-# include <stdio.h>
-# include <unistd.h>
-
-int
-main(void)
-{
-	long id;
-	pid_t ppid;
-
-	id = syscall(__NR_getxpid);
-	ppid = getppid();
-	printf("getxpid() = %ld (ppid %ld)\n", id, (long) ppid);
-	printf("getxpid() = %ld (ppid %ld)\n", id, (long) ppid);
-
-	id = syscall(__NR_getxuid);
-	printf("getxuid() = %ld (euid %ld)\n", id, id);
-
-	id = syscall(__NR_getxgid);
-	printf("getxgid() = %ld (egid %ld)\n", id, id);
-
-	puts("+++ exited with 0 +++");
-	return 0;
-}
-
-#else
-
-SKIP_MAIN_UNDEFINED("__NR_getxpid && __NR_getxuid && __NR_getxgid")
-
-#endif
diff -pruN 5.5-3/tests-m32/getxxid.gen.test 5.9-0ubuntu2/tests-m32/getxxid.gen.test
--- 5.5-3/tests-m32/getxxid.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/getxxid.gen.test	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-#!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getxxid -a10 -e trace=getxpid,getxuid,getxgid); do not edit.
-. "${srcdir=.}/init.sh"
-run_strace_match_diff -a10 -e trace=getxpid,getxuid,getxgid
diff -pruN 5.5-3/tests-m32/init.sh 5.9-0ubuntu2/tests-m32/init.sh
--- 5.5-3/tests-m32/init.sh	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/init.sh	2020-08-25 14:29:30.000000000 +0000
@@ -189,7 +189,7 @@ match_diff()
 # dump both files and fail with ERROR_MESSAGE.
 match_grep()
 {
-	local output patterns error pattern cnt failed=
+	local output patterns error pattern cnt failed= rc negated
 	if [ $# -eq 0 ]; then
 		output="$LOG"
 	else
@@ -211,7 +211,15 @@ match_grep()
 
 	cnt=1
 	while read -r pattern; do
-		LC_ALL=C grep -E -x -e "$pattern" < "$output" > /dev/null || {
+		negated=0
+		[ "x${pattern#!}" = "x${pattern}" ] ||
+			negated=1
+
+		rc="$negated"
+		LC_ALL=C grep -E -x -e "${pattern#!}" < "$output" > /dev/null ||
+			rc="$((!negated))"
+
+		[ 0 = "$rc" ] || {
 			test -n "$failed" || {
 				echo 'Failed patterns of expected output:'
 				failed=1
@@ -219,7 +227,8 @@ match_grep()
 			printf '#%d: %s\n' "$cnt" "$pattern"
 		}
 		cnt=$(($cnt + 1))
-	done < "$patterns"
+	done < "$patterns" ||
+		fail_ "Error reading patterns from \"$patterns\""
 	test -z "$failed" || {
 		echo 'Actual output:'
 		cat < "$output"
@@ -231,7 +240,7 @@ match_grep()
 run_strace_match_diff()
 {
 	args="$*"
-	[ -n "$args" -a -z "${args##*-e trace=*}" ] ||
+	[ -n "$args" -a \( -z "${args##*-e trace=*}" -o -z "${args##*--trace=*}" \) ] ||
 		set -- -e trace="$NAME" "$@"
 	run_prog > /dev/null
 	run_strace "$@" $args > "$EXP"
@@ -242,7 +251,7 @@ run_strace_match_diff()
 run_strace_match_grep()
 {
 	args="$*"
-	[ -n "$args" -a -z "${args##*-e trace=*}" ] ||
+	[ -n "$args" -a \( -z "${args##*-e trace=*}" -o -z "${args##*--trace=*}" \) ] ||
 		set -- -e trace="$NAME" "$@"
 	run_prog > /dev/null
 	run_strace "$@" $args > "$EXP"
@@ -281,7 +290,7 @@ require_min_nproc()
 	local min_nproc
 	min_nproc="$1"; shift
 
-	check_prog
+	check_prog nproc
 	local nproc
 	nproc="$(nproc)"
 
@@ -339,6 +348,13 @@ test_pure_prog_set()
 
 		try_run_prog "../$t" || continue
 		run_strace $prog_args "$@" "../$t" > "$expfile"
+
+		case "$STRACE_ARCH:$MIPS_ABI:$NAME" in
+			mips:o32:*creds)
+				sed -i '/^prctl(PR_GET_FP_MODE)  *= 0$/d' "$LOG"
+				;;
+		esac
+
 		match_diff "$LOG" "$expfile"
 	} < /dev/null; done
 }
@@ -371,6 +387,36 @@ test_prog_set()
 	test_pure_prog_set "$@" < "$srcdir/$NAME.in"
 }
 
+test_pidns_run_strace()
+{
+	local parent_pid init_pid
+
+	check_prog tail
+	check_prog cut
+	check_prog grep
+
+	run_prog > /dev/null
+	run_strace --pidns-translation -f $@ $args > "$EXP"
+
+	# filter out logs made by the parent or init process of the pidns test
+	parent_pid="$(tail -n 2 $LOG | head -n 1 | cut -d' ' -f1)"
+	init_pid="$(tail -n 1 $LOG | cut -d' ' -f1)"
+	grep -E -v "^($parent_pid|$init_pid) " "$LOG" > "$OUT"
+	match_diff "$OUT" "$EXP"
+}
+
+test_pidns()
+{
+	check_prog unshare
+	unshare -Urpf true || framework_skip_ "unshare -Urpf true failed"
+
+	test_pidns_run_strace "$@"
+
+	# test PID translation when /proc is mounted from an other namespace
+	STRACE="unshare -Urpf $STRACE"
+	test_pidns_run_strace "$@"
+}
+
 check_prog cat
 check_prog rm
 
@@ -412,7 +458,7 @@ fi
 : "${STRACE_EXE:=$STRACE}"
 export STRACE_EXE
 
-: "${TIMEOUT_DURATION:=600}"
+: "${TIMEOUT_DURATION:=1500}"
 : "${SLEEP_A_BIT:=sleep 1}"
 
 [ -z "${VERBOSE-}" ] ||
diff -pruN 5.5-3/tests-m32/inject-nf.c 5.9-0ubuntu2/tests-m32/inject-nf.c
--- 5.5-3/tests-m32/inject-nf.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/inject-nf.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check decoding of return values injected into a syscall that "never fails".
  *
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -16,28 +16,26 @@
 
 #include "raw_syscall.h"
 
-#ifdef __alpha__
-/* alpha has no getpid */
-# define SC_NR __NR_getpgrp
-# define SC_NAME "getpgrp"
-# define getpid getpgrp
+#ifdef __NR_geteuid32
+# define SC_NR __NR_geteuid32
+# define SC_NAME "geteuid32"
 #else
-# define SC_NR __NR_getpid
-# define SC_NAME "getpid"
+# define SC_NR __NR_geteuid
+# define SC_NAME "geteuid"
 #endif
 
 #ifdef raw_syscall_0
 # define INVOKE_SC(err) raw_syscall_0(SC_NR, &err)
 #else
-/* No raw_syscall_0, let's use getpid() and hope for the best.  */
-# define INVOKE_SC(err) getpid()
+/* No raw_syscall_0, let's use geteuid() and hope for the best. */
+# define INVOKE_SC(err) geteuid()
 #endif
 
 /*
  * This prototype is intentionally different
  * from the prototype provided by <unistd.h>.
  */
-extern kernel_ulong_t getpid(void);
+extern kernel_ulong_t geteuid(void);
 
 int
 main(int ac, char **av)
@@ -45,7 +43,7 @@ main(int ac, char **av)
 	assert(ac == 1 || ac == 2);
 
 	kernel_ulong_t expected =
-		(ac == 1) ? getpid() : strtoull(av[1], NULL, 0);
+		(ac == 1) ? geteuid() : strtoull(av[1], NULL, 0);
 	kernel_ulong_t err = 0;
 	kernel_ulong_t rc = INVOKE_SC(err);
 
diff -pruN 5.5-3/tests-m32/inject-nf.test 5.9-0ubuntu2/tests-m32/inject-nf.test
--- 5.5-3/tests-m32/inject-nf.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/inject-nf.test	2020-08-03 08:00:00.000000000 +0000
@@ -2,21 +2,14 @@
 #
 # Check decoding of return values injected into a syscall that "never fails".
 #
-# Copyright (c) 2018 The strace developers.
+# Copyright (c) 2018-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/scno_tampering.sh"
 
-case "$STRACE_ARCH" in
-alpha)
-	SYSCALL=getpgrp
-	;;
-*)
-	SYSCALL=getpid
-	;;
-esac
+SYSCALL='/^geteuid(32)?$'
 
 run_prog
 prog="$args"
diff -pruN 5.5-3/tests-m32/ioctl_block.c 5.9-0ubuntu2/tests-m32/ioctl_block.c
--- 5.5-3/tests-m32/ioctl_block.c	2019-07-24 17:12:18.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_block.c	2020-08-25 14:29:30.000000000 +0000
@@ -2,14 +2,16 @@
  * This file is part of ioctl_block strace test.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include "pidns.h"
 #include <errno.h>
+#include <unistd.h>
 #include <inttypes.h>
 #include <stdio.h>
 #include <string.h>
@@ -41,12 +43,15 @@ static struct xlat_data block_argless[]
 #define TEST_NULL_ARG(cmd)						\
 	do {								\
 		ioctl(-1, cmd, 0);					\
+		pidns_print_leader();					\
 		printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n", #cmd);	\
 	} while (0)
 
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	TEST_NULL_ARG(BLKBSZGET);
 	TEST_NULL_ARG(BLKBSZSET);
 	TEST_NULL_ARG(BLKFRAGET);
@@ -91,18 +96,22 @@ main(void)
 #endif
 
 	ioctl(-1, BLKRASET, lmagic);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKRASET, %lu) = -1 EBADF (%m)\n", lmagic);
 
 	ioctl(-1, BLKFRASET, lmagic);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKFRASET, %lu) = -1 EBADF (%m)\n", lmagic);
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(int, val_int);
 	*val_int = magic;
 
 	ioctl(-1, BLKROSET, val_int);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKROSET, [%d]) = -1 EBADF (%m)\n", *val_int);
 
 	ioctl(-1, BLKBSZSET, val_int);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKBSZSET, [%d]) = -1 EBADF (%m)\n", *val_int);
 
 	uint64_t *pair_int64 = tail_alloc(sizeof(*pair_int64) * 2);
@@ -111,18 +120,21 @@ main(void)
 
 #ifdef BLKDISCARD
 	ioctl(-1, BLKDISCARD, pair_int64);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKDISCARD, [%" PRIu64 ", %" PRIu64 "])"
 	       " = -1 EBADF (%m)\n", pair_int64[0], pair_int64[1]);
 #endif
 
 #ifdef BLKSECDISCARD
 	ioctl(-1, BLKSECDISCARD, pair_int64);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKSECDISCARD, [%" PRIu64 ", %" PRIu64 "])"
 	       " = -1 EBADF (%m)\n", pair_int64[0], pair_int64[1]);
 #endif
 
 #ifdef BLKZEROOUT
 	ioctl(-1, BLKZEROOUT, pair_int64);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKZEROOUT, [%" PRIu64 ", %" PRIu64 "])"
 	       " = -1 EBADF (%m)\n", pair_int64[0], pair_int64[1]);
 #endif
@@ -134,6 +146,7 @@ main(void)
 	blkpg->data = (void *) (unsigned long) 0xcafef00dfffffeedULL;
 
 	ioctl(-1, BLKPG, blkpg);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKPG, {op=%s, flags=%d, datalen=%d"
 	       ", data=%#lx}) = -1 EBADF (%m)\n",
 	       "BLKPG_RESIZE_PARTITION", blkpg->flags, blkpg->datalen,
@@ -149,6 +162,7 @@ main(void)
 	blkpg->data = bp;
 
 	ioctl(-1, BLKPG, blkpg);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKPG, {op=%s, flags=%d, datalen=%d"
 	       ", data={start=%lld, length=%lld, pno=%d"
 	       ", devname=\"%.*s\"..., volname=\"%.*s\"...}})"
@@ -162,25 +176,31 @@ main(void)
 #if defined BLKTRACESETUP && defined HAVE_STRUCT_BLK_USER_TRACE_SETUP
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct blk_user_trace_setup, buts);
 	fill_memory(buts, sizeof(*buts));
+	buts->pid = getpid();
 
 	ioctl(-1, BLKTRACESETUP, buts);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKTRACESETUP, {act_mask=%hu, buf_size=%u, buf_nr=%u"
-	       ", start_lba=%" PRI__u64 ", end_lba=%" PRI__u64 ", pid=%u})"
+	       ", start_lba=%" PRI__u64 ", end_lba=%" PRI__u64 ", pid=%d%s})"
 	       " = -1 EBADF (%m)\n",
 	       buts->act_mask, buts->buf_size, buts->buf_nr,
-	       buts->start_lba, buts->end_lba, buts->pid);
+	       buts->start_lba, buts->end_lba, buts->pid,
+	       pidns_pid2str(PT_TGID));
 #endif
 
 	unsigned int i;
 	for (i = 0; i < ARRAY_SIZE(block_argless); ++i) {
 		ioctl(-1, (unsigned long) block_argless[i].val, lmagic);
+		pidns_print_leader();
 		printf("ioctl(-1, %s) = -1 EBADF (%m)\n", block_argless[i].str);
 	}
 
 	ioctl(-1, _IOC(_IOC_READ, 0x12, 0xfe, 0xff), lmagic);
+	pidns_print_leader();
 	printf("ioctl(-1, %s, %#lx) = -1 EBADF (%m)\n",
 	       "_IOC(_IOC_READ, 0x12, 0xfe, 0xff)", lmagic);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/ioctl_block--pidns-translation.c 5.9-0ubuntu2/tests-m32/ioctl_block--pidns-translation.c
--- 5.5-3/tests-m32/ioctl_block--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_block--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "ioctl_block.c"
diff -pruN 5.5-3/tests-m32/ioctl_block--pidns-translation.test 5.9-0ubuntu2/tests-m32/ioctl_block--pidns-translation.test
--- 5.5-3/tests-m32/ioctl_block--pidns-translation.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_block--pidns-translation.test	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,22 @@
+#!/bin/sh
+#
+# Check pidns translation of ioctl(BLK*) syscall decoding.
+#
+# Copyright (c) 2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: LGPL-2.1-or-later
+
+. "${srcdir=.}/init.sh"
+
+check_prog head
+check_prog tail
+check_prog cut
+check_prog grep
+
+run_prog > /dev/null
+run_strace --pidns-translation -f -a16 -e trace=ioctl $@ $args > "$EXP"
+parent_pid="$(tail -n 2 $LOG | head -n 1 | cut -d' ' -f1)"
+init_pid="$(tail -n 1 $LOG | cut -d' ' -f1)"
+grep -E -v "^($parent_pid|$init_pid) |ioctl\([0123][,<]" "$LOG" > "$OUT"
+match_diff "$OUT" "$EXP"
diff -pruN 5.5-3/tests-m32/ioctl.c 5.9-0ubuntu2/tests-m32/ioctl.c
--- 5.5-3/tests-m32/ioctl.c	2018-12-30 15:35:21.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -14,6 +14,8 @@
 #include <termios.h>
 #include <sys/ioctl.h>
 
+#include <linux/types.h>
+
 #ifdef HAVE_LINUX_MMTIMER_H
 # include <linux/mmtimer.h>
 #endif
diff -pruN 5.5-3/tests-m32/ioctl_evdev.c 5.9-0ubuntu2/tests-m32/ioctl_evdev.c
--- 5.5-3/tests-m32/ioctl_evdev.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_evdev.c	2020-08-03 08:00:00.000000000 +0000
@@ -2,7 +2,7 @@
  * This file is part of ioctl_evdev strace test.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -50,7 +50,7 @@ static void
 print_ffe_common(const struct ff_effect *const ffe, const char *const type_str)
 {
 	printf("ioctl(-1, %s", XLAT_STR(EVIOCSFF));
-	printf(", {type=%s, id=%" PRIu16
+	printf(", {type=%s, id=%" PRId16
 	       ", direction=%" PRIu16 ", ",
 	       sprintxlat(type_str, ffe->type, NULL),
 	       ffe->id, ffe->direction);
@@ -223,7 +223,7 @@ main(void)
 	for (i = 0; i < ARRAY_SIZE(ike->scancode); ++i) {
 		if (i > 0)
 			printf(", ");
-		printf("%" PRIx8, ike->scancode[i]);
+		printf("%#" PRIx8, ike->scancode[i]);
 	}
 	printf("]");
 #  else
diff -pruN 5.5-3/tests-m32/ioctl_evdev-success.c 5.9-0ubuntu2/tests-m32/ioctl_evdev-success.c
--- 5.5-3/tests-m32/ioctl_evdev-success.c	2019-10-22 17:44:08.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_evdev-success.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -99,10 +99,10 @@ print_input_id(long rc, const void *ptr,
 		printf("%p", id);
 		return;
 	}
-	printf("{ID_BUS=%" PRIu16
-	       ", ID_VENDOR=%" PRIu16
-	       ", ID_PRODUCT=%" PRIu16
-	       ", ID_VERSION=%" PRIu16 "}",
+	printf("{bustype=%" PRIu16
+	       ", vendor=%" PRIu16
+	       ", product=%" PRIu16
+	       ", version=%" PRIu16 "}",
 	       id->bustype, id->vendor, id->product, id->version);
 }
 
diff -pruN 5.5-3/tests-m32/ioctl_hdio.c 5.9-0ubuntu2/tests-m32/ioctl_hdio.c
--- 5.5-3/tests-m32/ioctl_hdio.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,227 @@
+/*
+ * Check HDIO_* ioctl decoding.
+ *
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+
+#include <errno.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <linux/hdreg.h>
+#include <sys/ioctl.h>
+
+static const char *errstr;
+
+static long
+do_ioctl(kernel_ulong_t cmd, kernel_ulong_t arg)
+{
+	long rc = ioctl(-1, cmd, arg);
+
+	errstr = sprintrc(rc);
+
+#ifdef INJECT_RETVAL
+	if (rc != INJECT_RETVAL)
+		error_msg_and_fail("Got a return value of %ld != %ld",
+				   rc, (long) INJECT_RETVAL);
+
+	static char inj_errstr[4096];
+
+	snprintf(inj_errstr, sizeof(inj_errstr), "%s (INJECTED)", errstr);
+	errstr = inj_errstr;
+#endif
+
+	return rc;
+}
+
+static inline long
+do_ioctl_ptr(kernel_ulong_t cmd, const void *arg)
+{
+	return do_ioctl(cmd, (uintptr_t) arg);
+}
+
+int
+main(int argc, char *argv[])
+{
+#ifdef INJECT_RETVAL
+	unsigned long num_skip;
+	bool locked = false;
+
+	if (argc < 2)
+		error_msg_and_fail("Usage: %s NUM_SKIP", argv[0]);
+
+	num_skip = strtoul(argv[1], NULL, 0);
+
+	for (size_t i = 0; i < num_skip; i++) {
+		long ret = ioctl(-1, HDIO_GET_UNMASKINTR, 0);
+
+		printf("ioctl(-1, %s, 0) = %s%s\n",
+		       XLAT_STR(HDIO_GET_UNMASKINTR), sprintrc(ret),
+		       ret == INJECT_RETVAL ? " (INJECTED)" : "");
+
+		if (ret != INJECT_RETVAL)
+			continue;
+
+		locked = true;
+		break;
+	}
+
+	if (!locked)
+		error_msg_and_fail("Hasn't locked on ioctl(-1"
+				   ", HDIO_GET_UNMASKINTR, 0) returning %d",
+				   INJECT_RETVAL);
+#endif
+
+	long rc;
+
+	/* Decoding is not supported */
+	static const struct {
+		uint32_t cmd;
+		const char *str;
+	} unsupp_cmds[] = {
+		{ ARG_STR(HDIO_GET_UNMASKINTR) },
+		{ ARG_STR(HDIO_GET_MULTCOUNT) },
+		{ ARG_STR(HDIO_GET_QDMA) },
+		{ ARG_STR(HDIO_SET_XFER) },
+		{ ARG_STR(HDIO_OBSOLETE_IDENTITY) },
+		{ ARG_STR(HDIO_GET_KEEPSETTINGS) },
+		{ ARG_STR(HDIO_GET_32BIT) },
+		{ ARG_STR(HDIO_GET_NOWERR) },
+		{ ARG_STR(HDIO_GET_DMA) },
+		{ ARG_STR(HDIO_GET_NICE) },
+		{ ARG_STR(HDIO_GET_IDENTITY) },
+		{ ARG_STR(HDIO_GET_WCACHE) },
+		{ ARG_STR(HDIO_GET_ACOUSTIC) },
+		{ ARG_STR(HDIO_GET_ADDRESS) },
+		{ ARG_STR(HDIO_GET_BUSSTATE) },
+		{ ARG_STR(HDIO_TRISTATE_HWIF) },
+		{ ARG_STR(HDIO_DRIVE_RESET) },
+		{ ARG_STR(HDIO_DRIVE_TASKFILE) },
+		{ ARG_STR(HDIO_DRIVE_TASK) },
+		{ ARG_STR(HDIO_SET_MULTCOUNT) },
+		{ ARG_STR(HDIO_SET_UNMASKINTR) },
+		{ ARG_STR(HDIO_SET_KEEPSETTINGS) },
+		{ ARG_STR(HDIO_SET_32BIT) },
+		{ ARG_STR(HDIO_SET_NOWERR) },
+		{ ARG_STR(HDIO_SET_DMA) },
+		{ ARG_STR(HDIO_SET_PIO_MODE) },
+		{ ARG_STR(HDIO_SCAN_HWIF) },
+		{ ARG_STR(HDIO_UNREGISTER_HWIF) },
+		{ ARG_STR(HDIO_SET_NICE) },
+		{ ARG_STR(HDIO_SET_WCACHE) },
+		{ ARG_STR(HDIO_SET_ACOUSTIC) },
+		{ ARG_STR(HDIO_SET_BUSSTATE) },
+		{ ARG_STR(HDIO_SET_QDMA) },
+		{ ARG_STR(HDIO_SET_ADDRESS) },
+	};
+
+	for (size_t i = 0; i < ARRAY_SIZE(unsupp_cmds); i++) {
+		do_ioctl(unsupp_cmds[i].cmd, 0);
+		printf("ioctl(-1, " XLAT_FMT ", 0) = %s\n",
+		       XLAT_SEL(unsupp_cmds[i].cmd, unsupp_cmds[i].str),
+		       errstr);
+
+		do_ioctl(unsupp_cmds[i].cmd,
+			 (unsigned long) 0xbadc0deddeadc0deULL);
+		printf("ioctl(-1, " XLAT_FMT ", %#lx) = %s\n",
+		       XLAT_SEL(unsupp_cmds[i].cmd, unsupp_cmds[i].str),
+		       (unsigned long) 0xbadc0deddeadc0deULL, errstr);
+	}
+
+
+	/* HDIO_GETGEO */
+	do_ioctl(HDIO_GETGEO, 0);
+	printf("ioctl(-1, %s, NULL) = %s\n",
+	       XLAT_STR(HDIO_GETGEO), errstr);
+
+	TAIL_ALLOC_OBJECT_CONST_PTR(struct hd_geometry, p_hd_geom);
+
+	p_hd_geom->heads = 0xca;
+	p_hd_geom->sectors = 0xfe;
+	p_hd_geom->cylinders = 0xbabe;
+	p_hd_geom->start = (unsigned long) 0xbadc0deddeadfaceULL;
+
+	do_ioctl_ptr(HDIO_GETGEO, (char *) p_hd_geom + 1);
+	printf("ioctl(-1, %s, %p) = %s\n",
+	       XLAT_STR(HDIO_GETGEO), (char *) p_hd_geom + 1, errstr);
+
+	rc = do_ioctl_ptr(HDIO_GETGEO, p_hd_geom);
+	printf("ioctl(-1, %s, ", XLAT_STR(HDIO_GETGEO));
+	if (rc >= 0) {
+		printf("{heads=202, sectors=254, cylinders=47806, start=%lu}",
+		       (unsigned long) 0xbadc0deddeadfaceULL);
+	} else {
+		printf("%p", p_hd_geom);
+	}
+	printf(") = %s\n", errstr);
+
+	/* HDIO_DRIVE_CMD */
+	do_ioctl(HDIO_DRIVE_CMD, 0);
+	printf("ioctl(-1, %s, NULL) = %s\n",
+	       XLAT_STR(HDIO_DRIVE_CMD), errstr);
+
+	TAIL_ALLOC_OBJECT_CONST_PTR(struct hd_drive_cmd_hdr, p_hd_drive_cmd);
+	struct hd_drive_cmd_hdr *p_hd_drive_cmd2 =
+		tail_alloc(sizeof(*p_hd_drive_cmd2) + 16);
+	struct hd_drive_cmd_hdr *p_hd_drive_cmd3 =
+		tail_alloc(sizeof(*p_hd_drive_cmd3) + DEFAULT_STRLEN + 1);
+
+	fill_memory(p_hd_drive_cmd2, sizeof(*p_hd_drive_cmd2) + 16);
+	fill_memory(p_hd_drive_cmd3,
+		    sizeof(*p_hd_drive_cmd3) + DEFAULT_STRLEN + 1);
+
+	p_hd_drive_cmd->command = 0xca;
+	p_hd_drive_cmd->sector_number = 0xff;
+	p_hd_drive_cmd->feature = 0xee;
+	p_hd_drive_cmd->sector_count = 0;
+
+	do_ioctl_ptr(HDIO_DRIVE_CMD, (char *) p_hd_drive_cmd + 1);
+	printf("ioctl(-1, %s, %p) = %s\n",
+	       XLAT_STR(HDIO_DRIVE_CMD), (char *) p_hd_drive_cmd + 1, errstr);
+
+	for (size_t i = 0; i < 2; i++) {
+		p_hd_drive_cmd->sector_count = i;
+
+		rc = do_ioctl_ptr(HDIO_DRIVE_CMD, p_hd_drive_cmd);
+		printf("ioctl(-1, %s, {command=" XLAT_FMT ", sector_number=255"
+		       ", feature=238, sector_count=%zu",
+		       XLAT_STR(HDIO_DRIVE_CMD),
+		       XLAT_SEL(0xca, "ATA_CMD_WRITE"), i);
+		if (rc >= 0) {
+			printf("} => {/* status */ 0xca, /* error */ 255"
+			       ", /* nsector */ 238");
+			if (i)
+				printf(", %p", p_hd_drive_cmd + 1);
+		}
+		printf("}) = %s\n", errstr);
+	}
+
+	rc = do_ioctl_ptr(HDIO_DRIVE_CMD, p_hd_drive_cmd2);
+	printf("ioctl(-1, %s, {command=0x80" NRAW(" /* ATA_CMD_??? */")
+	       ", sector_number=129, feature=130, sector_count=131",
+	       XLAT_STR(HDIO_DRIVE_CMD));
+	if (rc >= 0) {
+		printf("} => {/* status */ 0x80, /* error */ 129"
+		       ", /* nsector */ 130, %p", p_hd_drive_cmd2 + 1);
+	}
+	printf("}) = %s\n", errstr);
+
+	rc = do_ioctl_ptr(HDIO_DRIVE_CMD, p_hd_drive_cmd3);
+	printf("ioctl(-1, %s, {command=0x80" NRAW(" /* ATA_CMD_??? */")
+	       ", sector_number=129, feature=130, sector_count=131",
+	       XLAT_STR(HDIO_DRIVE_CMD));
+	if (rc >= 0) {
+		printf("} => {/* status */ 0x80, /* error */ 129"
+		       ", /* nsector */ 130, ");
+		print_quoted_hex(p_hd_drive_cmd3 + 1, DEFAULT_STRLEN);
+		printf("...");
+	}
+	printf("}) = %s\n", errstr);
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
diff -pruN 5.5-3/tests-m32/ioctl_hdio.gen.test 5.9-0ubuntu2/tests-m32/ioctl_hdio.gen.test
--- 5.5-3/tests-m32/ioctl_hdio.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio +ioctl.test -a27); do not edit.
+set -- -a27
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-success.c 5.9-0ubuntu2/tests-m32/ioctl_hdio-success.c
--- 5.5-3/tests-m32/ioctl_hdio-success.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-success.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define INJECT_RETVAL 42
+#include "ioctl_hdio.c"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-success.gen.test 5.9-0ubuntu2/tests-m32/ioctl_hdio-success.gen.test
--- 5.5-3/tests-m32/ioctl_hdio-success.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-success.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-success +ioctl-success.sh -a27); do not edit.
+set -- -a27
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-success-v.c 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-v.c
--- 5.5-3/tests-m32/ioctl_hdio-success-v.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-v.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define VERBOSE 1
+#include "ioctl_hdio-success.c"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-success-v.gen.test 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-v.gen.test
--- 5.5-3/tests-m32/ioctl_hdio-success-v.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-v.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-success-v +ioctl-success.sh -a27 -v); do not edit.
+set -- -a27 -v
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-success-v-Xabbrev.c 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-v-Xabbrev.c
--- 5.5-3/tests-m32/ioctl_hdio-success-v-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-v-Xabbrev.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "ioctl_hdio-success-v.c"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-success-v-Xabbrev.gen.test 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-v-Xabbrev.gen.test
--- 5.5-3/tests-m32/ioctl_hdio-success-v-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-v-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-success-v-Xabbrev +ioctl-success.sh -a27 -v -Xabbrev); do not edit.
+set -- -a27 -v -Xabbrev
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-success-v-Xraw.c 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-v-Xraw.c
--- 5.5-3/tests-m32/ioctl_hdio-success-v-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-v-Xraw.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "ioctl_hdio-success-v.c"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-success-v-Xraw.gen.test 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-v-Xraw.gen.test
--- 5.5-3/tests-m32/ioctl_hdio-success-v-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-v-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-success-v-Xraw +ioctl-success.sh -a20 -v -Xraw); do not edit.
+set -- -a20 -v -Xraw
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-success-v-Xverbose.c 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-v-Xverbose.c
--- 5.5-3/tests-m32/ioctl_hdio-success-v-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-v-Xverbose.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "ioctl_hdio-success-v.c"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-success-v-Xverbose.gen.test 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-v-Xverbose.gen.test
--- 5.5-3/tests-m32/ioctl_hdio-success-v-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-v-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-success-v-Xverbose +ioctl-success.sh -a39 -v -Xverbose); do not edit.
+set -- -a39 -v -Xverbose
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-success-Xabbrev.c 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-Xabbrev.c
--- 5.5-3/tests-m32/ioctl_hdio-success-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-Xabbrev.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "ioctl_hdio-success.c"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-success-Xabbrev.gen.test 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-Xabbrev.gen.test
--- 5.5-3/tests-m32/ioctl_hdio-success-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-success-Xabbrev +ioctl-success.sh -a27 -Xabbrev); do not edit.
+set -- -a27 -Xabbrev
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-success-Xraw.c 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-Xraw.c
--- 5.5-3/tests-m32/ioctl_hdio-success-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-Xraw.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "ioctl_hdio-success.c"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-success-Xraw.gen.test 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-Xraw.gen.test
--- 5.5-3/tests-m32/ioctl_hdio-success-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-success-Xraw +ioctl-success.sh -a20 -Xraw); do not edit.
+set -- -a20 -Xraw
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-success-Xverbose.c 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-Xverbose.c
--- 5.5-3/tests-m32/ioctl_hdio-success-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-Xverbose.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "ioctl_hdio-success.c"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-success-Xverbose.gen.test 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-Xverbose.gen.test
--- 5.5-3/tests-m32/ioctl_hdio-success-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-success-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-success-Xverbose +ioctl-success.sh -a39 -Xverbose); do not edit.
+set -- -a39 -Xverbose
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-v.c 5.9-0ubuntu2/tests-m32/ioctl_hdio-v.c
--- 5.5-3/tests-m32/ioctl_hdio-v.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-v.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define VERBOSE 1
+#include "ioctl_hdio.c"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-v.gen.test 5.9-0ubuntu2/tests-m32/ioctl_hdio-v.gen.test
--- 5.5-3/tests-m32/ioctl_hdio-v.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-v.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-v +ioctl.test -a27 -v); do not edit.
+set -- -a27 -v
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-v-Xabbrev.c 5.9-0ubuntu2/tests-m32/ioctl_hdio-v-Xabbrev.c
--- 5.5-3/tests-m32/ioctl_hdio-v-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-v-Xabbrev.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "ioctl_hdio-v.c"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-v-Xabbrev.gen.test 5.9-0ubuntu2/tests-m32/ioctl_hdio-v-Xabbrev.gen.test
--- 5.5-3/tests-m32/ioctl_hdio-v-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-v-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-v-Xabbrev +ioctl.test -a27 -v -Xabbrev); do not edit.
+set -- -a27 -v -Xabbrev
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-v-Xraw.c 5.9-0ubuntu2/tests-m32/ioctl_hdio-v-Xraw.c
--- 5.5-3/tests-m32/ioctl_hdio-v-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-v-Xraw.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "ioctl_hdio-v.c"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-v-Xraw.gen.test 5.9-0ubuntu2/tests-m32/ioctl_hdio-v-Xraw.gen.test
--- 5.5-3/tests-m32/ioctl_hdio-v-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-v-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-v-Xraw +ioctl.test -a20 -v -Xraw); do not edit.
+set -- -a20 -v -Xraw
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-v-Xverbose.c 5.9-0ubuntu2/tests-m32/ioctl_hdio-v-Xverbose.c
--- 5.5-3/tests-m32/ioctl_hdio-v-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-v-Xverbose.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "ioctl_hdio-v.c"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-v-Xverbose.gen.test 5.9-0ubuntu2/tests-m32/ioctl_hdio-v-Xverbose.gen.test
--- 5.5-3/tests-m32/ioctl_hdio-v-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-v-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-v-Xverbose +ioctl.test -a39 -v -Xverbose); do not edit.
+set -- -a39 -v -Xverbose
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-Xabbrev.c 5.9-0ubuntu2/tests-m32/ioctl_hdio-Xabbrev.c
--- 5.5-3/tests-m32/ioctl_hdio-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-Xabbrev.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "ioctl_hdio.c"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-Xabbrev.gen.test 5.9-0ubuntu2/tests-m32/ioctl_hdio-Xabbrev.gen.test
--- 5.5-3/tests-m32/ioctl_hdio-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-Xabbrev +ioctl.test -a27 -Xabbrev); do not edit.
+set -- -a27 -Xabbrev
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-Xraw.c 5.9-0ubuntu2/tests-m32/ioctl_hdio-Xraw.c
--- 5.5-3/tests-m32/ioctl_hdio-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-Xraw.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "ioctl_hdio.c"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-Xraw.gen.test 5.9-0ubuntu2/tests-m32/ioctl_hdio-Xraw.gen.test
--- 5.5-3/tests-m32/ioctl_hdio-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-Xraw +ioctl.test -a20 -Xraw); do not edit.
+set -- -a20 -Xraw
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-Xverbose.c 5.9-0ubuntu2/tests-m32/ioctl_hdio-Xverbose.c
--- 5.5-3/tests-m32/ioctl_hdio-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-Xverbose.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "ioctl_hdio.c"
diff -pruN 5.5-3/tests-m32/ioctl_hdio-Xverbose.gen.test 5.9-0ubuntu2/tests-m32/ioctl_hdio-Xverbose.gen.test
--- 5.5-3/tests-m32/ioctl_hdio-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_hdio-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-Xverbose +ioctl.test -a39 -Xverbose); do not edit.
+set -- -a39 -Xverbose
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-m32/ioctl_loop.c 5.9-0ubuntu2/tests-m32/ioctl_loop.c
--- 5.5-3/tests-m32/ioctl_loop.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_loop.c	2020-08-03 08:00:00.000000000 +0000
@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2016 JingPiao Chen <chenjingpiao@gmail.com>
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -22,6 +22,12 @@
 #include <linux/loop.h>
 #include "print_fields.h"
 
+#ifdef HAVE_STRUCT_LOOP_CONFIG
+typedef struct loop_config struct_loop_config;
+#else
+# include "types/loop.h"
+#endif
+
 #define XLAT_MACROS_ONLY
 #include "xlat/loop_cmds.h"
 #undef XLAT_MACROS_ONLY
@@ -155,6 +161,27 @@ print_loop_info64(struct loop_info64 * c
 #endif /* !ABBREV */
 }
 
+static void
+print_loop_config(struct_loop_config *config, bool print_reserved)
+{
+#if ABBREV
+	printf("%p", config);
+#else
+	printf("{fd=%d, block_size=%u, info=",
+	       (int) config->fd, config->block_size);
+	print_loop_info64(&config->info, false, "LO_CRYPT_NONE", NULL,
+			  "LO_FLAGS_READ_ONLY");
+	if (print_reserved) {
+		printf(", __reserved=");
+		for (size_t i = 0; i < ARRAY_SIZE(config->__reserved); ++i)
+			printf("%s%#llx", (i ? ", " : "["),
+			       (unsigned long long) config->__reserved[i]);
+		printf("]");
+	}
+	printf("}");
+#endif /* !ABBREV */
+}
+
 int
 main(void)
 {
@@ -167,6 +194,7 @@ main(void)
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct loop_info, info);
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct loop_info64, info64);
+	TAIL_ALLOC_OBJECT_CONST_PTR(struct_loop_config, config);
 
 	/* Unknown loop commands */
 	sys_ioctl(-1, unknown_loop_cmd, magic);
@@ -178,12 +206,12 @@ main(void)
 	       _IOC_SIZE((unsigned int) unknown_loop_cmd),
 	       (unsigned long) magic);
 
-	sys_ioctl(-1, LOOP_SET_BLOCK_SIZE + 1, magic);
+	sys_ioctl(-1, LOOP_CONFIGURE + 1, magic);
 	printf("ioctl(-1, _IOC(%s, 0x4c, %#x, %#x), %#lx) = "
 	       "-1 EBADF (%m)\n",
 	       _IOC_NONE ? "0" : "_IOC_NONE",
-	       _IOC_NR(LOOP_SET_BLOCK_SIZE + 1),
-	       _IOC_SIZE(LOOP_SET_BLOCK_SIZE + 1),
+	       _IOC_NR(LOOP_CONFIGURE + 1),
+	       _IOC_SIZE(LOOP_CONFIGURE + 1),
 	       (unsigned long) magic);
 
 	sys_ioctl(-1, LOOP_CTL_GET_FREE + 1, magic);
@@ -281,6 +309,32 @@ main(void)
 	ioctl(-1, LOOP_GET_STATUS64, (unsigned long) info64 | kernel_mask);
 	printf("ioctl(-1, LOOP_GET_STATUS64, %p) = -1 EBADF (%m)\n", info64);
 
+	/* LOOP_CONFIGURE */
+	ioctl(-1, LOOP_CONFIGURE, NULL);
+	printf("ioctl(-1, LOOP_CONFIGURE, NULL) = -1 EBADF (%m)\n");
+
+	fill_memory(config, sizeof(*config));
+	config->info.lo_flags = LO_FLAGS_READ_ONLY;
+	config->info.lo_encrypt_type = LO_CRYPT_NONE;
+	memset(config->info.lo_file_name, 'C', sizeof(config->info.lo_file_name));
+	memset(config->info.lo_crypt_name, 'D', sizeof(config->info.lo_crypt_name));
+	memset(config->info.lo_encrypt_key, 'E', sizeof(config->info.lo_encrypt_key));
+
+	ioctl(-1, LOOP_CONFIGURE, (void *) config + ALIGNOF(config));
+	printf("ioctl(-1, LOOP_CONFIGURE, %p) = -1 EBADF (%m)\n",
+	       (void *) config + ALIGNOF(config));
+
+	printf("ioctl(-1, LOOP_CONFIGURE, ");
+	print_loop_config(config, true);
+	ioctl(-1, LOOP_CONFIGURE, config);
+	printf(") = -1 EBADF (%m)\n");
+
+	memset(config->__reserved, 0, sizeof(config->__reserved));
+	printf("ioctl(-1, LOOP_CONFIGURE, ");
+	print_loop_config(config, false);
+	ioctl(-1, LOOP_CONFIGURE, config);
+	printf(") = -1 EBADF (%m)\n");
+
 	/* LOOP_CHANGE_FD */
 	sys_ioctl(-1, LOOP_CHANGE_FD, magic);
 	printf("ioctl(-1, LOOP_CHANGE_FD, %d) = -1 EBADF (%m)\n",
diff -pruN 5.5-3/tests-m32/ioctl_nsfs.c 5.9-0ubuntu2/tests-m32/ioctl_nsfs.c
--- 5.5-3/tests-m32/ioctl_nsfs.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_nsfs.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of NS_* commands of ioctl syscall.
  *
  * Copyright (c) 2017 Nikolay Marchuk <marchuk.nikolay.a@gmail.com>
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
diff -pruN 5.5-3/tests-m32/ioctl_perf-success.c 5.9-0ubuntu2/tests-m32/ioctl_perf-success.c
--- 5.5-3/tests-m32/ioctl_perf-success.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_perf-success.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check decoding of successful PERF_EVENT_IOC_{ID,QUERY_BPF} ioctls.
  *
- * Copyright (c) 2018 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -9,29 +9,31 @@
 
 #include "tests.h"
 
-#ifdef HAVE_LINUX_PERF_EVENT_H
 
-# include <assert.h>
-# include <inttypes.h>
-# include <stdio.h>
-# include <stdlib.h>
-# include <string.h>
-# include <sys/ioctl.h>
+#include <assert.h>
+#include <inttypes.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <sys/ioctl.h>
+
+#ifdef HAVE_LINUX_PERF_EVENT_H
 # include <linux/perf_event.h>
+#endif
 
-# ifndef PERF_EVENT_IOC_ID
-#  define PERF_EVENT_IOC_ID			_IOR('$', 7, void *)
-# endif
+#ifndef PERF_EVENT_IOC_ID
+# define PERF_EVENT_IOC_ID			_IOR('$', 7, void *)
+#endif
 
-# ifndef PERF_EVENT_IOC_QUERY_BPF
-#  define PERF_EVENT_IOC_QUERY_BPF		_IOWR('$', 10, void *)
+#ifndef PERF_EVENT_IOC_QUERY_BPF
+# define PERF_EVENT_IOC_QUERY_BPF		_IOWR('$', 10, void *)
 
 struct perf_event_query_bpf {
         uint32_t ids_len;
         uint32_t prog_cnt;
         uint32_t ids[0];
 };
-# endif
+#endif
 
 int
 main(int argc, char **argv)
@@ -137,9 +139,3 @@ main(int argc, char **argv)
 	puts("+++ exited with 0 +++");
 	return 0;
 }
-
-#else
-
-SKIP_MAIN_UNDEFINED("HAVE_LINUX_PERF_EVENT_H");
-
-#endif
diff -pruN 5.5-3/tests-m32/ioctl_perf-success.gen.test 5.9-0ubuntu2/tests-m32/ioctl_perf-success.gen.test
--- 5.5-3/tests-m32/ioctl_perf-success.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_perf-success.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_perf-success +ioctl-success.sh -a35); do not edit.
+set -- -a35
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-m32/ioctl_perf-success.test 5.9-0ubuntu2/tests-m32/ioctl_perf-success.test
--- 5.5-3/tests-m32/ioctl_perf-success.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_perf-success.test	1970-01-01 00:00:00.000000000 +0000
@@ -1,20 +0,0 @@
-#!/bin/sh -efu
-#
-# Check decoding of successful PERF_EVENT_IOC_{ID,QUERY_BPF} ioctls.
-#
-# Copyright (c) 2018 The strace developers.
-# All rights reserved.
-#
-# SPDX-License-Identifier: GPL-2.0-or-later
-
-. "${srcdir=.}/scno_tampering.sh"
-
-: ${IOCTL_INJECT_START=256}
-: ${IOCTL_INJECT_RETVAL=42}
-
-run_prog
-run_strace -a35 -e trace=ioctl \
-	-e inject=ioctl:retval="${IOCTL_INJECT_RETVAL}":when="${IOCTL_INJECT_START}+" \
-	../ioctl_perf-success "${IOCTL_INJECT_START}" "${IOCTL_INJECT_RETVAL}" > "$EXP"
-grep -v '^ioctl([012][,<]' < "$LOG" > "$OUT"
-match_diff "$OUT" "$EXP"
diff -pruN 5.5-3/tests-m32/ioctl-success.sh 5.9-0ubuntu2/tests-m32/ioctl-success.sh
--- 5.5-3/tests-m32/ioctl-success.sh	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl-success.sh	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,21 @@
+#!/bin/sh -efu
+#
+# Check decoding of ioctls using syscall injection.
+#
+# Expects a binary that accepts IOCTL_INJECT_START as the first argument.
+#
+# Copyright (c) 2018-2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: GPL-2.0-or-later
+
+. "${srcdir=.}/scno_tampering.sh"
+
+: ${IOCTL_INJECT_START=256}
+: ${IOCTL_INJECT_RETVAL=42}
+
+run_strace -a50 "$@" -e trace=ioctl \
+	-e inject=ioctl:retval="${IOCTL_INJECT_RETVAL}":when="${IOCTL_INJECT_START}+" \
+	"../$NAME" "${IOCTL_INJECT_START}" "${IOCTL_INJECT_RETVAL}" > "$EXP"
+grep -v '^ioctl([012][,<]' < "$LOG" > "$OUT"
+match_diff "$OUT" "$EXP"
diff -pruN 5.5-3/tests-m32/ioctl_tee.c 5.9-0ubuntu2/tests-m32/ioctl_tee.c
--- 5.5-3/tests-m32/ioctl_tee.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_tee.c	2020-09-23 16:28:11.000000000 +0000
@@ -0,0 +1,437 @@
+/*
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+
+#ifdef HAVE_LINUX_TEE_H
+
+# include <fcntl.h>
+# include <stdio.h>
+# include <string.h>
+
+# include <linux/tee.h>
+
+# include <sys/ioctl.h>
+# include <sys/stat.h>
+# include <sys/types.h>
+
+# include "xlat.h"
+
+# define NUM_PARAMS 8
+# define RVAL_EBADF " = -1 EBADF (%m)\n"
+
+# define UUID_SIZE 16
+
+# ifndef TEE_IOCTL_PARAM_ATTR_META
+#  define TEE_IOCTL_PARAM_ATTR_META 0x100
+# endif
+
+# ifndef HAVE_STRUCT_TEE_IOCTL_SHM_REGISTER_FD_DATA
+struct tee_ioctl_shm_register_fd_data {
+	__s64 fd;
+	__u64 size;
+	__u32 flags;
+	__u8  _pad1[4];
+	__u32 id;
+	__u8  _pad2[4];
+} ATTRIBUTE_ALIGNED(8);
+# endif
+
+# ifndef HAVE_STRUCT_TEE_IOCTL_SHM_REGISTER_DATA
+struct tee_ioctl_shm_register_data {
+	__u64 addr;
+	__u64 length;
+	__u32 flags;
+	__s32 id;
+};
+# endif
+
+# ifndef TEE_IOC_SHM_REGISTER_FD
+#  define TEE_IOC_SHM_REGISTER_FD _IOWR(TEE_IOC_MAGIC, TEE_IOC_BASE + 8, \
+					struct tee_ioctl_shm_register_fd_data)
+# endif
+
+# ifndef TEE_IOC_SHM_REGISTER
+#  define TEE_IOC_SHM_REGISTER    _IOWR(TEE_IOC_MAGIC, TEE_IOC_BASE + 9, \
+					struct tee_ioctl_shm_register_data)
+# endif
+
+
+typedef struct {
+	uint8_t b[UUID_SIZE];
+} uuid_t;
+
+# define UUID_INIT(a_, b_, c_, d0, d1, d2, d3, d4, d5, d6, d7)		\
+{ .b = {((a_) >> 24) & 0xff, ((a_) >> 16) & 0xff,			\
+        ((a_) >> 8) & 0xff, (a_) & 0xff,				\
+        ((b_) >> 8) & 0xff, (b_) & 0xff,				\
+        ((c_) >> 8) & 0xff, (c_) & 0xff,				\
+        (d0), (d1), (d2), (d3), (d4), (d5), (d6), (d7)} }
+
+# define CHK_NULL(ioctl_)						\
+	do {								\
+		ioctl(-1, ioctl_, NULL);				\
+		printf("ioctl(-1, " #ioctl_ ", NULL)" RVAL_EBADF);	\
+	} while (0)
+
+# define CHK_BUF(ioctl_)						\
+	do {								\
+		ioctl(-1, ioctl_, &buf_data);				\
+		printf("ioctl(-1, " #ioctl_				\
+		       ", {buf_len=%llu, buf_ptr=%#llx})" RVAL_EBADF,	\
+		       (unsigned long long) buf_data.buf_len,		\
+		       (unsigned long long) buf_data.buf_ptr);		\
+	} while (0)
+
+# define DEFINE_BUF_W_PARAMS(type_, shorthand_)				\
+	const size_t shorthand_ ## _size = sizeof(type_) +		\
+		NUM_PARAMS * sizeof(struct tee_ioctl_param);		\
+	union {								\
+		type_ shorthand_;					\
+		uint8_t data[shorthand_ ## _size];			\
+	} shorthand_ ## _buf
+
+static const unsigned long one_beef = (unsigned long) 0xcafef00ddeadbeefULL;
+static const unsigned long two_beef = (unsigned long) 0xbadc0dedbadc0dedULL;
+static const unsigned long red_beef = (unsigned long) 0xdefacedbeef0beefULL;
+static const unsigned long blu_beef = (unsigned long) 0xfacefeedcafef00dULL;
+
+static const uuid_t uuid_beef = UUID_INIT(0xdeadbeef, 0xcafe, 0xc0de,
+					  0xba, 0xdc, 0x0d, 0xed,
+					  0xfa, 0xce, 0xfe, 0xed);
+
+static void
+fill_params(struct tee_ioctl_param *params)
+{
+	for (unsigned i = 0; i < NUM_PARAMS; i++) {
+		params[i].a = two_beef;
+		params[i].b = red_beef;
+		params[i].c = blu_beef;
+	}
+	params[0].attr = TEE_IOCTL_PARAM_ATTR_TYPE_NONE;
+	params[1].attr = TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INPUT;
+	params[2].attr = TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_OUTPUT;
+	params[3].attr = TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INOUT;
+	params[4].attr = TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INPUT;
+	params[5].attr = TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_OUTPUT;
+	params[6].attr = TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INOUT;
+	params[7].attr = TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INPUT |
+			 TEE_IOCTL_PARAM_ATTR_META;
+}
+
+static void
+print_params(struct tee_ioctl_param *params)
+{
+	printf("{attr=TEE_IOCTL_PARAM_ATTR_TYPE_NONE}, "
+	       "{attr=TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INPUT, a=%#llx, b=%#llx, c=%#llx}, "
+	       "{attr=TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_OUTPUT, a=%#llx, b=%#llx, c=%#llx}, "
+	       "{attr=TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INOUT, a=%#llx, b=%#llx, c=%#llx}, "
+	       "{attr=TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INPUT, shm_offs=%#llx, size=%#llx, shm_id=%llu}, "
+	       "{attr=TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_OUTPUT, shm_offs=%#llx, size=%#llx, shm_id=%llu}, "
+	       "{attr=TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INOUT, shm_offs=%#llx, size=%#llx, shm_id=%llu}, "
+	       "{attr=TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INPUT|TEE_IOCTL_PARAM_ATTR_META, a=%#llx, b=%#llx, c=%#llx}",
+	       (unsigned long long) two_beef, (unsigned long long) red_beef,
+	       (unsigned long long) blu_beef, (unsigned long long) two_beef,
+	       (unsigned long long) red_beef, (unsigned long long) blu_beef,
+	       (unsigned long long) two_beef, (unsigned long long) red_beef,
+	       (unsigned long long) blu_beef, (unsigned long long) two_beef,
+	       (unsigned long long) red_beef, (unsigned long long) blu_beef,
+	       (unsigned long long) two_beef, (unsigned long long) red_beef,
+	       (unsigned long long) blu_beef, (unsigned long long) two_beef,
+	       (unsigned long long) red_beef, (unsigned long long) blu_beef,
+	       (unsigned long long) two_beef, (unsigned long long) red_beef,
+	       (unsigned long long) blu_beef
+	       );
+}
+
+int
+main(void)
+{
+	gid_t gid;
+
+	struct tee_ioctl_cancel_arg cancel;
+	struct tee_ioctl_shm_alloc_data shm_alloc;
+	struct tee_ioctl_shm_register_data shm_register;
+	struct tee_ioctl_close_session_arg close_session;
+	struct tee_ioctl_shm_register_fd_data shm_register_fd;
+
+	struct tee_ioctl_buf_data buf_data;
+	struct tee_ioctl_param *params = NULL;
+
+	DEFINE_BUF_W_PARAMS(struct tee_ioctl_invoke_arg, invoke);
+	DEFINE_BUF_W_PARAMS(struct tee_iocl_supp_recv_arg, supp_recv);
+	DEFINE_BUF_W_PARAMS(struct tee_iocl_supp_send_arg, supp_send);
+	DEFINE_BUF_W_PARAMS(struct tee_ioctl_open_session_arg, open_session);
+
+	static const char null_path[] = "/dev/null";
+	int fd = open(null_path, O_RDONLY);
+
+	/* NULL as arg */
+	CHK_NULL(TEE_IOC_CANCEL);
+	CHK_NULL(TEE_IOC_INVOKE);
+	CHK_NULL(TEE_IOC_VERSION);
+	CHK_NULL(TEE_IOC_SHM_ALLOC);
+	CHK_NULL(TEE_IOC_SUPPL_RECV);
+	CHK_NULL(TEE_IOC_SUPPL_SEND);
+	CHK_NULL(TEE_IOC_OPEN_SESSION);
+	CHK_NULL(TEE_IOC_SHM_REGISTER);
+	CHK_NULL(TEE_IOC_CLOSE_SESSION);
+
+	/* Valid parameterless calls */
+	ioctl(-1, TEE_IOC_SHM_REGISTER_FD, NULL);
+	printf("ioctl(-1, _IOC(_IOC_READ|_IOC_WRITE, 0xa4, 0x8, 0x20), NULL)"
+	       RVAL_EBADF);
+	ioctl(-1, _IOC(_IOC_NONE, 0xa4, 0xa, 0), NULL);
+	printf("ioctl(-1, _IOC(_IOC_NONE, 0xa4, 0xa, 0), 0)" RVAL_EBADF);
+
+	cancel.cancel_id = (uint32_t) one_beef;
+	cancel.session = (uint32_t) two_beef;
+	ioctl(-1, TEE_IOC_CANCEL, &cancel);
+	printf("ioctl(-1, TEE_IOC_CANCEL, {cancel_id=%u, session=%#x})" RVAL_EBADF,
+	       (uint32_t) one_beef, (uint32_t) two_beef);
+
+	close_session.session = (uint32_t) red_beef;
+	ioctl(-1, TEE_IOC_CLOSE_SESSION, &close_session);
+	printf("ioctl(-1, TEE_IOC_CLOSE_SESSION, {session=%#x})" RVAL_EBADF,
+	       (uint32_t) red_beef);
+
+	shm_alloc.size = one_beef;
+	shm_alloc.flags = TEE_IOCTL_SHM_MAPPED | TEE_IOCTL_SHM_DMA_BUF | 0x80;
+	ioctl(-1, TEE_IOC_SHM_ALLOC, &shm_alloc);
+	printf("ioctl(-1, TEE_IOC_SHM_ALLOC, {size=%#llx, "
+	       "flags=TEE_IOCTL_SHM_MAPPED|TEE_IOCTL_SHM_DMA_BUF|0x80})" RVAL_EBADF,
+	       (unsigned long long) one_beef);
+
+	shm_register.addr = red_beef;
+	shm_register.length = blu_beef;
+	shm_register.flags = TEE_IOCTL_SHM_MAPPED | 0x80;
+	ioctl(-1, TEE_IOC_SHM_REGISTER, &shm_register);
+	printf("ioctl(-1, TEE_IOC_SHM_REGISTER, {addr=%#llx, length=%#llx, "
+	       "flags=TEE_IOCTL_SHM_MAPPED|0x80})" RVAL_EBADF,
+	       (unsigned long long) red_beef,
+	       (unsigned long long) blu_beef);
+
+	if (fd >= 0) {
+		shm_register_fd.fd = fd;
+		shm_register_fd.flags = TEE_IOCTL_SHM_DMA_BUF;
+		ioctl(-1, TEE_IOC_SHM_REGISTER_FD, &shm_register_fd);
+		printf("ioctl(-1, _IOC(_IOC_READ|_IOC_WRITE, 0xa4, 0x8, 0x20), "
+		       "{fd=%d, flags=TEE_IOCTL_SHM_DMA_BUF})" RVAL_EBADF, fd);
+	}
+
+	/* Beef in buf_data */
+	buf_data.buf_ptr = one_beef;
+	buf_data.buf_len = two_beef;
+	CHK_BUF(TEE_IOC_INVOKE);
+	CHK_BUF(TEE_IOC_OPEN_SESSION);
+	CHK_BUF(TEE_IOC_SUPPL_RECV);
+	CHK_BUF(TEE_IOC_SUPPL_SEND);
+
+	/* Valid calls with parameters */
+	invoke_buf.invoke.func = (uint32_t) one_beef;
+	invoke_buf.invoke.session = (uint32_t) two_beef;
+	invoke_buf.invoke.cancel_id = (uint32_t) red_beef;
+	invoke_buf.invoke.num_params = NUM_PARAMS;
+	params = (struct tee_ioctl_param *)(&invoke_buf.invoke + 1);
+	fill_params(params);
+	buf_data.buf_ptr = (uintptr_t) &invoke_buf;
+	buf_data.buf_len = invoke_size;
+	ioctl(-1, TEE_IOC_INVOKE, &buf_data);
+	printf("ioctl(-1, TEE_IOC_INVOKE, {buf_len=%llu, "
+	       "buf_ptr={func=%u, session=%#x, cancel_id=%u, "
+	       "num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       (uint32_t) one_beef, (uint32_t) two_beef,
+	       (uint32_t) red_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	open_session_buf.open_session.clnt_login = TEE_IOCTL_LOGIN_PUBLIC;
+	gid = (gid_t) blu_beef;
+	memcpy(&open_session_buf.open_session.clnt_uuid, &gid, sizeof(gid_t));
+	memcpy(&open_session_buf.open_session.uuid, &uuid_beef, UUID_SIZE);
+	open_session_buf.open_session.cancel_id = (uint32_t) red_beef;
+	open_session_buf.open_session.num_params = NUM_PARAMS;
+	params = (struct tee_ioctl_param *)(&open_session_buf.open_session + 1);
+	fill_params(params);
+	buf_data.buf_ptr = (uintptr_t) &open_session_buf;
+	buf_data.buf_len = open_session_size;
+	ioctl(-1, TEE_IOC_OPEN_SESSION, &buf_data);
+	printf("ioctl(-1, TEE_IOC_OPEN_SESSION, {buf_len=%llu, "
+	       "buf_ptr={uuid=deadbeef-cafe-c0de-badc-0dedfacefeed, "
+	       "clnt_login=TEE_IOCTL_LOGIN_PUBLIC, "
+	       "cancel_id=%u, "
+	       "num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       (uint32_t) red_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	/* All the login types */
+	open_session_buf.open_session.clnt_login = TEE_IOCTL_LOGIN_USER;
+	ioctl(-1, TEE_IOC_OPEN_SESSION, &buf_data);
+	printf("ioctl(-1, TEE_IOC_OPEN_SESSION, {buf_len=%llu, "
+	       "buf_ptr={uuid=deadbeef-cafe-c0de-badc-0dedfacefeed, "
+	       "clnt_login=TEE_IOCTL_LOGIN_USER, "
+	       "cancel_id=%u, "
+	       "num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       (uint32_t) red_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	open_session_buf.open_session.clnt_login = TEE_IOCTL_LOGIN_GROUP;
+	ioctl(-1, TEE_IOC_OPEN_SESSION, &buf_data);
+	printf("ioctl(-1, TEE_IOC_OPEN_SESSION, {buf_len=%llu, "
+	       "buf_ptr={uuid=deadbeef-cafe-c0de-badc-0dedfacefeed, "
+	       "clnt_login=TEE_IOCTL_LOGIN_GROUP, "
+	       "clnt_uuid=%u, cancel_id=%u, "
+	       "num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       gid, (uint32_t) red_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	open_session_buf.open_session.clnt_login = TEE_IOCTL_LOGIN_APPLICATION;
+	ioctl(-1, TEE_IOC_OPEN_SESSION, &buf_data);
+	printf("ioctl(-1, TEE_IOC_OPEN_SESSION, {buf_len=%llu, "
+	       "buf_ptr={uuid=deadbeef-cafe-c0de-badc-0dedfacefeed, "
+	       "clnt_login=TEE_IOCTL_LOGIN_APPLICATION, "
+	       "cancel_id=%u, "
+	       "num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       (uint32_t) red_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	open_session_buf.open_session.clnt_login = TEE_IOCTL_LOGIN_USER_APPLICATION;
+	ioctl(-1, TEE_IOC_OPEN_SESSION, &buf_data);
+	printf("ioctl(-1, TEE_IOC_OPEN_SESSION, {buf_len=%llu, "
+	       "buf_ptr={uuid=deadbeef-cafe-c0de-badc-0dedfacefeed, "
+	       "clnt_login=TEE_IOCTL_LOGIN_USER_APPLICATION, "
+	       "cancel_id=%u, "
+	       "num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       (uint32_t) red_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	open_session_buf.open_session.clnt_login = TEE_IOCTL_LOGIN_GROUP_APPLICATION;
+	ioctl(-1, TEE_IOC_OPEN_SESSION, &buf_data);
+	printf("ioctl(-1, TEE_IOC_OPEN_SESSION, {buf_len=%llu, "
+	       "buf_ptr={uuid=deadbeef-cafe-c0de-badc-0dedfacefeed, "
+	       "clnt_login=TEE_IOCTL_LOGIN_GROUP_APPLICATION, "
+	       "clnt_uuid=%u, cancel_id=%u, "
+	       "num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       gid, (uint32_t) red_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	open_session_buf.open_session.clnt_login = 0xff;
+	ioctl(-1, TEE_IOC_OPEN_SESSION, &buf_data);
+	printf("ioctl(-1, TEE_IOC_OPEN_SESSION, {buf_len=%llu, "
+	       "buf_ptr={uuid=deadbeef-cafe-c0de-badc-0dedfacefeed, "
+	       "clnt_login=%#x /* TEE_IOCTL_LOGIN_??? */, "
+	       "clnt_uuid=[", (unsigned long long) buf_data.buf_len,
+	       open_session_buf.open_session.clnt_login);
+	for (unsigned i = 0; i < UUID_SIZE; i++) {
+		if (i > 0)
+			printf(", ");
+		printf("%#x", open_session_buf.open_session.clnt_uuid[i]);
+	}
+	printf("], cancel_id=%u, "
+	       "num_params=%u, params=[",
+	       (uint32_t) red_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	supp_recv_buf.supp_recv.func = (uint32_t) blu_beef;
+	supp_recv_buf.supp_recv.num_params = NUM_PARAMS;
+	params = (struct tee_ioctl_param *)(&supp_recv_buf.supp_recv + 1);
+	fill_params(params);
+	buf_data.buf_ptr = (uintptr_t) &supp_recv_buf;
+	buf_data.buf_len = supp_recv_size;
+	ioctl(-1, TEE_IOC_SUPPL_RECV, &buf_data);
+	printf("ioctl(-1, TEE_IOC_SUPPL_RECV, {buf_len=%llu, "
+	       "buf_ptr={func=%u, "
+	       "num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       (uint32_t) blu_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	supp_send_buf.supp_send.num_params = NUM_PARAMS;
+	params = (struct tee_ioctl_param *)(&supp_send_buf.supp_send + 1);
+	fill_params(params);
+	buf_data.buf_ptr = (uintptr_t) &supp_send_buf;
+	buf_data.buf_len = supp_send_size;
+	ioctl(-1, TEE_IOC_SUPPL_SEND, &buf_data);
+	printf("ioctl(-1, TEE_IOC_SUPPL_SEND, {buf_len=%llu, "
+	       "buf_ptr={num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	/* Valid buf, but unmatching num_params */
+	invoke_buf.invoke.num_params = 0;
+	supp_recv_buf.supp_recv.num_params = 0;
+	supp_send_buf.supp_send.num_params = 0;
+	open_session_buf.open_session.num_params = 0;
+
+	buf_data.buf_ptr = (uintptr_t) &invoke_buf;
+	buf_data.buf_len = invoke_size;
+	CHK_BUF(TEE_IOC_INVOKE);
+	buf_data.buf_ptr = (uintptr_t) &open_session_buf;
+	buf_data.buf_len = open_session_size;
+	CHK_BUF(TEE_IOC_OPEN_SESSION);
+	buf_data.buf_ptr = (uintptr_t) &supp_recv_buf;
+	buf_data.buf_len = supp_recv_size;
+	CHK_BUF(TEE_IOC_SUPPL_RECV);
+	buf_data.buf_ptr = (uintptr_t) &supp_send_buf;
+	buf_data.buf_len = supp_send_size;
+	CHK_BUF(TEE_IOC_SUPPL_SEND);
+
+	invoke_buf.invoke.num_params = NUM_PARAMS;
+	supp_recv_buf.supp_recv.num_params = NUM_PARAMS;
+	supp_send_buf.supp_send.num_params = NUM_PARAMS;
+	open_session_buf.open_session.num_params = NUM_PARAMS;
+
+	/* Invalid buf_len */
+	buf_data.buf_len = 0;
+	CHK_BUF(TEE_IOC_INVOKE);
+	CHK_BUF(TEE_IOC_OPEN_SESSION);
+	CHK_BUF(TEE_IOC_SUPPL_RECV);
+	CHK_BUF(TEE_IOC_SUPPL_SEND);
+
+	buf_data.buf_len = (unsigned long long) -1;
+	CHK_BUF(TEE_IOC_INVOKE);
+	CHK_BUF(TEE_IOC_OPEN_SESSION);
+	CHK_BUF(TEE_IOC_SUPPL_RECV);
+	CHK_BUF(TEE_IOC_SUPPL_SEND);
+
+	/* Valid buf_len, invalid buf_ptr */
+	buf_data.buf_ptr = one_beef;
+	buf_data.buf_len = invoke_size;
+	CHK_BUF(TEE_IOC_INVOKE);
+	buf_data.buf_len = open_session_size;
+	CHK_BUF(TEE_IOC_OPEN_SESSION);
+	buf_data.buf_len = supp_recv_size;
+	CHK_BUF(TEE_IOC_SUPPL_RECV);
+	buf_data.buf_len = supp_send_size;
+	CHK_BUF(TEE_IOC_SUPPL_SEND);
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else /* !HAVE_LINUX_TEE_H */
+
+SKIP_MAIN_UNDEFINED("HAVE_LINUX_TEE_H")
+
+#endif /* HAVE_LINUX_TEE_H */
diff -pruN 5.5-3/tests-m32/ioctl_tee.gen.test 5.9-0ubuntu2/tests-m32/ioctl_tee.gen.test
--- 5.5-3/tests-m32/ioctl_tee.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_tee.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_tee +ioctl.test ); do not edit.
+set -- 
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-m32/ioctl_uffdio.c 5.9-0ubuntu2/tests-m32/ioctl_uffdio.c
--- 5.5-3/tests-m32/ioctl_uffdio.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_uffdio.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
  * Copyright (c)      2016 Red Hat, Inc.
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -135,6 +135,13 @@ main(void)
 	       " mode=UFFDIO_COPY_MODE_DONTWAKE, copy=%#zx}) = %d\n",
 	       fd, area2, area1, pagesize, pagesize, rc);
 
+	copy_struct->mode = 0xdeadbeef;;
+	rc = ioctl(fd, UFFDIO_COPY, copy_struct);
+	printf("ioctl(%d, UFFDIO_COPY, {dst=%p, src=%p, len=%#zx,"
+	       " mode=UFFDIO_COPY_MODE_DONTWAKE|UFFDIO_COPY_MODE_WP|0xdeadbeec"
+	       "}) = %s\n",
+	       fd, area2, area1, pagesize, sprintrc(rc));
+
 	/* ---- ZEROPAGE ---- */
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct uffdio_zeropage, zero_struct);
 	madvise(area2, pagesize, MADV_DONTNEED);
diff -pruN 5.5-3/tests-m32/ioctl_v4l2.c 5.9-0ubuntu2/tests-m32/ioctl_v4l2.c
--- 5.5-3/tests-m32/ioctl_v4l2.c	2019-08-05 22:48:31.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -8,11 +8,23 @@
 
 #include "tests.h"
 #include <errno.h>
+#include <stdint.h>
 #include <stdio.h>
 #include <string.h>
 #include <sys/ioctl.h>
-#include <linux/types.h>
-#include <linux/videodev2.h>
+#include "kernel_v4l2_types.h"
+
+#define XLAT_MACROS_ONLY
+# include "xlat/v4l2_ioctl_cmds.h"
+#undef XLAT_MACROS_ONLY
+
+#ifndef V4L2_CTRL_FLAG_NEXT_CTRL
+# define V4L2_CTRL_FLAG_NEXT_CTRL 0x80000000
+#endif
+
+#ifndef V4L2_CTRL_CLASS_DETECT
+# define V4L2_CTRL_CLASS_DETECT 0x00a30000
+#endif
 
 #define cc0(arg) ((unsigned int) (unsigned char) (arg))
 #define cc1(arg) ((unsigned int) (unsigned char) ((unsigned int) (arg) >> 8))
@@ -70,8 +82,21 @@ init_v4l2_format(struct v4l2_format *con
 		     i < ARRAY_SIZE(f->fmt.pix_mp.plane_fmt);
 		     i++) {
 			cur_pix[i].sizeimage = 0x1e3c531c | i;
-			cur_pix[i].bytesperline = 0xa983d721 | i;
+			if (sizeof(cur_pix[i].bytesperline) ==
+			    sizeof(uint32_t)) {
+				cur_pix[i].bytesperline = 0xa983d721 | i;
+			} else {
+# if WORDS_BIGENDIAN
+				cur_pix[i].bytesperline = 0xa983;
+				cur_pix[i].reserved[0] = 0xd721 | i;
+# else
+				cur_pix[i].bytesperline = 0xd721 | i;
+				cur_pix[i].reserved[0] = 0xa983;
+# endif
+			}
 		}
+		if (buf_type == V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE)
+			f->fmt.pix_mp.num_planes = 1;
 		break;
 	}
 #endif
@@ -85,10 +110,10 @@ init_v4l2_format(struct v4l2_format *con
 		f->fmt.win.w.height = 0xbbd886c8;
 		f->fmt.win.field = V4L2_FIELD_ANY;
 		f->fmt.win.chromakey = 0xdb1f991f;
-		f->fmt.win.clipcount = 2;
+		f->fmt.win.clipcount =
+			buf_type == V4L2_BUF_TYPE_VIDEO_OVERLAY ? 3 : 2;
 		f->fmt.win.clips =
-			tail_alloc(sizeof(*f->fmt.win.clips) *
-			f->fmt.win.clipcount);
+			tail_alloc(sizeof(*f->fmt.win.clips) * 2);
 		f->fmt.win.clips[0].c.left = 0x3313d36e;
 		f->fmt.win.clips[0].c.top = 0xcdffe510;
 		f->fmt.win.clips[0].c.width = 0x2064f3a8;
@@ -101,6 +126,9 @@ init_v4l2_format(struct v4l2_format *con
 		f->fmt.win.bitmap = (void *) -2UL;
 #ifdef HAVE_STRUCT_V4L2_WINDOW_GLOBAL_ALPHA
 		f->fmt.win.global_alpha = 0xce;
+#else
+		((uint8_t *) &f->fmt.win)[offsetofend(struct v4l2_window,
+						      bitmap)] = 0xce;
 #endif
 		break;
 	case V4L2_BUF_TYPE_VBI_CAPTURE:
@@ -138,7 +166,12 @@ init_v4l2_format(struct v4l2_format *con
 	case V4L2_BUF_TYPE_SDR_OUTPUT:
 		f->fmt.sdr.pixelformat = sf_magic;
 # ifdef HAVE_STRUCT_V4L2_SDR_FORMAT_BUFFERSIZE
-		f->fmt.sdr.buffersize = 0x25afabfb;
+		if (sizeof(f->fmt.sdr.buffersize == sizeof(uint32_t)))
+			f->fmt.sdr.buffersize = 0x25afabfb;
+		else
+			((uint32_t *) &f->fmt.sdr)[1] = 0x25afabfb;
+# else
+		((uint32_t *) &f->fmt.sdr)[1] = 0x25afabfb;
 # endif
 		break;
 #endif
@@ -155,8 +188,8 @@ init_v4l2_format(struct v4l2_format *con
 
 static void
 dprint_ioctl_v4l2(struct v4l2_format *const f,
-		  const char *request, const unsigned int buf_type,
-		  const char *buf_type_string)
+		  XLAT_SEL(unsigned reqval, const char *reqstr),
+		  const unsigned int buf_type, const char *buf_type_string)
 {
 	int saved_errno;
 
@@ -164,12 +197,16 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 	case V4L2_BUF_TYPE_VIDEO_CAPTURE:
 	case V4L2_BUF_TYPE_VIDEO_OUTPUT:
 		saved_errno = errno;
-		printf("ioctl(-1, %s, {type=%s"
+		printf("ioctl(-1, " XLAT_FMT ", {type=" XLAT_FMT
 		       ", fmt.pix={width=%u, height=%u, pixelformat=",
-		       request,
-		       buf_type_string,
+		       XLAT_SEL(reqval, reqstr),
+		       XLAT_SEL(buf_type, buf_type_string),
 		       f->fmt.pix.width, f->fmt.pix.height);
 
+#if XLAT_RAW
+		printf("%#x", buf_type == V4L2_BUF_TYPE_VIDEO_CAPTURE
+			      ? magic : pf_magic);
+#else /* !XLAT_RAW */
 		if (buf_type == V4L2_BUF_TYPE_VIDEO_CAPTURE)
 			printf("v4l2_fourcc('\\x%x', '\\x%x', '\\x%x', '\\x%x')",
 			       cc0(magic), cc1(magic), cc2(magic), cc3(magic));
@@ -178,12 +215,15 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 			       "/* V4L2_PIX_FMT_SPCA508 */",
 			       cc0(pf_magic), cc1(pf_magic), cc2(pf_magic),
 			       cc3(pf_magic));
+#endif /* XLAT_RAW */
 
 		errno = saved_errno;
-		printf(", field=V4L2_FIELD_NONE, bytesperline=%u, sizeimage=%u"
-		       ", colorspace=V4L2_COLORSPACE_JPEG}}) = -1 EBADF (%m)\n",
+		printf(", field=" XLAT_FMT ", bytesperline=%u, sizeimage=%u"
+		       ", colorspace=" XLAT_FMT "}}) = -1 EBADF (%m)\n",
+		       XLAT_ARGS(V4L2_FIELD_NONE),
 		       f->fmt.pix.bytesperline,
-		       f->fmt.pix.sizeimage);
+		       f->fmt.pix.sizeimage,
+		       XLAT_ARGS(V4L2_COLORSPACE_JPEG));
 		break;
 #if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE
 	case V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE:
@@ -191,13 +231,17 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 		unsigned int i;
 
 		saved_errno = errno;
-		printf("ioctl(-1, %s"
-		       ", {type=%s"
+		printf("ioctl(-1, " XLAT_FMT
+		       ", {type=" XLAT_FMT
 		       ", fmt.pix_mp={width=%u, height=%u, pixelformat=",
-		       request,
-		       buf_type_string,
+		       XLAT_SEL(reqval, reqstr),
+		       XLAT_SEL(buf_type, buf_type_string),
 		       f->fmt.pix_mp.width, f->fmt.pix_mp.height);
 
+# if XLAT_RAW
+		printf("%#x", buf_type == V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE
+			      ? magic : pf_magic);
+# else /* !XLAT_RAW */
 		if (buf_type == V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE)
 			printf("v4l2_fourcc('\\x%x', '\\x%x', '\\x%x', '\\x%x')",
 			       cc0(magic), cc1(magic), cc2(magic), cc3(magic));
@@ -206,21 +250,35 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 			       "/* V4L2_PIX_FMT_SPCA508 */",
 			       cc0(pf_magic), cc1(pf_magic), cc2(pf_magic),
 			       cc3(pf_magic));
+# endif /* XLAT_RAW */
 
-		printf(", field=V4L2_FIELD_NONE, colorspace="
-		       "V4L2_COLORSPACE_JPEG, plane_fmt=[");
+		printf(", field=" XLAT_FMT ", colorspace=" XLAT_FMT
+		       ", plane_fmt=[",
+		       XLAT_ARGS(V4L2_FIELD_NONE),
+		       XLAT_ARGS(V4L2_COLORSPACE_JPEG));
 		for (i = 0;
-		     i < ARRAY_SIZE(f->fmt.pix_mp.plane_fmt);
+		     i < (buf_type == V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE
+		          ? 1 : ARRAY_SIZE(f->fmt.pix_mp.plane_fmt));
 		     ++i) {
 			if (i)
 				printf(", ");
 			printf("{sizeimage=%u, bytesperline=%u}",
 			f->fmt.pix_mp.plane_fmt[i].sizeimage,
-			f->fmt.pix_mp.plane_fmt[i].bytesperline);
+			sizeof(f->fmt.pix_mp.plane_fmt[i].bytesperline) ==
+			sizeof(uint32_t)
+			? f->fmt.pix_mp.plane_fmt[i].bytesperline :
+# if WORDS_BIGENDIAN
+			(f->fmt.pix_mp.plane_fmt[i].bytesperline << 16) |
+			f->fmt.pix_mp.plane_fmt[i].reserved[0]
+# else
+			f->fmt.pix_mp.plane_fmt[i].bytesperline |
+			(f->fmt.pix_mp.plane_fmt[i].reserved[0] << 16)
+# endif
+			);
 		}
 		errno = saved_errno;
 		printf("], num_planes=%u}}) = -1 EBADF (%m)\n",
-		f->fmt.pix_mp.num_planes);
+		       f->fmt.pix_mp.num_planes);
 		break;
 	}
 #endif
@@ -228,20 +286,17 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 	case V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY:
 #endif
 	case V4L2_BUF_TYPE_VIDEO_OVERLAY:
-		printf("ioctl(-1, %s, {type=%s"
+		saved_errno = errno;
+		printf("ioctl(-1, " XLAT_FMT ", {type=" XLAT_FMT
 		       ", fmt.win={left=%d, top=%d, width=%u, height=%u"
-		       ", field=V4L2_FIELD_ANY, chromakey=%#x, clips="
+		       ", field=" XLAT_FMT ", chromakey=%#x, clips="
 		       "[{left=%d, top=%d, width=%u, height=%u}, "
-		       "{left=%d, top=%d, width=%u, height=%u}]"
-		       ", clipcount=%u, bitmap=%p"
-#ifdef HAVE_STRUCT_V4L2_WINDOW_GLOBAL_ALPHA
-		       ", global_alpha=%#x"
-#endif
-		       "}}) = -1 EBADF (%m)\n",
-		       request,
-		       buf_type_string,
+		       "{left=%d, top=%d, width=%u, height=%u}",
+		       XLAT_SEL(reqval, reqstr),
+		       XLAT_SEL(buf_type, buf_type_string),
 		       f->fmt.win.w.left, f->fmt.win.w.top,
 		       f->fmt.win.w.width, f->fmt.win.w.height,
+		       XLAT_ARGS(V4L2_FIELD_ANY),
 		       f->fmt.win.chromakey,
 		       f->fmt.win.clips[0].c.left,
 		       f->fmt.win.clips[0].c.top,
@@ -250,24 +305,37 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 		       f->fmt.win.clips[1].c.left,
 		       f->fmt.win.clips[1].c.top,
 		       f->fmt.win.clips[1].c.width,
-		       f->fmt.win.clips[1].c.height,
-		       f->fmt.win.clipcount, f->fmt.win.bitmap
+		       f->fmt.win.clips[1].c.height);
+		if (f->fmt.win.clipcount > 2)
+			printf(", ... /* %p */", f->fmt.win.clips + 2);
+		errno = saved_errno;
+		printf("], clipcount=%u, bitmap=%p"
+		       ", global_alpha=%#x"
+		       "}}) = -1 EBADF (%m)\n",
+		       f->fmt.win.clipcount, f->fmt.win.bitmap,
 #ifdef HAVE_STRUCT_V4L2_WINDOW_GLOBAL_ALPHA
-		       , f->fmt.win.global_alpha
+		       f->fmt.win.global_alpha
+#else
+		       ((uint8_t *) &f->fmt.win)[offsetofend(struct v4l2_window,
+							     bitmap)]
 #endif
 		       );
 		break;
 	case V4L2_BUF_TYPE_VBI_CAPTURE:
 	case V4L2_BUF_TYPE_VBI_OUTPUT:
 		saved_errno = errno;
-		printf("ioctl(-1, %s, {type=%s"
+		printf("ioctl(-1, " XLAT_FMT ", {type=" XLAT_FMT
 		       ", fmt.vbi={sampling_rate=%u, offset=%u"
 		       ", samples_per_line=%u, sample_format=",
-		       request,
-		       buf_type_string,
+		       XLAT_SEL(reqval, reqstr),
+		       XLAT_SEL(buf_type, buf_type_string),
 		       f->fmt.vbi.sampling_rate, f->fmt.vbi.offset,
 		       f->fmt.vbi.samples_per_line);
 
+#if XLAT_RAW
+		printf("%#x", buf_type == V4L2_BUF_TYPE_VBI_CAPTURE
+			      ? magic : pf_magic);
+#else /* !XLAT_RAW */
 		if (buf_type == V4L2_BUF_TYPE_VBI_CAPTURE)
 			printf("v4l2_fourcc('\\x%x', '\\x%x', '\\x%x', '\\x%x')",
 			       cc0(magic), cc1(magic), cc2(magic), cc3(magic));
@@ -276,24 +344,27 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 			       "/* V4L2_PIX_FMT_SPCA508 */",
 			       cc0(pf_magic), cc1(pf_magic), cc2(pf_magic),
 			       cc3(pf_magic));
+#endif /* XLAT_RAW */
 
 		errno = saved_errno;
-		printf(", start=[%u, %u], count=[%u, %u]"
-		       ", flags=V4L2_VBI_INTERLACED}})"
+		printf(", start=[%d, %d], count=[%u, %u]"
+		       ", flags=" XLAT_FMT "}})"
 		       " = -1 EBADF (%m)\n",
 		       f->fmt.vbi.start[0], f->fmt.vbi.start[1],
-		       f->fmt.vbi.count[0], f->fmt.vbi.count[1]);
+		       f->fmt.vbi.count[0], f->fmt.vbi.count[1],
+		       XLAT_ARGS(V4L2_VBI_INTERLACED));
 		break;
 #if HAVE_DECL_V4L2_BUF_TYPE_SLICED_VBI_CAPTURE
 	case V4L2_BUF_TYPE_SLICED_VBI_CAPTURE:
 	case V4L2_BUF_TYPE_SLICED_VBI_OUTPUT: {
 		unsigned int i, j;
 
-		printf("ioctl(-1, %s, {type=%s"
-		       ", fmt.sliced={service_set=V4L2_SLICED_VPS"
+		printf("ioctl(-1, " XLAT_FMT ", {type=" XLAT_FMT
+		       ", fmt.sliced={service_set=" XLAT_FMT
 		       ", io_size=%u, service_lines=[",
-		       request,
-		       buf_type_string,
+		       XLAT_SEL(reqval, reqstr),
+		       XLAT_SEL(buf_type, buf_type_string),
+		       XLAT_ARGS(V4L2_SLICED_VPS),
 		       f->fmt.sliced.io_size);
 		for (i = 0;
 		     i < ARRAY_SIZE(f->fmt.sliced.service_lines);
@@ -321,30 +392,38 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 #if HAVE_DECL_V4L2_BUF_TYPE_SDR_CAPTURE
 	case V4L2_BUF_TYPE_SDR_CAPTURE:
 		saved_errno = errno;
-		printf("ioctl(-1, %s, {type=%s"
+		printf("ioctl(-1, " XLAT_FMT ", {type=" XLAT_FMT
 		       ", fmt.sdr={pixelformat=",
-		       request,
-		       buf_type_string);
+		       XLAT_SEL(reqval, reqstr),
+		       XLAT_SEL(buf_type, buf_type_string));
 
+# if XLAT_RAW
+		if (buf_type == V4L2_BUF_TYPE_SDR_CAPTURE)
+			printf("%#x", magic);
+#  if HAVE_DECL_V4L2_BUF_TYPE_SDR_OUTPUT
+		else
+			printf("%#x", sf_magic);
+#  endif
+# else /* !XLAT_RAW */
 		if (buf_type == V4L2_BUF_TYPE_SDR_CAPTURE)
 			printf("v4l2_fourcc('\\x%x', '\\x%x', '\\x%x', '\\x%x')",
 			       cc0(magic), cc1(magic), cc2(magic), cc3(magic));
-# if HAVE_DECL_V4L2_BUF_TYPE_SDR_OUTPUT
+#  if HAVE_DECL_V4L2_BUF_TYPE_SDR_OUTPUT
 		else
 			printf("v4l2_fourcc('%c', '%c', '%c', '%c') "
 			       "/* V4L2_SDR_FMT_RU12LE */",
 			       cc0(sf_magic), cc1(sf_magic), cc2(sf_magic),
 			       cc3(sf_magic));
-# endif
+#  endif
+# endif /* XLAT_RAW */
 
 		errno = saved_errno;
-		printf(
-# ifdef HAVE_STRUCT_V4L2_SDR_FORMAT_BUFFERSIZE
-		       ", buffersize=%u"
-# endif
-		       "}}) = -1 EBADF (%m)\n"
+		printf(", buffersize=%u}}) = -1 EBADF (%m)\n"
 # ifdef HAVE_STRUCT_V4L2_SDR_FORMAT_BUFFERSIZE
-		       , f->fmt.sdr.buffersize
+		       , sizeof(f->fmt.sdr.buffersize == sizeof(uint32_t))
+			? f->fmt.sdr.buffersize : ((uint32_t *) &f->fmt.sdr)[1]
+# else
+		       , ((uint32_t *) &f->fmt.sdr)[1]
 # endif
 		       );
 		break;
@@ -352,7 +431,8 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 	}
 }
 #define print_ioctl_v4l2(v4l2_format, request, buf_type)	\
-	dprint_ioctl_v4l2((v4l2_format), (request), (buf_type), #buf_type)
+	dprint_ioctl_v4l2((v4l2_format), XLAT_SEL(request, #request), \
+			  (buf_type), #buf_type)
 
 int
 main(void)
@@ -364,267 +444,559 @@ main(void)
 
 	unsigned char cc[sizeof(int)] = { 'A', '\'', '\\', '\xfa' };
 
+	/* Unknown */
+	static const struct {
+		uint32_t flags;
+		const char *str;
+	} cmd_flags[] = {
+		{ ARG_STR(_IOC_NONE) },
+		{ ARG_STR(_IOC_READ) },
+		{ ARG_STR(_IOC_WRITE) },
+		{ ARG_STR(_IOC_READ|_IOC_WRITE) },
+	};
+	static const uint8_t unknown_cmds[] = {
+		1, 3, 6 /* VIDIOC_G_MPEGCOMP */, 7 /* VIDIOC_S_MPEGCOMP */,
+		12, 13, 20, 31, 32, 35, 42, 43, 44, 45, 51, 52, 53,
+		81 /* VIDIOC_G_CHIP_IDENT_OLD */,
+		83 /* VIDIOC_ENUM_DV_PRESETS */, 84 /* VIDIOC_S_DV_PRESET */,
+		85 /* VIDIOC_G_DV_PRESET */, 86 /* VIDIOC_QUERY_DV_PRESET */,
+		104 /* 103 is the last existing */, 255
+	};
+
+	for (size_t i = 0; i < ARRAY_SIZE(unknown_cmds); i++) {
+		/* Trying to hit common argument sizes */
+		for (size_t j = 0; j < 256; j += 4) {
+			for (size_t k = 0; k < ARRAY_SIZE(cmd_flags); k++) {
+				uint32_t ioc = _IOC(cmd_flags[k].flags, 'V',
+						    unknown_cmds[i], j);
+				/*
+				 * Conflicts with VT* and VBG* ioctls
+				 * that happen to also use 'V' command type.
+				 */
+				switch (ioc) {
+				/* VT_GETMODE */
+				case _IOC(_IOC_NONE, 'V', 1, 0):
+				/* VT_GETSTATE */
+				case _IOC(_IOC_NONE, 'V', 3, 0):
+				/* VBG_IOCTL_VMMDEV_REQUEST_BIG */
+				case _IOC(_IOC_READ|_IOC_WRITE, 'V', 3, 0):
+				/* VT_ACTIVATE */
+				case _IOC(_IOC_NONE, 'V', 6, 0):
+				/* VT_WAITACTIVE */
+				case _IOC(_IOC_NONE, 'V', 7, 0):
+				/* VT_UNLOCKSWITCH */
+				case _IOC(_IOC_NONE, 'V', 12, 0):
+				/* VBG_IOCTL_CHANGE_FILTER_MASK */
+				case _IOC(_IOC_READ|_IOC_WRITE, 'V', 12, 32):
+				/* VT_GETHIFONTMASK */
+				case _IOC(_IOC_NONE, 'V', 13, 0):
+					continue;
+				/* VBG_IOCTL_ACQUIRE_GUEST_CAPABILITIES */
+				case _IOC(_IOC_READ|_IOC_WRITE, 'V', 13, 36):
+					continue;
+				}
+
+				ioctl(-1, ioc, 0);
+				printf("ioctl(-1, " NABBR("%#x") VERB(" /* ")
+				       NRAW("_IOC(%s, 0x56, %#x, %#zx)")
+				       VERB(" */") ", 0) = -1 EBADF (%m)\n"
+#if XLAT_RAW || XLAT_VERBOSE
+				       , ioc
+#endif
+#if !XLAT_RAW
+				       , cmd_flags[k].str, unknown_cmds[i], j
+#endif
+				       );
+
+				ioctl(-1, ioc,
+				      (unsigned long) 0xbadc0deddeadc0deULL);
+				printf("ioctl(-1, " NABBR("%#x") VERB(" /* ")
+				       NRAW("_IOC(%s, 0x56, %#x, %#zx)")
+				       VERB(" */") ", %#lx) = -1 EBADF (%m)\n",
+#if XLAT_RAW || XLAT_VERBOSE
+				       ioc,
+#endif
+#if !XLAT_RAW
+				       cmd_flags[k].str, unknown_cmds[i], j,
+#endif
+				       (unsigned long) 0xbadc0deddeadc0deULL);
+			}
+		}
+	}
+
+	/* Decoding is not supported */
+	static const struct {
+		uint32_t cmd;
+		const char *str;
+	} unsupp_cmds[] = {
+		{ ARG_STR(VIDIOC_OVERLAY) },
+#ifdef VIDIOC_EXPBUF
+		{ ARG_STR(VIDIOC_EXPBUF) },
+#endif
+		{ ARG_STR(VIDIOC_G_AUDIO) },
+		{ ARG_STR(VIDIOC_S_AUDIO) },
+		{ ARG_STR(VIDIOC_QUERYMENU) },
+#ifdef VIDIOC_G_EDID
+		{ ARG_STR(VIDIOC_G_EDID) },
+#endif
+#ifdef VIDIOC_S_EDID
+		{ ARG_STR(VIDIOC_S_EDID) },
+#endif
+		{ ARG_STR(VIDIOC_G_OUTPUT) },
+		{ ARG_STR(VIDIOC_S_OUTPUT) },
+		{ ARG_STR(VIDIOC_ENUMOUTPUT) },
+		{ ARG_STR(VIDIOC_G_AUDOUT) },
+		{ ARG_STR(VIDIOC_S_AUDOUT) },
+		{ ARG_STR(VIDIOC_G_MODULATOR) },
+		{ ARG_STR(VIDIOC_S_MODULATOR) },
+		{ ARG_STR(VIDIOC_G_FREQUENCY) },
+		{ ARG_STR(VIDIOC_S_FREQUENCY) },
+		{ ARG_STR(VIDIOC_G_JPEGCOMP) },
+		{ ARG_STR(VIDIOC_S_JPEGCOMP) },
+		{ ARG_STR(VIDIOC_QUERYSTD) },
+		{ ARG_STR(VIDIOC_ENUMAUDIO) },
+		{ ARG_STR(VIDIOC_ENUMAUDOUT) },
+		{ ARG_STR(VIDIOC_G_PRIORITY) },
+		{ ARG_STR(VIDIOC_S_PRIORITY) },
+		{ ARG_STR(VIDIOC_G_SLICED_VBI_CAP) },
+		{ ARG_STR(VIDIOC_LOG_STATUS) },
+#ifdef VIDIOC_G_ENC_INDEX
+		{ ARG_STR(VIDIOC_G_ENC_INDEX) },
+#endif
+#ifdef VIDIOC_ENCODER_CMD
+		{ ARG_STR(VIDIOC_ENCODER_CMD) },
+#endif
+#ifdef VIDIOC_TRY_ENCODER_CMD
+		{ ARG_STR(VIDIOC_TRY_ENCODER_CMD) },
+#endif
+#ifdef VIDIOC_DBG_S_REGISTER
+		{ ARG_STR(VIDIOC_DBG_S_REGISTER) },
+#endif
+#ifdef VIDIOC_DBG_G_REGISTER
+		{ ARG_STR(VIDIOC_DBG_G_REGISTER) },
+#endif
+#ifdef VIDIOC_G_CHIP_IDENT_OLD
+		{ ARG_STR(VIDIOC_G_CHIP_IDENT_OLD) },
+#endif
+#ifdef VIDIOC_DBG_G_CHIP_IDENT
+		/* Broken on RHEL 6/7 */
+		/* { ARG_STR(VIDIOC_DBG_G_CHIP_IDENT) }, */
+#endif
+#ifdef VIDIOC_S_HW_FREQ_SEEK
+		{ ARG_STR(VIDIOC_S_HW_FREQ_SEEK) },
+#endif
+#ifdef VIDIOC_ENUM_DV_PRESETS
+		/* Next 4 are broken on RHEL 6 */
+		/* { ARG_STR(VIDIOC_ENUM_DV_PRESETS) }, */
+#endif
+#ifdef VIDIOC_S_DV_PRESET
+		/* { ARG_STR(VIDIOC_S_DV_PRESET) }, */
+#endif
+#ifdef VIDIOC_G_DV_PRESET
+		/* { ARG_STR(VIDIOC_G_DV_PRESET) }, */
+#endif
+#ifdef VIDIOC_QUERY_DV_PRESET
+		/* { ARG_STR(VIDIOC_QUERY_DV_PRESET) }, */
+#endif
+#ifdef VIDIOC_S_DV_TIMINGS
+		{ ARG_STR(VIDIOC_S_DV_TIMINGS) },
+#endif
+#ifdef VIDIOC_G_DV_TIMINGS
+		{ ARG_STR(VIDIOC_G_DV_TIMINGS) },
+#endif
+#ifdef VIDIOC_DQEVENT
+		{ ARG_STR(VIDIOC_DQEVENT) },
+#endif
+#ifdef VIDIOC_SUBSCRIBE_EVENT
+		{ ARG_STR(VIDIOC_SUBSCRIBE_EVENT) },
+#endif
+#ifdef VIDIOC_UNSUBSCRIBE_EVENT
+		{ ARG_STR(VIDIOC_UNSUBSCRIBE_EVENT) },
+#endif
+#ifdef VIDIOC_PREPARE_BUF
+		{ ARG_STR(VIDIOC_PREPARE_BUF) },
+#endif
+#ifdef VIDIOC_G_SELECTION
+		{ ARG_STR(VIDIOC_G_SELECTION) },
+#endif
+#ifdef VIDIOC_S_SELECTION
+		{ ARG_STR(VIDIOC_S_SELECTION) },
+#endif
+#ifdef VIDIOC_DECODER_CMD
+		{ ARG_STR(VIDIOC_DECODER_CMD) },
+#endif
+#ifdef VIDIOC_TRY_DECODER_CMD
+		{ ARG_STR(VIDIOC_TRY_DECODER_CMD) },
+#endif
+#ifdef VIDIOC_ENUM_DV_TIMINGS
+		{ ARG_STR(VIDIOC_ENUM_DV_TIMINGS) },
+#endif
+#ifdef VIDIOC_QUERY_DV_TIMINGS
+		{ ARG_STR(VIDIOC_QUERY_DV_TIMINGS) },
+#endif
+#ifdef VIDIOC_DV_TIMINGS_CAP
+		{ ARG_STR(VIDIOC_DV_TIMINGS_CAP) },
+#endif
+#ifdef VIDIOC_ENUM_FREQ_BANDS
+		{ ARG_STR(VIDIOC_ENUM_FREQ_BANDS) },
+#endif
+#ifdef VIDIOC_DBG_G_CHIP_INFO
+		{ ARG_STR(VIDIOC_DBG_G_CHIP_INFO) },
+#endif
+#ifdef VIDIOC_QUERY_EXT_CTRL
+		{ ARG_STR(VIDIOC_QUERY_EXT_CTRL) },
+#endif
+#ifdef VIDIOC_SUBDEV_ENUM_MBUS_CODE
+		{ ARG_STR(VIDIOC_SUBDEV_ENUM_MBUS_CODE) },
+#endif
+#ifdef VIDIOC_SUBDEV_G_FMT
+		{ ARG_STR(VIDIOC_SUBDEV_G_FMT) },
+#endif
+#ifdef VIDIOC_SUBDEV_S_FMT
+		{ ARG_STR(VIDIOC_SUBDEV_S_FMT) },
+#endif
+#ifdef VIDIOC_SUBDEV_G_FRAME_INTERVAL
+		{ ARG_STR(VIDIOC_SUBDEV_G_FRAME_INTERVAL) },
+#endif
+#ifdef VIDIOC_SUBDEV_S_FRAME_INTERVAL
+		{ ARG_STR(VIDIOC_SUBDEV_S_FRAME_INTERVAL) },
+#endif
+#ifdef VIDIOC_SUBDEV_G_CROP
+		{ ARG_STR(VIDIOC_SUBDEV_G_CROP) },
+#endif
+#ifdef VIDIOC_SUBDEV_S_CROP
+		{ ARG_STR(VIDIOC_SUBDEV_S_CROP) },
+#endif
+#ifdef VIDIOC_SUBDEV_G_SELECTION
+		{ ARG_STR(VIDIOC_SUBDEV_G_SELECTION) },
+#endif
+#ifdef VIDIOC_SUBDEV_S_SELECTION
+		{ ARG_STR(VIDIOC_SUBDEV_S_SELECTION) },
+#endif
+#ifdef VIDIOC_SUBDEV_ENUM_FRAME_SIZE
+		{ ARG_STR(VIDIOC_SUBDEV_ENUM_FRAME_SIZE) },
+#endif
+#ifdef VIDIOC_SUBDEV_ENUM_FRAME_INTERVAL
+		{ ARG_STR(VIDIOC_SUBDEV_ENUM_FRAME_INTERVAL) },
+#endif
+	};
+
+	for (size_t i = 0; i < ARRAY_SIZE(unsupp_cmds); i++) {
+		switch (unsupp_cmds[i].cmd) {
+		/*
+		 * VIDIOC_G_SLICED_VBI_CAP macro has been changed from
+		 * IOR to IOWR in Linux v2.6.19-rc1~643^2~37, skip it.
+		 */
+		case _IOR('V', 69, struct v4l2_sliced_vbi_cap):
+			continue;
+		}
+
+		ioctl(-1, unsupp_cmds[i].cmd, 0);
+		printf("ioctl(-1, " XLAT_FMT ", 0) = -1 EBADF (%m)\n",
+		       XLAT_SEL(unsupp_cmds[i].cmd, unsupp_cmds[i].str));
+
+		ioctl(-1, unsupp_cmds[i].cmd,
+		      (unsigned long) 0xbadc0deddeadc0deULL);
+		printf("ioctl(-1, " XLAT_FMT ", %#lx) = -1 EBADF (%m)\n",
+		       XLAT_SEL(unsupp_cmds[i].cmd, unsupp_cmds[i].str),
+		       (unsigned long) 0xbadc0deddeadc0deULL);
+	}
+
 	/* VIDIOC_QUERYCAP */
 	ioctl(-1, VIDIOC_QUERYCAP, 0);
-	printf("ioctl(-1, VIDIOC_QUERYCAP, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QUERYCAP));
 
 	ioctl(-1, VIDIOC_QUERYCAP, page);
-	printf("ioctl(-1, VIDIOC_QUERYCAP, %p) = -1 EBADF (%m)\n", page);
+	printf("ioctl(-1, %s, %p) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QUERYCAP), page);
 
 	/* VIDIOC_ENUM_FMT */
 	ioctl(-1, VIDIOC_ENUM_FMT, 0);
-	printf("ioctl(-1, VIDIOC_ENUM_FMT, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUM_FMT));
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct v4l2_fmtdesc, p_fmtdesc);
 	p_fmtdesc->index = magic;
 	p_fmtdesc->type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
 	ioctl(-1, VIDIOC_ENUM_FMT, p_fmtdesc);
-	printf("ioctl(-1, VIDIOC_ENUM_FMT, {index=%u"
-	       ", type=V4L2_BUF_TYPE_VIDEO_CAPTURE}) = -1 EBADF (%m)\n",
-	       p_fmtdesc->index);
+	printf("ioctl(-1, %s, {index=%u, type=" XLAT_FMT
+	       "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUM_FMT), p_fmtdesc->index,
+	       XLAT_ARGS(V4L2_BUF_TYPE_VIDEO_CAPTURE));
 
 	/* VIDIOC_G_FMT */
 	ioctl(-1, VIDIOC_G_FMT, 0);
-	printf("ioctl(-1, VIDIOC_G_FMT, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT));
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct v4l2_format, p_format);
 
 	p_format->type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
 	ioctl(-1, VIDIOC_G_FMT, p_format);
-	printf("ioctl(-1, VIDIOC_G_FMT"
-	       ", {type=V4L2_BUF_TYPE_VIDEO_CAPTURE}) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {type=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT),
+	       XLAT_ARGS(V4L2_BUF_TYPE_VIDEO_CAPTURE));
 #if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE
 	p_format->type = V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE;
 	ioctl(-1, VIDIOC_G_FMT, p_format);
-	printf("ioctl(-1, VIDIOC_G_FMT"
-	       ", {type=V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE}) ="
-	       " -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {type=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT),
+	       XLAT_ARGS(V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE));
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY
 	p_format->type = V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY;
 	ioctl(-1, VIDIOC_G_FMT, p_format);
-	printf("ioctl(-1, VIDIOC_G_FMT"
-	       ", {type=V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY}) ="
-	       " -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {type=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT),
+	       XLAT_ARGS(V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY));
 #endif
 	p_format->type = V4L2_BUF_TYPE_VIDEO_OVERLAY;
 	ioctl(-1, VIDIOC_G_FMT, p_format);
-	printf("ioctl(-1, VIDIOC_G_FMT"
-	       ", {type=V4L2_BUF_TYPE_VIDEO_OVERLAY}) ="
-	       " -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {type=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT),
+	       XLAT_ARGS(V4L2_BUF_TYPE_VIDEO_OVERLAY));
 
 	p_format->type = V4L2_BUF_TYPE_VBI_CAPTURE;
 	ioctl(-1, VIDIOC_G_FMT, p_format);
-	printf("ioctl(-1, VIDIOC_G_FMT"
-	       ", {type=V4L2_BUF_TYPE_VBI_CAPTURE}) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {type=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT),
+	       XLAT_ARGS(V4L2_BUF_TYPE_VBI_CAPTURE));
 #if HAVE_DECL_V4L2_BUF_TYPE_SLICED_VBI_CAPTURE
 	p_format->type = V4L2_BUF_TYPE_SLICED_VBI_CAPTURE;
 	ioctl(-1, VIDIOC_G_FMT, p_format);
-	printf("ioctl(-1, VIDIOC_G_FMT"
-	       ", {type=V4L2_BUF_TYPE_SLICED_VBI_CAPTURE}) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {type=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT),
+	       XLAT_ARGS(V4L2_BUF_TYPE_SLICED_VBI_CAPTURE));
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_SDR_CAPTURE
 	p_format->type = V4L2_BUF_TYPE_SDR_CAPTURE;
 	ioctl(-1, VIDIOC_G_FMT, p_format);
-	printf("ioctl(-1, VIDIOC_G_FMT"
-	       ", {type=V4L2_BUF_TYPE_SDR_CAPTURE}) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {type=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT),
+	       XLAT_ARGS(V4L2_BUF_TYPE_SDR_CAPTURE));
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_SDR_OUTPUT
 	p_format->type = V4L2_BUF_TYPE_SDR_OUTPUT;
 	ioctl(-1, VIDIOC_G_FMT, p_format);
-	printf("ioctl(-1, VIDIOC_G_FMT"
-	       ", {type=V4L2_BUF_TYPE_SDR_OUTPUT}) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {type=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT),
+	       XLAT_ARGS(V4L2_BUF_TYPE_SDR_OUTPUT));
 #endif
 	/* VIDIOC_S_FMT */
 	ioctl(-1, VIDIOC_S_FMT, 0);
-	printf("ioctl(-1, VIDIOC_S_FMT, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_FMT));
 
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VIDEO_OUTPUT);
 	ioctl(-1, VIDIOC_S_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_S_FMT", V4L2_BUF_TYPE_VIDEO_OUTPUT);
+	print_ioctl_v4l2(p_format, VIDIOC_S_FMT,
+			 V4L2_BUF_TYPE_VIDEO_OUTPUT);
 #if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE);
 	ioctl(-1, VIDIOC_S_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_S_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_S_FMT,
 			 V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE);
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY);
 	ioctl(-1, VIDIOC_S_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_S_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_S_FMT,
 			 V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY);
 #endif
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VIDEO_OVERLAY);
 	ioctl(-1, VIDIOC_S_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_S_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_S_FMT,
 			 V4L2_BUF_TYPE_VIDEO_OVERLAY);
 
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VBI_CAPTURE);
 	ioctl(-1, VIDIOC_S_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_S_FMT", V4L2_BUF_TYPE_VBI_CAPTURE);
+	print_ioctl_v4l2(p_format, VIDIOC_S_FMT, V4L2_BUF_TYPE_VBI_CAPTURE);
 #if HAVE_DECL_V4L2_BUF_TYPE_SLICED_VBI_CAPTURE
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_SLICED_VBI_CAPTURE);
 	ioctl(-1, VIDIOC_S_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_S_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_S_FMT,
 			 V4L2_BUF_TYPE_SLICED_VBI_CAPTURE);
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_SDR_CAPTURE
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_SDR_CAPTURE);
 	ioctl(-1, VIDIOC_S_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_S_FMT", V4L2_BUF_TYPE_SDR_CAPTURE);
+	print_ioctl_v4l2(p_format, VIDIOC_S_FMT, V4L2_BUF_TYPE_SDR_CAPTURE);
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_SDR_OUTPUT
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_SDR_OUTPUT);
 	ioctl(-1, VIDIOC_S_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_S_FMT", V4L2_BUF_TYPE_SDR_OUTPUT);
+	print_ioctl_v4l2(p_format, VIDIOC_S_FMT, V4L2_BUF_TYPE_SDR_OUTPUT);
 #endif
 	/* VIDIOC_TRY_FMT */
 	ioctl(-1, VIDIOC_TRY_FMT, 0);
-	printf("ioctl(-1, VIDIOC_TRY_FMT, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_TRY_FMT));
 
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VIDEO_OUTPUT);
 	ioctl(-1, VIDIOC_TRY_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_TRY_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_TRY_FMT,
 			 V4L2_BUF_TYPE_VIDEO_OUTPUT);
 #if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE);
 	ioctl(-1, VIDIOC_TRY_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_TRY_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_TRY_FMT,
 			 V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE);
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY);
 	ioctl(-1, VIDIOC_TRY_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_TRY_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_TRY_FMT,
 			 V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY);
 #endif
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VIDEO_OVERLAY);
 	ioctl(-1, VIDIOC_TRY_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_TRY_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_TRY_FMT,
 			 V4L2_BUF_TYPE_VIDEO_OVERLAY);
 
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VBI_CAPTURE);
 	ioctl(-1, VIDIOC_TRY_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_TRY_FMT", V4L2_BUF_TYPE_VBI_CAPTURE);
+	print_ioctl_v4l2(p_format, VIDIOC_TRY_FMT, V4L2_BUF_TYPE_VBI_CAPTURE);
 #if HAVE_DECL_V4L2_BUF_TYPE_SLICED_VBI_CAPTURE
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_SLICED_VBI_CAPTURE);
 	ioctl(-1, VIDIOC_TRY_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_TRY_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_TRY_FMT,
 			 V4L2_BUF_TYPE_SLICED_VBI_CAPTURE);
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_SDR_CAPTURE
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_SDR_CAPTURE);
 	ioctl(-1, VIDIOC_TRY_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_TRY_FMT", V4L2_BUF_TYPE_SDR_CAPTURE);
+	print_ioctl_v4l2(p_format, VIDIOC_TRY_FMT, V4L2_BUF_TYPE_SDR_CAPTURE);
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_SDR_OUTPUT
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_SDR_OUTPUT);
 	ioctl(-1, VIDIOC_TRY_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_TRY_FMT", V4L2_BUF_TYPE_SDR_OUTPUT);
+	print_ioctl_v4l2(p_format, VIDIOC_TRY_FMT, V4L2_BUF_TYPE_SDR_OUTPUT);
 #endif
 	struct v4l2_format *const p_v4l2_format =
 		page_end - sizeof(*p_v4l2_format);
 	ioctl(-1, VIDIOC_TRY_FMT, p_v4l2_format);
-	printf("ioctl(-1, VIDIOC_TRY_FMT, {type=%#x /* V4L2_BUF_TYPE_??? */})"
-	       " = -1 EBADF (%m)\n", p_v4l2_format->type);
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */") "})"
+	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_TRY_FMT), p_v4l2_format->type);
 
 	/* VIDIOC_REQBUFS */
 	ioctl(-1, VIDIOC_REQBUFS, 0);
-	printf("ioctl(-1, VIDIOC_REQBUFS, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_REQBUFS));
 
 	struct v4l2_requestbuffers *const p_v4l2_requestbuffers =
 		page_end - sizeof(*p_v4l2_requestbuffers);
 	ioctl(-1, VIDIOC_REQBUFS, p_v4l2_requestbuffers);
-	printf("ioctl(-1, VIDIOC_REQBUFS, {type=%#x /* V4L2_BUF_TYPE_??? */, "
-	       "memory=%#x /* V4L2_MEMORY_??? */, count=%u})"
+	printf("ioctl(-1, %s, {type=%#x"
+	       NRAW(" /* V4L2_BUF_TYPE_??? */")
+	       ", memory=%#x" NRAW(" /* V4L2_MEMORY_??? */") ", count=%u})"
 	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_REQBUFS),
 	       p_v4l2_requestbuffers->type,
 	       p_v4l2_requestbuffers->memory,
 	       p_v4l2_requestbuffers->count);
 
 	/* VIDIOC_QUERYBUF */
 	ioctl(-1, VIDIOC_QUERYBUF, 0);
-	printf("ioctl(-1, VIDIOC_QUERYBUF, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QUERYBUF));
 
-	struct v4l2_buffer *const p_v4l2_buffer =
+	kernel_v4l2_buffer_t *const p_v4l2_buffer =
 		page_end - sizeof(*p_v4l2_buffer);
 	ioctl(-1, VIDIOC_QUERYBUF, p_v4l2_buffer);
-	printf("ioctl(-1, VIDIOC_QUERYBUF, {type=%#x /* V4L2_BUF_TYPE_??? */"
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */")
 	       ", index=%u}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QUERYBUF),
 	       p_v4l2_buffer->type, p_v4l2_buffer->index);
 
 	/* VIDIOC_QBUF */
 	ioctl(-1, VIDIOC_QBUF, 0);
-	printf("ioctl(-1, VIDIOC_QBUF, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QBUF));
 
 	ioctl(-1, VIDIOC_QBUF, p_v4l2_buffer);
-	printf("ioctl(-1, VIDIOC_QBUF, {type=%#x /* V4L2_BUF_TYPE_??? */"
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */")
 	       ", index=%u}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QBUF),
 	       p_v4l2_buffer->type, p_v4l2_buffer->index);
 
 	/* VIDIOC_DQBUF */
 	ioctl(-1, VIDIOC_DQBUF, 0);
-	printf("ioctl(-1, VIDIOC_DQBUF, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_DQBUF));
 
 	ioctl(-1, VIDIOC_DQBUF, p_v4l2_buffer);
-	printf("ioctl(-1, VIDIOC_DQBUF, {type=%#x"
-	       " /* V4L2_BUF_TYPE_??? */}) = -1 EBADF (%m)\n",
-	       p_v4l2_buffer->type);
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */")
+	       "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_DQBUF), p_v4l2_buffer->type);
 
 	/* VIDIOC_G_FBUF */
 	ioctl(-1, VIDIOC_G_FBUF, 0);
-	printf("ioctl(-1, VIDIOC_G_FBUF, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FBUF));
 
 	ioctl(-1, VIDIOC_G_FBUF, page);
-	printf("ioctl(-1, VIDIOC_G_FBUF, %p) = -1 EBADF (%m)\n", page);
+	printf("ioctl(-1, %s, %p) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FBUF), page);
 
 	/* VIDIOC_S_FBUF */
 	ioctl(-1, VIDIOC_S_FBUF, 0);
-	printf("ioctl(-1, VIDIOC_S_FBUF, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_FBUF));
 
 	struct v4l2_framebuffer *const p_v4l2_framebuffer =
 		page_end - sizeof(*p_v4l2_framebuffer);
 	ioctl(-1, VIDIOC_S_FBUF, p_v4l2_framebuffer);
-	printf("ioctl(-1, VIDIOC_S_FBUF, {capability=%#x"
+	printf("ioctl(-1, %s, {capability=%#x"
 	       ", flags=%#x, base=%p}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_FBUF),
 	       p_v4l2_framebuffer->capability,
 	       p_v4l2_framebuffer->flags,
 	       p_v4l2_framebuffer->base);
 
 	/* VIDIOC_STREAMON */
 	ioctl(-1, VIDIOC_STREAMON, 0);
-	printf("ioctl(-1, VIDIOC_STREAMON, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_STREAMON));
 
 	int *const p_int = page_end - sizeof(int);
 	ioctl(-1, VIDIOC_STREAMON, p_int);
-	printf("ioctl(-1, VIDIOC_STREAMON, [%#x /* V4L2_BUF_TYPE_??? */])"
-	       " = -1 EBADF (%m)\n", *p_int);
+	printf("ioctl(-1, %s, [%#x" NRAW(" /* V4L2_BUF_TYPE_??? */") "])"
+	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_STREAMON), *p_int);
 
 	/* VIDIOC_STREAMOFF */
 	ioctl(-1, VIDIOC_STREAMOFF, 0);
-	printf("ioctl(-1, VIDIOC_STREAMOFF, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_STREAMOFF));
 
 	ioctl(-1, VIDIOC_STREAMOFF, p_int);
-	printf("ioctl(-1, VIDIOC_STREAMOFF, [%#x /* V4L2_BUF_TYPE_??? */])"
-	       " = -1 EBADF (%m)\n", *p_int);
+	printf("ioctl(-1, %s, [%#x" NRAW(" /* V4L2_BUF_TYPE_??? */") "])"
+	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_STREAMOFF), *p_int);
 
 	/* VIDIOC_G_PARM */
 	ioctl(-1, VIDIOC_G_PARM, 0);
-	printf("ioctl(-1, VIDIOC_G_PARM, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_PARM));
 
 	struct v4l2_streamparm *const p_v4l2_streamparm =
 		page_end - sizeof(*p_v4l2_streamparm);
 	ioctl(-1, VIDIOC_G_PARM, p_v4l2_streamparm);
-	printf("ioctl(-1, VIDIOC_G_PARM, {type=%#x /* V4L2_BUF_TYPE_??? */})"
-	       " = -1 EBADF (%m)\n", p_v4l2_streamparm->type);
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */") "})"
+	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_PARM), p_v4l2_streamparm->type);
 
 	/* VIDIOC_S_PARM */
 	ioctl(-1, VIDIOC_S_PARM, 0);
-	printf("ioctl(-1, VIDIOC_S_PARM, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_PARM));
 
 	ioctl(-1, VIDIOC_S_PARM, p_v4l2_streamparm);
-	printf("ioctl(-1, VIDIOC_S_PARM, {type=%#x /* V4L2_BUF_TYPE_??? */})"
-	       " = -1 EBADF (%m)\n", p_v4l2_streamparm->type);
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */") "})"
+	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_PARM), p_v4l2_streamparm->type);
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct v4l2_streamparm, p_streamparm);
 	p_streamparm->type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
@@ -633,62 +1005,72 @@ main(void)
 	p_streamparm->parm.capture.timeperframe.numerator = 0xdeadbeef;
 	p_streamparm->parm.capture.timeperframe.denominator = 0xbadc0ded;
 	ioctl(-1, VIDIOC_S_PARM, p_streamparm);
-	printf("ioctl(-1, VIDIOC_S_PARM, {type=V4L2_BUF_TYPE_VIDEO_CAPTURE"
-	       ", parm.capture={capability=V4L2_CAP_TIMEPERFRAME"
-	       ", capturemode=V4L2_MODE_HIGHQUALITY, timeperframe=%u/%u"
-	       ", extendedmode=%u, readbuffers=%u}}) = -1 EBADF (%m)\n",
+	printf("ioctl(-1, %s, {type=" XLAT_FMT
+	       ", parm.capture={capability=" XLAT_FMT
+	       ", capturemode=" XLAT_FMT ", timeperframe=%u/%u"
+	       ", extendedmode=%#x, readbuffers=%u}}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_PARM), XLAT_ARGS(V4L2_BUF_TYPE_VIDEO_CAPTURE),
+	       XLAT_ARGS(V4L2_CAP_TIMEPERFRAME), XLAT_ARGS(V4L2_MODE_HIGHQUALITY),
 	       p_streamparm->parm.capture.timeperframe.numerator,
 	       p_streamparm->parm.capture.timeperframe.denominator, -1U, -1U);
 
 	p_streamparm->type = V4L2_BUF_TYPE_VIDEO_OUTPUT;
 	p_streamparm->parm.output.outputmode = 0;
 	ioctl(-1, VIDIOC_S_PARM, p_streamparm);
-	printf("ioctl(-1, VIDIOC_S_PARM, {type=V4L2_BUF_TYPE_VIDEO_OUTPUT"
-	       ", parm.output={capability=V4L2_CAP_TIMEPERFRAME"
+	printf("ioctl(-1, %s, {type=" XLAT_FMT
+	       ", parm.output={capability=" XLAT_FMT
 	       ", outputmode=0, timeperframe=%u/%u"
-	       ", extendedmode=%u, writebuffers=%u}}) = -1 EBADF (%m)\n",
+	       ", extendedmode=%#x, writebuffers=%u}}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_PARM), XLAT_ARGS(V4L2_BUF_TYPE_VIDEO_OUTPUT),
+	       XLAT_ARGS(V4L2_CAP_TIMEPERFRAME),
 	       p_streamparm->parm.output.timeperframe.numerator,
 	       p_streamparm->parm.output.timeperframe.denominator, -1U, -1U);
 
 	/* VIDIOC_G_STD */
 	ioctl(-1, VIDIOC_G_STD, 0);
-	printf("ioctl(-1, VIDIOC_G_STD, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_STD));
 
 	ioctl(-1, VIDIOC_G_STD, page);
-	printf("ioctl(-1, VIDIOC_G_STD, %p) = -1 EBADF (%m)\n", page);
+	printf("ioctl(-1, %s, %p) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_STD), page);
 
 	/* VIDIOC_S_STD */
 	ioctl(-1, VIDIOC_S_STD, 0);
-	printf("ioctl(-1, VIDIOC_S_STD, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_STD));
 
 	long long *const p_longlong = page_end - sizeof(*p_longlong);
 	ioctl(-1, VIDIOC_S_STD, p_longlong);
-	printf("ioctl(-1, VIDIOC_S_STD, [%#llx]) = -1 EBADF (%m)\n",
-	       *p_longlong);
+	printf("ioctl(-1, %s, [%#llx]) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_STD), *p_longlong);
 
 	/* VIDIOC_ENUMSTD */
 	ioctl(-1, VIDIOC_ENUMSTD, 0);
-	printf("ioctl(-1, VIDIOC_ENUMSTD, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUMSTD));
 
 	struct v4l2_standard *const p_v4l2_standard =
 		page_end - sizeof(*p_v4l2_standard);
 	ioctl(-1, VIDIOC_ENUMSTD, p_v4l2_standard);
-	printf("ioctl(-1, VIDIOC_ENUMSTD, {index=%u}) = -1 EBADF (%m)\n",
-	       p_v4l2_standard->index);
+	printf("ioctl(-1, %s, {index=%u}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUMSTD), p_v4l2_standard->index);
 
 	/* VIDIOC_ENUMINPUT */
 	ioctl(-1, VIDIOC_ENUMINPUT, 0);
-	printf("ioctl(-1, VIDIOC_ENUMINPUT, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUMINPUT));
 
 	struct v4l2_input *const p_v4l2_input =
 		page_end - sizeof(*p_v4l2_input);
 	ioctl(-1, VIDIOC_ENUMINPUT, p_v4l2_input);
-	printf("ioctl(-1, VIDIOC_ENUMINPUT, {index=%u}) = -1 EBADF (%m)\n",
-	       p_v4l2_input->index);
+	printf("ioctl(-1, %s, {index=%u}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUMINPUT), p_v4l2_input->index);
 
 	/* VIDIOC_G_CTRL */
 	ioctl(-1, VIDIOC_G_CTRL, 0);
-	printf("ioctl(-1, VIDIOC_G_CTRL, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_CTRL));
 
 	static const struct v4l2_control v4l2_control_vals[] = {
 		{ .id = 0,                    .value = 3141592653U },
@@ -699,55 +1081,59 @@ main(void)
 		{ .id = 0xa40000,             .value = -1 },
 	};
 	static const char *id_strs[] = {
-		"0 /* V4L2_CID_??? */",
-		"0x97abcd /* V4L2_CID_??? */",
-		"V4L2_CTRL_CLASS_USER+0",
-		"V4L2_CID_MPEG_VIDEO_H264_CPB_SIZE",
-		"V4L2_CTRL_CLASS_DETECT+0x1234",
-		"0xa40000 /* V4L2_CID_??? */",
+		"0" NRAW(" /* V4L2_CID_??? */"),
+		"0x97abcd" NRAW(" /* V4L2_CID_??? */"),
+		XLAT_KNOWN(0x980000, "V4L2_CTRL_CLASS_USER+0"),
+		XLAT_KNOWN(0x990a64, "V4L2_CID_MPEG_VIDEO_H264_CPB_SIZE"),
+		XLAT_KNOWN(0xa31234, "V4L2_CTRL_CLASS_DETECT+0x1234"),
+		"0xa40000" NRAW(" /* V4L2_CID_??? */"),
 	};
 
 	struct v4l2_control *const p_v4l2_control =
 		page_end - sizeof(*p_v4l2_control);
 	ioctl(-1, VIDIOC_G_CTRL, p_v4l2_control);
-	printf("ioctl(-1, VIDIOC_G_CTRL, {id=%#x /* V4L2_CID_??? */})"
-	       " = -1 EBADF (%m)\n", p_v4l2_control->id);
+	printf("ioctl(-1, %s, {id=%#x" NRAW(" /* V4L2_CID_??? */")
+	       "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_CTRL), p_v4l2_control->id);
 
 	/* VIDIOC_S_CTRL */
 	ioctl(-1, VIDIOC_S_CTRL, 0);
-	printf("ioctl(-1, VIDIOC_S_CTRL, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_CTRL));
 
 	ioctl(-1, VIDIOC_S_CTRL, p_v4l2_control);
-	printf("ioctl(-1, VIDIOC_S_CTRL, {id=%#x /* V4L2_CID_??? */"
+	printf("ioctl(-1, %s, {id=%#x" NRAW(" /* V4L2_CID_??? */")
 	       ", value=%d}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_CTRL),
 	       p_v4l2_control->id, p_v4l2_control->value);
 
 	for (size_t i = 0; i < ARRAY_SIZE(id_strs); i++) {
 		struct v4l2_control v4l2_c = v4l2_control_vals[i];
 
 		ioctl(-1, VIDIOC_G_CTRL, &v4l2_c);
-		printf("ioctl(-1, VIDIOC_G_CTRL, {id=%s}) = -1 EBADF (%m)\n",
-		       id_strs[i]);
+		printf("ioctl(-1, %s, {id=%s}) = -1 EBADF (%m)\n",
+		       XLAT_STR(VIDIOC_G_CTRL), id_strs[i]);
 
 		ioctl(-1, VIDIOC_S_CTRL, &v4l2_c);
-		printf("ioctl(-1, VIDIOC_S_CTRL, {id=%s, value=%d})"
-		       " = -1 EBADF (%m)\n",
-		       id_strs[i], v4l2_c.value);
+		printf("ioctl(-1, %s, {id=%s, value=%d}) = -1 EBADF (%m)\n",
+		       XLAT_STR(VIDIOC_S_CTRL), id_strs[i], v4l2_c.value);
 	}
 
 	/* VIDIOC_G_TUNER */
 	ioctl(-1, VIDIOC_G_TUNER, 0);
-	printf("ioctl(-1, VIDIOC_G_TUNER, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_TUNER));
 
 	struct v4l2_tuner *const p_v4l2_tuner =
 		page_end - sizeof(*p_v4l2_tuner);
 	ioctl(-1, VIDIOC_G_TUNER, p_v4l2_tuner);
-	printf("ioctl(-1, VIDIOC_G_TUNER, {index=%u})"
-	       " = -1 EBADF (%m)\n", p_v4l2_tuner->index);
+	printf("ioctl(-1, %s, {index=%u}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_TUNER), p_v4l2_tuner->index);
 
 	/* VIDIOC_S_TUNER */
 	ioctl(-1, VIDIOC_S_TUNER, 0);
-	printf("ioctl(-1, VIDIOC_S_TUNER, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_TUNER));
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct v4l2_tuner, p_tuner);
 	p_tuner->index = 0x4fb6df39;
@@ -761,79 +1147,98 @@ main(void)
 	p_tuner->signal = 0x10bf92c8;
 	p_tuner->afc = 0x3bf7e18b;
 	ioctl(-1, VIDIOC_S_TUNER, p_tuner);
-	printf("ioctl(-1, VIDIOC_S_TUNER, {index=%u"
-	       ", name=\"cum tacent clamant\""
-	       ", type=V4L2_TUNER_RADIO, capability=V4L2_TUNER_CAP_LOW"
+	printf("ioctl(-1, %s, {index=%u, name=\"cum tacent clamant\""
+	       ", type=" XLAT_FMT ", capability=" XLAT_FMT
 	       ", rangelow=%u, rangehigh=%u"
-	       ", rxsubchans=V4L2_TUNER_SUB_MONO"
-	       ", audmode=V4L2_TUNER_MODE_MONO, signal=%d, afc=%d"
-	       "}) = -1 EBADF (%m)\n",
-	       p_tuner->index, p_tuner->rangelow,
-	       p_tuner->rangehigh, p_tuner->signal, p_tuner->afc);
+	       ", rxsubchans=" XLAT_FMT ", audmode=" XLAT_FMT
+	       ", signal=%d, afc=%d}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_TUNER), p_tuner->index,
+	       XLAT_ARGS(V4L2_TUNER_RADIO), XLAT_ARGS(V4L2_TUNER_CAP_LOW),
+	       p_tuner->rangelow, p_tuner->rangehigh,
+	       XLAT_ARGS(V4L2_TUNER_SUB_MONO), XLAT_ARGS(V4L2_TUNER_MODE_MONO),
+	       p_tuner->signal, p_tuner->afc);
 
 	/* VIDIOC_QUERYCTRL */
 	ioctl(-1, VIDIOC_QUERYCTRL, 0);
-	printf("ioctl(-1, VIDIOC_QUERYCTRL, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QUERYCTRL));
 
 	struct v4l2_queryctrl *const p_v4l2_queryctrl =
 		page_end - sizeof(*p_v4l2_queryctrl);
 	ioctl(-1, VIDIOC_QUERYCTRL, p_v4l2_queryctrl);
-#ifdef V4L2_CTRL_FLAG_NEXT_CTRL
-	printf("ioctl(-1, VIDIOC_QUERYCTRL, {id=V4L2_CTRL_FLAG_NEXT_CTRL"
-	       "|%#x /* V4L2_CID_??? */}) = -1 EBADF (%m)\n",
-	       p_v4l2_queryctrl->id & ~V4L2_CTRL_FLAG_NEXT_CTRL);
+	printf("ioctl(-1, %s, {id="
+#if XLAT_RAW
+	      "%#x"
+#else
+	       XLAT_FMT "|%#x /* V4L2_CID_??? */"
+#endif
+	       "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QUERYCTRL),
+#if XLAT_RAW
+	       p_v4l2_queryctrl->id
 #else
-	printf("ioctl(-1, VIDIOC_QUERYCTRL, {id=%#x /* V4L2_CID_??? */})"
-	       " = -1 EBADF (%m)\n", p_v4l2_queryctrl->id);
+	       XLAT_ARGS(V4L2_CTRL_FLAG_NEXT_CTRL),
+	       p_v4l2_queryctrl->id & ~V4L2_CTRL_FLAG_NEXT_CTRL
 #endif
+	       );
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct v4l2_queryctrl, p_queryctrl);
 	p_queryctrl->id = V4L2_CID_SATURATION;
 	ioctl(-1, VIDIOC_QUERYCTRL, p_queryctrl);
-	printf("ioctl(-1, VIDIOC_QUERYCTRL, {id=V4L2_CID_SATURATION})"
-	       " = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {id=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QUERYCTRL), XLAT_ARGS(V4L2_CID_SATURATION));
 
 	/* VIDIOC_G_INPUT */
 	ioctl(-1, VIDIOC_G_INPUT, 0);
-	printf("ioctl(-1, VIDIOC_G_INPUT, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_INPUT));
 
 	ioctl(-1, VIDIOC_G_INPUT, page);
-	printf("ioctl(-1, VIDIOC_G_INPUT, %p) = -1 EBADF (%m)\n", page);
+	printf("ioctl(-1, %s, %p) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_INPUT), page);
 
 	/* VIDIOC_S_INPUT */
 	ioctl(-1, VIDIOC_S_INPUT, 0);
-	printf("ioctl(-1, VIDIOC_S_INPUT, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_INPUT));
 
 	ioctl(-1, VIDIOC_S_INPUT, p_int);
-	printf("ioctl(-1, VIDIOC_S_INPUT, [%u]) = -1 EBADF (%m)\n", *p_int);
+	printf("ioctl(-1, %s, [%u]) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_INPUT), *p_int);
 
 	/* VIDIOC_CROPCAP */
 	ioctl(-1, VIDIOC_CROPCAP, 0);
-	printf("ioctl(-1, VIDIOC_CROPCAP, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_CROPCAP));
 
 	struct v4l2_cropcap *const p_v4l2_cropcap =
 		page_end - sizeof(*p_v4l2_cropcap);
 	ioctl(-1, VIDIOC_CROPCAP, p_v4l2_cropcap);
-	printf("ioctl(-1, VIDIOC_CROPCAP, {type=%#x /* V4L2_BUF_TYPE_??? */})"
-	       " = -1 EBADF (%m)\n", p_v4l2_cropcap->type);
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */") "})"
+	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_CROPCAP), p_v4l2_cropcap->type);
 
 	/* VIDIOC_G_CROP */
 	ioctl(-1, VIDIOC_G_CROP, 0);
-	printf("ioctl(-1, VIDIOC_G_CROP, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_CROP));
 
 	struct v4l2_crop *const p_v4l2_crop =
 		page_end - sizeof(*p_v4l2_crop);
 	ioctl(-1, VIDIOC_G_CROP, p_v4l2_crop);
-	printf("ioctl(-1, VIDIOC_G_CROP, {type=%#x /* V4L2_BUF_TYPE_??? */})"
-	       " = -1 EBADF (%m)\n", p_v4l2_crop->type);
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */") "})"
+	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_CROP), p_v4l2_crop->type);
 
 	/* VIDIOC_S_CROP */
 	ioctl(-1, VIDIOC_S_CROP, 0);
-	printf("ioctl(-1, VIDIOC_S_CROP, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_CROP));
 
 	ioctl(-1, VIDIOC_S_CROP, p_v4l2_crop);
-	printf("ioctl(-1, VIDIOC_S_CROP, {type=%#x /* V4L2_BUF_TYPE_??? */"
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */")
 	       ", c={left=%d, top=%d, width=%u, height=%u}}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_CROP),
 	       p_v4l2_crop->type,
 	       p_v4l2_crop->c.left,
 	       p_v4l2_crop->c.top,
@@ -843,36 +1248,42 @@ main(void)
 #ifdef VIDIOC_S_EXT_CTRLS
 	/* VIDIOC_S_EXT_CTRLS */
 	ioctl(-1, VIDIOC_S_EXT_CTRLS, 0);
-	printf("ioctl(-1, VIDIOC_S_EXT_CTRLS, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_EXT_CTRLS));
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct v4l2_ext_controls, p_ext_controls);
 	p_ext_controls->ctrl_class = V4L2_CTRL_CLASS_USER;
 	p_ext_controls->count = 0;
 	p_ext_controls->controls = (void *) -2UL;
 	ioctl(-1, VIDIOC_S_EXT_CTRLS, p_ext_controls);
-	printf("ioctl(-1, VIDIOC_S_EXT_CTRLS, {ctrl_class=V4L2_CTRL_CLASS_USER"
-	       ", count=%u}) = -1 EBADF (%m)\n", p_ext_controls->count);
+	printf("ioctl(-1, %s, {ctrl_class=" XLAT_FMT ", count=%u})"
+	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_EXT_CTRLS), XLAT_ARGS(V4L2_CTRL_CLASS_USER),
+	       p_ext_controls->count);
 
 	p_ext_controls->ctrl_class = 0x00a30000;
 	p_ext_controls->count = magic;
 	ioctl(-1, VIDIOC_S_EXT_CTRLS, p_ext_controls);
-	printf("ioctl(-1, VIDIOC_S_EXT_CTRLS, {ctrl_class=V4L2_CTRL_CLASS_DETECT"
+	printf("ioctl(-1, %s, {ctrl_class=" XLAT_FMT
 	       ", count=%u, controls=%p}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_EXT_CTRLS), XLAT_ARGS(V4L2_CTRL_CLASS_DETECT),
 	       p_ext_controls->count, p_ext_controls->controls);
 
 	p_ext_controls->ctrl_class = 0x00a40000;
 	p_ext_controls->count = magic;
 	ioctl(-1, VIDIOC_S_EXT_CTRLS, p_ext_controls);
-	printf("ioctl(-1, VIDIOC_S_EXT_CTRLS"
-	       ", {ctrl_class=0xa40000 /* V4L2_CTRL_CLASS_??? */"
+	printf("ioctl(-1, %s"
+	       ", {ctrl_class=0xa40000" NRAW(" /* V4L2_CTRL_CLASS_??? */")
 	       ", count=%u, controls=%p}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_EXT_CTRLS),
 	       p_ext_controls->count, p_ext_controls->controls);
 
 	p_ext_controls->ctrl_class = V4L2_CTRL_CLASS_MPEG;
 	p_ext_controls->count = magic;
 	ioctl(-1, VIDIOC_S_EXT_CTRLS, p_ext_controls);
-	printf("ioctl(-1, VIDIOC_S_EXT_CTRLS, {ctrl_class=V4L2_CTRL_CLASS_MPEG"
+	printf("ioctl(-1, %s, {ctrl_class=" XLAT_FMT
 	       ", count=%u, controls=%p}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_EXT_CTRLS), XLAT_ARGS(V4L2_CTRL_CLASS_MPEG),
 	       p_ext_controls->count, p_ext_controls->controls);
 
 # if HAVE_DECL_V4L2_CTRL_TYPE_STRING
@@ -888,107 +1299,132 @@ main(void)
 		tail_alloc(p_ext_controls->controls[1].size);
 
 	ioctl(-1, VIDIOC_S_EXT_CTRLS, p_ext_controls);
-	printf("ioctl(-1, VIDIOC_S_EXT_CTRLS"
-	       ", {ctrl_class=V4L2_CTRL_CLASS_MPEG, count=%u, controls="
-	       "[{id=V4L2_CID_BRIGHTNESS, size=0, value=%d, value64=%lld}"
-	       ", {id=V4L2_CID_CONTRAST, size=2, string=\"\\377\\377\"}"
-	       "] => controls="
-	       "[{id=V4L2_CID_BRIGHTNESS, size=0, value=%d, value64=%lld}"
-	       ", {id=V4L2_CID_CONTRAST, size=2, string=\"\\377\\377\"}"
+	printf("ioctl(-1, %s, {ctrl_class=" XLAT_FMT ", count=%u, controls="
+	       "[{id=" XLAT_FMT ", size=0, value=%d, value64=%lld}"
+	       ", {id=" XLAT_FMT ", size=2, string=\"\\377\\377\"}"
+	       "]} => {controls="
+	       "[{id=" XLAT_FMT ", size=0, value=%d, value64=%lld}"
+	       ", {id=" XLAT_FMT ", size=2, string=\"\\377\\377\"}"
 	       "], error_idx=%u}) = -1 EBADF (%m)\n",
-	       p_ext_controls->count,
+	       XLAT_STR(VIDIOC_S_EXT_CTRLS), XLAT_ARGS(V4L2_CTRL_CLASS_MPEG),
+	       p_ext_controls->count, XLAT_ARGS(V4L2_CID_BRIGHTNESS),
 	       p_ext_controls->controls[0].value,
 	       (long long) p_ext_controls->controls[0].value64,
+	       XLAT_ARGS(V4L2_CID_CONTRAST), XLAT_ARGS(V4L2_CID_BRIGHTNESS),
 	       p_ext_controls->controls[0].value,
 	       (long long) p_ext_controls->controls[0].value64,
-	       p_ext_controls->error_idx);
+	       XLAT_ARGS(V4L2_CID_CONTRAST), p_ext_controls->error_idx);
 
 	++p_ext_controls->count;
 	ioctl(-1, VIDIOC_S_EXT_CTRLS, p_ext_controls);
-	printf("ioctl(-1, VIDIOC_S_EXT_CTRLS"
-	       ", {ctrl_class=V4L2_CTRL_CLASS_MPEG, count=%u, controls="
-	       "[{id=V4L2_CID_BRIGHTNESS, size=0, value=%d, value64=%lld}"
-	       ", {id=V4L2_CID_CONTRAST, size=2, string=\"\\377\\377\"}"
+	printf("ioctl(-1, %s, {ctrl_class=" XLAT_FMT ", count=%u, controls="
+	       "[{id=" XLAT_FMT ", size=0, value=%d, value64=%lld}"
+	       ", {id=" XLAT_FMT ", size=2, string=\"\\377\\377\"}"
 	       ", ... /* %p */]}) = -1 EBADF (%m)\n",
-	       p_ext_controls->count,
+	       XLAT_STR(VIDIOC_S_EXT_CTRLS), XLAT_ARGS(V4L2_CTRL_CLASS_MPEG),
+	       p_ext_controls->count, XLAT_ARGS(V4L2_CID_BRIGHTNESS),
 	       p_ext_controls->controls[0].value,
 	       (long long) p_ext_controls->controls[0].value64,
-	       p_ext_controls->controls + 2);
+	       XLAT_ARGS(V4L2_CID_CONTRAST), p_ext_controls->controls + 2);
 # endif /* HAVE_DECL_V4L2_CTRL_TYPE_STRING */
 
 	/* VIDIOC_TRY_EXT_CTRLS */
 	ioctl(-1, VIDIOC_TRY_EXT_CTRLS, 0);
-	printf("ioctl(-1, VIDIOC_TRY_EXT_CTRLS, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_TRY_EXT_CTRLS));
 
 	p_ext_controls->ctrl_class = V4L2_CTRL_CLASS_USER;
 	p_ext_controls->count = magic;
 	p_ext_controls->controls = (void *) -2UL;
 	ioctl(-1, VIDIOC_TRY_EXT_CTRLS, p_ext_controls);
-	printf("ioctl(-1, VIDIOC_TRY_EXT_CTRLS"
-	       ", {ctrl_class=V4L2_CTRL_CLASS_USER, count=%u, controls=%p})"
+	printf("ioctl(-1, %s, {ctrl_class=" XLAT_FMT ", count=%u, controls=%p})"
 	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_TRY_EXT_CTRLS), XLAT_ARGS(V4L2_CTRL_CLASS_USER),
 	       p_ext_controls->count, p_ext_controls->controls);
 
 	/* VIDIOC_G_EXT_CTRLS */
 	ioctl(-1, VIDIOC_G_EXT_CTRLS, 0);
-	printf("ioctl(-1, VIDIOC_G_EXT_CTRLS, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_EXT_CTRLS));
 
 	ioctl(-1, VIDIOC_G_EXT_CTRLS, p_ext_controls);
-	printf("ioctl(-1, VIDIOC_G_EXT_CTRLS"
-	       ", {ctrl_class=V4L2_CTRL_CLASS_USER, count=%u, controls=%p"
+	printf("ioctl(-1, %s, {ctrl_class=" XLAT_FMT ", count=%u, controls=%p"
 	       ", error_idx=%u}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_EXT_CTRLS), XLAT_ARGS(V4L2_CTRL_CLASS_USER),
 	       p_ext_controls->count, p_ext_controls->controls,
 	       p_ext_controls->error_idx);
 #endif /* VIDIOC_S_EXT_CTRLS */
 
-#ifdef VIDIOC_ENUM_FRAMESIZES
+#ifdef HAVE_STRUCT_V4L2_FRMSIZEENUM
 	ioctl(-1, VIDIOC_ENUM_FRAMESIZES, 0);
-	printf("ioctl(-1, VIDIOC_ENUM_FRAMESIZES, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMESIZES));
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct v4l2_frmsizeenum, p_frmsizeenum);
 	p_frmsizeenum->index = magic;
 	p_frmsizeenum->pixel_format = fourcc(cc[0], cc[1], cc[2], cc[3]);
 
 	ioctl(-1, VIDIOC_ENUM_FRAMESIZES, p_frmsizeenum);
-	printf("ioctl(-1, VIDIOC_ENUM_FRAMESIZES, {index=%u"
-	       ", pixel_format=v4l2_fourcc('%c', '\\%c', '\\%c', '\\x%x')})"
-	       " = -1 EBADF (%m)\n", p_frmsizeenum->index,
-	       cc[0], cc[1], cc[2], cc[3]);
-#endif /* VIDIOC_ENUM_FRAMESIZES */
+	printf("ioctl(-1, %s, {index=%u, pixel_format="
+# if XLAT_RAW
+	       "0x%hhx%hhx%hhx%hhx"
+# else /* !XLAT_RAW */
+	       "v4l2_fourcc('%c', '\\%c', '\\%c', '\\x%x')"
+# endif /* XLAT_RAW */
+	       "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMESIZES), p_frmsizeenum->index,
+# if XLAT_RAW
+	       cc[3], cc[2], cc[1], cc[0]
+# else /* !XLAT_RAW */
+	       cc[0], cc[1], cc[2], cc[3]
+# endif /* XLAT_RAW */
+	       );
+#endif /* HAVE_STRUCT_V4L2_FRMSIZEENUM */
 
-#ifdef VIDIOC_ENUM_FRAMEINTERVALS
+#ifdef HAVE_STRUCT_V4L2_FRMIVALENUM
 	ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, 0);
-	printf("ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMEINTERVALS));
 
 	struct v4l2_frmivalenum *const p_v4l2_frmivalenum =
 		page_end - sizeof(*p_v4l2_frmivalenum);
 	ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, p_v4l2_frmivalenum);
-	printf("ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, {index=%u"
-	       ", pixel_format=v4l2_fourcc('\\x%x', '\\x%x', '\\x%x', '\\x%x')"
+	printf("ioctl(-1, %s, {index=%u, pixel_format="
+# if XLAT_RAW
+	       "%#x"
+# else /* !XLAT_RAW */
+	       "v4l2_fourcc('\\x%x', '\\x%x', '\\x%x', '\\x%x')"
+# endif /* XLAT_RAW */
 	       ", width=%u, height=%u}) = -1 EBADF (%m)\n",
-	       p_v4l2_frmivalenum->index,
+	       XLAT_STR(VIDIOC_ENUM_FRAMEINTERVALS), p_v4l2_frmivalenum->index,
+# if XLAT_RAW
+	       p_v4l2_frmivalenum->pixel_format,
+# else /* !XLAT_RAW */
 	       cc0(p_v4l2_frmivalenum->pixel_format),
 	       cc1(p_v4l2_frmivalenum->pixel_format),
 	       cc2(p_v4l2_frmivalenum->pixel_format),
 	       cc3(p_v4l2_frmivalenum->pixel_format),
+# endif /* XLAT_RAW */
 	       p_v4l2_frmivalenum->width,
 	       p_v4l2_frmivalenum->height);
-#endif /* VIDIOC_ENUM_FRAMEINTERVALS */
+#endif /* HAVE_STRUCT_V4L2_FRMIVALENUM */
 
-#ifdef VIDIOC_CREATE_BUFS
+#ifdef HAVE_STRUCT_V4L2_CREATE_BUFFERS
 	ioctl(-1, VIDIOC_CREATE_BUFS, 0);
-	printf("ioctl(-1, VIDIOC_CREATE_BUFS, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_CREATE_BUFS));
 
 	struct v4l2_create_buffers *const p_v4l2_create_buffers =
 		page_end - sizeof(*p_v4l2_create_buffers);
 	ioctl(-1, VIDIOC_CREATE_BUFS, p_v4l2_create_buffers);
-	printf("ioctl(-1, VIDIOC_CREATE_BUFS, {count=%u, memory=%#x"
-	       " /* V4L2_MEMORY_??? */, format={type=%#x"
-	       " /* V4L2_BUF_TYPE_??? */}}) = -1 EBADF (%m)\n",
+	printf("ioctl(-1, %s, {count=%u, memory=%#x"
+	       NRAW(" /* V4L2_MEMORY_??? */") ", format={type=%#x"
+	       NRAW(" /* V4L2_BUF_TYPE_??? */") "}}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_CREATE_BUFS),
 	       p_v4l2_create_buffers->count,
 	       p_v4l2_create_buffers->memory,
 	       p_v4l2_create_buffers->format.type);
-#endif /* VIDIOC_CREATE_BUFS */
+#endif /* HAVE_STRUCT_V4L2_CREATE_BUFFERS */
 
 	puts("+++ exited with 0 +++");
 	return 0;
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-success.c 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success.c
--- 5.5-3/tests-m32/ioctl_v4l2-success.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success.c	2020-09-06 08:00:00.000000000 +0000
@@ -0,0 +1,1473 @@
+/*
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+
+#include <stdint.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <sys/ioctl.h>
+#include "kernel_v4l2_types.h"
+
+#define XLAT_MACROS_ONLY
+# include "xlat/v4l2_ioctl_cmds.h"
+#undef XLAT_MACROS_ONLY
+
+static bool
+fill_fmt(struct v4l2_format *f)
+{
+	static struct v4l2_clip *clips;
+
+	switch (f->type) {
+	case V4L2_BUF_TYPE_VIDEO_CAPTURE:
+	case V4L2_BUF_TYPE_VIDEO_OUTPUT:
+		f->fmt.pix.width        = 0xdeadc0de;
+		f->fmt.pix.height       = 0xfeedbeef;
+		f->fmt.pix.pixelformat  = 0xb5315258; /* forurcc_be("XR15") */
+		f->fmt.pix.field = f->type == V4L2_BUF_TYPE_VIDEO_CAPTURE
+			? V4L2_FIELD_ALTERNATE : 0xdec0ded1;
+		f->fmt.pix.bytesperline = 0xbadc0ded;
+		f->fmt.pix.sizeimage    = 0xface1e55;
+		f->fmt.pix.colorspace   = V4L2_COLORSPACE_REC709;
+		break;
+
+	case V4L2_BUF_TYPE_VIDEO_OVERLAY:
+#if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY
+	case V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY:
+#endif
+		f->fmt.win.w.left    = 0xa0a1a2a3;
+		f->fmt.win.w.top     = 0xb0b1b2b3;
+		f->fmt.win.w.width   = 0xc0c1c2c3;
+		f->fmt.win.w.height  = 0xd0d1d2d3;
+		f->fmt.win.field     = f->type == V4L2_BUF_TYPE_VIDEO_OVERLAY
+			? V4L2_FIELD_ANY : 10;
+		f->fmt.win.chromakey = 0xbeefface;
+
+		if (!clips)
+			clips = tail_alloc(sizeof(*clips) * 3);
+		f->fmt.win.clips = clips;
+
+		f->fmt.win.clips[0].c.left   = 0xa4a5a6a7;
+		f->fmt.win.clips[0].c.top    = 0xb4b5b6b7;
+		f->fmt.win.clips[0].c.width  = 0xc4c5c6c7;
+		f->fmt.win.clips[0].c.height = 0xd4d5d6d7;
+		f->fmt.win.clips[0].next     = clips;
+
+		f->fmt.win.clips[1].c.left   = 0xa8a9aaab;
+		f->fmt.win.clips[1].c.top    = 0xb8b9babb;
+		f->fmt.win.clips[1].c.width  = 0xc8c9cacb;
+		f->fmt.win.clips[1].c.height = 0xd8d9dadb;
+
+		f->fmt.win.clips[2].c.left   = 0xacadaeaf;
+		f->fmt.win.clips[2].c.top    = 0xbcbdbebf;
+		f->fmt.win.clips[2].c.width  = 0xcccdcecf;
+		f->fmt.win.clips[2].c.height = 0xdcdddedf;
+		f->fmt.win.clips[2].next     = clips + 1;
+
+		f->fmt.win.clipcount = f->type == V4L2_BUF_TYPE_VIDEO_OVERLAY
+			? 4 : 0;
+		f->fmt.win.bitmap    = f->type == V4L2_BUF_TYPE_VIDEO_OVERLAY
+			? NULL : clips;
+		break;
+
+	case V4L2_BUF_TYPE_VBI_CAPTURE:
+	case V4L2_BUF_TYPE_VBI_OUTPUT:
+		f->fmt.vbi.sampling_rate    = 0xdecaffed;
+		f->fmt.vbi.offset           = 0xcafefeed;
+		f->fmt.vbi.samples_per_line = 0xbeefaced;
+		f->fmt.vbi.sample_format    = V4L2_PIX_FMT_RGB555X;
+
+		f->fmt.vbi.start[0] = 0xdec0ded0;
+		f->fmt.vbi.start[1] = 0xdec0ded1;
+		f->fmt.vbi.count[0] = 0xacceded2;
+		f->fmt.vbi.count[1] = 0xacceded3;
+
+		f->fmt.vbi.flags = f->type == V4L2_BUF_TYPE_VBI_CAPTURE
+			? 0x3 : 0x1ce50d1c;
+		break;
+
+#if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE
+	case V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE:
+	case V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE:
+		f->fmt.pix_mp.width        = 0xdeaffade;
+		f->fmt.pix_mp.height       = 0xfadeb1a5;
+		f->fmt.pix_mp.pixelformat  = 0x36314454;
+		f->fmt.pix_mp.field        = V4L2_FIELD_NONE;
+		f->fmt.pix_mp.colorspace   = 13;
+
+		for (size_t i = 0; i < VIDEO_MAX_PLANES; i++) {
+			f->fmt.pix_mp.plane_fmt[i].sizeimage = 0xd0decad0 ^ i;
+			if (sizeof(f->fmt.pix_mp.plane_fmt[i].bytesperline) ==
+			    sizeof(uint32_t)) {
+				f->fmt.pix_mp.plane_fmt[i].bytesperline
+					= 0xd0decad1 ^ i;
+			} else {
+# if WORDS_BIGENDIAN
+				f->fmt.pix_mp.plane_fmt[i].bytesperline
+					= 0xd0de;
+				f->fmt.pix_mp.plane_fmt[i].reserved[0]
+					= 0xcad1 ^ i;
+# else
+				f->fmt.pix_mp.plane_fmt[i].bytesperline
+					= 0xcad1 ^ i;
+				f->fmt.pix_mp.plane_fmt[i].reserved[0]
+					= 0xd0de;
+# endif
+			}
+		}
+
+		f->fmt.pix_mp.num_planes   = f->type ==
+			V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE ? 0xd5 : 0;
+		break;
+#endif
+#if HAVE_DECL_V4L2_BUF_TYPE_SLICED_VBI_CAPTURE
+	case V4L2_BUF_TYPE_SLICED_VBI_CAPTURE:
+	case V4L2_BUF_TYPE_SLICED_VBI_OUTPUT:
+		f->fmt.sliced.service_set = 0xfeed;
+		for (size_t i = 0; i < 2; i++) {
+			for (size_t j = 0; j < 24; j++) {
+				f->fmt.sliced.service_lines[i][j] =
+					0xdead ^ (i << 8) ^ j;
+			}
+		}
+		f->fmt.sliced.io_size = 0xdefaceed;
+		break;
+#endif
+#if HAVE_DECL_V4L2_BUF_TYPE_SDR_CAPTURE
+	case V4L2_BUF_TYPE_SDR_CAPTURE:
+# if HAVE_DECL_V4L2_BUF_TYPE_SDR_OUTPUT
+	case V4L2_BUF_TYPE_SDR_OUTPUT:
+# endif
+		f->fmt.sdr.pixelformat = V4L2_SDR_FMT_CU8;
+# ifdef HAVE_STRUCT_V4L2_SDR_FORMAT_BUFFERSIZE
+		if (sizeof(f->fmt.sdr.buffersize == sizeof(uint32_t)))
+			f->fmt.sdr.buffersize = 0xbadc0ded;
+		else
+			((uint32_t *) &f->fmt.sdr)[1] = 0xbadc0ded;
+# else
+		((uint32_t *) &f->fmt.sdr)[1] = 0xbadc0ded;
+# endif
+		break;
+#endif
+	default:
+		return false;
+	}
+
+	return true;
+}
+
+static void
+print_fmt(const char *pfx, struct v4l2_format *f)
+{
+	switch (f->type) {
+	case V4L2_BUF_TYPE_VIDEO_CAPTURE:
+	case V4L2_BUF_TYPE_VIDEO_OUTPUT:
+		printf("%sfmt.pix={width=3735929054, height=4276993775"
+		       ", pixelformat=" RAW("0xb5315258")
+		       NRAW("v4l2_fourcc('X', 'R', '1', '\\xb5')"
+		            " /* V4L2_PIX_FMT_XRGB555X */")
+		       ", field=%s, bytesperline=3134983661"
+		       ", sizeimage=4207812181, colorspace="
+		       XLAT_KNOWN(0x3, "V4L2_COLORSPACE_REC709") "}",
+		       pfx, f->type == V4L2_BUF_TYPE_VIDEO_CAPTURE
+			? XLAT_STR(V4L2_FIELD_ALTERNATE)
+			: XLAT_UNKNOWN(0xdec0ded1, "V4L2_FIELD_???"));
+		break;
+
+	case V4L2_BUF_TYPE_VIDEO_OVERLAY:
+#if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY
+	case V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY:
+#endif
+		printf("%sfmt.win={left=-1600019805, top=-1330531661"
+		       ", width=3233923779, height=3503411923, field=%s"
+		       ", chromakey=0xbeefface, clips=[",
+		       pfx, f->type == V4L2_BUF_TYPE_VIDEO_OVERLAY
+			? XLAT_STR(V4L2_FIELD_ANY)
+			: XLAT_UNKNOWN(0xa, "V4L2_FIELD_???"));
+		if (f->type == V4L2_BUF_TYPE_VIDEO_OVERLAY) {
+			printf("{left=-1532647769, top=-1263159625"
+			       ", width=3301295815, height=3570783959}, "
+			       "{left=-1465275733, top=-1195787589"
+			       ", width=3368667851, height=3638155995}, "
+			       "{left=-1397903697, top=-1128415553"
+			       ", width=3436039887, height=3705528031}, "
+			       "... /* %p */", f->fmt.win.clips + 3);
+		}
+		printf("], clipcount=%d, bitmap=",
+		       f->type == V4L2_BUF_TYPE_VIDEO_OVERLAY ? 4 : 0);
+
+		if (f->type == V4L2_BUF_TYPE_VIDEO_OVERLAY)
+			printf("NULL");
+		else
+			printf("%p", f->fmt.win.bitmap);
+
+#ifdef HAVE_STRUCT_V4L2_WINDOW_GLOBAL_ALPHA
+		printf(", global_alpha=%#hhx}", f->fmt.win.global_alpha);
+#else
+		struct win_ga {
+			struct v4l2_rect w;
+			uint32_t field;
+			uint32_t chromakey;
+			struct v4l2_clip *clips;
+			uint32_t clipcount;
+			void *bitmap;
+			uint8_t global_alpha;
+		};
+		printf(", global_alpha=%#hhx}",
+		       ((struct win_ga *) &f->fmt.win)->global_alpha);
+#endif
+		break;
+
+	case V4L2_BUF_TYPE_VBI_CAPTURE:
+	case V4L2_BUF_TYPE_VBI_OUTPUT:
+		printf("%sfmt.vbi={sampling_rate=3737845741, offset=3405709037"
+		       ", samples_per_line=3203378413, sample_format="
+		       RAW("0x51424752") NRAW("v4l2_fourcc('R', 'G', 'B', 'Q')"
+		       " /* V4L2_PIX_FMT_RGB555X */")
+		       ", start=[-557785392, -557785391]"
+		       ", count=[2899238610, 2899238611], flags=%s}",
+		       pfx, f->type == V4L2_BUF_TYPE_VBI_CAPTURE
+			? XLAT_KNOWN(0x3, "V4L2_VBI_UNSYNC|V4L2_VBI_INTERLACED")
+			: XLAT_UNKNOWN(0x1ce50d1c, "V4L2_VBI_???"));
+		break;
+
+#if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE
+	case V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE:
+	case V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE:
+		printf("%sfmt.pix_mp={width=3736074974, height=4208898469"
+		       ", pixelformat=" RAW("0x36314454")
+		       NRAW("v4l2_fourcc('T', 'D', '1', '6')")
+		       ", field=%s, colorspace=0xd"
+		       NRAW(" /* V4L2_COLORSPACE_??? */") ", plane_fmt=[",
+		       pfx, XLAT_STR(V4L2_FIELD_NONE));
+		if (f->type == V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE) {
+			printf("{sizeimage=3504261840, bytesperline=3504261841}"
+			", "
+			       "{sizeimage=3504261841, bytesperline=3504261840}"
+			       ", "
+			       "{sizeimage=3504261842, bytesperline=3504261843}"
+			       ", "
+			       "{sizeimage=3504261843, bytesperline=3504261842}"
+			       ", "
+			       "{sizeimage=3504261844, bytesperline=3504261845}"
+			       ", "
+			       "{sizeimage=3504261845, bytesperline=3504261844}"
+			       ", "
+			       "{sizeimage=3504261846, bytesperline=3504261847}"
+			       ", "
+			       "{sizeimage=3504261847, bytesperline=3504261846}"
+			       "], num_planes=213}");
+		} else {
+			printf("], num_planes=0}");
+		}
+		break;
+#endif
+#if HAVE_DECL_V4L2_BUF_TYPE_SLICED_VBI_CAPTURE
+	case V4L2_BUF_TYPE_SLICED_VBI_CAPTURE:
+	case V4L2_BUF_TYPE_SLICED_VBI_OUTPUT:
+		printf("%sfmt.sliced={service_set="
+		       XLAT_UNKNOWN(0xfeed, "V4L2_SLICED_???")
+		       ", io_size=3740978925, service_lines=[[0xdead, 0xdeac"
+		       ", 0xdeaf, 0xdeae, 0xdea9, 0xdea8, 0xdeab, 0xdeaa"
+		       ", 0xdea5, 0xdea4, 0xdea7, 0xdea6, 0xdea1, 0xdea0"
+		       ", 0xdea3, 0xdea2, 0xdebd, 0xdebc, 0xdebf, 0xdebe"
+		       ", 0xdeb9, 0xdeb8, 0xdebb, 0xdeba], [0xdfad, 0xdfac"
+		       ", 0xdfaf, 0xdfae, 0xdfa9, 0xdfa8, 0xdfab, 0xdfaa"
+		       ", 0xdfa5, 0xdfa4, 0xdfa7, 0xdfa6, 0xdfa1, 0xdfa0"
+		       ", 0xdfa3, 0xdfa2, 0xdfbd, 0xdfbc, 0xdfbf, 0xdfbe"
+		       ", 0xdfb9, 0xdfb8, 0xdfbb, 0xdfba]]}",
+		       pfx);
+		break;
+#endif
+#if HAVE_DECL_V4L2_BUF_TYPE_SDR_CAPTURE
+	case V4L2_BUF_TYPE_SDR_CAPTURE:
+# if HAVE_DECL_V4L2_BUF_TYPE_SDR_OUTPUT
+	case V4L2_BUF_TYPE_SDR_OUTPUT:
+# endif
+		printf("%sfmt.sdr={pixelformat=" RAW("0x38305543")
+		       NRAW("v4l2_fourcc('C', 'U', '0', '8')"
+			    " /* V4L2_SDR_FMT_CU8 */")
+		       ", buffersize=3134983661}",
+		       pfx);
+		break;
+#endif
+	}
+}
+
+int
+main(int argc, char **argv)
+{
+	unsigned long num_skip;
+	long inject_retval;
+	bool locked = false;
+
+	if (argc == 1)
+		return 0;
+
+	if (argc < 3)
+		error_msg_and_fail("Usage: %s NUM_SKIP INJECT_RETVAL", argv[0]);
+
+	num_skip = strtoul(argv[1], NULL, 0);
+	inject_retval = strtol(argv[2], NULL, 0);
+
+	if (inject_retval < 0)
+		error_msg_and_fail("Expected non-negative INJECT_RETVAL, "
+				   "but got %ld", inject_retval);
+
+	for (unsigned int i = 0; i < num_skip; i++) {
+		long rc = ioctl(-1, VIDIOC_QUERYCAP, NULL);
+		printf("ioctl(-1, %s, NULL) = %s%s\n",
+		       XLAT_STR(VIDIOC_QUERYCAP), sprintrc(rc),
+		       rc == inject_retval ? " (INJECTED)" : "");
+
+		if (rc != inject_retval)
+			continue;
+
+		locked = true;
+		break;
+	}
+
+	if (!locked)
+		error_msg_and_fail("Hasn't locked on ioctl(-1"
+				   ", VIDIOC_QUERYCAP, NULL) returning %lu",
+				   inject_retval);
+
+
+	/* VIDIOC_QUERYCAP */
+	struct v4l2_capability *caps = tail_alloc(sizeof(*caps));
+
+	fill_memory(caps, sizeof(*caps));
+	caps->capabilities = 0xdeadbeef;
+#ifdef HAVE_STRUCT_V4L2_CAPABILITY_DEVICE_CAPS
+	caps->device_caps = 0xfacefeed;
+#else
+	caps->reserved[0] = 0xfacefeed;
+#endif
+
+	ioctl(-1, VIDIOC_QUERYCAP, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_QUERYCAP), inject_retval);
+
+	ioctl(-1, VIDIOC_QUERYCAP, (char *) caps + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_QUERYCAP), (char *) caps + 1, inject_retval);
+
+	ioctl(-1, VIDIOC_QUERYCAP, caps);
+	printf("ioctl(-1, %s, {driver=", XLAT_STR(VIDIOC_QUERYCAP));
+	print_quoted_cstring((char *) caps->driver, sizeof(caps->driver));
+	printf(", card=");
+	print_quoted_cstring((char *) caps->card, sizeof(caps->card));
+	printf(", bus_info=");
+	print_quoted_cstring((char *) caps->bus_info, sizeof(caps->bus_info));
+	printf(", version="
+#ifdef WORDS_BIGENDIAN
+	       XLAT_KNOWN(0xd0d1d2d3, "KERNEL_VERSION(53457, 210, 211)")
+#else
+	       XLAT_KNOWN(0xd3d2d1d0, "KERNEL_VERSION(54226, 209, 208)")
+#endif
+	       ", capabilities=" XLAT_KNOWN(0xdeadbeef,
+	       "V4L2_CAP_VIDEO_CAPTURE|V4L2_CAP_VIDEO_OUTPUT"
+	       "|V4L2_CAP_VIDEO_OVERLAY|V4L2_CAP_VBI_OUTPUT"
+	       "|V4L2_CAP_SLICED_VBI_CAPTURE|V4L2_CAP_SLICED_VBI_OUTPUT"
+	       "|V4L2_CAP_VIDEO_OUTPUT_OVERLAY|V4L2_CAP_HW_FREQ_SEEK"
+	       "|V4L2_CAP_RDS_OUTPUT|V4L2_CAP_VIDEO_CAPTURE_MPLANE"
+	       "|V4L2_CAP_VIDEO_OUTPUT_MPLANE|V4L2_CAP_VIDEO_M2M"
+	       "|V4L2_CAP_TUNER|V4L2_CAP_RADIO|V4L2_CAP_MODULATOR"
+	       "|V4L2_CAP_EXT_PIX_FORMAT|V4L2_CAP_META_CAPTURE|V4L2_CAP_ASYNCIO"
+	       "|V4L2_CAP_STREAMING|V4L2_CAP_META_OUTPUT|V4L2_CAP_TOUCH"
+	       "|V4L2_CAP_DEVICE_CAPS|0x40000008"));
+	printf(", device_caps=" XLAT_KNOWN(0xfacefeed,
+	       "V4L2_CAP_VIDEO_CAPTURE|V4L2_CAP_VIDEO_OVERLAY"
+	       "|V4L2_CAP_VBI_OUTPUT|V4L2_CAP_SLICED_VBI_CAPTURE"
+	       "|V4L2_CAP_SLICED_VBI_OUTPUT|V4L2_CAP_VIDEO_OUTPUT_OVERLAY"
+	       "|V4L2_CAP_HW_FREQ_SEEK|V4L2_CAP_RDS_OUTPUT"
+	       "|V4L2_CAP_VIDEO_CAPTURE_MPLANE|V4L2_CAP_VIDEO_OUTPUT_MPLANE"
+	       "|V4L2_CAP_VIDEO_M2M_MPLANE|V4L2_CAP_VIDEO_M2M|V4L2_CAP_AUDIO"
+	       "|V4L2_CAP_RADIO|V4L2_CAP_MODULATOR|V4L2_CAP_SDR_OUTPUT"
+	       "|V4L2_CAP_META_CAPTURE|V4L2_CAP_ASYNCIO|V4L2_CAP_META_OUTPUT"
+	       "|V4L2_CAP_TOUCH|V4L2_CAP_DEVICE_CAPS|0x60000008"));
+	printf("}) = %ld (INJECTED)\n", inject_retval);
+
+
+	/* VIDIOC_ENUM_FMT */
+	static const struct strval32 buf_types[] = {
+		{ ARG_XLAT_UNKNOWN(0, "V4L2_BUF_TYPE_???") },
+		{ ARG_XLAT_KNOWN(0x1, "V4L2_BUF_TYPE_VIDEO_CAPTURE") },
+		{ ARG_XLAT_KNOWN(0x2, "V4L2_BUF_TYPE_VIDEO_OUTPUT") },
+		{ ARG_XLAT_KNOWN(0x3, "V4L2_BUF_TYPE_VIDEO_OVERLAY") },
+		{ ARG_XLAT_KNOWN(0x4, "V4L2_BUF_TYPE_VBI_CAPTURE") },
+		{ ARG_XLAT_KNOWN(0x5, "V4L2_BUF_TYPE_VBI_OUTPUT") },
+		{ ARG_XLAT_KNOWN(0x6, "V4L2_BUF_TYPE_SLICED_VBI_CAPTURE") },
+		{ ARG_XLAT_KNOWN(0x7, "V4L2_BUF_TYPE_SLICED_VBI_OUTPUT") },
+		{ ARG_XLAT_KNOWN(0x8, "V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY") },
+		{ ARG_XLAT_KNOWN(0x9, "V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE") },
+		{ ARG_XLAT_KNOWN(0xa, "V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE") },
+		{ ARG_XLAT_KNOWN(0xb, "V4L2_BUF_TYPE_SDR_CAPTURE") },
+		{ ARG_XLAT_KNOWN(0xc, "V4L2_BUF_TYPE_SDR_OUTPUT") },
+		{ ARG_XLAT_KNOWN(0xd, "V4L2_BUF_TYPE_META_CAPTURE") },
+		{ ARG_XLAT_KNOWN(0xe, "V4L2_BUF_TYPE_META_OUTPUT") },
+		{ ARG_XLAT_UNKNOWN(0xf, "V4L2_BUF_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0x80, "V4L2_BUF_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0xbadc0ded, "V4L2_BUF_TYPE_???") },
+	};
+	static const struct strval32 fmtdesc_flags[] = {
+		{ ARG_STR(0) },
+		{ ARG_XLAT_KNOWN(0x1, "V4L2_FMT_FLAG_COMPRESSED") },
+		{ ARG_XLAT_KNOWN(0x3e, "V4L2_FMT_FLAG_EMULATED"
+				       "|V4L2_FMT_FLAG_CONTINUOUS_BYTESTREAM"
+				       "|V4L2_FMT_FLAG_DYN_RESOLUTION"
+				       "|V4L2_FMT_FLAG_ENC_CAP_FRAME_INTERVAL"
+				       "|0x20") },
+		{ ARG_XLAT_UNKNOWN(0xdead0000, "V4L2_FMT_FLAG_???") },
+	};
+	static const struct strval32 fmtdesc_fmts[] = {
+		{ 0x4c47504a, RAW("0x4c47504a")
+			      NRAW("v4l2_fourcc('J', 'P', 'G', 'L')"
+			           " /* V4L2_PIX_FMT_JPGL */") },
+		{ 0xbadc0ded, RAW("0xbadc0ded")
+			      NRAW("v4l2_fourcc('\\xed', '\\x0d', '\\xdc',"
+			           " '\\xba')") },
+	};
+	struct v4l2_fmtdesc *fmtdesc = tail_alloc(sizeof(*fmtdesc));
+
+	fill_memory(fmtdesc, sizeof(*fmtdesc));
+	fmtdesc->index = 0xdeac0de;
+
+	ioctl(-1, VIDIOC_ENUM_FMT, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FMT), inject_retval);
+
+	ioctl(-1, VIDIOC_ENUM_FMT, (char *) fmtdesc + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FMT), (char *) fmtdesc + 1, inject_retval);
+
+	for (size_t i = 0; i < ARRAY_SIZE(buf_types); i++) {
+		for (size_t j = 0; j < ARRAY_SIZE(fmtdesc_flags); j++) {
+			for (size_t k = 0; k < ARRAY_SIZE(fmtdesc_fmts); k++) {
+				fmtdesc->type = buf_types[i].val;
+				fmtdesc->flags = fmtdesc_flags[j].val;
+				fmtdesc->pixelformat = fmtdesc_fmts[k].val;
+
+				ioctl(-1, VIDIOC_ENUM_FMT, fmtdesc);
+				printf("ioctl(-1, %s, {index=233488606, type=%s"
+				       ", flags=%s, description=",
+				       XLAT_STR(VIDIOC_ENUM_FMT),
+				       buf_types[i].str,
+				       fmtdesc_flags[j].str);
+				print_quoted_cstring((char *) fmtdesc->description,
+					sizeof(fmtdesc->description));
+				printf(", pixelformat=%s}) = %ld (INJECTED)\n",
+				       fmtdesc_fmts[k].str, inject_retval);
+
+				fill_memory_ex(fmtdesc->description,
+					       sizeof(fmtdesc->description),
+					       (i * 9 + j) * 7 + k,
+					       (k * 3 + j) * 11 + i + 5);
+			}
+		}
+	}
+
+
+	/* VIDIOC_REQBUFS */
+	static const struct strval32 reqb_mems[] = {
+		{ ARG_XLAT_UNKNOWN(0, "V4L2_MEMORY_???") },
+		{ ARG_XLAT_KNOWN(0x1, "V4L2_MEMORY_MMAP") },
+		{ ARG_XLAT_KNOWN(0x4, "V4L2_MEMORY_DMABUF") },
+		{ ARG_XLAT_UNKNOWN(0x5, "V4L2_MEMORY_???") },
+		{ ARG_XLAT_UNKNOWN(0xbadc0ded, "V4L2_MEMORY_???") },
+	};
+	struct v4l2_requestbuffers *reqb = tail_alloc(sizeof(*reqb));
+
+	fill_memory(reqb, sizeof(*reqb));
+	reqb->count = 0xfeedface;
+
+	ioctl(-1, VIDIOC_REQBUFS, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_REQBUFS), inject_retval);
+
+	ioctl(-1, VIDIOC_REQBUFS, (char *) reqb + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_REQBUFS), (char *) reqb + 1, inject_retval);
+
+	for (size_t i = 0; i < MAX(ARRAY_SIZE(buf_types),
+				   ARRAY_SIZE(reqb_mems)); i++) {
+		reqb->type = buf_types[i % ARRAY_SIZE(buf_types)].val;
+		reqb->memory = reqb_mems[i % ARRAY_SIZE(reqb_mems)].val;
+
+		ioctl(-1, VIDIOC_REQBUFS, reqb);
+		printf("ioctl(-1, %s, {type=%s, memory=%s"
+		       ", count=4277009102 => 4277009102}) = %ld (INJECTED)\n",
+		       XLAT_STR(VIDIOC_REQBUFS),
+		       buf_types[i % ARRAY_SIZE(buf_types)].str,
+		       reqb_mems[i % ARRAY_SIZE(reqb_mems)].str,
+		       inject_retval);
+	}
+
+
+	/* VIDIOC_G_FMT, VIDIOC_S_FMT, VIDIOC_TRY_FMT */
+	static const struct strval32 fmt_cmds[] = {
+		{ ARG_STR(VIDIOC_G_FMT) },
+		{ ARG_STR(VIDIOC_S_FMT) },
+		{ ARG_STR(VIDIOC_TRY_FMT) },
+	};
+
+	struct v4l2_format *fmt = tail_alloc(sizeof(*fmt));
+
+	for (size_t i = 0; i < ARRAY_SIZE(fmt_cmds); i++) {
+		ioctl(-1, fmt_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(fmt_cmds[i].str, fmt_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, fmt_cmds[i].val, (char *) fmt + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(fmt_cmds[i].str, fmt_cmds[i].val, NULL),
+		       (char *) fmt + 1, inject_retval);
+
+		for (size_t j = 0; j < ARRAY_SIZE(buf_types); j++) {
+			fill_memory(fmt, sizeof(*fmt));
+
+			fmt->type = buf_types[j].val;
+			if (!fill_fmt(fmt))
+				continue;
+
+			ioctl(-1, fmt_cmds[i].val, fmt);
+			printf("ioctl(-1, %s, {type=%s",
+			       sprintxlat(fmt_cmds[i].str, fmt_cmds[i].val,
+					  NULL),
+			       buf_types[j].str);
+			print_fmt(", ", fmt);
+			if (fmt_cmds[i].val != VIDIOC_G_FMT &&
+			    buf_types[j].val != V4L2_BUF_TYPE_VIDEO_OVERLAY &&
+			    buf_types[j].val != 8)
+				print_fmt("} => {", fmt);
+			printf("}) = %ld (INJECTED)\n", inject_retval);
+		}
+	}
+
+
+	/* VIDIOC_QUERYBUF, VIDIOC_QBUF, VIDIOC_DQBUF */
+	static const struct strval32 buf_cmds[] = {
+		{ ARG_STR(VIDIOC_QUERYBUF) },
+		{ ARG_STR(VIDIOC_QBUF) },
+		{ ARG_STR(VIDIOC_DQBUF) },
+	};
+
+	kernel_v4l2_buffer_t *buf = tail_alloc(sizeof(*buf));
+
+	for (size_t i = 0; i < ARRAY_SIZE(buf_cmds); i++) {
+		ioctl(-1, buf_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(buf_cmds[i].str, buf_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, buf_cmds[i].val, (char *) buf + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(buf_cmds[i].str, buf_cmds[i].val, NULL),
+		       (char *) buf + 1, inject_retval);
+
+		fill_memory(buf, sizeof(*buf));
+		buf->index     = 0xdeadc0de;
+		buf->type      = V4L2_BUF_TYPE_VIDEO_CAPTURE;
+		buf->bytesused = 0xdecaffee;
+		buf->flags     = 0x1ff; /* TODO: update */
+		buf->field     = V4L2_FIELD_TOP;
+
+		buf->timestamp.tv_sec  = 0x1e55c0de;
+		buf->timestamp.tv_usec = 999999;
+
+		buf->timecode.type = V4L2_TC_TYPE_24FPS;
+		buf->timecode.flags = 0xbeefdeaf;
+
+		buf->memory    = V4L2_MEMORY_MMAP;
+		buf->m.offset  = 0xfacefeed;
+		buf->length    = 0xcafebed5;
+		buf->reserved  = 0xdeefaced;
+
+		ioctl(-1, buf_cmds[i].val, buf);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_KNOWN(0x1, "V4L2_BUF_TYPE_VIDEO_CAPTURE")
+		       ", index=3735929054, memory="
+		       XLAT_KNOWN(0x1, "V4L2_MEMORY_MMAP")
+		       ", m.offset=0xfacefeed, length=3405692629"
+		       ", bytesused=3737845742, flags=" RAW("0x1ff")
+#if !XLAT_RAW
+		       XLAT_KNOWN(0x1ff, "V4L2_BUF_FLAG_MAPPED"
+		       "|V4L2_BUF_FLAG_QUEUED|V4L2_BUF_FLAG_DONE"
+		       "|V4L2_BUF_FLAG_KEYFRAME|V4L2_BUF_FLAG_PFRAME"
+		       "|V4L2_BUF_FLAG_BFRAME|V4L2_BUF_FLAG_ERROR"
+		       "|V4L2_BUF_FLAG_IN_REQUEST|V4L2_BUF_FLAG_TIMECODE") "|"
+		       XLAT_KNOWN(0, "V4L2_BUF_FLAG_TIMESTAMP_UNKNOWN") "|"
+		       XLAT_KNOWN(0, "V4L2_BUF_FLAG_TSTAMP_SRC_EOF")
+#endif
+		       "%s, ...}) = %ld (INJECTED)\n",
+		       sprintxlat(buf_cmds[i].str, buf_cmds[i].val, NULL),
+		       buf_cmds[i].val == VIDIOC_DQBUF
+			? ", timestamp={tv_sec=508936414, tv_usec=999999}" : "",
+		       inject_retval);
+
+		buf->type      = V4L2_BUF_TYPE_VBI_CAPTURE;
+		buf->flags     = 0x268040;
+		buf->field     = 0xb;
+		buf->memory    = V4L2_MEMORY_USERPTR;
+		buf->m.userptr = (long) 0xdefaced0dec0ded1LL;
+
+		ioctl(-1, buf_cmds[i].val, buf);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_KNOWN(0x4, "V4L2_BUF_TYPE_VBI_CAPTURE")
+		       ", index=3735929054, memory="
+		       XLAT_KNOWN(0x2, "V4L2_MEMORY_USERPTR")
+		       ", m.userptr=%p, length=3405692629"
+		       ", bytesused=3737845742, flags=" RAW("0x268040")
+#if !XLAT_RAW
+		       XLAT_KNOWN(0x200040, "V4L2_BUF_FLAG_ERROR|0x200000") "|"
+		       XLAT_UNKNOWN(0x8000, "V4L2_BUF_FLAG_TIMESTAMP_???") "|"
+		       XLAT_UNKNOWN(0x60000, "V4L2_BUF_FLAG_TSTAMP_SRC_???")
+#endif
+		       "%s, ...}) = %ld (INJECTED)\n",
+		       sprintxlat(buf_cmds[i].str, buf_cmds[i].val, NULL),
+		       (void *) (intptr_t) 0xdefaced0dec0ded1LL,
+		       buf_cmds[i].val == VIDIOC_DQBUF
+			? ", timestamp={tv_sec=508936414, tv_usec=999999}" : "",
+		       inject_retval);
+
+		buf->type      = 0x9;
+		buf->flags     = 0;
+
+		ioctl(-1, buf_cmds[i].val, buf);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_KNOWN(0x9, "V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE")
+		       ", index=3735929054, memory="
+		       XLAT_KNOWN(0x2, "V4L2_MEMORY_USERPTR")
+		       ", m.userptr=%p, length=3405692629"
+		       ", bytesused=3737845742, flags=" RAW("0")
+#if !XLAT_RAW
+		       XLAT_KNOWN(0, "V4L2_BUF_FLAG_TIMESTAMP_UNKNOWN") "|"
+		       XLAT_KNOWN(0, "V4L2_BUF_FLAG_TSTAMP_SRC_EOF")
+#endif
+		       "%s, ...}) = %ld (INJECTED)\n",
+		       sprintxlat(buf_cmds[i].str, buf_cmds[i].val, NULL),
+		       (void *) (intptr_t) 0xdefaced0dec0ded1LL,
+		       buf_cmds[i].val == VIDIOC_DQBUF
+			? ", timestamp={tv_sec=508936414, tv_usec=999999}" : "",
+		       inject_retval);
+
+		buf->type      = 0xa;
+		buf->memory    = V4L2_MEMORY_OVERLAY;
+		buf->flags     = 0x2000;
+
+		ioctl(-1, buf_cmds[i].val, buf);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_KNOWN(0xa, "V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE")
+		       ", index=3735929054, memory="
+		       XLAT_KNOWN(0x3, "V4L2_MEMORY_OVERLAY")
+		       ", length=3405692629, bytesused=3737845742"
+		       ", flags=" RAW("0x2000")
+#if !XLAT_RAW
+		       XLAT_KNOWN(0x2000, "V4L2_BUF_FLAG_TIMESTAMP_MONOTONIC")
+		       "|" XLAT_KNOWN(0, "V4L2_BUF_FLAG_TSTAMP_SRC_EOF")
+#endif
+		       "%s, ...}) = %ld (INJECTED)\n",
+		       sprintxlat(buf_cmds[i].str, buf_cmds[i].val, NULL),
+		       buf_cmds[i].val == VIDIOC_DQBUF
+			? ", timestamp={tv_sec=508936414, tv_usec=999999}" : "",
+		       inject_retval);
+	}
+
+
+	/* VIDIOC_G_FBUF, VIDIOC_S_FBUF */
+	static const struct strval32 fbuf_cmds[] = {
+		{ ARG_STR(VIDIOC_G_FBUF) },
+		{ ARG_STR(VIDIOC_S_FBUF) },
+	};
+
+	struct v4l2_framebuffer *fbuf = tail_alloc(sizeof(*fbuf));
+
+	for (size_t i = 0; i < ARRAY_SIZE(fbuf_cmds); i++) {
+		ioctl(-1, fbuf_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(fbuf_cmds[i].str, fbuf_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, fbuf_cmds[i].val, (char *) fbuf + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(fbuf_cmds[i].str, fbuf_cmds[i].val, NULL),
+		       (char *) fbuf + 1, inject_retval);
+
+		fill_memory32(fbuf, sizeof(*fbuf));
+		fbuf->base = NULL;
+
+		ioctl(-1, fbuf_cmds[i].val, fbuf);
+		printf("ioctl(-1, %s, {capability=0x80a0c0e0, flags=0x80a0c0e1"
+		       ", base=NULL}) = %ld (INJECTED)\n",
+		       sprintxlat(fbuf_cmds[i].str, fbuf_cmds[i].val, NULL),
+		       inject_retval);
+	}
+
+
+	/* VIDIOC_G_PARM, VIDIOC_S_PARM */
+	static const struct strval32 sparm_cmds[] = {
+		{ ARG_STR(VIDIOC_G_PARM) },
+		{ ARG_STR(VIDIOC_S_PARM) },
+	};
+
+	struct v4l2_streamparm *sparm = tail_alloc(sizeof(*sparm));
+
+	for (size_t i = 0; i < ARRAY_SIZE(sparm_cmds); i++) {
+		ioctl(-1, sparm_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(sparm_cmds[i].str, sparm_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, sparm_cmds[i].val, (char *) sparm + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(sparm_cmds[i].str, sparm_cmds[i].val, NULL),
+		       (char *) sparm + 1, inject_retval);
+
+		fill_memory32(sparm, sizeof(*sparm));
+
+		ioctl(-1, sparm_cmds[i].val, sparm);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_UNKNOWN(0x80a0c0e0, "V4L2_BUF_TYPE_???")
+		       "}) = %ld (INJECTED)\n",
+		       sprintxlat(sparm_cmds[i].str, sparm_cmds[i].val, NULL),
+		       inject_retval);
+
+		sparm->type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
+
+		static const char *parm_str1 = "parm.capture={capability="
+			XLAT_UNKNOWN(0x80a0c0e1, "V4L2_CAP_???")
+			", capturemode="
+			XLAT_UNKNOWN(0x80a0c0e2, "V4L2_MODE_???")
+			", timeperframe=2158018787/2158018788"
+			", extendedmode=0x80a0c0e5, readbuffers=2158018790}";
+
+		ioctl(-1, sparm_cmds[i].val, sparm);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_KNOWN(0x1, "V4L2_BUF_TYPE_VIDEO_CAPTURE")
+		       ", %s}%s%s%s) = %ld (INJECTED)\n",
+		       sprintxlat(sparm_cmds[i].str, sparm_cmds[i].val, NULL),
+		       parm_str1,
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? " => {" : "",
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? parm_str1 : "",
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? "}" : "",
+		       inject_retval);
+
+		sparm->parm.capture.capability = 0x1000;
+		sparm->parm.capture.capturemode = 0x1;
+
+		static const char *parm_str2 = "parm.capture={capability="
+			XLAT_KNOWN(0x1000, "V4L2_CAP_TIMEPERFRAME")
+			", capturemode="
+			XLAT_KNOWN(0x1, "V4L2_MODE_HIGHQUALITY")
+			", timeperframe=2158018787/2158018788"
+			", extendedmode=0x80a0c0e5, readbuffers=2158018790}";
+
+		ioctl(-1, sparm_cmds[i].val, sparm);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_KNOWN(0x1, "V4L2_BUF_TYPE_VIDEO_CAPTURE")
+		       ", %s}%s%s%s) = %ld (INJECTED)\n",
+		       sprintxlat(sparm_cmds[i].str, sparm_cmds[i].val, NULL),
+		       parm_str2,
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? " => {" : "",
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? parm_str2 : "",
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? "}" : "",
+		       inject_retval);
+
+		sparm->type = 0x9;
+		sparm->parm.capture.capability = 0xdeadbeef;
+		sparm->parm.capture.capturemode = 0xadec0ded;
+
+		ioctl(-1, sparm_cmds[i].val, sparm);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_KNOWN(0x9, "V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE")
+		       "}) = %ld (INJECTED)\n",
+		       sprintxlat(sparm_cmds[i].str, sparm_cmds[i].val, NULL),
+		       inject_retval);
+
+		fill_memory32(sparm, sizeof(*sparm));
+		sparm->type = V4L2_BUF_TYPE_VIDEO_OUTPUT;
+
+		static const char *parm_str3 = "parm.output={capability="
+			XLAT_UNKNOWN(0x80a0c0e1, "V4L2_CAP_???")
+			", outputmode="
+			XLAT_UNKNOWN(0x80a0c0e2, "V4L2_MODE_???")
+			", timeperframe=2158018787/2158018788"
+			", extendedmode=0x80a0c0e5, writebuffers=2158018790}";
+
+		ioctl(-1, sparm_cmds[i].val, sparm);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_KNOWN(0x2, "V4L2_BUF_TYPE_VIDEO_OUTPUT")
+		       ", %s}%s%s%s) = %ld (INJECTED)\n",
+		       sprintxlat(sparm_cmds[i].str, sparm_cmds[i].val, NULL),
+		       parm_str3,
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? " => {" : "",
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? parm_str3 : "",
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? "}" : "",
+		       inject_retval);
+
+	}
+
+
+	/* VIDIOC_G_STD, VIDIOC_S_STD */
+	static const struct strval32 stdid_cmds[] = {
+		{ ARG_STR(VIDIOC_G_STD) },
+		{ ARG_STR(VIDIOC_S_STD) },
+	};
+	static const struct strval64 stdids[] = {
+		{ ARG_STR(0) },
+		{ ARG_STR(0x1) },
+		{ ARG_STR(0xb000) },
+		{ ARG_STR(0x3ffffff) },
+		{ ARG_STR(0xffffffff) },
+		{ ARG_ULL_STR(0xbadc0deddeadface) },
+	};
+
+	v4l2_std_id *stdid = tail_alloc(sizeof(*stdid));
+
+	for (size_t i = 0; i < ARRAY_SIZE(stdid_cmds); i++) {
+		ioctl(-1, stdid_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(stdid_cmds[i].str, stdid_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, stdid_cmds[i].val, (char *) stdid + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(stdid_cmds[i].str, stdid_cmds[i].val, NULL),
+		       (char *) stdid + 1, inject_retval);
+
+		for (size_t j = 0; j < ARRAY_SIZE(stdids); j++) {
+			*stdid = stdids[j].val;
+
+			ioctl(-1, stdid_cmds[i].val, stdid);
+			printf("ioctl(-1, %s, [%s]) = %ld (INJECTED)\n",
+			       sprintxlat(stdid_cmds[i].str, stdid_cmds[i].val, NULL),
+			       stdids[j].str, inject_retval);
+
+		}
+	}
+
+
+	/* VIDIOC_ENUMSTD */
+	struct v4l2_standard *std = tail_alloc(sizeof(*std));
+
+	ioctl(-1, VIDIOC_ENUMSTD, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUMSTD), inject_retval);
+
+	ioctl(-1, VIDIOC_ENUMSTD, (char *) std + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUMSTD), (char *) std + 1, inject_retval);
+
+	for (size_t i = 0; i < ARRAY_SIZE(stdids); i++) {
+		fill_memory32(&std->frameperiod, sizeof(*std) -
+			      offsetof(struct v4l2_standard, frameperiod));
+		fill_memory_ex(std->name, sizeof(std->name), i * 47 + 1, 255);
+		std->index = 0xdeadface;
+		std->id = stdids[i].val;
+
+		ioctl(-1, VIDIOC_ENUMSTD, std);
+		printf("ioctl(-1, %s, {index=3735943886, name=",
+		       XLAT_STR(VIDIOC_ENUMSTD));
+		print_quoted_cstring((char *) std->name, sizeof(std->name));
+		printf(", frameperiod=2158018784/2158018785"
+		       ", framelines=2158018786}) = %ld (INJECTED)\n",
+		       inject_retval);
+	}
+
+
+	/* VIDIOC_ENUMINPUT */
+	static const struct strval32 input_types[] = {
+		{ ARG_XLAT_UNKNOWN(0, "V4L2_INPUT_TYPE_???") },
+		{ V4L2_INPUT_TYPE_TUNER,
+		  XLAT_KNOWN(0x1, "V4L2_INPUT_TYPE_TUNER") },
+		{ V4L2_INPUT_TYPE_CAMERA,
+		  XLAT_KNOWN(0x2, "V4L2_INPUT_TYPE_CAMERA") },
+		{ ARG_XLAT_UNKNOWN(0x4, "V4L2_INPUT_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0xdeadc0de, "V4L2_INPUT_TYPE_???") },
+	};
+
+	struct v4l2_input *input = tail_alloc(sizeof(*input));
+
+	ioctl(-1, VIDIOC_ENUMINPUT, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUMINPUT), inject_retval);
+
+	ioctl(-1, VIDIOC_ENUMINPUT, (char *) input + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUMINPUT), (char *) input + 1, inject_retval);
+
+	for (size_t i = 0; i < ARRAY_SIZE(stdids); i++) {
+		for (size_t j = 0; j < ARRAY_SIZE(input_types); j++) {
+			fill_memory32(input, sizeof(*input));
+			fill_memory_ex(input->name, sizeof(input->name),
+				       i * 47 + 13, 255);
+			input->type = input_types[j].val;
+			input->std = stdids[i].val;
+
+			ioctl(-1, VIDIOC_ENUMINPUT, input);
+			printf("ioctl(-1, %s, {index=2158018784, name=",
+			       XLAT_STR(VIDIOC_ENUMINPUT));
+			print_quoted_cstring((char *) input->name,
+					     sizeof(input->name));
+			printf(", type=%s}) = %ld (INJECTED)\n",
+			       input_types[j].str, inject_retval);
+		}
+	}
+
+
+	/* VIDIOC_G_CTRL, VIDIOC_S_CTRL */
+	static const struct strval32 ctrl_cmds[] = {
+		{ ARG_STR(VIDIOC_G_CTRL) },
+		{ ARG_STR(VIDIOC_S_CTRL) },
+	};
+
+	struct v4l2_control *ctrl = tail_alloc(sizeof(*ctrl));
+
+	for (size_t i = 0; i < ARRAY_SIZE(ctrl_cmds); i++) {
+		ioctl(-1, ctrl_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(ctrl_cmds[i].str, ctrl_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, ctrl_cmds[i].val, (char *) ctrl + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(ctrl_cmds[i].str, ctrl_cmds[i].val, NULL),
+		       (char *) ctrl + 1, inject_retval);
+
+		/* NB: cid printing is mostly tested in ioctl_v4l2.c */
+		fill_memory32(ctrl, sizeof(*ctrl));
+		ioctl(-1, ctrl_cmds[i].val, ctrl);
+		printf("ioctl(-1, %s, {id=0x80a0c0e0"
+		       NRAW(" /* V4L2_CID_??? */")
+		       ", value=-2136948511%s}) = %ld (INJECTED)\n",
+		       sprintxlat(ctrl_cmds[i].str, ctrl_cmds[i].val, NULL),
+		       ctrl_cmds[i].val == VIDIOC_S_CTRL
+			? " => -2136948511" : "",
+		       inject_retval);
+	}
+
+
+	/* VIDIOC_G_TUNER, VIDIOC_S_TUNER */
+	static const struct strval32 tuner_cmds[] = {
+		{ ARG_STR(VIDIOC_G_TUNER) },
+		{ ARG_STR(VIDIOC_S_TUNER) },
+	};
+	static const struct strval32 tuner_types[] = {
+		{ ARG_XLAT_UNKNOWN(0, "V4L2_TUNER_???") },
+		{ ARG_XLAT_KNOWN(0x1, "V4L2_TUNER_RADIO") },
+		{ ARG_XLAT_KNOWN(0x5, "V4L2_TUNER_RF") },
+		{ ARG_XLAT_UNKNOWN(0x6, "V4L2_TUNER_???") },
+		{ ARG_XLAT_UNKNOWN(0xdeadc0de, "V4L2_TUNER_???") },
+	};
+	static const struct strval32 tuner_caps[] = {
+		{ ARG_STR(0) },
+		{ ARG_XLAT_KNOWN(0x1fff, "V4L2_TUNER_CAP_LOW"
+				 "|V4L2_TUNER_CAP_NORM"
+				 "|V4L2_TUNER_CAP_HWSEEK_BOUNDED"
+				 "|V4L2_TUNER_CAP_HWSEEK_WRAP"
+				 "|V4L2_TUNER_CAP_STEREO|V4L2_TUNER_CAP_LANG2"
+				 "|V4L2_TUNER_CAP_LANG1|V4L2_TUNER_CAP_RDS"
+				 "|V4L2_TUNER_CAP_RDS_BLOCK_IO"
+				 "|V4L2_TUNER_CAP_RDS_CONTROLS"
+				 "|V4L2_TUNER_CAP_FREQ_BANDS"
+				 "|V4L2_TUNER_CAP_HWSEEK_PROG_LIM"
+				 "|V4L2_TUNER_CAP_1HZ") },
+		{ ARG_XLAT_KNOWN(0xdeadc0de, "V4L2_TUNER_CAP_NORM"
+				 "|V4L2_TUNER_CAP_HWSEEK_BOUNDED"
+				 "|V4L2_TUNER_CAP_HWSEEK_WRAP"
+				 "|V4L2_TUNER_CAP_STEREO|V4L2_TUNER_CAP_LANG1"
+				 "|V4L2_TUNER_CAP_RDS|0xdeadc000") },
+		{ ARG_XLAT_UNKNOWN(0xffffe000, "V4L2_TUNER_CAP_???") },
+	};
+	static const struct strval32 tuner_rxsc[] = {
+		{ ARG_STR(0) },
+		{ ARG_XLAT_KNOWN(0x1f, "V4L2_TUNER_SUB_MONO"
+				 "|V4L2_TUNER_SUB_STEREO|V4L2_TUNER_SUB_LANG2"
+				 "|V4L2_TUNER_SUB_LANG1|V4L2_TUNER_SUB_RDS") },
+		{ ARG_XLAT_KNOWN(0xbeefface, "V4L2_TUNER_SUB_STEREO"
+				 "|V4L2_TUNER_SUB_LANG2|V4L2_TUNER_SUB_LANG1"
+				 "|0xbeeffac0") },
+		{ ARG_XLAT_UNKNOWN(0xffffffe0, "V4L2_TUNER_SUB_???") },
+
+	};
+	static const struct strval32 tuner_amodes[] = {
+		{ ARG_XLAT_KNOWN(0, "V4L2_TUNER_MODE_MONO") },
+		{ ARG_XLAT_KNOWN(0x2, "V4L2_TUNER_MODE_LANG2") },
+		{ ARG_XLAT_KNOWN(0x4, "V4L2_TUNER_MODE_LANG1_LANG2") },
+		{ ARG_XLAT_UNKNOWN(0x5, "V4L2_TUNER_MODE_???") },
+		{ ARG_XLAT_UNKNOWN(0xcaffeeed, "V4L2_TUNER_MODE_???") },
+	};
+	static const size_t tuner_iters = MAX(MAX(MAX(ARRAY_SIZE(tuner_types),
+						      ARRAY_SIZE(tuner_caps)),
+						  ARRAY_SIZE(tuner_rxsc)),
+					      ARRAY_SIZE(tuner_amodes));
+
+	struct v4l2_tuner *tuner = tail_alloc(sizeof(*tuner));
+
+	for (size_t i = 0; i < ARRAY_SIZE(tuner_cmds); i++) {
+		ioctl(-1, tuner_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(tuner_cmds[i].str, tuner_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, tuner_cmds[i].val, (char *) tuner + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(tuner_cmds[i].str, tuner_cmds[i].val, NULL),
+		       (char *) tuner + 1, inject_retval);
+
+		for (size_t j = 0; j < tuner_iters; j++) {
+			fill_memory32(tuner, sizeof(*tuner));
+			fill_memory_ex(tuner->name, sizeof(tuner->name),
+				       j * 47 + 7, 255);
+			tuner->type =
+				tuner_types[j % ARRAY_SIZE(tuner_types)].val;
+			tuner->capability =
+				tuner_caps[j % ARRAY_SIZE(tuner_caps)].val;
+			tuner->rxsubchans =
+				tuner_rxsc[j % ARRAY_SIZE(tuner_rxsc)].val;
+			tuner->audmode =
+				tuner_amodes[j % ARRAY_SIZE(tuner_amodes)].val;
+
+			ioctl(-1, tuner_cmds[i].val, tuner);
+			printf("ioctl(-1, %s, {index=2158018784",
+			       sprintxlat(tuner_cmds[i].str,
+					  tuner_cmds[i].val, NULL));
+			for (size_t k = 0;
+			     k < (tuner_cmds[i].val == VIDIOC_S_TUNER ? 2 : 1);
+			     k++) {
+				printf("%sname=", k ? "} => {" : ", ");
+				print_quoted_cstring((char *) tuner->name,
+						     sizeof(tuner->name));
+				printf(", type=%s, capability=%s"
+				       ", rangelow=2158018795"
+				       ", rangehigh=2158018796, rxsubchans=%s"
+				       ", audmode=%s, signal=-2136948497"
+				       ", afc=-2136948496",
+				       tuner_types[j %
+						   ARRAY_SIZE(tuner_types)].str,
+				       tuner_caps[j %
+						  ARRAY_SIZE(tuner_caps)].str,
+				       tuner_rxsc[j %
+						  ARRAY_SIZE(tuner_rxsc)].str,
+				       tuner_amodes[j %
+						 ARRAY_SIZE(tuner_amodes)].str);
+			}
+			printf("}) = %ld (INJECTED)\n", inject_retval);
+		}
+	}
+
+
+	/* VIDIOC_QUERYCTRL */
+	static const struct strval32 cids[] = {
+		{ ARG_XLAT_UNKNOWN(0, "V4L2_CID_???") },
+		{ ARG_XLAT_UNKNOWN(0x97abcd, "V4L2_CID_???") },
+		{ ARG_XLAT_KNOWN(0x980000, "V4L2_CTRL_CLASS_USER+0") },
+		{ ARG_XLAT_KNOWN(0x990a64,
+				 "V4L2_CID_MPEG_VIDEO_H264_CPB_SIZE") },
+		{ ARG_XLAT_KNOWN(0xa31234, "V4L2_CTRL_CLASS_DETECT+0x1234") },
+		{ ARG_XLAT_UNKNOWN(0xa40000, "V4L2_CID_???") },
+		{ 0xdeadc0de,
+#if XLAT_RAW
+		  "0xdeadc0de"
+#else
+		  XLAT_KNOWN(0xc0000000, "V4L2_CTRL_FLAG_NEXT_CTRL"
+					 "|V4L2_CTRL_FLAG_NEXT_COMPOUND")
+		  "|0x1eadc0de /* V4L2_CID_??? */"
+#endif
+			      },
+	};
+	static const struct strval32 ctrl_types[] = {
+		{ ARG_XLAT_UNKNOWN(0, "V4L2_CTRL_TYPE_???") },
+		{ ARG_XLAT_KNOWN(0x1, "V4L2_CTRL_TYPE_INTEGER") },
+		{ ARG_XLAT_KNOWN(0x2, "V4L2_CTRL_TYPE_BOOLEAN") },
+		{ ARG_XLAT_KNOWN(0x3, "V4L2_CTRL_TYPE_MENU") },
+		{ ARG_XLAT_KNOWN(0x4, "V4L2_CTRL_TYPE_BUTTON") },
+		{ ARG_XLAT_KNOWN(0x5, "V4L2_CTRL_TYPE_INTEGER64") },
+		{ ARG_XLAT_KNOWN(0x6, "V4L2_CTRL_TYPE_CTRL_CLASS") },
+		{ ARG_XLAT_KNOWN(0x7, "V4L2_CTRL_TYPE_STRING") },
+		{ ARG_XLAT_KNOWN(0x8, "V4L2_CTRL_TYPE_BITMASK") },
+		{ ARG_XLAT_KNOWN(0x9, "V4L2_CTRL_TYPE_INTEGER_MENU") },
+		{ ARG_XLAT_UNKNOWN(0xa, "V4L2_CTRL_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0xff, "V4L2_CTRL_TYPE_???") },
+		{ ARG_XLAT_KNOWN(0x100, "V4L2_CTRL_TYPE_U8") },
+		{ ARG_XLAT_KNOWN(0x101, "V4L2_CTRL_TYPE_U16") },
+		{ ARG_XLAT_KNOWN(0x102, "V4L2_CTRL_TYPE_U32") },
+		{ ARG_XLAT_UNKNOWN(0x103, "V4L2_CTRL_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0x104, "V4L2_CTRL_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0x105, "V4L2_CTRL_TYPE_???") },
+		{ ARG_XLAT_KNOWN(0x106, "V4L2_CTRL_TYPE_AREA") },
+		{ ARG_XLAT_UNKNOWN(0x107, "V4L2_CTRL_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0xdeadc0de, "V4L2_CTRL_TYPE_???") },
+	};
+	static const struct strval32 ctrl_flags[] = {
+		{ ARG_STR(0) },
+		{ ARG_XLAT_KNOWN(0x7ff, "V4L2_CTRL_FLAG_DISABLED"
+					"|V4L2_CTRL_FLAG_GRABBED"
+					"|V4L2_CTRL_FLAG_READ_ONLY"
+					"|V4L2_CTRL_FLAG_UPDATE"
+					"|V4L2_CTRL_FLAG_INACTIVE"
+					"|V4L2_CTRL_FLAG_SLIDER"
+					"|V4L2_CTRL_FLAG_WRITE_ONLY"
+					"|V4L2_CTRL_FLAG_VOLATILE"
+					"|V4L2_CTRL_FLAG_HAS_PAYLOAD"
+					"|V4L2_CTRL_FLAG_EXECUTE_ON_WRITE"
+					"|V4L2_CTRL_FLAG_MODIFY_LAYOUT") },
+		{ ARG_XLAT_KNOWN(0xbeefface, "V4L2_CTRL_FLAG_GRABBED"
+					     "|V4L2_CTRL_FLAG_READ_ONLY"
+					     "|V4L2_CTRL_FLAG_UPDATE"
+					     "|V4L2_CTRL_FLAG_WRITE_ONLY"
+					     "|V4L2_CTRL_FLAG_VOLATILE"
+					     "|V4L2_CTRL_FLAG_EXECUTE_ON_WRITE"
+					     "|0xbeeff800") },
+		{ ARG_XLAT_UNKNOWN(0xfffff800, "V4L2_CTRL_FLAG_???") },
+	};
+	static const size_t qctrl_iters = MAX(MAX(ARRAY_SIZE(cids),
+						  ARRAY_SIZE(ctrl_types)),
+					       ARRAY_SIZE(ctrl_flags));
+
+	struct v4l2_queryctrl *qctrl = tail_alloc(sizeof(*qctrl));
+
+	ioctl(-1, VIDIOC_QUERYCTRL, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_QUERYCTRL), inject_retval);
+
+	ioctl(-1, VIDIOC_QUERYCTRL, (char *) qctrl + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_QUERYCTRL), (char *) qctrl + 1, inject_retval);
+
+	for (size_t i = 0; i < qctrl_iters; i++) {
+		fill_memory32(qctrl, sizeof(*qctrl));
+		fill_memory_ex(qctrl->name, sizeof(qctrl->name),
+			       i * 47 + 5, 255);
+		qctrl->id    = cids[i % ARRAY_SIZE(cids)].val;
+		qctrl->type  = ctrl_types[i % ARRAY_SIZE(ctrl_types)].val;
+		qctrl->flags = ctrl_flags[i % ARRAY_SIZE(ctrl_flags)].val;
+
+		if (i % 2)
+			memset(qctrl->reserved, 0, sizeof(qctrl->reserved));
+
+		ioctl(-1, VIDIOC_QUERYCTRL, qctrl);
+		printf("ioctl(-1, %s, {id=%s, type=%s, name=",
+		       XLAT_STR(VIDIOC_QUERYCTRL),
+		       cids[i % ARRAY_SIZE(cids)].str,
+		       ctrl_types[i % ARRAY_SIZE(ctrl_types)].str);
+		print_quoted_cstring((char *) qctrl->name, sizeof(qctrl->name));
+#if VERBOSE
+		printf(", minimum=-2136948502, maximum=-2136948501"
+		       ", step=-2136948500, default_value=-2136948499"
+		       ", flags=%s%s",
+		       ctrl_flags[i % ARRAY_SIZE(ctrl_flags)].str,
+		       i % 2 ? "" : ", reserved=[0x80a0c0ef, 0x80a0c0f0]");
+#else
+		printf(", ...");
+#endif
+		printf("}) = %ld (INJECTED)\n", inject_retval);
+	}
+
+
+	/* VIDIOC_G_INPUT, VIDIOC_S_INPUT */
+	static const struct strval32 input_cmds[] = {
+		{ ARG_STR(VIDIOC_G_INPUT) },
+		{ ARG_STR(VIDIOC_S_INPUT) },
+	};
+	static const struct strval32 inputids[] = {
+		{ ARG_STR(0) },
+		{ ARG_STR(1) },
+		{ ARG_STR(1578221295) },
+		{ ARG_STR(31415926) },
+		{ ARG_STR(4294967295) },
+	};
+
+	int *inputid = tail_alloc(sizeof(*inputid));
+
+	for (size_t i = 0; i < ARRAY_SIZE(input_cmds); i++) {
+		ioctl(-1, input_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(input_cmds[i].str, input_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, input_cmds[i].val, (char *) inputid + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(input_cmds[i].str, input_cmds[i].val, NULL),
+		       (char *) inputid + 1, inject_retval);
+
+		for (size_t j = 0; j < ARRAY_SIZE(inputids); j++) {
+			*inputid = inputids[j].val;
+
+			ioctl(-1, input_cmds[i].val, inputid);
+			printf("ioctl(-1, %s, [%s]) = %ld (INJECTED)\n",
+			       sprintxlat(input_cmds[i].str, input_cmds[i].val,
+					  NULL),
+			       inputids[j].str, inject_retval);
+
+		}
+	}
+
+
+	/* VIDIOC_CROPCAP */
+	struct v4l2_cropcap *ccap = tail_alloc(sizeof(*ccap));
+
+	fill_memory32(ccap, sizeof(*ccap));
+
+	ioctl(-1, VIDIOC_CROPCAP, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_CROPCAP), inject_retval);
+
+	ioctl(-1, VIDIOC_CROPCAP, (char *) ccap + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_CROPCAP), (char *) ccap + 1, inject_retval);
+
+	for (size_t i = 0; i < ARRAY_SIZE(buf_types); i++) {
+		ccap->type = buf_types[i].val;
+
+		ioctl(-1, VIDIOC_CROPCAP, ccap);
+		printf("ioctl(-1, %s, {type=%s"
+		       ", bounds={left=-2136948511, top=-2136948510"
+		       ", width=2158018787, height=2158018788}"
+		       ", defrect={left=-2136948507, top=-2136948506"
+		       ", width=2158018791, height=2158018792}"
+		       ", pixelaspect=2158018793/2158018794})"
+		       " = %ld (INJECTED)\n",
+		       XLAT_STR(VIDIOC_CROPCAP),
+		       buf_types[i].str, inject_retval);
+	}
+
+
+	/* VIDIOC_G_CROP, VIDIOC_S_CROP */
+	static const struct strval32 crop_cmds[] = {
+		{ ARG_STR(VIDIOC_G_CROP) },
+		{ ARG_STR(VIDIOC_S_CROP) },
+	};
+	struct v4l2_crop *crop = tail_alloc(sizeof(*crop));
+
+	for (size_t i = 0; i < ARRAY_SIZE(crop_cmds); i++) {
+		fill_memory32(crop, sizeof(*crop));
+
+		ioctl(-1, crop_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(crop_cmds[i].str, crop_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, crop_cmds[i].val, (char *) crop + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(crop_cmds[i].str, crop_cmds[i].val, NULL),
+		       (char *) crop + 1, inject_retval);
+
+		for (size_t j = 0; j < ARRAY_SIZE(buf_types); j++) {
+			crop->type = buf_types[j].val;
+
+			ioctl(-1, crop_cmds[i].val, crop);
+			printf("ioctl(-1, %s, {type=%s, c={left=-2136948511"
+			       ", top=-2136948510, width=2158018787"
+			       ", height=2158018788}}) = %ld (INJECTED)\n",
+			       sprintxlat(crop_cmds[i].str, crop_cmds[i].val,
+					  NULL),
+			       buf_types[j].str, inject_retval);
+		}
+	}
+
+
+#ifdef VIDIOC_S_EXT_CTRLS
+	/* VIDIOC_S_EXT_CTRLS, VIDIOC_TRY_EXT_CTRLS, VIDIOC_G_EXT_CTRLS */
+	static const struct strval32 ectrl_cmds[] = {
+		{ ARG_STR(VIDIOC_S_EXT_CTRLS) },
+		{ ARG_STR(VIDIOC_TRY_EXT_CTRLS) },
+		{ ARG_STR(VIDIOC_G_EXT_CTRLS) },
+	};
+	/* static const struct strval32 ectrl_which = {
+	}; */
+
+	struct v4l2_ext_controls *ectrls = tail_alloc(sizeof(*ectrls));
+	/* struct v4l2_ext_control *ectrl = tail_alloc(sizeof(*ectrl) * 2); */
+
+	for (size_t i = 0; i < ARRAY_SIZE(ectrl_cmds); i++) {
+		fill_memory32(ectrls, sizeof(*ectrls));
+
+		ioctl(-1, ectrl_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(ectrl_cmds[i].str, ectrl_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, ectrl_cmds[i].val, (char *) ectrls + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(ectrl_cmds[i].str, ectrl_cmds[i].val, NULL),
+		       (char *) ectrls + 1, inject_retval);
+	}
+
+#endif /* VIDIOC_S_EXT_CTRLS */
+
+
+#ifdef HAVE_STRUCT_V4L2_FRMSIZEENUM
+	/* VIDIOC_ENUM_FRAMESIZES */
+	static const struct strval32 frmsz_simple_types[] = {
+		{ ARG_XLAT_UNKNOWN(0, "V4L2_FRMSIZE_TYPE_???") },
+		{ ARG_XLAT_KNOWN(0x2, "V4L2_FRMSIZE_TYPE_CONTINUOUS") },
+		{ ARG_XLAT_UNKNOWN(0x4, "V4L2_FRMSIZE_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0xdeadf157, "V4L2_FRMSIZE_TYPE_???") },
+	};
+
+	struct v4l2_frmsizeenum *fse = tail_alloc(sizeof(*fse));
+
+	ioctl(-1, VIDIOC_ENUM_FRAMESIZES, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMESIZES), inject_retval);
+
+	ioctl(-1, VIDIOC_ENUM_FRAMESIZES, (char *) fse + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMESIZES), (char *) fse + 1,
+	       inject_retval);
+
+	fill_memory32(fse, sizeof(*fse));
+	fse->type = V4L2_FRMSIZE_TYPE_DISCRETE;
+
+	ioctl(-1, VIDIOC_ENUM_FRAMESIZES, fse);
+	printf("ioctl(-1, %s, {index=2158018784, pixel_format="
+	       RAW("0x80a0c0e1")
+	       NRAW("v4l2_fourcc('\\xe1', '\\xc0', '\\xa0', '\\x80')")
+	       ", type=" XLAT_KNOWN(0x1, "V4L2_FRMSIZE_TYPE_DISCRETE")
+	       ", discrete={width=2158018787, height=2158018788}"
+	       "}) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMESIZES), inject_retval);
+
+	fse->pixel_format = 0x5c22270d;
+	fse->type = V4L2_FRMSIZE_TYPE_STEPWISE;
+
+	ioctl(-1, VIDIOC_ENUM_FRAMESIZES, fse);
+	printf("ioctl(-1, %s, {index=2158018784, pixel_format="
+	       RAW("0x5c22270d")
+	       NRAW("v4l2_fourcc('\\x0d', '\\\'', '\"', '\\\\')")
+	       ", type=" XLAT_KNOWN(0x3, "V4L2_FRMSIZE_TYPE_STEPWISE")
+	       ", stepwise={min_width=2158018787, max_width=2158018788"
+	       ", step_width=2158018789, min_height=2158018790"
+	       ", max_height=2158018791, step_height=2158018792}"
+	       "}) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMESIZES), inject_retval);
+
+	for (size_t i = 0; i < ARRAY_SIZE(frmsz_simple_types); i++) {
+		fill_memory32(fse, sizeof(*fse));
+		fse->type = frmsz_simple_types[i].val;
+
+		ioctl(-1, VIDIOC_ENUM_FRAMESIZES, fse);
+		printf("ioctl(-1, %s, {index=2158018784, pixel_format="
+		       RAW("0x80a0c0e1")
+		       NRAW("v4l2_fourcc('\\xe1', '\\xc0', '\\xa0', '\\x80')")
+		       ", type=%s}) = %ld (INJECTED)\n",
+		       XLAT_STR(VIDIOC_ENUM_FRAMESIZES),
+		       frmsz_simple_types[i].str, inject_retval);
+
+	}
+#endif /* HAVE_STRUCT_V4L2_FRMSIZEENUM */
+
+
+#ifdef HAVE_STRUCT_V4L2_FRMIVALENUM
+	/* VIDIOC_ENUM_FRAMEINTERVALS */
+	static const struct strval32 frmival_simple_types[] = {
+		{ ARG_XLAT_UNKNOWN(0, "V4L2_FRMIVAL_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0x4, "V4L2_FRMIVAL_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0xdeadf157, "V4L2_FRMIVAL_TYPE_???") },
+	};
+	static const struct strval32 frmival_step_types[] = {
+		{ ARG_XLAT_KNOWN(0x2, "V4L2_FRMIVAL_TYPE_CONTINUOUS") },
+		{ ARG_XLAT_KNOWN(0x3, "V4L2_FRMIVAL_TYPE_STEPWISE") },
+	};
+
+	struct v4l2_frmivalenum *fie = tail_alloc(sizeof(*fie));
+
+	ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMEINTERVALS), inject_retval);
+
+	ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, (char *) fie + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMEINTERVALS), (char *) fie + 1,
+	       inject_retval);
+
+	fill_memory32(fie, sizeof(*fie));
+	fie->type = V4L2_FRMIVAL_TYPE_DISCRETE;
+
+	ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, fie);
+	printf("ioctl(-1, %s, {index=2158018784, pixel_format="
+	       RAW("0x80a0c0e1")
+	       NRAW("v4l2_fourcc('\\xe1', '\\xc0', '\\xa0', '\\x80')")
+	       ", width=2158018786, height=2158018787"
+	       ", type=" XLAT_KNOWN(0x1, "V4L2_FRMIVAL_TYPE_DISCRETE")
+	       ", discrete=2158018789/2158018790}) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMEINTERVALS), inject_retval);
+
+	fie->pixel_format = 0x5c22270d;
+
+	for (size_t i = 0; i < ARRAY_SIZE(frmival_step_types); i++) {
+		fie->type = frmival_step_types[i].val;
+
+		ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, fie);
+		printf("ioctl(-1, %s, {index=2158018784, pixel_format="
+		       RAW("0x5c22270d")
+		       NRAW("v4l2_fourcc('\\x0d', '\\\'', '\"', '\\\\')")
+		       ", width=2158018786, height=2158018787, type=%s"
+		       ", stepwise={min=2158018789/2158018790"
+		       ", max=2158018791/2158018792"
+		       ", step=2158018793/2158018794}}) = %ld (INJECTED)\n",
+		       XLAT_STR(VIDIOC_ENUM_FRAMEINTERVALS),
+		       frmival_step_types[i].str, inject_retval);
+	}
+
+	for (size_t i = 0; i < ARRAY_SIZE(frmival_simple_types); i++) {
+		fill_memory32(fie, sizeof(*fie));
+		fie->type = frmival_simple_types[i].val;
+
+		ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, fie);
+		printf("ioctl(-1, %s, {index=2158018784, pixel_format="
+		       RAW("0x80a0c0e1")
+		       NRAW("v4l2_fourcc('\\xe1', '\\xc0', '\\xa0', '\\x80')")
+	               ", width=2158018786, height=2158018787, type=%s})"
+		       " = %ld (INJECTED)\n",
+		       XLAT_STR(VIDIOC_ENUM_FRAMEINTERVALS),
+		       frmival_simple_types[i].str, inject_retval);
+
+	}
+#endif /* HAVE_STRUCT_V4L2_FRMIVALENUM */
+
+
+#ifdef HAVE_STRUCT_V4L2_CREATE_BUFFERS
+	/* VIDIOC_CREATE_BUFS */
+	struct v4l2_create_buffers *cbuf = tail_alloc(sizeof(*cbuf));
+
+	fill_memory32(cbuf, sizeof(*cbuf));
+
+	ioctl(-1, VIDIOC_CREATE_BUFS, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_CREATE_BUFS), inject_retval);
+
+	ioctl(-1, VIDIOC_CREATE_BUFS, (char *) cbuf + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_CREATE_BUFS), (char *) cbuf + 1, inject_retval);
+
+	for (size_t i = 0; i < MAX(ARRAY_SIZE(buf_types),
+				   ARRAY_SIZE(reqb_mems)); i++) {
+		cbuf->memory = reqb_mems[i % ARRAY_SIZE(reqb_mems)].val;
+		cbuf->format.type = buf_types[i % ARRAY_SIZE(buf_types)].val;
+		if (!fill_fmt(&cbuf->format))
+			continue;
+
+		ioctl(-1, VIDIOC_CREATE_BUFS, cbuf);
+		printf("ioctl(-1, %s, {count=2158018785, memory=%s"
+		       ", format={type=%s",
+		       XLAT_STR(VIDIOC_CREATE_BUFS),
+		       reqb_mems[i % ARRAY_SIZE(reqb_mems)].str,
+		       buf_types[i % ARRAY_SIZE(buf_types)].str);
+		print_fmt(", ", &cbuf->format);
+		printf("}}) = %ld ({index=2158018784, count=2158018785})"
+		       " (INJECTED)\n", inject_retval);
+	}
+#endif /* HAVE_STRUCT_V4L2_CREATE_BUFFERS */
+
+	puts("+++ exited with 0 +++");
+
+	return 0;
+}
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-success.gen.test 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success.gen.test
--- 5.5-3/tests-m32/ioctl_v4l2-success.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-success +ioctl-success.sh -a29); do not edit.
+set -- -a29
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-success-v.c 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-v.c
--- 5.5-3/tests-m32/ioctl_v4l2-success-v.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-v.c	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,2 @@
+#define VERBOSE 1
+#include "ioctl_v4l2-success.c"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-success-v.gen.test 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-v.gen.test
--- 5.5-3/tests-m32/ioctl_v4l2-success-v.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-v.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-success-v +ioctl-success.sh -a29 -v); do not edit.
+set -- -a29 -v
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-success-v-Xabbrev.c 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-v-Xabbrev.c
--- 5.5-3/tests-m32/ioctl_v4l2-success-v-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-v-Xabbrev.c	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "ioctl_v4l2-success-v.c"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-success-v-Xabbrev.gen.test 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-v-Xabbrev.gen.test
--- 5.5-3/tests-m32/ioctl_v4l2-success-v-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-v-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-success-v-Xabbrev +ioctl-success.sh -a29 -v -Xabbrev); do not edit.
+set -- -a29 -v -Xabbrev
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-success-v-Xraw.c 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-v-Xraw.c
--- 5.5-3/tests-m32/ioctl_v4l2-success-v-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-v-Xraw.c	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "ioctl_v4l2-success-v.c"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-success-v-Xraw.gen.test 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-v-Xraw.gen.test
--- 5.5-3/tests-m32/ioctl_v4l2-success-v-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-v-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-success-v-Xraw +ioctl-success.sh -a27 -v -Xraw); do not edit.
+set -- -a27 -v -Xraw
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-success-v-Xverbose.c 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-v-Xverbose.c
--- 5.5-3/tests-m32/ioctl_v4l2-success-v-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-v-Xverbose.c	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "ioctl_v4l2-success-v.c"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-success-v-Xverbose.gen.test 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-v-Xverbose.gen.test
--- 5.5-3/tests-m32/ioctl_v4l2-success-v-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-v-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-success-v-Xverbose +ioctl-success.sh -a29 -v -Xverbose); do not edit.
+set -- -a29 -v -Xverbose
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-success-Xabbrev.c 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-Xabbrev.c
--- 5.5-3/tests-m32/ioctl_v4l2-success-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-Xabbrev.c	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "ioctl_v4l2-success.c"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-success-Xabbrev.gen.test 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-Xabbrev.gen.test
--- 5.5-3/tests-m32/ioctl_v4l2-success-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-success-Xabbrev +ioctl-success.sh -a29 -Xabbrev); do not edit.
+set -- -a29 -Xabbrev
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-success-Xraw.c 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-Xraw.c
--- 5.5-3/tests-m32/ioctl_v4l2-success-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-Xraw.c	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "ioctl_v4l2-success.c"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-success-Xraw.gen.test 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-Xraw.gen.test
--- 5.5-3/tests-m32/ioctl_v4l2-success-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-success-Xraw +ioctl-success.sh -a27 -Xraw); do not edit.
+set -- -a27 -Xraw
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-success-Xverbose.c 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-Xverbose.c
--- 5.5-3/tests-m32/ioctl_v4l2-success-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-Xverbose.c	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "ioctl_v4l2-success.c"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-success-Xverbose.gen.test 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-Xverbose.gen.test
--- 5.5-3/tests-m32/ioctl_v4l2-success-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-success-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-success-Xverbose +ioctl-success.sh -a30 -Xverbose); do not edit.
+set -- -a30 -Xverbose
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-v.c 5.9-0ubuntu2/tests-m32/ioctl_v4l2-v.c
--- 5.5-3/tests-m32/ioctl_v4l2-v.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-v.c	2020-03-28 16:57:34.000000000 +0000
@@ -0,0 +1,3 @@
+/* This file is part of ioctl_v4l2-v strace test. */
+#define VERBOSE 1
+#include "ioctl_v4l2.c"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-v.gen.test 5.9-0ubuntu2/tests-m32/ioctl_v4l2-v.gen.test
--- 5.5-3/tests-m32/ioctl_v4l2-v.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-v.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-v +ioctl.test -v); do not edit.
+set -- -v
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-v-Xabbrev.c 5.9-0ubuntu2/tests-m32/ioctl_v4l2-v-Xabbrev.c
--- 5.5-3/tests-m32/ioctl_v4l2-v-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-v-Xabbrev.c	2020-03-28 16:57:34.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "ioctl_v4l2-v.c"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-v-Xabbrev.gen.test 5.9-0ubuntu2/tests-m32/ioctl_v4l2-v-Xabbrev.gen.test
--- 5.5-3/tests-m32/ioctl_v4l2-v-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-v-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-v-Xabbrev +ioctl.test -v -Xabbrev); do not edit.
+set -- -v -Xabbrev
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-v-Xraw.c 5.9-0ubuntu2/tests-m32/ioctl_v4l2-v-Xraw.c
--- 5.5-3/tests-m32/ioctl_v4l2-v-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-v-Xraw.c	2020-03-28 16:57:34.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "ioctl_v4l2-v.c"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-v-Xraw.gen.test 5.9-0ubuntu2/tests-m32/ioctl_v4l2-v-Xraw.gen.test
--- 5.5-3/tests-m32/ioctl_v4l2-v-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-v-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-v-Xraw +ioctl.test -v -Xraw); do not edit.
+set -- -v -Xraw
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-v-Xverbose.c 5.9-0ubuntu2/tests-m32/ioctl_v4l2-v-Xverbose.c
--- 5.5-3/tests-m32/ioctl_v4l2-v-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-v-Xverbose.c	2020-03-28 16:57:34.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "ioctl_v4l2-v.c"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-v-Xverbose.gen.test 5.9-0ubuntu2/tests-m32/ioctl_v4l2-v-Xverbose.gen.test
--- 5.5-3/tests-m32/ioctl_v4l2-v-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-v-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-v-Xverbose +ioctl.test -v -Xverbose); do not edit.
+set -- -v -Xverbose
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-Xabbrev.c 5.9-0ubuntu2/tests-m32/ioctl_v4l2-Xabbrev.c
--- 5.5-3/tests-m32/ioctl_v4l2-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-Xabbrev.c	2020-03-28 16:57:34.000000000 +0000
@@ -0,0 +1 @@
+#include "ioctl_v4l2.c"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-Xabbrev.gen.test 5.9-0ubuntu2/tests-m32/ioctl_v4l2-Xabbrev.gen.test
--- 5.5-3/tests-m32/ioctl_v4l2-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-Xabbrev +ioctl.test -Xabbrev); do not edit.
+set -- -Xabbrev
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-Xraw.c 5.9-0ubuntu2/tests-m32/ioctl_v4l2-Xraw.c
--- 5.5-3/tests-m32/ioctl_v4l2-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-Xraw.c	2020-03-28 16:57:34.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "ioctl_v4l2.c"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-Xraw.gen.test 5.9-0ubuntu2/tests-m32/ioctl_v4l2-Xraw.gen.test
--- 5.5-3/tests-m32/ioctl_v4l2-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-Xraw +ioctl.test -Xraw); do not edit.
+set -- -Xraw
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-Xverbose.c 5.9-0ubuntu2/tests-m32/ioctl_v4l2-Xverbose.c
--- 5.5-3/tests-m32/ioctl_v4l2-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-Xverbose.c	2020-03-28 16:57:34.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "ioctl_v4l2.c"
diff -pruN 5.5-3/tests-m32/ioctl_v4l2-Xverbose.gen.test 5.9-0ubuntu2/tests-m32/ioctl_v4l2-Xverbose.gen.test
--- 5.5-3/tests-m32/ioctl_v4l2-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioctl_v4l2-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-Xverbose +ioctl.test -Xverbose); do not edit.
+set -- -Xverbose
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-m32/ioprio.c 5.9-0ubuntu2/tests-m32/ioprio.c
--- 5.5-3/tests-m32/ioprio.c	2019-09-24 15:31:28.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioprio.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,15 +2,15 @@
  * Check decoding of ioprio_get and ioprio_set syscalls.
  *
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-
 #include "scno.h"
+#include "pidns.h"
 
 #if defined(__NR_ioprio_get) && defined(__NR_ioprio_set)
 
@@ -30,12 +30,18 @@ enum {
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	static const kernel_ulong_t bogus_which =
 		(kernel_ulong_t) 0xdeadfacefa57beefULL;
 	static const kernel_ulong_t bogus_who =
 		(kernel_ulong_t) 0xbadc0dedda7a1057ULL;
 	static const kernel_ulong_t bogus_ioprio =
 		(kernel_ulong_t) 0xdec0ded1facefeedULL;
+
+	const int pid = getpid();
+	const int pgid = getpgid(0);
+
 # if !XLAT_RAW
 	static const char * const bogus_ioprio_str =
 		"IOPRIO_PRIO_VALUE(0x7d677 /* IOPRIO_CLASS_??? */, 7917)";
@@ -46,6 +52,7 @@ main(void)
 
 	rc = syscall(__NR_ioprio_get, bogus_which, bogus_who);
 	errstr = sprintrc(rc);
+	pidns_print_leader();
 # if XLAT_RAW
 	printf("ioprio_get(%#x, %d) = %s\n",
 	       (int) bogus_which, (int) bogus_who, errstr);
@@ -54,42 +61,52 @@ main(void)
 	       (int) bogus_which, (int) bogus_who, errstr);
 # endif
 
-	rc = syscall(__NR_ioprio_get, 1, 0);
+	rc = syscall(__NR_ioprio_get, 1, pid);
 	errstr = sprintrc(rc);
+	pidns_print_leader();
+	printf("ioprio_get(");
 # if XLAT_RAW
-	printf("ioprio_get(0x1, 0) = %s\n", errstr);
+	printf("0x1, ");
+# elif XLAT_VERBOSE
+	printf("0x1 /* IOPRIO_WHO_PROCESS */, ");
 # else /* XLAT_ABBREV */
-#  if XLAT_VERBOSE
-	printf("ioprio_get(0x1 /* IOPRIO_WHO_PROCESS */, 0) = %s", errstr);
-#  else
-	printf("ioprio_get(IOPRIO_WHO_PROCESS, 0) = %s", errstr);
-#  endif
+	printf("IOPRIO_WHO_PROCESS, ");
+# endif
+	printf("%d%s) = %s", pid, pidns_pid2str(PT_TGID), errstr);
+# if !XLAT_RAW
 	if (rc >= 0) {
 		printf(" (IOPRIO_PRIO_VALUE(");
 		printxval(ioprio_class, (unsigned int) rc >> 13,
 			  "IOPRIO_CLASS_???");
 		printf(", %u))", (unsigned int) rc & 0x1fff);
 	}
-	puts("");
 # endif
+	puts("");
 
-	rc = syscall(__NR_ioprio_set, 2, 0, 8191);
+	rc = syscall(__NR_ioprio_set, 2, pgid, 8191);
 	errstr = sprintrc(rc);
+	pidns_print_leader();
+	printf("ioprio_set(");
 # if XLAT_RAW
-	printf("ioprio_set(%#x, 0, 8191) = %s\n", 2, errstr);
+	printf("%#x", 2);
 # elif XLAT_VERBOSE
-	printf("ioprio_set(%#x /* IOPRIO_WHO_PGRP */, 0, 8191"
-	       " /* IOPRIO_PRIO_VALUE(0 /* IOPRIO_CLASS_NONE */, 8191) */)"
-	       " = %s\n",
-	       2, errstr);
+	printf("%#x /* IOPRIO_WHO_PGRP */", 2);
 # else /* XLAT_ABBREV */
-	printf("ioprio_set(IOPRIO_WHO_PGRP, 0"
-	       ", IOPRIO_PRIO_VALUE(IOPRIO_CLASS_NONE, 8191)) = %s\n",
-	       errstr);
+	printf("IOPRIO_WHO_PGRP");
+# endif
+	printf(", %d%s", pgid, pidns_pid2str(PT_PGID));
+# if XLAT_RAW
+	printf(", 8191)");
+# elif XLAT_VERBOSE
+	printf(", 8191 /* IOPRIO_PRIO_VALUE(0 /* IOPRIO_CLASS_NONE */, 8191) */)");
+# else /* XLAT_ABBREV */
+	printf(", IOPRIO_PRIO_VALUE(IOPRIO_CLASS_NONE, 8191))");
 # endif
+	printf(" = %s\n", errstr);
 
 	rc = syscall(__NR_ioprio_set, bogus_which, bogus_who, bogus_ioprio);
 	errstr = sprintrc(rc);
+	pidns_print_leader();
 # if XLAT_RAW
 	printf("ioprio_set(%#x, %d, %d) = %s\n",
 	       (int) bogus_which, (int) bogus_who, (int) bogus_ioprio,
@@ -104,6 +121,7 @@ main(void)
 	       errstr);
 # endif
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 
 	return 0;
diff -pruN 5.5-3/tests-m32/ioprio--pidns-translation.c 5.9-0ubuntu2/tests-m32/ioprio--pidns-translation.c
--- 5.5-3/tests-m32/ioprio--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioprio--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "ioprio.c"
diff -pruN 5.5-3/tests-m32/ioprio--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/ioprio--pidns-translation.gen.test
--- 5.5-3/tests-m32/ioprio--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ioprio--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioprio--pidns-translation test_pidns -a18 -e trace=ioprio_get,ioprio_set); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a18 -e trace=ioprio_get,ioprio_set
diff -pruN 5.5-3/tests-m32/io_uring_register.c 5.9-0ubuntu2/tests-m32/io_uring_register.c
--- 5.5-3/tests-m32/io_uring_register.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/io_uring_register.c	2020-06-28 08:00:00.000000000 +0000
@@ -25,16 +25,21 @@
 # endif
 
 /* From tests/bpf.c */
-#if defined MPERS_IS_m32 || SIZEOF_KERNEL_LONG_T > 4
-# define BIG_ADDR_MAYBE(addr_)
-#elif defined __arm__ || defined __i386__ || defined __mips__ \
+# if defined MPERS_IS_m32 || SIZEOF_KERNEL_LONG_T > 4
+#  define BIG_ADDR_MAYBE(addr_)
+# elif defined __arm__ || defined __i386__ || defined __mips__ \
    || defined __powerpc__ || defined __riscv__ || defined __s390__ \
    || defined __sparc__ || defined __tile__
-# define BIG_ADDR_MAYBE(addr_) addr_ " or "
-#else
-# define BIG_ADDR_MAYBE(addr_)
-#endif
+#  define BIG_ADDR_MAYBE(addr_) addr_ " or "
+# else
+#  define BIG_ADDR_MAYBE(addr_)
+# endif
 
+# if WORDS_BIGENDIAN
+#  define BE_LE(be_, le_) be_
+# else
+#  define BE_LE(be_, le_) le_
+# endif
 
 static const char *errstr;
 
@@ -81,12 +86,12 @@ main(void)
 
 	int fd_full = open(path_full, O_RDONLY);
 	if (fd_full < 0)
-		perror_msg_and_fail("open: %s", path_null);
+		perror_msg_and_fail("open: %s", path_full);
 
 	int fds[] = { fd_full, fd_null };
 	const int *arg_fds = tail_memdup(fds, sizeof(fds));
 
-	static const unsigned int invalid_ops[] = { 0xbadc0dedU, 7 };
+	static const unsigned int invalid_ops[] = { 0xbadc0dedU, 11 };
 
 	for (size_t i = 0; i < ARRAY_SIZE(invalid_ops); i++) {
 		sys_io_uring_register(fd_null, invalid_ops[i], path_null,
@@ -104,6 +109,8 @@ main(void)
 		{ 1, "IORING_UNREGISTER_BUFFERS" },
 		{ 3, "IORING_UNREGISTER_FILES" },
 		{ 5, "IORING_UNREGISTER_EVENTFD" },
+		{ 9, "IORING_REGISTER_PERSONALITY" },
+		{ 10, "IORING_UNREGISTER_PERSONALITY" },
 	};
 
 	for (size_t i = 0; i < ARRAY_SIZE(no_arg_ops); i++) {
@@ -129,6 +136,7 @@ main(void)
 	} fd_arr_ops[] = {
 		{ 2, "IORING_REGISTER_FILES" },
 		{ 4, "IORING_REGISTER_EVENTFD" },
+		{ 7, "IORING_REGISTER_EVENTFD_ASYNC" },
 	};
 
 	for (size_t i = 0; i < ARRAY_SIZE(fd_arr_ops); i++) {
@@ -141,7 +149,7 @@ main(void)
 		       (unsigned int) ARRAY_SIZE(fds), errstr);
 	}
 
-#ifdef HAVE_STRUCT_IO_URING_FILES_UPDATE
+# ifdef HAVE_STRUCT_IO_URING_FILES_UPDATE
 	struct io_uring_files_update bogus_iufu;
 	struct io_uring_files_update iufu;
 
@@ -154,7 +162,8 @@ main(void)
 	sys_io_uring_register(fd_null, 6, &bogus_iufu, 0);
 	printf("io_uring_register(%u<%s>, IORING_REGISTER_FILES_UPDATE"
 	       ", {offset=%" PRIu32 ", resv=%#" PRIx32 ", fds="
-	       BIG_ADDR_MAYBE("0x8f8e8d8c8b8a8988") "[]}, 0) = %s\n",
+	       BIG_ADDR_MAYBE(BE_LE("0x88898a8b8c8d8e8f", "0x8f8e8d8c8b8a8988"))
+	       "[]}, 0) = %s\n",
 	       fd_null, path_null,
 	       ((uint32_t *) &bogus_iufu)[0], ((uint32_t *) &bogus_iufu)[1],
 	       errstr);
@@ -167,7 +176,111 @@ main(void)
 	       ", {offset=3735929054, fds=[%u<%s>, %u<%s>]}, %u) = %s\n",
 	       fd_null, path_null, fd_full, path_full, fd_null, path_null,
 	       (unsigned int) ARRAY_SIZE(fds), errstr);
-#endif
+# endif
+
+# ifdef HAVE_STRUCT_IO_URING_PROBE
+	struct io_uring_probe *probe = tail_alloc(sizeof(*probe) +
+		       (DEFAULT_STRLEN + 1) * sizeof(struct io_uring_probe_op));
+
+	sys_io_uring_register(fd_null, IORING_REGISTER_PROBE, NULL, 0xfacefeed);
+	printf("io_uring_register(%u<%s>, IORING_REGISTER_PROBE"
+	       ", NULL, 4207869677) = %s\n",
+	       fd_null, path_null, errstr);
+
+	sys_io_uring_register(fd_null, IORING_REGISTER_PROBE, probe,
+			      0xfacefeed);
+	printf("io_uring_register(%u<%s>, IORING_REGISTER_PROBE"
+	       ", %p, 4207869677) = %s\n",
+	       fd_null, path_null, probe, errstr);
+
+	sys_io_uring_register(fd_null, IORING_REGISTER_PROBE,
+			      (char *) probe + 1, DEFAULT_STRLEN + 1);
+	printf("io_uring_register(%u<%s>, IORING_REGISTER_PROBE"
+	       ", %p, %d) = %s\n",
+	       fd_null, path_null, (char *) probe + 1, DEFAULT_STRLEN + 1,
+	       errstr);
+
+	sys_io_uring_register(fd_null, IORING_REGISTER_PROBE, probe, 0);
+	printf("io_uring_register(%u<%s>, IORING_REGISTER_PROBE"
+	       ", {last_op=%u /* IORING_OP_??? */, ops_len=%hhu, resv=%#hx"
+	       ", resv2=[%#x, %#x, %#x], ops=[]}, 0) = %s\n",
+	       fd_null, path_null, probe->last_op, probe->ops_len, probe->resv,
+	       probe->resv2[0], probe->resv2[1], probe->resv2[2], errstr);
+
+	probe->last_op = IORING_OP_READV;
+	probe->resv = 0;
+	sys_io_uring_register(fd_null, IORING_REGISTER_PROBE, probe, 0);
+	printf("io_uring_register(%u<%s>, IORING_REGISTER_PROBE"
+	       ", {last_op=IORING_OP_READV, ops_len=%hhu"
+	       ", resv2=[%#x, %#x, %#x], ops=[]}, 0) = %s\n",
+	       fd_null, path_null, probe->ops_len,
+	       probe->resv2[0], probe->resv2[1], probe->resv2[2], errstr);
+
+	probe->last_op = IORING_OP_EPOLL_CTL;
+	probe->resv2[0] = 0;
+	probe->resv2[2] = 0;
+
+	probe->ops[0].op = IORING_OP_NOP;
+	probe->ops[0].resv = 0xde;
+	probe->ops[0].flags = 0;
+	probe->ops[0].resv2 = 0xbeefface;
+
+	probe->ops[1].op = 33;
+	probe->ops[1].resv = 0;
+	probe->ops[1].flags = IO_URING_OP_SUPPORTED;
+	probe->ops[1].resv2 = 0xdeadc0de;
+
+	probe->ops[2].op = 34;
+	probe->ops[2].resv = 0xaf;
+	probe->ops[2].flags = 0xbeef;
+	probe->ops[2].resv2 = 0;
+
+	probe->ops[3].op = 0xfe;
+	probe->ops[3].resv = 0;
+	probe->ops[3].flags = 0xc0de;
+	probe->ops[3].resv2 = 0;
+
+	sys_io_uring_register(fd_null, IORING_REGISTER_PROBE, probe, 4);
+	printf("io_uring_register(%u<%s>, IORING_REGISTER_PROBE"
+	       ", {last_op=IORING_OP_EPOLL_CTL, ops_len=%hhu"
+	       ", resv2=[0, %#x, 0], ops=["
+	       "{op=IORING_OP_NOP, resv=0xde, flags=0, resv2=0xbeefface}, "
+	       "{op=IORING_OP_TEE, flags=IO_URING_OP_SUPPORTED"
+	       ", resv2=0xdeadc0de}, "
+	       "{op=34 /* IORING_OP_??? */, resv=0xaf"
+	       ", flags=IO_URING_OP_SUPPORTED|0xbeee}, "
+	       "{op=254 /* IORING_OP_??? */"
+	       ", flags=0xc0de /* IO_URING_OP_??? */}]}, 4) = %s\n",
+	       fd_null, path_null, probe->ops_len, probe->resv2[1], errstr);
+
+	probe->last_op = 34;
+	probe->resv2[1] = 0;
+	fill_memory_ex(probe->ops, sizeof(probe->ops[0]) * (DEFAULT_STRLEN + 1),
+		    0x40, 0x80);
+	sys_io_uring_register(fd_null, IORING_REGISTER_PROBE, probe,
+			      DEFAULT_STRLEN + 1);
+	printf("io_uring_register(%u<%s>, IORING_REGISTER_PROBE"
+	       ", {last_op=34 /* IORING_OP_??? */, ops_len=%hhu, ops=[",
+	       fd_null, path_null, probe->ops_len);
+	for (size_t i = 0; i < DEFAULT_STRLEN; i++) {
+		printf("%s{op=%u /* IORING_OP_??? */, resv=%#hhx"
+		       ", flags=%s%#hx%s, resv2=%#x}",
+		       i ? ", " : "",
+		       probe->ops[i].op, probe->ops[i].resv,
+		       probe->ops[i].flags & 1 ? "IO_URING_OP_SUPPORTED|" : "",
+		       (typeof(probe->ops[i].flags)) (probe->ops[i].flags & ~1),
+		       probe->ops[i].flags & 1 ? "" : " /* IO_URING_OP_??? */",
+		       probe->ops[i].resv2);
+	}
+	printf(", ...]}, %d) = %s\n", DEFAULT_STRLEN + 1, errstr);
+
+	probe->last_op = 0;
+	probe->ops_len = 0;
+	memset(probe->ops, 0, sizeof(probe->ops[0]) * (DEFAULT_STRLEN + 1));
+	sys_io_uring_register(fd_null, IORING_REGISTER_PROBE, probe, 8);
+	printf("io_uring_register(%u<%s>, IORING_REGISTER_PROBE, %p, 8) = %s\n",
+	       fd_null, path_null, probe, errstr);
+# endif
 
 	puts("+++ exited with 0 +++");
 	return 0;
diff -pruN 5.5-3/tests-m32/io_uring_setup.c 5.9-0ubuntu2/tests-m32/io_uring_setup.c
--- 5.5-3/tests-m32/io_uring_setup.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/io_uring_setup.c	2020-09-23 16:29:35.000000000 +0000
@@ -27,6 +27,7 @@
 # include "xlat.h"
 
 # include "xlat/uring_setup_features.h"
+# include "xlat/uring_cqring_flags.h"
 
 # ifdef HAVE_STRUCT_IO_URING_PARAMS_FEATURES
 #  ifdef HAVE_STRUCT_IO_URING_PARAMS_WQ_FD
@@ -144,20 +145,40 @@ main(void)
 						params->sq_off.resv2);
 
 			printf("}, cq_off={head=%u, tail=%u, ring_mask=%u"
-			       ", ring_entries=%u, overflow=%u, cqes=%u",
+			       ", ring_entries=%u, overflow=%u, cqes=%u, flags=",
 			       params->cq_off.head,
 			       params->cq_off.tail,
 			       params->cq_off.ring_mask,
 			       params->cq_off.ring_entries,
 			       params->cq_off.overflow,
 			       params->cq_off.cqes);
-			if (params->cq_off.resv[0] || params->cq_off.resv[1]) {
-				printf(", resv=[%#llx, %#llx]",
+# ifdef HAVE_STRUCT_IO_CQRING_OFFSETS_FLAGS
+			printflags(uring_cqring_flags,
+			       params->cq_off.flags,
+			       "IORING_CQ_???");
+			if (params->cq_off.resv1)
+				printf(", resv1=%#x", params->cq_off.resv1);
+			if (params->cq_off.resv2)
+				printf(", resv2=%#llx",
 				       (unsigned long long)
-						params->cq_off.resv[0],
+						params->cq_off.resv2);
+# else
+			union {
+				struct {
+					uint32_t flags;
+					uint32_t resv1;
+				} s;
+				uint64_t v;
+			} u = { .v = params->cq_off.resv[0] };
+			printflags(uring_cqring_flags, u.s.flags,
+				   "IORING_CQ_???");
+			if (u.s.resv1)
+				printf(", resv1=%#x", u.s.resv1);
+			if (params->cq_off.resv[1])
+				printf(", resv2=%#llx",
 				       (unsigned long long)
 						params->cq_off.resv[1]);
-			}
+# endif
 
 			printf("}}) = %ld<anon_inode:[io_uring]>\n", rc);
 		}
diff -pruN 5.5-3/tests-m32/ipc_msg.c 5.9-0ubuntu2/tests-m32/ipc_msg.c
--- 5.5-3/tests-m32/ipc_msg.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ipc_msg.c	2020-09-19 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2015 Elvira Khabirova <lineprinter0@gmail.com>
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -20,18 +20,24 @@
 # define MSG_STAT_ANY 13
 #endif
 
+#undef TEST_MSGCTL_BOGUS_ADDR
+
+/*
+ * Starting with commit glibc-2.32~83, on every 32-bit architecture
+ * where 32-bit time_t support is enabled, glibc tries to retrieve
+ * the data provided in the third argument of msgctl call.
+ */
+#if GLIBC_PREREQ_GE(2, 32) && defined __TIMESIZE && __TIMESIZE != 64
+# define TEST_MSGCTL_BOGUS_ADDR 0
+#endif
 /*
  * Before glibc-2.22-122-gbe48165, ppc64 code tried to retrieve data
  * provided in third argument of msgctl call (in case of IPC_SET cmd)
  * which led to segmentation fault.
  */
-#undef TEST_MSGCTL_BOGUS_ADDR
-#if defined __GLIBC__ && (defined POWERPC64 || defined POWERPC64LE)
-# if !(defined __GLIBC_MINOR__) \
-   || ((__GLIBC__ << 16) + __GLIBC_MINOR__ < (2 << 16) + 23)
-#  define TEST_MSGCTL_BOGUS_ADDR 0
-# endif
-#endif /* __GLIBC__ && (POWERPC64 || POWERPC64LE) */
+#if GLIBC_PREREQ_LT(2, 23) && (defined POWERPC64 || defined POWERPC64LE)
+# define TEST_MSGCTL_BOGUS_ADDR 0
+#endif
 
 #ifndef TEST_MSGCTL_BOGUS_ADDR
 # define TEST_MSGCTL_BOGUS_ADDR 1
@@ -43,6 +49,7 @@
 # define str_ipc_rmid "0"
 # define str_ipc_set "0x1"
 # define str_ipc_stat "0x2"
+# define str_ipc_info "0x3"
 # define str_msg_stat "0xb"
 # define str_msg_info "0xc"
 # define str_msg_stat_any "0xd"
@@ -55,6 +62,7 @@
 # define str_ipc_rmid "0 /\\* IPC_RMID \\*/"
 # define str_ipc_set "0x1 /\\* IPC_SET \\*/"
 # define str_ipc_stat "0x2 /\\* IPC_STAT \\*/"
+# define str_ipc_info "0x3 /\\* IPC_INFO \\*/"
 # define str_msg_stat "0xb /\\* MSG_STAT \\*/"
 # define str_msg_info "0xc /\\* MSG_INFO \\*/"
 # define str_msg_stat_any "0xd /\\* MSG_STAT_ANY \\*/"
@@ -66,6 +74,7 @@
 # define str_ipc_rmid "IPC_RMID"
 # define str_ipc_set "IPC_SET"
 # define str_ipc_stat "IPC_STAT"
+# define str_ipc_info "IPC_INFO"
 # define str_msg_stat "MSG_STAT"
 # define str_msg_info "MSG_INFO"
 # define str_msg_stat_any "MSG_STAT_ANY"
@@ -84,6 +93,68 @@ cleanup(void)
 	id = -1;
 }
 
+static void
+print_msginfo(const char *const str_ipc_cmd,
+	      const struct msginfo *const info,
+	      const int rc)
+{
+	if (rc < 0) {
+		printf("msgctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
+		       id, str_ipc_64, str_ipc_cmd, info, sprintrc_grep(rc));
+		return;
+	}
+
+	printf("msgctl\\(%d, (%s\\|)?%s, \\{msgpool=%d, msgmap=%d, msgmax=%d"
+	       ", msgmnb=%d, msgmni=%d, msgssz=%d, msgtql=%d, msgseg=%u\\}\\)"
+	       " = %d\n",
+	       id,
+	       str_ipc_64,
+	       str_ipc_cmd,
+	       info->msgpool,
+	       info->msgmap,
+	       info->msgmax,
+	       info->msgmnb,
+	       info->msgmni,
+	       info->msgssz,
+	       info->msgtql,
+	       (unsigned) info->msgseg,
+	       rc);
+}
+
+static void
+print_msqid_ds(const char *const str_ipc_cmd,
+	       const struct msqid_ds *const ds,
+	       const int rc)
+{
+	if (rc < 0) {
+		printf("msgctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
+		       id, str_ipc_64, str_ipc_cmd, ds, sprintrc_grep(rc));
+		return;
+	}
+
+	printf("msgctl\\(%d, (%s\\|)?%s, \\{msg_perm=\\{uid=%u"
+	       ", gid=%u, mode=%#o, key=%u, cuid=%u, cgid=%u\\}"
+	       ", msg_stime=%u, msg_rtime=%u, msg_ctime=%u, msg_qnum=%u"
+	       ", msg_qbytes=%u, msg_lspid=%d, msg_lrpid=%d\\}\\) = %d\n",
+	       id,
+	       str_ipc_64,
+	       str_ipc_cmd,
+	       (unsigned) ds->msg_perm.uid,
+	       (unsigned) ds->msg_perm.gid,
+	       (unsigned) ds->msg_perm.mode,
+	       (unsigned) ds->msg_perm.__key,
+	       (unsigned) ds->msg_perm.cuid,
+	       (unsigned) ds->msg_perm.cgid,
+	       (unsigned) ds->msg_stime,
+	       (unsigned) ds->msg_rtime,
+	       (unsigned) ds->msg_ctime,
+	       (unsigned) ds->msg_qnum,
+	       (unsigned) ds->msg_qbytes,
+	       (int) ds->msg_lspid,
+	       (int) ds->msg_lrpid,
+	       rc);
+}
+
 int
 main(void)
 {
@@ -98,7 +169,10 @@ main(void)
 	static const int bogus_flags = 0xface1e55 & ~IPC_CREAT;
 
 	int rc;
-	struct msqid_ds ds;
+	union {
+		struct msqid_ds ds;
+		struct msginfo info;
+	} buf;
 
 	rc = msgget(bogus_key, bogus_flags);
 	printf("msgget\\(%#llx, %s\\|%#04o\\) = %s\n",
@@ -123,39 +197,32 @@ main(void)
 	       sprintrc_grep(rc));
 #endif
 
-	if (msgctl(id, IPC_STAT, &ds))
+	rc = msgctl(id, IPC_STAT, &buf.ds);
+	if (rc < 0)
 		perror_msg_and_skip("msgctl IPC_STAT");
-	printf("msgctl\\(%d, (%s\\|)?%s, \\{msg_perm=\\{uid=%u"
-	       ", gid=%u, mode=%#o, key=%u, cuid=%u, cgid=%u\\}, msg_stime=%u"
-	       ", msg_rtime=%u, msg_ctime=%u, msg_qnum=%u, msg_qbytes=%u"
-	       ", msg_lspid=%u, msg_lrpid=%u\\}\\) = 0\n",
-	       id, str_ipc_64, str_ipc_stat,
-	       (unsigned) ds.msg_perm.uid, (unsigned) ds.msg_perm.gid,
-	       (unsigned) ds.msg_perm.mode, (unsigned) ds.msg_perm.__key,
-	       (unsigned) ds.msg_perm.cuid, (unsigned) ds.msg_perm.cgid,
-	       (unsigned) ds.msg_stime, (unsigned) ds.msg_rtime,
-	       (unsigned) ds.msg_ctime, (unsigned) ds.msg_qnum,
-	       (unsigned) ds.msg_qbytes, (unsigned) ds.msg_lspid,
-	       (unsigned) ds.msg_lrpid);
+	print_msqid_ds(str_ipc_stat, &buf.ds, rc);
 
-	if (msgctl(id, IPC_SET, &ds))
+	if (msgctl(id, IPC_SET, &buf.ds))
 		perror_msg_and_skip("msgctl IPC_SET");
 	printf("msgctl\\(%d, (%s\\|)?%s, \\{msg_perm=\\{uid=%u"
-	       ", gid=%u, mode=%#o\\}, ...\\}\\) = 0\n",
-	       id, str_ipc_64, str_ipc_set, (unsigned) ds.msg_perm.uid,
-	       (unsigned) ds.msg_perm.gid, (unsigned) ds.msg_perm.mode);
-
-	rc = msgctl(0, MSG_INFO, &ds);
-	printf("msgctl\\(0, (%s\\|)?%s, %p\\) = %s\n",
-	       str_ipc_64, str_msg_info, &ds, sprintrc_grep(rc));
+	       ", gid=%u, mode=%#o\\}, msg_qbytes=%u\\}\\) = 0\n",
+	       id, str_ipc_64, str_ipc_set,
+	       (unsigned) buf.ds.msg_perm.uid,
+	       (unsigned) buf.ds.msg_perm.gid,
+	       (unsigned) buf.ds.msg_perm.mode,
+	       (unsigned) buf.ds.msg_qbytes);
+
+	rc = msgctl(id, IPC_INFO, &buf.ds);
+	print_msginfo(str_ipc_info, &buf.info, rc);
 
-	rc = msgctl(id, MSG_STAT, &ds);
-	printf("msgctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
-	       id, str_ipc_64, str_msg_stat, &ds, sprintrc_grep(rc));
+	rc = msgctl(id, MSG_INFO, &buf.ds);
+	print_msginfo(str_msg_info, &buf.info, rc);
 
-	rc = msgctl(id, MSG_STAT_ANY, &ds);
-	printf("msgctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
-	       id, str_ipc_64, str_msg_stat_any, &ds, sprintrc_grep(rc));
+	rc = msgctl(id, MSG_STAT, &buf.ds);
+	print_msqid_ds(str_msg_stat, &buf.ds, rc);
+
+	rc = msgctl(id, MSG_STAT_ANY, &buf.ds);
+	print_msqid_ds(str_msg_stat_any, &buf.ds, rc);
 
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/ipc_sem.c 5.9-0ubuntu2/tests-m32/ipc_sem.c
--- 5.5-3/tests-m32/ipc_sem.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ipc_sem.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2015 Andreas Schwab <schwab@suse.de>
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -11,6 +11,7 @@
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <sys/sem.h>
 
 #include "xlat.h"
@@ -24,7 +25,9 @@
 # define str_ipc_flags "0xface1e00"
 # define str_ipc_private "0"
 # define str_ipc_rmid "0"
+# define str_ipc_set "0x1"
 # define str_ipc_stat "0x2"
+# define str_ipc_info "0x3"
 # define str_sem_stat "0x12"
 # define str_sem_info "0x13"
 # define str_sem_stat_any "0x14"
@@ -35,7 +38,9 @@
 	"0xface1e00 /\\* IPC_CREAT\\|IPC_EXCL\\|IPC_NOWAIT\\|0xface1000 \\*/"
 # define str_ipc_private "0 /\\* IPC_PRIVATE \\*/"
 # define str_ipc_rmid "0 /\\* IPC_RMID \\*/"
+# define str_ipc_set "0x1 /\\* IPC_SET \\*/"
 # define str_ipc_stat "0x2 /\\* IPC_STAT \\*/"
+# define str_ipc_info "0x3 /\\* IPC_INFO \\*/"
 # define str_sem_stat "0x12 /\\* SEM_STAT \\*/"
 # define str_sem_info "0x13 /\\* SEM_INFO \\*/"
 # define str_sem_stat_any "0x14 /\\* SEM_STAT_ANY \\*/"
@@ -45,7 +50,9 @@
 # define str_ipc_flags "IPC_CREAT\\|IPC_EXCL\\|IPC_NOWAIT\\|0xface1000"
 # define str_ipc_private "IPC_PRIVATE"
 # define str_ipc_rmid "IPC_RMID"
+# define str_ipc_set "IPC_SET"
 # define str_ipc_stat "IPC_STAT"
+# define str_ipc_info "IPC_INFO"
 # define str_sem_stat "SEM_STAT"
 # define str_sem_info "SEM_INFO"
 # define str_sem_stat_any "SEM_STAT_ANY"
@@ -72,6 +79,66 @@ cleanup(void)
 	id = -1;
 }
 
+static void
+print_semid_ds(const char *const str_ipc_cmd,
+              const struct semid_ds *const ds,
+              const int rc)
+{
+	if (rc < 0) {
+		printf("semctl\\(%d, 0, (%s\\|)?%s, (%p|\\[%p\\])\\) = %s\n",
+		       id, str_ipc_64, str_ipc_cmd, &ds, &ds,
+		       sprintrc_grep(rc));
+		return;
+	}
+	printf("semctl\\(%d, 0, (%s\\|)?%s, \\{sem_perm=\\{uid=%u, gid=%u"
+		", mode=%#o, key=%u, cuid=%u, cgid=%u\\}, sem_otime=%llu"
+		", sem_ctime=%llu, sem_nsems=%llu\\}\\) = %d\n",
+		id,
+		str_ipc_64,
+		str_ipc_cmd,
+		(unsigned) ds->sem_perm.uid,
+		(unsigned) ds->sem_perm.gid,
+		(unsigned) ds->sem_perm.mode,
+		(unsigned) ds->sem_perm.__key,
+		(unsigned) ds->sem_perm.cuid,
+		(unsigned) ds->sem_perm.cgid,
+		(unsigned long long) ds->sem_otime,
+		(unsigned long long) ds->sem_ctime,
+		(unsigned long long) ds->sem_nsems,
+		rc);
+}
+
+static void
+print_sem_info(const char *const str_ipc_cmd,
+               const struct seminfo *const info,
+               const int rc)
+{
+	if (rc < 0) {
+		printf("semctl\\(%d, 0, (%s\\|)?%s, (%p|\\[%p\\])\\) = %s\n",
+		       id, str_ipc_64, str_ipc_cmd, &info, &info,
+		       sprintrc_grep(rc));
+		return;
+	}
+
+	printf("semctl\\(%d, 0, (%s\\|)?%s, \\{semmap=%d, semmni=%d"
+	       ", semmns=%d, semmnu=%d, semmsl=%d, semopm=%d, semume=%d"
+	       ", semusz=%d, semvmx=%d, semaem=%d\\}\\) = %d\n",
+	       id,
+	       str_ipc_64,
+	       str_ipc_cmd,
+	       info->semmap,
+	       info->semmni,
+	       info->semmns,
+	       info->semmnu,
+	       info->semmsl,
+	       info->semopm,
+	       info->semume,
+	       info->semusz,
+	       info->semvmx,
+	       info->semaem,
+	       rc);
+}
+
 int
 main(void)
 {
@@ -91,6 +158,8 @@ main(void)
 	struct semid_ds ds;
 	struct seminfo info;
 
+	memset(&ds, 0, sizeof(ds));
+
 	rc = semget(bogus_key, bogus_size, bogus_flags);
 	printf("semget\\(%#llx, %d, %s\\|%#04o\\) = %s\n",
 	       zero_extend_signed_to_ull(bogus_key), bogus_size,
@@ -108,25 +177,41 @@ main(void)
 	       bogus_semid, bogus_semnum, str_ipc_64, str_bogus_cmd,
 	       bogus_arg, bogus_arg, sprintrc_grep(rc));
 
+	un.__buf = &info;
+	rc = semctl(id, 0, IPC_INFO, un);
+        print_sem_info(str_ipc_info, &info, rc);
+
+	rc = semctl(id, 0, SEM_INFO, un);
+        print_sem_info(str_sem_info, &info, rc);
+
 	un.buf = &ds;
-	if (semctl(id, 0, IPC_STAT, un))
+	rc = semctl(id, 0, IPC_STAT, un);
+	if (rc < 0)
 		perror_msg_and_skip("semctl IPC_STAT");
-	printf("semctl\\(%d, 0, (%s\\|)?%s, \\[?%p\\]?\\) = 0\n",
-	       id, str_ipc_64, str_ipc_stat, &ds);
+	print_semid_ds(str_ipc_stat, &ds, rc);
 
-	un.__buf = &info;
-	rc = semctl(0, 0, SEM_INFO, un);
-	printf("semctl\\(0, 0, (%s\\|)?%s, \\[?%p\\]?\\) = %s\n",
-	       str_ipc_64, str_sem_info, &info, sprintrc_grep(rc));
+	if (semctl(id, 0, IPC_SET, un))
+		perror_msg_and_skip("semctl IPC_SET");
+	printf("semctl\\(%d, 0, (%s\\|)?%s, \\{sem_perm=\\{uid=%u, gid=%u"
+	       ", mode=%#o\\}\\}\\) = 0\n",
+	       id, str_ipc_64, str_ipc_set,
+	       (unsigned) ds.sem_perm.uid,
+	       (unsigned) ds.sem_perm.gid,
+	       (unsigned) ds.sem_perm.mode);
 
-	un.buf = &ds;
 	rc = semctl(id, 0, SEM_STAT, un);
-	printf("semctl\\(%d, 0, (%s\\|)?%s, \\[?%p\\]?\\) = %s\n",
-	       id, str_ipc_64, str_sem_stat, &ds, sprintrc_grep(rc));
+	print_semid_ds(str_sem_stat, &ds, rc);
 
+/*
+ * glibc fails to pass the buffer for SEM_STAT_ANY command,
+ * so the kernel receives garbage instead of un.buf address:
+ * https://sourceware.org/bugzilla/show_bug.cgi?id=26637
+ * musl doesn't pass the buffer either.
+ */
+#if 0
 	rc = semctl(id, 0, SEM_STAT_ANY, un);
-	printf("semctl\\(%d, 0, (%s\\|)?%s, (%p|\\[(%p|NULL)\\]|NULL)\\) = %s\n",
-	       id, str_ipc_64, str_sem_stat_any, &ds, &ds, sprintrc_grep(rc));
+	print_semid_ds(str_sem_stat_any, &ds, rc);
+#endif
 
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/ipc_shm.c 5.9-0ubuntu2/tests-m32/ipc_shm.c
--- 5.5-3/tests-m32/ipc_shm.c	2019-11-28 19:30:05.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ipc_shm.c	2020-09-19 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2015 Elvira Khabirova <lineprinter0@gmail.com>
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -39,6 +39,7 @@
 # define str_ipc_rmid "0"
 # define str_ipc_set "0x1"
 # define str_ipc_stat "0x2"
+# define str_ipc_info "0x3"
 # define str_shm_stat "0xd"
 # define str_shm_info "0xe"
 # define str_shm_stat_any "0xf"
@@ -53,6 +54,7 @@
 # define str_ipc_rmid "0 /\\* IPC_RMID \\*/"
 # define str_ipc_set "0x1 /\\* IPC_SET \\*/"
 # define str_ipc_stat "0x2 /\\* IPC_STAT \\*/"
+# define str_ipc_info "0x3 /\\* IPC_INFO \\*/"
 # define str_shm_stat "0xd /\\* SHM_STAT \\*/"
 # define str_shm_info "0xe /\\* SHM_INFO \\*/"
 # define str_shm_stat_any "0xf /\\* SHM_STAT_ANY \\*/"
@@ -66,6 +68,7 @@
 # define str_ipc_rmid "IPC_RMID"
 # define str_ipc_set "IPC_SET"
 # define str_ipc_stat "IPC_STAT"
+# define str_ipc_info "IPC_INFO"
 # define str_shm_stat "SHM_STAT"
 # define str_shm_info "SHM_INFO"
 # define str_shm_stat_any "SHM_STAT_ANY"
@@ -73,6 +76,21 @@
 # define str_bogus_cmd "0xdefaced2 /\\* SHM_\\?\\?\\? \\*/"
 #endif
 
+#undef TEST_SHMCTL_BOGUS_ADDR
+
+/*
+ * Starting with commit glibc-2.32~80, on every 32-bit architecture
+ * where 32-bit time_t support is enabled, glibc tries to retrieve
+ * the data provided in the third argument of shmctl call.
+ */
+#if GLIBC_PREREQ_GE(2, 32) && defined __TIMESIZE && __TIMESIZE != 64
+# define TEST_SHMCTL_BOGUS_ADDR 0
+#endif
+
+#ifndef TEST_SHMCTL_BOGUS_ADDR
+# define TEST_SHMCTL_BOGUS_ADDR 1
+#endif
+
 static int id = -1;
 
 static void
@@ -84,6 +102,89 @@ cleanup(void)
 	id = -1;
 }
 
+static void
+print_shmid_ds(const char *const str_ipc_cmd,
+	       const struct shmid_ds *const ds,
+	       const int rc)
+{
+	if (rc < 0) {
+		printf("shmctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
+		       id, str_ipc_64, str_ipc_cmd, ds, sprintrc_grep(rc));
+		return;
+	}
+	printf("shmctl\\(%d, (%s\\|)?%s, \\{shm_perm=\\{uid=%u, gid=%u"
+		", mode=%#o, key=%u, cuid=%u, cgid=%u\\}, shm_segsz=%u"
+		", shm_cpid=%d, shm_lpid=%d, shm_nattch=%u, shm_atime=%u"
+		", shm_dtime=%u, shm_ctime=%u\\}\\) = %d\n",
+		id,
+		str_ipc_64,
+		str_ipc_cmd,
+		(unsigned) ds->shm_perm.uid,
+		(unsigned) ds->shm_perm.gid,
+		(unsigned) ds->shm_perm.mode,
+		(unsigned) ds->shm_perm.__key,
+		(unsigned) ds->shm_perm.cuid,
+		(unsigned) ds->shm_perm.cgid,
+		(unsigned) ds->shm_segsz,
+		(int) ds->shm_cpid,
+		(int) ds->shm_lpid,
+		(unsigned) ds->shm_nattch,
+		(unsigned) ds->shm_atime,
+		(unsigned) ds->shm_dtime,
+		(unsigned) ds->shm_ctime,
+		rc);
+}
+
+static void
+print_ipc_info(const char *const str_ipc_cmd,
+               const struct shminfo *const info,
+               const int rc)
+{
+	if (rc < 0) {
+		printf("shmctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
+		       id, str_ipc_64, str_ipc_cmd, info, sprintrc_grep(rc));
+		return;
+	}
+
+	printf("shmctl\\(%d, (%s\\|)?%s, \\{shmmax=%llu, shmmin=%llu"
+	       ", shmmni=%llu, shmseg=%llu, shmall=%llu\\}\\) = %d\n",
+	       id,
+	       str_ipc_64,
+	       str_ipc_cmd,
+	       (unsigned long long) info->shmmax,
+	       (unsigned long long) info->shmmin,
+	       (unsigned long long) info->shmmni,
+	       (unsigned long long) info->shmseg,
+	       (unsigned long long) info->shmall,
+	       rc);
+}
+
+static void
+print_shm_info(const char *const str_ipc_cmd,
+              const struct shm_info *const info,
+              const int rc)
+{
+	if (rc < 0) {
+		printf("shmctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
+		       id, str_ipc_64, str_ipc_cmd, info, sprintrc_grep(rc));
+		return;
+	}
+
+	printf("shmctl\\(%d, (%s\\|)?%s, \\{used_ids=%d, shm_tot=%llu"
+	       ", shm_rss=%llu, shm_swp=%llu, swap_attempts=%llu"
+	       ", swap_successes=%llu\\}\\) = %d\n",
+	       id,
+	       str_ipc_64,
+	       str_ipc_cmd,
+	       info->used_ids,
+	       (unsigned long long) info->shm_tot,
+	       (unsigned long long) info->shm_rss,
+	       (unsigned long long) info->shm_swp,
+	       (unsigned long long) info->swap_attempts,
+	       (unsigned long long) info->swap_successes,
+	       rc);
+}
+
 int
 main(void)
 {
@@ -92,7 +193,9 @@ main(void)
 	static const key_t bogus_key = (key_t) 0xeca86420fdb97531ULL;
 	static const int bogus_id = 0xdefaced1;
 	static const int bogus_cmd = 0xdefaced2;
+#if TEST_SHMCTL_BOGUS_ADDR
 	static void * const bogus_addr = (void *) -1L;
+#endif
 	static const size_t bogus_size =
 	/*
 	 * musl sets size to SIZE_MAX if size argument is greater than
@@ -109,7 +212,11 @@ main(void)
 	static const unsigned int huge_flags = 21 << SHM_HUGE_SHIFT;
 	int bogus_flags;
 	int rc;
-	struct shmid_ds ds;
+	union {
+		struct shmid_ds ds;
+		struct shminfo ipc_info;
+		struct shm_info shm_info;
+	} buf;
 
 	rc = shmget(bogus_key, bogus_size, 0);
 	printf("shmget\\(%#llx, %zu, 000\\) = %s\n",
@@ -160,45 +267,38 @@ main(void)
 	printf("shmctl\\(%d, (%s\\|)?%s, NULL\\) = %s\n",
 	       bogus_id, str_ipc_64, str_bogus_cmd, sprintrc_grep(rc));
 
+#if TEST_SHMCTL_BOGUS_ADDR
 	rc = shmctl(bogus_id, IPC_STAT, bogus_addr);
 	printf("shmctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
 	       bogus_id, str_ipc_64, str_ipc_stat, bogus_addr,
 	       sprintrc_grep(rc));
+#endif
 
-	if (shmctl(id, IPC_STAT, &ds))
+	rc = shmctl(id, IPC_STAT, &buf.ds);
+	if (rc < 0)
 		perror_msg_and_skip("shmctl IPC_STAT");
-	printf("shmctl\\(%d, (%s\\|)?%s, \\{shm_perm=\\{uid=%u, gid=%u, "
-		"mode=%#o, key=%u, cuid=%u, cgid=%u\\}, shm_segsz=%u, shm_cpid=%u, "
-		"shm_lpid=%u, shm_nattch=%u, shm_atime=%u, shm_dtime=%u, "
-		"shm_ctime=%u\\}\\) = 0\n",
-		id, str_ipc_64, str_ipc_stat,
-		(unsigned) ds.shm_perm.uid, (unsigned) ds.shm_perm.gid,
-		(unsigned) ds.shm_perm.mode, (unsigned) ds.shm_perm.__key,
-		(unsigned) ds.shm_perm.cuid, (unsigned) ds.shm_perm.cgid,
-		(unsigned) ds.shm_segsz, (unsigned) ds.shm_cpid,
-		(unsigned) ds.shm_lpid, (unsigned) ds.shm_nattch,
-		(unsigned) ds.shm_atime, (unsigned) ds.shm_dtime,
-		(unsigned) ds. shm_ctime);
+	print_shmid_ds(str_ipc_stat, &buf.ds, rc);
 
-	if (shmctl(id, IPC_SET, &ds))
+	if (shmctl(id, IPC_SET, &buf.ds))
 		perror_msg_and_skip("shmctl IPC_SET");
 	printf("shmctl\\(%d, (%s\\|)?%s, \\{shm_perm=\\{uid=%u, gid=%u"
-	       ", mode=%#o\\}, ...\\}\\) = 0\n",
+	       ", mode=%#o\\}\\}\\) = 0\n",
 	       id, str_ipc_64, str_ipc_set,
-	       (unsigned) ds.shm_perm.uid, (unsigned) ds.shm_perm.gid,
-	       (unsigned) ds.shm_perm.mode);
+	       (unsigned) buf.ds.shm_perm.uid,
+	       (unsigned) buf.ds.shm_perm.gid,
+	       (unsigned) buf.ds.shm_perm.mode);
 
-	rc = shmctl(0, SHM_INFO, &ds);
-	printf("shmctl\\(0, (%s\\|)?%s, %p\\) = %s\n",
-	       str_ipc_64, str_shm_info, &ds, sprintrc_grep(rc));
+	rc = shmctl(id, IPC_INFO, &buf.ds);
+	print_ipc_info(str_ipc_info, &buf.ipc_info, rc);
 
-	rc = shmctl(id, SHM_STAT, &ds);
-	printf("shmctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
-	       id, str_ipc_64, str_shm_stat, &ds, sprintrc_grep(rc));
+	rc = shmctl(id, SHM_INFO, &buf.ds);
+	print_shm_info(str_shm_info, &buf.shm_info, rc);
 
-	rc = shmctl(id, SHM_STAT_ANY, &ds);
-	printf("shmctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
-	       id, str_ipc_64, str_shm_stat_any, &ds, sprintrc_grep(rc));
+	rc = shmctl(id, SHM_STAT, &buf.ds);
+	print_shmid_ds(str_shm_stat, &buf.ds, rc);
+
+	rc = shmctl(id, SHM_STAT_ANY, &buf.ds);
+	print_shmid_ds(str_shm_stat_any, &buf.ds, rc);
 
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/kcmp.c 5.9-0ubuntu2/tests-m32/kcmp.c
--- 5.5-3/tests-m32/kcmp.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/kcmp.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,15 +2,15 @@
  * Check decoding of kcmp syscall.
  *
  * Copyright (c) 2016-2017 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-
 #include "scno.h"
+#include "pidns.h"
 
 #ifdef __NR_kcmp
 
@@ -64,7 +64,26 @@ static const char zero_path[] = "/dev/ze
 static void
 printpidfd(const char *prefix, pid_t pid, unsigned fd)
 {
-	printf("%s%d", prefix, fd);
+	const char *path = NULL;
+
+# if VERBOSE_FD
+	if (pid == getpid()) {
+		switch (fd)
+		{
+		case NULL_FD:
+			path = null_path;
+			break;
+		case ZERO_FD:
+			path = zero_path;
+			break;
+		}
+	}
+# endif
+
+	if (path)
+		printf("%s%d<%s>", prefix, fd, path);
+	else
+		printf("%s%d", prefix, fd);
 }
 
 /*
@@ -82,7 +101,11 @@ do_kcmp(kernel_ulong_t pid1, kernel_ulon
 	rc = syscall(__NR_kcmp, pid1, pid2, type, idx1, idx2);
 	errstr = sprintrc(rc);
 
-	printf("kcmp(%d, %d, ", (int) pid1, (int) pid2);
+	const char *pid_str = pidns_pid2str(PT_TGID);
+	pidns_print_leader();
+	printf("kcmp(%d%s, %d%s, ",
+		(int) pid1, (int) pid1 == getpid() ? pid_str : "",
+		(int) pid2, (int) pid2 == getpid() ? pid_str : "");
 
 	if (type_str)
 		printf("%s", type_str);
@@ -127,6 +150,8 @@ do_kcmp(kernel_ulong_t pid1, kernel_ulon
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	static const kernel_ulong_t bogus_pid1 =
 		(kernel_ulong_t) 0xdeadca75face1057ULL;
 	static const kernel_ulong_t bogus_pid2 =
@@ -179,7 +204,7 @@ main(void)
 	/* KCMP_FILE is the only type which has additional args */
 	do_kcmp(3141592653U, 2718281828U, ARG_STR(KCMP_FILE), bogus_idx1,
 		bogus_idx2);
-	do_kcmp(-1, -1, ARG_STR(KCMP_FILE), NULL_FD, ZERO_FD);
+	do_kcmp(getpid(), getpid(), ARG_STR(KCMP_FILE), NULL_FD, ZERO_FD);
 
 	/* Types without additional args */
 	do_kcmp(-1, -1, ARG_STR(KCMP_VM), bogus_idx1, bogus_idx2);
@@ -198,10 +223,11 @@ main(void)
 	for (i = 0; i < ARRAY_SIZE(slot_data); i++) {
 		memcpy(slot, slot_data + i, sizeof(*slot));
 
-		do_kcmp(getpid(), getppid(), ARG_STR(KCMP_EPOLL_TFD), NULL_FD,
+		do_kcmp(getpid(), -1, ARG_STR(KCMP_EPOLL_TFD), NULL_FD,
 			(uintptr_t) slot, 1);
 	}
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 
 	return 0;
diff -pruN 5.5-3/tests-m32/kcmp-y--pidns-translation.c 5.9-0ubuntu2/tests-m32/kcmp-y--pidns-translation.c
--- 5.5-3/tests-m32/kcmp-y--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/kcmp-y--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "kcmp-y.c"
diff -pruN 5.5-3/tests-m32/kcmp-y--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/kcmp-y--pidns-translation.gen.test
--- 5.5-3/tests-m32/kcmp-y--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/kcmp-y--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (kcmp-y--pidns-translation test_pidns -a22 -y -e trace=kcmp); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a22 -y -e trace=kcmp
diff -pruN 5.5-3/tests-m32/kernel_version.c 5.9-0ubuntu2/tests-m32/kernel_version.c
--- 5.5-3/tests-m32/kernel_version.c	2019-12-10 09:44:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/kernel_version.c	2020-09-06 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check kernel version decoding.
  *
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -34,9 +34,9 @@ static void
 print_bpf_attr(void)
 {
 #if XLAT_RAW
-	printf("{prog_type=0x1b"
+	printf("{prog_type=0x1f"
 #else
-	printf("{prog_type=0x1b /* BPF_PROG_TYPE_??? */"
+	printf("{prog_type=0x1f /* BPF_PROG_TYPE_??? */"
 #endif
 		", insn_cnt=3134983661"
 		", insns=NULL"
@@ -79,7 +79,7 @@ main(void)
 {
 	long ret;
 	struct BPF_PROG_LOAD_struct prog = {
-		.prog_type = 27,
+		.prog_type = 31,
 		.insn_cnt = 0xbadc0ded,
 		.insns = 0,
 		.license = 0,
diff -pruN 5.5-3/tests-m32/kill.c 5.9-0ubuntu2/tests-m32/kill.c
--- 5.5-3/tests-m32/kill.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/kill.c	2020-09-23 16:29:35.000000000 +0000
@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
  * Copyright (c) 2016 Fei Jie <feij.fnst@cn.fujitsu.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -11,6 +11,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #ifdef __NR_kill
 
@@ -26,6 +27,8 @@ handler(int sig)
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	const struct sigaction act = { .sa_handler = handler };
 	if (sigaction(SIGALRM, &act, NULL))
 		perror_msg_and_fail("sigaction");
@@ -37,18 +40,23 @@ main(void)
 		perror_msg_and_fail("sigprocmask");
 
 	const int pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
 	long rc = syscall(__NR_kill, pid, (long) 0xdefaced00000000ULL | SIGALRM);
-	printf("kill(%d, SIGALRM) = %ld\n", pid, rc);
+	pidns_print_leader();
+	printf("kill(%d%s, SIGALRM) = %ld\n", pid, pid_str, rc);
 
 	const long big_pid = (long) 0xfacefeedbadc0dedULL;
 	const long big_sig = (long) 0xdeadbeefcafef00dULL;
 	rc = syscall(__NR_kill, big_pid, big_sig);
+	pidns_print_leader();
 	printf("kill(%d, %d) = %ld %s (%m)\n",
 	       (int) big_pid, (int) big_sig, rc, errno2name());
 
 	rc = syscall(__NR_kill, (long) 0xdefaced00000000ULL | pid, 0);
-	printf("kill(%d, 0) = %ld\n", pid, rc);
+	pidns_print_leader();
+	printf("kill(%d%s, 0) = %ld\n", pid, pid_str, rc);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/kill--pidns-translation.c 5.9-0ubuntu2/tests-m32/kill--pidns-translation.c
--- 5.5-3/tests-m32/kill--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/kill--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "kill.c"
diff -pruN 5.5-3/tests-m32/kill--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/kill--pidns-translation.gen.test
--- 5.5-3/tests-m32/kill--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/kill--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (kill--pidns-translation test_pidns -a12 -e trace=kill -esignal=none); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a12 -e trace=kill -esignal=none
diff -pruN 5.5-3/tests-m32/looping_threads.test 5.9-0ubuntu2/tests-m32/looping_threads.test
--- 5.5-3/tests-m32/looping_threads.test	2019-11-28 19:30:05.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/looping_threads.test	2020-09-03 18:42:36.000000000 +0000
@@ -2,7 +2,7 @@
 #
 # Check tracing of looping threads.
 #
-# Copyright (c) 2009-2019 The strace developers.
+# Copyright (c) 2009-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -20,16 +20,16 @@ inc="$(nproc)"
 [ "$inc" -ge 1 ] || inc=1
 
 timeout_2="$(($TIMEOUT_DURATION/2))"
-timeout_8="$(($TIMEOUT_DURATION/8))"
+timeout_16="$(($TIMEOUT_DURATION/16))"
 nproc=1
 
-run_prog "../$NAME" "$timeout_8" "$nproc"
+run_prog "../$NAME" "$timeout_16" "$nproc"
 
 while :; do
-	run_strace -f -qq -enone -esignal=none "../$NAME" "$timeout_2" "$nproc"
+	run_strace --follow-forks -qq -enone -esignal=none "../$NAME" "$timeout_2" "$nproc"
 
 	s1="$(date +%s)"
-	[ "$(($s1-$s0))" -lt "$timeout_8" ] ||
+	[ "$(($s1-$s0))" -lt "$timeout_16" ] ||
 		break
 
 	nproc="$(($nproc+$inc))"
diff -pruN 5.5-3/tests-m32/Makefile.am 5.9-0ubuntu2/tests-m32/Makefile.am
--- 5.5-3/tests-m32/Makefile.am	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/Makefile.am	2020-09-24 09:18:50.000000000 +0000
@@ -30,6 +30,7 @@ AM_LDFLAGS = $(ARCH_MFLAGS)
 
 libtests_a_SOURCES = \
 	create_nl_socket.c \
+	create_tmpfile.c \
 	errno2name.c \
 	error_msg.c \
 	fill_memory.c \
@@ -43,6 +44,8 @@ libtests_a_SOURCES = \
 	libsocketcall.c \
 	lock_file.c \
 	overflowuid.c \
+	pidns.c \
+	pidns.h \
 	pipe_maxfd.c \
 	print_quoted_string.c \
 	print_time.c \
@@ -63,6 +66,7 @@ libtests_a_SOURCES = \
 	test_ucopy.h \
 	tests.h \
 	tprintf.c \
+	xmalloc_for_tests.c \
 	# end of libtests_a_SOURCES
 libtests_a_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 check_LIBRARIES = libtests.a
@@ -84,12 +88,20 @@ check_PROGRAMS = $(PURE_EXECUTABLES) \
 	bpf-obj_get_info_by_fd-prog-v \
 	bpf-obj_get_info_by_fd-v \
 	bpf-success \
+	bpf-success-long-y \
 	bpf-success-v \
 	caps-abbrev \
 	check_sigblock \
 	check_sigign \
 	clone_parent \
+	clone_parent--quiet-exit \
+	clone_parent-q \
+	clone_parent-qq \
 	clone_ptrace \
+	clone_ptrace--quiet-attach \
+	clone_ptrace--quiet-exit \
+	clone_ptrace-q \
+	clone_ptrace-qq \
 	clone3-success \
 	clone3-success-Xabbrev \
 	clone3-success-Xraw \
@@ -98,16 +110,25 @@ check_PROGRAMS = $(PURE_EXECUTABLES) \
 	delay \
 	execve-v \
 	execveat-v \
+	fcntl--pidns-translation \
+	fcntl64--pidns-translation \
 	filter_seccomp-flag \
 	filter_seccomp-perf \
 	filter-unavailable \
 	fork-f \
+	fork--pidns-translation \
 	fsync-y \
+	get_process_reaper \
+	getpgrp--pidns-translation	\
 	getpid	\
+	getpid--pidns-translation	\
 	getppid	\
+	getsid--pidns-translation \
 	gettid \
+	gettid--pidns-translation \
 	inject-nf \
 	int_0x80 \
+	ioctl_block--pidns-translation \
 	ioctl_dm-v \
 	ioctl_evdev-success \
 	ioctl_evdev-success-Xabbrev \
@@ -117,22 +138,46 @@ check_PROGRAMS = $(PURE_EXECUTABLES) \
 	ioctl_evdev-success-v-Xabbrev \
 	ioctl_evdev-success-v-Xraw \
 	ioctl_evdev-success-v-Xverbose \
+	ioctl_hdio-success \
+	ioctl_hdio-success-Xabbrev \
+	ioctl_hdio-success-Xraw \
+	ioctl_hdio-success-Xverbose \
+	ioctl_hdio-success-v \
+	ioctl_hdio-success-v-Xabbrev \
+	ioctl_hdio-success-v-Xraw \
+	ioctl_hdio-success-v-Xverbose \
 	ioctl_loop-nv \
 	ioctl_loop-v \
 	ioctl_nsfs \
 	ioctl_perf-success \
 	ioctl_rtc-v \
+	ioctl_v4l2-success \
+	ioctl_v4l2-success-Xabbrev \
+	ioctl_v4l2-success-Xraw \
+	ioctl_v4l2-success-Xverbose \
+	ioctl_v4l2-success-v \
+	ioctl_v4l2-success-v-Xabbrev \
+	ioctl_v4l2-success-v-Xraw \
+	ioctl_v4l2-success-v-Xverbose \
+	ioprio--pidns-translation \
 	is_linux_mips_n64 \
+	kcmp-y--pidns-translation \
 	kill_child \
+	kill--pidns-translation \
 	ksysent \
 	list_sigaction_signum \
 	localtime \
 	looping_threads \
+	migrate_pages--pidns-translation \
 	mmsg-silent \
 	mmsg_name-v \
+	move_pages--pidns-translation \
 	msg_control-v \
 	net-accept-connect \
+	net-sockaddr--pidns-translation \
 	net-tpacket_stats-success \
+	nlattr_ifla_xdp-y \
+	netlink_audit--pidns-translation \
 	netlink_inet_diag \
 	netlink_netlink_diag \
 	netlink_unix_diag \
@@ -144,11 +189,20 @@ check_PROGRAMS = $(PURE_EXECUTABLES) \
 	pc \
 	perf_event_open_nonverbose \
 	perf_event_open_unabbrev \
+	pidfd_open--pidns-translation \
+	pidfd_send_signal--pidns-translation \
+	pidns-cache \
+	poll-P \
+	ppoll-P \
 	ppoll-v \
+	prlimit64--pidns-translation \
 	prctl-seccomp-filter-v \
 	prctl-seccomp-strict \
 	prctl-spec-inject \
 	print_maxfd \
+	print_ppid_tracerpid \
+	process_vm_readv--pidns-translation \
+	process_vm_writev--pidns-translation \
 	qual_fault \
 	qual_inject-error-signal \
 	qual_inject-retval \
@@ -162,7 +216,13 @@ check_PROGRAMS = $(PURE_EXECUTABLES) \
 	quotactl-xfs-v \
 	redirect-fds \
 	restart_syscall \
+	rt_sigqueueinfo--pidns-translation \
+	rt_tgsigqueueinfo--pidns-translation \
 	run_expect_termsig \
+	sched_xetaffinity--pidns-translation \
+	sched_xetattr--pidns-translation \
+	sched_xetparam--pidns-translation \
+	sched_xetscheduler--pidns-translation \
 	scm_rights \
 	seccomp-filter-v \
 	seccomp-strict \
@@ -170,22 +230,35 @@ check_PROGRAMS = $(PURE_EXECUTABLES) \
 	set_ptracer_any \
 	set_sigblock \
 	set_sigign \
+	setpgrp-exec \
 	signal_receive \
+	signal_receive--pidns-translation \
 	sleep \
 	stack-fcall \
 	stack-fcall-attach \
 	stack-fcall-mangled \
 	status-none-threads \
 	status-unfinished-threads \
+	so_peercred--pidns-translation \
 	syslog-success \
+	tgkill--pidns-translation \
 	threads-execve \
+	threads-execve--quiet-thread-execve \
+	threads-execve-q \
+	threads-execve-qq \
+	threads-execve-qqq \
+	tkill--pidns-translation \
 	tracer_ppid_pgid_sid \
+	trie_test \
 	unblock_reset_raise \
 	unix-pair-send-recv \
 	unix-pair-sendto-recvfrom \
 	vfork-f \
 	wait4-v \
 	waitid-v \
+	xetpgid--pidns-translation \
+	xetpriority--pidns-translation \
+	xet_robust_list--pidns-translation \
 	zeroargc \
 	# end of check_PROGRAMS
 
@@ -200,6 +273,7 @@ localtime_LDADD = $(clock_LIBS) $(LDADD)
 looping_threads_LDADD = -lpthread $(LDADD)
 lstat64_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 maybe_switch_current_tcp_LDADD = -lpthread $(LDADD)
+maybe_switch_current_tcp__quiet_thread_execve_LDADD = -lpthread $(LDADD)
 mmap64_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 mmap64_Xabbrev_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 mmap64_Xraw_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
@@ -216,6 +290,10 @@ statfs_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE
 status_none_threads_LDADD = -lpthread $(LDADD)
 status_unfinished_threads_LDADD = -lpthread $(LDADD)
 threads_execve_LDADD = -lpthread $(clock_LIBS) $(LDADD)
+threads_execve__quiet_thread_execve_LDADD = -lpthread $(clock_LIBS) $(LDADD)
+threads_execve_q_LDADD = -lpthread $(clock_LIBS) $(LDADD)
+threads_execve_qq_LDADD = -lpthread $(clock_LIBS) $(LDADD)
+threads_execve_qqq_LDADD = -lpthread $(clock_LIBS) $(LDADD)
 times_LDADD = $(clock_LIBS) $(LDADD)
 truncate64_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 uio_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
@@ -230,6 +308,11 @@ stack_fcall_mangled_SOURCES = stack-fcal
 	stack-fcall-mangled-0.c stack-fcall-mangled-1.c \
 	stack-fcall-mangled-2.c stack-fcall-mangled-3.c
 
+trie_test_SOURCES = trie_test.c trie_for_tests.c
+trie_test_CPPFLAGS = $(AM_CPPFLAGS) $(CODE_COVERAGE_CPPFLAGS)
+trie_test_CFLAGS = $(AM_CFLAGS) $(CODE_COVERAGE_CFLAGS)
+trie_test_LDADD = $(LDADD) $(CODE_COVERAGE_LIBS)
+
 include gen_tests.am
 
 if ENABLE_STACKTRACE
@@ -242,6 +325,7 @@ STACKTRACE_TESTS =
 endif
 
 DECODER_TESTS = \
+	bpf-success-long-y.test \
 	bpf-success-v.test \
 	bpf-success.test \
 	brk.test \
@@ -260,13 +344,15 @@ DECODER_TESTS = \
 	execve-v.test \
 	execve.test \
 	fadvise64.test \
+	faccessat.test \
+	faccessat2.test \
 	futex.test \
 	getuid.test \
 	int_0x80.test \
 	inotify_init-y.test \
 	ioctl.test \
+	ioctl_block--pidns-translation.test \
 	ioctl_evdev-success.test \
-	ioctl_perf-success.test \
 	ipc_msgbuf.test \
 	kern_features-fault.test \
 	llseek.test \
@@ -324,7 +410,6 @@ MISC_TESTS = \
 	attach-f-p.test \
 	attach-p-cmd.test \
 	bexecve.test \
-	clone_parent.test \
 	clone_ptrace.test \
 	count-f.test \
 	count.test \
@@ -338,15 +423,19 @@ MISC_TESTS = \
 	filtering_fd-syntax.test \
 	filtering_syscall-syntax.test \
 	first_exec_failure.test \
+	fork--pidns-translation.test \
 	get_regs.test \
+	gettid--pidns-translation.test \
 	inject-nf.test \
 	interactive_block.test \
 	kill_child.test \
 	localtime.test \
 	looping_threads.test \
+	netlink_audit--pidns-translation.test \
 	opipe.test \
 	options-syntax.test \
 	pc.test \
+	pidns-cache.test \
 	printpath-umovestr-legacy.test \
 	printstrn-umoven-legacy.test \
 	qual_fault-syntax.test \
@@ -374,6 +463,8 @@ MISC_TESTS = \
 	strace-DD.test \
 	strace-DDD.test \
 	strace-E.test \
+	strace-E-override.test \
+	strace-E-unset.test \
 	strace-S.test \
 	strace-T.test \
 	strace-V.test \
@@ -422,6 +513,7 @@ EXTRA_DIST = \
 	filter_seccomp.in \
 	filter_seccomp.sh \
 	filter-unavailable.expected \
+	fork--pidns-translation.awk \
 	fstatat.c \
 	fstatx.c \
 	gen_pure_executables.sh \
@@ -430,6 +522,7 @@ EXTRA_DIST = \
 	getresugid.c \
 	init.sh \
 	init_delete_module.h \
+	ioctl-success.sh \
 	ioctl_kvm_run_common.c \
 	ipc.sh \
 	kernel_old_timespec.h \
@@ -438,7 +531,6 @@ EXTRA_DIST = \
 	lstatx.c \
 	match.awk \
 	net.expected \
-	netlink_sock_diag-v.sh \
 	nlattr_ifla.h \
 	pipe.expected \
 	print_user_desc.c \
@@ -467,11 +559,22 @@ EXTRA_DIST = \
 	sockname.c \
 	stack-fcall.h \
 	status-detached.expected \
+	strace--follow-forks-output-separately.expected \
+	strace--relative-timestamps.expected \
+	strace--relative-timestamps-s.expected \
+	strace--relative-timestamps-ms.expected \
+	strace--relative-timestamps-us.expected \
+	strace--relative-timestamps-ns.expected \
+	strace--syscall-times.expected \
+	strace--syscall-times-s.expected \
+	strace--syscall-times-ms.expected \
+	strace--syscall-times-us.expected \
+	strace--syscall-times-ns.expected \
 	strace-C.expected \
 	strace-D.expected \
-	strace-DD.expected \
 	strace-DDD.expected \
 	strace-E.expected \
+	strace-E-unset.expected \
 	strace-T.expected \
 	strace-ff.expected \
 	strace-k-demangle.expected \
@@ -484,6 +587,7 @@ EXTRA_DIST = \
 	strace.supp \
 	sun_path.expected \
 	syntax.sh \
+	trace_clock.in \
 	trace_creds.in \
 	trace_fstat.in \
 	trace_fstatfs.in \
@@ -505,6 +609,7 @@ EXTRA_DIST = \
 	unix-pair-send-recv.expected \
 	unix-pair-sendto-recvfrom.expected \
 	xchownx.c \
+	xgetdents.c \
 	xgetrlimit.c \
 	xselect.c \
 	xstatfs.c \
diff -pruN 5.5-3/tests-m32/Makefile.in 5.9-0ubuntu2/tests-m32/Makefile.in
--- 5.5-3/tests-m32/Makefile.in	2020-02-06 16:23:36.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/Makefile.in	2020-09-24 09:19:01.000000000 +0000
@@ -1,7 +1,7 @@
-# Makefile.in generated by automake 1.16.1 from Makefile.am.
+# Makefile.in generated by automake 1.16.2 from Makefile.am.
 # @configure_input@
 
-# Copyright (C) 1994-2018 Free Software Foundation, Inc.
+# Copyright (C) 1994-2020 Free Software Foundation, Inc.
 
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -110,69 +110,161 @@ check_PROGRAMS = $(am__EXEEXT_1) _newsel
 	bpf-obj_get_info_by_fd-prog$(EXEEXT) \
 	bpf-obj_get_info_by_fd-prog-v$(EXEEXT) \
 	bpf-obj_get_info_by_fd-v$(EXEEXT) bpf-success$(EXEEXT) \
-	bpf-success-v$(EXEEXT) caps-abbrev$(EXEEXT) \
-	check_sigblock$(EXEEXT) check_sigign$(EXEEXT) \
-	clone_parent$(EXEEXT) clone_ptrace$(EXEEXT) \
-	clone3-success$(EXEEXT) clone3-success-Xabbrev$(EXEEXT) \
-	clone3-success-Xraw$(EXEEXT) clone3-success-Xverbose$(EXEEXT) \
-	count-f$(EXEEXT) delay$(EXEEXT) execve-v$(EXEEXT) \
-	execveat-v$(EXEEXT) filter_seccomp-flag$(EXEEXT) \
-	filter_seccomp-perf$(EXEEXT) filter-unavailable$(EXEEXT) \
-	fork-f$(EXEEXT) fsync-y$(EXEEXT) getpid$(EXEEXT) \
-	getppid$(EXEEXT) gettid$(EXEEXT) inject-nf$(EXEEXT) \
-	int_0x80$(EXEEXT) ioctl_dm-v$(EXEEXT) \
-	ioctl_evdev-success$(EXEEXT) \
+	bpf-success-long-y$(EXEEXT) bpf-success-v$(EXEEXT) \
+	caps-abbrev$(EXEEXT) check_sigblock$(EXEEXT) \
+	check_sigign$(EXEEXT) clone_parent$(EXEEXT) \
+	clone_parent--quiet-exit$(EXEEXT) clone_parent-q$(EXEEXT) \
+	clone_parent-qq$(EXEEXT) clone_ptrace$(EXEEXT) \
+	clone_ptrace--quiet-attach$(EXEEXT) \
+	clone_ptrace--quiet-exit$(EXEEXT) clone_ptrace-q$(EXEEXT) \
+	clone_ptrace-qq$(EXEEXT) clone3-success$(EXEEXT) \
+	clone3-success-Xabbrev$(EXEEXT) clone3-success-Xraw$(EXEEXT) \
+	clone3-success-Xverbose$(EXEEXT) count-f$(EXEEXT) \
+	delay$(EXEEXT) execve-v$(EXEEXT) execveat-v$(EXEEXT) \
+	fcntl--pidns-translation$(EXEEXT) \
+	fcntl64--pidns-translation$(EXEEXT) \
+	filter_seccomp-flag$(EXEEXT) filter_seccomp-perf$(EXEEXT) \
+	filter-unavailable$(EXEEXT) fork-f$(EXEEXT) \
+	fork--pidns-translation$(EXEEXT) fsync-y$(EXEEXT) \
+	get_process_reaper$(EXEEXT) \
+	getpgrp--pidns-translation$(EXEEXT) getpid$(EXEEXT) \
+	getpid--pidns-translation$(EXEEXT) getppid$(EXEEXT) \
+	getsid--pidns-translation$(EXEEXT) gettid$(EXEEXT) \
+	gettid--pidns-translation$(EXEEXT) inject-nf$(EXEEXT) \
+	int_0x80$(EXEEXT) ioctl_block--pidns-translation$(EXEEXT) \
+	ioctl_dm-v$(EXEEXT) ioctl_evdev-success$(EXEEXT) \
 	ioctl_evdev-success-Xabbrev$(EXEEXT) \
 	ioctl_evdev-success-Xraw$(EXEEXT) \
 	ioctl_evdev-success-Xverbose$(EXEEXT) \
 	ioctl_evdev-success-v$(EXEEXT) \
 	ioctl_evdev-success-v-Xabbrev$(EXEEXT) \
 	ioctl_evdev-success-v-Xraw$(EXEEXT) \
-	ioctl_evdev-success-v-Xverbose$(EXEEXT) ioctl_loop-nv$(EXEEXT) \
+	ioctl_evdev-success-v-Xverbose$(EXEEXT) \
+	ioctl_hdio-success$(EXEEXT) \
+	ioctl_hdio-success-Xabbrev$(EXEEXT) \
+	ioctl_hdio-success-Xraw$(EXEEXT) \
+	ioctl_hdio-success-Xverbose$(EXEEXT) \
+	ioctl_hdio-success-v$(EXEEXT) \
+	ioctl_hdio-success-v-Xabbrev$(EXEEXT) \
+	ioctl_hdio-success-v-Xraw$(EXEEXT) \
+	ioctl_hdio-success-v-Xverbose$(EXEEXT) ioctl_loop-nv$(EXEEXT) \
 	ioctl_loop-v$(EXEEXT) ioctl_nsfs$(EXEEXT) \
 	ioctl_perf-success$(EXEEXT) ioctl_rtc-v$(EXEEXT) \
-	is_linux_mips_n64$(EXEEXT) kill_child$(EXEEXT) \
-	ksysent$(EXEEXT) list_sigaction_signum$(EXEEXT) \
-	localtime$(EXEEXT) looping_threads$(EXEEXT) \
-	mmsg-silent$(EXEEXT) mmsg_name-v$(EXEEXT) \
+	ioctl_v4l2-success$(EXEEXT) \
+	ioctl_v4l2-success-Xabbrev$(EXEEXT) \
+	ioctl_v4l2-success-Xraw$(EXEEXT) \
+	ioctl_v4l2-success-Xverbose$(EXEEXT) \
+	ioctl_v4l2-success-v$(EXEEXT) \
+	ioctl_v4l2-success-v-Xabbrev$(EXEEXT) \
+	ioctl_v4l2-success-v-Xraw$(EXEEXT) \
+	ioctl_v4l2-success-v-Xverbose$(EXEEXT) \
+	ioprio--pidns-translation$(EXEEXT) is_linux_mips_n64$(EXEEXT) \
+	kcmp-y--pidns-translation$(EXEEXT) kill_child$(EXEEXT) \
+	kill--pidns-translation$(EXEEXT) ksysent$(EXEEXT) \
+	list_sigaction_signum$(EXEEXT) localtime$(EXEEXT) \
+	looping_threads$(EXEEXT) \
+	migrate_pages--pidns-translation$(EXEEXT) mmsg-silent$(EXEEXT) \
+	mmsg_name-v$(EXEEXT) move_pages--pidns-translation$(EXEEXT) \
 	msg_control-v$(EXEEXT) net-accept-connect$(EXEEXT) \
-	net-tpacket_stats-success$(EXEEXT) netlink_inet_diag$(EXEEXT) \
-	netlink_netlink_diag$(EXEEXT) netlink_unix_diag$(EXEEXT) \
-	nsyscalls$(EXEEXT) nsyscalls-d$(EXEEXT) oldselect-P$(EXEEXT) \
+	net-sockaddr--pidns-translation$(EXEEXT) \
+	net-tpacket_stats-success$(EXEEXT) nlattr_ifla_xdp-y$(EXEEXT) \
+	netlink_audit--pidns-translation$(EXEEXT) \
+	netlink_inet_diag$(EXEEXT) netlink_netlink_diag$(EXEEXT) \
+	netlink_unix_diag$(EXEEXT) nsyscalls$(EXEEXT) \
+	nsyscalls-d$(EXEEXT) oldselect-P$(EXEEXT) \
 	oldselect-efault-P$(EXEEXT) orphaned_process_group$(EXEEXT) \
 	pc$(EXEEXT) perf_event_open_nonverbose$(EXEEXT) \
-	perf_event_open_unabbrev$(EXEEXT) ppoll-v$(EXEEXT) \
+	perf_event_open_unabbrev$(EXEEXT) \
+	pidfd_open--pidns-translation$(EXEEXT) \
+	pidfd_send_signal--pidns-translation$(EXEEXT) \
+	pidns-cache$(EXEEXT) poll-P$(EXEEXT) ppoll-P$(EXEEXT) \
+	ppoll-v$(EXEEXT) prlimit64--pidns-translation$(EXEEXT) \
 	prctl-seccomp-filter-v$(EXEEXT) prctl-seccomp-strict$(EXEEXT) \
 	prctl-spec-inject$(EXEEXT) print_maxfd$(EXEEXT) \
+	print_ppid_tracerpid$(EXEEXT) \
+	process_vm_readv--pidns-translation$(EXEEXT) \
+	process_vm_writev--pidns-translation$(EXEEXT) \
 	qual_fault$(EXEEXT) qual_inject-error-signal$(EXEEXT) \
 	qual_inject-retval$(EXEEXT) qual_inject-signal$(EXEEXT) \
 	qual_signal$(EXEEXT) quotactl-success$(EXEEXT) \
 	quotactl-success-v$(EXEEXT) quotactl-v$(EXEEXT) \
 	quotactl-xfs-success$(EXEEXT) quotactl-xfs-success-v$(EXEEXT) \
 	quotactl-xfs-v$(EXEEXT) redirect-fds$(EXEEXT) \
-	restart_syscall$(EXEEXT) run_expect_termsig$(EXEEXT) \
+	restart_syscall$(EXEEXT) \
+	rt_sigqueueinfo--pidns-translation$(EXEEXT) \
+	rt_tgsigqueueinfo--pidns-translation$(EXEEXT) \
+	run_expect_termsig$(EXEEXT) \
+	sched_xetaffinity--pidns-translation$(EXEEXT) \
+	sched_xetattr--pidns-translation$(EXEEXT) \
+	sched_xetparam--pidns-translation$(EXEEXT) \
+	sched_xetscheduler--pidns-translation$(EXEEXT) \
 	scm_rights$(EXEEXT) seccomp-filter-v$(EXEEXT) \
 	seccomp-strict$(EXEEXT) select-P$(EXEEXT) \
 	set_ptracer_any$(EXEEXT) set_sigblock$(EXEEXT) \
-	set_sigign$(EXEEXT) signal_receive$(EXEEXT) sleep$(EXEEXT) \
+	set_sigign$(EXEEXT) setpgrp-exec$(EXEEXT) \
+	signal_receive$(EXEEXT) \
+	signal_receive--pidns-translation$(EXEEXT) sleep$(EXEEXT) \
 	stack-fcall$(EXEEXT) stack-fcall-attach$(EXEEXT) \
 	stack-fcall-mangled$(EXEEXT) status-none-threads$(EXEEXT) \
-	status-unfinished-threads$(EXEEXT) syslog-success$(EXEEXT) \
-	threads-execve$(EXEEXT) tracer_ppid_pgid_sid$(EXEEXT) \
+	status-unfinished-threads$(EXEEXT) \
+	so_peercred--pidns-translation$(EXEEXT) \
+	syslog-success$(EXEEXT) tgkill--pidns-translation$(EXEEXT) \
+	threads-execve$(EXEEXT) \
+	threads-execve--quiet-thread-execve$(EXEEXT) \
+	threads-execve-q$(EXEEXT) threads-execve-qq$(EXEEXT) \
+	threads-execve-qqq$(EXEEXT) tkill--pidns-translation$(EXEEXT) \
+	tracer_ppid_pgid_sid$(EXEEXT) trie_test$(EXEEXT) \
 	unblock_reset_raise$(EXEEXT) unix-pair-send-recv$(EXEEXT) \
 	unix-pair-sendto-recvfrom$(EXEEXT) vfork-f$(EXEEXT) \
-	wait4-v$(EXEEXT) waitid-v$(EXEEXT) zeroargc$(EXEEXT)
+	wait4-v$(EXEEXT) waitid-v$(EXEEXT) \
+	xetpgid--pidns-translation$(EXEEXT) \
+	xetpriority--pidns-translation$(EXEEXT) \
+	xet_robust_list--pidns-translation$(EXEEXT) zeroargc$(EXEEXT)
 @ENABLE_STACKTRACE_TRUE@@USE_DEMANGLE_TRUE@am__append_1 = strace-k-demangle.test
 TESTS = $(GEN_TESTS) $(DECODER_TESTS) $(MISC_TESTS) $(am__EXEEXT_2)
 subdir = tests-m32
 ACLOCAL_M4 = $(top_srcdir)/aclocal.m4
-am__aclocal_m4_deps = $(top_srcdir)/types/check-cryptouser.m4 \
+am__aclocal_m4_deps = $(top_srcdir)/xlat/btrfs_compress_types.m4 \
+	$(top_srcdir)/xlat/close_range_flags.m4 \
+	$(top_srcdir)/xlat/loop_flags_options.m4 \
+	$(top_srcdir)/xlat/rtnl_ifla_xdp_attached_mode.m4 \
+	$(top_srcdir)/xlat/rtnl_ifla_xdp_attrs.m4 \
+	$(top_srcdir)/xlat/rtnl_link_attrs.m4 \
+	$(top_srcdir)/xlat/rtnl_tc_action_attrs.m4 \
+	$(top_srcdir)/xlat/rtnl_tca_stab_attrs.m4 \
+	$(top_srcdir)/xlat/rtnl_tca_stats_attrs.m4 \
+	$(top_srcdir)/xlat/st_check_enums.m4 \
+	$(top_srcdir)/xlat/sysctl_kern.m4 \
+	$(top_srcdir)/xlat/sysctl_net.m4 \
+	$(top_srcdir)/xlat/sysctl_net_core.m4 \
+	$(top_srcdir)/xlat/sysctl_net_ipv4.m4 \
+	$(top_srcdir)/xlat/sysctl_net_ipv4_conf.m4 \
+	$(top_srcdir)/xlat/sysctl_net_ipv4_route.m4 \
+	$(top_srcdir)/xlat/sysctl_net_ipv6.m4 \
+	$(top_srcdir)/xlat/sysctl_net_ipv6_route.m4 \
+	$(top_srcdir)/xlat/sysctl_net_unix.m4 \
+	$(top_srcdir)/xlat/sysctl_root.m4 \
+	$(top_srcdir)/xlat/sysctl_vm.m4 \
+	$(top_srcdir)/xlat/v4l2_buf_types.m4 \
+	$(top_srcdir)/xlat/v4l2_colorspaces.m4 \
+	$(top_srcdir)/xlat/v4l2_control_types.m4 \
+	$(top_srcdir)/xlat/v4l2_fields.m4 \
+	$(top_srcdir)/xlat/v4l2_framesize_types.m4 \
+	$(top_srcdir)/xlat/v4l2_memories.m4 \
+	$(top_srcdir)/xlat/v4l2_tuner_types.m4 \
+	$(top_srcdir)/xlat/waitid_types.m4 \
+	$(top_srcdir)/types/check-btrfs.m4 \
+	$(top_srcdir)/types/check-cryptouser.m4 \
 	$(top_srcdir)/types/check-evdev.m4 \
 	$(top_srcdir)/types/check-io_uring.m4 \
+	$(top_srcdir)/types/check-loop.m4 \
+	$(top_srcdir)/types/check-openat2.m4 \
 	$(top_srcdir)/types/check-rtnl_link.m4 \
 	$(top_srcdir)/types/check-rtnl_mdb.m4 \
 	$(top_srcdir)/types/check-rtnl_neightbl.m4 \
 	$(top_srcdir)/types/check-rtnl_route.m4 \
+	$(top_srcdir)/types/check-tee.m4 \
+	$(top_srcdir)/types/check-v4l2.m4 \
 	$(top_srcdir)/types/st_check_types.m4 \
 	$(top_srcdir)/m4/ax_code_coverage.m4 \
 	$(top_srcdir)/m4/ax_prog_cc_for_build.m4 \
@@ -201,12 +293,21 @@ am__EXEEXT_1 = _newselect$(EXEEXT) accep
 	clock_nanosleep$(EXEEXT) clock_xettime$(EXEEXT) \
 	clone-flags$(EXEEXT) clone3$(EXEEXT) clone3-Xabbrev$(EXEEXT) \
 	clone3-Xraw$(EXEEXT) clone3-Xverbose$(EXEEXT) \
+	close_range$(EXEEXT) close_range-P$(EXEEXT) \
+	close_range-y$(EXEEXT) close_range-yy$(EXEEXT) \
 	copy_file_range$(EXEEXT) creat$(EXEEXT) delete_module$(EXEEXT) \
-	dev-yy$(EXEEXT) dup$(EXEEXT) dup2$(EXEEXT) dup3$(EXEEXT) \
+	dev--decode-fds-dev$(EXEEXT) dev--decode-fds-path$(EXEEXT) \
+	dev--decode-fds-socket$(EXEEXT) dev-yy$(EXEEXT) dup$(EXEEXT) \
+	dup-P$(EXEEXT) dup-y$(EXEEXT) dup-yy$(EXEEXT) dup2$(EXEEXT) \
+	dup2-P$(EXEEXT) dup2-y$(EXEEXT) dup2-yy$(EXEEXT) dup3$(EXEEXT) \
+	dup3-P$(EXEEXT) dup3-y$(EXEEXT) dup3-yy$(EXEEXT) \
 	epoll_create$(EXEEXT) epoll_create1$(EXEEXT) \
 	epoll_ctl$(EXEEXT) epoll_pwait$(EXEEXT) epoll_wait$(EXEEXT) \
 	erestartsys$(EXEEXT) eventfd$(EXEEXT) execve$(EXEEXT) \
-	execveat$(EXEEXT) faccessat$(EXEEXT) fadvise64$(EXEEXT) \
+	execveat$(EXEEXT) faccessat$(EXEEXT) faccessat-P$(EXEEXT) \
+	faccessat-y$(EXEEXT) faccessat-yy$(EXEEXT) faccessat2$(EXEEXT) \
+	faccessat2-P$(EXEEXT) faccessat2-y$(EXEEXT) \
+	faccessat2-yy$(EXEEXT) fadvise64$(EXEEXT) \
 	fadvise64_64$(EXEEXT) fallocate$(EXEEXT) \
 	fanotify_init$(EXEEXT) fanotify_mark$(EXEEXT) \
 	fanotify_mark-Xabbrev$(EXEEXT) fanotify_mark-Xraw$(EXEEXT) \
@@ -224,17 +325,18 @@ am__EXEEXT_1 = _newselect$(EXEEXT) accep
 	fstatfs64$(EXEEXT) fsync$(EXEEXT) ftruncate$(EXEEXT) \
 	ftruncate64$(EXEEXT) futex$(EXEEXT) futimesat$(EXEEXT) \
 	get_mempolicy$(EXEEXT) getcpu$(EXEEXT) getcwd$(EXEEXT) \
-	getdents$(EXEEXT) getdents64$(EXEEXT) getegid$(EXEEXT) \
-	getegid32$(EXEEXT) geteuid$(EXEEXT) geteuid32$(EXEEXT) \
-	getgid$(EXEEXT) getgid32$(EXEEXT) getgroups$(EXEEXT) \
-	getgroups32$(EXEEXT) getpeername$(EXEEXT) getpgrp$(EXEEXT) \
-	getpid$(EXEEXT) getppid$(EXEEXT) getrandom$(EXEEXT) \
-	getresgid$(EXEEXT) getresgid32$(EXEEXT) getresuid$(EXEEXT) \
-	getresuid32$(EXEEXT) getrlimit$(EXEEXT) getrusage$(EXEEXT) \
-	getsid$(EXEEXT) getsockname$(EXEEXT) getuid$(EXEEXT) \
-	getuid32$(EXEEXT) getxxid$(EXEEXT) group_req$(EXEEXT) \
-	inet-cmsg$(EXEEXT) init_module$(EXEEXT) inotify$(EXEEXT) \
-	inotify_init$(EXEEXT) inotify_init-y$(EXEEXT) \
+	getdents$(EXEEXT) getdents-v$(EXEEXT) getdents64$(EXEEXT) \
+	getdents64-v$(EXEEXT) getegid$(EXEEXT) getegid32$(EXEEXT) \
+	geteuid$(EXEEXT) geteuid32$(EXEEXT) getgid$(EXEEXT) \
+	getgid32$(EXEEXT) getgroups$(EXEEXT) getgroups32$(EXEEXT) \
+	getpeername$(EXEEXT) getpgrp$(EXEEXT) getpid$(EXEEXT) \
+	getppid$(EXEEXT) getrandom$(EXEEXT) getresgid$(EXEEXT) \
+	getresgid32$(EXEEXT) getresuid$(EXEEXT) getresuid32$(EXEEXT) \
+	getrlimit$(EXEEXT) getrusage$(EXEEXT) getsid$(EXEEXT) \
+	getsockname$(EXEEXT) getuid$(EXEEXT) getuid32$(EXEEXT) \
+	getxgid$(EXEEXT) getxpid$(EXEEXT) getxuid$(EXEEXT) \
+	group_req$(EXEEXT) inet-cmsg$(EXEEXT) init_module$(EXEEXT) \
+	inotify$(EXEEXT) inotify_init$(EXEEXT) inotify_init-y$(EXEEXT) \
 	inotify_init1$(EXEEXT) inotify_init1-y$(EXEEXT) \
 	io_uring_enter$(EXEEXT) io_uring_register$(EXEEXT) \
 	io_uring_setup$(EXEEXT) ioctl$(EXEEXT) ioctl_block$(EXEEXT) \
@@ -242,16 +344,24 @@ am__EXEEXT_1 = _newselect$(EXEEXT) accep
 	ioctl_evdev-Xabbrev$(EXEEXT) ioctl_evdev-Xraw$(EXEEXT) \
 	ioctl_evdev-Xverbose$(EXEEXT) ioctl_evdev-v$(EXEEXT) \
 	ioctl_evdev-v-Xabbrev$(EXEEXT) ioctl_evdev-v-Xraw$(EXEEXT) \
-	ioctl_evdev-v-Xverbose$(EXEEXT) ioctl_inotify$(EXEEXT) \
+	ioctl_evdev-v-Xverbose$(EXEEXT) ioctl_hdio$(EXEEXT) \
+	ioctl_hdio-Xabbrev$(EXEEXT) ioctl_hdio-Xraw$(EXEEXT) \
+	ioctl_hdio-Xverbose$(EXEEXT) ioctl_hdio-v$(EXEEXT) \
+	ioctl_hdio-v-Xabbrev$(EXEEXT) ioctl_hdio-v-Xraw$(EXEEXT) \
+	ioctl_hdio-v-Xverbose$(EXEEXT) ioctl_inotify$(EXEEXT) \
 	ioctl_kvm_run$(EXEEXT) ioctl_kvm_run-v$(EXEEXT) \
 	ioctl_kvm_run_auxstr_vcpu$(EXEEXT) ioctl_loop$(EXEEXT) \
 	ioctl_mtd$(EXEEXT) ioctl_nbd$(EXEEXT) ioctl_perf$(EXEEXT) \
 	ioctl_ptp$(EXEEXT) ioctl_random$(EXEEXT) ioctl_rtc$(EXEEXT) \
 	ioctl_scsi$(EXEEXT) ioctl_sg_io_v3$(EXEEXT) \
 	ioctl_sg_io_v4$(EXEEXT) ioctl_sock_gifconf$(EXEEXT) \
-	ioctl_uffdio$(EXEEXT) ioctl_v4l2$(EXEEXT) \
-	ioctl_watchdog$(EXEEXT) ioperm$(EXEEXT) iopl$(EXEEXT) \
-	ioprio$(EXEEXT) ioprio-Xabbrev$(EXEEXT) ioprio-Xraw$(EXEEXT) \
+	ioctl_tee$(EXEEXT) ioctl_uffdio$(EXEEXT) ioctl_v4l2$(EXEEXT) \
+	ioctl_v4l2-Xabbrev$(EXEEXT) ioctl_v4l2-Xraw$(EXEEXT) \
+	ioctl_v4l2-Xverbose$(EXEEXT) ioctl_v4l2-v$(EXEEXT) \
+	ioctl_v4l2-v-Xabbrev$(EXEEXT) ioctl_v4l2-v-Xraw$(EXEEXT) \
+	ioctl_v4l2-v-Xverbose$(EXEEXT) ioctl_watchdog$(EXEEXT) \
+	ioperm$(EXEEXT) iopl$(EXEEXT) ioprio$(EXEEXT) \
+	ioprio-Xabbrev$(EXEEXT) ioprio-Xraw$(EXEEXT) \
 	ioprio-Xverbose$(EXEEXT) ip_mreq$(EXEEXT) ipc$(EXEEXT) \
 	ipc_msg$(EXEEXT) ipc_msg-Xabbrev$(EXEEXT) \
 	ipc_msg-Xraw$(EXEEXT) ipc_msg-Xverbose$(EXEEXT) \
@@ -270,6 +380,7 @@ am__EXEEXT_1 = _newselect$(EXEEXT) accep
 	linkat$(EXEEXT) llseek$(EXEEXT) lookup_dcookie$(EXEEXT) \
 	lseek$(EXEEXT) lstat$(EXEEXT) lstat64$(EXEEXT) \
 	madvise$(EXEEXT) maybe_switch_current_tcp$(EXEEXT) \
+	maybe_switch_current_tcp--quiet-thread-execve$(EXEEXT) \
 	mbind$(EXEEXT) mbind-Xabbrev$(EXEEXT) mbind-Xraw$(EXEEXT) \
 	mbind-Xverbose$(EXEEXT) membarrier$(EXEEXT) \
 	memfd_create$(EXEEXT) memfd_create-Xabbrev$(EXEEXT) \
@@ -288,9 +399,12 @@ am__EXEEXT_1 = _newselect$(EXEEXT) accep
 	move_pages-Xverbose$(EXEEXT) mq$(EXEEXT) mq_sendrecv$(EXEEXT) \
 	mq_sendrecv-read$(EXEEXT) mq_sendrecv-write$(EXEEXT) \
 	msg_control$(EXEEXT) msg_name$(EXEEXT) munlockall$(EXEEXT) \
-	nanosleep$(EXEEXT) net-icmp_filter$(EXEEXT) \
-	net-packet_mreq$(EXEEXT) net-packet_mreq-Xabbrev$(EXEEXT) \
-	net-packet_mreq-Xraw$(EXEEXT) \
+	nanosleep$(EXEEXT) net--decode-fds-dev-netlink$(EXEEXT) \
+	net--decode-fds-none-netlink$(EXEEXT) \
+	net--decode-fds-path-netlink$(EXEEXT) \
+	net--decode-fds-socket-netlink$(EXEEXT) \
+	net-icmp_filter$(EXEEXT) net-packet_mreq$(EXEEXT) \
+	net-packet_mreq-Xabbrev$(EXEEXT) net-packet_mreq-Xraw$(EXEEXT) \
 	net-packet_mreq-Xverbose$(EXEEXT) net-sockaddr$(EXEEXT) \
 	net-tpacket_req$(EXEEXT) net-tpacket_stats$(EXEEXT) \
 	net-y-unix$(EXEEXT) net-yy-inet$(EXEEXT) net-yy-inet6$(EXEEXT) \
@@ -329,19 +443,27 @@ am__EXEEXT_1 = _newselect$(EXEEXT) accep
 	old_mmap-v-none$(EXEEXT) oldfstat$(EXEEXT) oldlstat$(EXEEXT) \
 	oldselect$(EXEEXT) oldselect-efault$(EXEEXT) oldstat$(EXEEXT) \
 	open$(EXEEXT) open_tree$(EXEEXT) open_tree-P$(EXEEXT) \
-	openat$(EXEEXT) osf_utimes$(EXEEXT) pause$(EXEEXT) \
-	perf_event_open$(EXEEXT) personality$(EXEEXT) \
-	personality-Xabbrev$(EXEEXT) personality-Xraw$(EXEEXT) \
-	personality-Xverbose$(EXEEXT) pidfd_open$(EXEEXT) \
-	pidfd_open-P$(EXEEXT) pidfd_open-y$(EXEEXT) \
+	openat$(EXEEXT) openat2$(EXEEXT) openat2-Xabbrev$(EXEEXT) \
+	openat2-Xraw$(EXEEXT) openat2-Xverbose$(EXEEXT) \
+	openat2-v$(EXEEXT) openat2-v-y$(EXEEXT) \
+	openat2-v-y-Xabbrev$(EXEEXT) openat2-v-y-Xraw$(EXEEXT) \
+	openat2-v-y-Xverbose$(EXEEXT) openat2-y$(EXEEXT) \
+	osf_utimes$(EXEEXT) pause$(EXEEXT) perf_event_open$(EXEEXT) \
+	personality$(EXEEXT) personality-Xabbrev$(EXEEXT) \
+	personality-Xraw$(EXEEXT) personality-Xverbose$(EXEEXT) \
+	pidfd_getfd$(EXEEXT) pidfd_getfd-y$(EXEEXT) \
+	pidfd_getfd-yy$(EXEEXT) pidfd_open$(EXEEXT) \
+	pidfd_open--decode-fd-path$(EXEEXT) \
+	pidfd_open--decode-fd-pidfd$(EXEEXT) \
+	pidfd_open--decode-fd-socket$(EXEEXT) pidfd_open-P$(EXEEXT) \
+	pidfd_open-y$(EXEEXT) pidfd_open-yy$(EXEEXT) \
 	pidfd_send_signal$(EXEEXT) pipe$(EXEEXT) pipe2$(EXEEXT) \
 	pkey_alloc$(EXEEXT) pkey_free$(EXEEXT) pkey_mprotect$(EXEEXT) \
-	poll$(EXEEXT) poll-P$(EXEEXT) ppoll$(EXEEXT) ppoll-P$(EXEEXT) \
-	prctl-arg2-intptr$(EXEEXT) prctl-dumpable$(EXEEXT) \
-	prctl-name$(EXEEXT) prctl-no-args$(EXEEXT) \
-	prctl-pdeathsig$(EXEEXT) prctl-securebits$(EXEEXT) \
-	prctl-tid_address$(EXEEXT) prctl-tsc$(EXEEXT) \
-	pread64-pwrite64$(EXEEXT) preadv$(EXEEXT) \
+	poll$(EXEEXT) ppoll$(EXEEXT) prctl-arg2-intptr$(EXEEXT) \
+	prctl-dumpable$(EXEEXT) prctl-name$(EXEEXT) \
+	prctl-no-args$(EXEEXT) prctl-pdeathsig$(EXEEXT) \
+	prctl-securebits$(EXEEXT) prctl-tid_address$(EXEEXT) \
+	prctl-tsc$(EXEEXT) pread64-pwrite64$(EXEEXT) preadv$(EXEEXT) \
 	preadv-pwritev$(EXEEXT) preadv2-pwritev2$(EXEEXT) \
 	printpath-umovestr$(EXEEXT) \
 	printpath-umovestr-peekdata$(EXEEXT) \
@@ -402,29 +524,35 @@ am__EXEEXT_1 = _newselect$(EXEEXT) accep
 	sockopt-sol_netlink$(EXEEXT) sockopt-timestamp$(EXEEXT) \
 	splice$(EXEEXT) stat$(EXEEXT) stat64$(EXEEXT) statfs$(EXEEXT) \
 	statfs64$(EXEEXT) status-all$(EXEEXT) status-failed$(EXEEXT) \
+	status-failed-long$(EXEEXT) status-failed-status$(EXEEXT) \
 	status-none$(EXEEXT) status-none-f$(EXEEXT) \
-	status-successful$(EXEEXT) status-unfinished$(EXEEXT) \
-	statx$(EXEEXT) swap$(EXEEXT) sxetmask$(EXEEXT) \
-	symlink$(EXEEXT) symlinkat$(EXEEXT) sync$(EXEEXT) \
-	sync_file_range$(EXEEXT) sync_file_range2$(EXEEXT) \
-	sysinfo$(EXEEXT) syslog$(EXEEXT) tee$(EXEEXT) time$(EXEEXT) \
+	status-successful$(EXEEXT) status-successful-long$(EXEEXT) \
+	status-successful-status$(EXEEXT) status-unfinished$(EXEEXT) \
+	statx$(EXEEXT) strace--strings-in-hex$(EXEEXT) \
+	strace--strings-in-hex-all$(EXEEXT) \
+	strace--strings-in-hex-non-ascii$(EXEEXT) strace-n$(EXEEXT) \
+	strace-x$(EXEEXT) strace-xx$(EXEEXT) swap$(EXEEXT) \
+	sxetmask$(EXEEXT) symlink$(EXEEXT) symlinkat$(EXEEXT) \
+	sync$(EXEEXT) sync_file_range$(EXEEXT) \
+	sync_file_range2$(EXEEXT) sysinfo$(EXEEXT) syslog$(EXEEXT) \
+	tee$(EXEEXT) tgkill$(EXEEXT) time$(EXEEXT) \
 	timer_create$(EXEEXT) timer_xettime$(EXEEXT) \
 	timerfd_xettime$(EXEEXT) times$(EXEEXT) times-fail$(EXEEXT) \
-	truncate$(EXEEXT) truncate64$(EXEEXT) ugetrlimit$(EXEEXT) \
-	uio$(EXEEXT) umask$(EXEEXT) umount$(EXEEXT) umount2$(EXEEXT) \
-	umoven-illptr$(EXEEXT) umovestr$(EXEEXT) \
-	umovestr-illptr$(EXEEXT) umovestr2$(EXEEXT) umovestr3$(EXEEXT) \
-	umovestr_cached$(EXEEXT) uname$(EXEEXT) unlink$(EXEEXT) \
-	unlinkat$(EXEEXT) unshare$(EXEEXT) userfaultfd$(EXEEXT) \
-	ustat$(EXEEXT) utime$(EXEEXT) utimensat$(EXEEXT) \
-	utimensat-Xabbrev$(EXEEXT) utimensat-Xraw$(EXEEXT) \
-	utimensat-Xverbose$(EXEEXT) utimes$(EXEEXT) vhangup$(EXEEXT) \
-	vmsplice$(EXEEXT) wait4$(EXEEXT) waitid$(EXEEXT) \
-	waitpid$(EXEEXT) xattr$(EXEEXT) xattr-strings$(EXEEXT) \
-	xet_robust_list$(EXEEXT) xet_thread_area_x86$(EXEEXT) \
-	xetitimer$(EXEEXT) xetpgid$(EXEEXT) xetpriority$(EXEEXT) \
-	xettimeofday$(EXEEXT)
-AR = ar
+	tkill$(EXEEXT) truncate$(EXEEXT) truncate64$(EXEEXT) \
+	ugetrlimit$(EXEEXT) uio$(EXEEXT) umask$(EXEEXT) \
+	umount$(EXEEXT) umount2$(EXEEXT) umoven-illptr$(EXEEXT) \
+	umovestr$(EXEEXT) umovestr-illptr$(EXEEXT) umovestr2$(EXEEXT) \
+	umovestr3$(EXEEXT) umovestr_cached$(EXEEXT) \
+	umovestr_cached_adjacent$(EXEEXT) uname$(EXEEXT) \
+	unlink$(EXEEXT) unlinkat$(EXEEXT) unshare$(EXEEXT) \
+	userfaultfd$(EXEEXT) ustat$(EXEEXT) utime$(EXEEXT) \
+	utimensat$(EXEEXT) utimensat-Xabbrev$(EXEEXT) \
+	utimensat-Xraw$(EXEEXT) utimensat-Xverbose$(EXEEXT) \
+	utimes$(EXEEXT) vhangup$(EXEEXT) vmsplice$(EXEEXT) \
+	wait4$(EXEEXT) waitid$(EXEEXT) waitpid$(EXEEXT) xattr$(EXEEXT) \
+	xattr-strings$(EXEEXT) xet_robust_list$(EXEEXT) \
+	xet_thread_area_x86$(EXEEXT) xetitimer$(EXEEXT) \
+	xetpgid$(EXEEXT) xetpriority$(EXEEXT) xettimeofday$(EXEEXT)
 ARFLAGS = cru
 AM_V_AR = $(am__v_AR_@AM_V@)
 am__v_AR_ = $(am__v_AR_@AM_DEFAULT_V@)
@@ -433,6 +561,7 @@ am__v_AR_1 =
 libtests_a_AR = $(AR) $(ARFLAGS)
 libtests_a_LIBADD =
 am_libtests_a_OBJECTS = libtests_a-create_nl_socket.$(OBJEXT) \
+	libtests_a-create_tmpfile.$(OBJEXT) \
 	libtests_a-errno2name.$(OBJEXT) libtests_a-error_msg.$(OBJEXT) \
 	libtests_a-fill_memory.$(OBJEXT) \
 	libtests_a-get_page_size.$(OBJEXT) \
@@ -444,7 +573,7 @@ am_libtests_a_OBJECTS = libtests_a-creat
 	libtests_a-libmmsg.$(OBJEXT) \
 	libtests_a-libsocketcall.$(OBJEXT) \
 	libtests_a-lock_file.$(OBJEXT) \
-	libtests_a-overflowuid.$(OBJEXT) \
+	libtests_a-overflowuid.$(OBJEXT) libtests_a-pidns.$(OBJEXT) \
 	libtests_a-pipe_maxfd.$(OBJEXT) \
 	libtests_a-print_quoted_string.$(OBJEXT) \
 	libtests_a-print_time.$(OBJEXT) \
@@ -458,7 +587,8 @@ am_libtests_a_OBJECTS = libtests_a-creat
 	libtests_a-tail_alloc.$(OBJEXT) \
 	libtests_a-test_printpath.$(OBJEXT) \
 	libtests_a-test_printstrn.$(OBJEXT) \
-	libtests_a-test_ucopy.$(OBJEXT) libtests_a-tprintf.$(OBJEXT)
+	libtests_a-test_ucopy.$(OBJEXT) libtests_a-tprintf.$(OBJEXT) \
+	libtests_a-xmalloc_for_tests.$(OBJEXT)
 libtests_a_OBJECTS = $(am_libtests_a_OBJECTS)
 _newselect_SOURCES = _newselect.c
 _newselect_OBJECTS = _newselect.$(OBJEXT)
@@ -558,6 +688,10 @@ bpf_success_SOURCES = bpf-success.c
 bpf_success_OBJECTS = bpf-success.$(OBJEXT)
 bpf_success_LDADD = $(LDADD)
 bpf_success_DEPENDENCIES = libtests.a
+bpf_success_long_y_SOURCES = bpf-success-long-y.c
+bpf_success_long_y_OBJECTS = bpf-success-long-y.$(OBJEXT)
+bpf_success_long_y_LDADD = $(LDADD)
+bpf_success_long_y_DEPENDENCIES = libtests.a
 bpf_success_v_SOURCES = bpf-success-v.c
 bpf_success_v_OBJECTS = bpf-success-v.$(OBJEXT)
 bpf_success_v_LDADD = $(LDADD)
@@ -658,10 +792,55 @@ clone_parent_SOURCES = clone_parent.c
 clone_parent_OBJECTS = clone_parent.$(OBJEXT)
 clone_parent_LDADD = $(LDADD)
 clone_parent_DEPENDENCIES = libtests.a
+clone_parent__quiet_exit_SOURCES = clone_parent--quiet-exit.c
+clone_parent__quiet_exit_OBJECTS = clone_parent--quiet-exit.$(OBJEXT)
+clone_parent__quiet_exit_LDADD = $(LDADD)
+clone_parent__quiet_exit_DEPENDENCIES = libtests.a
+clone_parent_q_SOURCES = clone_parent-q.c
+clone_parent_q_OBJECTS = clone_parent-q.$(OBJEXT)
+clone_parent_q_LDADD = $(LDADD)
+clone_parent_q_DEPENDENCIES = libtests.a
+clone_parent_qq_SOURCES = clone_parent-qq.c
+clone_parent_qq_OBJECTS = clone_parent-qq.$(OBJEXT)
+clone_parent_qq_LDADD = $(LDADD)
+clone_parent_qq_DEPENDENCIES = libtests.a
 clone_ptrace_SOURCES = clone_ptrace.c
 clone_ptrace_OBJECTS = clone_ptrace.$(OBJEXT)
 clone_ptrace_LDADD = $(LDADD)
 clone_ptrace_DEPENDENCIES = libtests.a
+clone_ptrace__quiet_attach_SOURCES = clone_ptrace--quiet-attach.c
+clone_ptrace__quiet_attach_OBJECTS =  \
+	clone_ptrace--quiet-attach.$(OBJEXT)
+clone_ptrace__quiet_attach_LDADD = $(LDADD)
+clone_ptrace__quiet_attach_DEPENDENCIES = libtests.a
+clone_ptrace__quiet_exit_SOURCES = clone_ptrace--quiet-exit.c
+clone_ptrace__quiet_exit_OBJECTS = clone_ptrace--quiet-exit.$(OBJEXT)
+clone_ptrace__quiet_exit_LDADD = $(LDADD)
+clone_ptrace__quiet_exit_DEPENDENCIES = libtests.a
+clone_ptrace_q_SOURCES = clone_ptrace-q.c
+clone_ptrace_q_OBJECTS = clone_ptrace-q.$(OBJEXT)
+clone_ptrace_q_LDADD = $(LDADD)
+clone_ptrace_q_DEPENDENCIES = libtests.a
+clone_ptrace_qq_SOURCES = clone_ptrace-qq.c
+clone_ptrace_qq_OBJECTS = clone_ptrace-qq.$(OBJEXT)
+clone_ptrace_qq_LDADD = $(LDADD)
+clone_ptrace_qq_DEPENDENCIES = libtests.a
+close_range_SOURCES = close_range.c
+close_range_OBJECTS = close_range.$(OBJEXT)
+close_range_LDADD = $(LDADD)
+close_range_DEPENDENCIES = libtests.a
+close_range_P_SOURCES = close_range-P.c
+close_range_P_OBJECTS = close_range-P.$(OBJEXT)
+close_range_P_LDADD = $(LDADD)
+close_range_P_DEPENDENCIES = libtests.a
+close_range_y_SOURCES = close_range-y.c
+close_range_y_OBJECTS = close_range-y.$(OBJEXT)
+close_range_y_LDADD = $(LDADD)
+close_range_y_DEPENDENCIES = libtests.a
+close_range_yy_SOURCES = close_range-yy.c
+close_range_yy_OBJECTS = close_range-yy.$(OBJEXT)
+close_range_yy_LDADD = $(LDADD)
+close_range_yy_DEPENDENCIES = libtests.a
 copy_file_range_SOURCES = copy_file_range.c
 copy_file_range_OBJECTS = copy_file_range.$(OBJEXT)
 copy_file_range_LDADD = $(LDADD)
@@ -681,6 +860,18 @@ delete_module_SOURCES = delete_module.c
 delete_module_OBJECTS = delete_module.$(OBJEXT)
 delete_module_LDADD = $(LDADD)
 delete_module_DEPENDENCIES = libtests.a
+dev__decode_fds_dev_SOURCES = dev--decode-fds-dev.c
+dev__decode_fds_dev_OBJECTS = dev--decode-fds-dev.$(OBJEXT)
+dev__decode_fds_dev_LDADD = $(LDADD)
+dev__decode_fds_dev_DEPENDENCIES = libtests.a
+dev__decode_fds_path_SOURCES = dev--decode-fds-path.c
+dev__decode_fds_path_OBJECTS = dev--decode-fds-path.$(OBJEXT)
+dev__decode_fds_path_LDADD = $(LDADD)
+dev__decode_fds_path_DEPENDENCIES = libtests.a
+dev__decode_fds_socket_SOURCES = dev--decode-fds-socket.c
+dev__decode_fds_socket_OBJECTS = dev--decode-fds-socket.$(OBJEXT)
+dev__decode_fds_socket_LDADD = $(LDADD)
+dev__decode_fds_socket_DEPENDENCIES = libtests.a
 dev_yy_SOURCES = dev-yy.c
 dev_yy_OBJECTS = dev-yy.$(OBJEXT)
 dev_yy_LDADD = $(LDADD)
@@ -689,14 +880,50 @@ dup_SOURCES = dup.c
 dup_OBJECTS = dup.$(OBJEXT)
 dup_LDADD = $(LDADD)
 dup_DEPENDENCIES = libtests.a
+dup_P_SOURCES = dup-P.c
+dup_P_OBJECTS = dup-P.$(OBJEXT)
+dup_P_LDADD = $(LDADD)
+dup_P_DEPENDENCIES = libtests.a
+dup_y_SOURCES = dup-y.c
+dup_y_OBJECTS = dup-y.$(OBJEXT)
+dup_y_LDADD = $(LDADD)
+dup_y_DEPENDENCIES = libtests.a
+dup_yy_SOURCES = dup-yy.c
+dup_yy_OBJECTS = dup-yy.$(OBJEXT)
+dup_yy_LDADD = $(LDADD)
+dup_yy_DEPENDENCIES = libtests.a
 dup2_SOURCES = dup2.c
 dup2_OBJECTS = dup2.$(OBJEXT)
 dup2_LDADD = $(LDADD)
 dup2_DEPENDENCIES = libtests.a
+dup2_P_SOURCES = dup2-P.c
+dup2_P_OBJECTS = dup2-P.$(OBJEXT)
+dup2_P_LDADD = $(LDADD)
+dup2_P_DEPENDENCIES = libtests.a
+dup2_y_SOURCES = dup2-y.c
+dup2_y_OBJECTS = dup2-y.$(OBJEXT)
+dup2_y_LDADD = $(LDADD)
+dup2_y_DEPENDENCIES = libtests.a
+dup2_yy_SOURCES = dup2-yy.c
+dup2_yy_OBJECTS = dup2-yy.$(OBJEXT)
+dup2_yy_LDADD = $(LDADD)
+dup2_yy_DEPENDENCIES = libtests.a
 dup3_SOURCES = dup3.c
 dup3_OBJECTS = dup3.$(OBJEXT)
 dup3_LDADD = $(LDADD)
 dup3_DEPENDENCIES = libtests.a
+dup3_P_SOURCES = dup3-P.c
+dup3_P_OBJECTS = dup3-P.$(OBJEXT)
+dup3_P_LDADD = $(LDADD)
+dup3_P_DEPENDENCIES = libtests.a
+dup3_y_SOURCES = dup3-y.c
+dup3_y_OBJECTS = dup3-y.$(OBJEXT)
+dup3_y_LDADD = $(LDADD)
+dup3_y_DEPENDENCIES = libtests.a
+dup3_yy_SOURCES = dup3-yy.c
+dup3_yy_OBJECTS = dup3-yy.$(OBJEXT)
+dup3_yy_LDADD = $(LDADD)
+dup3_yy_DEPENDENCIES = libtests.a
 epoll_create_SOURCES = epoll_create.c
 epoll_create_OBJECTS = epoll_create.$(OBJEXT)
 epoll_create_LDADD = $(LDADD)
@@ -745,6 +972,34 @@ faccessat_SOURCES = faccessat.c
 faccessat_OBJECTS = faccessat.$(OBJEXT)
 faccessat_LDADD = $(LDADD)
 faccessat_DEPENDENCIES = libtests.a
+faccessat_P_SOURCES = faccessat-P.c
+faccessat_P_OBJECTS = faccessat-P.$(OBJEXT)
+faccessat_P_LDADD = $(LDADD)
+faccessat_P_DEPENDENCIES = libtests.a
+faccessat_y_SOURCES = faccessat-y.c
+faccessat_y_OBJECTS = faccessat-y.$(OBJEXT)
+faccessat_y_LDADD = $(LDADD)
+faccessat_y_DEPENDENCIES = libtests.a
+faccessat_yy_SOURCES = faccessat-yy.c
+faccessat_yy_OBJECTS = faccessat-yy.$(OBJEXT)
+faccessat_yy_LDADD = $(LDADD)
+faccessat_yy_DEPENDENCIES = libtests.a
+faccessat2_SOURCES = faccessat2.c
+faccessat2_OBJECTS = faccessat2.$(OBJEXT)
+faccessat2_LDADD = $(LDADD)
+faccessat2_DEPENDENCIES = libtests.a
+faccessat2_P_SOURCES = faccessat2-P.c
+faccessat2_P_OBJECTS = faccessat2-P.$(OBJEXT)
+faccessat2_P_LDADD = $(LDADD)
+faccessat2_P_DEPENDENCIES = libtests.a
+faccessat2_y_SOURCES = faccessat2-y.c
+faccessat2_y_OBJECTS = faccessat2-y.$(OBJEXT)
+faccessat2_y_LDADD = $(LDADD)
+faccessat2_y_DEPENDENCIES = libtests.a
+faccessat2_yy_SOURCES = faccessat2-yy.c
+faccessat2_yy_OBJECTS = faccessat2-yy.$(OBJEXT)
+faccessat2_yy_LDADD = $(LDADD)
+faccessat2_yy_DEPENDENCIES = libtests.a
 fadvise64_SOURCES = fadvise64.c
 fadvise64_OBJECTS = fadvise64.$(OBJEXT)
 fadvise64_LDADD = $(LDADD)
@@ -805,10 +1060,19 @@ fcntl_SOURCES = fcntl.c
 fcntl_OBJECTS = fcntl.$(OBJEXT)
 fcntl_LDADD = $(LDADD)
 fcntl_DEPENDENCIES = libtests.a
+fcntl__pidns_translation_SOURCES = fcntl--pidns-translation.c
+fcntl__pidns_translation_OBJECTS = fcntl--pidns-translation.$(OBJEXT)
+fcntl__pidns_translation_LDADD = $(LDADD)
+fcntl__pidns_translation_DEPENDENCIES = libtests.a
 fcntl64_SOURCES = fcntl64.c
 fcntl64_OBJECTS = fcntl64.$(OBJEXT)
 fcntl64_LDADD = $(LDADD)
 fcntl64_DEPENDENCIES = libtests.a
+fcntl64__pidns_translation_SOURCES = fcntl64--pidns-translation.c
+fcntl64__pidns_translation_OBJECTS =  \
+	fcntl64--pidns-translation.$(OBJEXT)
+fcntl64__pidns_translation_LDADD = $(LDADD)
+fcntl64__pidns_translation_DEPENDENCIES = libtests.a
 fdatasync_SOURCES = fdatasync.c
 fdatasync_OBJECTS = fdatasync.$(OBJEXT)
 fdatasync_LDADD = $(LDADD)
@@ -844,6 +1108,10 @@ flock_SOURCES = flock.c
 flock_OBJECTS = flock.$(OBJEXT)
 flock_LDADD = $(LDADD)
 flock_DEPENDENCIES = libtests.a
+fork__pidns_translation_SOURCES = fork--pidns-translation.c
+fork__pidns_translation_OBJECTS = fork--pidns-translation.$(OBJEXT)
+fork__pidns_translation_LDADD = $(LDADD)
+fork__pidns_translation_DEPENDENCIES = libtests.a
 fork_f_SOURCES = fork-f.c
 fork_f_OBJECTS = fork-f.$(OBJEXT)
 fork_f_LDADD = $(LDADD)
@@ -944,6 +1212,10 @@ get_mempolicy_SOURCES = get_mempolicy.c
 get_mempolicy_OBJECTS = get_mempolicy.$(OBJEXT)
 get_mempolicy_LDADD = $(LDADD)
 get_mempolicy_DEPENDENCIES = libtests.a
+get_process_reaper_SOURCES = get_process_reaper.c
+get_process_reaper_OBJECTS = get_process_reaper.$(OBJEXT)
+get_process_reaper_LDADD = $(LDADD)
+get_process_reaper_DEPENDENCIES = libtests.a
 getcpu_SOURCES = getcpu.c
 getcpu_OBJECTS = getcpu.$(OBJEXT)
 getcpu_LDADD = $(LDADD)
@@ -956,10 +1228,18 @@ getdents_SOURCES = getdents.c
 getdents_OBJECTS = getdents.$(OBJEXT)
 getdents_LDADD = $(LDADD)
 getdents_DEPENDENCIES = libtests.a
+getdents_v_SOURCES = getdents-v.c
+getdents_v_OBJECTS = getdents-v.$(OBJEXT)
+getdents_v_LDADD = $(LDADD)
+getdents_v_DEPENDENCIES = libtests.a
 getdents64_SOURCES = getdents64.c
 getdents64_OBJECTS = getdents64.$(OBJEXT)
 getdents64_LDADD = $(LDADD)
 getdents64_DEPENDENCIES = libtests.a
+getdents64_v_SOURCES = getdents64-v.c
+getdents64_v_OBJECTS = getdents64-v.$(OBJEXT)
+getdents64_v_LDADD = $(LDADD)
+getdents64_v_DEPENDENCIES = libtests.a
 getegid_SOURCES = getegid.c
 getegid_OBJECTS = getegid.$(OBJEXT)
 getegid_LDADD = $(LDADD)
@@ -1000,10 +1280,20 @@ getpgrp_SOURCES = getpgrp.c
 getpgrp_OBJECTS = getpgrp.$(OBJEXT)
 getpgrp_LDADD = $(LDADD)
 getpgrp_DEPENDENCIES = libtests.a
+getpgrp__pidns_translation_SOURCES = getpgrp--pidns-translation.c
+getpgrp__pidns_translation_OBJECTS =  \
+	getpgrp--pidns-translation.$(OBJEXT)
+getpgrp__pidns_translation_LDADD = $(LDADD)
+getpgrp__pidns_translation_DEPENDENCIES = libtests.a
 getpid_SOURCES = getpid.c
 getpid_OBJECTS = getpid.$(OBJEXT)
 getpid_LDADD = $(LDADD)
 getpid_DEPENDENCIES = libtests.a
+getpid__pidns_translation_SOURCES = getpid--pidns-translation.c
+getpid__pidns_translation_OBJECTS =  \
+	getpid--pidns-translation.$(OBJEXT)
+getpid__pidns_translation_LDADD = $(LDADD)
+getpid__pidns_translation_DEPENDENCIES = libtests.a
 getppid_SOURCES = getppid.c
 getppid_OBJECTS = getppid.$(OBJEXT)
 getppid_LDADD = $(LDADD)
@@ -1040,6 +1330,11 @@ getsid_SOURCES = getsid.c
 getsid_OBJECTS = getsid.$(OBJEXT)
 getsid_LDADD = $(LDADD)
 getsid_DEPENDENCIES = libtests.a
+getsid__pidns_translation_SOURCES = getsid--pidns-translation.c
+getsid__pidns_translation_OBJECTS =  \
+	getsid--pidns-translation.$(OBJEXT)
+getsid__pidns_translation_LDADD = $(LDADD)
+getsid__pidns_translation_DEPENDENCIES = libtests.a
 getsockname_SOURCES = getsockname.c
 getsockname_OBJECTS = getsockname.$(OBJEXT)
 getsockname_LDADD = $(LDADD)
@@ -1048,6 +1343,11 @@ gettid_SOURCES = gettid.c
 gettid_OBJECTS = gettid.$(OBJEXT)
 gettid_LDADD = $(LDADD)
 gettid_DEPENDENCIES = libtests.a
+gettid__pidns_translation_SOURCES = gettid--pidns-translation.c
+gettid__pidns_translation_OBJECTS =  \
+	gettid--pidns-translation.$(OBJEXT)
+gettid__pidns_translation_LDADD = $(LDADD)
+gettid__pidns_translation_DEPENDENCIES = libtests.a
 getuid_SOURCES = getuid.c
 getuid_OBJECTS = getuid.$(OBJEXT)
 getuid_LDADD = $(LDADD)
@@ -1056,10 +1356,18 @@ getuid32_SOURCES = getuid32.c
 getuid32_OBJECTS = getuid32.$(OBJEXT)
 getuid32_LDADD = $(LDADD)
 getuid32_DEPENDENCIES = libtests.a
-getxxid_SOURCES = getxxid.c
-getxxid_OBJECTS = getxxid.$(OBJEXT)
-getxxid_LDADD = $(LDADD)
-getxxid_DEPENDENCIES = libtests.a
+getxgid_SOURCES = getxgid.c
+getxgid_OBJECTS = getxgid.$(OBJEXT)
+getxgid_LDADD = $(LDADD)
+getxgid_DEPENDENCIES = libtests.a
+getxpid_SOURCES = getxpid.c
+getxpid_OBJECTS = getxpid.$(OBJEXT)
+getxpid_LDADD = $(LDADD)
+getxpid_DEPENDENCIES = libtests.a
+getxuid_SOURCES = getxuid.c
+getxuid_OBJECTS = getxuid.$(OBJEXT)
+getxuid_LDADD = $(LDADD)
+getxuid_DEPENDENCIES = libtests.a
 group_req_SOURCES = group_req.c
 group_req_OBJECTS = group_req.$(OBJEXT)
 group_req_LDADD = $(LDADD)
@@ -1120,6 +1428,12 @@ ioctl_block_SOURCES = ioctl_block.c
 ioctl_block_OBJECTS = ioctl_block.$(OBJEXT)
 ioctl_block_LDADD = $(LDADD)
 ioctl_block_DEPENDENCIES = libtests.a
+ioctl_block__pidns_translation_SOURCES =  \
+	ioctl_block--pidns-translation.c
+ioctl_block__pidns_translation_OBJECTS =  \
+	ioctl_block--pidns-translation.$(OBJEXT)
+ioctl_block__pidns_translation_LDADD = $(LDADD)
+ioctl_block__pidns_translation_DEPENDENCIES = libtests.a
 ioctl_dm_SOURCES = ioctl_dm.c
 ioctl_dm_OBJECTS = ioctl_dm.$(OBJEXT)
 ioctl_dm_LDADD = $(LDADD)
@@ -1199,6 +1513,76 @@ ioctl_evdev_v_Xverbose_SOURCES = ioctl_e
 ioctl_evdev_v_Xverbose_OBJECTS = ioctl_evdev-v-Xverbose.$(OBJEXT)
 ioctl_evdev_v_Xverbose_LDADD = $(LDADD)
 ioctl_evdev_v_Xverbose_DEPENDENCIES = libtests.a
+ioctl_hdio_SOURCES = ioctl_hdio.c
+ioctl_hdio_OBJECTS = ioctl_hdio.$(OBJEXT)
+ioctl_hdio_LDADD = $(LDADD)
+ioctl_hdio_DEPENDENCIES = libtests.a
+ioctl_hdio_Xabbrev_SOURCES = ioctl_hdio-Xabbrev.c
+ioctl_hdio_Xabbrev_OBJECTS = ioctl_hdio-Xabbrev.$(OBJEXT)
+ioctl_hdio_Xabbrev_LDADD = $(LDADD)
+ioctl_hdio_Xabbrev_DEPENDENCIES = libtests.a
+ioctl_hdio_Xraw_SOURCES = ioctl_hdio-Xraw.c
+ioctl_hdio_Xraw_OBJECTS = ioctl_hdio-Xraw.$(OBJEXT)
+ioctl_hdio_Xraw_LDADD = $(LDADD)
+ioctl_hdio_Xraw_DEPENDENCIES = libtests.a
+ioctl_hdio_Xverbose_SOURCES = ioctl_hdio-Xverbose.c
+ioctl_hdio_Xverbose_OBJECTS = ioctl_hdio-Xverbose.$(OBJEXT)
+ioctl_hdio_Xverbose_LDADD = $(LDADD)
+ioctl_hdio_Xverbose_DEPENDENCIES = libtests.a
+ioctl_hdio_success_SOURCES = ioctl_hdio-success.c
+ioctl_hdio_success_OBJECTS = ioctl_hdio-success.$(OBJEXT)
+ioctl_hdio_success_LDADD = $(LDADD)
+ioctl_hdio_success_DEPENDENCIES = libtests.a
+ioctl_hdio_success_Xabbrev_SOURCES = ioctl_hdio-success-Xabbrev.c
+ioctl_hdio_success_Xabbrev_OBJECTS =  \
+	ioctl_hdio-success-Xabbrev.$(OBJEXT)
+ioctl_hdio_success_Xabbrev_LDADD = $(LDADD)
+ioctl_hdio_success_Xabbrev_DEPENDENCIES = libtests.a
+ioctl_hdio_success_Xraw_SOURCES = ioctl_hdio-success-Xraw.c
+ioctl_hdio_success_Xraw_OBJECTS = ioctl_hdio-success-Xraw.$(OBJEXT)
+ioctl_hdio_success_Xraw_LDADD = $(LDADD)
+ioctl_hdio_success_Xraw_DEPENDENCIES = libtests.a
+ioctl_hdio_success_Xverbose_SOURCES = ioctl_hdio-success-Xverbose.c
+ioctl_hdio_success_Xverbose_OBJECTS =  \
+	ioctl_hdio-success-Xverbose.$(OBJEXT)
+ioctl_hdio_success_Xverbose_LDADD = $(LDADD)
+ioctl_hdio_success_Xverbose_DEPENDENCIES = libtests.a
+ioctl_hdio_success_v_SOURCES = ioctl_hdio-success-v.c
+ioctl_hdio_success_v_OBJECTS = ioctl_hdio-success-v.$(OBJEXT)
+ioctl_hdio_success_v_LDADD = $(LDADD)
+ioctl_hdio_success_v_DEPENDENCIES = libtests.a
+ioctl_hdio_success_v_Xabbrev_SOURCES = ioctl_hdio-success-v-Xabbrev.c
+ioctl_hdio_success_v_Xabbrev_OBJECTS =  \
+	ioctl_hdio-success-v-Xabbrev.$(OBJEXT)
+ioctl_hdio_success_v_Xabbrev_LDADD = $(LDADD)
+ioctl_hdio_success_v_Xabbrev_DEPENDENCIES = libtests.a
+ioctl_hdio_success_v_Xraw_SOURCES = ioctl_hdio-success-v-Xraw.c
+ioctl_hdio_success_v_Xraw_OBJECTS =  \
+	ioctl_hdio-success-v-Xraw.$(OBJEXT)
+ioctl_hdio_success_v_Xraw_LDADD = $(LDADD)
+ioctl_hdio_success_v_Xraw_DEPENDENCIES = libtests.a
+ioctl_hdio_success_v_Xverbose_SOURCES =  \
+	ioctl_hdio-success-v-Xverbose.c
+ioctl_hdio_success_v_Xverbose_OBJECTS =  \
+	ioctl_hdio-success-v-Xverbose.$(OBJEXT)
+ioctl_hdio_success_v_Xverbose_LDADD = $(LDADD)
+ioctl_hdio_success_v_Xverbose_DEPENDENCIES = libtests.a
+ioctl_hdio_v_SOURCES = ioctl_hdio-v.c
+ioctl_hdio_v_OBJECTS = ioctl_hdio-v.$(OBJEXT)
+ioctl_hdio_v_LDADD = $(LDADD)
+ioctl_hdio_v_DEPENDENCIES = libtests.a
+ioctl_hdio_v_Xabbrev_SOURCES = ioctl_hdio-v-Xabbrev.c
+ioctl_hdio_v_Xabbrev_OBJECTS = ioctl_hdio-v-Xabbrev.$(OBJEXT)
+ioctl_hdio_v_Xabbrev_LDADD = $(LDADD)
+ioctl_hdio_v_Xabbrev_DEPENDENCIES = libtests.a
+ioctl_hdio_v_Xraw_SOURCES = ioctl_hdio-v-Xraw.c
+ioctl_hdio_v_Xraw_OBJECTS = ioctl_hdio-v-Xraw.$(OBJEXT)
+ioctl_hdio_v_Xraw_LDADD = $(LDADD)
+ioctl_hdio_v_Xraw_DEPENDENCIES = libtests.a
+ioctl_hdio_v_Xverbose_SOURCES = ioctl_hdio-v-Xverbose.c
+ioctl_hdio_v_Xverbose_OBJECTS = ioctl_hdio-v-Xverbose.$(OBJEXT)
+ioctl_hdio_v_Xverbose_LDADD = $(LDADD)
+ioctl_hdio_v_Xverbose_DEPENDENCIES = libtests.a
 ioctl_inotify_SOURCES = ioctl_inotify.c
 ioctl_inotify_OBJECTS = ioctl_inotify.$(OBJEXT)
 ioctl_inotify_LDADD = $(LDADD)
@@ -1280,6 +1664,10 @@ ioctl_sock_gifconf_SOURCES = ioctl_sock_
 ioctl_sock_gifconf_OBJECTS = ioctl_sock_gifconf.$(OBJEXT)
 ioctl_sock_gifconf_LDADD = $(LDADD)
 ioctl_sock_gifconf_DEPENDENCIES = libtests.a
+ioctl_tee_SOURCES = ioctl_tee.c
+ioctl_tee_OBJECTS = ioctl_tee.$(OBJEXT)
+ioctl_tee_LDADD = $(LDADD)
+ioctl_tee_DEPENDENCIES = libtests.a
 ioctl_uffdio_SOURCES = ioctl_uffdio.c
 ioctl_uffdio_OBJECTS = ioctl_uffdio.$(OBJEXT)
 ioctl_uffdio_LDADD = $(LDADD)
@@ -1288,6 +1676,72 @@ ioctl_v4l2_SOURCES = ioctl_v4l2.c
 ioctl_v4l2_OBJECTS = ioctl_v4l2.$(OBJEXT)
 ioctl_v4l2_LDADD = $(LDADD)
 ioctl_v4l2_DEPENDENCIES = libtests.a
+ioctl_v4l2_Xabbrev_SOURCES = ioctl_v4l2-Xabbrev.c
+ioctl_v4l2_Xabbrev_OBJECTS = ioctl_v4l2-Xabbrev.$(OBJEXT)
+ioctl_v4l2_Xabbrev_LDADD = $(LDADD)
+ioctl_v4l2_Xabbrev_DEPENDENCIES = libtests.a
+ioctl_v4l2_Xraw_SOURCES = ioctl_v4l2-Xraw.c
+ioctl_v4l2_Xraw_OBJECTS = ioctl_v4l2-Xraw.$(OBJEXT)
+ioctl_v4l2_Xraw_LDADD = $(LDADD)
+ioctl_v4l2_Xraw_DEPENDENCIES = libtests.a
+ioctl_v4l2_Xverbose_SOURCES = ioctl_v4l2-Xverbose.c
+ioctl_v4l2_Xverbose_OBJECTS = ioctl_v4l2-Xverbose.$(OBJEXT)
+ioctl_v4l2_Xverbose_LDADD = $(LDADD)
+ioctl_v4l2_Xverbose_DEPENDENCIES = libtests.a
+ioctl_v4l2_success_SOURCES = ioctl_v4l2-success.c
+ioctl_v4l2_success_OBJECTS = ioctl_v4l2-success.$(OBJEXT)
+ioctl_v4l2_success_LDADD = $(LDADD)
+ioctl_v4l2_success_DEPENDENCIES = libtests.a
+ioctl_v4l2_success_Xabbrev_SOURCES = ioctl_v4l2-success-Xabbrev.c
+ioctl_v4l2_success_Xabbrev_OBJECTS =  \
+	ioctl_v4l2-success-Xabbrev.$(OBJEXT)
+ioctl_v4l2_success_Xabbrev_LDADD = $(LDADD)
+ioctl_v4l2_success_Xabbrev_DEPENDENCIES = libtests.a
+ioctl_v4l2_success_Xraw_SOURCES = ioctl_v4l2-success-Xraw.c
+ioctl_v4l2_success_Xraw_OBJECTS = ioctl_v4l2-success-Xraw.$(OBJEXT)
+ioctl_v4l2_success_Xraw_LDADD = $(LDADD)
+ioctl_v4l2_success_Xraw_DEPENDENCIES = libtests.a
+ioctl_v4l2_success_Xverbose_SOURCES = ioctl_v4l2-success-Xverbose.c
+ioctl_v4l2_success_Xverbose_OBJECTS =  \
+	ioctl_v4l2-success-Xverbose.$(OBJEXT)
+ioctl_v4l2_success_Xverbose_LDADD = $(LDADD)
+ioctl_v4l2_success_Xverbose_DEPENDENCIES = libtests.a
+ioctl_v4l2_success_v_SOURCES = ioctl_v4l2-success-v.c
+ioctl_v4l2_success_v_OBJECTS = ioctl_v4l2-success-v.$(OBJEXT)
+ioctl_v4l2_success_v_LDADD = $(LDADD)
+ioctl_v4l2_success_v_DEPENDENCIES = libtests.a
+ioctl_v4l2_success_v_Xabbrev_SOURCES = ioctl_v4l2-success-v-Xabbrev.c
+ioctl_v4l2_success_v_Xabbrev_OBJECTS =  \
+	ioctl_v4l2-success-v-Xabbrev.$(OBJEXT)
+ioctl_v4l2_success_v_Xabbrev_LDADD = $(LDADD)
+ioctl_v4l2_success_v_Xabbrev_DEPENDENCIES = libtests.a
+ioctl_v4l2_success_v_Xraw_SOURCES = ioctl_v4l2-success-v-Xraw.c
+ioctl_v4l2_success_v_Xraw_OBJECTS =  \
+	ioctl_v4l2-success-v-Xraw.$(OBJEXT)
+ioctl_v4l2_success_v_Xraw_LDADD = $(LDADD)
+ioctl_v4l2_success_v_Xraw_DEPENDENCIES = libtests.a
+ioctl_v4l2_success_v_Xverbose_SOURCES =  \
+	ioctl_v4l2-success-v-Xverbose.c
+ioctl_v4l2_success_v_Xverbose_OBJECTS =  \
+	ioctl_v4l2-success-v-Xverbose.$(OBJEXT)
+ioctl_v4l2_success_v_Xverbose_LDADD = $(LDADD)
+ioctl_v4l2_success_v_Xverbose_DEPENDENCIES = libtests.a
+ioctl_v4l2_v_SOURCES = ioctl_v4l2-v.c
+ioctl_v4l2_v_OBJECTS = ioctl_v4l2-v.$(OBJEXT)
+ioctl_v4l2_v_LDADD = $(LDADD)
+ioctl_v4l2_v_DEPENDENCIES = libtests.a
+ioctl_v4l2_v_Xabbrev_SOURCES = ioctl_v4l2-v-Xabbrev.c
+ioctl_v4l2_v_Xabbrev_OBJECTS = ioctl_v4l2-v-Xabbrev.$(OBJEXT)
+ioctl_v4l2_v_Xabbrev_LDADD = $(LDADD)
+ioctl_v4l2_v_Xabbrev_DEPENDENCIES = libtests.a
+ioctl_v4l2_v_Xraw_SOURCES = ioctl_v4l2-v-Xraw.c
+ioctl_v4l2_v_Xraw_OBJECTS = ioctl_v4l2-v-Xraw.$(OBJEXT)
+ioctl_v4l2_v_Xraw_LDADD = $(LDADD)
+ioctl_v4l2_v_Xraw_DEPENDENCIES = libtests.a
+ioctl_v4l2_v_Xverbose_SOURCES = ioctl_v4l2-v-Xverbose.c
+ioctl_v4l2_v_Xverbose_OBJECTS = ioctl_v4l2-v-Xverbose.$(OBJEXT)
+ioctl_v4l2_v_Xverbose_LDADD = $(LDADD)
+ioctl_v4l2_v_Xverbose_DEPENDENCIES = libtests.a
 ioctl_watchdog_SOURCES = ioctl_watchdog.c
 ioctl_watchdog_OBJECTS = ioctl_watchdog.$(OBJEXT)
 ioctl_watchdog_LDADD = $(LDADD)
@@ -1304,6 +1758,11 @@ ioprio_SOURCES = ioprio.c
 ioprio_OBJECTS = ioprio.$(OBJEXT)
 ioprio_LDADD = $(LDADD)
 ioprio_DEPENDENCIES = libtests.a
+ioprio__pidns_translation_SOURCES = ioprio--pidns-translation.c
+ioprio__pidns_translation_OBJECTS =  \
+	ioprio--pidns-translation.$(OBJEXT)
+ioprio__pidns_translation_LDADD = $(LDADD)
+ioprio__pidns_translation_DEPENDENCIES = libtests.a
 ioprio_Xabbrev_SOURCES = ioprio-Xabbrev.c
 ioprio_Xabbrev_OBJECTS = ioprio-Xabbrev.$(OBJEXT)
 ioprio_Xabbrev_LDADD = $(LDADD)
@@ -1400,6 +1859,11 @@ kcmp_y_SOURCES = kcmp-y.c
 kcmp_y_OBJECTS = kcmp-y.$(OBJEXT)
 kcmp_y_LDADD = $(LDADD)
 kcmp_y_DEPENDENCIES = libtests.a
+kcmp_y__pidns_translation_SOURCES = kcmp-y--pidns-translation.c
+kcmp_y__pidns_translation_OBJECTS =  \
+	kcmp-y--pidns-translation.$(OBJEXT)
+kcmp_y__pidns_translation_LDADD = $(LDADD)
+kcmp_y__pidns_translation_DEPENDENCIES = libtests.a
 kern_features_SOURCES = kern_features.c
 kern_features_OBJECTS = kern_features.$(OBJEXT)
 kern_features_LDADD = $(LDADD)
@@ -1448,6 +1912,10 @@ kill_SOURCES = kill.c
 kill_OBJECTS = kill.$(OBJEXT)
 kill_LDADD = $(LDADD)
 kill_DEPENDENCIES = libtests.a
+kill__pidns_translation_SOURCES = kill--pidns-translation.c
+kill__pidns_translation_OBJECTS = kill--pidns-translation.$(OBJEXT)
+kill__pidns_translation_LDADD = $(LDADD)
+kill__pidns_translation_DEPENDENCIES = libtests.a
 kill_child_SOURCES = kill_child.c
 kill_child_OBJECTS = kill_child.$(OBJEXT)
 kill_child_LDADD = $(LDADD)
@@ -1509,6 +1977,11 @@ madvise_DEPENDENCIES = libtests.a
 maybe_switch_current_tcp_SOURCES = maybe_switch_current_tcp.c
 maybe_switch_current_tcp_OBJECTS = maybe_switch_current_tcp.$(OBJEXT)
 maybe_switch_current_tcp_DEPENDENCIES = $(LDADD)
+maybe_switch_current_tcp__quiet_thread_execve_SOURCES =  \
+	maybe_switch_current_tcp--quiet-thread-execve.c
+maybe_switch_current_tcp__quiet_thread_execve_OBJECTS =  \
+	maybe_switch_current_tcp--quiet-thread-execve.$(OBJEXT)
+maybe_switch_current_tcp__quiet_thread_execve_DEPENDENCIES = $(LDADD)
 mbind_SOURCES = mbind.c
 mbind_OBJECTS = mbind.$(OBJEXT)
 mbind_LDADD = $(LDADD)
@@ -1549,6 +2022,12 @@ migrate_pages_SOURCES = migrate_pages.c
 migrate_pages_OBJECTS = migrate_pages.$(OBJEXT)
 migrate_pages_LDADD = $(LDADD)
 migrate_pages_DEPENDENCIES = libtests.a
+migrate_pages__pidns_translation_SOURCES =  \
+	migrate_pages--pidns-translation.c
+migrate_pages__pidns_translation_OBJECTS =  \
+	migrate_pages--pidns-translation.$(OBJEXT)
+migrate_pages__pidns_translation_LDADD = $(LDADD)
+migrate_pages__pidns_translation_DEPENDENCIES = libtests.a
 mincore_SOURCES = mincore.c
 mincore_OBJECTS = mincore.$(OBJEXT)
 mincore_LDADD = $(LDADD)
@@ -1661,6 +2140,12 @@ move_pages_SOURCES = move_pages.c
 move_pages_OBJECTS = move_pages.$(OBJEXT)
 move_pages_LDADD = $(LDADD)
 move_pages_DEPENDENCIES = libtests.a
+move_pages__pidns_translation_SOURCES =  \
+	move_pages--pidns-translation.c
+move_pages__pidns_translation_OBJECTS =  \
+	move_pages--pidns-translation.$(OBJEXT)
+move_pages__pidns_translation_LDADD = $(LDADD)
+move_pages__pidns_translation_DEPENDENCIES = libtests.a
 move_pages_Xabbrev_SOURCES = move_pages-Xabbrev.c
 move_pages_Xabbrev_OBJECTS = move_pages-Xabbrev.$(OBJEXT)
 move_pages_Xabbrev_LDADD = $(LDADD)
@@ -1708,6 +2193,27 @@ nanosleep_SOURCES = nanosleep.c
 nanosleep_OBJECTS = nanosleep.$(OBJEXT)
 nanosleep_LDADD = $(LDADD)
 nanosleep_DEPENDENCIES = libtests.a
+net__decode_fds_dev_netlink_SOURCES = net--decode-fds-dev-netlink.c
+net__decode_fds_dev_netlink_OBJECTS =  \
+	net--decode-fds-dev-netlink.$(OBJEXT)
+net__decode_fds_dev_netlink_LDADD = $(LDADD)
+net__decode_fds_dev_netlink_DEPENDENCIES = libtests.a
+net__decode_fds_none_netlink_SOURCES = net--decode-fds-none-netlink.c
+net__decode_fds_none_netlink_OBJECTS =  \
+	net--decode-fds-none-netlink.$(OBJEXT)
+net__decode_fds_none_netlink_LDADD = $(LDADD)
+net__decode_fds_none_netlink_DEPENDENCIES = libtests.a
+net__decode_fds_path_netlink_SOURCES = net--decode-fds-path-netlink.c
+net__decode_fds_path_netlink_OBJECTS =  \
+	net--decode-fds-path-netlink.$(OBJEXT)
+net__decode_fds_path_netlink_LDADD = $(LDADD)
+net__decode_fds_path_netlink_DEPENDENCIES = libtests.a
+net__decode_fds_socket_netlink_SOURCES =  \
+	net--decode-fds-socket-netlink.c
+net__decode_fds_socket_netlink_OBJECTS =  \
+	net--decode-fds-socket-netlink.$(OBJEXT)
+net__decode_fds_socket_netlink_LDADD = $(LDADD)
+net__decode_fds_socket_netlink_DEPENDENCIES = libtests.a
 net_accept_connect_SOURCES = net-accept-connect.c
 net_accept_connect_OBJECTS = net-accept-connect.$(OBJEXT)
 net_accept_connect_LDADD = $(LDADD)
@@ -1736,6 +2242,12 @@ net_sockaddr_SOURCES = net-sockaddr.c
 net_sockaddr_OBJECTS = net-sockaddr.$(OBJEXT)
 net_sockaddr_LDADD = $(LDADD)
 net_sockaddr_DEPENDENCIES = libtests.a
+net_sockaddr__pidns_translation_SOURCES =  \
+	net-sockaddr--pidns-translation.c
+net_sockaddr__pidns_translation_OBJECTS =  \
+	net-sockaddr--pidns-translation.$(OBJEXT)
+net_sockaddr__pidns_translation_LDADD = $(LDADD)
+net_sockaddr__pidns_translation_DEPENDENCIES = libtests.a
 net_tpacket_req_SOURCES = net-tpacket_req.c
 net_tpacket_req_OBJECTS = net-tpacket_req.$(OBJEXT)
 net_tpacket_req_LDADD = $(LDADD)
@@ -1773,6 +2285,12 @@ netlink_audit_SOURCES = netlink_audit.c
 netlink_audit_OBJECTS = netlink_audit.$(OBJEXT)
 netlink_audit_LDADD = $(LDADD)
 netlink_audit_DEPENDENCIES = libtests.a
+netlink_audit__pidns_translation_SOURCES =  \
+	netlink_audit--pidns-translation.c
+netlink_audit__pidns_translation_OBJECTS =  \
+	netlink_audit--pidns-translation.$(OBJEXT)
+netlink_audit__pidns_translation_LDADD = $(LDADD)
+netlink_audit__pidns_translation_DEPENDENCIES = libtests.a
 netlink_crypto_SOURCES = netlink_crypto.c
 netlink_crypto_OBJECTS = netlink_crypto.$(OBJEXT)
 netlink_crypto_LDADD = $(LDADD)
@@ -1921,6 +2439,10 @@ nlattr_ifla_xdp_SOURCES = nlattr_ifla_xd
 nlattr_ifla_xdp_OBJECTS = nlattr_ifla_xdp.$(OBJEXT)
 nlattr_ifla_xdp_LDADD = $(LDADD)
 nlattr_ifla_xdp_DEPENDENCIES = libtests.a
+nlattr_ifla_xdp_y_SOURCES = nlattr_ifla_xdp-y.c
+nlattr_ifla_xdp_y_OBJECTS = nlattr_ifla_xdp-y.$(OBJEXT)
+nlattr_ifla_xdp_y_LDADD = $(LDADD)
+nlattr_ifla_xdp_y_DEPENDENCIES = libtests.a
 nlattr_inet_diag_msg_SOURCES = nlattr_inet_diag_msg.c
 nlattr_inet_diag_msg_OBJECTS = nlattr_inet_diag_msg.$(OBJEXT)
 nlattr_inet_diag_msg_LDADD = $(LDADD)
@@ -2074,6 +2596,46 @@ openat_SOURCES = openat.c
 openat_OBJECTS = openat.$(OBJEXT)
 openat_LDADD = $(LDADD)
 openat_DEPENDENCIES = libtests.a
+openat2_SOURCES = openat2.c
+openat2_OBJECTS = openat2.$(OBJEXT)
+openat2_LDADD = $(LDADD)
+openat2_DEPENDENCIES = libtests.a
+openat2_Xabbrev_SOURCES = openat2-Xabbrev.c
+openat2_Xabbrev_OBJECTS = openat2-Xabbrev.$(OBJEXT)
+openat2_Xabbrev_LDADD = $(LDADD)
+openat2_Xabbrev_DEPENDENCIES = libtests.a
+openat2_Xraw_SOURCES = openat2-Xraw.c
+openat2_Xraw_OBJECTS = openat2-Xraw.$(OBJEXT)
+openat2_Xraw_LDADD = $(LDADD)
+openat2_Xraw_DEPENDENCIES = libtests.a
+openat2_Xverbose_SOURCES = openat2-Xverbose.c
+openat2_Xverbose_OBJECTS = openat2-Xverbose.$(OBJEXT)
+openat2_Xverbose_LDADD = $(LDADD)
+openat2_Xverbose_DEPENDENCIES = libtests.a
+openat2_v_SOURCES = openat2-v.c
+openat2_v_OBJECTS = openat2-v.$(OBJEXT)
+openat2_v_LDADD = $(LDADD)
+openat2_v_DEPENDENCIES = libtests.a
+openat2_v_y_SOURCES = openat2-v-y.c
+openat2_v_y_OBJECTS = openat2-v-y.$(OBJEXT)
+openat2_v_y_LDADD = $(LDADD)
+openat2_v_y_DEPENDENCIES = libtests.a
+openat2_v_y_Xabbrev_SOURCES = openat2-v-y-Xabbrev.c
+openat2_v_y_Xabbrev_OBJECTS = openat2-v-y-Xabbrev.$(OBJEXT)
+openat2_v_y_Xabbrev_LDADD = $(LDADD)
+openat2_v_y_Xabbrev_DEPENDENCIES = libtests.a
+openat2_v_y_Xraw_SOURCES = openat2-v-y-Xraw.c
+openat2_v_y_Xraw_OBJECTS = openat2-v-y-Xraw.$(OBJEXT)
+openat2_v_y_Xraw_LDADD = $(LDADD)
+openat2_v_y_Xraw_DEPENDENCIES = libtests.a
+openat2_v_y_Xverbose_SOURCES = openat2-v-y-Xverbose.c
+openat2_v_y_Xverbose_OBJECTS = openat2-v-y-Xverbose.$(OBJEXT)
+openat2_v_y_Xverbose_LDADD = $(LDADD)
+openat2_v_y_Xverbose_DEPENDENCIES = libtests.a
+openat2_y_SOURCES = openat2-y.c
+openat2_y_OBJECTS = openat2-y.$(OBJEXT)
+openat2_y_LDADD = $(LDADD)
+openat2_y_DEPENDENCIES = libtests.a
 orphaned_process_group_SOURCES = orphaned_process_group.c
 orphaned_process_group_OBJECTS = orphaned_process_group.$(OBJEXT)
 orphaned_process_group_LDADD = $(LDADD)
@@ -2118,10 +2680,43 @@ personality_Xverbose_SOURCES = personali
 personality_Xverbose_OBJECTS = personality-Xverbose.$(OBJEXT)
 personality_Xverbose_LDADD = $(LDADD)
 personality_Xverbose_DEPENDENCIES = libtests.a
+pidfd_getfd_SOURCES = pidfd_getfd.c
+pidfd_getfd_OBJECTS = pidfd_getfd.$(OBJEXT)
+pidfd_getfd_LDADD = $(LDADD)
+pidfd_getfd_DEPENDENCIES = libtests.a
+pidfd_getfd_y_SOURCES = pidfd_getfd-y.c
+pidfd_getfd_y_OBJECTS = pidfd_getfd-y.$(OBJEXT)
+pidfd_getfd_y_LDADD = $(LDADD)
+pidfd_getfd_y_DEPENDENCIES = libtests.a
+pidfd_getfd_yy_SOURCES = pidfd_getfd-yy.c
+pidfd_getfd_yy_OBJECTS = pidfd_getfd-yy.$(OBJEXT)
+pidfd_getfd_yy_LDADD = $(LDADD)
+pidfd_getfd_yy_DEPENDENCIES = libtests.a
 pidfd_open_SOURCES = pidfd_open.c
 pidfd_open_OBJECTS = pidfd_open.$(OBJEXT)
 pidfd_open_LDADD = $(LDADD)
 pidfd_open_DEPENDENCIES = libtests.a
+pidfd_open__decode_fd_path_SOURCES = pidfd_open--decode-fd-path.c
+pidfd_open__decode_fd_path_OBJECTS =  \
+	pidfd_open--decode-fd-path.$(OBJEXT)
+pidfd_open__decode_fd_path_LDADD = $(LDADD)
+pidfd_open__decode_fd_path_DEPENDENCIES = libtests.a
+pidfd_open__decode_fd_pidfd_SOURCES = pidfd_open--decode-fd-pidfd.c
+pidfd_open__decode_fd_pidfd_OBJECTS =  \
+	pidfd_open--decode-fd-pidfd.$(OBJEXT)
+pidfd_open__decode_fd_pidfd_LDADD = $(LDADD)
+pidfd_open__decode_fd_pidfd_DEPENDENCIES = libtests.a
+pidfd_open__decode_fd_socket_SOURCES = pidfd_open--decode-fd-socket.c
+pidfd_open__decode_fd_socket_OBJECTS =  \
+	pidfd_open--decode-fd-socket.$(OBJEXT)
+pidfd_open__decode_fd_socket_LDADD = $(LDADD)
+pidfd_open__decode_fd_socket_DEPENDENCIES = libtests.a
+pidfd_open__pidns_translation_SOURCES =  \
+	pidfd_open--pidns-translation.c
+pidfd_open__pidns_translation_OBJECTS =  \
+	pidfd_open--pidns-translation.$(OBJEXT)
+pidfd_open__pidns_translation_LDADD = $(LDADD)
+pidfd_open__pidns_translation_DEPENDENCIES = libtests.a
 pidfd_open_P_SOURCES = pidfd_open-P.c
 pidfd_open_P_OBJECTS = pidfd_open-P.$(OBJEXT)
 pidfd_open_P_LDADD = $(LDADD)
@@ -2130,10 +2725,24 @@ pidfd_open_y_SOURCES = pidfd_open-y.c
 pidfd_open_y_OBJECTS = pidfd_open-y.$(OBJEXT)
 pidfd_open_y_LDADD = $(LDADD)
 pidfd_open_y_DEPENDENCIES = libtests.a
+pidfd_open_yy_SOURCES = pidfd_open-yy.c
+pidfd_open_yy_OBJECTS = pidfd_open-yy.$(OBJEXT)
+pidfd_open_yy_LDADD = $(LDADD)
+pidfd_open_yy_DEPENDENCIES = libtests.a
 pidfd_send_signal_SOURCES = pidfd_send_signal.c
 pidfd_send_signal_OBJECTS = pidfd_send_signal.$(OBJEXT)
 pidfd_send_signal_LDADD = $(LDADD)
 pidfd_send_signal_DEPENDENCIES = libtests.a
+pidfd_send_signal__pidns_translation_SOURCES =  \
+	pidfd_send_signal--pidns-translation.c
+pidfd_send_signal__pidns_translation_OBJECTS =  \
+	pidfd_send_signal--pidns-translation.$(OBJEXT)
+pidfd_send_signal__pidns_translation_LDADD = $(LDADD)
+pidfd_send_signal__pidns_translation_DEPENDENCIES = libtests.a
+pidns_cache_SOURCES = pidns-cache.c
+pidns_cache_OBJECTS = pidns-cache.$(OBJEXT)
+pidns_cache_LDADD = $(LDADD)
+pidns_cache_DEPENDENCIES = libtests.a
 pipe_SOURCES = pipe.c
 pipe_OBJECTS = pipe.$(OBJEXT)
 pipe_LDADD = $(LDADD)
@@ -2239,6 +2848,10 @@ print_maxfd_SOURCES = print_maxfd.c
 print_maxfd_OBJECTS = print_maxfd.$(OBJEXT)
 print_maxfd_LDADD = $(LDADD)
 print_maxfd_DEPENDENCIES = libtests.a
+print_ppid_tracerpid_SOURCES = print_ppid_tracerpid.c
+print_ppid_tracerpid_OBJECTS = print_ppid_tracerpid.$(OBJEXT)
+print_ppid_tracerpid_LDADD = $(LDADD)
+print_ppid_tracerpid_DEPENDENCIES = libtests.a
 printpath_umovestr_SOURCES = printpath-umovestr.c
 printpath_umovestr_OBJECTS = printpath-umovestr.$(OBJEXT)
 printpath_umovestr_LDADD = $(LDADD)
@@ -2288,14 +2901,31 @@ prlimit64_SOURCES = prlimit64.c
 prlimit64_OBJECTS = prlimit64.$(OBJEXT)
 prlimit64_LDADD = $(LDADD)
 prlimit64_DEPENDENCIES = libtests.a
+prlimit64__pidns_translation_SOURCES = prlimit64--pidns-translation.c
+prlimit64__pidns_translation_OBJECTS =  \
+	prlimit64--pidns-translation.$(OBJEXT)
+prlimit64__pidns_translation_LDADD = $(LDADD)
+prlimit64__pidns_translation_DEPENDENCIES = libtests.a
 process_vm_readv_SOURCES = process_vm_readv.c
 process_vm_readv_OBJECTS = process_vm_readv.$(OBJEXT)
 process_vm_readv_LDADD = $(LDADD)
 process_vm_readv_DEPENDENCIES = libtests.a
+process_vm_readv__pidns_translation_SOURCES =  \
+	process_vm_readv--pidns-translation.c
+process_vm_readv__pidns_translation_OBJECTS =  \
+	process_vm_readv--pidns-translation.$(OBJEXT)
+process_vm_readv__pidns_translation_LDADD = $(LDADD)
+process_vm_readv__pidns_translation_DEPENDENCIES = libtests.a
 process_vm_writev_SOURCES = process_vm_writev.c
 process_vm_writev_OBJECTS = process_vm_writev.$(OBJEXT)
 process_vm_writev_LDADD = $(LDADD)
 process_vm_writev_DEPENDENCIES = libtests.a
+process_vm_writev__pidns_translation_SOURCES =  \
+	process_vm_writev--pidns-translation.c
+process_vm_writev__pidns_translation_OBJECTS =  \
+	process_vm_writev--pidns-translation.$(OBJEXT)
+process_vm_writev__pidns_translation_LDADD = $(LDADD)
+process_vm_writev__pidns_translation_DEPENDENCIES = libtests.a
 pselect6_SOURCES = pselect6.c
 pselect6_OBJECTS = pselect6.$(OBJEXT)
 pselect6_LDADD = $(LDADD)
@@ -2489,6 +3119,12 @@ rt_sigqueueinfo_SOURCES = rt_sigqueueinf
 rt_sigqueueinfo_OBJECTS = rt_sigqueueinfo.$(OBJEXT)
 rt_sigqueueinfo_LDADD = $(LDADD)
 rt_sigqueueinfo_DEPENDENCIES = libtests.a
+rt_sigqueueinfo__pidns_translation_SOURCES =  \
+	rt_sigqueueinfo--pidns-translation.c
+rt_sigqueueinfo__pidns_translation_OBJECTS =  \
+	rt_sigqueueinfo--pidns-translation.$(OBJEXT)
+rt_sigqueueinfo__pidns_translation_LDADD = $(LDADD)
+rt_sigqueueinfo__pidns_translation_DEPENDENCIES = libtests.a
 rt_sigreturn_SOURCES = rt_sigreturn.c
 rt_sigreturn_OBJECTS = rt_sigreturn.$(OBJEXT)
 rt_sigreturn_LDADD = $(LDADD)
@@ -2505,6 +3141,12 @@ rt_tgsigqueueinfo_SOURCES = rt_tgsigqueu
 rt_tgsigqueueinfo_OBJECTS = rt_tgsigqueueinfo.$(OBJEXT)
 rt_tgsigqueueinfo_LDADD = $(LDADD)
 rt_tgsigqueueinfo_DEPENDENCIES = libtests.a
+rt_tgsigqueueinfo__pidns_translation_SOURCES =  \
+	rt_tgsigqueueinfo--pidns-translation.c
+rt_tgsigqueueinfo__pidns_translation_OBJECTS =  \
+	rt_tgsigqueueinfo--pidns-translation.$(OBJEXT)
+rt_tgsigqueueinfo__pidns_translation_LDADD = $(LDADD)
+rt_tgsigqueueinfo__pidns_translation_DEPENDENCIES = libtests.a
 run_expect_termsig_SOURCES = run_expect_termsig.c
 run_expect_termsig_OBJECTS = run_expect_termsig.$(OBJEXT)
 run_expect_termsig_LDADD = $(LDADD)
@@ -2545,18 +3187,42 @@ sched_xetaffinity_SOURCES = sched_xetaff
 sched_xetaffinity_OBJECTS = sched_xetaffinity.$(OBJEXT)
 sched_xetaffinity_LDADD = $(LDADD)
 sched_xetaffinity_DEPENDENCIES = libtests.a
+sched_xetaffinity__pidns_translation_SOURCES =  \
+	sched_xetaffinity--pidns-translation.c
+sched_xetaffinity__pidns_translation_OBJECTS =  \
+	sched_xetaffinity--pidns-translation.$(OBJEXT)
+sched_xetaffinity__pidns_translation_LDADD = $(LDADD)
+sched_xetaffinity__pidns_translation_DEPENDENCIES = libtests.a
 sched_xetattr_SOURCES = sched_xetattr.c
 sched_xetattr_OBJECTS = sched_xetattr.$(OBJEXT)
 sched_xetattr_LDADD = $(LDADD)
 sched_xetattr_DEPENDENCIES = libtests.a
+sched_xetattr__pidns_translation_SOURCES =  \
+	sched_xetattr--pidns-translation.c
+sched_xetattr__pidns_translation_OBJECTS =  \
+	sched_xetattr--pidns-translation.$(OBJEXT)
+sched_xetattr__pidns_translation_LDADD = $(LDADD)
+sched_xetattr__pidns_translation_DEPENDENCIES = libtests.a
 sched_xetparam_SOURCES = sched_xetparam.c
 sched_xetparam_OBJECTS = sched_xetparam.$(OBJEXT)
 sched_xetparam_LDADD = $(LDADD)
 sched_xetparam_DEPENDENCIES = libtests.a
+sched_xetparam__pidns_translation_SOURCES =  \
+	sched_xetparam--pidns-translation.c
+sched_xetparam__pidns_translation_OBJECTS =  \
+	sched_xetparam--pidns-translation.$(OBJEXT)
+sched_xetparam__pidns_translation_LDADD = $(LDADD)
+sched_xetparam__pidns_translation_DEPENDENCIES = libtests.a
 sched_xetscheduler_SOURCES = sched_xetscheduler.c
 sched_xetscheduler_OBJECTS = sched_xetscheduler.$(OBJEXT)
 sched_xetscheduler_LDADD = $(LDADD)
 sched_xetscheduler_DEPENDENCIES = libtests.a
+sched_xetscheduler__pidns_translation_SOURCES =  \
+	sched_xetscheduler--pidns-translation.c
+sched_xetscheduler__pidns_translation_OBJECTS =  \
+	sched_xetscheduler--pidns-translation.$(OBJEXT)
+sched_xetscheduler__pidns_translation_LDADD = $(LDADD)
+sched_xetscheduler__pidns_translation_DEPENDENCIES = libtests.a
 sched_yield_SOURCES = sched_yield.c
 sched_yield_OBJECTS = sched_yield.$(OBJEXT)
 sched_yield_LDADD = $(LDADD)
@@ -2681,6 +3347,10 @@ setns_SOURCES = setns.c
 setns_OBJECTS = setns.$(OBJEXT)
 setns_LDADD = $(LDADD)
 setns_DEPENDENCIES = libtests.a
+setpgrp_exec_SOURCES = setpgrp-exec.c
+setpgrp_exec_OBJECTS = setpgrp-exec.$(OBJEXT)
+setpgrp_exec_LDADD = $(LDADD)
+setpgrp_exec_DEPENDENCIES = libtests.a
 setregid_SOURCES = setregid.c
 setregid_OBJECTS = setregid.$(OBJEXT)
 setregid_LDADD = $(LDADD)
@@ -2765,6 +3435,12 @@ signal_receive_SOURCES = signal_receive.
 signal_receive_OBJECTS = signal_receive.$(OBJEXT)
 signal_receive_LDADD = $(LDADD)
 signal_receive_DEPENDENCIES = libtests.a
+signal_receive__pidns_translation_SOURCES =  \
+	signal_receive--pidns-translation.c
+signal_receive__pidns_translation_OBJECTS =  \
+	signal_receive--pidns-translation.$(OBJEXT)
+signal_receive__pidns_translation_LDADD = $(LDADD)
+signal_receive__pidns_translation_DEPENDENCIES = libtests.a
 signalfd4_SOURCES = signalfd4.c
 signalfd4_OBJECTS = signalfd4.$(OBJEXT)
 signalfd4_LDADD = $(LDADD)
@@ -2801,6 +3477,12 @@ so_peercred_SOURCES = so_peercred.c
 so_peercred_OBJECTS = so_peercred.$(OBJEXT)
 so_peercred_LDADD = $(LDADD)
 so_peercred_DEPENDENCIES = libtests.a
+so_peercred__pidns_translation_SOURCES =  \
+	so_peercred--pidns-translation.c
+so_peercred__pidns_translation_OBJECTS =  \
+	so_peercred--pidns-translation.$(OBJEXT)
+so_peercred__pidns_translation_LDADD = $(LDADD)
+so_peercred__pidns_translation_DEPENDENCIES = libtests.a
 so_peercred_Xabbrev_SOURCES = so_peercred-Xabbrev.c
 so_peercred_Xabbrev_OBJECTS = so_peercred-Xabbrev.$(OBJEXT)
 so_peercred_Xabbrev_LDADD = $(LDADD)
@@ -2901,6 +3583,14 @@ status_failed_SOURCES = status-failed.c
 status_failed_OBJECTS = status-failed.$(OBJEXT)
 status_failed_LDADD = $(LDADD)
 status_failed_DEPENDENCIES = libtests.a
+status_failed_long_SOURCES = status-failed-long.c
+status_failed_long_OBJECTS = status-failed-long.$(OBJEXT)
+status_failed_long_LDADD = $(LDADD)
+status_failed_long_DEPENDENCIES = libtests.a
+status_failed_status_SOURCES = status-failed-status.c
+status_failed_status_OBJECTS = status-failed-status.$(OBJEXT)
+status_failed_status_LDADD = $(LDADD)
+status_failed_status_DEPENDENCIES = libtests.a
 status_none_SOURCES = status-none.c
 status_none_OBJECTS = status-none.$(OBJEXT)
 status_none_LDADD = $(LDADD)
@@ -2916,6 +3606,14 @@ status_successful_SOURCES = status-succe
 status_successful_OBJECTS = status-successful.$(OBJEXT)
 status_successful_LDADD = $(LDADD)
 status_successful_DEPENDENCIES = libtests.a
+status_successful_long_SOURCES = status-successful-long.c
+status_successful_long_OBJECTS = status-successful-long.$(OBJEXT)
+status_successful_long_LDADD = $(LDADD)
+status_successful_long_DEPENDENCIES = libtests.a
+status_successful_status_SOURCES = status-successful-status.c
+status_successful_status_OBJECTS = status-successful-status.$(OBJEXT)
+status_successful_status_LDADD = $(LDADD)
+status_successful_status_DEPENDENCIES = libtests.a
 status_unfinished_SOURCES = status-unfinished.c
 status_unfinished_OBJECTS = status-unfinished.$(OBJEXT)
 status_unfinished_LDADD = $(LDADD)
@@ -2928,6 +3626,33 @@ statx_SOURCES = statx.c
 statx_OBJECTS = statx.$(OBJEXT)
 statx_LDADD = $(LDADD)
 statx_DEPENDENCIES = libtests.a
+strace__strings_in_hex_SOURCES = strace--strings-in-hex.c
+strace__strings_in_hex_OBJECTS = strace--strings-in-hex.$(OBJEXT)
+strace__strings_in_hex_LDADD = $(LDADD)
+strace__strings_in_hex_DEPENDENCIES = libtests.a
+strace__strings_in_hex_all_SOURCES = strace--strings-in-hex-all.c
+strace__strings_in_hex_all_OBJECTS =  \
+	strace--strings-in-hex-all.$(OBJEXT)
+strace__strings_in_hex_all_LDADD = $(LDADD)
+strace__strings_in_hex_all_DEPENDENCIES = libtests.a
+strace__strings_in_hex_non_ascii_SOURCES =  \
+	strace--strings-in-hex-non-ascii.c
+strace__strings_in_hex_non_ascii_OBJECTS =  \
+	strace--strings-in-hex-non-ascii.$(OBJEXT)
+strace__strings_in_hex_non_ascii_LDADD = $(LDADD)
+strace__strings_in_hex_non_ascii_DEPENDENCIES = libtests.a
+strace_n_SOURCES = strace-n.c
+strace_n_OBJECTS = strace-n.$(OBJEXT)
+strace_n_LDADD = $(LDADD)
+strace_n_DEPENDENCIES = libtests.a
+strace_x_SOURCES = strace-x.c
+strace_x_OBJECTS = strace-x.$(OBJEXT)
+strace_x_LDADD = $(LDADD)
+strace_x_DEPENDENCIES = libtests.a
+strace_xx_SOURCES = strace-xx.c
+strace_xx_OBJECTS = strace-xx.$(OBJEXT)
+strace_xx_LDADD = $(LDADD)
+strace_xx_DEPENDENCIES = libtests.a
 swap_SOURCES = swap.c
 swap_OBJECTS = swap.$(OBJEXT)
 swap_LDADD = $(LDADD)
@@ -2972,9 +3697,33 @@ tee_SOURCES = tee.c
 tee_OBJECTS = tee.$(OBJEXT)
 tee_LDADD = $(LDADD)
 tee_DEPENDENCIES = libtests.a
+tgkill_SOURCES = tgkill.c
+tgkill_OBJECTS = tgkill.$(OBJEXT)
+tgkill_LDADD = $(LDADD)
+tgkill_DEPENDENCIES = libtests.a
+tgkill__pidns_translation_SOURCES = tgkill--pidns-translation.c
+tgkill__pidns_translation_OBJECTS =  \
+	tgkill--pidns-translation.$(OBJEXT)
+tgkill__pidns_translation_LDADD = $(LDADD)
+tgkill__pidns_translation_DEPENDENCIES = libtests.a
 threads_execve_SOURCES = threads-execve.c
 threads_execve_OBJECTS = threads-execve.$(OBJEXT)
 threads_execve_DEPENDENCIES = $(am__DEPENDENCIES_1) $(LDADD)
+threads_execve__quiet_thread_execve_SOURCES =  \
+	threads-execve--quiet-thread-execve.c
+threads_execve__quiet_thread_execve_OBJECTS =  \
+	threads-execve--quiet-thread-execve.$(OBJEXT)
+threads_execve__quiet_thread_execve_DEPENDENCIES =  \
+	$(am__DEPENDENCIES_1) $(LDADD)
+threads_execve_q_SOURCES = threads-execve-q.c
+threads_execve_q_OBJECTS = threads-execve-q.$(OBJEXT)
+threads_execve_q_DEPENDENCIES = $(am__DEPENDENCIES_1) $(LDADD)
+threads_execve_qq_SOURCES = threads-execve-qq.c
+threads_execve_qq_OBJECTS = threads-execve-qq.$(OBJEXT)
+threads_execve_qq_DEPENDENCIES = $(am__DEPENDENCIES_1) $(LDADD)
+threads_execve_qqq_SOURCES = threads-execve-qqq.c
+threads_execve_qqq_OBJECTS = threads-execve-qqq.$(OBJEXT)
+threads_execve_qqq_DEPENDENCIES = $(am__DEPENDENCIES_1) $(LDADD)
 time_SOURCES = time.c
 time_OBJECTS = time.$(OBJEXT)
 time_LDADD = $(LDADD)
@@ -2998,10 +3747,24 @@ times_fail_SOURCES = times-fail.c
 times_fail_OBJECTS = times-fail.$(OBJEXT)
 times_fail_LDADD = $(LDADD)
 times_fail_DEPENDENCIES = libtests.a
+tkill_SOURCES = tkill.c
+tkill_OBJECTS = tkill.$(OBJEXT)
+tkill_LDADD = $(LDADD)
+tkill_DEPENDENCIES = libtests.a
+tkill__pidns_translation_SOURCES = tkill--pidns-translation.c
+tkill__pidns_translation_OBJECTS = tkill--pidns-translation.$(OBJEXT)
+tkill__pidns_translation_LDADD = $(LDADD)
+tkill__pidns_translation_DEPENDENCIES = libtests.a
 tracer_ppid_pgid_sid_SOURCES = tracer_ppid_pgid_sid.c
 tracer_ppid_pgid_sid_OBJECTS = tracer_ppid_pgid_sid.$(OBJEXT)
 tracer_ppid_pgid_sid_LDADD = $(LDADD)
 tracer_ppid_pgid_sid_DEPENDENCIES = libtests.a
+am_trie_test_OBJECTS = trie_test-trie_test.$(OBJEXT) \
+	trie_test-trie_for_tests.$(OBJEXT)
+trie_test_OBJECTS = $(am_trie_test_OBJECTS)
+trie_test_DEPENDENCIES = $(LDADD) $(am__DEPENDENCIES_1)
+trie_test_LINK = $(CCLD) $(trie_test_CFLAGS) $(CFLAGS) $(AM_LDFLAGS) \
+	$(LDFLAGS) -o $@
 truncate_SOURCES = truncate.c
 truncate_OBJECTS = truncate.$(OBJEXT)
 truncate_LDADD = $(LDADD)
@@ -3054,6 +3817,10 @@ umovestr_cached_SOURCES = umovestr_cache
 umovestr_cached_OBJECTS = umovestr_cached.$(OBJEXT)
 umovestr_cached_LDADD = $(LDADD)
 umovestr_cached_DEPENDENCIES = libtests.a
+umovestr_cached_adjacent_SOURCES = umovestr_cached_adjacent.c
+umovestr_cached_adjacent_OBJECTS = umovestr_cached_adjacent.$(OBJEXT)
+umovestr_cached_adjacent_LDADD = $(LDADD)
+umovestr_cached_adjacent_DEPENDENCIES = libtests.a
 uname_SOURCES = uname.c
 uname_OBJECTS = uname.$(OBJEXT)
 uname_LDADD = $(LDADD)
@@ -3159,6 +3926,12 @@ xet_robust_list_SOURCES = xet_robust_lis
 xet_robust_list_OBJECTS = xet_robust_list.$(OBJEXT)
 xet_robust_list_LDADD = $(LDADD)
 xet_robust_list_DEPENDENCIES = libtests.a
+xet_robust_list__pidns_translation_SOURCES =  \
+	xet_robust_list--pidns-translation.c
+xet_robust_list__pidns_translation_OBJECTS =  \
+	xet_robust_list--pidns-translation.$(OBJEXT)
+xet_robust_list__pidns_translation_LDADD = $(LDADD)
+xet_robust_list__pidns_translation_DEPENDENCIES = libtests.a
 xet_thread_area_x86_SOURCES = xet_thread_area_x86.c
 xet_thread_area_x86_OBJECTS = xet_thread_area_x86.$(OBJEXT)
 xet_thread_area_x86_LDADD = $(LDADD)
@@ -3171,10 +3944,21 @@ xetpgid_SOURCES = xetpgid.c
 xetpgid_OBJECTS = xetpgid.$(OBJEXT)
 xetpgid_LDADD = $(LDADD)
 xetpgid_DEPENDENCIES = libtests.a
+xetpgid__pidns_translation_SOURCES = xetpgid--pidns-translation.c
+xetpgid__pidns_translation_OBJECTS =  \
+	xetpgid--pidns-translation.$(OBJEXT)
+xetpgid__pidns_translation_LDADD = $(LDADD)
+xetpgid__pidns_translation_DEPENDENCIES = libtests.a
 xetpriority_SOURCES = xetpriority.c
 xetpriority_OBJECTS = xetpriority.$(OBJEXT)
 xetpriority_LDADD = $(LDADD)
 xetpriority_DEPENDENCIES = libtests.a
+xetpriority__pidns_translation_SOURCES =  \
+	xetpriority--pidns-translation.c
+xetpriority__pidns_translation_OBJECTS =  \
+	xetpriority--pidns-translation.$(OBJEXT)
+xetpriority__pidns_translation_LDADD = $(LDADD)
+xetpriority__pidns_translation_DEPENDENCIES = libtests.a
 xettimeofday_SOURCES = xettimeofday.c
 xettimeofday_OBJECTS = xettimeofday.$(OBJEXT)
 xettimeofday_LDADD = $(LDADD)
@@ -3213,31 +3997,50 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/bpf-obj_get_info_by_fd-prog.Po \
 	./$(DEPDIR)/bpf-obj_get_info_by_fd-v.Po \
 	./$(DEPDIR)/bpf-obj_get_info_by_fd.Po \
-	./$(DEPDIR)/bpf-success-v.Po ./$(DEPDIR)/bpf-success.Po \
-	./$(DEPDIR)/bpf-v.Po ./$(DEPDIR)/bpf.Po ./$(DEPDIR)/brk.Po \
-	./$(DEPDIR)/btrfs.Po ./$(DEPDIR)/caps-abbrev.Po \
-	./$(DEPDIR)/caps.Po ./$(DEPDIR)/check_sigblock.Po \
-	./$(DEPDIR)/check_sigign.Po ./$(DEPDIR)/chmod.Po \
-	./$(DEPDIR)/chown.Po ./$(DEPDIR)/chown32.Po \
-	./$(DEPDIR)/chroot.Po ./$(DEPDIR)/clock_adjtime.Po \
-	./$(DEPDIR)/clock_nanosleep.Po ./$(DEPDIR)/clock_xettime.Po \
-	./$(DEPDIR)/clone-flags.Po ./$(DEPDIR)/clone3-Xabbrev.Po \
-	./$(DEPDIR)/clone3-Xraw.Po ./$(DEPDIR)/clone3-Xverbose.Po \
+	./$(DEPDIR)/bpf-success-long-y.Po ./$(DEPDIR)/bpf-success-v.Po \
+	./$(DEPDIR)/bpf-success.Po ./$(DEPDIR)/bpf-v.Po \
+	./$(DEPDIR)/bpf.Po ./$(DEPDIR)/brk.Po ./$(DEPDIR)/btrfs.Po \
+	./$(DEPDIR)/caps-abbrev.Po ./$(DEPDIR)/caps.Po \
+	./$(DEPDIR)/check_sigblock.Po ./$(DEPDIR)/check_sigign.Po \
+	./$(DEPDIR)/chmod.Po ./$(DEPDIR)/chown.Po \
+	./$(DEPDIR)/chown32.Po ./$(DEPDIR)/chroot.Po \
+	./$(DEPDIR)/clock_adjtime.Po ./$(DEPDIR)/clock_nanosleep.Po \
+	./$(DEPDIR)/clock_xettime.Po ./$(DEPDIR)/clone-flags.Po \
+	./$(DEPDIR)/clone3-Xabbrev.Po ./$(DEPDIR)/clone3-Xraw.Po \
+	./$(DEPDIR)/clone3-Xverbose.Po \
 	./$(DEPDIR)/clone3-success-Xabbrev.Po \
 	./$(DEPDIR)/clone3-success-Xraw.Po \
 	./$(DEPDIR)/clone3-success-Xverbose.Po \
 	./$(DEPDIR)/clone3-success.Po ./$(DEPDIR)/clone3.Po \
-	./$(DEPDIR)/clone_parent.Po ./$(DEPDIR)/clone_ptrace.Po \
-	./$(DEPDIR)/copy_file_range.Po ./$(DEPDIR)/count-f.Po \
-	./$(DEPDIR)/creat.Po ./$(DEPDIR)/delay.Po \
-	./$(DEPDIR)/delete_module.Po ./$(DEPDIR)/dev-yy.Po \
-	./$(DEPDIR)/dup.Po ./$(DEPDIR)/dup2.Po ./$(DEPDIR)/dup3.Po \
-	./$(DEPDIR)/epoll_create.Po ./$(DEPDIR)/epoll_create1.Po \
-	./$(DEPDIR)/epoll_ctl.Po ./$(DEPDIR)/epoll_pwait.Po \
-	./$(DEPDIR)/epoll_wait.Po ./$(DEPDIR)/erestartsys.Po \
-	./$(DEPDIR)/eventfd.Po ./$(DEPDIR)/execve-v.Po \
-	./$(DEPDIR)/execve.Po ./$(DEPDIR)/execveat-v.Po \
-	./$(DEPDIR)/execveat.Po ./$(DEPDIR)/faccessat.Po \
+	./$(DEPDIR)/clone_parent--quiet-exit.Po \
+	./$(DEPDIR)/clone_parent-q.Po ./$(DEPDIR)/clone_parent-qq.Po \
+	./$(DEPDIR)/clone_parent.Po \
+	./$(DEPDIR)/clone_ptrace--quiet-attach.Po \
+	./$(DEPDIR)/clone_ptrace--quiet-exit.Po \
+	./$(DEPDIR)/clone_ptrace-q.Po ./$(DEPDIR)/clone_ptrace-qq.Po \
+	./$(DEPDIR)/clone_ptrace.Po ./$(DEPDIR)/close_range-P.Po \
+	./$(DEPDIR)/close_range-y.Po ./$(DEPDIR)/close_range-yy.Po \
+	./$(DEPDIR)/close_range.Po ./$(DEPDIR)/copy_file_range.Po \
+	./$(DEPDIR)/count-f.Po ./$(DEPDIR)/creat.Po \
+	./$(DEPDIR)/delay.Po ./$(DEPDIR)/delete_module.Po \
+	./$(DEPDIR)/dev--decode-fds-dev.Po \
+	./$(DEPDIR)/dev--decode-fds-path.Po \
+	./$(DEPDIR)/dev--decode-fds-socket.Po ./$(DEPDIR)/dev-yy.Po \
+	./$(DEPDIR)/dup-P.Po ./$(DEPDIR)/dup-y.Po \
+	./$(DEPDIR)/dup-yy.Po ./$(DEPDIR)/dup.Po ./$(DEPDIR)/dup2-P.Po \
+	./$(DEPDIR)/dup2-y.Po ./$(DEPDIR)/dup2-yy.Po \
+	./$(DEPDIR)/dup2.Po ./$(DEPDIR)/dup3-P.Po \
+	./$(DEPDIR)/dup3-y.Po ./$(DEPDIR)/dup3-yy.Po \
+	./$(DEPDIR)/dup3.Po ./$(DEPDIR)/epoll_create.Po \
+	./$(DEPDIR)/epoll_create1.Po ./$(DEPDIR)/epoll_ctl.Po \
+	./$(DEPDIR)/epoll_pwait.Po ./$(DEPDIR)/epoll_wait.Po \
+	./$(DEPDIR)/erestartsys.Po ./$(DEPDIR)/eventfd.Po \
+	./$(DEPDIR)/execve-v.Po ./$(DEPDIR)/execve.Po \
+	./$(DEPDIR)/execveat-v.Po ./$(DEPDIR)/execveat.Po \
+	./$(DEPDIR)/faccessat-P.Po ./$(DEPDIR)/faccessat-y.Po \
+	./$(DEPDIR)/faccessat-yy.Po ./$(DEPDIR)/faccessat.Po \
+	./$(DEPDIR)/faccessat2-P.Po ./$(DEPDIR)/faccessat2-y.Po \
+	./$(DEPDIR)/faccessat2-yy.Po ./$(DEPDIR)/faccessat2.Po \
 	./$(DEPDIR)/fadvise64.Po ./$(DEPDIR)/fadvise64_64.Po \
 	./$(DEPDIR)/fallocate.Po ./$(DEPDIR)/fanotify_init.Po \
 	./$(DEPDIR)/fanotify_mark-Xabbrev.Po \
@@ -3246,49 +4049,59 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/fanotify_mark.Po ./$(DEPDIR)/fchdir.Po \
 	./$(DEPDIR)/fchmod.Po ./$(DEPDIR)/fchmodat.Po \
 	./$(DEPDIR)/fchown.Po ./$(DEPDIR)/fchown32.Po \
-	./$(DEPDIR)/fchownat.Po ./$(DEPDIR)/fcntl.Po \
+	./$(DEPDIR)/fchownat.Po \
+	./$(DEPDIR)/fcntl--pidns-translation.Po ./$(DEPDIR)/fcntl.Po \
+	./$(DEPDIR)/fcntl64--pidns-translation.Po \
 	./$(DEPDIR)/fcntl64.Po ./$(DEPDIR)/fdatasync.Po \
 	./$(DEPDIR)/fflush.Po ./$(DEPDIR)/file_handle.Po \
 	./$(DEPDIR)/file_ioctl.Po ./$(DEPDIR)/filter-unavailable.Po \
 	./$(DEPDIR)/filter_seccomp-flag.Po \
 	./$(DEPDIR)/filter_seccomp-perf.Po ./$(DEPDIR)/finit_module.Po \
-	./$(DEPDIR)/flock.Po ./$(DEPDIR)/fork-f.Po \
-	./$(DEPDIR)/fsconfig-P.Po ./$(DEPDIR)/fsconfig.Po \
-	./$(DEPDIR)/fsmount.Po ./$(DEPDIR)/fsopen.Po \
-	./$(DEPDIR)/fspick-P.Po ./$(DEPDIR)/fspick.Po \
-	./$(DEPDIR)/fstat-Xabbrev.Po ./$(DEPDIR)/fstat-Xraw.Po \
-	./$(DEPDIR)/fstat-Xverbose.Po ./$(DEPDIR)/fstat.Po \
-	./$(DEPDIR)/fstat64-Xabbrev.Po ./$(DEPDIR)/fstat64-Xraw.Po \
-	./$(DEPDIR)/fstat64-Xverbose.Po ./$(DEPDIR)/fstat64-fstat64.Po \
+	./$(DEPDIR)/flock.Po ./$(DEPDIR)/fork--pidns-translation.Po \
+	./$(DEPDIR)/fork-f.Po ./$(DEPDIR)/fsconfig-P.Po \
+	./$(DEPDIR)/fsconfig.Po ./$(DEPDIR)/fsmount.Po \
+	./$(DEPDIR)/fsopen.Po ./$(DEPDIR)/fspick-P.Po \
+	./$(DEPDIR)/fspick.Po ./$(DEPDIR)/fstat-Xabbrev.Po \
+	./$(DEPDIR)/fstat-Xraw.Po ./$(DEPDIR)/fstat-Xverbose.Po \
+	./$(DEPDIR)/fstat.Po ./$(DEPDIR)/fstat64-Xabbrev.Po \
+	./$(DEPDIR)/fstat64-Xraw.Po ./$(DEPDIR)/fstat64-Xverbose.Po \
+	./$(DEPDIR)/fstat64-fstat64.Po \
 	./$(DEPDIR)/fstatat64-fstatat64.Po ./$(DEPDIR)/fstatfs.Po \
 	./$(DEPDIR)/fstatfs64.Po ./$(DEPDIR)/fsync-y.Po \
 	./$(DEPDIR)/fsync.Po ./$(DEPDIR)/ftruncate.Po \
 	./$(DEPDIR)/ftruncate64-ftruncate64.Po ./$(DEPDIR)/futex.Po \
 	./$(DEPDIR)/futimesat.Po ./$(DEPDIR)/get_mempolicy.Po \
-	./$(DEPDIR)/getcpu.Po ./$(DEPDIR)/getcwd.Po \
-	./$(DEPDIR)/getdents.Po ./$(DEPDIR)/getdents64.Po \
-	./$(DEPDIR)/getegid.Po ./$(DEPDIR)/getegid32.Po \
-	./$(DEPDIR)/geteuid.Po ./$(DEPDIR)/geteuid32.Po \
-	./$(DEPDIR)/getgid.Po ./$(DEPDIR)/getgid32.Po \
-	./$(DEPDIR)/getgroups.Po ./$(DEPDIR)/getgroups32.Po \
-	./$(DEPDIR)/getpeername.Po ./$(DEPDIR)/getpgrp.Po \
-	./$(DEPDIR)/getpid.Po ./$(DEPDIR)/getppid.Po \
-	./$(DEPDIR)/getrandom.Po ./$(DEPDIR)/getresgid.Po \
-	./$(DEPDIR)/getresgid32.Po ./$(DEPDIR)/getresuid.Po \
-	./$(DEPDIR)/getresuid32.Po ./$(DEPDIR)/getrlimit.Po \
-	./$(DEPDIR)/getrusage.Po ./$(DEPDIR)/getsid.Po \
-	./$(DEPDIR)/getsockname.Po ./$(DEPDIR)/gettid.Po \
+	./$(DEPDIR)/get_process_reaper.Po ./$(DEPDIR)/getcpu.Po \
+	./$(DEPDIR)/getcwd.Po ./$(DEPDIR)/getdents-v.Po \
+	./$(DEPDIR)/getdents.Po ./$(DEPDIR)/getdents64-v.Po \
+	./$(DEPDIR)/getdents64.Po ./$(DEPDIR)/getegid.Po \
+	./$(DEPDIR)/getegid32.Po ./$(DEPDIR)/geteuid.Po \
+	./$(DEPDIR)/geteuid32.Po ./$(DEPDIR)/getgid.Po \
+	./$(DEPDIR)/getgid32.Po ./$(DEPDIR)/getgroups.Po \
+	./$(DEPDIR)/getgroups32.Po ./$(DEPDIR)/getpeername.Po \
+	./$(DEPDIR)/getpgrp--pidns-translation.Po \
+	./$(DEPDIR)/getpgrp.Po \
+	./$(DEPDIR)/getpid--pidns-translation.Po ./$(DEPDIR)/getpid.Po \
+	./$(DEPDIR)/getppid.Po ./$(DEPDIR)/getrandom.Po \
+	./$(DEPDIR)/getresgid.Po ./$(DEPDIR)/getresgid32.Po \
+	./$(DEPDIR)/getresuid.Po ./$(DEPDIR)/getresuid32.Po \
+	./$(DEPDIR)/getrlimit.Po ./$(DEPDIR)/getrusage.Po \
+	./$(DEPDIR)/getsid--pidns-translation.Po ./$(DEPDIR)/getsid.Po \
+	./$(DEPDIR)/getsockname.Po \
+	./$(DEPDIR)/gettid--pidns-translation.Po ./$(DEPDIR)/gettid.Po \
 	./$(DEPDIR)/getuid.Po ./$(DEPDIR)/getuid32.Po \
-	./$(DEPDIR)/getxxid.Po ./$(DEPDIR)/group_req.Po \
+	./$(DEPDIR)/getxgid.Po ./$(DEPDIR)/getxpid.Po \
+	./$(DEPDIR)/getxuid.Po ./$(DEPDIR)/group_req.Po \
 	./$(DEPDIR)/inet-cmsg.Po ./$(DEPDIR)/init_module.Po \
 	./$(DEPDIR)/inject-nf.Po ./$(DEPDIR)/inotify.Po \
 	./$(DEPDIR)/inotify_init-y.Po ./$(DEPDIR)/inotify_init.Po \
 	./$(DEPDIR)/inotify_init1-y.Po ./$(DEPDIR)/inotify_init1.Po \
 	./$(DEPDIR)/int_0x80.Po ./$(DEPDIR)/io_uring_enter.Po \
 	./$(DEPDIR)/io_uring_register.Po ./$(DEPDIR)/io_uring_setup.Po \
-	./$(DEPDIR)/ioctl.Po ./$(DEPDIR)/ioctl_block.Po \
-	./$(DEPDIR)/ioctl_dm-v.Po ./$(DEPDIR)/ioctl_dm.Po \
-	./$(DEPDIR)/ioctl_evdev-Xabbrev.Po \
+	./$(DEPDIR)/ioctl.Po \
+	./$(DEPDIR)/ioctl_block--pidns-translation.Po \
+	./$(DEPDIR)/ioctl_block.Po ./$(DEPDIR)/ioctl_dm-v.Po \
+	./$(DEPDIR)/ioctl_dm.Po ./$(DEPDIR)/ioctl_evdev-Xabbrev.Po \
 	./$(DEPDIR)/ioctl_evdev-Xraw.Po \
 	./$(DEPDIR)/ioctl_evdev-Xverbose.Po \
 	./$(DEPDIR)/ioctl_evdev-success-Xabbrev.Po \
@@ -3303,6 +4116,21 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/ioctl_evdev-v-Xraw.Po \
 	./$(DEPDIR)/ioctl_evdev-v-Xverbose.Po \
 	./$(DEPDIR)/ioctl_evdev-v.Po ./$(DEPDIR)/ioctl_evdev.Po \
+	./$(DEPDIR)/ioctl_hdio-Xabbrev.Po \
+	./$(DEPDIR)/ioctl_hdio-Xraw.Po \
+	./$(DEPDIR)/ioctl_hdio-Xverbose.Po \
+	./$(DEPDIR)/ioctl_hdio-success-Xabbrev.Po \
+	./$(DEPDIR)/ioctl_hdio-success-Xraw.Po \
+	./$(DEPDIR)/ioctl_hdio-success-Xverbose.Po \
+	./$(DEPDIR)/ioctl_hdio-success-v-Xabbrev.Po \
+	./$(DEPDIR)/ioctl_hdio-success-v-Xraw.Po \
+	./$(DEPDIR)/ioctl_hdio-success-v-Xverbose.Po \
+	./$(DEPDIR)/ioctl_hdio-success-v.Po \
+	./$(DEPDIR)/ioctl_hdio-success.Po \
+	./$(DEPDIR)/ioctl_hdio-v-Xabbrev.Po \
+	./$(DEPDIR)/ioctl_hdio-v-Xraw.Po \
+	./$(DEPDIR)/ioctl_hdio-v-Xverbose.Po \
+	./$(DEPDIR)/ioctl_hdio-v.Po ./$(DEPDIR)/ioctl_hdio.Po \
 	./$(DEPDIR)/ioctl_inotify.Po ./$(DEPDIR)/ioctl_kvm_run-v.Po \
 	./$(DEPDIR)/ioctl_kvm_run.Po \
 	./$(DEPDIR)/ioctl_kvm_run_auxstr_vcpu.Po \
@@ -3314,9 +4142,24 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/ioctl_rtc-v.Po ./$(DEPDIR)/ioctl_rtc.Po \
 	./$(DEPDIR)/ioctl_scsi.Po ./$(DEPDIR)/ioctl_sg_io_v3.Po \
 	./$(DEPDIR)/ioctl_sg_io_v4.Po \
-	./$(DEPDIR)/ioctl_sock_gifconf.Po ./$(DEPDIR)/ioctl_uffdio.Po \
-	./$(DEPDIR)/ioctl_v4l2.Po ./$(DEPDIR)/ioctl_watchdog.Po \
-	./$(DEPDIR)/ioperm.Po ./$(DEPDIR)/iopl.Po \
+	./$(DEPDIR)/ioctl_sock_gifconf.Po ./$(DEPDIR)/ioctl_tee.Po \
+	./$(DEPDIR)/ioctl_uffdio.Po ./$(DEPDIR)/ioctl_v4l2-Xabbrev.Po \
+	./$(DEPDIR)/ioctl_v4l2-Xraw.Po \
+	./$(DEPDIR)/ioctl_v4l2-Xverbose.Po \
+	./$(DEPDIR)/ioctl_v4l2-success-Xabbrev.Po \
+	./$(DEPDIR)/ioctl_v4l2-success-Xraw.Po \
+	./$(DEPDIR)/ioctl_v4l2-success-Xverbose.Po \
+	./$(DEPDIR)/ioctl_v4l2-success-v-Xabbrev.Po \
+	./$(DEPDIR)/ioctl_v4l2-success-v-Xraw.Po \
+	./$(DEPDIR)/ioctl_v4l2-success-v-Xverbose.Po \
+	./$(DEPDIR)/ioctl_v4l2-success-v.Po \
+	./$(DEPDIR)/ioctl_v4l2-success.Po \
+	./$(DEPDIR)/ioctl_v4l2-v-Xabbrev.Po \
+	./$(DEPDIR)/ioctl_v4l2-v-Xraw.Po \
+	./$(DEPDIR)/ioctl_v4l2-v-Xverbose.Po \
+	./$(DEPDIR)/ioctl_v4l2-v.Po ./$(DEPDIR)/ioctl_v4l2.Po \
+	./$(DEPDIR)/ioctl_watchdog.Po ./$(DEPDIR)/ioperm.Po \
+	./$(DEPDIR)/iopl.Po ./$(DEPDIR)/ioprio--pidns-translation.Po \
 	./$(DEPDIR)/ioprio-Xabbrev.Po ./$(DEPDIR)/ioprio-Xraw.Po \
 	./$(DEPDIR)/ioprio-Xverbose.Po ./$(DEPDIR)/ioprio.Po \
 	./$(DEPDIR)/ip_mreq.Po ./$(DEPDIR)/ipc.Po \
@@ -3329,7 +4172,8 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/ipc_sem-Xverbose.Po ./$(DEPDIR)/ipc_sem.Po \
 	./$(DEPDIR)/ipc_shm-Xabbrev.Po ./$(DEPDIR)/ipc_shm-Xraw.Po \
 	./$(DEPDIR)/ipc_shm-Xverbose.Po ./$(DEPDIR)/ipc_shm.Po \
-	./$(DEPDIR)/is_linux_mips_n64.Po ./$(DEPDIR)/kcmp-y.Po \
+	./$(DEPDIR)/is_linux_mips_n64.Po \
+	./$(DEPDIR)/kcmp-y--pidns-translation.Po ./$(DEPDIR)/kcmp-y.Po \
 	./$(DEPDIR)/kcmp.Po ./$(DEPDIR)/kern_features.Po \
 	./$(DEPDIR)/kernel_version-Xabbrev.Po \
 	./$(DEPDIR)/kernel_version-Xraw.Po \
@@ -3337,10 +4181,12 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/kernel_version.Po ./$(DEPDIR)/kexec_file_load.Po \
 	./$(DEPDIR)/kexec_load.Po ./$(DEPDIR)/keyctl-Xabbrev.Po \
 	./$(DEPDIR)/keyctl-Xraw.Po ./$(DEPDIR)/keyctl-Xverbose.Po \
-	./$(DEPDIR)/keyctl.Po ./$(DEPDIR)/kill.Po \
-	./$(DEPDIR)/kill_child.Po ./$(DEPDIR)/ksysent.Po \
-	./$(DEPDIR)/lchown.Po ./$(DEPDIR)/lchown32.Po \
+	./$(DEPDIR)/keyctl.Po ./$(DEPDIR)/kill--pidns-translation.Po \
+	./$(DEPDIR)/kill.Po ./$(DEPDIR)/kill_child.Po \
+	./$(DEPDIR)/ksysent.Po ./$(DEPDIR)/lchown.Po \
+	./$(DEPDIR)/lchown32.Po \
 	./$(DEPDIR)/libtests_a-create_nl_socket.Po \
+	./$(DEPDIR)/libtests_a-create_tmpfile.Po \
 	./$(DEPDIR)/libtests_a-errno2name.Po \
 	./$(DEPDIR)/libtests_a-error_msg.Po \
 	./$(DEPDIR)/libtests_a-fill_memory.Po \
@@ -3354,6 +4200,7 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/libtests_a-libsocketcall.Po \
 	./$(DEPDIR)/libtests_a-lock_file.Po \
 	./$(DEPDIR)/libtests_a-overflowuid.Po \
+	./$(DEPDIR)/libtests_a-pidns.Po \
 	./$(DEPDIR)/libtests_a-pipe_maxfd.Po \
 	./$(DEPDIR)/libtests_a-print_quoted_string.Po \
 	./$(DEPDIR)/libtests_a-print_time.Po \
@@ -3369,26 +4216,30 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/libtests_a-test_printpath.Po \
 	./$(DEPDIR)/libtests_a-test_printstrn.Po \
 	./$(DEPDIR)/libtests_a-test_ucopy.Po \
-	./$(DEPDIR)/libtests_a-tprintf.Po ./$(DEPDIR)/link.Po \
-	./$(DEPDIR)/linkat.Po ./$(DEPDIR)/list_sigaction_signum.Po \
-	./$(DEPDIR)/llseek.Po ./$(DEPDIR)/localtime.Po \
-	./$(DEPDIR)/lookup_dcookie.Po ./$(DEPDIR)/looping_threads.Po \
-	./$(DEPDIR)/lseek.Po ./$(DEPDIR)/lstat.Po \
-	./$(DEPDIR)/lstat64-lstat64.Po ./$(DEPDIR)/madvise.Po \
+	./$(DEPDIR)/libtests_a-tprintf.Po \
+	./$(DEPDIR)/libtests_a-xmalloc_for_tests.Po \
+	./$(DEPDIR)/link.Po ./$(DEPDIR)/linkat.Po \
+	./$(DEPDIR)/list_sigaction_signum.Po ./$(DEPDIR)/llseek.Po \
+	./$(DEPDIR)/localtime.Po ./$(DEPDIR)/lookup_dcookie.Po \
+	./$(DEPDIR)/looping_threads.Po ./$(DEPDIR)/lseek.Po \
+	./$(DEPDIR)/lstat.Po ./$(DEPDIR)/lstat64-lstat64.Po \
+	./$(DEPDIR)/madvise.Po \
+	./$(DEPDIR)/maybe_switch_current_tcp--quiet-thread-execve.Po \
 	./$(DEPDIR)/maybe_switch_current_tcp.Po \
 	./$(DEPDIR)/mbind-Xabbrev.Po ./$(DEPDIR)/mbind-Xraw.Po \
 	./$(DEPDIR)/mbind-Xverbose.Po ./$(DEPDIR)/mbind.Po \
 	./$(DEPDIR)/membarrier.Po ./$(DEPDIR)/memfd_create-Xabbrev.Po \
 	./$(DEPDIR)/memfd_create-Xraw.Po \
 	./$(DEPDIR)/memfd_create-Xverbose.Po \
-	./$(DEPDIR)/memfd_create.Po ./$(DEPDIR)/migrate_pages.Po \
-	./$(DEPDIR)/mincore.Po ./$(DEPDIR)/mkdir.Po \
-	./$(DEPDIR)/mkdirat.Po ./$(DEPDIR)/mknod.Po \
-	./$(DEPDIR)/mknodat.Po ./$(DEPDIR)/mlock.Po \
-	./$(DEPDIR)/mlock2.Po ./$(DEPDIR)/mlockall.Po \
-	./$(DEPDIR)/mmap-Xabbrev.Po ./$(DEPDIR)/mmap-Xraw.Po \
-	./$(DEPDIR)/mmap-Xverbose.Po ./$(DEPDIR)/mmap.Po \
-	./$(DEPDIR)/mmap64-mmap64.Po \
+	./$(DEPDIR)/memfd_create.Po \
+	./$(DEPDIR)/migrate_pages--pidns-translation.Po \
+	./$(DEPDIR)/migrate_pages.Po ./$(DEPDIR)/mincore.Po \
+	./$(DEPDIR)/mkdir.Po ./$(DEPDIR)/mkdirat.Po \
+	./$(DEPDIR)/mknod.Po ./$(DEPDIR)/mknodat.Po \
+	./$(DEPDIR)/mlock.Po ./$(DEPDIR)/mlock2.Po \
+	./$(DEPDIR)/mlockall.Po ./$(DEPDIR)/mmap-Xabbrev.Po \
+	./$(DEPDIR)/mmap-Xraw.Po ./$(DEPDIR)/mmap-Xverbose.Po \
+	./$(DEPDIR)/mmap.Po ./$(DEPDIR)/mmap64-mmap64.Po \
 	./$(DEPDIR)/mmap64_Xabbrev-mmap64-Xabbrev.Po \
 	./$(DEPDIR)/mmap64_Xraw-mmap64-Xraw.Po \
 	./$(DEPDIR)/mmap64_Xverbose-mmap64-Xverbose.Po \
@@ -3397,24 +4248,33 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/modify_ldt.Po ./$(DEPDIR)/mount-Xabbrev.Po \
 	./$(DEPDIR)/mount-Xraw.Po ./$(DEPDIR)/mount-Xverbose.Po \
 	./$(DEPDIR)/mount.Po ./$(DEPDIR)/move_mount-P.Po \
-	./$(DEPDIR)/move_mount.Po ./$(DEPDIR)/move_pages-Xabbrev.Po \
+	./$(DEPDIR)/move_mount.Po \
+	./$(DEPDIR)/move_pages--pidns-translation.Po \
+	./$(DEPDIR)/move_pages-Xabbrev.Po \
 	./$(DEPDIR)/move_pages-Xraw.Po \
 	./$(DEPDIR)/move_pages-Xverbose.Po ./$(DEPDIR)/move_pages.Po \
 	./$(DEPDIR)/mq.Po ./$(DEPDIR)/mq_sendrecv-read.Po \
 	./$(DEPDIR)/mq_sendrecv-write.Po ./$(DEPDIR)/mq_sendrecv.Po \
 	./$(DEPDIR)/msg_control-v.Po ./$(DEPDIR)/msg_control.Po \
 	./$(DEPDIR)/msg_name.Po ./$(DEPDIR)/munlockall.Po \
-	./$(DEPDIR)/nanosleep.Po ./$(DEPDIR)/net-accept-connect.Po \
+	./$(DEPDIR)/nanosleep.Po \
+	./$(DEPDIR)/net--decode-fds-dev-netlink.Po \
+	./$(DEPDIR)/net--decode-fds-none-netlink.Po \
+	./$(DEPDIR)/net--decode-fds-path-netlink.Po \
+	./$(DEPDIR)/net--decode-fds-socket-netlink.Po \
+	./$(DEPDIR)/net-accept-connect.Po \
 	./$(DEPDIR)/net-icmp_filter.Po \
 	./$(DEPDIR)/net-packet_mreq-Xabbrev.Po \
 	./$(DEPDIR)/net-packet_mreq-Xraw.Po \
 	./$(DEPDIR)/net-packet_mreq-Xverbose.Po \
-	./$(DEPDIR)/net-packet_mreq.Po ./$(DEPDIR)/net-sockaddr.Po \
-	./$(DEPDIR)/net-tpacket_req.Po \
+	./$(DEPDIR)/net-packet_mreq.Po \
+	./$(DEPDIR)/net-sockaddr--pidns-translation.Po \
+	./$(DEPDIR)/net-sockaddr.Po ./$(DEPDIR)/net-tpacket_req.Po \
 	./$(DEPDIR)/net-tpacket_stats-success.Po \
 	./$(DEPDIR)/net-tpacket_stats.Po ./$(DEPDIR)/net-y-unix.Po \
 	./$(DEPDIR)/net-yy-inet.Po ./$(DEPDIR)/net-yy-inet6.Po \
 	./$(DEPDIR)/net-yy-netlink.Po ./$(DEPDIR)/net-yy-unix.Po \
+	./$(DEPDIR)/netlink_audit--pidns-translation.Po \
 	./$(DEPDIR)/netlink_audit.Po ./$(DEPDIR)/netlink_crypto.Po \
 	./$(DEPDIR)/netlink_generic.Po \
 	./$(DEPDIR)/netlink_inet_diag.Po \
@@ -3445,7 +4305,9 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/nlattr_ifla_af_spec.Po \
 	./$(DEPDIR)/nlattr_ifla_brport.Po \
 	./$(DEPDIR)/nlattr_ifla_linkinfo.Po \
-	./$(DEPDIR)/nlattr_ifla_port.Po ./$(DEPDIR)/nlattr_ifla_xdp.Po \
+	./$(DEPDIR)/nlattr_ifla_port.Po \
+	./$(DEPDIR)/nlattr_ifla_xdp-y.Po \
+	./$(DEPDIR)/nlattr_ifla_xdp.Po \
 	./$(DEPDIR)/nlattr_inet_diag_msg.Po \
 	./$(DEPDIR)/nlattr_inet_diag_req_compat.Po \
 	./$(DEPDIR)/nlattr_inet_diag_req_v2.Po \
@@ -3470,7 +4332,13 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/oldselect-efault.Po ./$(DEPDIR)/oldselect.Po \
 	./$(DEPDIR)/oldstat.Po ./$(DEPDIR)/open.Po \
 	./$(DEPDIR)/open_tree-P.Po ./$(DEPDIR)/open_tree.Po \
-	./$(DEPDIR)/openat.Po ./$(DEPDIR)/orphaned_process_group.Po \
+	./$(DEPDIR)/openat.Po ./$(DEPDIR)/openat2-Xabbrev.Po \
+	./$(DEPDIR)/openat2-Xraw.Po ./$(DEPDIR)/openat2-Xverbose.Po \
+	./$(DEPDIR)/openat2-v-y-Xabbrev.Po \
+	./$(DEPDIR)/openat2-v-y-Xraw.Po \
+	./$(DEPDIR)/openat2-v-y-Xverbose.Po ./$(DEPDIR)/openat2-v-y.Po \
+	./$(DEPDIR)/openat2-v.Po ./$(DEPDIR)/openat2-y.Po \
+	./$(DEPDIR)/openat2.Po ./$(DEPDIR)/orphaned_process_group.Po \
 	./$(DEPDIR)/osf_utimes.Po ./$(DEPDIR)/pause.Po \
 	./$(DEPDIR)/pc.Po ./$(DEPDIR)/perf_event_open.Po \
 	./$(DEPDIR)/perf_event_open_nonverbose.Po \
@@ -3478,8 +4346,16 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/personality-Xabbrev.Po \
 	./$(DEPDIR)/personality-Xraw.Po \
 	./$(DEPDIR)/personality-Xverbose.Po ./$(DEPDIR)/personality.Po \
+	./$(DEPDIR)/pidfd_getfd-y.Po ./$(DEPDIR)/pidfd_getfd-yy.Po \
+	./$(DEPDIR)/pidfd_getfd.Po \
+	./$(DEPDIR)/pidfd_open--decode-fd-path.Po \
+	./$(DEPDIR)/pidfd_open--decode-fd-pidfd.Po \
+	./$(DEPDIR)/pidfd_open--decode-fd-socket.Po \
+	./$(DEPDIR)/pidfd_open--pidns-translation.Po \
 	./$(DEPDIR)/pidfd_open-P.Po ./$(DEPDIR)/pidfd_open-y.Po \
-	./$(DEPDIR)/pidfd_open.Po ./$(DEPDIR)/pidfd_send_signal.Po \
+	./$(DEPDIR)/pidfd_open-yy.Po ./$(DEPDIR)/pidfd_open.Po \
+	./$(DEPDIR)/pidfd_send_signal--pidns-translation.Po \
+	./$(DEPDIR)/pidfd_send_signal.Po ./$(DEPDIR)/pidns-cache.Po \
 	./$(DEPDIR)/pipe.Po ./$(DEPDIR)/pipe2.Po \
 	./$(DEPDIR)/pkey_alloc.Po ./$(DEPDIR)/pkey_free.Po \
 	./$(DEPDIR)/pkey_mprotect.Po ./$(DEPDIR)/poll-P.Po \
@@ -3496,7 +4372,7 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/pread64_pwrite64-pread64-pwrite64.Po \
 	./$(DEPDIR)/preadv-preadv.Po ./$(DEPDIR)/preadv2-pwritev2.Po \
 	./$(DEPDIR)/preadv_pwritev-preadv-pwritev.Po \
-	./$(DEPDIR)/print_maxfd.Po \
+	./$(DEPDIR)/print_maxfd.Po ./$(DEPDIR)/print_ppid_tracerpid.Po \
 	./$(DEPDIR)/printpath-umovestr-peekdata.Po \
 	./$(DEPDIR)/printpath-umovestr-undumpable.Po \
 	./$(DEPDIR)/printpath-umovestr.Po \
@@ -3505,8 +4381,12 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/printsignal-Xverbose.Po ./$(DEPDIR)/printstr.Po \
 	./$(DEPDIR)/printstrn-umoven-peekdata.Po \
 	./$(DEPDIR)/printstrn-umoven-undumpable.Po \
-	./$(DEPDIR)/printstrn-umoven.Po ./$(DEPDIR)/prlimit64.Po \
+	./$(DEPDIR)/printstrn-umoven.Po \
+	./$(DEPDIR)/prlimit64--pidns-translation.Po \
+	./$(DEPDIR)/prlimit64.Po \
+	./$(DEPDIR)/process_vm_readv--pidns-translation.Po \
 	./$(DEPDIR)/process_vm_readv.Po \
+	./$(DEPDIR)/process_vm_writev--pidns-translation.Po \
 	./$(DEPDIR)/process_vm_writev.Po ./$(DEPDIR)/pselect6.Po \
 	./$(DEPDIR)/ptrace.Po ./$(DEPDIR)/ptrace_syscall_info.Po \
 	./$(DEPDIR)/pwritev-pwritev.Po ./$(DEPDIR)/qual_fault.Po \
@@ -3536,9 +4416,11 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/request_key.Po ./$(DEPDIR)/restart_syscall.Po \
 	./$(DEPDIR)/riscv_flush_icache.Po ./$(DEPDIR)/rmdir.Po \
 	./$(DEPDIR)/rt_sigaction.Po ./$(DEPDIR)/rt_sigpending.Po \
-	./$(DEPDIR)/rt_sigprocmask.Po ./$(DEPDIR)/rt_sigqueueinfo.Po \
-	./$(DEPDIR)/rt_sigreturn.Po ./$(DEPDIR)/rt_sigsuspend.Po \
-	./$(DEPDIR)/rt_sigtimedwait.Po \
+	./$(DEPDIR)/rt_sigprocmask.Po \
+	./$(DEPDIR)/rt_sigqueueinfo--pidns-translation.Po \
+	./$(DEPDIR)/rt_sigqueueinfo.Po ./$(DEPDIR)/rt_sigreturn.Po \
+	./$(DEPDIR)/rt_sigsuspend.Po ./$(DEPDIR)/rt_sigtimedwait.Po \
+	./$(DEPDIR)/rt_tgsigqueueinfo--pidns-translation.Po \
 	./$(DEPDIR)/rt_tgsigqueueinfo.Po \
 	./$(DEPDIR)/run_expect_termsig.Po \
 	./$(DEPDIR)/s390_guarded_storage-v.Po \
@@ -3548,8 +4430,13 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/s390_sthyi.Po \
 	./$(DEPDIR)/sched_get_priority_mxx.Po \
 	./$(DEPDIR)/sched_rr_get_interval.Po \
-	./$(DEPDIR)/sched_xetaffinity.Po ./$(DEPDIR)/sched_xetattr.Po \
+	./$(DEPDIR)/sched_xetaffinity--pidns-translation.Po \
+	./$(DEPDIR)/sched_xetaffinity.Po \
+	./$(DEPDIR)/sched_xetattr--pidns-translation.Po \
+	./$(DEPDIR)/sched_xetattr.Po \
+	./$(DEPDIR)/sched_xetparam--pidns-translation.Po \
 	./$(DEPDIR)/sched_xetparam.Po \
+	./$(DEPDIR)/sched_xetscheduler--pidns-translation.Po \
 	./$(DEPDIR)/sched_xetscheduler.Po ./$(DEPDIR)/sched_yield.Po \
 	./$(DEPDIR)/scm_rights.Po ./$(DEPDIR)/seccomp-filter-v.Po \
 	./$(DEPDIR)/seccomp-filter.Po ./$(DEPDIR)/seccomp-strict.Po \
@@ -3567,22 +4454,25 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/setfsuid32.Po ./$(DEPDIR)/setgid.Po \
 	./$(DEPDIR)/setgid32.Po ./$(DEPDIR)/setgroups.Po \
 	./$(DEPDIR)/setgroups32.Po ./$(DEPDIR)/sethostname.Po \
-	./$(DEPDIR)/setns.Po ./$(DEPDIR)/setregid.Po \
-	./$(DEPDIR)/setregid32.Po ./$(DEPDIR)/setresgid.Po \
-	./$(DEPDIR)/setresgid32.Po ./$(DEPDIR)/setresuid.Po \
-	./$(DEPDIR)/setresuid32.Po ./$(DEPDIR)/setreuid.Po \
-	./$(DEPDIR)/setreuid32.Po ./$(DEPDIR)/setrlimit-Xabbrev.Po \
-	./$(DEPDIR)/setrlimit-Xraw.Po \
+	./$(DEPDIR)/setns.Po ./$(DEPDIR)/setpgrp-exec.Po \
+	./$(DEPDIR)/setregid.Po ./$(DEPDIR)/setregid32.Po \
+	./$(DEPDIR)/setresgid.Po ./$(DEPDIR)/setresgid32.Po \
+	./$(DEPDIR)/setresuid.Po ./$(DEPDIR)/setresuid32.Po \
+	./$(DEPDIR)/setreuid.Po ./$(DEPDIR)/setreuid32.Po \
+	./$(DEPDIR)/setrlimit-Xabbrev.Po ./$(DEPDIR)/setrlimit-Xraw.Po \
 	./$(DEPDIR)/setrlimit-Xverbose.Po ./$(DEPDIR)/setrlimit.Po \
 	./$(DEPDIR)/setuid.Po ./$(DEPDIR)/setuid32.Po \
 	./$(DEPDIR)/shmxt.Po ./$(DEPDIR)/shutdown.Po \
 	./$(DEPDIR)/sigaction.Po ./$(DEPDIR)/sigaltstack.Po \
 	./$(DEPDIR)/siginfo.Po ./$(DEPDIR)/signal.Po \
+	./$(DEPDIR)/signal_receive--pidns-translation.Po \
 	./$(DEPDIR)/signal_receive.Po ./$(DEPDIR)/signalfd4.Po \
 	./$(DEPDIR)/sigpending.Po ./$(DEPDIR)/sigprocmask.Po \
 	./$(DEPDIR)/sigreturn.Po ./$(DEPDIR)/sigsuspend.Po \
 	./$(DEPDIR)/sleep.Po ./$(DEPDIR)/so_error.Po \
-	./$(DEPDIR)/so_linger.Po ./$(DEPDIR)/so_peercred-Xabbrev.Po \
+	./$(DEPDIR)/so_linger.Po \
+	./$(DEPDIR)/so_peercred--pidns-translation.Po \
+	./$(DEPDIR)/so_peercred-Xabbrev.Po \
 	./$(DEPDIR)/so_peercred-Xraw.Po \
 	./$(DEPDIR)/so_peercred-Xverbose.Po ./$(DEPDIR)/so_peercred.Po \
 	./$(DEPDIR)/sock_filter-v-Xabbrev.Po \
@@ -3604,29 +4494,45 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/stack-fcall-mangled.Po ./$(DEPDIR)/stack-fcall.Po \
 	./$(DEPDIR)/stat.Po ./$(DEPDIR)/stat64-stat64.Po \
 	./$(DEPDIR)/statfs-statfs.Po ./$(DEPDIR)/statfs64.Po \
-	./$(DEPDIR)/status-all.Po ./$(DEPDIR)/status-failed.Po \
-	./$(DEPDIR)/status-none-f.Po \
+	./$(DEPDIR)/status-all.Po ./$(DEPDIR)/status-failed-long.Po \
+	./$(DEPDIR)/status-failed-status.Po \
+	./$(DEPDIR)/status-failed.Po ./$(DEPDIR)/status-none-f.Po \
 	./$(DEPDIR)/status-none-threads.Po ./$(DEPDIR)/status-none.Po \
+	./$(DEPDIR)/status-successful-long.Po \
+	./$(DEPDIR)/status-successful-status.Po \
 	./$(DEPDIR)/status-successful.Po \
 	./$(DEPDIR)/status-unfinished-threads.Po \
 	./$(DEPDIR)/status-unfinished.Po ./$(DEPDIR)/statx.Po \
+	./$(DEPDIR)/strace--strings-in-hex-all.Po \
+	./$(DEPDIR)/strace--strings-in-hex-non-ascii.Po \
+	./$(DEPDIR)/strace--strings-in-hex.Po ./$(DEPDIR)/strace-n.Po \
+	./$(DEPDIR)/strace-x.Po ./$(DEPDIR)/strace-xx.Po \
 	./$(DEPDIR)/swap.Po ./$(DEPDIR)/sxetmask.Po \
 	./$(DEPDIR)/symlink.Po ./$(DEPDIR)/symlinkat.Po \
 	./$(DEPDIR)/sync.Po ./$(DEPDIR)/sync_file_range.Po \
 	./$(DEPDIR)/sync_file_range2.Po ./$(DEPDIR)/sysinfo.Po \
 	./$(DEPDIR)/syslog-success.Po ./$(DEPDIR)/syslog.Po \
-	./$(DEPDIR)/tee.Po ./$(DEPDIR)/threads-execve.Po \
-	./$(DEPDIR)/time.Po ./$(DEPDIR)/timer_create.Po \
-	./$(DEPDIR)/timer_xettime.Po ./$(DEPDIR)/timerfd_xettime.Po \
-	./$(DEPDIR)/times-fail.Po ./$(DEPDIR)/times.Po \
-	./$(DEPDIR)/tracer_ppid_pgid_sid.Po ./$(DEPDIR)/truncate.Po \
+	./$(DEPDIR)/tee.Po ./$(DEPDIR)/tgkill--pidns-translation.Po \
+	./$(DEPDIR)/tgkill.Po \
+	./$(DEPDIR)/threads-execve--quiet-thread-execve.Po \
+	./$(DEPDIR)/threads-execve-q.Po \
+	./$(DEPDIR)/threads-execve-qq.Po \
+	./$(DEPDIR)/threads-execve-qqq.Po \
+	./$(DEPDIR)/threads-execve.Po ./$(DEPDIR)/time.Po \
+	./$(DEPDIR)/timer_create.Po ./$(DEPDIR)/timer_xettime.Po \
+	./$(DEPDIR)/timerfd_xettime.Po ./$(DEPDIR)/times-fail.Po \
+	./$(DEPDIR)/times.Po ./$(DEPDIR)/tkill--pidns-translation.Po \
+	./$(DEPDIR)/tkill.Po ./$(DEPDIR)/tracer_ppid_pgid_sid.Po \
+	./$(DEPDIR)/trie_test-trie_for_tests.Po \
+	./$(DEPDIR)/trie_test-trie_test.Po ./$(DEPDIR)/truncate.Po \
 	./$(DEPDIR)/truncate64-truncate64.Po ./$(DEPDIR)/ugetrlimit.Po \
 	./$(DEPDIR)/uio-uio.Po ./$(DEPDIR)/umask.Po \
 	./$(DEPDIR)/umount.Po ./$(DEPDIR)/umount2.Po \
 	./$(DEPDIR)/umoven-illptr.Po ./$(DEPDIR)/umovestr-illptr.Po \
 	./$(DEPDIR)/umovestr.Po ./$(DEPDIR)/umovestr2.Po \
 	./$(DEPDIR)/umovestr3.Po ./$(DEPDIR)/umovestr_cached.Po \
-	./$(DEPDIR)/uname.Po ./$(DEPDIR)/unblock_reset_raise.Po \
+	./$(DEPDIR)/umovestr_cached_adjacent.Po ./$(DEPDIR)/uname.Po \
+	./$(DEPDIR)/unblock_reset_raise.Po \
 	./$(DEPDIR)/unix-pair-send-recv.Po \
 	./$(DEPDIR)/unix-pair-sendto-recvfrom.Po ./$(DEPDIR)/unlink.Po \
 	./$(DEPDIR)/unlinkat.Po ./$(DEPDIR)/unshare.Po \
@@ -3639,10 +4545,15 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/wait4-v.Po ./$(DEPDIR)/wait4.Po \
 	./$(DEPDIR)/waitid-v.Po ./$(DEPDIR)/waitid.Po \
 	./$(DEPDIR)/waitpid.Po ./$(DEPDIR)/xattr-strings.Po \
-	./$(DEPDIR)/xattr.Po ./$(DEPDIR)/xet_robust_list.Po \
+	./$(DEPDIR)/xattr.Po \
+	./$(DEPDIR)/xet_robust_list--pidns-translation.Po \
+	./$(DEPDIR)/xet_robust_list.Po \
 	./$(DEPDIR)/xet_thread_area_x86.Po ./$(DEPDIR)/xetitimer.Po \
-	./$(DEPDIR)/xetpgid.Po ./$(DEPDIR)/xetpriority.Po \
-	./$(DEPDIR)/xettimeofday.Po ./$(DEPDIR)/zeroargc.Po
+	./$(DEPDIR)/xetpgid--pidns-translation.Po \
+	./$(DEPDIR)/xetpgid.Po \
+	./$(DEPDIR)/xetpriority--pidns-translation.Po \
+	./$(DEPDIR)/xetpriority.Po ./$(DEPDIR)/xettimeofday.Po \
+	./$(DEPDIR)/zeroargc.Po
 am__mv = mv -f
 AM_V_lt = $(am__v_lt_@AM_V@)
 am__v_lt_ = $(am__v_lt_@AM_DEFAULT_V@)
@@ -3667,85 +4578,121 @@ SOURCES = $(libtests_a_SOURCES) _newsele
 	block_reset_raise_run.c block_reset_run.c bpf.c \
 	bpf-obj_get_info_by_fd.c bpf-obj_get_info_by_fd-prog.c \
 	bpf-obj_get_info_by_fd-prog-v.c bpf-obj_get_info_by_fd-v.c \
-	bpf-success.c bpf-success-v.c bpf-v.c brk.c btrfs.c caps.c \
-	caps-abbrev.c check_sigblock.c check_sigign.c chmod.c chown.c \
-	chown32.c chroot.c clock_adjtime.c clock_nanosleep.c \
-	clock_xettime.c clone-flags.c clone3.c clone3-Xabbrev.c \
-	clone3-Xraw.c clone3-Xverbose.c clone3-success.c \
-	clone3-success-Xabbrev.c clone3-success-Xraw.c \
-	clone3-success-Xverbose.c clone_parent.c clone_ptrace.c \
+	bpf-success.c bpf-success-long-y.c bpf-success-v.c bpf-v.c \
+	brk.c btrfs.c caps.c caps-abbrev.c check_sigblock.c \
+	check_sigign.c chmod.c chown.c chown32.c chroot.c \
+	clock_adjtime.c clock_nanosleep.c clock_xettime.c \
+	clone-flags.c clone3.c clone3-Xabbrev.c clone3-Xraw.c \
+	clone3-Xverbose.c clone3-success.c clone3-success-Xabbrev.c \
+	clone3-success-Xraw.c clone3-success-Xverbose.c clone_parent.c \
+	clone_parent--quiet-exit.c clone_parent-q.c clone_parent-qq.c \
+	clone_ptrace.c clone_ptrace--quiet-attach.c \
+	clone_ptrace--quiet-exit.c clone_ptrace-q.c clone_ptrace-qq.c \
+	close_range.c close_range-P.c close_range-y.c close_range-yy.c \
 	copy_file_range.c count-f.c creat.c delay.c delete_module.c \
-	dev-yy.c dup.c dup2.c dup3.c epoll_create.c epoll_create1.c \
-	epoll_ctl.c epoll_pwait.c epoll_wait.c erestartsys.c eventfd.c \
-	execve.c execve-v.c execveat.c execveat-v.c faccessat.c \
-	fadvise64.c fadvise64_64.c fallocate.c fanotify_init.c \
-	fanotify_mark.c fanotify_mark-Xabbrev.c fanotify_mark-Xraw.c \
+	dev--decode-fds-dev.c dev--decode-fds-path.c \
+	dev--decode-fds-socket.c dev-yy.c dup.c dup-P.c dup-y.c \
+	dup-yy.c dup2.c dup2-P.c dup2-y.c dup2-yy.c dup3.c dup3-P.c \
+	dup3-y.c dup3-yy.c epoll_create.c epoll_create1.c epoll_ctl.c \
+	epoll_pwait.c epoll_wait.c erestartsys.c eventfd.c execve.c \
+	execve-v.c execveat.c execveat-v.c faccessat.c faccessat-P.c \
+	faccessat-y.c faccessat-yy.c faccessat2.c faccessat2-P.c \
+	faccessat2-y.c faccessat2-yy.c fadvise64.c fadvise64_64.c \
+	fallocate.c fanotify_init.c fanotify_mark.c \
+	fanotify_mark-Xabbrev.c fanotify_mark-Xraw.c \
 	fanotify_mark-Xverbose.c fchdir.c fchmod.c fchmodat.c fchown.c \
-	fchown32.c fchownat.c fcntl.c fcntl64.c fdatasync.c fflush.c \
+	fchown32.c fchownat.c fcntl.c fcntl--pidns-translation.c \
+	fcntl64.c fcntl64--pidns-translation.c fdatasync.c fflush.c \
 	file_handle.c file_ioctl.c filter-unavailable.c \
 	filter_seccomp-flag.c filter_seccomp-perf.c finit_module.c \
-	flock.c fork-f.c fsconfig.c fsconfig-P.c fsmount.c fsopen.c \
-	fspick.c fspick-P.c fstat.c fstat-Xabbrev.c fstat-Xraw.c \
-	fstat-Xverbose.c fstat64.c fstat64-Xabbrev.c fstat64-Xraw.c \
-	fstat64-Xverbose.c fstatat64.c fstatfs.c fstatfs64.c fsync.c \
-	fsync-y.c ftruncate.c ftruncate64.c futex.c futimesat.c \
-	get_mempolicy.c getcpu.c getcwd.c getdents.c getdents64.c \
-	getegid.c getegid32.c geteuid.c geteuid32.c getgid.c \
-	getgid32.c getgroups.c getgroups32.c getpeername.c getpgrp.c \
-	getpid.c getppid.c getrandom.c getresgid.c getresgid32.c \
-	getresuid.c getresuid32.c getrlimit.c getrusage.c getsid.c \
-	getsockname.c gettid.c getuid.c getuid32.c getxxid.c \
-	group_req.c inet-cmsg.c init_module.c inject-nf.c inotify.c \
-	inotify_init.c inotify_init-y.c inotify_init1.c \
-	inotify_init1-y.c int_0x80.c io_uring_enter.c \
-	io_uring_register.c io_uring_setup.c ioctl.c ioctl_block.c \
-	ioctl_dm.c ioctl_dm-v.c ioctl_evdev.c ioctl_evdev-Xabbrev.c \
+	flock.c fork--pidns-translation.c fork-f.c fsconfig.c \
+	fsconfig-P.c fsmount.c fsopen.c fspick.c fspick-P.c fstat.c \
+	fstat-Xabbrev.c fstat-Xraw.c fstat-Xverbose.c fstat64.c \
+	fstat64-Xabbrev.c fstat64-Xraw.c fstat64-Xverbose.c \
+	fstatat64.c fstatfs.c fstatfs64.c fsync.c fsync-y.c \
+	ftruncate.c ftruncate64.c futex.c futimesat.c get_mempolicy.c \
+	get_process_reaper.c getcpu.c getcwd.c getdents.c getdents-v.c \
+	getdents64.c getdents64-v.c getegid.c getegid32.c geteuid.c \
+	geteuid32.c getgid.c getgid32.c getgroups.c getgroups32.c \
+	getpeername.c getpgrp.c getpgrp--pidns-translation.c getpid.c \
+	getpid--pidns-translation.c getppid.c getrandom.c getresgid.c \
+	getresgid32.c getresuid.c getresuid32.c getrlimit.c \
+	getrusage.c getsid.c getsid--pidns-translation.c getsockname.c \
+	gettid.c gettid--pidns-translation.c getuid.c getuid32.c \
+	getxgid.c getxpid.c getxuid.c group_req.c inet-cmsg.c \
+	init_module.c inject-nf.c inotify.c inotify_init.c \
+	inotify_init-y.c inotify_init1.c inotify_init1-y.c int_0x80.c \
+	io_uring_enter.c io_uring_register.c io_uring_setup.c ioctl.c \
+	ioctl_block.c ioctl_block--pidns-translation.c ioctl_dm.c \
+	ioctl_dm-v.c ioctl_evdev.c ioctl_evdev-Xabbrev.c \
 	ioctl_evdev-Xraw.c ioctl_evdev-Xverbose.c \
 	ioctl_evdev-success.c ioctl_evdev-success-Xabbrev.c \
 	ioctl_evdev-success-Xraw.c ioctl_evdev-success-Xverbose.c \
 	ioctl_evdev-success-v.c ioctl_evdev-success-v-Xabbrev.c \
 	ioctl_evdev-success-v-Xraw.c ioctl_evdev-success-v-Xverbose.c \
 	ioctl_evdev-v.c ioctl_evdev-v-Xabbrev.c ioctl_evdev-v-Xraw.c \
-	ioctl_evdev-v-Xverbose.c ioctl_inotify.c ioctl_kvm_run.c \
+	ioctl_evdev-v-Xverbose.c ioctl_hdio.c ioctl_hdio-Xabbrev.c \
+	ioctl_hdio-Xraw.c ioctl_hdio-Xverbose.c ioctl_hdio-success.c \
+	ioctl_hdio-success-Xabbrev.c ioctl_hdio-success-Xraw.c \
+	ioctl_hdio-success-Xverbose.c ioctl_hdio-success-v.c \
+	ioctl_hdio-success-v-Xabbrev.c ioctl_hdio-success-v-Xraw.c \
+	ioctl_hdio-success-v-Xverbose.c ioctl_hdio-v.c \
+	ioctl_hdio-v-Xabbrev.c ioctl_hdio-v-Xraw.c \
+	ioctl_hdio-v-Xverbose.c ioctl_inotify.c ioctl_kvm_run.c \
 	ioctl_kvm_run-v.c ioctl_kvm_run_auxstr_vcpu.c ioctl_loop.c \
 	ioctl_loop-nv.c ioctl_loop-v.c ioctl_mtd.c ioctl_nbd.c \
 	ioctl_nsfs.c ioctl_perf.c ioctl_perf-success.c ioctl_ptp.c \
 	ioctl_random.c ioctl_rtc.c ioctl_rtc-v.c ioctl_scsi.c \
 	ioctl_sg_io_v3.c ioctl_sg_io_v4.c ioctl_sock_gifconf.c \
-	ioctl_uffdio.c ioctl_v4l2.c ioctl_watchdog.c ioperm.c iopl.c \
-	ioprio.c ioprio-Xabbrev.c ioprio-Xraw.c ioprio-Xverbose.c \
-	ip_mreq.c ipc.c ipc_msg.c ipc_msg-Xabbrev.c ipc_msg-Xraw.c \
-	ipc_msg-Xverbose.c ipc_msgbuf.c ipc_msgbuf-Xabbrev.c \
-	ipc_msgbuf-Xraw.c ipc_msgbuf-Xverbose.c ipc_sem.c \
-	ipc_sem-Xabbrev.c ipc_sem-Xraw.c ipc_sem-Xverbose.c ipc_shm.c \
-	ipc_shm-Xabbrev.c ipc_shm-Xraw.c ipc_shm-Xverbose.c \
-	is_linux_mips_n64.c kcmp.c kcmp-y.c kern_features.c \
+	ioctl_tee.c ioctl_uffdio.c ioctl_v4l2.c ioctl_v4l2-Xabbrev.c \
+	ioctl_v4l2-Xraw.c ioctl_v4l2-Xverbose.c ioctl_v4l2-success.c \
+	ioctl_v4l2-success-Xabbrev.c ioctl_v4l2-success-Xraw.c \
+	ioctl_v4l2-success-Xverbose.c ioctl_v4l2-success-v.c \
+	ioctl_v4l2-success-v-Xabbrev.c ioctl_v4l2-success-v-Xraw.c \
+	ioctl_v4l2-success-v-Xverbose.c ioctl_v4l2-v.c \
+	ioctl_v4l2-v-Xabbrev.c ioctl_v4l2-v-Xraw.c \
+	ioctl_v4l2-v-Xverbose.c ioctl_watchdog.c ioperm.c iopl.c \
+	ioprio.c ioprio--pidns-translation.c ioprio-Xabbrev.c \
+	ioprio-Xraw.c ioprio-Xverbose.c ip_mreq.c ipc.c ipc_msg.c \
+	ipc_msg-Xabbrev.c ipc_msg-Xraw.c ipc_msg-Xverbose.c \
+	ipc_msgbuf.c ipc_msgbuf-Xabbrev.c ipc_msgbuf-Xraw.c \
+	ipc_msgbuf-Xverbose.c ipc_sem.c ipc_sem-Xabbrev.c \
+	ipc_sem-Xraw.c ipc_sem-Xverbose.c ipc_shm.c ipc_shm-Xabbrev.c \
+	ipc_shm-Xraw.c ipc_shm-Xverbose.c is_linux_mips_n64.c kcmp.c \
+	kcmp-y.c kcmp-y--pidns-translation.c kern_features.c \
 	kernel_version.c kernel_version-Xabbrev.c \
 	kernel_version-Xraw.c kernel_version-Xverbose.c \
 	kexec_file_load.c kexec_load.c keyctl.c keyctl-Xabbrev.c \
-	keyctl-Xraw.c keyctl-Xverbose.c kill.c kill_child.c ksysent.c \
-	lchown.c lchown32.c link.c linkat.c list_sigaction_signum.c \
-	llseek.c localtime.c lookup_dcookie.c looping_threads.c \
-	lseek.c lstat.c lstat64.c madvise.c maybe_switch_current_tcp.c \
-	mbind.c mbind-Xabbrev.c mbind-Xraw.c mbind-Xverbose.c \
-	membarrier.c memfd_create.c memfd_create-Xabbrev.c \
-	memfd_create-Xraw.c memfd_create-Xverbose.c migrate_pages.c \
-	mincore.c mkdir.c mkdirat.c mknod.c mknodat.c mlock.c mlock2.c \
-	mlockall.c mmap.c mmap-Xabbrev.c mmap-Xraw.c mmap-Xverbose.c \
-	mmap64.c mmap64-Xabbrev.c mmap64-Xraw.c mmap64-Xverbose.c \
-	mmsg.c mmsg-silent.c mmsg_name.c mmsg_name-v.c modify_ldt.c \
-	mount.c mount-Xabbrev.c mount-Xraw.c mount-Xverbose.c \
-	move_mount.c move_mount-P.c move_pages.c move_pages-Xabbrev.c \
-	move_pages-Xraw.c move_pages-Xverbose.c mq.c mq_sendrecv.c \
-	mq_sendrecv-read.c mq_sendrecv-write.c msg_control.c \
-	msg_control-v.c msg_name.c munlockall.c nanosleep.c \
-	net-accept-connect.c net-icmp_filter.c net-packet_mreq.c \
-	net-packet_mreq-Xabbrev.c net-packet_mreq-Xraw.c \
-	net-packet_mreq-Xverbose.c net-sockaddr.c net-tpacket_req.c \
-	net-tpacket_stats.c net-tpacket_stats-success.c net-y-unix.c \
-	net-yy-inet.c net-yy-inet6.c net-yy-netlink.c net-yy-unix.c \
-	netlink_audit.c netlink_crypto.c netlink_generic.c \
-	netlink_inet_diag.c netlink_kobject_uevent.c \
+	keyctl-Xraw.c keyctl-Xverbose.c kill.c \
+	kill--pidns-translation.c kill_child.c ksysent.c lchown.c \
+	lchown32.c link.c linkat.c list_sigaction_signum.c llseek.c \
+	localtime.c lookup_dcookie.c looping_threads.c lseek.c lstat.c \
+	lstat64.c madvise.c maybe_switch_current_tcp.c \
+	maybe_switch_current_tcp--quiet-thread-execve.c mbind.c \
+	mbind-Xabbrev.c mbind-Xraw.c mbind-Xverbose.c membarrier.c \
+	memfd_create.c memfd_create-Xabbrev.c memfd_create-Xraw.c \
+	memfd_create-Xverbose.c migrate_pages.c \
+	migrate_pages--pidns-translation.c mincore.c mkdir.c mkdirat.c \
+	mknod.c mknodat.c mlock.c mlock2.c mlockall.c mmap.c \
+	mmap-Xabbrev.c mmap-Xraw.c mmap-Xverbose.c mmap64.c \
+	mmap64-Xabbrev.c mmap64-Xraw.c mmap64-Xverbose.c mmsg.c \
+	mmsg-silent.c mmsg_name.c mmsg_name-v.c modify_ldt.c mount.c \
+	mount-Xabbrev.c mount-Xraw.c mount-Xverbose.c move_mount.c \
+	move_mount-P.c move_pages.c move_pages--pidns-translation.c \
+	move_pages-Xabbrev.c move_pages-Xraw.c move_pages-Xverbose.c \
+	mq.c mq_sendrecv.c mq_sendrecv-read.c mq_sendrecv-write.c \
+	msg_control.c msg_control-v.c msg_name.c munlockall.c \
+	nanosleep.c net--decode-fds-dev-netlink.c \
+	net--decode-fds-none-netlink.c net--decode-fds-path-netlink.c \
+	net--decode-fds-socket-netlink.c net-accept-connect.c \
+	net-icmp_filter.c net-packet_mreq.c net-packet_mreq-Xabbrev.c \
+	net-packet_mreq-Xraw.c net-packet_mreq-Xverbose.c \
+	net-sockaddr.c net-sockaddr--pidns-translation.c \
+	net-tpacket_req.c net-tpacket_stats.c \
+	net-tpacket_stats-success.c net-y-unix.c net-yy-inet.c \
+	net-yy-inet6.c net-yy-netlink.c net-yy-unix.c netlink_audit.c \
+	netlink_audit--pidns-translation.c netlink_crypto.c \
+	netlink_generic.c netlink_inet_diag.c netlink_kobject_uevent.c \
 	netlink_netfilter.c netlink_netlink_diag.c netlink_protocol.c \
 	netlink_route.c netlink_selinux.c netlink_sock_diag.c \
 	netlink_unix_diag.c netlink_xfrm.c newfstatat.c \
@@ -3757,56 +4704,71 @@ SOURCES = $(libtests_a_SOURCES) _newsele
 	nlattr_fib_rule_hdr.c nlattr_ifaddrlblmsg.c nlattr_ifaddrmsg.c \
 	nlattr_ifinfomsg.c nlattr_ifla_af_spec.c nlattr_ifla_brport.c \
 	nlattr_ifla_linkinfo.c nlattr_ifla_port.c nlattr_ifla_xdp.c \
-	nlattr_inet_diag_msg.c nlattr_inet_diag_req_compat.c \
-	nlattr_inet_diag_req_v2.c nlattr_mdba_mdb_entry.c \
-	nlattr_mdba_router_port.c nlattr_ndmsg.c nlattr_ndtmsg.c \
-	nlattr_netconfmsg.c nlattr_netlink_diag_msg.c \
-	nlattr_nlmsgerr.c nlattr_packet_diag_msg.c nlattr_rtgenmsg.c \
-	nlattr_rtmsg.c nlattr_smc_diag_msg.c nlattr_tc_stats.c \
-	nlattr_tca_stab.c nlattr_tcamsg.c nlattr_tcmsg.c \
-	nlattr_unix_diag_msg.c nsyscalls.c nsyscalls-d.c old_mmap.c \
-	old_mmap-P.c old_mmap-Xabbrev.c old_mmap-Xraw.c \
-	old_mmap-Xverbose.c old_mmap-v-none.c oldfstat.c oldlstat.c \
-	oldselect.c oldselect-P.c oldselect-efault.c \
-	oldselect-efault-P.c oldstat.c open.c open_tree.c \
-	open_tree-P.c openat.c orphaned_process_group.c osf_utimes.c \
-	pause.c pc.c perf_event_open.c perf_event_open_nonverbose.c \
+	nlattr_ifla_xdp-y.c nlattr_inet_diag_msg.c \
+	nlattr_inet_diag_req_compat.c nlattr_inet_diag_req_v2.c \
+	nlattr_mdba_mdb_entry.c nlattr_mdba_router_port.c \
+	nlattr_ndmsg.c nlattr_ndtmsg.c nlattr_netconfmsg.c \
+	nlattr_netlink_diag_msg.c nlattr_nlmsgerr.c \
+	nlattr_packet_diag_msg.c nlattr_rtgenmsg.c nlattr_rtmsg.c \
+	nlattr_smc_diag_msg.c nlattr_tc_stats.c nlattr_tca_stab.c \
+	nlattr_tcamsg.c nlattr_tcmsg.c nlattr_unix_diag_msg.c \
+	nsyscalls.c nsyscalls-d.c old_mmap.c old_mmap-P.c \
+	old_mmap-Xabbrev.c old_mmap-Xraw.c old_mmap-Xverbose.c \
+	old_mmap-v-none.c oldfstat.c oldlstat.c oldselect.c \
+	oldselect-P.c oldselect-efault.c oldselect-efault-P.c \
+	oldstat.c open.c open_tree.c open_tree-P.c openat.c openat2.c \
+	openat2-Xabbrev.c openat2-Xraw.c openat2-Xverbose.c \
+	openat2-v.c openat2-v-y.c openat2-v-y-Xabbrev.c \
+	openat2-v-y-Xraw.c openat2-v-y-Xverbose.c openat2-y.c \
+	orphaned_process_group.c osf_utimes.c pause.c pc.c \
+	perf_event_open.c perf_event_open_nonverbose.c \
 	perf_event_open_unabbrev.c personality.c personality-Xabbrev.c \
-	personality-Xraw.c personality-Xverbose.c pidfd_open.c \
-	pidfd_open-P.c pidfd_open-y.c pidfd_send_signal.c pipe.c \
-	pipe2.c pkey_alloc.c pkey_free.c pkey_mprotect.c poll.c \
-	poll-P.c ppoll.c ppoll-P.c ppoll-v.c prctl-arg2-intptr.c \
-	prctl-dumpable.c prctl-name.c prctl-no-args.c \
-	prctl-pdeathsig.c prctl-seccomp-filter-v.c \
+	personality-Xraw.c personality-Xverbose.c pidfd_getfd.c \
+	pidfd_getfd-y.c pidfd_getfd-yy.c pidfd_open.c \
+	pidfd_open--decode-fd-path.c pidfd_open--decode-fd-pidfd.c \
+	pidfd_open--decode-fd-socket.c pidfd_open--pidns-translation.c \
+	pidfd_open-P.c pidfd_open-y.c pidfd_open-yy.c \
+	pidfd_send_signal.c pidfd_send_signal--pidns-translation.c \
+	pidns-cache.c pipe.c pipe2.c pkey_alloc.c pkey_free.c \
+	pkey_mprotect.c poll.c poll-P.c ppoll.c ppoll-P.c ppoll-v.c \
+	prctl-arg2-intptr.c prctl-dumpable.c prctl-name.c \
+	prctl-no-args.c prctl-pdeathsig.c prctl-seccomp-filter-v.c \
 	prctl-seccomp-strict.c prctl-securebits.c prctl-spec-inject.c \
 	prctl-tid_address.c prctl-tsc.c pread64-pwrite64.c preadv.c \
 	preadv-pwritev.c preadv2-pwritev2.c print_maxfd.c \
-	printpath-umovestr.c printpath-umovestr-peekdata.c \
-	printpath-umovestr-undumpable.c printsignal-Xabbrev.c \
-	printsignal-Xraw.c printsignal-Xverbose.c printstr.c \
-	printstrn-umoven.c printstrn-umoven-peekdata.c \
-	printstrn-umoven-undumpable.c prlimit64.c process_vm_readv.c \
-	process_vm_writev.c pselect6.c ptrace.c ptrace_syscall_info.c \
-	pwritev.c qual_fault.c qual_inject-error-signal.c \
-	qual_inject-retval.c qual_inject-signal.c qual_signal.c \
-	quotactl.c quotactl-Xabbrev.c quotactl-Xraw.c \
-	quotactl-Xverbose.c quotactl-success.c quotactl-success-v.c \
-	quotactl-v.c quotactl-xfs.c quotactl-xfs-success.c \
-	quotactl-xfs-success-v.c quotactl-xfs-v.c read-write.c \
-	readahead.c readdir.c readlink.c readlinkat.c readv.c reboot.c \
-	recv-MSG_TRUNC.c recvfrom.c recvfrom-MSG_TRUNC.c \
-	recvmmsg-timeout.c recvmsg.c redirect-fds.c remap_file_pages.c \
-	remap_file_pages-Xabbrev.c remap_file_pages-Xraw.c \
-	remap_file_pages-Xverbose.c rename.c renameat.c renameat2.c \
-	request_key.c restart_syscall.c riscv_flush_icache.c rmdir.c \
-	rt_sigaction.c rt_sigpending.c rt_sigprocmask.c \
-	rt_sigqueueinfo.c rt_sigreturn.c rt_sigsuspend.c \
-	rt_sigtimedwait.c rt_tgsigqueueinfo.c run_expect_termsig.c \
+	print_ppid_tracerpid.c printpath-umovestr.c \
+	printpath-umovestr-peekdata.c printpath-umovestr-undumpable.c \
+	printsignal-Xabbrev.c printsignal-Xraw.c \
+	printsignal-Xverbose.c printstr.c printstrn-umoven.c \
+	printstrn-umoven-peekdata.c printstrn-umoven-undumpable.c \
+	prlimit64.c prlimit64--pidns-translation.c process_vm_readv.c \
+	process_vm_readv--pidns-translation.c process_vm_writev.c \
+	process_vm_writev--pidns-translation.c pselect6.c ptrace.c \
+	ptrace_syscall_info.c pwritev.c qual_fault.c \
+	qual_inject-error-signal.c qual_inject-retval.c \
+	qual_inject-signal.c qual_signal.c quotactl.c \
+	quotactl-Xabbrev.c quotactl-Xraw.c quotactl-Xverbose.c \
+	quotactl-success.c quotactl-success-v.c quotactl-v.c \
+	quotactl-xfs.c quotactl-xfs-success.c quotactl-xfs-success-v.c \
+	quotactl-xfs-v.c read-write.c readahead.c readdir.c readlink.c \
+	readlinkat.c readv.c reboot.c recv-MSG_TRUNC.c recvfrom.c \
+	recvfrom-MSG_TRUNC.c recvmmsg-timeout.c recvmsg.c \
+	redirect-fds.c remap_file_pages.c remap_file_pages-Xabbrev.c \
+	remap_file_pages-Xraw.c remap_file_pages-Xverbose.c rename.c \
+	renameat.c renameat2.c request_key.c restart_syscall.c \
+	riscv_flush_icache.c rmdir.c rt_sigaction.c rt_sigpending.c \
+	rt_sigprocmask.c rt_sigqueueinfo.c \
+	rt_sigqueueinfo--pidns-translation.c rt_sigreturn.c \
+	rt_sigsuspend.c rt_sigtimedwait.c rt_tgsigqueueinfo.c \
+	rt_tgsigqueueinfo--pidns-translation.c run_expect_termsig.c \
 	s390_guarded_storage.c s390_guarded_storage-v.c \
 	s390_pci_mmio_read_write.c s390_runtime_instr.c s390_sthyi.c \
 	s390_sthyi-v.c sched_get_priority_mxx.c \
-	sched_rr_get_interval.c sched_xetaffinity.c sched_xetattr.c \
-	sched_xetparam.c sched_xetscheduler.c sched_yield.c \
+	sched_rr_get_interval.c sched_xetaffinity.c \
+	sched_xetaffinity--pidns-translation.c sched_xetattr.c \
+	sched_xetattr--pidns-translation.c sched_xetparam.c \
+	sched_xetparam--pidns-translation.c sched_xetscheduler.c \
+	sched_xetscheduler--pidns-translation.c sched_yield.c \
 	scm_rights.c seccomp-filter.c seccomp-filter-v.c \
 	seccomp-strict.c seccomp_get_action_avail.c select.c \
 	select-P.c semop.c semop-indirect.c semtimedop.c sendfile.c \
@@ -3815,38 +4777,50 @@ SOURCES = $(libtests_a_SOURCES) _newsele
 	set_ptracer_any.c set_sigblock.c set_sigign.c setdomainname.c \
 	setfsgid.c setfsgid32.c setfsuid.c setfsuid32.c setgid.c \
 	setgid32.c setgroups.c setgroups32.c sethostname.c setns.c \
-	setregid.c setregid32.c setresgid.c setresgid32.c setresuid.c \
-	setresuid32.c setreuid.c setreuid32.c setrlimit.c \
-	setrlimit-Xabbrev.c setrlimit-Xraw.c setrlimit-Xverbose.c \
-	setuid.c setuid32.c shmxt.c shutdown.c sigaction.c \
-	sigaltstack.c siginfo.c signal.c signal_receive.c signalfd4.c \
-	sigpending.c sigprocmask.c sigreturn.c sigsuspend.c sleep.c \
-	so_error.c so_linger.c so_peercred.c so_peercred-Xabbrev.c \
-	so_peercred-Xraw.c so_peercred-Xverbose.c sock_filter-v.c \
-	sock_filter-v-Xabbrev.c sock_filter-v-Xraw.c \
-	sock_filter-v-Xverbose.c sockaddr_xlat-Xabbrev.c \
-	sockaddr_xlat-Xraw.c sockaddr_xlat-Xverbose.c socketcall.c \
-	sockopt-sol_netlink.c sockopt-timestamp.c splice.c \
-	$(stack_fcall_SOURCES) $(stack_fcall_attach_SOURCES) \
-	$(stack_fcall_mangled_SOURCES) stat.c stat64.c statfs.c \
-	statfs64.c status-all.c status-failed.c status-none.c \
-	status-none-f.c status-none-threads.c status-successful.c \
-	status-unfinished.c status-unfinished-threads.c statx.c swap.c \
-	sxetmask.c symlink.c symlinkat.c sync.c sync_file_range.c \
-	sync_file_range2.c sysinfo.c syslog.c syslog-success.c tee.c \
-	threads-execve.c time.c timer_create.c timer_xettime.c \
-	timerfd_xettime.c times.c times-fail.c tracer_ppid_pgid_sid.c \
-	truncate.c truncate64.c ugetrlimit.c uio.c umask.c umount.c \
-	umount2.c umoven-illptr.c umovestr.c umovestr-illptr.c \
-	umovestr2.c umovestr3.c umovestr_cached.c uname.c \
-	unblock_reset_raise.c unix-pair-send-recv.c \
+	setpgrp-exec.c setregid.c setregid32.c setresgid.c \
+	setresgid32.c setresuid.c setresuid32.c setreuid.c \
+	setreuid32.c setrlimit.c setrlimit-Xabbrev.c setrlimit-Xraw.c \
+	setrlimit-Xverbose.c setuid.c setuid32.c shmxt.c shutdown.c \
+	sigaction.c sigaltstack.c siginfo.c signal.c signal_receive.c \
+	signal_receive--pidns-translation.c signalfd4.c sigpending.c \
+	sigprocmask.c sigreturn.c sigsuspend.c sleep.c so_error.c \
+	so_linger.c so_peercred.c so_peercred--pidns-translation.c \
+	so_peercred-Xabbrev.c so_peercred-Xraw.c \
+	so_peercred-Xverbose.c sock_filter-v.c sock_filter-v-Xabbrev.c \
+	sock_filter-v-Xraw.c sock_filter-v-Xverbose.c \
+	sockaddr_xlat-Xabbrev.c sockaddr_xlat-Xraw.c \
+	sockaddr_xlat-Xverbose.c socketcall.c sockopt-sol_netlink.c \
+	sockopt-timestamp.c splice.c $(stack_fcall_SOURCES) \
+	$(stack_fcall_attach_SOURCES) $(stack_fcall_mangled_SOURCES) \
+	stat.c stat64.c statfs.c statfs64.c status-all.c \
+	status-failed.c status-failed-long.c status-failed-status.c \
+	status-none.c status-none-f.c status-none-threads.c \
+	status-successful.c status-successful-long.c \
+	status-successful-status.c status-unfinished.c \
+	status-unfinished-threads.c statx.c strace--strings-in-hex.c \
+	strace--strings-in-hex-all.c \
+	strace--strings-in-hex-non-ascii.c strace-n.c strace-x.c \
+	strace-xx.c swap.c sxetmask.c symlink.c symlinkat.c sync.c \
+	sync_file_range.c sync_file_range2.c sysinfo.c syslog.c \
+	syslog-success.c tee.c tgkill.c tgkill--pidns-translation.c \
+	threads-execve.c threads-execve--quiet-thread-execve.c \
+	threads-execve-q.c threads-execve-qq.c threads-execve-qqq.c \
+	time.c timer_create.c timer_xettime.c timerfd_xettime.c \
+	times.c times-fail.c tkill.c tkill--pidns-translation.c \
+	tracer_ppid_pgid_sid.c $(trie_test_SOURCES) truncate.c \
+	truncate64.c ugetrlimit.c uio.c umask.c umount.c umount2.c \
+	umoven-illptr.c umovestr.c umovestr-illptr.c umovestr2.c \
+	umovestr3.c umovestr_cached.c umovestr_cached_adjacent.c \
+	uname.c unblock_reset_raise.c unix-pair-send-recv.c \
 	unix-pair-sendto-recvfrom.c unlink.c unlinkat.c unshare.c \
 	userfaultfd.c ustat.c utime.c utimensat.c utimensat-Xabbrev.c \
 	utimensat-Xraw.c utimensat-Xverbose.c utimes.c vfork-f.c \
 	vhangup.c vmsplice.c wait4.c wait4-v.c waitid.c waitid-v.c \
 	waitpid.c xattr.c xattr-strings.c xet_robust_list.c \
-	xet_thread_area_x86.c xetitimer.c xetpgid.c xetpriority.c \
-	xettimeofday.c zeroargc.c
+	xet_robust_list--pidns-translation.c xet_thread_area_x86.c \
+	xetitimer.c xetpgid.c xetpgid--pidns-translation.c \
+	xetpriority.c xetpriority--pidns-translation.c xettimeofday.c \
+	zeroargc.c
 DIST_SOURCES = $(libtests_a_SOURCES) _newselect.c _newselect-P.c \
 	accept.c accept4.c access.c acct.c add_key.c adjtimex.c aio.c \
 	aio_pgetevents.c alarm.c answer.c attach-f-p.c \
@@ -3854,85 +4828,121 @@ DIST_SOURCES = $(libtests_a_SOURCES) _ne
 	block_reset_raise_run.c block_reset_run.c bpf.c \
 	bpf-obj_get_info_by_fd.c bpf-obj_get_info_by_fd-prog.c \
 	bpf-obj_get_info_by_fd-prog-v.c bpf-obj_get_info_by_fd-v.c \
-	bpf-success.c bpf-success-v.c bpf-v.c brk.c btrfs.c caps.c \
-	caps-abbrev.c check_sigblock.c check_sigign.c chmod.c chown.c \
-	chown32.c chroot.c clock_adjtime.c clock_nanosleep.c \
-	clock_xettime.c clone-flags.c clone3.c clone3-Xabbrev.c \
-	clone3-Xraw.c clone3-Xverbose.c clone3-success.c \
-	clone3-success-Xabbrev.c clone3-success-Xraw.c \
-	clone3-success-Xverbose.c clone_parent.c clone_ptrace.c \
+	bpf-success.c bpf-success-long-y.c bpf-success-v.c bpf-v.c \
+	brk.c btrfs.c caps.c caps-abbrev.c check_sigblock.c \
+	check_sigign.c chmod.c chown.c chown32.c chroot.c \
+	clock_adjtime.c clock_nanosleep.c clock_xettime.c \
+	clone-flags.c clone3.c clone3-Xabbrev.c clone3-Xraw.c \
+	clone3-Xverbose.c clone3-success.c clone3-success-Xabbrev.c \
+	clone3-success-Xraw.c clone3-success-Xverbose.c clone_parent.c \
+	clone_parent--quiet-exit.c clone_parent-q.c clone_parent-qq.c \
+	clone_ptrace.c clone_ptrace--quiet-attach.c \
+	clone_ptrace--quiet-exit.c clone_ptrace-q.c clone_ptrace-qq.c \
+	close_range.c close_range-P.c close_range-y.c close_range-yy.c \
 	copy_file_range.c count-f.c creat.c delay.c delete_module.c \
-	dev-yy.c dup.c dup2.c dup3.c epoll_create.c epoll_create1.c \
-	epoll_ctl.c epoll_pwait.c epoll_wait.c erestartsys.c eventfd.c \
-	execve.c execve-v.c execveat.c execveat-v.c faccessat.c \
-	fadvise64.c fadvise64_64.c fallocate.c fanotify_init.c \
-	fanotify_mark.c fanotify_mark-Xabbrev.c fanotify_mark-Xraw.c \
+	dev--decode-fds-dev.c dev--decode-fds-path.c \
+	dev--decode-fds-socket.c dev-yy.c dup.c dup-P.c dup-y.c \
+	dup-yy.c dup2.c dup2-P.c dup2-y.c dup2-yy.c dup3.c dup3-P.c \
+	dup3-y.c dup3-yy.c epoll_create.c epoll_create1.c epoll_ctl.c \
+	epoll_pwait.c epoll_wait.c erestartsys.c eventfd.c execve.c \
+	execve-v.c execveat.c execveat-v.c faccessat.c faccessat-P.c \
+	faccessat-y.c faccessat-yy.c faccessat2.c faccessat2-P.c \
+	faccessat2-y.c faccessat2-yy.c fadvise64.c fadvise64_64.c \
+	fallocate.c fanotify_init.c fanotify_mark.c \
+	fanotify_mark-Xabbrev.c fanotify_mark-Xraw.c \
 	fanotify_mark-Xverbose.c fchdir.c fchmod.c fchmodat.c fchown.c \
-	fchown32.c fchownat.c fcntl.c fcntl64.c fdatasync.c fflush.c \
+	fchown32.c fchownat.c fcntl.c fcntl--pidns-translation.c \
+	fcntl64.c fcntl64--pidns-translation.c fdatasync.c fflush.c \
 	file_handle.c file_ioctl.c filter-unavailable.c \
 	filter_seccomp-flag.c filter_seccomp-perf.c finit_module.c \
-	flock.c fork-f.c fsconfig.c fsconfig-P.c fsmount.c fsopen.c \
-	fspick.c fspick-P.c fstat.c fstat-Xabbrev.c fstat-Xraw.c \
-	fstat-Xverbose.c fstat64.c fstat64-Xabbrev.c fstat64-Xraw.c \
-	fstat64-Xverbose.c fstatat64.c fstatfs.c fstatfs64.c fsync.c \
-	fsync-y.c ftruncate.c ftruncate64.c futex.c futimesat.c \
-	get_mempolicy.c getcpu.c getcwd.c getdents.c getdents64.c \
-	getegid.c getegid32.c geteuid.c geteuid32.c getgid.c \
-	getgid32.c getgroups.c getgroups32.c getpeername.c getpgrp.c \
-	getpid.c getppid.c getrandom.c getresgid.c getresgid32.c \
-	getresuid.c getresuid32.c getrlimit.c getrusage.c getsid.c \
-	getsockname.c gettid.c getuid.c getuid32.c getxxid.c \
-	group_req.c inet-cmsg.c init_module.c inject-nf.c inotify.c \
-	inotify_init.c inotify_init-y.c inotify_init1.c \
-	inotify_init1-y.c int_0x80.c io_uring_enter.c \
-	io_uring_register.c io_uring_setup.c ioctl.c ioctl_block.c \
-	ioctl_dm.c ioctl_dm-v.c ioctl_evdev.c ioctl_evdev-Xabbrev.c \
+	flock.c fork--pidns-translation.c fork-f.c fsconfig.c \
+	fsconfig-P.c fsmount.c fsopen.c fspick.c fspick-P.c fstat.c \
+	fstat-Xabbrev.c fstat-Xraw.c fstat-Xverbose.c fstat64.c \
+	fstat64-Xabbrev.c fstat64-Xraw.c fstat64-Xverbose.c \
+	fstatat64.c fstatfs.c fstatfs64.c fsync.c fsync-y.c \
+	ftruncate.c ftruncate64.c futex.c futimesat.c get_mempolicy.c \
+	get_process_reaper.c getcpu.c getcwd.c getdents.c getdents-v.c \
+	getdents64.c getdents64-v.c getegid.c getegid32.c geteuid.c \
+	geteuid32.c getgid.c getgid32.c getgroups.c getgroups32.c \
+	getpeername.c getpgrp.c getpgrp--pidns-translation.c getpid.c \
+	getpid--pidns-translation.c getppid.c getrandom.c getresgid.c \
+	getresgid32.c getresuid.c getresuid32.c getrlimit.c \
+	getrusage.c getsid.c getsid--pidns-translation.c getsockname.c \
+	gettid.c gettid--pidns-translation.c getuid.c getuid32.c \
+	getxgid.c getxpid.c getxuid.c group_req.c inet-cmsg.c \
+	init_module.c inject-nf.c inotify.c inotify_init.c \
+	inotify_init-y.c inotify_init1.c inotify_init1-y.c int_0x80.c \
+	io_uring_enter.c io_uring_register.c io_uring_setup.c ioctl.c \
+	ioctl_block.c ioctl_block--pidns-translation.c ioctl_dm.c \
+	ioctl_dm-v.c ioctl_evdev.c ioctl_evdev-Xabbrev.c \
 	ioctl_evdev-Xraw.c ioctl_evdev-Xverbose.c \
 	ioctl_evdev-success.c ioctl_evdev-success-Xabbrev.c \
 	ioctl_evdev-success-Xraw.c ioctl_evdev-success-Xverbose.c \
 	ioctl_evdev-success-v.c ioctl_evdev-success-v-Xabbrev.c \
 	ioctl_evdev-success-v-Xraw.c ioctl_evdev-success-v-Xverbose.c \
 	ioctl_evdev-v.c ioctl_evdev-v-Xabbrev.c ioctl_evdev-v-Xraw.c \
-	ioctl_evdev-v-Xverbose.c ioctl_inotify.c ioctl_kvm_run.c \
+	ioctl_evdev-v-Xverbose.c ioctl_hdio.c ioctl_hdio-Xabbrev.c \
+	ioctl_hdio-Xraw.c ioctl_hdio-Xverbose.c ioctl_hdio-success.c \
+	ioctl_hdio-success-Xabbrev.c ioctl_hdio-success-Xraw.c \
+	ioctl_hdio-success-Xverbose.c ioctl_hdio-success-v.c \
+	ioctl_hdio-success-v-Xabbrev.c ioctl_hdio-success-v-Xraw.c \
+	ioctl_hdio-success-v-Xverbose.c ioctl_hdio-v.c \
+	ioctl_hdio-v-Xabbrev.c ioctl_hdio-v-Xraw.c \
+	ioctl_hdio-v-Xverbose.c ioctl_inotify.c ioctl_kvm_run.c \
 	ioctl_kvm_run-v.c ioctl_kvm_run_auxstr_vcpu.c ioctl_loop.c \
 	ioctl_loop-nv.c ioctl_loop-v.c ioctl_mtd.c ioctl_nbd.c \
 	ioctl_nsfs.c ioctl_perf.c ioctl_perf-success.c ioctl_ptp.c \
 	ioctl_random.c ioctl_rtc.c ioctl_rtc-v.c ioctl_scsi.c \
 	ioctl_sg_io_v3.c ioctl_sg_io_v4.c ioctl_sock_gifconf.c \
-	ioctl_uffdio.c ioctl_v4l2.c ioctl_watchdog.c ioperm.c iopl.c \
-	ioprio.c ioprio-Xabbrev.c ioprio-Xraw.c ioprio-Xverbose.c \
-	ip_mreq.c ipc.c ipc_msg.c ipc_msg-Xabbrev.c ipc_msg-Xraw.c \
-	ipc_msg-Xverbose.c ipc_msgbuf.c ipc_msgbuf-Xabbrev.c \
-	ipc_msgbuf-Xraw.c ipc_msgbuf-Xverbose.c ipc_sem.c \
-	ipc_sem-Xabbrev.c ipc_sem-Xraw.c ipc_sem-Xverbose.c ipc_shm.c \
-	ipc_shm-Xabbrev.c ipc_shm-Xraw.c ipc_shm-Xverbose.c \
-	is_linux_mips_n64.c kcmp.c kcmp-y.c kern_features.c \
+	ioctl_tee.c ioctl_uffdio.c ioctl_v4l2.c ioctl_v4l2-Xabbrev.c \
+	ioctl_v4l2-Xraw.c ioctl_v4l2-Xverbose.c ioctl_v4l2-success.c \
+	ioctl_v4l2-success-Xabbrev.c ioctl_v4l2-success-Xraw.c \
+	ioctl_v4l2-success-Xverbose.c ioctl_v4l2-success-v.c \
+	ioctl_v4l2-success-v-Xabbrev.c ioctl_v4l2-success-v-Xraw.c \
+	ioctl_v4l2-success-v-Xverbose.c ioctl_v4l2-v.c \
+	ioctl_v4l2-v-Xabbrev.c ioctl_v4l2-v-Xraw.c \
+	ioctl_v4l2-v-Xverbose.c ioctl_watchdog.c ioperm.c iopl.c \
+	ioprio.c ioprio--pidns-translation.c ioprio-Xabbrev.c \
+	ioprio-Xraw.c ioprio-Xverbose.c ip_mreq.c ipc.c ipc_msg.c \
+	ipc_msg-Xabbrev.c ipc_msg-Xraw.c ipc_msg-Xverbose.c \
+	ipc_msgbuf.c ipc_msgbuf-Xabbrev.c ipc_msgbuf-Xraw.c \
+	ipc_msgbuf-Xverbose.c ipc_sem.c ipc_sem-Xabbrev.c \
+	ipc_sem-Xraw.c ipc_sem-Xverbose.c ipc_shm.c ipc_shm-Xabbrev.c \
+	ipc_shm-Xraw.c ipc_shm-Xverbose.c is_linux_mips_n64.c kcmp.c \
+	kcmp-y.c kcmp-y--pidns-translation.c kern_features.c \
 	kernel_version.c kernel_version-Xabbrev.c \
 	kernel_version-Xraw.c kernel_version-Xverbose.c \
 	kexec_file_load.c kexec_load.c keyctl.c keyctl-Xabbrev.c \
-	keyctl-Xraw.c keyctl-Xverbose.c kill.c kill_child.c ksysent.c \
-	lchown.c lchown32.c link.c linkat.c list_sigaction_signum.c \
-	llseek.c localtime.c lookup_dcookie.c looping_threads.c \
-	lseek.c lstat.c lstat64.c madvise.c maybe_switch_current_tcp.c \
-	mbind.c mbind-Xabbrev.c mbind-Xraw.c mbind-Xverbose.c \
-	membarrier.c memfd_create.c memfd_create-Xabbrev.c \
-	memfd_create-Xraw.c memfd_create-Xverbose.c migrate_pages.c \
-	mincore.c mkdir.c mkdirat.c mknod.c mknodat.c mlock.c mlock2.c \
-	mlockall.c mmap.c mmap-Xabbrev.c mmap-Xraw.c mmap-Xverbose.c \
-	mmap64.c mmap64-Xabbrev.c mmap64-Xraw.c mmap64-Xverbose.c \
-	mmsg.c mmsg-silent.c mmsg_name.c mmsg_name-v.c modify_ldt.c \
-	mount.c mount-Xabbrev.c mount-Xraw.c mount-Xverbose.c \
-	move_mount.c move_mount-P.c move_pages.c move_pages-Xabbrev.c \
-	move_pages-Xraw.c move_pages-Xverbose.c mq.c mq_sendrecv.c \
-	mq_sendrecv-read.c mq_sendrecv-write.c msg_control.c \
-	msg_control-v.c msg_name.c munlockall.c nanosleep.c \
-	net-accept-connect.c net-icmp_filter.c net-packet_mreq.c \
-	net-packet_mreq-Xabbrev.c net-packet_mreq-Xraw.c \
-	net-packet_mreq-Xverbose.c net-sockaddr.c net-tpacket_req.c \
-	net-tpacket_stats.c net-tpacket_stats-success.c net-y-unix.c \
-	net-yy-inet.c net-yy-inet6.c net-yy-netlink.c net-yy-unix.c \
-	netlink_audit.c netlink_crypto.c netlink_generic.c \
-	netlink_inet_diag.c netlink_kobject_uevent.c \
+	keyctl-Xraw.c keyctl-Xverbose.c kill.c \
+	kill--pidns-translation.c kill_child.c ksysent.c lchown.c \
+	lchown32.c link.c linkat.c list_sigaction_signum.c llseek.c \
+	localtime.c lookup_dcookie.c looping_threads.c lseek.c lstat.c \
+	lstat64.c madvise.c maybe_switch_current_tcp.c \
+	maybe_switch_current_tcp--quiet-thread-execve.c mbind.c \
+	mbind-Xabbrev.c mbind-Xraw.c mbind-Xverbose.c membarrier.c \
+	memfd_create.c memfd_create-Xabbrev.c memfd_create-Xraw.c \
+	memfd_create-Xverbose.c migrate_pages.c \
+	migrate_pages--pidns-translation.c mincore.c mkdir.c mkdirat.c \
+	mknod.c mknodat.c mlock.c mlock2.c mlockall.c mmap.c \
+	mmap-Xabbrev.c mmap-Xraw.c mmap-Xverbose.c mmap64.c \
+	mmap64-Xabbrev.c mmap64-Xraw.c mmap64-Xverbose.c mmsg.c \
+	mmsg-silent.c mmsg_name.c mmsg_name-v.c modify_ldt.c mount.c \
+	mount-Xabbrev.c mount-Xraw.c mount-Xverbose.c move_mount.c \
+	move_mount-P.c move_pages.c move_pages--pidns-translation.c \
+	move_pages-Xabbrev.c move_pages-Xraw.c move_pages-Xverbose.c \
+	mq.c mq_sendrecv.c mq_sendrecv-read.c mq_sendrecv-write.c \
+	msg_control.c msg_control-v.c msg_name.c munlockall.c \
+	nanosleep.c net--decode-fds-dev-netlink.c \
+	net--decode-fds-none-netlink.c net--decode-fds-path-netlink.c \
+	net--decode-fds-socket-netlink.c net-accept-connect.c \
+	net-icmp_filter.c net-packet_mreq.c net-packet_mreq-Xabbrev.c \
+	net-packet_mreq-Xraw.c net-packet_mreq-Xverbose.c \
+	net-sockaddr.c net-sockaddr--pidns-translation.c \
+	net-tpacket_req.c net-tpacket_stats.c \
+	net-tpacket_stats-success.c net-y-unix.c net-yy-inet.c \
+	net-yy-inet6.c net-yy-netlink.c net-yy-unix.c netlink_audit.c \
+	netlink_audit--pidns-translation.c netlink_crypto.c \
+	netlink_generic.c netlink_inet_diag.c netlink_kobject_uevent.c \
 	netlink_netfilter.c netlink_netlink_diag.c netlink_protocol.c \
 	netlink_route.c netlink_selinux.c netlink_sock_diag.c \
 	netlink_unix_diag.c netlink_xfrm.c newfstatat.c \
@@ -3944,56 +4954,71 @@ DIST_SOURCES = $(libtests_a_SOURCES) _ne
 	nlattr_fib_rule_hdr.c nlattr_ifaddrlblmsg.c nlattr_ifaddrmsg.c \
 	nlattr_ifinfomsg.c nlattr_ifla_af_spec.c nlattr_ifla_brport.c \
 	nlattr_ifla_linkinfo.c nlattr_ifla_port.c nlattr_ifla_xdp.c \
-	nlattr_inet_diag_msg.c nlattr_inet_diag_req_compat.c \
-	nlattr_inet_diag_req_v2.c nlattr_mdba_mdb_entry.c \
-	nlattr_mdba_router_port.c nlattr_ndmsg.c nlattr_ndtmsg.c \
-	nlattr_netconfmsg.c nlattr_netlink_diag_msg.c \
-	nlattr_nlmsgerr.c nlattr_packet_diag_msg.c nlattr_rtgenmsg.c \
-	nlattr_rtmsg.c nlattr_smc_diag_msg.c nlattr_tc_stats.c \
-	nlattr_tca_stab.c nlattr_tcamsg.c nlattr_tcmsg.c \
-	nlattr_unix_diag_msg.c nsyscalls.c nsyscalls-d.c old_mmap.c \
-	old_mmap-P.c old_mmap-Xabbrev.c old_mmap-Xraw.c \
-	old_mmap-Xverbose.c old_mmap-v-none.c oldfstat.c oldlstat.c \
-	oldselect.c oldselect-P.c oldselect-efault.c \
-	oldselect-efault-P.c oldstat.c open.c open_tree.c \
-	open_tree-P.c openat.c orphaned_process_group.c osf_utimes.c \
-	pause.c pc.c perf_event_open.c perf_event_open_nonverbose.c \
+	nlattr_ifla_xdp-y.c nlattr_inet_diag_msg.c \
+	nlattr_inet_diag_req_compat.c nlattr_inet_diag_req_v2.c \
+	nlattr_mdba_mdb_entry.c nlattr_mdba_router_port.c \
+	nlattr_ndmsg.c nlattr_ndtmsg.c nlattr_netconfmsg.c \
+	nlattr_netlink_diag_msg.c nlattr_nlmsgerr.c \
+	nlattr_packet_diag_msg.c nlattr_rtgenmsg.c nlattr_rtmsg.c \
+	nlattr_smc_diag_msg.c nlattr_tc_stats.c nlattr_tca_stab.c \
+	nlattr_tcamsg.c nlattr_tcmsg.c nlattr_unix_diag_msg.c \
+	nsyscalls.c nsyscalls-d.c old_mmap.c old_mmap-P.c \
+	old_mmap-Xabbrev.c old_mmap-Xraw.c old_mmap-Xverbose.c \
+	old_mmap-v-none.c oldfstat.c oldlstat.c oldselect.c \
+	oldselect-P.c oldselect-efault.c oldselect-efault-P.c \
+	oldstat.c open.c open_tree.c open_tree-P.c openat.c openat2.c \
+	openat2-Xabbrev.c openat2-Xraw.c openat2-Xverbose.c \
+	openat2-v.c openat2-v-y.c openat2-v-y-Xabbrev.c \
+	openat2-v-y-Xraw.c openat2-v-y-Xverbose.c openat2-y.c \
+	orphaned_process_group.c osf_utimes.c pause.c pc.c \
+	perf_event_open.c perf_event_open_nonverbose.c \
 	perf_event_open_unabbrev.c personality.c personality-Xabbrev.c \
-	personality-Xraw.c personality-Xverbose.c pidfd_open.c \
-	pidfd_open-P.c pidfd_open-y.c pidfd_send_signal.c pipe.c \
-	pipe2.c pkey_alloc.c pkey_free.c pkey_mprotect.c poll.c \
-	poll-P.c ppoll.c ppoll-P.c ppoll-v.c prctl-arg2-intptr.c \
-	prctl-dumpable.c prctl-name.c prctl-no-args.c \
-	prctl-pdeathsig.c prctl-seccomp-filter-v.c \
+	personality-Xraw.c personality-Xverbose.c pidfd_getfd.c \
+	pidfd_getfd-y.c pidfd_getfd-yy.c pidfd_open.c \
+	pidfd_open--decode-fd-path.c pidfd_open--decode-fd-pidfd.c \
+	pidfd_open--decode-fd-socket.c pidfd_open--pidns-translation.c \
+	pidfd_open-P.c pidfd_open-y.c pidfd_open-yy.c \
+	pidfd_send_signal.c pidfd_send_signal--pidns-translation.c \
+	pidns-cache.c pipe.c pipe2.c pkey_alloc.c pkey_free.c \
+	pkey_mprotect.c poll.c poll-P.c ppoll.c ppoll-P.c ppoll-v.c \
+	prctl-arg2-intptr.c prctl-dumpable.c prctl-name.c \
+	prctl-no-args.c prctl-pdeathsig.c prctl-seccomp-filter-v.c \
 	prctl-seccomp-strict.c prctl-securebits.c prctl-spec-inject.c \
 	prctl-tid_address.c prctl-tsc.c pread64-pwrite64.c preadv.c \
 	preadv-pwritev.c preadv2-pwritev2.c print_maxfd.c \
-	printpath-umovestr.c printpath-umovestr-peekdata.c \
-	printpath-umovestr-undumpable.c printsignal-Xabbrev.c \
-	printsignal-Xraw.c printsignal-Xverbose.c printstr.c \
-	printstrn-umoven.c printstrn-umoven-peekdata.c \
-	printstrn-umoven-undumpable.c prlimit64.c process_vm_readv.c \
-	process_vm_writev.c pselect6.c ptrace.c ptrace_syscall_info.c \
-	pwritev.c qual_fault.c qual_inject-error-signal.c \
-	qual_inject-retval.c qual_inject-signal.c qual_signal.c \
-	quotactl.c quotactl-Xabbrev.c quotactl-Xraw.c \
-	quotactl-Xverbose.c quotactl-success.c quotactl-success-v.c \
-	quotactl-v.c quotactl-xfs.c quotactl-xfs-success.c \
-	quotactl-xfs-success-v.c quotactl-xfs-v.c read-write.c \
-	readahead.c readdir.c readlink.c readlinkat.c readv.c reboot.c \
-	recv-MSG_TRUNC.c recvfrom.c recvfrom-MSG_TRUNC.c \
-	recvmmsg-timeout.c recvmsg.c redirect-fds.c remap_file_pages.c \
-	remap_file_pages-Xabbrev.c remap_file_pages-Xraw.c \
-	remap_file_pages-Xverbose.c rename.c renameat.c renameat2.c \
-	request_key.c restart_syscall.c riscv_flush_icache.c rmdir.c \
-	rt_sigaction.c rt_sigpending.c rt_sigprocmask.c \
-	rt_sigqueueinfo.c rt_sigreturn.c rt_sigsuspend.c \
-	rt_sigtimedwait.c rt_tgsigqueueinfo.c run_expect_termsig.c \
+	print_ppid_tracerpid.c printpath-umovestr.c \
+	printpath-umovestr-peekdata.c printpath-umovestr-undumpable.c \
+	printsignal-Xabbrev.c printsignal-Xraw.c \
+	printsignal-Xverbose.c printstr.c printstrn-umoven.c \
+	printstrn-umoven-peekdata.c printstrn-umoven-undumpable.c \
+	prlimit64.c prlimit64--pidns-translation.c process_vm_readv.c \
+	process_vm_readv--pidns-translation.c process_vm_writev.c \
+	process_vm_writev--pidns-translation.c pselect6.c ptrace.c \
+	ptrace_syscall_info.c pwritev.c qual_fault.c \
+	qual_inject-error-signal.c qual_inject-retval.c \
+	qual_inject-signal.c qual_signal.c quotactl.c \
+	quotactl-Xabbrev.c quotactl-Xraw.c quotactl-Xverbose.c \
+	quotactl-success.c quotactl-success-v.c quotactl-v.c \
+	quotactl-xfs.c quotactl-xfs-success.c quotactl-xfs-success-v.c \
+	quotactl-xfs-v.c read-write.c readahead.c readdir.c readlink.c \
+	readlinkat.c readv.c reboot.c recv-MSG_TRUNC.c recvfrom.c \
+	recvfrom-MSG_TRUNC.c recvmmsg-timeout.c recvmsg.c \
+	redirect-fds.c remap_file_pages.c remap_file_pages-Xabbrev.c \
+	remap_file_pages-Xraw.c remap_file_pages-Xverbose.c rename.c \
+	renameat.c renameat2.c request_key.c restart_syscall.c \
+	riscv_flush_icache.c rmdir.c rt_sigaction.c rt_sigpending.c \
+	rt_sigprocmask.c rt_sigqueueinfo.c \
+	rt_sigqueueinfo--pidns-translation.c rt_sigreturn.c \
+	rt_sigsuspend.c rt_sigtimedwait.c rt_tgsigqueueinfo.c \
+	rt_tgsigqueueinfo--pidns-translation.c run_expect_termsig.c \
 	s390_guarded_storage.c s390_guarded_storage-v.c \
 	s390_pci_mmio_read_write.c s390_runtime_instr.c s390_sthyi.c \
 	s390_sthyi-v.c sched_get_priority_mxx.c \
-	sched_rr_get_interval.c sched_xetaffinity.c sched_xetattr.c \
-	sched_xetparam.c sched_xetscheduler.c sched_yield.c \
+	sched_rr_get_interval.c sched_xetaffinity.c \
+	sched_xetaffinity--pidns-translation.c sched_xetattr.c \
+	sched_xetattr--pidns-translation.c sched_xetparam.c \
+	sched_xetparam--pidns-translation.c sched_xetscheduler.c \
+	sched_xetscheduler--pidns-translation.c sched_yield.c \
 	scm_rights.c seccomp-filter.c seccomp-filter-v.c \
 	seccomp-strict.c seccomp_get_action_avail.c select.c \
 	select-P.c semop.c semop-indirect.c semtimedop.c sendfile.c \
@@ -4002,38 +5027,50 @@ DIST_SOURCES = $(libtests_a_SOURCES) _ne
 	set_ptracer_any.c set_sigblock.c set_sigign.c setdomainname.c \
 	setfsgid.c setfsgid32.c setfsuid.c setfsuid32.c setgid.c \
 	setgid32.c setgroups.c setgroups32.c sethostname.c setns.c \
-	setregid.c setregid32.c setresgid.c setresgid32.c setresuid.c \
-	setresuid32.c setreuid.c setreuid32.c setrlimit.c \
-	setrlimit-Xabbrev.c setrlimit-Xraw.c setrlimit-Xverbose.c \
-	setuid.c setuid32.c shmxt.c shutdown.c sigaction.c \
-	sigaltstack.c siginfo.c signal.c signal_receive.c signalfd4.c \
-	sigpending.c sigprocmask.c sigreturn.c sigsuspend.c sleep.c \
-	so_error.c so_linger.c so_peercred.c so_peercred-Xabbrev.c \
-	so_peercred-Xraw.c so_peercred-Xverbose.c sock_filter-v.c \
-	sock_filter-v-Xabbrev.c sock_filter-v-Xraw.c \
-	sock_filter-v-Xverbose.c sockaddr_xlat-Xabbrev.c \
-	sockaddr_xlat-Xraw.c sockaddr_xlat-Xverbose.c socketcall.c \
-	sockopt-sol_netlink.c sockopt-timestamp.c splice.c \
-	$(stack_fcall_SOURCES) $(stack_fcall_attach_SOURCES) \
-	$(stack_fcall_mangled_SOURCES) stat.c stat64.c statfs.c \
-	statfs64.c status-all.c status-failed.c status-none.c \
-	status-none-f.c status-none-threads.c status-successful.c \
-	status-unfinished.c status-unfinished-threads.c statx.c swap.c \
-	sxetmask.c symlink.c symlinkat.c sync.c sync_file_range.c \
-	sync_file_range2.c sysinfo.c syslog.c syslog-success.c tee.c \
-	threads-execve.c time.c timer_create.c timer_xettime.c \
-	timerfd_xettime.c times.c times-fail.c tracer_ppid_pgid_sid.c \
-	truncate.c truncate64.c ugetrlimit.c uio.c umask.c umount.c \
-	umount2.c umoven-illptr.c umovestr.c umovestr-illptr.c \
-	umovestr2.c umovestr3.c umovestr_cached.c uname.c \
-	unblock_reset_raise.c unix-pair-send-recv.c \
+	setpgrp-exec.c setregid.c setregid32.c setresgid.c \
+	setresgid32.c setresuid.c setresuid32.c setreuid.c \
+	setreuid32.c setrlimit.c setrlimit-Xabbrev.c setrlimit-Xraw.c \
+	setrlimit-Xverbose.c setuid.c setuid32.c shmxt.c shutdown.c \
+	sigaction.c sigaltstack.c siginfo.c signal.c signal_receive.c \
+	signal_receive--pidns-translation.c signalfd4.c sigpending.c \
+	sigprocmask.c sigreturn.c sigsuspend.c sleep.c so_error.c \
+	so_linger.c so_peercred.c so_peercred--pidns-translation.c \
+	so_peercred-Xabbrev.c so_peercred-Xraw.c \
+	so_peercred-Xverbose.c sock_filter-v.c sock_filter-v-Xabbrev.c \
+	sock_filter-v-Xraw.c sock_filter-v-Xverbose.c \
+	sockaddr_xlat-Xabbrev.c sockaddr_xlat-Xraw.c \
+	sockaddr_xlat-Xverbose.c socketcall.c sockopt-sol_netlink.c \
+	sockopt-timestamp.c splice.c $(stack_fcall_SOURCES) \
+	$(stack_fcall_attach_SOURCES) $(stack_fcall_mangled_SOURCES) \
+	stat.c stat64.c statfs.c statfs64.c status-all.c \
+	status-failed.c status-failed-long.c status-failed-status.c \
+	status-none.c status-none-f.c status-none-threads.c \
+	status-successful.c status-successful-long.c \
+	status-successful-status.c status-unfinished.c \
+	status-unfinished-threads.c statx.c strace--strings-in-hex.c \
+	strace--strings-in-hex-all.c \
+	strace--strings-in-hex-non-ascii.c strace-n.c strace-x.c \
+	strace-xx.c swap.c sxetmask.c symlink.c symlinkat.c sync.c \
+	sync_file_range.c sync_file_range2.c sysinfo.c syslog.c \
+	syslog-success.c tee.c tgkill.c tgkill--pidns-translation.c \
+	threads-execve.c threads-execve--quiet-thread-execve.c \
+	threads-execve-q.c threads-execve-qq.c threads-execve-qqq.c \
+	time.c timer_create.c timer_xettime.c timerfd_xettime.c \
+	times.c times-fail.c tkill.c tkill--pidns-translation.c \
+	tracer_ppid_pgid_sid.c $(trie_test_SOURCES) truncate.c \
+	truncate64.c ugetrlimit.c uio.c umask.c umount.c umount2.c \
+	umoven-illptr.c umovestr.c umovestr-illptr.c umovestr2.c \
+	umovestr3.c umovestr_cached.c umovestr_cached_adjacent.c \
+	uname.c unblock_reset_raise.c unix-pair-send-recv.c \
 	unix-pair-sendto-recvfrom.c unlink.c unlinkat.c unshare.c \
 	userfaultfd.c ustat.c utime.c utimensat.c utimensat-Xabbrev.c \
 	utimensat-Xraw.c utimensat-Xverbose.c utimes.c vfork-f.c \
 	vhangup.c vmsplice.c wait4.c wait4-v.c waitid.c waitid-v.c \
 	waitpid.c xattr.c xattr-strings.c xet_robust_list.c \
-	xet_thread_area_x86.c xetitimer.c xetpgid.c xetpriority.c \
-	xettimeofday.c zeroargc.c
+	xet_robust_list--pidns-translation.c xet_thread_area_x86.c \
+	xetitimer.c xetpgid.c xetpgid--pidns-translation.c \
+	xetpriority.c xetpriority--pidns-translation.c xettimeofday.c \
+	zeroargc.c
 am__can_run_installinfo = \
   case $$AM_UPDATE_INFO_DIR in \
     n|no|NO) false;; \
@@ -4244,6 +5281,7 @@ am__set_TESTS_bases = \
   bases='$(TEST_LOGS)'; \
   bases=`for i in $$bases; do echo $$i; done | sed 's/\.log$$//'`; \
   bases=`echo $$bases`
+AM_TESTSUITE_SUMMARY_HEADER = ' for $(PACKAGE_STRING)'
 RECHECK_LOGS = $(TEST_LOGS)
 AM_RECURSIVE_TARGETS = check recheck
 @ENABLE_STACKTRACE_TRUE@am__EXEEXT_2 = strace-k.test strace-k-p.test \
@@ -4273,6 +5311,7 @@ DISTFILES = $(DIST_COMMON) $(DIST_SOURCE
 ACLOCAL = @ACLOCAL@
 AMTAR = @AMTAR@
 AM_DEFAULT_VERBOSITY = @AM_DEFAULT_VERBOSITY@
+AR = @AR@
 AUTOCONF = @AUTOCONF@
 AUTOHEADER = @AUTOHEADER@
 AUTOMAKE = @AUTOMAKE@
@@ -4344,7 +5383,6 @@ PACKAGE_TARNAME = @PACKAGE_TARNAME@
 PACKAGE_URL = @PACKAGE_URL@
 PACKAGE_VERSION = @PACKAGE_VERSION@
 PATH_SEPARATOR = @PATH_SEPARATOR@
-PERL = @PERL@
 RANLIB = @RANLIB@
 READELF = @READELF@
 RPM_CHANGELOGTIME = @RPM_CHANGELOGTIME@
@@ -4363,6 +5401,7 @@ abs_builddir = @abs_builddir@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CC_FOR_BUILD = @ac_ct_CC_FOR_BUILD@
 am__include = @am__include@
@@ -4453,6 +5492,7 @@ AM_CPPFLAGS = $(ARCH_MFLAGS) \
 AM_LDFLAGS = $(ARCH_MFLAGS)
 libtests_a_SOURCES = \
 	create_nl_socket.c \
+	create_tmpfile.c \
 	errno2name.c \
 	error_msg.c \
 	fill_memory.c \
@@ -4466,6 +5506,8 @@ libtests_a_SOURCES = \
 	libsocketcall.c \
 	lock_file.c \
 	overflowuid.c \
+	pidns.c \
+	pidns.h \
 	pipe_maxfd.c \
 	print_quoted_string.c \
 	print_time.c \
@@ -4486,6 +5528,7 @@ libtests_a_SOURCES = \
 	test_ucopy.h \
 	tests.h \
 	tprintf.c \
+	xmalloc_for_tests.c \
 	# end of libtests_a_SOURCES
 
 libtests_a_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
@@ -4521,13 +5564,29 @@ PURE_EXECUTABLES = \
   clone3-Xabbrev \
   clone3-Xraw \
   clone3-Xverbose \
+  close_range \
+  close_range-P \
+  close_range-y \
+  close_range-yy \
   copy_file_range \
   creat \
   delete_module \
+  dev--decode-fds-dev \
+  dev--decode-fds-path \
+  dev--decode-fds-socket \
   dev-yy \
   dup \
+  dup-P \
+  dup-y \
+  dup-yy \
   dup2 \
+  dup2-P \
+  dup2-y \
+  dup2-yy \
   dup3 \
+  dup3-P \
+  dup3-y \
+  dup3-yy \
   epoll_create \
   epoll_create1 \
   epoll_ctl \
@@ -4538,6 +5597,13 @@ PURE_EXECUTABLES = \
   execve \
   execveat \
   faccessat \
+  faccessat-P \
+  faccessat-y \
+  faccessat-yy \
+  faccessat2 \
+  faccessat2-P \
+  faccessat2-y \
+  faccessat2-yy \
   fadvise64 \
   fadvise64_64 \
   fallocate \
@@ -4586,7 +5652,9 @@ PURE_EXECUTABLES = \
   getcpu \
   getcwd \
   getdents \
+  getdents-v \
   getdents64 \
+  getdents64-v \
   getegid \
   getegid32 \
   geteuid \
@@ -4610,7 +5678,9 @@ PURE_EXECUTABLES = \
   getsockname \
   getuid \
   getuid32 \
-  getxxid \
+  getxgid \
+  getxpid \
+  getxuid \
   group_req \
   inet-cmsg \
   init_module \
@@ -4633,6 +5703,14 @@ PURE_EXECUTABLES = \
   ioctl_evdev-v-Xabbrev \
   ioctl_evdev-v-Xraw \
   ioctl_evdev-v-Xverbose \
+  ioctl_hdio \
+  ioctl_hdio-Xabbrev \
+  ioctl_hdio-Xraw \
+  ioctl_hdio-Xverbose \
+  ioctl_hdio-v \
+  ioctl_hdio-v-Xabbrev \
+  ioctl_hdio-v-Xraw \
+  ioctl_hdio-v-Xverbose \
   ioctl_inotify \
   ioctl_kvm_run \
   ioctl_kvm_run-v \
@@ -4648,8 +5726,16 @@ PURE_EXECUTABLES = \
   ioctl_sg_io_v3 \
   ioctl_sg_io_v4 \
   ioctl_sock_gifconf \
+  ioctl_tee \
   ioctl_uffdio \
   ioctl_v4l2 \
+  ioctl_v4l2-Xabbrev \
+  ioctl_v4l2-Xraw \
+  ioctl_v4l2-Xverbose \
+  ioctl_v4l2-v \
+  ioctl_v4l2-v-Xabbrev \
+  ioctl_v4l2-v-Xraw \
+  ioctl_v4l2-v-Xverbose \
   ioctl_watchdog \
   ioperm \
   iopl \
@@ -4700,6 +5786,7 @@ PURE_EXECUTABLES = \
   lstat64 \
   madvise \
   maybe_switch_current_tcp \
+  maybe_switch_current_tcp--quiet-thread-execve \
   mbind \
   mbind-Xabbrev \
   mbind-Xraw \
@@ -4747,6 +5834,10 @@ PURE_EXECUTABLES = \
   msg_name \
   munlockall \
   nanosleep \
+  net--decode-fds-dev-netlink \
+  net--decode-fds-none-netlink \
+  net--decode-fds-path-netlink \
+  net--decode-fds-socket-netlink \
   net-icmp_filter \
   net-packet_mreq \
   net-packet_mreq-Xabbrev \
@@ -4829,6 +5920,16 @@ PURE_EXECUTABLES = \
   open_tree \
   open_tree-P \
   openat \
+  openat2 \
+  openat2-Xabbrev \
+  openat2-Xraw \
+  openat2-Xverbose \
+  openat2-v \
+  openat2-v-y \
+  openat2-v-y-Xabbrev \
+  openat2-v-y-Xraw \
+  openat2-v-y-Xverbose \
+  openat2-y \
   osf_utimes \
   pause \
   perf_event_open \
@@ -4836,9 +5937,16 @@ PURE_EXECUTABLES = \
   personality-Xabbrev \
   personality-Xraw \
   personality-Xverbose \
+  pidfd_getfd \
+  pidfd_getfd-y \
+  pidfd_getfd-yy \
   pidfd_open \
+  pidfd_open--decode-fd-path \
+  pidfd_open--decode-fd-pidfd \
+  pidfd_open--decode-fd-socket \
   pidfd_open-P \
   pidfd_open-y \
+  pidfd_open-yy \
   pidfd_send_signal \
   pipe \
   pipe2 \
@@ -4846,9 +5954,7 @@ PURE_EXECUTABLES = \
   pkey_free \
   pkey_mprotect \
   poll \
-  poll-P \
   ppoll \
-  ppoll-P \
   prctl-arg2-intptr \
   prctl-dumpable \
   prctl-name \
@@ -4997,11 +6103,21 @@ PURE_EXECUTABLES = \
   statfs64 \
   status-all \
   status-failed \
+  status-failed-long \
+  status-failed-status \
   status-none \
   status-none-f \
   status-successful \
+  status-successful-long \
+  status-successful-status \
   status-unfinished \
   statx \
+  strace--strings-in-hex \
+  strace--strings-in-hex-all \
+  strace--strings-in-hex-non-ascii \
+  strace-n \
+  strace-x \
+  strace-xx \
   swap \
   sxetmask \
   symlink \
@@ -5012,12 +6128,14 @@ PURE_EXECUTABLES = \
   sysinfo \
   syslog \
   tee \
+  tgkill \
   time \
   timer_create \
   timer_xettime \
   timerfd_xettime \
   times \
   times-fail \
+  tkill \
   truncate \
   truncate64 \
   ugetrlimit \
@@ -5031,6 +6149,7 @@ PURE_EXECUTABLES = \
   umovestr2 \
   umovestr3 \
   umovestr_cached \
+  umovestr_cached_adjacent \
   uname \
   unlink \
   unlinkat \
@@ -5069,6 +6188,7 @@ localtime_LDADD = $(clock_LIBS) $(LDADD)
 looping_threads_LDADD = -lpthread $(LDADD)
 lstat64_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 maybe_switch_current_tcp_LDADD = -lpthread $(LDADD)
+maybe_switch_current_tcp__quiet_thread_execve_LDADD = -lpthread $(LDADD)
 mmap64_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 mmap64_Xabbrev_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 mmap64_Xraw_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
@@ -5085,6 +6205,10 @@ statfs_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE
 status_none_threads_LDADD = -lpthread $(LDADD)
 status_unfinished_threads_LDADD = -lpthread $(LDADD)
 threads_execve_LDADD = -lpthread $(clock_LIBS) $(LDADD)
+threads_execve__quiet_thread_execve_LDADD = -lpthread $(clock_LIBS) $(LDADD)
+threads_execve_q_LDADD = -lpthread $(clock_LIBS) $(LDADD)
+threads_execve_qq_LDADD = -lpthread $(clock_LIBS) $(LDADD)
+threads_execve_qqq_LDADD = -lpthread $(clock_LIBS) $(LDADD)
 times_LDADD = $(clock_LIBS) $(LDADD)
 truncate64_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 uio_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
@@ -5098,6 +6222,10 @@ stack_fcall_mangled_SOURCES = stack-fcal
 	stack-fcall-mangled-0.c stack-fcall-mangled-1.c \
 	stack-fcall-mangled-2.c stack-fcall-mangled-3.c
 
+trie_test_SOURCES = trie_test.c trie_for_tests.c
+trie_test_CPPFLAGS = $(AM_CPPFLAGS) $(CODE_COVERAGE_CPPFLAGS)
+trie_test_CFLAGS = $(AM_CFLAGS) $(CODE_COVERAGE_CFLAGS)
+trie_test_LDADD = $(LDADD) $(CODE_COVERAGE_LIBS)
 
 # Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in; do not edit.
 GEN_TESTS = _newselect.gen.test _newselect-P.gen.test accept.gen.test \
@@ -5114,69 +6242,111 @@ GEN_TESTS = _newselect.gen.test _newsele
 	clone3.gen.test clone3-Xabbrev.gen.test clone3-Xraw.gen.test \
 	clone3-Xverbose.gen.test clone3-success-Xabbrev.gen.test \
 	clone3-success-Xraw.gen.test clone3-success-Xverbose.gen.test \
-	copy_file_range.gen.test creat.gen.test delete_module.gen.test \
-	dev-yy.gen.test dup.gen.test dup2.gen.test dup3.gen.test \
+	clone_parent.gen.test clone_parent--quiet-exit.gen.test \
+	clone_parent-q.gen.test clone_parent-qq.gen.test \
+	clone_ptrace--quiet-attach.gen.test \
+	clone_ptrace--quiet-exit.gen.test clone_ptrace-q.gen.test \
+	clone_ptrace-qq.gen.test close_range.gen.test \
+	close_range-P.gen.test close_range-y.gen.test \
+	close_range-yy.gen.test copy_file_range.gen.test \
+	creat.gen.test delete_module.gen.test \
+	dev--decode-fds-dev.gen.test dev--decode-fds-path.gen.test \
+	dev--decode-fds-socket.gen.test dev-yy.gen.test dup.gen.test \
+	dup-P.gen.test dup-y.gen.test dup-yy.gen.test dup2.gen.test \
+	dup2-P.gen.test dup2-y.gen.test dup2-yy.gen.test dup3.gen.test \
+	dup3-P.gen.test dup3-y.gen.test dup3-yy.gen.test \
 	epoll_create.gen.test epoll_create1.gen.test \
 	epoll_ctl.gen.test epoll_pwait.gen.test epoll_wait.gen.test \
 	erestartsys.gen.test execveat.gen.test execveat-v.gen.test \
-	faccessat.gen.test fadvise64_64.gen.test fallocate.gen.test \
+	faccessat-P.gen.test faccessat-y.gen.test \
+	faccessat-yy.gen.test faccessat2-P.gen.test \
+	faccessat2-y.gen.test faccessat2-yy.gen.test \
+	fadvise64_64.gen.test fallocate.gen.test \
 	fanotify_init.gen.test fanotify_mark.gen.test \
 	fanotify_mark-Xabbrev.gen.test fanotify_mark-Xraw.gen.test \
 	fanotify_mark-Xverbose.gen.test fchdir.gen.test \
 	fchmod.gen.test fchmodat.gen.test fchown.gen.test \
 	fchown32.gen.test fchownat.gen.test fcntl.gen.test \
-	fcntl64.gen.test fdatasync.gen.test file_handle.gen.test \
-	file_ioctl.gen.test filter_seccomp.gen.test \
-	filter_seccomp-flag.gen.test finit_module.gen.test \
-	flock.gen.test fork-f.gen.test fsconfig.gen.test \
-	fsconfig-P.gen.test fsmount.gen.test fsopen.gen.test \
-	fspick.gen.test fspick-P.gen.test fstat.gen.test \
-	fstat-Xabbrev.gen.test fstat-Xraw.gen.test \
+	fcntl--pidns-translation.gen.test fcntl64.gen.test \
+	fcntl64--pidns-translation.gen.test fdatasync.gen.test \
+	file_handle.gen.test file_ioctl.gen.test \
+	filter_seccomp.gen.test filter_seccomp-flag.gen.test \
+	finit_module.gen.test flock.gen.test fork-f.gen.test \
+	fsconfig.gen.test fsconfig-P.gen.test fsmount.gen.test \
+	fsopen.gen.test fspick.gen.test fspick-P.gen.test \
+	fstat.gen.test fstat-Xabbrev.gen.test fstat-Xraw.gen.test \
 	fstat-Xverbose.gen.test fstat64.gen.test \
 	fstat64-Xabbrev.gen.test fstat64-Xraw.gen.test \
 	fstat64-Xverbose.gen.test fstatat64.gen.test fstatfs.gen.test \
 	fstatfs64.gen.test fsync.gen.test fsync-y.gen.test \
 	ftruncate.gen.test ftruncate64.gen.test futimesat.gen.test \
 	get_mempolicy.gen.test getcpu.gen.test getcwd.gen.test \
-	getdents.gen.test getdents64.gen.test getegid.gen.test \
-	getegid-creds.gen.test getegid32.gen.test \
-	getegid32-creds.gen.test geteuid.gen.test \
+	getdents.gen.test getdents-v.gen.test getdents64.gen.test \
+	getdents64-v.gen.test getegid.gen.test getegid-creds.gen.test \
+	getegid32.gen.test getegid32-creds.gen.test geteuid.gen.test \
 	geteuid-creds.gen.test geteuid32.gen.test \
 	geteuid32-creds.gen.test getgid.gen.test getgid-creds.gen.test \
 	getgid32.gen.test getgid32-creds.gen.test getgroups.gen.test \
 	getgroups32.gen.test getpeername.gen.test getpgrp.gen.test \
-	getpid.gen.test getppid.gen.test getrandom.gen.test \
-	getresgid.gen.test getresgid32.gen.test getresuid.gen.test \
-	getresuid32.gen.test getrlimit.gen.test getrusage.gen.test \
-	getsid.gen.test getsockname.gen.test gettid.gen.test \
-	getuid-creds.gen.test getuid32.gen.test \
-	getuid32-creds.gen.test getxxid.gen.test group_req.gen.test \
-	inet-cmsg.gen.test init_module.gen.test inotify.gen.test \
-	inotify_init.gen.test inotify_init1.gen.test \
-	inotify_init1-y.gen.test io_uring_enter.gen.test \
-	io_uring_register.gen.test io_uring_setup.gen.test \
-	ioctl_block.gen.test ioctl_dm.gen.test ioctl_dm-v.gen.test \
-	ioctl_evdev.gen.test ioctl_evdev-Xabbrev.gen.test \
-	ioctl_evdev-Xraw.gen.test ioctl_evdev-Xverbose.gen.test \
-	ioctl_evdev-v.gen.test ioctl_evdev-v-Xabbrev.gen.test \
-	ioctl_evdev-v-Xraw.gen.test ioctl_evdev-v-Xverbose.gen.test \
+	getpgrp--pidns-translation.gen.test getpid.gen.test \
+	getpid--pidns-translation.gen.test getppid.gen.test \
+	getrandom.gen.test getresgid.gen.test getresgid32.gen.test \
+	getresuid.gen.test getresuid32.gen.test getrlimit.gen.test \
+	getrusage.gen.test getsid.gen.test \
+	getsid--pidns-translation.gen.test getsockname.gen.test \
+	gettid.gen.test getuid-creds.gen.test getuid32.gen.test \
+	getuid32-creds.gen.test getxgid.gen.test getxpid.gen.test \
+	getxuid.gen.test group_req.gen.test inet-cmsg.gen.test \
+	init_module.gen.test inotify.gen.test inotify_init.gen.test \
+	inotify_init1.gen.test inotify_init1-y.gen.test \
+	io_uring_enter.gen.test io_uring_register.gen.test \
+	io_uring_setup.gen.test ioctl_block.gen.test ioctl_dm.gen.test \
+	ioctl_dm-v.gen.test ioctl_evdev.gen.test \
+	ioctl_evdev-Xabbrev.gen.test ioctl_evdev-Xraw.gen.test \
+	ioctl_evdev-Xverbose.gen.test ioctl_evdev-v.gen.test \
+	ioctl_evdev-v-Xabbrev.gen.test ioctl_evdev-v-Xraw.gen.test \
+	ioctl_evdev-v-Xverbose.gen.test \
 	ioctl_evdev-success-Xabbrev.gen.test \
 	ioctl_evdev-success-Xraw.gen.test \
 	ioctl_evdev-success-Xverbose.gen.test \
 	ioctl_evdev-success-v.gen.test \
 	ioctl_evdev-success-v-Xabbrev.gen.test \
 	ioctl_evdev-success-v-Xraw.gen.test \
-	ioctl_evdev-success-v-Xverbose.gen.test ioctl_inotify.gen.test \
+	ioctl_evdev-success-v-Xverbose.gen.test ioctl_hdio.gen.test \
+	ioctl_hdio-Xabbrev.gen.test ioctl_hdio-Xraw.gen.test \
+	ioctl_hdio-Xverbose.gen.test ioctl_hdio-v.gen.test \
+	ioctl_hdio-v-Xabbrev.gen.test ioctl_hdio-v-Xraw.gen.test \
+	ioctl_hdio-v-Xverbose.gen.test ioctl_hdio-success.gen.test \
+	ioctl_hdio-success-Xabbrev.gen.test \
+	ioctl_hdio-success-Xraw.gen.test \
+	ioctl_hdio-success-Xverbose.gen.test \
+	ioctl_hdio-success-v.gen.test \
+	ioctl_hdio-success-v-Xabbrev.gen.test \
+	ioctl_hdio-success-v-Xraw.gen.test \
+	ioctl_hdio-success-v-Xverbose.gen.test ioctl_inotify.gen.test \
 	ioctl_kvm_run.gen.test ioctl_kvm_run-v.gen.test \
 	ioctl_kvm_run_auxstr_vcpu.gen.test ioctl_loop.gen.test \
 	ioctl_loop-nv.gen.test ioctl_loop-v.gen.test \
 	ioctl_mtd.gen.test ioctl_nbd.gen.test ioctl_nsfs.gen.test \
-	ioctl_perf.gen.test ioctl_ptp.gen.test ioctl_random.gen.test \
-	ioctl_rtc.gen.test ioctl_rtc-v.gen.test ioctl_scsi.gen.test \
+	ioctl_perf.gen.test ioctl_perf-success.gen.test \
+	ioctl_ptp.gen.test ioctl_random.gen.test ioctl_rtc.gen.test \
+	ioctl_rtc-v.gen.test ioctl_scsi.gen.test \
 	ioctl_sg_io_v3.gen.test ioctl_sg_io_v4.gen.test \
-	ioctl_sock_gifconf.gen.test ioctl_uffdio.gen.test \
-	ioctl_v4l2.gen.test ioctl_watchdog.gen.test ioperm.gen.test \
-	iopl.gen.test ioprio.gen.test ioprio-Xabbrev.gen.test \
+	ioctl_sock_gifconf.gen.test ioctl_tee.gen.test \
+	ioctl_uffdio.gen.test ioctl_v4l2.gen.test \
+	ioctl_v4l2-Xabbrev.gen.test ioctl_v4l2-Xraw.gen.test \
+	ioctl_v4l2-Xverbose.gen.test ioctl_v4l2-v.gen.test \
+	ioctl_v4l2-v-Xabbrev.gen.test ioctl_v4l2-v-Xraw.gen.test \
+	ioctl_v4l2-v-Xverbose.gen.test ioctl_v4l2-success.gen.test \
+	ioctl_v4l2-success-Xabbrev.gen.test \
+	ioctl_v4l2-success-Xraw.gen.test \
+	ioctl_v4l2-success-Xverbose.gen.test \
+	ioctl_v4l2-success-v.gen.test \
+	ioctl_v4l2-success-v-Xabbrev.gen.test \
+	ioctl_v4l2-success-v-Xraw.gen.test \
+	ioctl_v4l2-success-v-Xverbose.gen.test ioctl_watchdog.gen.test \
+	ioperm.gen.test iopl.gen.test ioprio.gen.test \
+	ioprio--pidns-translation.gen.test ioprio-Xabbrev.gen.test \
 	ioprio-Xraw.gen.test ioprio-Xverbose.gen.test ip_mreq.gen.test \
 	ipc.gen.test ipc_msg.gen.test ipc_msg-Xabbrev.gen.test \
 	ipc_msg-Xraw.gen.test ipc_msg-Xverbose.gen.test \
@@ -5186,23 +6356,27 @@ GEN_TESTS = _newselect.gen.test _newsele
 	ipc_sem-Xverbose.gen.test ipc_shm.gen.test \
 	ipc_shm-Xabbrev.gen.test ipc_shm-Xraw.gen.test \
 	ipc_shm-Xverbose.gen.test kcmp.gen.test kcmp-y.gen.test \
-	kern_features.gen.test kernel_version.gen.test \
-	kernel_version-Xabbrev.gen.test kernel_version-Xraw.gen.test \
-	kernel_version-Xverbose.gen.test kexec_file_load.gen.test \
-	kexec_load.gen.test keyctl.gen.test keyctl-Xabbrev.gen.test \
-	keyctl-Xraw.gen.test keyctl-Xverbose.gen.test kill.gen.test \
-	ksysent.gen.test lchown.gen.test lchown32.gen.test \
-	link.gen.test linkat.gen.test lookup_dcookie.gen.test \
-	lstat.gen.test lstat64.gen.test madvise.gen.test \
-	maybe_switch_current_tcp.gen.test mbind.gen.test \
-	mbind-Xabbrev.gen.test mbind-Xraw.gen.test \
+	kcmp-y--pidns-translation.gen.test kern_features.gen.test \
+	kernel_version.gen.test kernel_version-Xabbrev.gen.test \
+	kernel_version-Xraw.gen.test kernel_version-Xverbose.gen.test \
+	kexec_file_load.gen.test kexec_load.gen.test keyctl.gen.test \
+	keyctl-Xabbrev.gen.test keyctl-Xraw.gen.test \
+	keyctl-Xverbose.gen.test kill.gen.test \
+	kill--pidns-translation.gen.test ksysent.gen.test \
+	lchown.gen.test lchown32.gen.test link.gen.test \
+	linkat.gen.test lookup_dcookie.gen.test lstat.gen.test \
+	lstat64.gen.test madvise.gen.test \
+	maybe_switch_current_tcp.gen.test \
+	maybe_switch_current_tcp--quiet-thread-execve.gen.test \
+	mbind.gen.test mbind-Xabbrev.gen.test mbind-Xraw.gen.test \
 	mbind-Xverbose.gen.test membarrier.gen.test \
 	memfd_create.gen.test memfd_create-Xabbrev.gen.test \
 	memfd_create-Xraw.gen.test memfd_create-Xverbose.gen.test \
-	migrate_pages.gen.test mincore.gen.test mkdir.gen.test \
-	mkdirat.gen.test mknod.gen.test mknodat.gen.test \
-	mlock.gen.test mlock2.gen.test mlockall.gen.test \
-	mmap-Xabbrev.gen.test mmap-Xraw.gen.test \
+	migrate_pages.gen.test \
+	migrate_pages--pidns-translation.gen.test mincore.gen.test \
+	mkdir.gen.test mkdirat.gen.test mknod.gen.test \
+	mknodat.gen.test mlock.gen.test mlock2.gen.test \
+	mlockall.gen.test mmap-Xabbrev.gen.test mmap-Xraw.gen.test \
 	mmap-Xverbose.gen.test mmap64.gen.test mmap64-Xabbrev.gen.test \
 	mmap64-Xraw.gen.test mmap64-Xverbose.gen.test mmsg.gen.test \
 	mmsg-silent.gen.test mmsg_name.gen.test mmsg_name-v.gen.test \
@@ -5210,13 +6384,19 @@ GEN_TESTS = _newselect.gen.test _newsele
 	mount-Xraw.gen.test mount-Xverbose.gen.test \
 	move_mount.gen.test move_mount-P.gen.test move_pages.gen.test \
 	move_pages-Xabbrev.gen.test move_pages-Xraw.gen.test \
-	move_pages-Xverbose.gen.test mq.gen.test mq_sendrecv.gen.test \
-	mq_sendrecv-read.gen.test mq_sendrecv-write.gen.test \
-	msg_control.gen.test msg_control-v.gen.test msg_name.gen.test \
-	munlockall.gen.test nanosleep.gen.test \
+	move_pages-Xverbose.gen.test \
+	move_pages--pidns-translation.gen.test mq.gen.test \
+	mq_sendrecv.gen.test mq_sendrecv-read.gen.test \
+	mq_sendrecv-write.gen.test msg_control.gen.test \
+	msg_control-v.gen.test msg_name.gen.test munlockall.gen.test \
+	nanosleep.gen.test net--decode-fds-dev-netlink.gen.test \
+	net--decode-fds-none-netlink.gen.test \
+	net--decode-fds-path-netlink.gen.test \
+	net--decode-fds-socket-netlink.gen.test \
 	net-icmp_filter.gen.test net-packet_mreq.gen.test \
 	net-packet_mreq-Xabbrev.gen.test net-packet_mreq-Xraw.gen.test \
 	net-packet_mreq-Xverbose.gen.test net-sockaddr.gen.test \
+	net-sockaddr--pidns-translation.gen.test \
 	net-tpacket_req.gen.test net-tpacket_stats.gen.test \
 	net-yy-inet6.gen.test netlink_audit.gen.test \
 	netlink_crypto.gen.test netlink_generic.gen.test \
@@ -5235,7 +6415,8 @@ GEN_TESTS = _newselect.gen.test _newsele
 	nlattr_ifaddrmsg.gen.test nlattr_ifinfomsg.gen.test \
 	nlattr_ifla_af_spec.gen.test nlattr_ifla_brport.gen.test \
 	nlattr_ifla_linkinfo.gen.test nlattr_ifla_port.gen.test \
-	nlattr_ifla_xdp.gen.test nlattr_inet_diag_msg.gen.test \
+	nlattr_ifla_xdp.gen.test nlattr_ifla_xdp-y.gen.test \
+	nlattr_inet_diag_msg.gen.test \
 	nlattr_inet_diag_req_compat.gen.test \
 	nlattr_inet_diag_req_v2.gen.test \
 	nlattr_mdba_mdb_entry.gen.test \
@@ -5253,17 +6434,28 @@ GEN_TESTS = _newselect.gen.test _newsele
 	oldselect.gen.test oldselect-P.gen.test \
 	oldselect-efault.gen.test oldselect-efault-P.gen.test \
 	oldstat.gen.test open.gen.test open_tree.gen.test \
-	open_tree-P.gen.test openat.gen.test \
-	orphaned_process_group.gen.test osf_utimes.gen.test \
-	pause.gen.test perf_event_open.gen.test \
+	open_tree-P.gen.test openat.gen.test openat2.gen.test \
+	openat2-Xabbrev.gen.test openat2-Xraw.gen.test \
+	openat2-Xverbose.gen.test openat2-v.gen.test \
+	openat2-v-y.gen.test openat2-v-y-Xabbrev.gen.test \
+	openat2-v-y-Xraw.gen.test openat2-v-y-Xverbose.gen.test \
+	openat2-y.gen.test orphaned_process_group.gen.test \
+	osf_utimes.gen.test pause.gen.test perf_event_open.gen.test \
 	perf_event_open_nonverbose.gen.test \
 	perf_event_open_unabbrev.gen.test personality-Xabbrev.gen.test \
 	personality-Xraw.gen.test personality-Xverbose.gen.test \
-	pidfd_open.gen.test pidfd_open-P.gen.test \
-	pidfd_open-y.gen.test pidfd_send_signal.gen.test \
-	pipe2.gen.test pkey_alloc.gen.test pkey_free.gen.test \
-	pkey_mprotect.gen.test ppoll.gen.test ppoll-P.gen.test \
-	ppoll-v.gen.test pread64-pwrite64.gen.test preadv.gen.test \
+	pidfd_getfd.gen.test pidfd_getfd-y.gen.test \
+	pidfd_getfd-yy.gen.test pidfd_open.gen.test \
+	pidfd_open--decode-fd-path.gen.test \
+	pidfd_open--decode-fd-pidfd.gen.test \
+	pidfd_open--decode-fd-socket.gen.test pidfd_open-P.gen.test \
+	pidfd_open-y.gen.test pidfd_open-yy.gen.test \
+	pidfd_open--pidns-translation.gen.test \
+	pidfd_send_signal.gen.test \
+	pidfd_send_signal--pidns-translation.gen.test pipe2.gen.test \
+	pkey_alloc.gen.test pkey_free.gen.test pkey_mprotect.gen.test \
+	ppoll.gen.test ppoll-P.gen.test ppoll-v.gen.test \
+	pread64-pwrite64.gen.test preadv.gen.test \
 	preadv-pwritev.gen.test preadv2-pwritev2.gen.test \
 	printpath-umovestr.gen.test \
 	printpath-umovestr-peekdata.gen.test \
@@ -5272,7 +6464,11 @@ GEN_TESTS = _newselect.gen.test _newsele
 	printsignal-Xverbose.gen.test printstr.gen.test \
 	printstrn-umoven.gen.test printstrn-umoven-peekdata.gen.test \
 	printstrn-umoven-undumpable.gen.test prlimit64.gen.test \
-	process_vm_readv.gen.test process_vm_writev.gen.test \
+	prlimit64--pidns-translation.gen.test \
+	process_vm_readv.gen.test \
+	process_vm_readv--pidns-translation.gen.test \
+	process_vm_writev.gen.test \
+	process_vm_writev--pidns-translation.gen.test \
 	pselect6.gen.test ptrace.gen.test ptrace_syscall_info.gen.test \
 	pwritev.gen.test quotactl.gen.test quotactl-Xabbrev.gen.test \
 	quotactl-Xraw.gen.test quotactl-Xverbose.gen.test \
@@ -5288,15 +6484,23 @@ GEN_TESTS = _newselect.gen.test _newsele
 	renameat.gen.test renameat2.gen.test request_key.gen.test \
 	riscv_flush_icache.gen.test rmdir.gen.test \
 	rt_sigpending.gen.test rt_sigprocmask.gen.test \
-	rt_sigqueueinfo.gen.test rt_sigreturn.gen.test \
-	rt_sigsuspend.gen.test rt_sigtimedwait.gen.test \
-	rt_tgsigqueueinfo.gen.test s390_guarded_storage.gen.test \
-	s390_guarded_storage-v.gen.test \
+	rt_sigqueueinfo.gen.test \
+	rt_sigqueueinfo--pidns-translation.gen.test \
+	rt_sigreturn.gen.test rt_sigsuspend.gen.test \
+	rt_sigtimedwait.gen.test rt_tgsigqueueinfo.gen.test \
+	rt_tgsigqueueinfo--pidns-translation.gen.test \
+	s390_guarded_storage.gen.test s390_guarded_storage-v.gen.test \
 	s390_pci_mmio_read_write.gen.test s390_runtime_instr.gen.test \
 	s390_sthyi.gen.test s390_sthyi-v.gen.test sched.gen.test \
 	sched_get_priority_mxx.gen.test sched_rr_get_interval.gen.test \
-	sched_xetaffinity.gen.test sched_xetattr.gen.test \
-	sched_xetparam.gen.test sched_xetscheduler.gen.test \
+	sched_xetaffinity.gen.test \
+	sched_xetaffinity--pidns-translation.gen.test \
+	sched_xetattr.gen.test \
+	sched_xetattr--pidns-translation.gen.test \
+	sched_xetparam.gen.test \
+	sched_xetparam--pidns-translation.gen.test \
+	sched_xetscheduler.gen.test \
+	sched_xetscheduler--pidns-translation.gen.test \
 	sched_yield.gen.test seccomp-filter.gen.test \
 	seccomp-filter-v.gen.test seccomp_get_action_avail.gen.test \
 	select.gen.test select-P.gen.test semop.gen.test \
@@ -5314,26 +6518,70 @@ GEN_TESTS = _newselect.gen.test _newsele
 	setrlimit-Xraw.gen.test setrlimit-Xverbose.gen.test \
 	setuid.gen.test setuid32.gen.test shmxt.gen.test \
 	shutdown.gen.test sigaction.gen.test siginfo.gen.test \
-	signal.gen.test signal_receive.gen.test signalfd4.gen.test \
+	signal.gen.test signal_receive.gen.test \
+	signal_receive--pidns-translation.gen.test signalfd4.gen.test \
 	sigpending.gen.test sigprocmask.gen.test sigreturn.gen.test \
 	sigsuspend.gen.test so_error.gen.test so_linger.gen.test \
 	so_peercred.gen.test so_peercred-Xabbrev.gen.test \
 	so_peercred-Xraw.gen.test so_peercred-Xverbose.gen.test \
-	sock_filter-v.gen.test sock_filter-v-Xabbrev.gen.test \
-	sock_filter-v-Xraw.gen.test sock_filter-v-Xverbose.gen.test \
-	sockaddr_xlat-Xabbrev.gen.test sockaddr_xlat-Xraw.gen.test \
-	sockaddr_xlat-Xverbose.gen.test socketcall.gen.test \
-	sockopt-sol_netlink.gen.test sockopt-timestamp.gen.test \
-	splice.gen.test stat.gen.test stat64.gen.test statfs.gen.test \
-	statfs64.gen.test status-all.gen.test status-failed.gen.test \
+	so_peercred--pidns-translation.gen.test sock_filter-v.gen.test \
+	sock_filter-v-Xabbrev.gen.test sock_filter-v-Xraw.gen.test \
+	sock_filter-v-Xverbose.gen.test sockaddr_xlat-Xabbrev.gen.test \
+	sockaddr_xlat-Xraw.gen.test sockaddr_xlat-Xverbose.gen.test \
+	socketcall.gen.test sockopt-sol_netlink.gen.test \
+	sockopt-timestamp.gen.test splice.gen.test stat.gen.test \
+	stat64.gen.test statfs.gen.test statfs64.gen.test \
+	status-all.gen.test status-failed.gen.test \
+	status-failed-long.gen.test status-failed-status.gen.test \
 	status-none.gen.test status-successful.gen.test \
-	status-unfinished.gen.test statx.gen.test swap.gen.test \
+	status-successful-long.gen.test \
+	status-successful-status.gen.test status-unfinished.gen.test \
+	statx.gen.test strace--absolute-timestamps.gen.test \
+	strace--absolute-timestamps-format-time.gen.test \
+	strace--absolute-timestamps-format-time-precision-s.gen.test \
+	strace--absolute-timestamps-format-time-precision-ms.gen.test \
+	strace--absolute-timestamps-format-time-precision-us.gen.test \
+	strace--absolute-timestamps-format-time-precision-ns.gen.test \
+	strace--absolute-timestamps-format-unix-precision-s.gen.test \
+	strace--absolute-timestamps-format-unix-precision-ms.gen.test \
+	strace--absolute-timestamps-format-unix-precision-us.gen.test \
+	strace--absolute-timestamps-format-unix-precision-ns.gen.test \
+	strace--follow-forks-output-separately.gen.test \
+	strace--relative-timestamps.gen.test \
+	strace--relative-timestamps-s.gen.test \
+	strace--relative-timestamps-ms.gen.test \
+	strace--relative-timestamps-us.gen.test \
+	strace--relative-timestamps-ns.gen.test \
+	strace--syscall-times.gen.test \
+	strace--syscall-times-s.gen.test \
+	strace--syscall-times-ms.gen.test \
+	strace--syscall-times-us.gen.test \
+	strace--syscall-times-ns.gen.test \
+	strace--strings-in-hex.gen.test \
+	strace--strings-in-hex-all.gen.test \
+	strace--strings-in-hex-non-ascii.gen.test \
+	strace--timestamps.gen.test strace--timestamps-time.gen.test \
+	strace--timestamps-time-s.gen.test \
+	strace--timestamps-time-ms.gen.test \
+	strace--timestamps-time-us.gen.test \
+	strace--timestamps-time-ns.gen.test \
+	strace--timestamps-unix-s.gen.test \
+	strace--timestamps-unix-ms.gen.test \
+	strace--timestamps-unix-us.gen.test \
+	strace--timestamps-unix-ns.gen.test strace-n.gen.test \
+	strace-x.gen.test strace-xx.gen.test swap.gen.test \
 	sxetmask.gen.test symlink.gen.test symlinkat.gen.test \
 	sync.gen.test sync_file_range.gen.test \
 	sync_file_range2.gen.test sysinfo.gen.test syslog.gen.test \
-	tee.gen.test time.gen.test timer_create.gen.test \
-	timer_xettime.gen.test timerfd_xettime.gen.test times.gen.test \
-	times-fail.gen.test trace_creds.gen.test trace_fstat.gen.test \
+	tee.gen.test tgkill.gen.test \
+	tgkill--pidns-translation.gen.test \
+	threads-execve--quiet-thread-execve.gen.test \
+	threads-execve-q.gen.test threads-execve-qq.gen.test \
+	threads-execve-qqq.gen.test time.gen.test \
+	timer_create.gen.test timer_xettime.gen.test \
+	timerfd_xettime.gen.test times.gen.test times-fail.gen.test \
+	tkill.gen.test tkill--pidns-translation.gen.test \
+	trace_clock.gen.test trace_creds.gen.test trace_fstat.gen.test \
 	trace_fstatfs.gen.test trace_lstat.gen.test \
 	trace_personality_32.gen.test trace_personality_64.gen.test \
 	trace_personality_regex_32.gen.test \
@@ -5342,22 +6590,27 @@ GEN_TESTS = _newselect.gen.test _newsele
 	trace_personality_x32.gen.test trace_question.gen.test \
 	trace_stat.gen.test trace_stat_like.gen.test \
 	trace_statfs.gen.test trace_statfs_like.gen.test \
-	truncate.gen.test truncate64.gen.test ugetrlimit.gen.test \
-	umask.gen.test umoven-illptr.gen.test umovestr-illptr.gen.test \
-	umovestr3.gen.test unlink.gen.test unlinkat.gen.test \
-	unshare.gen.test userfaultfd.gen.test ustat.gen.test \
-	utime.gen.test utimensat.gen.test utimensat-Xabbrev.gen.test \
-	utimensat-Xraw.gen.test utimensat-Xverbose.gen.test \
-	utimes.gen.test vfork-f.gen.test vhangup.gen.test \
-	vmsplice.gen.test wait4.gen.test wait4-v.gen.test \
-	waitid.gen.test waitid-v.gen.test waitpid.gen.test \
-	xattr.gen.test xattr-strings.gen.test xet_robust_list.gen.test \
-	xetitimer.gen.test xetpgid.gen.test xetpriority.gen.test \
+	trie_test.gen.test truncate.gen.test truncate64.gen.test \
+	ugetrlimit.gen.test umask.gen.test umoven-illptr.gen.test \
+	umovestr-illptr.gen.test umovestr3.gen.test \
+	umovestr_cached_adjacent.gen.test unlink.gen.test \
+	unlinkat.gen.test unshare.gen.test userfaultfd.gen.test \
+	ustat.gen.test utime.gen.test utimensat.gen.test \
+	utimensat-Xabbrev.gen.test utimensat-Xraw.gen.test \
+	utimensat-Xverbose.gen.test utimes.gen.test vfork-f.gen.test \
+	vhangup.gen.test vmsplice.gen.test wait4.gen.test \
+	wait4-v.gen.test waitid.gen.test waitid-v.gen.test \
+	waitpid.gen.test xattr.gen.test xattr-strings.gen.test \
+	xet_robust_list.gen.test \
+	xet_robust_list--pidns-translation.gen.test xetitimer.gen.test \
+	xetpgid.gen.test xetpgid--pidns-translation.gen.test \
+	xetpriority.gen.test xetpriority--pidns-translation.gen.test \
 	xettimeofday.gen.test
 @ENABLE_STACKTRACE_FALSE@STACKTRACE_TESTS = 
 @ENABLE_STACKTRACE_TRUE@STACKTRACE_TESTS = strace-k.test \
 @ENABLE_STACKTRACE_TRUE@	strace-k-p.test $(am__append_1)
 DECODER_TESTS = \
+	bpf-success-long-y.test \
 	bpf-success-v.test \
 	bpf-success.test \
 	brk.test \
@@ -5376,13 +6629,15 @@ DECODER_TESTS = \
 	execve-v.test \
 	execve.test \
 	fadvise64.test \
+	faccessat.test \
+	faccessat2.test \
 	futex.test \
 	getuid.test \
 	int_0x80.test \
 	inotify_init-y.test \
 	ioctl.test \
+	ioctl_block--pidns-translation.test \
 	ioctl_evdev-success.test \
-	ioctl_perf-success.test \
 	ipc_msgbuf.test \
 	kern_features-fault.test \
 	llseek.test \
@@ -5440,7 +6695,6 @@ MISC_TESTS = \
 	attach-f-p.test \
 	attach-p-cmd.test \
 	bexecve.test \
-	clone_parent.test \
 	clone_ptrace.test \
 	count-f.test \
 	count.test \
@@ -5454,15 +6708,19 @@ MISC_TESTS = \
 	filtering_fd-syntax.test \
 	filtering_syscall-syntax.test \
 	first_exec_failure.test \
+	fork--pidns-translation.test \
 	get_regs.test \
+	gettid--pidns-translation.test \
 	inject-nf.test \
 	interactive_block.test \
 	kill_child.test \
 	localtime.test \
 	looping_threads.test \
+	netlink_audit--pidns-translation.test \
 	opipe.test \
 	options-syntax.test \
 	pc.test \
+	pidns-cache.test \
 	printpath-umovestr-legacy.test \
 	printstrn-umoven-legacy.test \
 	qual_fault-syntax.test \
@@ -5490,6 +6748,8 @@ MISC_TESTS = \
 	strace-DD.test \
 	strace-DDD.test \
 	strace-E.test \
+	strace-E-override.test \
+	strace-E-unset.test \
 	strace-S.test \
 	strace-T.test \
 	strace-V.test \
@@ -5533,6 +6793,7 @@ EXTRA_DIST = \
 	filter_seccomp.in \
 	filter_seccomp.sh \
 	filter-unavailable.expected \
+	fork--pidns-translation.awk \
 	fstatat.c \
 	fstatx.c \
 	gen_pure_executables.sh \
@@ -5541,6 +6802,7 @@ EXTRA_DIST = \
 	getresugid.c \
 	init.sh \
 	init_delete_module.h \
+	ioctl-success.sh \
 	ioctl_kvm_run_common.c \
 	ipc.sh \
 	kernel_old_timespec.h \
@@ -5549,7 +6811,6 @@ EXTRA_DIST = \
 	lstatx.c \
 	match.awk \
 	net.expected \
-	netlink_sock_diag-v.sh \
 	nlattr_ifla.h \
 	pipe.expected \
 	print_user_desc.c \
@@ -5578,11 +6839,22 @@ EXTRA_DIST = \
 	sockname.c \
 	stack-fcall.h \
 	status-detached.expected \
+	strace--follow-forks-output-separately.expected \
+	strace--relative-timestamps.expected \
+	strace--relative-timestamps-s.expected \
+	strace--relative-timestamps-ms.expected \
+	strace--relative-timestamps-us.expected \
+	strace--relative-timestamps-ns.expected \
+	strace--syscall-times.expected \
+	strace--syscall-times-s.expected \
+	strace--syscall-times-ms.expected \
+	strace--syscall-times-us.expected \
+	strace--syscall-times-ns.expected \
 	strace-C.expected \
 	strace-D.expected \
-	strace-DD.expected \
 	strace-DDD.expected \
 	strace-E.expected \
+	strace-E-unset.expected \
 	strace-T.expected \
 	strace-ff.expected \
 	strace-k-demangle.expected \
@@ -5595,6 +6867,7 @@ EXTRA_DIST = \
 	strace.supp \
 	sun_path.expected \
 	syntax.sh \
+	trace_clock.in \
 	trace_creds.in \
 	trace_fstat.in \
 	trace_fstatfs.in \
@@ -5616,6 +6889,7 @@ EXTRA_DIST = \
 	unix-pair-send-recv.expected \
 	unix-pair-sendto-recvfrom.expected \
 	xchownx.c \
+	xgetdents.c \
 	xgetrlimit.c \
 	xselect.c \
 	xstatfs.c \
@@ -5777,6 +7051,10 @@ bpf-success$(EXEEXT): $(bpf_success_OBJE
 	@rm -f bpf-success$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(bpf_success_OBJECTS) $(bpf_success_LDADD) $(LIBS)
 
+bpf-success-long-y$(EXEEXT): $(bpf_success_long_y_OBJECTS) $(bpf_success_long_y_DEPENDENCIES) $(EXTRA_bpf_success_long_y_DEPENDENCIES) 
+	@rm -f bpf-success-long-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(bpf_success_long_y_OBJECTS) $(bpf_success_long_y_LDADD) $(LIBS)
+
 bpf-success-v$(EXEEXT): $(bpf_success_v_OBJECTS) $(bpf_success_v_DEPENDENCIES) $(EXTRA_bpf_success_v_DEPENDENCIES) 
 	@rm -f bpf-success-v$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(bpf_success_v_OBJECTS) $(bpf_success_v_LDADD) $(LIBS)
@@ -5877,10 +7155,54 @@ clone_parent$(EXEEXT): $(clone_parent_OB
 	@rm -f clone_parent$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(clone_parent_OBJECTS) $(clone_parent_LDADD) $(LIBS)
 
+clone_parent--quiet-exit$(EXEEXT): $(clone_parent__quiet_exit_OBJECTS) $(clone_parent__quiet_exit_DEPENDENCIES) $(EXTRA_clone_parent__quiet_exit_DEPENDENCIES) 
+	@rm -f clone_parent--quiet-exit$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(clone_parent__quiet_exit_OBJECTS) $(clone_parent__quiet_exit_LDADD) $(LIBS)
+
+clone_parent-q$(EXEEXT): $(clone_parent_q_OBJECTS) $(clone_parent_q_DEPENDENCIES) $(EXTRA_clone_parent_q_DEPENDENCIES) 
+	@rm -f clone_parent-q$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(clone_parent_q_OBJECTS) $(clone_parent_q_LDADD) $(LIBS)
+
+clone_parent-qq$(EXEEXT): $(clone_parent_qq_OBJECTS) $(clone_parent_qq_DEPENDENCIES) $(EXTRA_clone_parent_qq_DEPENDENCIES) 
+	@rm -f clone_parent-qq$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(clone_parent_qq_OBJECTS) $(clone_parent_qq_LDADD) $(LIBS)
+
 clone_ptrace$(EXEEXT): $(clone_ptrace_OBJECTS) $(clone_ptrace_DEPENDENCIES) $(EXTRA_clone_ptrace_DEPENDENCIES) 
 	@rm -f clone_ptrace$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(clone_ptrace_OBJECTS) $(clone_ptrace_LDADD) $(LIBS)
 
+clone_ptrace--quiet-attach$(EXEEXT): $(clone_ptrace__quiet_attach_OBJECTS) $(clone_ptrace__quiet_attach_DEPENDENCIES) $(EXTRA_clone_ptrace__quiet_attach_DEPENDENCIES) 
+	@rm -f clone_ptrace--quiet-attach$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(clone_ptrace__quiet_attach_OBJECTS) $(clone_ptrace__quiet_attach_LDADD) $(LIBS)
+
+clone_ptrace--quiet-exit$(EXEEXT): $(clone_ptrace__quiet_exit_OBJECTS) $(clone_ptrace__quiet_exit_DEPENDENCIES) $(EXTRA_clone_ptrace__quiet_exit_DEPENDENCIES) 
+	@rm -f clone_ptrace--quiet-exit$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(clone_ptrace__quiet_exit_OBJECTS) $(clone_ptrace__quiet_exit_LDADD) $(LIBS)
+
+clone_ptrace-q$(EXEEXT): $(clone_ptrace_q_OBJECTS) $(clone_ptrace_q_DEPENDENCIES) $(EXTRA_clone_ptrace_q_DEPENDENCIES) 
+	@rm -f clone_ptrace-q$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(clone_ptrace_q_OBJECTS) $(clone_ptrace_q_LDADD) $(LIBS)
+
+clone_ptrace-qq$(EXEEXT): $(clone_ptrace_qq_OBJECTS) $(clone_ptrace_qq_DEPENDENCIES) $(EXTRA_clone_ptrace_qq_DEPENDENCIES) 
+	@rm -f clone_ptrace-qq$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(clone_ptrace_qq_OBJECTS) $(clone_ptrace_qq_LDADD) $(LIBS)
+
+close_range$(EXEEXT): $(close_range_OBJECTS) $(close_range_DEPENDENCIES) $(EXTRA_close_range_DEPENDENCIES) 
+	@rm -f close_range$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(close_range_OBJECTS) $(close_range_LDADD) $(LIBS)
+
+close_range-P$(EXEEXT): $(close_range_P_OBJECTS) $(close_range_P_DEPENDENCIES) $(EXTRA_close_range_P_DEPENDENCIES) 
+	@rm -f close_range-P$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(close_range_P_OBJECTS) $(close_range_P_LDADD) $(LIBS)
+
+close_range-y$(EXEEXT): $(close_range_y_OBJECTS) $(close_range_y_DEPENDENCIES) $(EXTRA_close_range_y_DEPENDENCIES) 
+	@rm -f close_range-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(close_range_y_OBJECTS) $(close_range_y_LDADD) $(LIBS)
+
+close_range-yy$(EXEEXT): $(close_range_yy_OBJECTS) $(close_range_yy_DEPENDENCIES) $(EXTRA_close_range_yy_DEPENDENCIES) 
+	@rm -f close_range-yy$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(close_range_yy_OBJECTS) $(close_range_yy_LDADD) $(LIBS)
+
 copy_file_range$(EXEEXT): $(copy_file_range_OBJECTS) $(copy_file_range_DEPENDENCIES) $(EXTRA_copy_file_range_DEPENDENCIES) 
 	@rm -f copy_file_range$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(copy_file_range_OBJECTS) $(copy_file_range_LDADD) $(LIBS)
@@ -5901,6 +7223,18 @@ delete_module$(EXEEXT): $(delete_module_
 	@rm -f delete_module$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(delete_module_OBJECTS) $(delete_module_LDADD) $(LIBS)
 
+dev--decode-fds-dev$(EXEEXT): $(dev__decode_fds_dev_OBJECTS) $(dev__decode_fds_dev_DEPENDENCIES) $(EXTRA_dev__decode_fds_dev_DEPENDENCIES) 
+	@rm -f dev--decode-fds-dev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dev__decode_fds_dev_OBJECTS) $(dev__decode_fds_dev_LDADD) $(LIBS)
+
+dev--decode-fds-path$(EXEEXT): $(dev__decode_fds_path_OBJECTS) $(dev__decode_fds_path_DEPENDENCIES) $(EXTRA_dev__decode_fds_path_DEPENDENCIES) 
+	@rm -f dev--decode-fds-path$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dev__decode_fds_path_OBJECTS) $(dev__decode_fds_path_LDADD) $(LIBS)
+
+dev--decode-fds-socket$(EXEEXT): $(dev__decode_fds_socket_OBJECTS) $(dev__decode_fds_socket_DEPENDENCIES) $(EXTRA_dev__decode_fds_socket_DEPENDENCIES) 
+	@rm -f dev--decode-fds-socket$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dev__decode_fds_socket_OBJECTS) $(dev__decode_fds_socket_LDADD) $(LIBS)
+
 dev-yy$(EXEEXT): $(dev_yy_OBJECTS) $(dev_yy_DEPENDENCIES) $(EXTRA_dev_yy_DEPENDENCIES) 
 	@rm -f dev-yy$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(dev_yy_OBJECTS) $(dev_yy_LDADD) $(LIBS)
@@ -5909,14 +7243,50 @@ dup$(EXEEXT): $(dup_OBJECTS) $(dup_DEPEN
 	@rm -f dup$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(dup_OBJECTS) $(dup_LDADD) $(LIBS)
 
+dup-P$(EXEEXT): $(dup_P_OBJECTS) $(dup_P_DEPENDENCIES) $(EXTRA_dup_P_DEPENDENCIES) 
+	@rm -f dup-P$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup_P_OBJECTS) $(dup_P_LDADD) $(LIBS)
+
+dup-y$(EXEEXT): $(dup_y_OBJECTS) $(dup_y_DEPENDENCIES) $(EXTRA_dup_y_DEPENDENCIES) 
+	@rm -f dup-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup_y_OBJECTS) $(dup_y_LDADD) $(LIBS)
+
+dup-yy$(EXEEXT): $(dup_yy_OBJECTS) $(dup_yy_DEPENDENCIES) $(EXTRA_dup_yy_DEPENDENCIES) 
+	@rm -f dup-yy$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup_yy_OBJECTS) $(dup_yy_LDADD) $(LIBS)
+
 dup2$(EXEEXT): $(dup2_OBJECTS) $(dup2_DEPENDENCIES) $(EXTRA_dup2_DEPENDENCIES) 
 	@rm -f dup2$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(dup2_OBJECTS) $(dup2_LDADD) $(LIBS)
 
+dup2-P$(EXEEXT): $(dup2_P_OBJECTS) $(dup2_P_DEPENDENCIES) $(EXTRA_dup2_P_DEPENDENCIES) 
+	@rm -f dup2-P$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup2_P_OBJECTS) $(dup2_P_LDADD) $(LIBS)
+
+dup2-y$(EXEEXT): $(dup2_y_OBJECTS) $(dup2_y_DEPENDENCIES) $(EXTRA_dup2_y_DEPENDENCIES) 
+	@rm -f dup2-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup2_y_OBJECTS) $(dup2_y_LDADD) $(LIBS)
+
+dup2-yy$(EXEEXT): $(dup2_yy_OBJECTS) $(dup2_yy_DEPENDENCIES) $(EXTRA_dup2_yy_DEPENDENCIES) 
+	@rm -f dup2-yy$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup2_yy_OBJECTS) $(dup2_yy_LDADD) $(LIBS)
+
 dup3$(EXEEXT): $(dup3_OBJECTS) $(dup3_DEPENDENCIES) $(EXTRA_dup3_DEPENDENCIES) 
 	@rm -f dup3$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(dup3_OBJECTS) $(dup3_LDADD) $(LIBS)
 
+dup3-P$(EXEEXT): $(dup3_P_OBJECTS) $(dup3_P_DEPENDENCIES) $(EXTRA_dup3_P_DEPENDENCIES) 
+	@rm -f dup3-P$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup3_P_OBJECTS) $(dup3_P_LDADD) $(LIBS)
+
+dup3-y$(EXEEXT): $(dup3_y_OBJECTS) $(dup3_y_DEPENDENCIES) $(EXTRA_dup3_y_DEPENDENCIES) 
+	@rm -f dup3-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup3_y_OBJECTS) $(dup3_y_LDADD) $(LIBS)
+
+dup3-yy$(EXEEXT): $(dup3_yy_OBJECTS) $(dup3_yy_DEPENDENCIES) $(EXTRA_dup3_yy_DEPENDENCIES) 
+	@rm -f dup3-yy$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup3_yy_OBJECTS) $(dup3_yy_LDADD) $(LIBS)
+
 epoll_create$(EXEEXT): $(epoll_create_OBJECTS) $(epoll_create_DEPENDENCIES) $(EXTRA_epoll_create_DEPENDENCIES) 
 	@rm -f epoll_create$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(epoll_create_OBJECTS) $(epoll_create_LDADD) $(LIBS)
@@ -5965,6 +7335,34 @@ faccessat$(EXEEXT): $(faccessat_OBJECTS)
 	@rm -f faccessat$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(faccessat_OBJECTS) $(faccessat_LDADD) $(LIBS)
 
+faccessat-P$(EXEEXT): $(faccessat_P_OBJECTS) $(faccessat_P_DEPENDENCIES) $(EXTRA_faccessat_P_DEPENDENCIES) 
+	@rm -f faccessat-P$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(faccessat_P_OBJECTS) $(faccessat_P_LDADD) $(LIBS)
+
+faccessat-y$(EXEEXT): $(faccessat_y_OBJECTS) $(faccessat_y_DEPENDENCIES) $(EXTRA_faccessat_y_DEPENDENCIES) 
+	@rm -f faccessat-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(faccessat_y_OBJECTS) $(faccessat_y_LDADD) $(LIBS)
+
+faccessat-yy$(EXEEXT): $(faccessat_yy_OBJECTS) $(faccessat_yy_DEPENDENCIES) $(EXTRA_faccessat_yy_DEPENDENCIES) 
+	@rm -f faccessat-yy$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(faccessat_yy_OBJECTS) $(faccessat_yy_LDADD) $(LIBS)
+
+faccessat2$(EXEEXT): $(faccessat2_OBJECTS) $(faccessat2_DEPENDENCIES) $(EXTRA_faccessat2_DEPENDENCIES) 
+	@rm -f faccessat2$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(faccessat2_OBJECTS) $(faccessat2_LDADD) $(LIBS)
+
+faccessat2-P$(EXEEXT): $(faccessat2_P_OBJECTS) $(faccessat2_P_DEPENDENCIES) $(EXTRA_faccessat2_P_DEPENDENCIES) 
+	@rm -f faccessat2-P$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(faccessat2_P_OBJECTS) $(faccessat2_P_LDADD) $(LIBS)
+
+faccessat2-y$(EXEEXT): $(faccessat2_y_OBJECTS) $(faccessat2_y_DEPENDENCIES) $(EXTRA_faccessat2_y_DEPENDENCIES) 
+	@rm -f faccessat2-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(faccessat2_y_OBJECTS) $(faccessat2_y_LDADD) $(LIBS)
+
+faccessat2-yy$(EXEEXT): $(faccessat2_yy_OBJECTS) $(faccessat2_yy_DEPENDENCIES) $(EXTRA_faccessat2_yy_DEPENDENCIES) 
+	@rm -f faccessat2-yy$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(faccessat2_yy_OBJECTS) $(faccessat2_yy_LDADD) $(LIBS)
+
 fadvise64$(EXEEXT): $(fadvise64_OBJECTS) $(fadvise64_DEPENDENCIES) $(EXTRA_fadvise64_DEPENDENCIES) 
 	@rm -f fadvise64$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(fadvise64_OBJECTS) $(fadvise64_LDADD) $(LIBS)
@@ -6025,10 +7423,18 @@ fcntl$(EXEEXT): $(fcntl_OBJECTS) $(fcntl
 	@rm -f fcntl$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(fcntl_OBJECTS) $(fcntl_LDADD) $(LIBS)
 
+fcntl--pidns-translation$(EXEEXT): $(fcntl__pidns_translation_OBJECTS) $(fcntl__pidns_translation_DEPENDENCIES) $(EXTRA_fcntl__pidns_translation_DEPENDENCIES) 
+	@rm -f fcntl--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(fcntl__pidns_translation_OBJECTS) $(fcntl__pidns_translation_LDADD) $(LIBS)
+
 fcntl64$(EXEEXT): $(fcntl64_OBJECTS) $(fcntl64_DEPENDENCIES) $(EXTRA_fcntl64_DEPENDENCIES) 
 	@rm -f fcntl64$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(fcntl64_OBJECTS) $(fcntl64_LDADD) $(LIBS)
 
+fcntl64--pidns-translation$(EXEEXT): $(fcntl64__pidns_translation_OBJECTS) $(fcntl64__pidns_translation_DEPENDENCIES) $(EXTRA_fcntl64__pidns_translation_DEPENDENCIES) 
+	@rm -f fcntl64--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(fcntl64__pidns_translation_OBJECTS) $(fcntl64__pidns_translation_LDADD) $(LIBS)
+
 fdatasync$(EXEEXT): $(fdatasync_OBJECTS) $(fdatasync_DEPENDENCIES) $(EXTRA_fdatasync_DEPENDENCIES) 
 	@rm -f fdatasync$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(fdatasync_OBJECTS) $(fdatasync_LDADD) $(LIBS)
@@ -6065,6 +7471,10 @@ flock$(EXEEXT): $(flock_OBJECTS) $(flock
 	@rm -f flock$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(flock_OBJECTS) $(flock_LDADD) $(LIBS)
 
+fork--pidns-translation$(EXEEXT): $(fork__pidns_translation_OBJECTS) $(fork__pidns_translation_DEPENDENCIES) $(EXTRA_fork__pidns_translation_DEPENDENCIES) 
+	@rm -f fork--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(fork__pidns_translation_OBJECTS) $(fork__pidns_translation_LDADD) $(LIBS)
+
 fork-f$(EXEEXT): $(fork_f_OBJECTS) $(fork_f_DEPENDENCIES) $(EXTRA_fork_f_DEPENDENCIES) 
 	@rm -f fork-f$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(fork_f_OBJECTS) $(fork_f_LDADD) $(LIBS)
@@ -6165,6 +7575,10 @@ get_mempolicy$(EXEEXT): $(get_mempolicy_
 	@rm -f get_mempolicy$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(get_mempolicy_OBJECTS) $(get_mempolicy_LDADD) $(LIBS)
 
+get_process_reaper$(EXEEXT): $(get_process_reaper_OBJECTS) $(get_process_reaper_DEPENDENCIES) $(EXTRA_get_process_reaper_DEPENDENCIES) 
+	@rm -f get_process_reaper$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(get_process_reaper_OBJECTS) $(get_process_reaper_LDADD) $(LIBS)
+
 getcpu$(EXEEXT): $(getcpu_OBJECTS) $(getcpu_DEPENDENCIES) $(EXTRA_getcpu_DEPENDENCIES) 
 	@rm -f getcpu$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getcpu_OBJECTS) $(getcpu_LDADD) $(LIBS)
@@ -6177,10 +7591,18 @@ getdents$(EXEEXT): $(getdents_OBJECTS) $
 	@rm -f getdents$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getdents_OBJECTS) $(getdents_LDADD) $(LIBS)
 
+getdents-v$(EXEEXT): $(getdents_v_OBJECTS) $(getdents_v_DEPENDENCIES) $(EXTRA_getdents_v_DEPENDENCIES) 
+	@rm -f getdents-v$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(getdents_v_OBJECTS) $(getdents_v_LDADD) $(LIBS)
+
 getdents64$(EXEEXT): $(getdents64_OBJECTS) $(getdents64_DEPENDENCIES) $(EXTRA_getdents64_DEPENDENCIES) 
 	@rm -f getdents64$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getdents64_OBJECTS) $(getdents64_LDADD) $(LIBS)
 
+getdents64-v$(EXEEXT): $(getdents64_v_OBJECTS) $(getdents64_v_DEPENDENCIES) $(EXTRA_getdents64_v_DEPENDENCIES) 
+	@rm -f getdents64-v$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(getdents64_v_OBJECTS) $(getdents64_v_LDADD) $(LIBS)
+
 getegid$(EXEEXT): $(getegid_OBJECTS) $(getegid_DEPENDENCIES) $(EXTRA_getegid_DEPENDENCIES) 
 	@rm -f getegid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getegid_OBJECTS) $(getegid_LDADD) $(LIBS)
@@ -6221,10 +7643,18 @@ getpgrp$(EXEEXT): $(getpgrp_OBJECTS) $(g
 	@rm -f getpgrp$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getpgrp_OBJECTS) $(getpgrp_LDADD) $(LIBS)
 
+getpgrp--pidns-translation$(EXEEXT): $(getpgrp__pidns_translation_OBJECTS) $(getpgrp__pidns_translation_DEPENDENCIES) $(EXTRA_getpgrp__pidns_translation_DEPENDENCIES) 
+	@rm -f getpgrp--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(getpgrp__pidns_translation_OBJECTS) $(getpgrp__pidns_translation_LDADD) $(LIBS)
+
 getpid$(EXEEXT): $(getpid_OBJECTS) $(getpid_DEPENDENCIES) $(EXTRA_getpid_DEPENDENCIES) 
 	@rm -f getpid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getpid_OBJECTS) $(getpid_LDADD) $(LIBS)
 
+getpid--pidns-translation$(EXEEXT): $(getpid__pidns_translation_OBJECTS) $(getpid__pidns_translation_DEPENDENCIES) $(EXTRA_getpid__pidns_translation_DEPENDENCIES) 
+	@rm -f getpid--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(getpid__pidns_translation_OBJECTS) $(getpid__pidns_translation_LDADD) $(LIBS)
+
 getppid$(EXEEXT): $(getppid_OBJECTS) $(getppid_DEPENDENCIES) $(EXTRA_getppid_DEPENDENCIES) 
 	@rm -f getppid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getppid_OBJECTS) $(getppid_LDADD) $(LIBS)
@@ -6261,6 +7691,10 @@ getsid$(EXEEXT): $(getsid_OBJECTS) $(get
 	@rm -f getsid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getsid_OBJECTS) $(getsid_LDADD) $(LIBS)
 
+getsid--pidns-translation$(EXEEXT): $(getsid__pidns_translation_OBJECTS) $(getsid__pidns_translation_DEPENDENCIES) $(EXTRA_getsid__pidns_translation_DEPENDENCIES) 
+	@rm -f getsid--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(getsid__pidns_translation_OBJECTS) $(getsid__pidns_translation_LDADD) $(LIBS)
+
 getsockname$(EXEEXT): $(getsockname_OBJECTS) $(getsockname_DEPENDENCIES) $(EXTRA_getsockname_DEPENDENCIES) 
 	@rm -f getsockname$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getsockname_OBJECTS) $(getsockname_LDADD) $(LIBS)
@@ -6269,6 +7703,10 @@ gettid$(EXEEXT): $(gettid_OBJECTS) $(get
 	@rm -f gettid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(gettid_OBJECTS) $(gettid_LDADD) $(LIBS)
 
+gettid--pidns-translation$(EXEEXT): $(gettid__pidns_translation_OBJECTS) $(gettid__pidns_translation_DEPENDENCIES) $(EXTRA_gettid__pidns_translation_DEPENDENCIES) 
+	@rm -f gettid--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(gettid__pidns_translation_OBJECTS) $(gettid__pidns_translation_LDADD) $(LIBS)
+
 getuid$(EXEEXT): $(getuid_OBJECTS) $(getuid_DEPENDENCIES) $(EXTRA_getuid_DEPENDENCIES) 
 	@rm -f getuid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getuid_OBJECTS) $(getuid_LDADD) $(LIBS)
@@ -6277,9 +7715,17 @@ getuid32$(EXEEXT): $(getuid32_OBJECTS) $
 	@rm -f getuid32$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getuid32_OBJECTS) $(getuid32_LDADD) $(LIBS)
 
-getxxid$(EXEEXT): $(getxxid_OBJECTS) $(getxxid_DEPENDENCIES) $(EXTRA_getxxid_DEPENDENCIES) 
-	@rm -f getxxid$(EXEEXT)
-	$(AM_V_CCLD)$(LINK) $(getxxid_OBJECTS) $(getxxid_LDADD) $(LIBS)
+getxgid$(EXEEXT): $(getxgid_OBJECTS) $(getxgid_DEPENDENCIES) $(EXTRA_getxgid_DEPENDENCIES) 
+	@rm -f getxgid$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(getxgid_OBJECTS) $(getxgid_LDADD) $(LIBS)
+
+getxpid$(EXEEXT): $(getxpid_OBJECTS) $(getxpid_DEPENDENCIES) $(EXTRA_getxpid_DEPENDENCIES) 
+	@rm -f getxpid$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(getxpid_OBJECTS) $(getxpid_LDADD) $(LIBS)
+
+getxuid$(EXEEXT): $(getxuid_OBJECTS) $(getxuid_DEPENDENCIES) $(EXTRA_getxuid_DEPENDENCIES) 
+	@rm -f getxuid$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(getxuid_OBJECTS) $(getxuid_LDADD) $(LIBS)
 
 group_req$(EXEEXT): $(group_req_OBJECTS) $(group_req_DEPENDENCIES) $(EXTRA_group_req_DEPENDENCIES) 
 	@rm -f group_req$(EXEEXT)
@@ -6341,6 +7787,10 @@ ioctl_block$(EXEEXT): $(ioctl_block_OBJE
 	@rm -f ioctl_block$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioctl_block_OBJECTS) $(ioctl_block_LDADD) $(LIBS)
 
+ioctl_block--pidns-translation$(EXEEXT): $(ioctl_block__pidns_translation_OBJECTS) $(ioctl_block__pidns_translation_DEPENDENCIES) $(EXTRA_ioctl_block__pidns_translation_DEPENDENCIES) 
+	@rm -f ioctl_block--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_block__pidns_translation_OBJECTS) $(ioctl_block__pidns_translation_LDADD) $(LIBS)
+
 ioctl_dm$(EXEEXT): $(ioctl_dm_OBJECTS) $(ioctl_dm_DEPENDENCIES) $(EXTRA_ioctl_dm_DEPENDENCIES) 
 	@rm -f ioctl_dm$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioctl_dm_OBJECTS) $(ioctl_dm_LDADD) $(LIBS)
@@ -6413,6 +7863,70 @@ ioctl_evdev-v-Xverbose$(EXEEXT): $(ioctl
 	@rm -f ioctl_evdev-v-Xverbose$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioctl_evdev_v_Xverbose_OBJECTS) $(ioctl_evdev_v_Xverbose_LDADD) $(LIBS)
 
+ioctl_hdio$(EXEEXT): $(ioctl_hdio_OBJECTS) $(ioctl_hdio_DEPENDENCIES) $(EXTRA_ioctl_hdio_DEPENDENCIES) 
+	@rm -f ioctl_hdio$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_OBJECTS) $(ioctl_hdio_LDADD) $(LIBS)
+
+ioctl_hdio-Xabbrev$(EXEEXT): $(ioctl_hdio_Xabbrev_OBJECTS) $(ioctl_hdio_Xabbrev_DEPENDENCIES) $(EXTRA_ioctl_hdio_Xabbrev_DEPENDENCIES) 
+	@rm -f ioctl_hdio-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_Xabbrev_OBJECTS) $(ioctl_hdio_Xabbrev_LDADD) $(LIBS)
+
+ioctl_hdio-Xraw$(EXEEXT): $(ioctl_hdio_Xraw_OBJECTS) $(ioctl_hdio_Xraw_DEPENDENCIES) $(EXTRA_ioctl_hdio_Xraw_DEPENDENCIES) 
+	@rm -f ioctl_hdio-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_Xraw_OBJECTS) $(ioctl_hdio_Xraw_LDADD) $(LIBS)
+
+ioctl_hdio-Xverbose$(EXEEXT): $(ioctl_hdio_Xverbose_OBJECTS) $(ioctl_hdio_Xverbose_DEPENDENCIES) $(EXTRA_ioctl_hdio_Xverbose_DEPENDENCIES) 
+	@rm -f ioctl_hdio-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_Xverbose_OBJECTS) $(ioctl_hdio_Xverbose_LDADD) $(LIBS)
+
+ioctl_hdio-success$(EXEEXT): $(ioctl_hdio_success_OBJECTS) $(ioctl_hdio_success_DEPENDENCIES) $(EXTRA_ioctl_hdio_success_DEPENDENCIES) 
+	@rm -f ioctl_hdio-success$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_success_OBJECTS) $(ioctl_hdio_success_LDADD) $(LIBS)
+
+ioctl_hdio-success-Xabbrev$(EXEEXT): $(ioctl_hdio_success_Xabbrev_OBJECTS) $(ioctl_hdio_success_Xabbrev_DEPENDENCIES) $(EXTRA_ioctl_hdio_success_Xabbrev_DEPENDENCIES) 
+	@rm -f ioctl_hdio-success-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_success_Xabbrev_OBJECTS) $(ioctl_hdio_success_Xabbrev_LDADD) $(LIBS)
+
+ioctl_hdio-success-Xraw$(EXEEXT): $(ioctl_hdio_success_Xraw_OBJECTS) $(ioctl_hdio_success_Xraw_DEPENDENCIES) $(EXTRA_ioctl_hdio_success_Xraw_DEPENDENCIES) 
+	@rm -f ioctl_hdio-success-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_success_Xraw_OBJECTS) $(ioctl_hdio_success_Xraw_LDADD) $(LIBS)
+
+ioctl_hdio-success-Xverbose$(EXEEXT): $(ioctl_hdio_success_Xverbose_OBJECTS) $(ioctl_hdio_success_Xverbose_DEPENDENCIES) $(EXTRA_ioctl_hdio_success_Xverbose_DEPENDENCIES) 
+	@rm -f ioctl_hdio-success-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_success_Xverbose_OBJECTS) $(ioctl_hdio_success_Xverbose_LDADD) $(LIBS)
+
+ioctl_hdio-success-v$(EXEEXT): $(ioctl_hdio_success_v_OBJECTS) $(ioctl_hdio_success_v_DEPENDENCIES) $(EXTRA_ioctl_hdio_success_v_DEPENDENCIES) 
+	@rm -f ioctl_hdio-success-v$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_success_v_OBJECTS) $(ioctl_hdio_success_v_LDADD) $(LIBS)
+
+ioctl_hdio-success-v-Xabbrev$(EXEEXT): $(ioctl_hdio_success_v_Xabbrev_OBJECTS) $(ioctl_hdio_success_v_Xabbrev_DEPENDENCIES) $(EXTRA_ioctl_hdio_success_v_Xabbrev_DEPENDENCIES) 
+	@rm -f ioctl_hdio-success-v-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_success_v_Xabbrev_OBJECTS) $(ioctl_hdio_success_v_Xabbrev_LDADD) $(LIBS)
+
+ioctl_hdio-success-v-Xraw$(EXEEXT): $(ioctl_hdio_success_v_Xraw_OBJECTS) $(ioctl_hdio_success_v_Xraw_DEPENDENCIES) $(EXTRA_ioctl_hdio_success_v_Xraw_DEPENDENCIES) 
+	@rm -f ioctl_hdio-success-v-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_success_v_Xraw_OBJECTS) $(ioctl_hdio_success_v_Xraw_LDADD) $(LIBS)
+
+ioctl_hdio-success-v-Xverbose$(EXEEXT): $(ioctl_hdio_success_v_Xverbose_OBJECTS) $(ioctl_hdio_success_v_Xverbose_DEPENDENCIES) $(EXTRA_ioctl_hdio_success_v_Xverbose_DEPENDENCIES) 
+	@rm -f ioctl_hdio-success-v-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_success_v_Xverbose_OBJECTS) $(ioctl_hdio_success_v_Xverbose_LDADD) $(LIBS)
+
+ioctl_hdio-v$(EXEEXT): $(ioctl_hdio_v_OBJECTS) $(ioctl_hdio_v_DEPENDENCIES) $(EXTRA_ioctl_hdio_v_DEPENDENCIES) 
+	@rm -f ioctl_hdio-v$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_v_OBJECTS) $(ioctl_hdio_v_LDADD) $(LIBS)
+
+ioctl_hdio-v-Xabbrev$(EXEEXT): $(ioctl_hdio_v_Xabbrev_OBJECTS) $(ioctl_hdio_v_Xabbrev_DEPENDENCIES) $(EXTRA_ioctl_hdio_v_Xabbrev_DEPENDENCIES) 
+	@rm -f ioctl_hdio-v-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_v_Xabbrev_OBJECTS) $(ioctl_hdio_v_Xabbrev_LDADD) $(LIBS)
+
+ioctl_hdio-v-Xraw$(EXEEXT): $(ioctl_hdio_v_Xraw_OBJECTS) $(ioctl_hdio_v_Xraw_DEPENDENCIES) $(EXTRA_ioctl_hdio_v_Xraw_DEPENDENCIES) 
+	@rm -f ioctl_hdio-v-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_v_Xraw_OBJECTS) $(ioctl_hdio_v_Xraw_LDADD) $(LIBS)
+
+ioctl_hdio-v-Xverbose$(EXEEXT): $(ioctl_hdio_v_Xverbose_OBJECTS) $(ioctl_hdio_v_Xverbose_DEPENDENCIES) $(EXTRA_ioctl_hdio_v_Xverbose_DEPENDENCIES) 
+	@rm -f ioctl_hdio-v-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_v_Xverbose_OBJECTS) $(ioctl_hdio_v_Xverbose_LDADD) $(LIBS)
+
 ioctl_inotify$(EXEEXT): $(ioctl_inotify_OBJECTS) $(ioctl_inotify_DEPENDENCIES) $(EXTRA_ioctl_inotify_DEPENDENCIES) 
 	@rm -f ioctl_inotify$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioctl_inotify_OBJECTS) $(ioctl_inotify_LDADD) $(LIBS)
@@ -6493,6 +8007,10 @@ ioctl_sock_gifconf$(EXEEXT): $(ioctl_soc
 	@rm -f ioctl_sock_gifconf$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioctl_sock_gifconf_OBJECTS) $(ioctl_sock_gifconf_LDADD) $(LIBS)
 
+ioctl_tee$(EXEEXT): $(ioctl_tee_OBJECTS) $(ioctl_tee_DEPENDENCIES) $(EXTRA_ioctl_tee_DEPENDENCIES) 
+	@rm -f ioctl_tee$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_tee_OBJECTS) $(ioctl_tee_LDADD) $(LIBS)
+
 ioctl_uffdio$(EXEEXT): $(ioctl_uffdio_OBJECTS) $(ioctl_uffdio_DEPENDENCIES) $(EXTRA_ioctl_uffdio_DEPENDENCIES) 
 	@rm -f ioctl_uffdio$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioctl_uffdio_OBJECTS) $(ioctl_uffdio_LDADD) $(LIBS)
@@ -6501,6 +8019,66 @@ ioctl_v4l2$(EXEEXT): $(ioctl_v4l2_OBJECT
 	@rm -f ioctl_v4l2$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_OBJECTS) $(ioctl_v4l2_LDADD) $(LIBS)
 
+ioctl_v4l2-Xabbrev$(EXEEXT): $(ioctl_v4l2_Xabbrev_OBJECTS) $(ioctl_v4l2_Xabbrev_DEPENDENCIES) $(EXTRA_ioctl_v4l2_Xabbrev_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_Xabbrev_OBJECTS) $(ioctl_v4l2_Xabbrev_LDADD) $(LIBS)
+
+ioctl_v4l2-Xraw$(EXEEXT): $(ioctl_v4l2_Xraw_OBJECTS) $(ioctl_v4l2_Xraw_DEPENDENCIES) $(EXTRA_ioctl_v4l2_Xraw_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_Xraw_OBJECTS) $(ioctl_v4l2_Xraw_LDADD) $(LIBS)
+
+ioctl_v4l2-Xverbose$(EXEEXT): $(ioctl_v4l2_Xverbose_OBJECTS) $(ioctl_v4l2_Xverbose_DEPENDENCIES) $(EXTRA_ioctl_v4l2_Xverbose_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_Xverbose_OBJECTS) $(ioctl_v4l2_Xverbose_LDADD) $(LIBS)
+
+ioctl_v4l2-success$(EXEEXT): $(ioctl_v4l2_success_OBJECTS) $(ioctl_v4l2_success_DEPENDENCIES) $(EXTRA_ioctl_v4l2_success_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-success$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_success_OBJECTS) $(ioctl_v4l2_success_LDADD) $(LIBS)
+
+ioctl_v4l2-success-Xabbrev$(EXEEXT): $(ioctl_v4l2_success_Xabbrev_OBJECTS) $(ioctl_v4l2_success_Xabbrev_DEPENDENCIES) $(EXTRA_ioctl_v4l2_success_Xabbrev_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-success-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_success_Xabbrev_OBJECTS) $(ioctl_v4l2_success_Xabbrev_LDADD) $(LIBS)
+
+ioctl_v4l2-success-Xraw$(EXEEXT): $(ioctl_v4l2_success_Xraw_OBJECTS) $(ioctl_v4l2_success_Xraw_DEPENDENCIES) $(EXTRA_ioctl_v4l2_success_Xraw_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-success-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_success_Xraw_OBJECTS) $(ioctl_v4l2_success_Xraw_LDADD) $(LIBS)
+
+ioctl_v4l2-success-Xverbose$(EXEEXT): $(ioctl_v4l2_success_Xverbose_OBJECTS) $(ioctl_v4l2_success_Xverbose_DEPENDENCIES) $(EXTRA_ioctl_v4l2_success_Xverbose_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-success-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_success_Xverbose_OBJECTS) $(ioctl_v4l2_success_Xverbose_LDADD) $(LIBS)
+
+ioctl_v4l2-success-v$(EXEEXT): $(ioctl_v4l2_success_v_OBJECTS) $(ioctl_v4l2_success_v_DEPENDENCIES) $(EXTRA_ioctl_v4l2_success_v_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-success-v$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_success_v_OBJECTS) $(ioctl_v4l2_success_v_LDADD) $(LIBS)
+
+ioctl_v4l2-success-v-Xabbrev$(EXEEXT): $(ioctl_v4l2_success_v_Xabbrev_OBJECTS) $(ioctl_v4l2_success_v_Xabbrev_DEPENDENCIES) $(EXTRA_ioctl_v4l2_success_v_Xabbrev_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-success-v-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_success_v_Xabbrev_OBJECTS) $(ioctl_v4l2_success_v_Xabbrev_LDADD) $(LIBS)
+
+ioctl_v4l2-success-v-Xraw$(EXEEXT): $(ioctl_v4l2_success_v_Xraw_OBJECTS) $(ioctl_v4l2_success_v_Xraw_DEPENDENCIES) $(EXTRA_ioctl_v4l2_success_v_Xraw_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-success-v-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_success_v_Xraw_OBJECTS) $(ioctl_v4l2_success_v_Xraw_LDADD) $(LIBS)
+
+ioctl_v4l2-success-v-Xverbose$(EXEEXT): $(ioctl_v4l2_success_v_Xverbose_OBJECTS) $(ioctl_v4l2_success_v_Xverbose_DEPENDENCIES) $(EXTRA_ioctl_v4l2_success_v_Xverbose_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-success-v-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_success_v_Xverbose_OBJECTS) $(ioctl_v4l2_success_v_Xverbose_LDADD) $(LIBS)
+
+ioctl_v4l2-v$(EXEEXT): $(ioctl_v4l2_v_OBJECTS) $(ioctl_v4l2_v_DEPENDENCIES) $(EXTRA_ioctl_v4l2_v_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-v$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_v_OBJECTS) $(ioctl_v4l2_v_LDADD) $(LIBS)
+
+ioctl_v4l2-v-Xabbrev$(EXEEXT): $(ioctl_v4l2_v_Xabbrev_OBJECTS) $(ioctl_v4l2_v_Xabbrev_DEPENDENCIES) $(EXTRA_ioctl_v4l2_v_Xabbrev_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-v-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_v_Xabbrev_OBJECTS) $(ioctl_v4l2_v_Xabbrev_LDADD) $(LIBS)
+
+ioctl_v4l2-v-Xraw$(EXEEXT): $(ioctl_v4l2_v_Xraw_OBJECTS) $(ioctl_v4l2_v_Xraw_DEPENDENCIES) $(EXTRA_ioctl_v4l2_v_Xraw_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-v-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_v_Xraw_OBJECTS) $(ioctl_v4l2_v_Xraw_LDADD) $(LIBS)
+
+ioctl_v4l2-v-Xverbose$(EXEEXT): $(ioctl_v4l2_v_Xverbose_OBJECTS) $(ioctl_v4l2_v_Xverbose_DEPENDENCIES) $(EXTRA_ioctl_v4l2_v_Xverbose_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-v-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_v_Xverbose_OBJECTS) $(ioctl_v4l2_v_Xverbose_LDADD) $(LIBS)
+
 ioctl_watchdog$(EXEEXT): $(ioctl_watchdog_OBJECTS) $(ioctl_watchdog_DEPENDENCIES) $(EXTRA_ioctl_watchdog_DEPENDENCIES) 
 	@rm -f ioctl_watchdog$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioctl_watchdog_OBJECTS) $(ioctl_watchdog_LDADD) $(LIBS)
@@ -6517,6 +8095,10 @@ ioprio$(EXEEXT): $(ioprio_OBJECTS) $(iop
 	@rm -f ioprio$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioprio_OBJECTS) $(ioprio_LDADD) $(LIBS)
 
+ioprio--pidns-translation$(EXEEXT): $(ioprio__pidns_translation_OBJECTS) $(ioprio__pidns_translation_DEPENDENCIES) $(EXTRA_ioprio__pidns_translation_DEPENDENCIES) 
+	@rm -f ioprio--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioprio__pidns_translation_OBJECTS) $(ioprio__pidns_translation_LDADD) $(LIBS)
+
 ioprio-Xabbrev$(EXEEXT): $(ioprio_Xabbrev_OBJECTS) $(ioprio_Xabbrev_DEPENDENCIES) $(EXTRA_ioprio_Xabbrev_DEPENDENCIES) 
 	@rm -f ioprio-Xabbrev$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioprio_Xabbrev_OBJECTS) $(ioprio_Xabbrev_LDADD) $(LIBS)
@@ -6613,6 +8195,10 @@ kcmp-y$(EXEEXT): $(kcmp_y_OBJECTS) $(kcm
 	@rm -f kcmp-y$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(kcmp_y_OBJECTS) $(kcmp_y_LDADD) $(LIBS)
 
+kcmp-y--pidns-translation$(EXEEXT): $(kcmp_y__pidns_translation_OBJECTS) $(kcmp_y__pidns_translation_DEPENDENCIES) $(EXTRA_kcmp_y__pidns_translation_DEPENDENCIES) 
+	@rm -f kcmp-y--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(kcmp_y__pidns_translation_OBJECTS) $(kcmp_y__pidns_translation_LDADD) $(LIBS)
+
 kern_features$(EXEEXT): $(kern_features_OBJECTS) $(kern_features_DEPENDENCIES) $(EXTRA_kern_features_DEPENDENCIES) 
 	@rm -f kern_features$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(kern_features_OBJECTS) $(kern_features_LDADD) $(LIBS)
@@ -6661,6 +8247,10 @@ kill$(EXEEXT): $(kill_OBJECTS) $(kill_DE
 	@rm -f kill$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(kill_OBJECTS) $(kill_LDADD) $(LIBS)
 
+kill--pidns-translation$(EXEEXT): $(kill__pidns_translation_OBJECTS) $(kill__pidns_translation_DEPENDENCIES) $(EXTRA_kill__pidns_translation_DEPENDENCIES) 
+	@rm -f kill--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(kill__pidns_translation_OBJECTS) $(kill__pidns_translation_LDADD) $(LIBS)
+
 kill_child$(EXEEXT): $(kill_child_OBJECTS) $(kill_child_DEPENDENCIES) $(EXTRA_kill_child_DEPENDENCIES) 
 	@rm -f kill_child$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(kill_child_OBJECTS) $(kill_child_LDADD) $(LIBS)
@@ -6725,6 +8315,10 @@ maybe_switch_current_tcp$(EXEEXT): $(may
 	@rm -f maybe_switch_current_tcp$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(maybe_switch_current_tcp_OBJECTS) $(maybe_switch_current_tcp_LDADD) $(LIBS)
 
+maybe_switch_current_tcp--quiet-thread-execve$(EXEEXT): $(maybe_switch_current_tcp__quiet_thread_execve_OBJECTS) $(maybe_switch_current_tcp__quiet_thread_execve_DEPENDENCIES) $(EXTRA_maybe_switch_current_tcp__quiet_thread_execve_DEPENDENCIES) 
+	@rm -f maybe_switch_current_tcp--quiet-thread-execve$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(maybe_switch_current_tcp__quiet_thread_execve_OBJECTS) $(maybe_switch_current_tcp__quiet_thread_execve_LDADD) $(LIBS)
+
 mbind$(EXEEXT): $(mbind_OBJECTS) $(mbind_DEPENDENCIES) $(EXTRA_mbind_DEPENDENCIES) 
 	@rm -f mbind$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(mbind_OBJECTS) $(mbind_LDADD) $(LIBS)
@@ -6765,6 +8359,10 @@ migrate_pages$(EXEEXT): $(migrate_pages_
 	@rm -f migrate_pages$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(migrate_pages_OBJECTS) $(migrate_pages_LDADD) $(LIBS)
 
+migrate_pages--pidns-translation$(EXEEXT): $(migrate_pages__pidns_translation_OBJECTS) $(migrate_pages__pidns_translation_DEPENDENCIES) $(EXTRA_migrate_pages__pidns_translation_DEPENDENCIES) 
+	@rm -f migrate_pages--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(migrate_pages__pidns_translation_OBJECTS) $(migrate_pages__pidns_translation_LDADD) $(LIBS)
+
 mincore$(EXEEXT): $(mincore_OBJECTS) $(mincore_DEPENDENCIES) $(EXTRA_mincore_DEPENDENCIES) 
 	@rm -f mincore$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(mincore_OBJECTS) $(mincore_LDADD) $(LIBS)
@@ -6877,6 +8475,10 @@ move_pages$(EXEEXT): $(move_pages_OBJECT
 	@rm -f move_pages$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(move_pages_OBJECTS) $(move_pages_LDADD) $(LIBS)
 
+move_pages--pidns-translation$(EXEEXT): $(move_pages__pidns_translation_OBJECTS) $(move_pages__pidns_translation_DEPENDENCIES) $(EXTRA_move_pages__pidns_translation_DEPENDENCIES) 
+	@rm -f move_pages--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(move_pages__pidns_translation_OBJECTS) $(move_pages__pidns_translation_LDADD) $(LIBS)
+
 move_pages-Xabbrev$(EXEEXT): $(move_pages_Xabbrev_OBJECTS) $(move_pages_Xabbrev_DEPENDENCIES) $(EXTRA_move_pages_Xabbrev_DEPENDENCIES) 
 	@rm -f move_pages-Xabbrev$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(move_pages_Xabbrev_OBJECTS) $(move_pages_Xabbrev_LDADD) $(LIBS)
@@ -6925,6 +8527,22 @@ nanosleep$(EXEEXT): $(nanosleep_OBJECTS)
 	@rm -f nanosleep$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(nanosleep_OBJECTS) $(nanosleep_LDADD) $(LIBS)
 
+net--decode-fds-dev-netlink$(EXEEXT): $(net__decode_fds_dev_netlink_OBJECTS) $(net__decode_fds_dev_netlink_DEPENDENCIES) $(EXTRA_net__decode_fds_dev_netlink_DEPENDENCIES) 
+	@rm -f net--decode-fds-dev-netlink$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(net__decode_fds_dev_netlink_OBJECTS) $(net__decode_fds_dev_netlink_LDADD) $(LIBS)
+
+net--decode-fds-none-netlink$(EXEEXT): $(net__decode_fds_none_netlink_OBJECTS) $(net__decode_fds_none_netlink_DEPENDENCIES) $(EXTRA_net__decode_fds_none_netlink_DEPENDENCIES) 
+	@rm -f net--decode-fds-none-netlink$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(net__decode_fds_none_netlink_OBJECTS) $(net__decode_fds_none_netlink_LDADD) $(LIBS)
+
+net--decode-fds-path-netlink$(EXEEXT): $(net__decode_fds_path_netlink_OBJECTS) $(net__decode_fds_path_netlink_DEPENDENCIES) $(EXTRA_net__decode_fds_path_netlink_DEPENDENCIES) 
+	@rm -f net--decode-fds-path-netlink$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(net__decode_fds_path_netlink_OBJECTS) $(net__decode_fds_path_netlink_LDADD) $(LIBS)
+
+net--decode-fds-socket-netlink$(EXEEXT): $(net__decode_fds_socket_netlink_OBJECTS) $(net__decode_fds_socket_netlink_DEPENDENCIES) $(EXTRA_net__decode_fds_socket_netlink_DEPENDENCIES) 
+	@rm -f net--decode-fds-socket-netlink$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(net__decode_fds_socket_netlink_OBJECTS) $(net__decode_fds_socket_netlink_LDADD) $(LIBS)
+
 net-accept-connect$(EXEEXT): $(net_accept_connect_OBJECTS) $(net_accept_connect_DEPENDENCIES) $(EXTRA_net_accept_connect_DEPENDENCIES) 
 	@rm -f net-accept-connect$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(net_accept_connect_OBJECTS) $(net_accept_connect_LDADD) $(LIBS)
@@ -6953,6 +8571,10 @@ net-sockaddr$(EXEEXT): $(net_sockaddr_OB
 	@rm -f net-sockaddr$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(net_sockaddr_OBJECTS) $(net_sockaddr_LDADD) $(LIBS)
 
+net-sockaddr--pidns-translation$(EXEEXT): $(net_sockaddr__pidns_translation_OBJECTS) $(net_sockaddr__pidns_translation_DEPENDENCIES) $(EXTRA_net_sockaddr__pidns_translation_DEPENDENCIES) 
+	@rm -f net-sockaddr--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(net_sockaddr__pidns_translation_OBJECTS) $(net_sockaddr__pidns_translation_LDADD) $(LIBS)
+
 net-tpacket_req$(EXEEXT): $(net_tpacket_req_OBJECTS) $(net_tpacket_req_DEPENDENCIES) $(EXTRA_net_tpacket_req_DEPENDENCIES) 
 	@rm -f net-tpacket_req$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(net_tpacket_req_OBJECTS) $(net_tpacket_req_LDADD) $(LIBS)
@@ -6989,6 +8611,10 @@ netlink_audit$(EXEEXT): $(netlink_audit_
 	@rm -f netlink_audit$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(netlink_audit_OBJECTS) $(netlink_audit_LDADD) $(LIBS)
 
+netlink_audit--pidns-translation$(EXEEXT): $(netlink_audit__pidns_translation_OBJECTS) $(netlink_audit__pidns_translation_DEPENDENCIES) $(EXTRA_netlink_audit__pidns_translation_DEPENDENCIES) 
+	@rm -f netlink_audit--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(netlink_audit__pidns_translation_OBJECTS) $(netlink_audit__pidns_translation_LDADD) $(LIBS)
+
 netlink_crypto$(EXEEXT): $(netlink_crypto_OBJECTS) $(netlink_crypto_DEPENDENCIES) $(EXTRA_netlink_crypto_DEPENDENCIES) 
 	@rm -f netlink_crypto$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(netlink_crypto_OBJECTS) $(netlink_crypto_LDADD) $(LIBS)
@@ -7137,6 +8763,10 @@ nlattr_ifla_xdp$(EXEEXT): $(nlattr_ifla_
 	@rm -f nlattr_ifla_xdp$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(nlattr_ifla_xdp_OBJECTS) $(nlattr_ifla_xdp_LDADD) $(LIBS)
 
+nlattr_ifla_xdp-y$(EXEEXT): $(nlattr_ifla_xdp_y_OBJECTS) $(nlattr_ifla_xdp_y_DEPENDENCIES) $(EXTRA_nlattr_ifla_xdp_y_DEPENDENCIES) 
+	@rm -f nlattr_ifla_xdp-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(nlattr_ifla_xdp_y_OBJECTS) $(nlattr_ifla_xdp_y_LDADD) $(LIBS)
+
 nlattr_inet_diag_msg$(EXEEXT): $(nlattr_inet_diag_msg_OBJECTS) $(nlattr_inet_diag_msg_DEPENDENCIES) $(EXTRA_nlattr_inet_diag_msg_DEPENDENCIES) 
 	@rm -f nlattr_inet_diag_msg$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(nlattr_inet_diag_msg_OBJECTS) $(nlattr_inet_diag_msg_LDADD) $(LIBS)
@@ -7289,6 +8919,46 @@ openat$(EXEEXT): $(openat_OBJECTS) $(ope
 	@rm -f openat$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(openat_OBJECTS) $(openat_LDADD) $(LIBS)
 
+openat2$(EXEEXT): $(openat2_OBJECTS) $(openat2_DEPENDENCIES) $(EXTRA_openat2_DEPENDENCIES) 
+	@rm -f openat2$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_OBJECTS) $(openat2_LDADD) $(LIBS)
+
+openat2-Xabbrev$(EXEEXT): $(openat2_Xabbrev_OBJECTS) $(openat2_Xabbrev_DEPENDENCIES) $(EXTRA_openat2_Xabbrev_DEPENDENCIES) 
+	@rm -f openat2-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_Xabbrev_OBJECTS) $(openat2_Xabbrev_LDADD) $(LIBS)
+
+openat2-Xraw$(EXEEXT): $(openat2_Xraw_OBJECTS) $(openat2_Xraw_DEPENDENCIES) $(EXTRA_openat2_Xraw_DEPENDENCIES) 
+	@rm -f openat2-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_Xraw_OBJECTS) $(openat2_Xraw_LDADD) $(LIBS)
+
+openat2-Xverbose$(EXEEXT): $(openat2_Xverbose_OBJECTS) $(openat2_Xverbose_DEPENDENCIES) $(EXTRA_openat2_Xverbose_DEPENDENCIES) 
+	@rm -f openat2-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_Xverbose_OBJECTS) $(openat2_Xverbose_LDADD) $(LIBS)
+
+openat2-v$(EXEEXT): $(openat2_v_OBJECTS) $(openat2_v_DEPENDENCIES) $(EXTRA_openat2_v_DEPENDENCIES) 
+	@rm -f openat2-v$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_v_OBJECTS) $(openat2_v_LDADD) $(LIBS)
+
+openat2-v-y$(EXEEXT): $(openat2_v_y_OBJECTS) $(openat2_v_y_DEPENDENCIES) $(EXTRA_openat2_v_y_DEPENDENCIES) 
+	@rm -f openat2-v-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_v_y_OBJECTS) $(openat2_v_y_LDADD) $(LIBS)
+
+openat2-v-y-Xabbrev$(EXEEXT): $(openat2_v_y_Xabbrev_OBJECTS) $(openat2_v_y_Xabbrev_DEPENDENCIES) $(EXTRA_openat2_v_y_Xabbrev_DEPENDENCIES) 
+	@rm -f openat2-v-y-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_v_y_Xabbrev_OBJECTS) $(openat2_v_y_Xabbrev_LDADD) $(LIBS)
+
+openat2-v-y-Xraw$(EXEEXT): $(openat2_v_y_Xraw_OBJECTS) $(openat2_v_y_Xraw_DEPENDENCIES) $(EXTRA_openat2_v_y_Xraw_DEPENDENCIES) 
+	@rm -f openat2-v-y-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_v_y_Xraw_OBJECTS) $(openat2_v_y_Xraw_LDADD) $(LIBS)
+
+openat2-v-y-Xverbose$(EXEEXT): $(openat2_v_y_Xverbose_OBJECTS) $(openat2_v_y_Xverbose_DEPENDENCIES) $(EXTRA_openat2_v_y_Xverbose_DEPENDENCIES) 
+	@rm -f openat2-v-y-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_v_y_Xverbose_OBJECTS) $(openat2_v_y_Xverbose_LDADD) $(LIBS)
+
+openat2-y$(EXEEXT): $(openat2_y_OBJECTS) $(openat2_y_DEPENDENCIES) $(EXTRA_openat2_y_DEPENDENCIES) 
+	@rm -f openat2-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_y_OBJECTS) $(openat2_y_LDADD) $(LIBS)
+
 orphaned_process_group$(EXEEXT): $(orphaned_process_group_OBJECTS) $(orphaned_process_group_DEPENDENCIES) $(EXTRA_orphaned_process_group_DEPENDENCIES) 
 	@rm -f orphaned_process_group$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(orphaned_process_group_OBJECTS) $(orphaned_process_group_LDADD) $(LIBS)
@@ -7333,10 +9003,38 @@ personality-Xverbose$(EXEEXT): $(persona
 	@rm -f personality-Xverbose$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(personality_Xverbose_OBJECTS) $(personality_Xverbose_LDADD) $(LIBS)
 
+pidfd_getfd$(EXEEXT): $(pidfd_getfd_OBJECTS) $(pidfd_getfd_DEPENDENCIES) $(EXTRA_pidfd_getfd_DEPENDENCIES) 
+	@rm -f pidfd_getfd$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_getfd_OBJECTS) $(pidfd_getfd_LDADD) $(LIBS)
+
+pidfd_getfd-y$(EXEEXT): $(pidfd_getfd_y_OBJECTS) $(pidfd_getfd_y_DEPENDENCIES) $(EXTRA_pidfd_getfd_y_DEPENDENCIES) 
+	@rm -f pidfd_getfd-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_getfd_y_OBJECTS) $(pidfd_getfd_y_LDADD) $(LIBS)
+
+pidfd_getfd-yy$(EXEEXT): $(pidfd_getfd_yy_OBJECTS) $(pidfd_getfd_yy_DEPENDENCIES) $(EXTRA_pidfd_getfd_yy_DEPENDENCIES) 
+	@rm -f pidfd_getfd-yy$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_getfd_yy_OBJECTS) $(pidfd_getfd_yy_LDADD) $(LIBS)
+
 pidfd_open$(EXEEXT): $(pidfd_open_OBJECTS) $(pidfd_open_DEPENDENCIES) $(EXTRA_pidfd_open_DEPENDENCIES) 
 	@rm -f pidfd_open$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(pidfd_open_OBJECTS) $(pidfd_open_LDADD) $(LIBS)
 
+pidfd_open--decode-fd-path$(EXEEXT): $(pidfd_open__decode_fd_path_OBJECTS) $(pidfd_open__decode_fd_path_DEPENDENCIES) $(EXTRA_pidfd_open__decode_fd_path_DEPENDENCIES) 
+	@rm -f pidfd_open--decode-fd-path$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_open__decode_fd_path_OBJECTS) $(pidfd_open__decode_fd_path_LDADD) $(LIBS)
+
+pidfd_open--decode-fd-pidfd$(EXEEXT): $(pidfd_open__decode_fd_pidfd_OBJECTS) $(pidfd_open__decode_fd_pidfd_DEPENDENCIES) $(EXTRA_pidfd_open__decode_fd_pidfd_DEPENDENCIES) 
+	@rm -f pidfd_open--decode-fd-pidfd$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_open__decode_fd_pidfd_OBJECTS) $(pidfd_open__decode_fd_pidfd_LDADD) $(LIBS)
+
+pidfd_open--decode-fd-socket$(EXEEXT): $(pidfd_open__decode_fd_socket_OBJECTS) $(pidfd_open__decode_fd_socket_DEPENDENCIES) $(EXTRA_pidfd_open__decode_fd_socket_DEPENDENCIES) 
+	@rm -f pidfd_open--decode-fd-socket$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_open__decode_fd_socket_OBJECTS) $(pidfd_open__decode_fd_socket_LDADD) $(LIBS)
+
+pidfd_open--pidns-translation$(EXEEXT): $(pidfd_open__pidns_translation_OBJECTS) $(pidfd_open__pidns_translation_DEPENDENCIES) $(EXTRA_pidfd_open__pidns_translation_DEPENDENCIES) 
+	@rm -f pidfd_open--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_open__pidns_translation_OBJECTS) $(pidfd_open__pidns_translation_LDADD) $(LIBS)
+
 pidfd_open-P$(EXEEXT): $(pidfd_open_P_OBJECTS) $(pidfd_open_P_DEPENDENCIES) $(EXTRA_pidfd_open_P_DEPENDENCIES) 
 	@rm -f pidfd_open-P$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(pidfd_open_P_OBJECTS) $(pidfd_open_P_LDADD) $(LIBS)
@@ -7345,10 +9043,22 @@ pidfd_open-y$(EXEEXT): $(pidfd_open_y_OB
 	@rm -f pidfd_open-y$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(pidfd_open_y_OBJECTS) $(pidfd_open_y_LDADD) $(LIBS)
 
+pidfd_open-yy$(EXEEXT): $(pidfd_open_yy_OBJECTS) $(pidfd_open_yy_DEPENDENCIES) $(EXTRA_pidfd_open_yy_DEPENDENCIES) 
+	@rm -f pidfd_open-yy$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_open_yy_OBJECTS) $(pidfd_open_yy_LDADD) $(LIBS)
+
 pidfd_send_signal$(EXEEXT): $(pidfd_send_signal_OBJECTS) $(pidfd_send_signal_DEPENDENCIES) $(EXTRA_pidfd_send_signal_DEPENDENCIES) 
 	@rm -f pidfd_send_signal$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(pidfd_send_signal_OBJECTS) $(pidfd_send_signal_LDADD) $(LIBS)
 
+pidfd_send_signal--pidns-translation$(EXEEXT): $(pidfd_send_signal__pidns_translation_OBJECTS) $(pidfd_send_signal__pidns_translation_DEPENDENCIES) $(EXTRA_pidfd_send_signal__pidns_translation_DEPENDENCIES) 
+	@rm -f pidfd_send_signal--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_send_signal__pidns_translation_OBJECTS) $(pidfd_send_signal__pidns_translation_LDADD) $(LIBS)
+
+pidns-cache$(EXEEXT): $(pidns_cache_OBJECTS) $(pidns_cache_DEPENDENCIES) $(EXTRA_pidns_cache_DEPENDENCIES) 
+	@rm -f pidns-cache$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidns_cache_OBJECTS) $(pidns_cache_LDADD) $(LIBS)
+
 pipe$(EXEEXT): $(pipe_OBJECTS) $(pipe_DEPENDENCIES) $(EXTRA_pipe_DEPENDENCIES) 
 	@rm -f pipe$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(pipe_OBJECTS) $(pipe_LDADD) $(LIBS)
@@ -7453,6 +9163,10 @@ print_maxfd$(EXEEXT): $(print_maxfd_OBJE
 	@rm -f print_maxfd$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(print_maxfd_OBJECTS) $(print_maxfd_LDADD) $(LIBS)
 
+print_ppid_tracerpid$(EXEEXT): $(print_ppid_tracerpid_OBJECTS) $(print_ppid_tracerpid_DEPENDENCIES) $(EXTRA_print_ppid_tracerpid_DEPENDENCIES) 
+	@rm -f print_ppid_tracerpid$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(print_ppid_tracerpid_OBJECTS) $(print_ppid_tracerpid_LDADD) $(LIBS)
+
 printpath-umovestr$(EXEEXT): $(printpath_umovestr_OBJECTS) $(printpath_umovestr_DEPENDENCIES) $(EXTRA_printpath_umovestr_DEPENDENCIES) 
 	@rm -f printpath-umovestr$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(printpath_umovestr_OBJECTS) $(printpath_umovestr_LDADD) $(LIBS)
@@ -7497,14 +9211,26 @@ prlimit64$(EXEEXT): $(prlimit64_OBJECTS)
 	@rm -f prlimit64$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(prlimit64_OBJECTS) $(prlimit64_LDADD) $(LIBS)
 
+prlimit64--pidns-translation$(EXEEXT): $(prlimit64__pidns_translation_OBJECTS) $(prlimit64__pidns_translation_DEPENDENCIES) $(EXTRA_prlimit64__pidns_translation_DEPENDENCIES) 
+	@rm -f prlimit64--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(prlimit64__pidns_translation_OBJECTS) $(prlimit64__pidns_translation_LDADD) $(LIBS)
+
 process_vm_readv$(EXEEXT): $(process_vm_readv_OBJECTS) $(process_vm_readv_DEPENDENCIES) $(EXTRA_process_vm_readv_DEPENDENCIES) 
 	@rm -f process_vm_readv$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(process_vm_readv_OBJECTS) $(process_vm_readv_LDADD) $(LIBS)
 
+process_vm_readv--pidns-translation$(EXEEXT): $(process_vm_readv__pidns_translation_OBJECTS) $(process_vm_readv__pidns_translation_DEPENDENCIES) $(EXTRA_process_vm_readv__pidns_translation_DEPENDENCIES) 
+	@rm -f process_vm_readv--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(process_vm_readv__pidns_translation_OBJECTS) $(process_vm_readv__pidns_translation_LDADD) $(LIBS)
+
 process_vm_writev$(EXEEXT): $(process_vm_writev_OBJECTS) $(process_vm_writev_DEPENDENCIES) $(EXTRA_process_vm_writev_DEPENDENCIES) 
 	@rm -f process_vm_writev$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(process_vm_writev_OBJECTS) $(process_vm_writev_LDADD) $(LIBS)
 
+process_vm_writev--pidns-translation$(EXEEXT): $(process_vm_writev__pidns_translation_OBJECTS) $(process_vm_writev__pidns_translation_DEPENDENCIES) $(EXTRA_process_vm_writev__pidns_translation_DEPENDENCIES) 
+	@rm -f process_vm_writev--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(process_vm_writev__pidns_translation_OBJECTS) $(process_vm_writev__pidns_translation_LDADD) $(LIBS)
+
 pselect6$(EXEEXT): $(pselect6_OBJECTS) $(pselect6_DEPENDENCIES) $(EXTRA_pselect6_DEPENDENCIES) 
 	@rm -f pselect6$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(pselect6_OBJECTS) $(pselect6_LDADD) $(LIBS)
@@ -7697,6 +9423,10 @@ rt_sigqueueinfo$(EXEEXT): $(rt_sigqueuei
 	@rm -f rt_sigqueueinfo$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(rt_sigqueueinfo_OBJECTS) $(rt_sigqueueinfo_LDADD) $(LIBS)
 
+rt_sigqueueinfo--pidns-translation$(EXEEXT): $(rt_sigqueueinfo__pidns_translation_OBJECTS) $(rt_sigqueueinfo__pidns_translation_DEPENDENCIES) $(EXTRA_rt_sigqueueinfo__pidns_translation_DEPENDENCIES) 
+	@rm -f rt_sigqueueinfo--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(rt_sigqueueinfo__pidns_translation_OBJECTS) $(rt_sigqueueinfo__pidns_translation_LDADD) $(LIBS)
+
 rt_sigreturn$(EXEEXT): $(rt_sigreturn_OBJECTS) $(rt_sigreturn_DEPENDENCIES) $(EXTRA_rt_sigreturn_DEPENDENCIES) 
 	@rm -f rt_sigreturn$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(rt_sigreturn_OBJECTS) $(rt_sigreturn_LDADD) $(LIBS)
@@ -7713,6 +9443,10 @@ rt_tgsigqueueinfo$(EXEEXT): $(rt_tgsigqu
 	@rm -f rt_tgsigqueueinfo$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(rt_tgsigqueueinfo_OBJECTS) $(rt_tgsigqueueinfo_LDADD) $(LIBS)
 
+rt_tgsigqueueinfo--pidns-translation$(EXEEXT): $(rt_tgsigqueueinfo__pidns_translation_OBJECTS) $(rt_tgsigqueueinfo__pidns_translation_DEPENDENCIES) $(EXTRA_rt_tgsigqueueinfo__pidns_translation_DEPENDENCIES) 
+	@rm -f rt_tgsigqueueinfo--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(rt_tgsigqueueinfo__pidns_translation_OBJECTS) $(rt_tgsigqueueinfo__pidns_translation_LDADD) $(LIBS)
+
 run_expect_termsig$(EXEEXT): $(run_expect_termsig_OBJECTS) $(run_expect_termsig_DEPENDENCIES) $(EXTRA_run_expect_termsig_DEPENDENCIES) 
 	@rm -f run_expect_termsig$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(run_expect_termsig_OBJECTS) $(run_expect_termsig_LDADD) $(LIBS)
@@ -7753,18 +9487,34 @@ sched_xetaffinity$(EXEEXT): $(sched_xeta
 	@rm -f sched_xetaffinity$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(sched_xetaffinity_OBJECTS) $(sched_xetaffinity_LDADD) $(LIBS)
 
+sched_xetaffinity--pidns-translation$(EXEEXT): $(sched_xetaffinity__pidns_translation_OBJECTS) $(sched_xetaffinity__pidns_translation_DEPENDENCIES) $(EXTRA_sched_xetaffinity__pidns_translation_DEPENDENCIES) 
+	@rm -f sched_xetaffinity--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(sched_xetaffinity__pidns_translation_OBJECTS) $(sched_xetaffinity__pidns_translation_LDADD) $(LIBS)
+
 sched_xetattr$(EXEEXT): $(sched_xetattr_OBJECTS) $(sched_xetattr_DEPENDENCIES) $(EXTRA_sched_xetattr_DEPENDENCIES) 
 	@rm -f sched_xetattr$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(sched_xetattr_OBJECTS) $(sched_xetattr_LDADD) $(LIBS)
 
+sched_xetattr--pidns-translation$(EXEEXT): $(sched_xetattr__pidns_translation_OBJECTS) $(sched_xetattr__pidns_translation_DEPENDENCIES) $(EXTRA_sched_xetattr__pidns_translation_DEPENDENCIES) 
+	@rm -f sched_xetattr--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(sched_xetattr__pidns_translation_OBJECTS) $(sched_xetattr__pidns_translation_LDADD) $(LIBS)
+
 sched_xetparam$(EXEEXT): $(sched_xetparam_OBJECTS) $(sched_xetparam_DEPENDENCIES) $(EXTRA_sched_xetparam_DEPENDENCIES) 
 	@rm -f sched_xetparam$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(sched_xetparam_OBJECTS) $(sched_xetparam_LDADD) $(LIBS)
 
+sched_xetparam--pidns-translation$(EXEEXT): $(sched_xetparam__pidns_translation_OBJECTS) $(sched_xetparam__pidns_translation_DEPENDENCIES) $(EXTRA_sched_xetparam__pidns_translation_DEPENDENCIES) 
+	@rm -f sched_xetparam--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(sched_xetparam__pidns_translation_OBJECTS) $(sched_xetparam__pidns_translation_LDADD) $(LIBS)
+
 sched_xetscheduler$(EXEEXT): $(sched_xetscheduler_OBJECTS) $(sched_xetscheduler_DEPENDENCIES) $(EXTRA_sched_xetscheduler_DEPENDENCIES) 
 	@rm -f sched_xetscheduler$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(sched_xetscheduler_OBJECTS) $(sched_xetscheduler_LDADD) $(LIBS)
 
+sched_xetscheduler--pidns-translation$(EXEEXT): $(sched_xetscheduler__pidns_translation_OBJECTS) $(sched_xetscheduler__pidns_translation_DEPENDENCIES) $(EXTRA_sched_xetscheduler__pidns_translation_DEPENDENCIES) 
+	@rm -f sched_xetscheduler--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(sched_xetscheduler__pidns_translation_OBJECTS) $(sched_xetscheduler__pidns_translation_LDADD) $(LIBS)
+
 sched_yield$(EXEEXT): $(sched_yield_OBJECTS) $(sched_yield_DEPENDENCIES) $(EXTRA_sched_yield_DEPENDENCIES) 
 	@rm -f sched_yield$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(sched_yield_OBJECTS) $(sched_yield_LDADD) $(LIBS)
@@ -7889,6 +9639,10 @@ setns$(EXEEXT): $(setns_OBJECTS) $(setns
 	@rm -f setns$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(setns_OBJECTS) $(setns_LDADD) $(LIBS)
 
+setpgrp-exec$(EXEEXT): $(setpgrp_exec_OBJECTS) $(setpgrp_exec_DEPENDENCIES) $(EXTRA_setpgrp_exec_DEPENDENCIES) 
+	@rm -f setpgrp-exec$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(setpgrp_exec_OBJECTS) $(setpgrp_exec_LDADD) $(LIBS)
+
 setregid$(EXEEXT): $(setregid_OBJECTS) $(setregid_DEPENDENCIES) $(EXTRA_setregid_DEPENDENCIES) 
 	@rm -f setregid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(setregid_OBJECTS) $(setregid_LDADD) $(LIBS)
@@ -7973,6 +9727,10 @@ signal_receive$(EXEEXT): $(signal_receiv
 	@rm -f signal_receive$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(signal_receive_OBJECTS) $(signal_receive_LDADD) $(LIBS)
 
+signal_receive--pidns-translation$(EXEEXT): $(signal_receive__pidns_translation_OBJECTS) $(signal_receive__pidns_translation_DEPENDENCIES) $(EXTRA_signal_receive__pidns_translation_DEPENDENCIES) 
+	@rm -f signal_receive--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(signal_receive__pidns_translation_OBJECTS) $(signal_receive__pidns_translation_LDADD) $(LIBS)
+
 signalfd4$(EXEEXT): $(signalfd4_OBJECTS) $(signalfd4_DEPENDENCIES) $(EXTRA_signalfd4_DEPENDENCIES) 
 	@rm -f signalfd4$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(signalfd4_OBJECTS) $(signalfd4_LDADD) $(LIBS)
@@ -8009,6 +9767,10 @@ so_peercred$(EXEEXT): $(so_peercred_OBJE
 	@rm -f so_peercred$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(so_peercred_OBJECTS) $(so_peercred_LDADD) $(LIBS)
 
+so_peercred--pidns-translation$(EXEEXT): $(so_peercred__pidns_translation_OBJECTS) $(so_peercred__pidns_translation_DEPENDENCIES) $(EXTRA_so_peercred__pidns_translation_DEPENDENCIES) 
+	@rm -f so_peercred--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(so_peercred__pidns_translation_OBJECTS) $(so_peercred__pidns_translation_LDADD) $(LIBS)
+
 so_peercred-Xabbrev$(EXEEXT): $(so_peercred_Xabbrev_OBJECTS) $(so_peercred_Xabbrev_DEPENDENCIES) $(EXTRA_so_peercred_Xabbrev_DEPENDENCIES) 
 	@rm -f so_peercred-Xabbrev$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(so_peercred_Xabbrev_OBJECTS) $(so_peercred_Xabbrev_LDADD) $(LIBS)
@@ -8101,6 +9863,14 @@ status-failed$(EXEEXT): $(status_failed_
 	@rm -f status-failed$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(status_failed_OBJECTS) $(status_failed_LDADD) $(LIBS)
 
+status-failed-long$(EXEEXT): $(status_failed_long_OBJECTS) $(status_failed_long_DEPENDENCIES) $(EXTRA_status_failed_long_DEPENDENCIES) 
+	@rm -f status-failed-long$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(status_failed_long_OBJECTS) $(status_failed_long_LDADD) $(LIBS)
+
+status-failed-status$(EXEEXT): $(status_failed_status_OBJECTS) $(status_failed_status_DEPENDENCIES) $(EXTRA_status_failed_status_DEPENDENCIES) 
+	@rm -f status-failed-status$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(status_failed_status_OBJECTS) $(status_failed_status_LDADD) $(LIBS)
+
 status-none$(EXEEXT): $(status_none_OBJECTS) $(status_none_DEPENDENCIES) $(EXTRA_status_none_DEPENDENCIES) 
 	@rm -f status-none$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(status_none_OBJECTS) $(status_none_LDADD) $(LIBS)
@@ -8117,6 +9887,14 @@ status-successful$(EXEEXT): $(status_suc
 	@rm -f status-successful$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(status_successful_OBJECTS) $(status_successful_LDADD) $(LIBS)
 
+status-successful-long$(EXEEXT): $(status_successful_long_OBJECTS) $(status_successful_long_DEPENDENCIES) $(EXTRA_status_successful_long_DEPENDENCIES) 
+	@rm -f status-successful-long$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(status_successful_long_OBJECTS) $(status_successful_long_LDADD) $(LIBS)
+
+status-successful-status$(EXEEXT): $(status_successful_status_OBJECTS) $(status_successful_status_DEPENDENCIES) $(EXTRA_status_successful_status_DEPENDENCIES) 
+	@rm -f status-successful-status$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(status_successful_status_OBJECTS) $(status_successful_status_LDADD) $(LIBS)
+
 status-unfinished$(EXEEXT): $(status_unfinished_OBJECTS) $(status_unfinished_DEPENDENCIES) $(EXTRA_status_unfinished_DEPENDENCIES) 
 	@rm -f status-unfinished$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(status_unfinished_OBJECTS) $(status_unfinished_LDADD) $(LIBS)
@@ -8129,6 +9907,30 @@ statx$(EXEEXT): $(statx_OBJECTS) $(statx
 	@rm -f statx$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(statx_OBJECTS) $(statx_LDADD) $(LIBS)
 
+strace--strings-in-hex$(EXEEXT): $(strace__strings_in_hex_OBJECTS) $(strace__strings_in_hex_DEPENDENCIES) $(EXTRA_strace__strings_in_hex_DEPENDENCIES) 
+	@rm -f strace--strings-in-hex$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(strace__strings_in_hex_OBJECTS) $(strace__strings_in_hex_LDADD) $(LIBS)
+
+strace--strings-in-hex-all$(EXEEXT): $(strace__strings_in_hex_all_OBJECTS) $(strace__strings_in_hex_all_DEPENDENCIES) $(EXTRA_strace__strings_in_hex_all_DEPENDENCIES) 
+	@rm -f strace--strings-in-hex-all$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(strace__strings_in_hex_all_OBJECTS) $(strace__strings_in_hex_all_LDADD) $(LIBS)
+
+strace--strings-in-hex-non-ascii$(EXEEXT): $(strace__strings_in_hex_non_ascii_OBJECTS) $(strace__strings_in_hex_non_ascii_DEPENDENCIES) $(EXTRA_strace__strings_in_hex_non_ascii_DEPENDENCIES) 
+	@rm -f strace--strings-in-hex-non-ascii$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(strace__strings_in_hex_non_ascii_OBJECTS) $(strace__strings_in_hex_non_ascii_LDADD) $(LIBS)
+
+strace-n$(EXEEXT): $(strace_n_OBJECTS) $(strace_n_DEPENDENCIES) $(EXTRA_strace_n_DEPENDENCIES) 
+	@rm -f strace-n$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(strace_n_OBJECTS) $(strace_n_LDADD) $(LIBS)
+
+strace-x$(EXEEXT): $(strace_x_OBJECTS) $(strace_x_DEPENDENCIES) $(EXTRA_strace_x_DEPENDENCIES) 
+	@rm -f strace-x$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(strace_x_OBJECTS) $(strace_x_LDADD) $(LIBS)
+
+strace-xx$(EXEEXT): $(strace_xx_OBJECTS) $(strace_xx_DEPENDENCIES) $(EXTRA_strace_xx_DEPENDENCIES) 
+	@rm -f strace-xx$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(strace_xx_OBJECTS) $(strace_xx_LDADD) $(LIBS)
+
 swap$(EXEEXT): $(swap_OBJECTS) $(swap_DEPENDENCIES) $(EXTRA_swap_DEPENDENCIES) 
 	@rm -f swap$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(swap_OBJECTS) $(swap_LDADD) $(LIBS)
@@ -8173,10 +9975,34 @@ tee$(EXEEXT): $(tee_OBJECTS) $(tee_DEPEN
 	@rm -f tee$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(tee_OBJECTS) $(tee_LDADD) $(LIBS)
 
+tgkill$(EXEEXT): $(tgkill_OBJECTS) $(tgkill_DEPENDENCIES) $(EXTRA_tgkill_DEPENDENCIES) 
+	@rm -f tgkill$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(tgkill_OBJECTS) $(tgkill_LDADD) $(LIBS)
+
+tgkill--pidns-translation$(EXEEXT): $(tgkill__pidns_translation_OBJECTS) $(tgkill__pidns_translation_DEPENDENCIES) $(EXTRA_tgkill__pidns_translation_DEPENDENCIES) 
+	@rm -f tgkill--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(tgkill__pidns_translation_OBJECTS) $(tgkill__pidns_translation_LDADD) $(LIBS)
+
 threads-execve$(EXEEXT): $(threads_execve_OBJECTS) $(threads_execve_DEPENDENCIES) $(EXTRA_threads_execve_DEPENDENCIES) 
 	@rm -f threads-execve$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(threads_execve_OBJECTS) $(threads_execve_LDADD) $(LIBS)
 
+threads-execve--quiet-thread-execve$(EXEEXT): $(threads_execve__quiet_thread_execve_OBJECTS) $(threads_execve__quiet_thread_execve_DEPENDENCIES) $(EXTRA_threads_execve__quiet_thread_execve_DEPENDENCIES) 
+	@rm -f threads-execve--quiet-thread-execve$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(threads_execve__quiet_thread_execve_OBJECTS) $(threads_execve__quiet_thread_execve_LDADD) $(LIBS)
+
+threads-execve-q$(EXEEXT): $(threads_execve_q_OBJECTS) $(threads_execve_q_DEPENDENCIES) $(EXTRA_threads_execve_q_DEPENDENCIES) 
+	@rm -f threads-execve-q$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(threads_execve_q_OBJECTS) $(threads_execve_q_LDADD) $(LIBS)
+
+threads-execve-qq$(EXEEXT): $(threads_execve_qq_OBJECTS) $(threads_execve_qq_DEPENDENCIES) $(EXTRA_threads_execve_qq_DEPENDENCIES) 
+	@rm -f threads-execve-qq$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(threads_execve_qq_OBJECTS) $(threads_execve_qq_LDADD) $(LIBS)
+
+threads-execve-qqq$(EXEEXT): $(threads_execve_qqq_OBJECTS) $(threads_execve_qqq_DEPENDENCIES) $(EXTRA_threads_execve_qqq_DEPENDENCIES) 
+	@rm -f threads-execve-qqq$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(threads_execve_qqq_OBJECTS) $(threads_execve_qqq_LDADD) $(LIBS)
+
 time$(EXEEXT): $(time_OBJECTS) $(time_DEPENDENCIES) $(EXTRA_time_DEPENDENCIES) 
 	@rm -f time$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(time_OBJECTS) $(time_LDADD) $(LIBS)
@@ -8201,10 +10027,22 @@ times-fail$(EXEEXT): $(times_fail_OBJECT
 	@rm -f times-fail$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(times_fail_OBJECTS) $(times_fail_LDADD) $(LIBS)
 
+tkill$(EXEEXT): $(tkill_OBJECTS) $(tkill_DEPENDENCIES) $(EXTRA_tkill_DEPENDENCIES) 
+	@rm -f tkill$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(tkill_OBJECTS) $(tkill_LDADD) $(LIBS)
+
+tkill--pidns-translation$(EXEEXT): $(tkill__pidns_translation_OBJECTS) $(tkill__pidns_translation_DEPENDENCIES) $(EXTRA_tkill__pidns_translation_DEPENDENCIES) 
+	@rm -f tkill--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(tkill__pidns_translation_OBJECTS) $(tkill__pidns_translation_LDADD) $(LIBS)
+
 tracer_ppid_pgid_sid$(EXEEXT): $(tracer_ppid_pgid_sid_OBJECTS) $(tracer_ppid_pgid_sid_DEPENDENCIES) $(EXTRA_tracer_ppid_pgid_sid_DEPENDENCIES) 
 	@rm -f tracer_ppid_pgid_sid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(tracer_ppid_pgid_sid_OBJECTS) $(tracer_ppid_pgid_sid_LDADD) $(LIBS)
 
+trie_test$(EXEEXT): $(trie_test_OBJECTS) $(trie_test_DEPENDENCIES) $(EXTRA_trie_test_DEPENDENCIES) 
+	@rm -f trie_test$(EXEEXT)
+	$(AM_V_CCLD)$(trie_test_LINK) $(trie_test_OBJECTS) $(trie_test_LDADD) $(LIBS)
+
 truncate$(EXEEXT): $(truncate_OBJECTS) $(truncate_DEPENDENCIES) $(EXTRA_truncate_DEPENDENCIES) 
 	@rm -f truncate$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(truncate_OBJECTS) $(truncate_LDADD) $(LIBS)
@@ -8257,6 +10095,10 @@ umovestr_cached$(EXEEXT): $(umovestr_cac
 	@rm -f umovestr_cached$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(umovestr_cached_OBJECTS) $(umovestr_cached_LDADD) $(LIBS)
 
+umovestr_cached_adjacent$(EXEEXT): $(umovestr_cached_adjacent_OBJECTS) $(umovestr_cached_adjacent_DEPENDENCIES) $(EXTRA_umovestr_cached_adjacent_DEPENDENCIES) 
+	@rm -f umovestr_cached_adjacent$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(umovestr_cached_adjacent_OBJECTS) $(umovestr_cached_adjacent_LDADD) $(LIBS)
+
 uname$(EXEEXT): $(uname_OBJECTS) $(uname_DEPENDENCIES) $(EXTRA_uname_DEPENDENCIES) 
 	@rm -f uname$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(uname_OBJECTS) $(uname_LDADD) $(LIBS)
@@ -8361,6 +10203,10 @@ xet_robust_list$(EXEEXT): $(xet_robust_l
 	@rm -f xet_robust_list$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(xet_robust_list_OBJECTS) $(xet_robust_list_LDADD) $(LIBS)
 
+xet_robust_list--pidns-translation$(EXEEXT): $(xet_robust_list__pidns_translation_OBJECTS) $(xet_robust_list__pidns_translation_DEPENDENCIES) $(EXTRA_xet_robust_list__pidns_translation_DEPENDENCIES) 
+	@rm -f xet_robust_list--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(xet_robust_list__pidns_translation_OBJECTS) $(xet_robust_list__pidns_translation_LDADD) $(LIBS)
+
 xet_thread_area_x86$(EXEEXT): $(xet_thread_area_x86_OBJECTS) $(xet_thread_area_x86_DEPENDENCIES) $(EXTRA_xet_thread_area_x86_DEPENDENCIES) 
 	@rm -f xet_thread_area_x86$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(xet_thread_area_x86_OBJECTS) $(xet_thread_area_x86_LDADD) $(LIBS)
@@ -8373,10 +10219,18 @@ xetpgid$(EXEEXT): $(xetpgid_OBJECTS) $(x
 	@rm -f xetpgid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(xetpgid_OBJECTS) $(xetpgid_LDADD) $(LIBS)
 
+xetpgid--pidns-translation$(EXEEXT): $(xetpgid__pidns_translation_OBJECTS) $(xetpgid__pidns_translation_DEPENDENCIES) $(EXTRA_xetpgid__pidns_translation_DEPENDENCIES) 
+	@rm -f xetpgid--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(xetpgid__pidns_translation_OBJECTS) $(xetpgid__pidns_translation_LDADD) $(LIBS)
+
 xetpriority$(EXEEXT): $(xetpriority_OBJECTS) $(xetpriority_DEPENDENCIES) $(EXTRA_xetpriority_DEPENDENCIES) 
 	@rm -f xetpriority$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(xetpriority_OBJECTS) $(xetpriority_LDADD) $(LIBS)
 
+xetpriority--pidns-translation$(EXEEXT): $(xetpriority__pidns_translation_OBJECTS) $(xetpriority__pidns_translation_DEPENDENCIES) $(EXTRA_xetpriority__pidns_translation_DEPENDENCIES) 
+	@rm -f xetpriority--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(xetpriority__pidns_translation_OBJECTS) $(xetpriority__pidns_translation_LDADD) $(LIBS)
+
 xettimeofday$(EXEEXT): $(xettimeofday_OBJECTS) $(xettimeofday_DEPENDENCIES) $(EXTRA_xettimeofday_DEPENDENCIES) 
 	@rm -f xettimeofday$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(xettimeofday_OBJECTS) $(xettimeofday_LDADD) $(LIBS)
@@ -8413,6 +10267,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/bpf-obj_get_info_by_fd-prog.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/bpf-obj_get_info_by_fd-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/bpf-obj_get_info_by_fd.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/bpf-success-long-y.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/bpf-success-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/bpf-success.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/bpf-v.Po@am__quote@ # am--include-marker
@@ -8439,16 +10294,39 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone3-success-Xverbose.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone3-success.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone3.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_parent--quiet-exit.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_parent-q.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_parent-qq.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_parent.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_ptrace--quiet-attach.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_ptrace--quiet-exit.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_ptrace-q.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_ptrace-qq.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_ptrace.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/close_range-P.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/close_range-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/close_range-yy.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/close_range.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/copy_file_range.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/count-f.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/creat.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/delay.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/delete_module.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dev--decode-fds-dev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dev--decode-fds-path.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dev--decode-fds-socket.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dev-yy.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup-P.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup-yy.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup2-P.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup2-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup2-yy.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup2.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup3-P.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup3-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup3-yy.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup3.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/epoll_create.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/epoll_create1.Po@am__quote@ # am--include-marker
@@ -8461,7 +10339,14 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/execve.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/execveat-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/execveat.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/faccessat-P.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/faccessat-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/faccessat-yy.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/faccessat.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/faccessat2-P.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/faccessat2-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/faccessat2-yy.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/faccessat2.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fadvise64.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fadvise64_64.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fallocate.Po@am__quote@ # am--include-marker
@@ -8476,7 +10361,9 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fchown.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fchown32.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fchownat.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fcntl--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fcntl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fcntl64--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fcntl64.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fdatasync.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fflush.Po@am__quote@ # am--include-marker
@@ -8487,6 +10374,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/filter_seccomp-perf.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/finit_module.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/flock.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fork--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fork-f.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fsconfig-P.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fsconfig.Po@am__quote@ # am--include-marker
@@ -8512,9 +10400,12 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/futex.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/futimesat.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/get_mempolicy.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/get_process_reaper.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getcpu.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getcwd.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getdents-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getdents.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getdents64-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getdents64.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getegid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getegid32.Po@am__quote@ # am--include-marker
@@ -8525,7 +10416,9 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getgroups.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getgroups32.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getpeername.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getpgrp--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getpgrp.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getpid--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getpid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getppid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getrandom.Po@am__quote@ # am--include-marker
@@ -8535,12 +10428,16 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getresuid32.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getrlimit.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getrusage.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getsid--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getsid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getsockname.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/gettid--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/gettid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getuid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getuid32.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getxxid.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getxgid.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getxpid.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getxuid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/group_req.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/inet-cmsg.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/init_module.Po@am__quote@ # am--include-marker
@@ -8555,6 +10452,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/io_uring_register.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/io_uring_setup.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_block--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_block.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_dm-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_dm.Po@am__quote@ # am--include-marker
@@ -8574,6 +10472,22 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_evdev-v-Xverbose.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_evdev-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_evdev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-success-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-success-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-success-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-success-v-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-success-v-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-success-v-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-success-v.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-success.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-v-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-v-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-v-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-v.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_inotify.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_kvm_run-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_kvm_run.Po@am__quote@ # am--include-marker
@@ -8594,11 +10508,28 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_sg_io_v3.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_sg_io_v4.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_sock_gifconf.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_tee.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_uffdio.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-success-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-success-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-success-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-success-v-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-success-v-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-success-v-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-success-v.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-success.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-v-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-v-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-v-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_watchdog.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioperm.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/iopl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioprio--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioprio-Xabbrev.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioprio-Xraw.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioprio-Xverbose.Po@am__quote@ # am--include-marker
@@ -8622,6 +10553,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipc_shm-Xverbose.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipc_shm.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/is_linux_mips_n64.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/kcmp-y--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/kcmp-y.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/kcmp.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/kern_features.Po@am__quote@ # am--include-marker
@@ -8635,12 +10567,14 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/keyctl-Xraw.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/keyctl-Xverbose.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/keyctl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/kill--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/kill.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/kill_child.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ksysent.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/lchown.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/lchown32.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-create_nl_socket.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-create_tmpfile.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-errno2name.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-error_msg.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-fill_memory.Po@am__quote@ # am--include-marker
@@ -8654,6 +10588,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-libsocketcall.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-lock_file.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-overflowuid.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-pidns.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-pipe_maxfd.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-print_quoted_string.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-print_time.Po@am__quote@ # am--include-marker
@@ -8670,6 +10605,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-test_printstrn.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-test_ucopy.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-tprintf.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-xmalloc_for_tests.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/link.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/linkat.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/list_sigaction_signum.Po@am__quote@ # am--include-marker
@@ -8681,6 +10617,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/lstat.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/lstat64-lstat64.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/madvise.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/maybe_switch_current_tcp--quiet-thread-execve.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/maybe_switch_current_tcp.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/mbind-Xabbrev.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/mbind-Xraw.Po@am__quote@ # am--include-marker
@@ -8691,6 +10628,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/memfd_create-Xraw.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/memfd_create-Xverbose.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/memfd_create.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/migrate_pages--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/migrate_pages.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/mincore.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/mkdir.Po@am__quote@ # am--include-marker
@@ -8719,6 +10657,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/mount.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/move_mount-P.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/move_mount.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/move_pages--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/move_pages-Xabbrev.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/move_pages-Xraw.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/move_pages-Xverbose.Po@am__quote@ # am--include-marker
@@ -8732,12 +10671,17 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/msg_name.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/munlockall.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/nanosleep.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net--decode-fds-dev-netlink.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net--decode-fds-none-netlink.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net--decode-fds-path-netlink.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net--decode-fds-socket-netlink.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-accept-connect.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-icmp_filter.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-packet_mreq-Xabbrev.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-packet_mreq-Xraw.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-packet_mreq-Xverbose.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-packet_mreq.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-sockaddr--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-sockaddr.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-tpacket_req.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-tpacket_stats-success.Po@am__quote@ # am--include-marker
@@ -8747,6 +10691,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-yy-inet6.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-yy-netlink.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-yy-unix.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/netlink_audit--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/netlink_audit.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/netlink_crypto.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/netlink_generic.Po@am__quote@ # am--include-marker
@@ -8784,6 +10729,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/nlattr_ifla_brport.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/nlattr_ifla_linkinfo.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/nlattr_ifla_port.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/nlattr_ifla_xdp-y.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/nlattr_ifla_xdp.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/nlattr_inet_diag_msg.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/nlattr_inet_diag_req_compat.Po@am__quote@ # am--include-marker
@@ -8823,6 +10769,16 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/open_tree-P.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/open_tree.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-v-y-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-v-y-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-v-y-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-v-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-v.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/orphaned_process_group.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/osf_utimes.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pause.Po@am__quote@ # am--include-marker
@@ -8834,10 +10790,20 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/personality-Xraw.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/personality-Xverbose.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/personality.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_getfd-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_getfd-yy.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_getfd.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_open--decode-fd-path.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_open--decode-fd-pidfd.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_open--decode-fd-socket.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_open--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_open-P.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_open-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_open-yy.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_open.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_send_signal--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_send_signal.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidns-cache.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pipe.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pipe2.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pkey_alloc.Po@am__quote@ # am--include-marker
@@ -8864,6 +10830,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/preadv2-pwritev2.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/preadv_pwritev-preadv-pwritev.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/print_maxfd.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/print_ppid_tracerpid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/printpath-umovestr-peekdata.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/printpath-umovestr-undumpable.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/printpath-umovestr.Po@am__quote@ # am--include-marker
@@ -8874,8 +10841,11 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/printstrn-umoven-peekdata.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/printstrn-umoven-undumpable.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/printstrn-umoven.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/prlimit64--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/prlimit64.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/process_vm_readv--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/process_vm_readv.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/process_vm_writev--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/process_vm_writev.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pselect6.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ptrace.Po@am__quote@ # am--include-marker
@@ -8924,10 +10894,12 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_sigaction.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_sigpending.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_sigprocmask.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_sigqueueinfo--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_sigqueueinfo.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_sigreturn.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_sigsuspend.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_sigtimedwait.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_tgsigqueueinfo--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_tgsigqueueinfo.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/run_expect_termsig.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/s390_guarded_storage-v.Po@am__quote@ # am--include-marker
@@ -8938,9 +10910,13 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/s390_sthyi.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_get_priority_mxx.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_rr_get_interval.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_xetaffinity--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_xetaffinity.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_xetattr--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_xetattr.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_xetparam--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_xetparam.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_xetscheduler--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_xetscheduler.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_yield.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/scm_rights.Po@am__quote@ # am--include-marker
@@ -8973,6 +10949,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/setgroups32.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sethostname.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/setns.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/setpgrp-exec.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/setregid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/setregid32.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/setresgid.Po@am__quote@ # am--include-marker
@@ -8993,6 +10970,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sigaltstack.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/siginfo.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/signal.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/signal_receive--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/signal_receive.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/signalfd4.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sigpending.Po@am__quote@ # am--include-marker
@@ -9002,6 +10980,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sleep.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/so_error.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/so_linger.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/so_peercred--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/so_peercred-Xabbrev.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/so_peercred-Xraw.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/so_peercred-Xverbose.Po@am__quote@ # am--include-marker
@@ -9033,14 +11012,24 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/statfs-statfs.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/statfs64.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-all.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-failed-long.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-failed-status.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-failed.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-none-f.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-none-threads.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-none.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-successful-long.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-successful-status.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-successful.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-unfinished-threads.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-unfinished.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/statx.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace--strings-in-hex-all.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace--strings-in-hex-non-ascii.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace--strings-in-hex.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-n.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-x.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-xx.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/swap.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sxetmask.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/symlink.Po@am__quote@ # am--include-marker
@@ -9052,6 +11041,12 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/syslog-success.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/syslog.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/tee.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/tgkill--pidns-translation.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/tgkill.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/threads-execve--quiet-thread-execve.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/threads-execve-q.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/threads-execve-qq.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/threads-execve-qqq.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/threads-execve.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/time.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/timer_create.Po@am__quote@ # am--include-marker
@@ -9059,7 +11054,11 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/timerfd_xettime.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/times-fail.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/times.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/tkill--pidns-translation.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/tkill.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/tracer_ppid_pgid_sid.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/trie_test-trie_for_tests.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/trie_test-trie_test.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/truncate.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/truncate64-truncate64.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ugetrlimit.Po@am__quote@ # am--include-marker
@@ -9073,6 +11072,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/umovestr2.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/umovestr3.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/umovestr_cached.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/umovestr_cached_adjacent.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/uname.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/unblock_reset_raise.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/unix-pair-send-recv.Po@am__quote@ # am--include-marker
@@ -9098,10 +11098,13 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/waitpid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xattr-strings.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xattr.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xet_robust_list--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xet_robust_list.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xet_thread_area_x86.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xetitimer.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xetpgid--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xetpgid.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xetpriority--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xetpriority.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xettimeofday.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/zeroargc.Po@am__quote@ # am--include-marker
@@ -9142,6 +11145,20 @@ libtests_a-create_nl_socket.obj: create_
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
 @am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-create_nl_socket.obj `if test -f 'create_nl_socket.c'; then $(CYGPATH_W) 'create_nl_socket.c'; else $(CYGPATH_W) '$(srcdir)/create_nl_socket.c'; fi`
 
+libtests_a-create_tmpfile.o: create_tmpfile.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT libtests_a-create_tmpfile.o -MD -MP -MF $(DEPDIR)/libtests_a-create_tmpfile.Tpo -c -o libtests_a-create_tmpfile.o `test -f 'create_tmpfile.c' || echo '$(srcdir)/'`create_tmpfile.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libtests_a-create_tmpfile.Tpo $(DEPDIR)/libtests_a-create_tmpfile.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='create_tmpfile.c' object='libtests_a-create_tmpfile.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-create_tmpfile.o `test -f 'create_tmpfile.c' || echo '$(srcdir)/'`create_tmpfile.c
+
+libtests_a-create_tmpfile.obj: create_tmpfile.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT libtests_a-create_tmpfile.obj -MD -MP -MF $(DEPDIR)/libtests_a-create_tmpfile.Tpo -c -o libtests_a-create_tmpfile.obj `if test -f 'create_tmpfile.c'; then $(CYGPATH_W) 'create_tmpfile.c'; else $(CYGPATH_W) '$(srcdir)/create_tmpfile.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libtests_a-create_tmpfile.Tpo $(DEPDIR)/libtests_a-create_tmpfile.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='create_tmpfile.c' object='libtests_a-create_tmpfile.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-create_tmpfile.obj `if test -f 'create_tmpfile.c'; then $(CYGPATH_W) 'create_tmpfile.c'; else $(CYGPATH_W) '$(srcdir)/create_tmpfile.c'; fi`
+
 libtests_a-errno2name.o: errno2name.c
 @am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT libtests_a-errno2name.o -MD -MP -MF $(DEPDIR)/libtests_a-errno2name.Tpo -c -o libtests_a-errno2name.o `test -f 'errno2name.c' || echo '$(srcdir)/'`errno2name.c
 @am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libtests_a-errno2name.Tpo $(DEPDIR)/libtests_a-errno2name.Po
@@ -9324,6 +11341,20 @@ libtests_a-overflowuid.obj: overflowuid.
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
 @am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-overflowuid.obj `if test -f 'overflowuid.c'; then $(CYGPATH_W) 'overflowuid.c'; else $(CYGPATH_W) '$(srcdir)/overflowuid.c'; fi`
 
+libtests_a-pidns.o: pidns.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT libtests_a-pidns.o -MD -MP -MF $(DEPDIR)/libtests_a-pidns.Tpo -c -o libtests_a-pidns.o `test -f 'pidns.c' || echo '$(srcdir)/'`pidns.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libtests_a-pidns.Tpo $(DEPDIR)/libtests_a-pidns.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='pidns.c' object='libtests_a-pidns.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-pidns.o `test -f 'pidns.c' || echo '$(srcdir)/'`pidns.c
+
+libtests_a-pidns.obj: pidns.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT libtests_a-pidns.obj -MD -MP -MF $(DEPDIR)/libtests_a-pidns.Tpo -c -o libtests_a-pidns.obj `if test -f 'pidns.c'; then $(CYGPATH_W) 'pidns.c'; else $(CYGPATH_W) '$(srcdir)/pidns.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libtests_a-pidns.Tpo $(DEPDIR)/libtests_a-pidns.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='pidns.c' object='libtests_a-pidns.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-pidns.obj `if test -f 'pidns.c'; then $(CYGPATH_W) 'pidns.c'; else $(CYGPATH_W) '$(srcdir)/pidns.c'; fi`
+
 libtests_a-pipe_maxfd.o: pipe_maxfd.c
 @am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT libtests_a-pipe_maxfd.o -MD -MP -MF $(DEPDIR)/libtests_a-pipe_maxfd.Tpo -c -o libtests_a-pipe_maxfd.o `test -f 'pipe_maxfd.c' || echo '$(srcdir)/'`pipe_maxfd.c
 @am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libtests_a-pipe_maxfd.Tpo $(DEPDIR)/libtests_a-pipe_maxfd.Po
@@ -9548,6 +11579,20 @@ libtests_a-tprintf.obj: tprintf.c
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
 @am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-tprintf.obj `if test -f 'tprintf.c'; then $(CYGPATH_W) 'tprintf.c'; else $(CYGPATH_W) '$(srcdir)/tprintf.c'; fi`
 
+libtests_a-xmalloc_for_tests.o: xmalloc_for_tests.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT libtests_a-xmalloc_for_tests.o -MD -MP -MF $(DEPDIR)/libtests_a-xmalloc_for_tests.Tpo -c -o libtests_a-xmalloc_for_tests.o `test -f 'xmalloc_for_tests.c' || echo '$(srcdir)/'`xmalloc_for_tests.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libtests_a-xmalloc_for_tests.Tpo $(DEPDIR)/libtests_a-xmalloc_for_tests.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='xmalloc_for_tests.c' object='libtests_a-xmalloc_for_tests.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-xmalloc_for_tests.o `test -f 'xmalloc_for_tests.c' || echo '$(srcdir)/'`xmalloc_for_tests.c
+
+libtests_a-xmalloc_for_tests.obj: xmalloc_for_tests.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT libtests_a-xmalloc_for_tests.obj -MD -MP -MF $(DEPDIR)/libtests_a-xmalloc_for_tests.Tpo -c -o libtests_a-xmalloc_for_tests.obj `if test -f 'xmalloc_for_tests.c'; then $(CYGPATH_W) 'xmalloc_for_tests.c'; else $(CYGPATH_W) '$(srcdir)/xmalloc_for_tests.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libtests_a-xmalloc_for_tests.Tpo $(DEPDIR)/libtests_a-xmalloc_for_tests.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='xmalloc_for_tests.c' object='libtests_a-xmalloc_for_tests.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-xmalloc_for_tests.obj `if test -f 'xmalloc_for_tests.c'; then $(CYGPATH_W) 'xmalloc_for_tests.c'; else $(CYGPATH_W) '$(srcdir)/xmalloc_for_tests.c'; fi`
+
 fstat64-fstat64.o: fstat64.c
 @am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(fstat64_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT fstat64-fstat64.o -MD -MP -MF $(DEPDIR)/fstat64-fstat64.Tpo -c -o fstat64-fstat64.o `test -f 'fstat64.c' || echo '$(srcdir)/'`fstat64.c
 @am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/fstat64-fstat64.Tpo $(DEPDIR)/fstat64-fstat64.Po
@@ -9758,6 +11803,34 @@ statfs-statfs.obj: statfs.c
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
 @am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(statfs_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o statfs-statfs.obj `if test -f 'statfs.c'; then $(CYGPATH_W) 'statfs.c'; else $(CYGPATH_W) '$(srcdir)/statfs.c'; fi`
 
+trie_test-trie_test.o: trie_test.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(trie_test_CPPFLAGS) $(CPPFLAGS) $(trie_test_CFLAGS) $(CFLAGS) -MT trie_test-trie_test.o -MD -MP -MF $(DEPDIR)/trie_test-trie_test.Tpo -c -o trie_test-trie_test.o `test -f 'trie_test.c' || echo '$(srcdir)/'`trie_test.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/trie_test-trie_test.Tpo $(DEPDIR)/trie_test-trie_test.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='trie_test.c' object='trie_test-trie_test.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(trie_test_CPPFLAGS) $(CPPFLAGS) $(trie_test_CFLAGS) $(CFLAGS) -c -o trie_test-trie_test.o `test -f 'trie_test.c' || echo '$(srcdir)/'`trie_test.c
+
+trie_test-trie_test.obj: trie_test.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(trie_test_CPPFLAGS) $(CPPFLAGS) $(trie_test_CFLAGS) $(CFLAGS) -MT trie_test-trie_test.obj -MD -MP -MF $(DEPDIR)/trie_test-trie_test.Tpo -c -o trie_test-trie_test.obj `if test -f 'trie_test.c'; then $(CYGPATH_W) 'trie_test.c'; else $(CYGPATH_W) '$(srcdir)/trie_test.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/trie_test-trie_test.Tpo $(DEPDIR)/trie_test-trie_test.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='trie_test.c' object='trie_test-trie_test.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(trie_test_CPPFLAGS) $(CPPFLAGS) $(trie_test_CFLAGS) $(CFLAGS) -c -o trie_test-trie_test.obj `if test -f 'trie_test.c'; then $(CYGPATH_W) 'trie_test.c'; else $(CYGPATH_W) '$(srcdir)/trie_test.c'; fi`
+
+trie_test-trie_for_tests.o: trie_for_tests.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(trie_test_CPPFLAGS) $(CPPFLAGS) $(trie_test_CFLAGS) $(CFLAGS) -MT trie_test-trie_for_tests.o -MD -MP -MF $(DEPDIR)/trie_test-trie_for_tests.Tpo -c -o trie_test-trie_for_tests.o `test -f 'trie_for_tests.c' || echo '$(srcdir)/'`trie_for_tests.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/trie_test-trie_for_tests.Tpo $(DEPDIR)/trie_test-trie_for_tests.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='trie_for_tests.c' object='trie_test-trie_for_tests.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(trie_test_CPPFLAGS) $(CPPFLAGS) $(trie_test_CFLAGS) $(CFLAGS) -c -o trie_test-trie_for_tests.o `test -f 'trie_for_tests.c' || echo '$(srcdir)/'`trie_for_tests.c
+
+trie_test-trie_for_tests.obj: trie_for_tests.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(trie_test_CPPFLAGS) $(CPPFLAGS) $(trie_test_CFLAGS) $(CFLAGS) -MT trie_test-trie_for_tests.obj -MD -MP -MF $(DEPDIR)/trie_test-trie_for_tests.Tpo -c -o trie_test-trie_for_tests.obj `if test -f 'trie_for_tests.c'; then $(CYGPATH_W) 'trie_for_tests.c'; else $(CYGPATH_W) '$(srcdir)/trie_for_tests.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/trie_test-trie_for_tests.Tpo $(DEPDIR)/trie_test-trie_for_tests.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='trie_for_tests.c' object='trie_test-trie_for_tests.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(trie_test_CPPFLAGS) $(CPPFLAGS) $(trie_test_CFLAGS) $(CFLAGS) -c -o trie_test-trie_for_tests.obj `if test -f 'trie_for_tests.c'; then $(CYGPATH_W) 'trie_for_tests.c'; else $(CYGPATH_W) '$(srcdir)/trie_for_tests.c'; fi`
+
 truncate64-truncate64.o: truncate64.c
 @am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(truncate64_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT truncate64-truncate64.o -MD -MP -MF $(DEPDIR)/truncate64-truncate64.Tpo -c -o truncate64-truncate64.o `test -f 'truncate64.c' || echo '$(srcdir)/'`truncate64.c
 @am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/truncate64-truncate64.Tpo $(DEPDIR)/truncate64-truncate64.Po
@@ -9950,7 +12023,7 @@ $(TEST_SUITE_LOG): $(TEST_LOGS)
 	  test x"$$VERBOSE" = x || cat $(TEST_SUITE_LOG);		\
 	fi;								\
 	echo "$${col}$$br$${std}"; 					\
-	echo "$${col}Testsuite summary for $(PACKAGE_STRING)$${std}";	\
+	echo "$${col}Testsuite summary"$(AM_TESTSUITE_SUMMARY_HEADER)"$${std}";	\
 	echo "$${col}$$br$${std}"; 					\
 	create_testsuite_report --maybe-color;				\
 	echo "$$col$$br$$std";						\
@@ -10123,6 +12196,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/bpf-obj_get_info_by_fd-prog.Po
 	-rm -f ./$(DEPDIR)/bpf-obj_get_info_by_fd-v.Po
 	-rm -f ./$(DEPDIR)/bpf-obj_get_info_by_fd.Po
+	-rm -f ./$(DEPDIR)/bpf-success-long-y.Po
 	-rm -f ./$(DEPDIR)/bpf-success-v.Po
 	-rm -f ./$(DEPDIR)/bpf-success.Po
 	-rm -f ./$(DEPDIR)/bpf-v.Po
@@ -10149,16 +12223,39 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/clone3-success-Xverbose.Po
 	-rm -f ./$(DEPDIR)/clone3-success.Po
 	-rm -f ./$(DEPDIR)/clone3.Po
+	-rm -f ./$(DEPDIR)/clone_parent--quiet-exit.Po
+	-rm -f ./$(DEPDIR)/clone_parent-q.Po
+	-rm -f ./$(DEPDIR)/clone_parent-qq.Po
 	-rm -f ./$(DEPDIR)/clone_parent.Po
+	-rm -f ./$(DEPDIR)/clone_ptrace--quiet-attach.Po
+	-rm -f ./$(DEPDIR)/clone_ptrace--quiet-exit.Po
+	-rm -f ./$(DEPDIR)/clone_ptrace-q.Po
+	-rm -f ./$(DEPDIR)/clone_ptrace-qq.Po
 	-rm -f ./$(DEPDIR)/clone_ptrace.Po
+	-rm -f ./$(DEPDIR)/close_range-P.Po
+	-rm -f ./$(DEPDIR)/close_range-y.Po
+	-rm -f ./$(DEPDIR)/close_range-yy.Po
+	-rm -f ./$(DEPDIR)/close_range.Po
 	-rm -f ./$(DEPDIR)/copy_file_range.Po
 	-rm -f ./$(DEPDIR)/count-f.Po
 	-rm -f ./$(DEPDIR)/creat.Po
 	-rm -f ./$(DEPDIR)/delay.Po
 	-rm -f ./$(DEPDIR)/delete_module.Po
+	-rm -f ./$(DEPDIR)/dev--decode-fds-dev.Po
+	-rm -f ./$(DEPDIR)/dev--decode-fds-path.Po
+	-rm -f ./$(DEPDIR)/dev--decode-fds-socket.Po
 	-rm -f ./$(DEPDIR)/dev-yy.Po
+	-rm -f ./$(DEPDIR)/dup-P.Po
+	-rm -f ./$(DEPDIR)/dup-y.Po
+	-rm -f ./$(DEPDIR)/dup-yy.Po
 	-rm -f ./$(DEPDIR)/dup.Po
+	-rm -f ./$(DEPDIR)/dup2-P.Po
+	-rm -f ./$(DEPDIR)/dup2-y.Po
+	-rm -f ./$(DEPDIR)/dup2-yy.Po
 	-rm -f ./$(DEPDIR)/dup2.Po
+	-rm -f ./$(DEPDIR)/dup3-P.Po
+	-rm -f ./$(DEPDIR)/dup3-y.Po
+	-rm -f ./$(DEPDIR)/dup3-yy.Po
 	-rm -f ./$(DEPDIR)/dup3.Po
 	-rm -f ./$(DEPDIR)/epoll_create.Po
 	-rm -f ./$(DEPDIR)/epoll_create1.Po
@@ -10171,7 +12268,14 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/execve.Po
 	-rm -f ./$(DEPDIR)/execveat-v.Po
 	-rm -f ./$(DEPDIR)/execveat.Po
+	-rm -f ./$(DEPDIR)/faccessat-P.Po
+	-rm -f ./$(DEPDIR)/faccessat-y.Po
+	-rm -f ./$(DEPDIR)/faccessat-yy.Po
 	-rm -f ./$(DEPDIR)/faccessat.Po
+	-rm -f ./$(DEPDIR)/faccessat2-P.Po
+	-rm -f ./$(DEPDIR)/faccessat2-y.Po
+	-rm -f ./$(DEPDIR)/faccessat2-yy.Po
+	-rm -f ./$(DEPDIR)/faccessat2.Po
 	-rm -f ./$(DEPDIR)/fadvise64.Po
 	-rm -f ./$(DEPDIR)/fadvise64_64.Po
 	-rm -f ./$(DEPDIR)/fallocate.Po
@@ -10186,7 +12290,9 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/fchown.Po
 	-rm -f ./$(DEPDIR)/fchown32.Po
 	-rm -f ./$(DEPDIR)/fchownat.Po
+	-rm -f ./$(DEPDIR)/fcntl--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/fcntl.Po
+	-rm -f ./$(DEPDIR)/fcntl64--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/fcntl64.Po
 	-rm -f ./$(DEPDIR)/fdatasync.Po
 	-rm -f ./$(DEPDIR)/fflush.Po
@@ -10197,6 +12303,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/filter_seccomp-perf.Po
 	-rm -f ./$(DEPDIR)/finit_module.Po
 	-rm -f ./$(DEPDIR)/flock.Po
+	-rm -f ./$(DEPDIR)/fork--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/fork-f.Po
 	-rm -f ./$(DEPDIR)/fsconfig-P.Po
 	-rm -f ./$(DEPDIR)/fsconfig.Po
@@ -10222,9 +12329,12 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/futex.Po
 	-rm -f ./$(DEPDIR)/futimesat.Po
 	-rm -f ./$(DEPDIR)/get_mempolicy.Po
+	-rm -f ./$(DEPDIR)/get_process_reaper.Po
 	-rm -f ./$(DEPDIR)/getcpu.Po
 	-rm -f ./$(DEPDIR)/getcwd.Po
+	-rm -f ./$(DEPDIR)/getdents-v.Po
 	-rm -f ./$(DEPDIR)/getdents.Po
+	-rm -f ./$(DEPDIR)/getdents64-v.Po
 	-rm -f ./$(DEPDIR)/getdents64.Po
 	-rm -f ./$(DEPDIR)/getegid.Po
 	-rm -f ./$(DEPDIR)/getegid32.Po
@@ -10235,7 +12345,9 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/getgroups.Po
 	-rm -f ./$(DEPDIR)/getgroups32.Po
 	-rm -f ./$(DEPDIR)/getpeername.Po
+	-rm -f ./$(DEPDIR)/getpgrp--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/getpgrp.Po
+	-rm -f ./$(DEPDIR)/getpid--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/getpid.Po
 	-rm -f ./$(DEPDIR)/getppid.Po
 	-rm -f ./$(DEPDIR)/getrandom.Po
@@ -10245,12 +12357,16 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/getresuid32.Po
 	-rm -f ./$(DEPDIR)/getrlimit.Po
 	-rm -f ./$(DEPDIR)/getrusage.Po
+	-rm -f ./$(DEPDIR)/getsid--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/getsid.Po
 	-rm -f ./$(DEPDIR)/getsockname.Po
+	-rm -f ./$(DEPDIR)/gettid--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/gettid.Po
 	-rm -f ./$(DEPDIR)/getuid.Po
 	-rm -f ./$(DEPDIR)/getuid32.Po
-	-rm -f ./$(DEPDIR)/getxxid.Po
+	-rm -f ./$(DEPDIR)/getxgid.Po
+	-rm -f ./$(DEPDIR)/getxpid.Po
+	-rm -f ./$(DEPDIR)/getxuid.Po
 	-rm -f ./$(DEPDIR)/group_req.Po
 	-rm -f ./$(DEPDIR)/inet-cmsg.Po
 	-rm -f ./$(DEPDIR)/init_module.Po
@@ -10265,6 +12381,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/io_uring_register.Po
 	-rm -f ./$(DEPDIR)/io_uring_setup.Po
 	-rm -f ./$(DEPDIR)/ioctl.Po
+	-rm -f ./$(DEPDIR)/ioctl_block--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/ioctl_block.Po
 	-rm -f ./$(DEPDIR)/ioctl_dm-v.Po
 	-rm -f ./$(DEPDIR)/ioctl_dm.Po
@@ -10284,6 +12401,22 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/ioctl_evdev-v-Xverbose.Po
 	-rm -f ./$(DEPDIR)/ioctl_evdev-v.Po
 	-rm -f ./$(DEPDIR)/ioctl_evdev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-v-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-v-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-v-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-v.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-v-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-v-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-v-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-v.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio.Po
 	-rm -f ./$(DEPDIR)/ioctl_inotify.Po
 	-rm -f ./$(DEPDIR)/ioctl_kvm_run-v.Po
 	-rm -f ./$(DEPDIR)/ioctl_kvm_run.Po
@@ -10304,11 +12437,28 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/ioctl_sg_io_v3.Po
 	-rm -f ./$(DEPDIR)/ioctl_sg_io_v4.Po
 	-rm -f ./$(DEPDIR)/ioctl_sock_gifconf.Po
+	-rm -f ./$(DEPDIR)/ioctl_tee.Po
 	-rm -f ./$(DEPDIR)/ioctl_uffdio.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-v-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-v-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-v-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-v.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-v-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-v-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-v-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-v.Po
 	-rm -f ./$(DEPDIR)/ioctl_v4l2.Po
 	-rm -f ./$(DEPDIR)/ioctl_watchdog.Po
 	-rm -f ./$(DEPDIR)/ioperm.Po
 	-rm -f ./$(DEPDIR)/iopl.Po
+	-rm -f ./$(DEPDIR)/ioprio--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/ioprio-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/ioprio-Xraw.Po
 	-rm -f ./$(DEPDIR)/ioprio-Xverbose.Po
@@ -10332,6 +12482,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/ipc_shm-Xverbose.Po
 	-rm -f ./$(DEPDIR)/ipc_shm.Po
 	-rm -f ./$(DEPDIR)/is_linux_mips_n64.Po
+	-rm -f ./$(DEPDIR)/kcmp-y--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/kcmp-y.Po
 	-rm -f ./$(DEPDIR)/kcmp.Po
 	-rm -f ./$(DEPDIR)/kern_features.Po
@@ -10345,12 +12496,14 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/keyctl-Xraw.Po
 	-rm -f ./$(DEPDIR)/keyctl-Xverbose.Po
 	-rm -f ./$(DEPDIR)/keyctl.Po
+	-rm -f ./$(DEPDIR)/kill--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/kill.Po
 	-rm -f ./$(DEPDIR)/kill_child.Po
 	-rm -f ./$(DEPDIR)/ksysent.Po
 	-rm -f ./$(DEPDIR)/lchown.Po
 	-rm -f ./$(DEPDIR)/lchown32.Po
 	-rm -f ./$(DEPDIR)/libtests_a-create_nl_socket.Po
+	-rm -f ./$(DEPDIR)/libtests_a-create_tmpfile.Po
 	-rm -f ./$(DEPDIR)/libtests_a-errno2name.Po
 	-rm -f ./$(DEPDIR)/libtests_a-error_msg.Po
 	-rm -f ./$(DEPDIR)/libtests_a-fill_memory.Po
@@ -10364,6 +12517,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/libtests_a-libsocketcall.Po
 	-rm -f ./$(DEPDIR)/libtests_a-lock_file.Po
 	-rm -f ./$(DEPDIR)/libtests_a-overflowuid.Po
+	-rm -f ./$(DEPDIR)/libtests_a-pidns.Po
 	-rm -f ./$(DEPDIR)/libtests_a-pipe_maxfd.Po
 	-rm -f ./$(DEPDIR)/libtests_a-print_quoted_string.Po
 	-rm -f ./$(DEPDIR)/libtests_a-print_time.Po
@@ -10380,6 +12534,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/libtests_a-test_printstrn.Po
 	-rm -f ./$(DEPDIR)/libtests_a-test_ucopy.Po
 	-rm -f ./$(DEPDIR)/libtests_a-tprintf.Po
+	-rm -f ./$(DEPDIR)/libtests_a-xmalloc_for_tests.Po
 	-rm -f ./$(DEPDIR)/link.Po
 	-rm -f ./$(DEPDIR)/linkat.Po
 	-rm -f ./$(DEPDIR)/list_sigaction_signum.Po
@@ -10391,6 +12546,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/lstat.Po
 	-rm -f ./$(DEPDIR)/lstat64-lstat64.Po
 	-rm -f ./$(DEPDIR)/madvise.Po
+	-rm -f ./$(DEPDIR)/maybe_switch_current_tcp--quiet-thread-execve.Po
 	-rm -f ./$(DEPDIR)/maybe_switch_current_tcp.Po
 	-rm -f ./$(DEPDIR)/mbind-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/mbind-Xraw.Po
@@ -10401,6 +12557,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/memfd_create-Xraw.Po
 	-rm -f ./$(DEPDIR)/memfd_create-Xverbose.Po
 	-rm -f ./$(DEPDIR)/memfd_create.Po
+	-rm -f ./$(DEPDIR)/migrate_pages--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/migrate_pages.Po
 	-rm -f ./$(DEPDIR)/mincore.Po
 	-rm -f ./$(DEPDIR)/mkdir.Po
@@ -10429,6 +12586,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/mount.Po
 	-rm -f ./$(DEPDIR)/move_mount-P.Po
 	-rm -f ./$(DEPDIR)/move_mount.Po
+	-rm -f ./$(DEPDIR)/move_pages--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/move_pages-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/move_pages-Xraw.Po
 	-rm -f ./$(DEPDIR)/move_pages-Xverbose.Po
@@ -10442,12 +12600,17 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/msg_name.Po
 	-rm -f ./$(DEPDIR)/munlockall.Po
 	-rm -f ./$(DEPDIR)/nanosleep.Po
+	-rm -f ./$(DEPDIR)/net--decode-fds-dev-netlink.Po
+	-rm -f ./$(DEPDIR)/net--decode-fds-none-netlink.Po
+	-rm -f ./$(DEPDIR)/net--decode-fds-path-netlink.Po
+	-rm -f ./$(DEPDIR)/net--decode-fds-socket-netlink.Po
 	-rm -f ./$(DEPDIR)/net-accept-connect.Po
 	-rm -f ./$(DEPDIR)/net-icmp_filter.Po
 	-rm -f ./$(DEPDIR)/net-packet_mreq-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/net-packet_mreq-Xraw.Po
 	-rm -f ./$(DEPDIR)/net-packet_mreq-Xverbose.Po
 	-rm -f ./$(DEPDIR)/net-packet_mreq.Po
+	-rm -f ./$(DEPDIR)/net-sockaddr--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/net-sockaddr.Po
 	-rm -f ./$(DEPDIR)/net-tpacket_req.Po
 	-rm -f ./$(DEPDIR)/net-tpacket_stats-success.Po
@@ -10457,6 +12620,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/net-yy-inet6.Po
 	-rm -f ./$(DEPDIR)/net-yy-netlink.Po
 	-rm -f ./$(DEPDIR)/net-yy-unix.Po
+	-rm -f ./$(DEPDIR)/netlink_audit--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/netlink_audit.Po
 	-rm -f ./$(DEPDIR)/netlink_crypto.Po
 	-rm -f ./$(DEPDIR)/netlink_generic.Po
@@ -10494,6 +12658,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/nlattr_ifla_brport.Po
 	-rm -f ./$(DEPDIR)/nlattr_ifla_linkinfo.Po
 	-rm -f ./$(DEPDIR)/nlattr_ifla_port.Po
+	-rm -f ./$(DEPDIR)/nlattr_ifla_xdp-y.Po
 	-rm -f ./$(DEPDIR)/nlattr_ifla_xdp.Po
 	-rm -f ./$(DEPDIR)/nlattr_inet_diag_msg.Po
 	-rm -f ./$(DEPDIR)/nlattr_inet_diag_req_compat.Po
@@ -10533,6 +12698,16 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/open_tree-P.Po
 	-rm -f ./$(DEPDIR)/open_tree.Po
 	-rm -f ./$(DEPDIR)/openat.Po
+	-rm -f ./$(DEPDIR)/openat2-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/openat2-Xraw.Po
+	-rm -f ./$(DEPDIR)/openat2-Xverbose.Po
+	-rm -f ./$(DEPDIR)/openat2-v-y-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/openat2-v-y-Xraw.Po
+	-rm -f ./$(DEPDIR)/openat2-v-y-Xverbose.Po
+	-rm -f ./$(DEPDIR)/openat2-v-y.Po
+	-rm -f ./$(DEPDIR)/openat2-v.Po
+	-rm -f ./$(DEPDIR)/openat2-y.Po
+	-rm -f ./$(DEPDIR)/openat2.Po
 	-rm -f ./$(DEPDIR)/orphaned_process_group.Po
 	-rm -f ./$(DEPDIR)/osf_utimes.Po
 	-rm -f ./$(DEPDIR)/pause.Po
@@ -10544,10 +12719,20 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/personality-Xraw.Po
 	-rm -f ./$(DEPDIR)/personality-Xverbose.Po
 	-rm -f ./$(DEPDIR)/personality.Po
+	-rm -f ./$(DEPDIR)/pidfd_getfd-y.Po
+	-rm -f ./$(DEPDIR)/pidfd_getfd-yy.Po
+	-rm -f ./$(DEPDIR)/pidfd_getfd.Po
+	-rm -f ./$(DEPDIR)/pidfd_open--decode-fd-path.Po
+	-rm -f ./$(DEPDIR)/pidfd_open--decode-fd-pidfd.Po
+	-rm -f ./$(DEPDIR)/pidfd_open--decode-fd-socket.Po
+	-rm -f ./$(DEPDIR)/pidfd_open--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/pidfd_open-P.Po
 	-rm -f ./$(DEPDIR)/pidfd_open-y.Po
+	-rm -f ./$(DEPDIR)/pidfd_open-yy.Po
 	-rm -f ./$(DEPDIR)/pidfd_open.Po
+	-rm -f ./$(DEPDIR)/pidfd_send_signal--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/pidfd_send_signal.Po
+	-rm -f ./$(DEPDIR)/pidns-cache.Po
 	-rm -f ./$(DEPDIR)/pipe.Po
 	-rm -f ./$(DEPDIR)/pipe2.Po
 	-rm -f ./$(DEPDIR)/pkey_alloc.Po
@@ -10574,6 +12759,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/preadv2-pwritev2.Po
 	-rm -f ./$(DEPDIR)/preadv_pwritev-preadv-pwritev.Po
 	-rm -f ./$(DEPDIR)/print_maxfd.Po
+	-rm -f ./$(DEPDIR)/print_ppid_tracerpid.Po
 	-rm -f ./$(DEPDIR)/printpath-umovestr-peekdata.Po
 	-rm -f ./$(DEPDIR)/printpath-umovestr-undumpable.Po
 	-rm -f ./$(DEPDIR)/printpath-umovestr.Po
@@ -10584,8 +12770,11 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/printstrn-umoven-peekdata.Po
 	-rm -f ./$(DEPDIR)/printstrn-umoven-undumpable.Po
 	-rm -f ./$(DEPDIR)/printstrn-umoven.Po
+	-rm -f ./$(DEPDIR)/prlimit64--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/prlimit64.Po
+	-rm -f ./$(DEPDIR)/process_vm_readv--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/process_vm_readv.Po
+	-rm -f ./$(DEPDIR)/process_vm_writev--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/process_vm_writev.Po
 	-rm -f ./$(DEPDIR)/pselect6.Po
 	-rm -f ./$(DEPDIR)/ptrace.Po
@@ -10634,10 +12823,12 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/rt_sigaction.Po
 	-rm -f ./$(DEPDIR)/rt_sigpending.Po
 	-rm -f ./$(DEPDIR)/rt_sigprocmask.Po
+	-rm -f ./$(DEPDIR)/rt_sigqueueinfo--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/rt_sigqueueinfo.Po
 	-rm -f ./$(DEPDIR)/rt_sigreturn.Po
 	-rm -f ./$(DEPDIR)/rt_sigsuspend.Po
 	-rm -f ./$(DEPDIR)/rt_sigtimedwait.Po
+	-rm -f ./$(DEPDIR)/rt_tgsigqueueinfo--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/rt_tgsigqueueinfo.Po
 	-rm -f ./$(DEPDIR)/run_expect_termsig.Po
 	-rm -f ./$(DEPDIR)/s390_guarded_storage-v.Po
@@ -10648,9 +12839,13 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/s390_sthyi.Po
 	-rm -f ./$(DEPDIR)/sched_get_priority_mxx.Po
 	-rm -f ./$(DEPDIR)/sched_rr_get_interval.Po
+	-rm -f ./$(DEPDIR)/sched_xetaffinity--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/sched_xetaffinity.Po
+	-rm -f ./$(DEPDIR)/sched_xetattr--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/sched_xetattr.Po
+	-rm -f ./$(DEPDIR)/sched_xetparam--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/sched_xetparam.Po
+	-rm -f ./$(DEPDIR)/sched_xetscheduler--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/sched_xetscheduler.Po
 	-rm -f ./$(DEPDIR)/sched_yield.Po
 	-rm -f ./$(DEPDIR)/scm_rights.Po
@@ -10683,6 +12878,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/setgroups32.Po
 	-rm -f ./$(DEPDIR)/sethostname.Po
 	-rm -f ./$(DEPDIR)/setns.Po
+	-rm -f ./$(DEPDIR)/setpgrp-exec.Po
 	-rm -f ./$(DEPDIR)/setregid.Po
 	-rm -f ./$(DEPDIR)/setregid32.Po
 	-rm -f ./$(DEPDIR)/setresgid.Po
@@ -10703,6 +12899,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/sigaltstack.Po
 	-rm -f ./$(DEPDIR)/siginfo.Po
 	-rm -f ./$(DEPDIR)/signal.Po
+	-rm -f ./$(DEPDIR)/signal_receive--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/signal_receive.Po
 	-rm -f ./$(DEPDIR)/signalfd4.Po
 	-rm -f ./$(DEPDIR)/sigpending.Po
@@ -10712,6 +12909,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/sleep.Po
 	-rm -f ./$(DEPDIR)/so_error.Po
 	-rm -f ./$(DEPDIR)/so_linger.Po
+	-rm -f ./$(DEPDIR)/so_peercred--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/so_peercred-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/so_peercred-Xraw.Po
 	-rm -f ./$(DEPDIR)/so_peercred-Xverbose.Po
@@ -10743,14 +12941,24 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/statfs-statfs.Po
 	-rm -f ./$(DEPDIR)/statfs64.Po
 	-rm -f ./$(DEPDIR)/status-all.Po
+	-rm -f ./$(DEPDIR)/status-failed-long.Po
+	-rm -f ./$(DEPDIR)/status-failed-status.Po
 	-rm -f ./$(DEPDIR)/status-failed.Po
 	-rm -f ./$(DEPDIR)/status-none-f.Po
 	-rm -f ./$(DEPDIR)/status-none-threads.Po
 	-rm -f ./$(DEPDIR)/status-none.Po
+	-rm -f ./$(DEPDIR)/status-successful-long.Po
+	-rm -f ./$(DEPDIR)/status-successful-status.Po
 	-rm -f ./$(DEPDIR)/status-successful.Po
 	-rm -f ./$(DEPDIR)/status-unfinished-threads.Po
 	-rm -f ./$(DEPDIR)/status-unfinished.Po
 	-rm -f ./$(DEPDIR)/statx.Po
+	-rm -f ./$(DEPDIR)/strace--strings-in-hex-all.Po
+	-rm -f ./$(DEPDIR)/strace--strings-in-hex-non-ascii.Po
+	-rm -f ./$(DEPDIR)/strace--strings-in-hex.Po
+	-rm -f ./$(DEPDIR)/strace-n.Po
+	-rm -f ./$(DEPDIR)/strace-x.Po
+	-rm -f ./$(DEPDIR)/strace-xx.Po
 	-rm -f ./$(DEPDIR)/swap.Po
 	-rm -f ./$(DEPDIR)/sxetmask.Po
 	-rm -f ./$(DEPDIR)/symlink.Po
@@ -10762,6 +12970,12 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/syslog-success.Po
 	-rm -f ./$(DEPDIR)/syslog.Po
 	-rm -f ./$(DEPDIR)/tee.Po
+	-rm -f ./$(DEPDIR)/tgkill--pidns-translation.Po
+	-rm -f ./$(DEPDIR)/tgkill.Po
+	-rm -f ./$(DEPDIR)/threads-execve--quiet-thread-execve.Po
+	-rm -f ./$(DEPDIR)/threads-execve-q.Po
+	-rm -f ./$(DEPDIR)/threads-execve-qq.Po
+	-rm -f ./$(DEPDIR)/threads-execve-qqq.Po
 	-rm -f ./$(DEPDIR)/threads-execve.Po
 	-rm -f ./$(DEPDIR)/time.Po
 	-rm -f ./$(DEPDIR)/timer_create.Po
@@ -10769,7 +12983,11 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/timerfd_xettime.Po
 	-rm -f ./$(DEPDIR)/times-fail.Po
 	-rm -f ./$(DEPDIR)/times.Po
+	-rm -f ./$(DEPDIR)/tkill--pidns-translation.Po
+	-rm -f ./$(DEPDIR)/tkill.Po
 	-rm -f ./$(DEPDIR)/tracer_ppid_pgid_sid.Po
+	-rm -f ./$(DEPDIR)/trie_test-trie_for_tests.Po
+	-rm -f ./$(DEPDIR)/trie_test-trie_test.Po
 	-rm -f ./$(DEPDIR)/truncate.Po
 	-rm -f ./$(DEPDIR)/truncate64-truncate64.Po
 	-rm -f ./$(DEPDIR)/ugetrlimit.Po
@@ -10783,6 +13001,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/umovestr2.Po
 	-rm -f ./$(DEPDIR)/umovestr3.Po
 	-rm -f ./$(DEPDIR)/umovestr_cached.Po
+	-rm -f ./$(DEPDIR)/umovestr_cached_adjacent.Po
 	-rm -f ./$(DEPDIR)/uname.Po
 	-rm -f ./$(DEPDIR)/unblock_reset_raise.Po
 	-rm -f ./$(DEPDIR)/unix-pair-send-recv.Po
@@ -10808,10 +13027,13 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/waitpid.Po
 	-rm -f ./$(DEPDIR)/xattr-strings.Po
 	-rm -f ./$(DEPDIR)/xattr.Po
+	-rm -f ./$(DEPDIR)/xet_robust_list--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/xet_robust_list.Po
 	-rm -f ./$(DEPDIR)/xet_thread_area_x86.Po
 	-rm -f ./$(DEPDIR)/xetitimer.Po
+	-rm -f ./$(DEPDIR)/xetpgid--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/xetpgid.Po
+	-rm -f ./$(DEPDIR)/xetpriority--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/xetpriority.Po
 	-rm -f ./$(DEPDIR)/xettimeofday.Po
 	-rm -f ./$(DEPDIR)/zeroargc.Po
@@ -10882,6 +13104,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/bpf-obj_get_info_by_fd-prog.Po
 	-rm -f ./$(DEPDIR)/bpf-obj_get_info_by_fd-v.Po
 	-rm -f ./$(DEPDIR)/bpf-obj_get_info_by_fd.Po
+	-rm -f ./$(DEPDIR)/bpf-success-long-y.Po
 	-rm -f ./$(DEPDIR)/bpf-success-v.Po
 	-rm -f ./$(DEPDIR)/bpf-success.Po
 	-rm -f ./$(DEPDIR)/bpf-v.Po
@@ -10908,16 +13131,39 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/clone3-success-Xverbose.Po
 	-rm -f ./$(DEPDIR)/clone3-success.Po
 	-rm -f ./$(DEPDIR)/clone3.Po
+	-rm -f ./$(DEPDIR)/clone_parent--quiet-exit.Po
+	-rm -f ./$(DEPDIR)/clone_parent-q.Po
+	-rm -f ./$(DEPDIR)/clone_parent-qq.Po
 	-rm -f ./$(DEPDIR)/clone_parent.Po
+	-rm -f ./$(DEPDIR)/clone_ptrace--quiet-attach.Po
+	-rm -f ./$(DEPDIR)/clone_ptrace--quiet-exit.Po
+	-rm -f ./$(DEPDIR)/clone_ptrace-q.Po
+	-rm -f ./$(DEPDIR)/clone_ptrace-qq.Po
 	-rm -f ./$(DEPDIR)/clone_ptrace.Po
+	-rm -f ./$(DEPDIR)/close_range-P.Po
+	-rm -f ./$(DEPDIR)/close_range-y.Po
+	-rm -f ./$(DEPDIR)/close_range-yy.Po
+	-rm -f ./$(DEPDIR)/close_range.Po
 	-rm -f ./$(DEPDIR)/copy_file_range.Po
 	-rm -f ./$(DEPDIR)/count-f.Po
 	-rm -f ./$(DEPDIR)/creat.Po
 	-rm -f ./$(DEPDIR)/delay.Po
 	-rm -f ./$(DEPDIR)/delete_module.Po
+	-rm -f ./$(DEPDIR)/dev--decode-fds-dev.Po
+	-rm -f ./$(DEPDIR)/dev--decode-fds-path.Po
+	-rm -f ./$(DEPDIR)/dev--decode-fds-socket.Po
 	-rm -f ./$(DEPDIR)/dev-yy.Po
+	-rm -f ./$(DEPDIR)/dup-P.Po
+	-rm -f ./$(DEPDIR)/dup-y.Po
+	-rm -f ./$(DEPDIR)/dup-yy.Po
 	-rm -f ./$(DEPDIR)/dup.Po
+	-rm -f ./$(DEPDIR)/dup2-P.Po
+	-rm -f ./$(DEPDIR)/dup2-y.Po
+	-rm -f ./$(DEPDIR)/dup2-yy.Po
 	-rm -f ./$(DEPDIR)/dup2.Po
+	-rm -f ./$(DEPDIR)/dup3-P.Po
+	-rm -f ./$(DEPDIR)/dup3-y.Po
+	-rm -f ./$(DEPDIR)/dup3-yy.Po
 	-rm -f ./$(DEPDIR)/dup3.Po
 	-rm -f ./$(DEPDIR)/epoll_create.Po
 	-rm -f ./$(DEPDIR)/epoll_create1.Po
@@ -10930,7 +13176,14 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/execve.Po
 	-rm -f ./$(DEPDIR)/execveat-v.Po
 	-rm -f ./$(DEPDIR)/execveat.Po
+	-rm -f ./$(DEPDIR)/faccessat-P.Po
+	-rm -f ./$(DEPDIR)/faccessat-y.Po
+	-rm -f ./$(DEPDIR)/faccessat-yy.Po
 	-rm -f ./$(DEPDIR)/faccessat.Po
+	-rm -f ./$(DEPDIR)/faccessat2-P.Po
+	-rm -f ./$(DEPDIR)/faccessat2-y.Po
+	-rm -f ./$(DEPDIR)/faccessat2-yy.Po
+	-rm -f ./$(DEPDIR)/faccessat2.Po
 	-rm -f ./$(DEPDIR)/fadvise64.Po
 	-rm -f ./$(DEPDIR)/fadvise64_64.Po
 	-rm -f ./$(DEPDIR)/fallocate.Po
@@ -10945,7 +13198,9 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/fchown.Po
 	-rm -f ./$(DEPDIR)/fchown32.Po
 	-rm -f ./$(DEPDIR)/fchownat.Po
+	-rm -f ./$(DEPDIR)/fcntl--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/fcntl.Po
+	-rm -f ./$(DEPDIR)/fcntl64--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/fcntl64.Po
 	-rm -f ./$(DEPDIR)/fdatasync.Po
 	-rm -f ./$(DEPDIR)/fflush.Po
@@ -10956,6 +13211,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/filter_seccomp-perf.Po
 	-rm -f ./$(DEPDIR)/finit_module.Po
 	-rm -f ./$(DEPDIR)/flock.Po
+	-rm -f ./$(DEPDIR)/fork--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/fork-f.Po
 	-rm -f ./$(DEPDIR)/fsconfig-P.Po
 	-rm -f ./$(DEPDIR)/fsconfig.Po
@@ -10981,9 +13237,12 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/futex.Po
 	-rm -f ./$(DEPDIR)/futimesat.Po
 	-rm -f ./$(DEPDIR)/get_mempolicy.Po
+	-rm -f ./$(DEPDIR)/get_process_reaper.Po
 	-rm -f ./$(DEPDIR)/getcpu.Po
 	-rm -f ./$(DEPDIR)/getcwd.Po
+	-rm -f ./$(DEPDIR)/getdents-v.Po
 	-rm -f ./$(DEPDIR)/getdents.Po
+	-rm -f ./$(DEPDIR)/getdents64-v.Po
 	-rm -f ./$(DEPDIR)/getdents64.Po
 	-rm -f ./$(DEPDIR)/getegid.Po
 	-rm -f ./$(DEPDIR)/getegid32.Po
@@ -10994,7 +13253,9 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/getgroups.Po
 	-rm -f ./$(DEPDIR)/getgroups32.Po
 	-rm -f ./$(DEPDIR)/getpeername.Po
+	-rm -f ./$(DEPDIR)/getpgrp--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/getpgrp.Po
+	-rm -f ./$(DEPDIR)/getpid--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/getpid.Po
 	-rm -f ./$(DEPDIR)/getppid.Po
 	-rm -f ./$(DEPDIR)/getrandom.Po
@@ -11004,12 +13265,16 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/getresuid32.Po
 	-rm -f ./$(DEPDIR)/getrlimit.Po
 	-rm -f ./$(DEPDIR)/getrusage.Po
+	-rm -f ./$(DEPDIR)/getsid--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/getsid.Po
 	-rm -f ./$(DEPDIR)/getsockname.Po
+	-rm -f ./$(DEPDIR)/gettid--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/gettid.Po
 	-rm -f ./$(DEPDIR)/getuid.Po
 	-rm -f ./$(DEPDIR)/getuid32.Po
-	-rm -f ./$(DEPDIR)/getxxid.Po
+	-rm -f ./$(DEPDIR)/getxgid.Po
+	-rm -f ./$(DEPDIR)/getxpid.Po
+	-rm -f ./$(DEPDIR)/getxuid.Po
 	-rm -f ./$(DEPDIR)/group_req.Po
 	-rm -f ./$(DEPDIR)/inet-cmsg.Po
 	-rm -f ./$(DEPDIR)/init_module.Po
@@ -11024,6 +13289,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/io_uring_register.Po
 	-rm -f ./$(DEPDIR)/io_uring_setup.Po
 	-rm -f ./$(DEPDIR)/ioctl.Po
+	-rm -f ./$(DEPDIR)/ioctl_block--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/ioctl_block.Po
 	-rm -f ./$(DEPDIR)/ioctl_dm-v.Po
 	-rm -f ./$(DEPDIR)/ioctl_dm.Po
@@ -11043,6 +13309,22 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/ioctl_evdev-v-Xverbose.Po
 	-rm -f ./$(DEPDIR)/ioctl_evdev-v.Po
 	-rm -f ./$(DEPDIR)/ioctl_evdev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-v-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-v-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-v-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-v.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-v-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-v-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-v-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-v.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio.Po
 	-rm -f ./$(DEPDIR)/ioctl_inotify.Po
 	-rm -f ./$(DEPDIR)/ioctl_kvm_run-v.Po
 	-rm -f ./$(DEPDIR)/ioctl_kvm_run.Po
@@ -11063,11 +13345,28 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/ioctl_sg_io_v3.Po
 	-rm -f ./$(DEPDIR)/ioctl_sg_io_v4.Po
 	-rm -f ./$(DEPDIR)/ioctl_sock_gifconf.Po
+	-rm -f ./$(DEPDIR)/ioctl_tee.Po
 	-rm -f ./$(DEPDIR)/ioctl_uffdio.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-v-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-v-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-v-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-v.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-v-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-v-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-v-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-v.Po
 	-rm -f ./$(DEPDIR)/ioctl_v4l2.Po
 	-rm -f ./$(DEPDIR)/ioctl_watchdog.Po
 	-rm -f ./$(DEPDIR)/ioperm.Po
 	-rm -f ./$(DEPDIR)/iopl.Po
+	-rm -f ./$(DEPDIR)/ioprio--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/ioprio-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/ioprio-Xraw.Po
 	-rm -f ./$(DEPDIR)/ioprio-Xverbose.Po
@@ -11091,6 +13390,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/ipc_shm-Xverbose.Po
 	-rm -f ./$(DEPDIR)/ipc_shm.Po
 	-rm -f ./$(DEPDIR)/is_linux_mips_n64.Po
+	-rm -f ./$(DEPDIR)/kcmp-y--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/kcmp-y.Po
 	-rm -f ./$(DEPDIR)/kcmp.Po
 	-rm -f ./$(DEPDIR)/kern_features.Po
@@ -11104,12 +13404,14 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/keyctl-Xraw.Po
 	-rm -f ./$(DEPDIR)/keyctl-Xverbose.Po
 	-rm -f ./$(DEPDIR)/keyctl.Po
+	-rm -f ./$(DEPDIR)/kill--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/kill.Po
 	-rm -f ./$(DEPDIR)/kill_child.Po
 	-rm -f ./$(DEPDIR)/ksysent.Po
 	-rm -f ./$(DEPDIR)/lchown.Po
 	-rm -f ./$(DEPDIR)/lchown32.Po
 	-rm -f ./$(DEPDIR)/libtests_a-create_nl_socket.Po
+	-rm -f ./$(DEPDIR)/libtests_a-create_tmpfile.Po
 	-rm -f ./$(DEPDIR)/libtests_a-errno2name.Po
 	-rm -f ./$(DEPDIR)/libtests_a-error_msg.Po
 	-rm -f ./$(DEPDIR)/libtests_a-fill_memory.Po
@@ -11123,6 +13425,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/libtests_a-libsocketcall.Po
 	-rm -f ./$(DEPDIR)/libtests_a-lock_file.Po
 	-rm -f ./$(DEPDIR)/libtests_a-overflowuid.Po
+	-rm -f ./$(DEPDIR)/libtests_a-pidns.Po
 	-rm -f ./$(DEPDIR)/libtests_a-pipe_maxfd.Po
 	-rm -f ./$(DEPDIR)/libtests_a-print_quoted_string.Po
 	-rm -f ./$(DEPDIR)/libtests_a-print_time.Po
@@ -11139,6 +13442,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/libtests_a-test_printstrn.Po
 	-rm -f ./$(DEPDIR)/libtests_a-test_ucopy.Po
 	-rm -f ./$(DEPDIR)/libtests_a-tprintf.Po
+	-rm -f ./$(DEPDIR)/libtests_a-xmalloc_for_tests.Po
 	-rm -f ./$(DEPDIR)/link.Po
 	-rm -f ./$(DEPDIR)/linkat.Po
 	-rm -f ./$(DEPDIR)/list_sigaction_signum.Po
@@ -11150,6 +13454,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/lstat.Po
 	-rm -f ./$(DEPDIR)/lstat64-lstat64.Po
 	-rm -f ./$(DEPDIR)/madvise.Po
+	-rm -f ./$(DEPDIR)/maybe_switch_current_tcp--quiet-thread-execve.Po
 	-rm -f ./$(DEPDIR)/maybe_switch_current_tcp.Po
 	-rm -f ./$(DEPDIR)/mbind-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/mbind-Xraw.Po
@@ -11160,6 +13465,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/memfd_create-Xraw.Po
 	-rm -f ./$(DEPDIR)/memfd_create-Xverbose.Po
 	-rm -f ./$(DEPDIR)/memfd_create.Po
+	-rm -f ./$(DEPDIR)/migrate_pages--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/migrate_pages.Po
 	-rm -f ./$(DEPDIR)/mincore.Po
 	-rm -f ./$(DEPDIR)/mkdir.Po
@@ -11188,6 +13494,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/mount.Po
 	-rm -f ./$(DEPDIR)/move_mount-P.Po
 	-rm -f ./$(DEPDIR)/move_mount.Po
+	-rm -f ./$(DEPDIR)/move_pages--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/move_pages-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/move_pages-Xraw.Po
 	-rm -f ./$(DEPDIR)/move_pages-Xverbose.Po
@@ -11201,12 +13508,17 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/msg_name.Po
 	-rm -f ./$(DEPDIR)/munlockall.Po
 	-rm -f ./$(DEPDIR)/nanosleep.Po
+	-rm -f ./$(DEPDIR)/net--decode-fds-dev-netlink.Po
+	-rm -f ./$(DEPDIR)/net--decode-fds-none-netlink.Po
+	-rm -f ./$(DEPDIR)/net--decode-fds-path-netlink.Po
+	-rm -f ./$(DEPDIR)/net--decode-fds-socket-netlink.Po
 	-rm -f ./$(DEPDIR)/net-accept-connect.Po
 	-rm -f ./$(DEPDIR)/net-icmp_filter.Po
 	-rm -f ./$(DEPDIR)/net-packet_mreq-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/net-packet_mreq-Xraw.Po
 	-rm -f ./$(DEPDIR)/net-packet_mreq-Xverbose.Po
 	-rm -f ./$(DEPDIR)/net-packet_mreq.Po
+	-rm -f ./$(DEPDIR)/net-sockaddr--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/net-sockaddr.Po
 	-rm -f ./$(DEPDIR)/net-tpacket_req.Po
 	-rm -f ./$(DEPDIR)/net-tpacket_stats-success.Po
@@ -11216,6 +13528,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/net-yy-inet6.Po
 	-rm -f ./$(DEPDIR)/net-yy-netlink.Po
 	-rm -f ./$(DEPDIR)/net-yy-unix.Po
+	-rm -f ./$(DEPDIR)/netlink_audit--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/netlink_audit.Po
 	-rm -f ./$(DEPDIR)/netlink_crypto.Po
 	-rm -f ./$(DEPDIR)/netlink_generic.Po
@@ -11253,6 +13566,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/nlattr_ifla_brport.Po
 	-rm -f ./$(DEPDIR)/nlattr_ifla_linkinfo.Po
 	-rm -f ./$(DEPDIR)/nlattr_ifla_port.Po
+	-rm -f ./$(DEPDIR)/nlattr_ifla_xdp-y.Po
 	-rm -f ./$(DEPDIR)/nlattr_ifla_xdp.Po
 	-rm -f ./$(DEPDIR)/nlattr_inet_diag_msg.Po
 	-rm -f ./$(DEPDIR)/nlattr_inet_diag_req_compat.Po
@@ -11292,6 +13606,16 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/open_tree-P.Po
 	-rm -f ./$(DEPDIR)/open_tree.Po
 	-rm -f ./$(DEPDIR)/openat.Po
+	-rm -f ./$(DEPDIR)/openat2-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/openat2-Xraw.Po
+	-rm -f ./$(DEPDIR)/openat2-Xverbose.Po
+	-rm -f ./$(DEPDIR)/openat2-v-y-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/openat2-v-y-Xraw.Po
+	-rm -f ./$(DEPDIR)/openat2-v-y-Xverbose.Po
+	-rm -f ./$(DEPDIR)/openat2-v-y.Po
+	-rm -f ./$(DEPDIR)/openat2-v.Po
+	-rm -f ./$(DEPDIR)/openat2-y.Po
+	-rm -f ./$(DEPDIR)/openat2.Po
 	-rm -f ./$(DEPDIR)/orphaned_process_group.Po
 	-rm -f ./$(DEPDIR)/osf_utimes.Po
 	-rm -f ./$(DEPDIR)/pause.Po
@@ -11303,10 +13627,20 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/personality-Xraw.Po
 	-rm -f ./$(DEPDIR)/personality-Xverbose.Po
 	-rm -f ./$(DEPDIR)/personality.Po
+	-rm -f ./$(DEPDIR)/pidfd_getfd-y.Po
+	-rm -f ./$(DEPDIR)/pidfd_getfd-yy.Po
+	-rm -f ./$(DEPDIR)/pidfd_getfd.Po
+	-rm -f ./$(DEPDIR)/pidfd_open--decode-fd-path.Po
+	-rm -f ./$(DEPDIR)/pidfd_open--decode-fd-pidfd.Po
+	-rm -f ./$(DEPDIR)/pidfd_open--decode-fd-socket.Po
+	-rm -f ./$(DEPDIR)/pidfd_open--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/pidfd_open-P.Po
 	-rm -f ./$(DEPDIR)/pidfd_open-y.Po
+	-rm -f ./$(DEPDIR)/pidfd_open-yy.Po
 	-rm -f ./$(DEPDIR)/pidfd_open.Po
+	-rm -f ./$(DEPDIR)/pidfd_send_signal--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/pidfd_send_signal.Po
+	-rm -f ./$(DEPDIR)/pidns-cache.Po
 	-rm -f ./$(DEPDIR)/pipe.Po
 	-rm -f ./$(DEPDIR)/pipe2.Po
 	-rm -f ./$(DEPDIR)/pkey_alloc.Po
@@ -11333,6 +13667,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/preadv2-pwritev2.Po
 	-rm -f ./$(DEPDIR)/preadv_pwritev-preadv-pwritev.Po
 	-rm -f ./$(DEPDIR)/print_maxfd.Po
+	-rm -f ./$(DEPDIR)/print_ppid_tracerpid.Po
 	-rm -f ./$(DEPDIR)/printpath-umovestr-peekdata.Po
 	-rm -f ./$(DEPDIR)/printpath-umovestr-undumpable.Po
 	-rm -f ./$(DEPDIR)/printpath-umovestr.Po
@@ -11343,8 +13678,11 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/printstrn-umoven-peekdata.Po
 	-rm -f ./$(DEPDIR)/printstrn-umoven-undumpable.Po
 	-rm -f ./$(DEPDIR)/printstrn-umoven.Po
+	-rm -f ./$(DEPDIR)/prlimit64--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/prlimit64.Po
+	-rm -f ./$(DEPDIR)/process_vm_readv--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/process_vm_readv.Po
+	-rm -f ./$(DEPDIR)/process_vm_writev--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/process_vm_writev.Po
 	-rm -f ./$(DEPDIR)/pselect6.Po
 	-rm -f ./$(DEPDIR)/ptrace.Po
@@ -11393,10 +13731,12 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/rt_sigaction.Po
 	-rm -f ./$(DEPDIR)/rt_sigpending.Po
 	-rm -f ./$(DEPDIR)/rt_sigprocmask.Po
+	-rm -f ./$(DEPDIR)/rt_sigqueueinfo--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/rt_sigqueueinfo.Po
 	-rm -f ./$(DEPDIR)/rt_sigreturn.Po
 	-rm -f ./$(DEPDIR)/rt_sigsuspend.Po
 	-rm -f ./$(DEPDIR)/rt_sigtimedwait.Po
+	-rm -f ./$(DEPDIR)/rt_tgsigqueueinfo--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/rt_tgsigqueueinfo.Po
 	-rm -f ./$(DEPDIR)/run_expect_termsig.Po
 	-rm -f ./$(DEPDIR)/s390_guarded_storage-v.Po
@@ -11407,9 +13747,13 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/s390_sthyi.Po
 	-rm -f ./$(DEPDIR)/sched_get_priority_mxx.Po
 	-rm -f ./$(DEPDIR)/sched_rr_get_interval.Po
+	-rm -f ./$(DEPDIR)/sched_xetaffinity--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/sched_xetaffinity.Po
+	-rm -f ./$(DEPDIR)/sched_xetattr--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/sched_xetattr.Po
+	-rm -f ./$(DEPDIR)/sched_xetparam--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/sched_xetparam.Po
+	-rm -f ./$(DEPDIR)/sched_xetscheduler--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/sched_xetscheduler.Po
 	-rm -f ./$(DEPDIR)/sched_yield.Po
 	-rm -f ./$(DEPDIR)/scm_rights.Po
@@ -11442,6 +13786,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/setgroups32.Po
 	-rm -f ./$(DEPDIR)/sethostname.Po
 	-rm -f ./$(DEPDIR)/setns.Po
+	-rm -f ./$(DEPDIR)/setpgrp-exec.Po
 	-rm -f ./$(DEPDIR)/setregid.Po
 	-rm -f ./$(DEPDIR)/setregid32.Po
 	-rm -f ./$(DEPDIR)/setresgid.Po
@@ -11462,6 +13807,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/sigaltstack.Po
 	-rm -f ./$(DEPDIR)/siginfo.Po
 	-rm -f ./$(DEPDIR)/signal.Po
+	-rm -f ./$(DEPDIR)/signal_receive--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/signal_receive.Po
 	-rm -f ./$(DEPDIR)/signalfd4.Po
 	-rm -f ./$(DEPDIR)/sigpending.Po
@@ -11471,6 +13817,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/sleep.Po
 	-rm -f ./$(DEPDIR)/so_error.Po
 	-rm -f ./$(DEPDIR)/so_linger.Po
+	-rm -f ./$(DEPDIR)/so_peercred--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/so_peercred-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/so_peercred-Xraw.Po
 	-rm -f ./$(DEPDIR)/so_peercred-Xverbose.Po
@@ -11502,14 +13849,24 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/statfs-statfs.Po
 	-rm -f ./$(DEPDIR)/statfs64.Po
 	-rm -f ./$(DEPDIR)/status-all.Po
+	-rm -f ./$(DEPDIR)/status-failed-long.Po
+	-rm -f ./$(DEPDIR)/status-failed-status.Po
 	-rm -f ./$(DEPDIR)/status-failed.Po
 	-rm -f ./$(DEPDIR)/status-none-f.Po
 	-rm -f ./$(DEPDIR)/status-none-threads.Po
 	-rm -f ./$(DEPDIR)/status-none.Po
+	-rm -f ./$(DEPDIR)/status-successful-long.Po
+	-rm -f ./$(DEPDIR)/status-successful-status.Po
 	-rm -f ./$(DEPDIR)/status-successful.Po
 	-rm -f ./$(DEPDIR)/status-unfinished-threads.Po
 	-rm -f ./$(DEPDIR)/status-unfinished.Po
 	-rm -f ./$(DEPDIR)/statx.Po
+	-rm -f ./$(DEPDIR)/strace--strings-in-hex-all.Po
+	-rm -f ./$(DEPDIR)/strace--strings-in-hex-non-ascii.Po
+	-rm -f ./$(DEPDIR)/strace--strings-in-hex.Po
+	-rm -f ./$(DEPDIR)/strace-n.Po
+	-rm -f ./$(DEPDIR)/strace-x.Po
+	-rm -f ./$(DEPDIR)/strace-xx.Po
 	-rm -f ./$(DEPDIR)/swap.Po
 	-rm -f ./$(DEPDIR)/sxetmask.Po
 	-rm -f ./$(DEPDIR)/symlink.Po
@@ -11521,6 +13878,12 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/syslog-success.Po
 	-rm -f ./$(DEPDIR)/syslog.Po
 	-rm -f ./$(DEPDIR)/tee.Po
+	-rm -f ./$(DEPDIR)/tgkill--pidns-translation.Po
+	-rm -f ./$(DEPDIR)/tgkill.Po
+	-rm -f ./$(DEPDIR)/threads-execve--quiet-thread-execve.Po
+	-rm -f ./$(DEPDIR)/threads-execve-q.Po
+	-rm -f ./$(DEPDIR)/threads-execve-qq.Po
+	-rm -f ./$(DEPDIR)/threads-execve-qqq.Po
 	-rm -f ./$(DEPDIR)/threads-execve.Po
 	-rm -f ./$(DEPDIR)/time.Po
 	-rm -f ./$(DEPDIR)/timer_create.Po
@@ -11528,7 +13891,11 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/timerfd_xettime.Po
 	-rm -f ./$(DEPDIR)/times-fail.Po
 	-rm -f ./$(DEPDIR)/times.Po
+	-rm -f ./$(DEPDIR)/tkill--pidns-translation.Po
+	-rm -f ./$(DEPDIR)/tkill.Po
 	-rm -f ./$(DEPDIR)/tracer_ppid_pgid_sid.Po
+	-rm -f ./$(DEPDIR)/trie_test-trie_for_tests.Po
+	-rm -f ./$(DEPDIR)/trie_test-trie_test.Po
 	-rm -f ./$(DEPDIR)/truncate.Po
 	-rm -f ./$(DEPDIR)/truncate64-truncate64.Po
 	-rm -f ./$(DEPDIR)/ugetrlimit.Po
@@ -11542,6 +13909,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/umovestr2.Po
 	-rm -f ./$(DEPDIR)/umovestr3.Po
 	-rm -f ./$(DEPDIR)/umovestr_cached.Po
+	-rm -f ./$(DEPDIR)/umovestr_cached_adjacent.Po
 	-rm -f ./$(DEPDIR)/uname.Po
 	-rm -f ./$(DEPDIR)/unblock_reset_raise.Po
 	-rm -f ./$(DEPDIR)/unix-pair-send-recv.Po
@@ -11567,10 +13935,13 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/waitpid.Po
 	-rm -f ./$(DEPDIR)/xattr-strings.Po
 	-rm -f ./$(DEPDIR)/xattr.Po
+	-rm -f ./$(DEPDIR)/xet_robust_list--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/xet_robust_list.Po
 	-rm -f ./$(DEPDIR)/xet_thread_area_x86.Po
 	-rm -f ./$(DEPDIR)/xetitimer.Po
+	-rm -f ./$(DEPDIR)/xetpgid--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/xetpgid.Po
+	-rm -f ./$(DEPDIR)/xetpriority--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/xetpriority.Po
 	-rm -f ./$(DEPDIR)/xettimeofday.Po
 	-rm -f ./$(DEPDIR)/zeroargc.Po
@@ -11714,6 +14085,42 @@ $(srcdir)/clone3-success-Xraw.gen.test:
 $(srcdir)/clone3-success-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/clone_parent.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_parent--quiet-exit.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_parent-q.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_parent-qq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_ptrace--quiet-attach.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_ptrace--quiet-exit.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_ptrace-q.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_ptrace-qq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/close_range.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/close_range-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/close_range-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/close_range-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/copy_file_range.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -11723,18 +14130,54 @@ $(srcdir)/creat.gen.test: $(abs_srcdir)/
 $(srcdir)/delete_module.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/dev--decode-fds-dev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dev--decode-fds-path.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dev--decode-fds-socket.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/dev-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/dup.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/dup-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/dup2.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/dup2-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup2-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup2-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/dup3.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/dup3-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup3-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup3-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/epoll_create.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -11759,7 +14202,22 @@ $(srcdir)/execveat.gen.test: $(abs_srcdi
 $(srcdir)/execveat-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
-$(srcdir)/faccessat.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+$(srcdir)/faccessat-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat2-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat2-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat2-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/fadvise64_64.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
@@ -11804,9 +14262,15 @@ $(srcdir)/fchownat.gen.test: $(abs_srcdi
 $(srcdir)/fcntl.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/fcntl--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/fcntl64.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/fcntl64--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/fdatasync.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -11909,9 +14373,15 @@ $(srcdir)/getcwd.gen.test: $(abs_srcdir)
 $(srcdir)/getdents.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getdents-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getdents64.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getdents64-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getegid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -11960,9 +14430,15 @@ $(srcdir)/getpeername.gen.test: $(abs_sr
 $(srcdir)/getpgrp.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getpgrp--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getpid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getpid--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getppid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -11990,6 +14466,9 @@ $(srcdir)/getrusage.gen.test: $(abs_srcd
 $(srcdir)/getsid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getsid--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getsockname.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12005,7 +14484,13 @@ $(srcdir)/getuid32.gen.test: $(abs_srcdi
 $(srcdir)/getuid32-creds.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
-$(srcdir)/getxxid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+$(srcdir)/getxgid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/getxpid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/getxuid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/group_req.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
@@ -12092,6 +14577,54 @@ $(srcdir)/ioctl_evdev-success-v-Xraw.gen
 $(srcdir)/ioctl_evdev-success-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioctl_hdio.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-v-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-v-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-v-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-v-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioctl_inotify.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12125,6 +14658,9 @@ $(srcdir)/ioctl_nsfs.gen.test: $(abs_src
 $(srcdir)/ioctl_perf.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioctl_perf-success.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioctl_ptp.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12149,12 +14685,60 @@ $(srcdir)/ioctl_sg_io_v4.gen.test: $(abs
 $(srcdir)/ioctl_sock_gifconf.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioctl_tee.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioctl_uffdio.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/ioctl_v4l2.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioctl_v4l2-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-v-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-v-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-v-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-v-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioctl_watchdog.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12167,6 +14751,9 @@ $(srcdir)/iopl.gen.test: $(abs_srcdir)/g
 $(srcdir)/ioprio.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioprio--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioprio-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12233,6 +14820,9 @@ $(srcdir)/kcmp.gen.test: $(abs_srcdir)/g
 $(srcdir)/kcmp-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/kcmp-y--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/kern_features.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12269,6 +14859,9 @@ $(srcdir)/keyctl-Xverbose.gen.test: $(ab
 $(srcdir)/kill.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/kill--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ksysent.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12299,6 +14892,9 @@ $(srcdir)/madvise.gen.test: $(abs_srcdir
 $(srcdir)/maybe_switch_current_tcp.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/maybe_switch_current_tcp--quiet-thread-execve.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/mbind.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12329,6 +14925,9 @@ $(srcdir)/memfd_create-Xverbose.gen.test
 $(srcdir)/migrate_pages.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/migrate_pages--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/mincore.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12419,6 +15018,9 @@ $(srcdir)/move_pages-Xraw.gen.test: $(ab
 $(srcdir)/move_pages-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/move_pages--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/mq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12446,6 +15048,18 @@ $(srcdir)/munlockall.gen.test: $(abs_src
 $(srcdir)/nanosleep.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/net--decode-fds-dev-netlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/net--decode-fds-none-netlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/net--decode-fds-path-netlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/net--decode-fds-socket-netlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/net-icmp_filter.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12464,6 +15078,9 @@ $(srcdir)/net-packet_mreq-Xverbose.gen.t
 $(srcdir)/net-sockaddr.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/net-sockaddr--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/net-tpacket_req.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12575,6 +15192,9 @@ $(srcdir)/nlattr_ifla_port.gen.test: $(a
 $(srcdir)/nlattr_ifla_xdp.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/nlattr_ifla_xdp-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/nlattr_inet_diag_msg.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12683,6 +15303,36 @@ $(srcdir)/open_tree-P.gen.test: $(abs_sr
 $(srcdir)/openat.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/openat2.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v-y-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v-y-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v-y-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/orphaned_process_group.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12710,18 +15360,45 @@ $(srcdir)/personality-Xraw.gen.test: $(a
 $(srcdir)/personality-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/pidfd_getfd.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_getfd-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_getfd-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pidfd_open.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/pidfd_open--decode-fd-path.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_open--decode-fd-pidfd.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_open--decode-fd-socket.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pidfd_open-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/pidfd_open-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/pidfd_open-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_open--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pidfd_send_signal.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/pidfd_send_signal--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pipe2.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12788,12 +15465,21 @@ $(srcdir)/printstrn-umoven-undumpable.ge
 $(srcdir)/prlimit64.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/prlimit64--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/process_vm_readv.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/process_vm_readv--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/process_vm_writev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/process_vm_writev--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pselect6.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12902,6 +15588,9 @@ $(srcdir)/rt_sigprocmask.gen.test: $(abs
 $(srcdir)/rt_sigqueueinfo.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/rt_sigqueueinfo--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/rt_sigreturn.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12914,6 +15603,9 @@ $(srcdir)/rt_sigtimedwait.gen.test: $(ab
 $(srcdir)/rt_tgsigqueueinfo.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/rt_tgsigqueueinfo--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/s390_guarded_storage.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12944,15 +15636,27 @@ $(srcdir)/sched_rr_get_interval.gen.test
 $(srcdir)/sched_xetaffinity.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/sched_xetaffinity--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sched_xetattr.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/sched_xetattr--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sched_xetparam.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/sched_xetparam--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sched_xetscheduler.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/sched_xetscheduler--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sched_yield.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -13091,6 +15795,9 @@ $(srcdir)/signal.gen.test: $(abs_srcdir)
 $(srcdir)/signal_receive.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/signal_receive--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/signalfd4.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -13124,6 +15831,9 @@ $(srcdir)/so_peercred-Xraw.gen.test: $(a
 $(srcdir)/so_peercred-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/so_peercred--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sock_filter-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -13175,18 +15885,141 @@ $(srcdir)/status-all.gen.test: $(abs_src
 $(srcdir)/status-failed.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/status-failed-long.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/status-failed-status.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/status-none.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/status-successful.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/status-successful-long.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/status-successful-status.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/status-unfinished.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/statx.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/strace--absolute-timestamps.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time-precision-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time-precision-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time-precision-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time-precision-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-unix-precision-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-unix-precision-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-unix-precision-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-unix-precision-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--follow-forks-output-separately.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--strings-in-hex.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--strings-in-hex-all.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--strings-in-hex-non-ascii.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-unix-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-unix-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-unix-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-unix-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace-n.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace-x.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace-xx.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/swap.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -13217,6 +16050,24 @@ $(srcdir)/syslog.gen.test: $(abs_srcdir)
 $(srcdir)/tee.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/tgkill.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/tgkill--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/threads-execve--quiet-thread-execve.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/threads-execve-q.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/threads-execve-qq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/threads-execve-qqq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/time.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -13235,6 +16086,15 @@ $(srcdir)/times.gen.test: $(abs_srcdir)/
 $(srcdir)/times-fail.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/tkill.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/tkill--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/trace_clock.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/trace_creds.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -13280,6 +16140,9 @@ $(srcdir)/trace_statfs.gen.test: $(abs_s
 $(srcdir)/trace_statfs_like.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/trie_test.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/truncate.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -13301,6 +16164,9 @@ $(srcdir)/umovestr-illptr.gen.test: $(ab
 $(srcdir)/umovestr3.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/umovestr_cached_adjacent.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/unlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -13367,15 +16233,24 @@ $(srcdir)/xattr-strings.gen.test: $(abs_
 $(srcdir)/xet_robust_list.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/xet_robust_list--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/xetitimer.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/xetpgid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/xetpgid--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/xetpriority.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/xetpriority--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/xettimeofday.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
diff -pruN 5.5-3/tests-m32/maybe_switch_current_tcp.c 5.9-0ubuntu2/tests-m32/maybe_switch_current_tcp.c
--- 5.5-3/tests-m32/maybe_switch_current_tcp.c	2019-07-16 17:46:47.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/maybe_switch_current_tcp.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,6 +2,7 @@
  * Check for PTRACE_EVENT_EXEC diagnostics.
  *
  * Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2019-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -14,6 +15,10 @@
 #include <unistd.h>
 #include "scno.h"
 
+#ifndef QUIET_MSG
+# define QUIET_MSG 0
+#endif
+
 static pid_t leader;
 static volatile unsigned int trigger;
 
@@ -25,9 +30,14 @@ thread(void *arg)
 
 	printf("%-5d execveat(AT_FDCWD, \"%s\", [\"%s\", \"%s\", \"%s\"]"
 	       ", NULL, 0 <pid changed to %d ...>\n"
-	       "%-5d +++ superseded by execve in pid %d +++\n",
-	       tid, argv[0], argv[0], argv[1], argv[2], leader,
-	       leader, tid);
+#if !QUIET_MSG
+	       "%-5d +++ superseded by execve in pid %d +++\n"
+#endif
+	       , tid, argv[0], argv[0], argv[1], argv[2], leader
+#if !QUIET_MSG
+	       , leader, tid
+#endif
+	       );
 
 	while (!trigger) {
 		/* Wait for the parent to enter the busy loop.  */
diff -pruN 5.5-3/tests-m32/maybe_switch_current_tcp--quiet-thread-execve.c 5.9-0ubuntu2/tests-m32/maybe_switch_current_tcp--quiet-thread-execve.c
--- 5.5-3/tests-m32/maybe_switch_current_tcp--quiet-thread-execve.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/maybe_switch_current_tcp--quiet-thread-execve.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define QUIET_MSG 1
+#include "maybe_switch_current_tcp.c"
diff -pruN 5.5-3/tests-m32/maybe_switch_current_tcp--quiet-thread-execve.gen.test 5.9-0ubuntu2/tests-m32/maybe_switch_current_tcp--quiet-thread-execve.gen.test
--- 5.5-3/tests-m32/maybe_switch_current_tcp--quiet-thread-execve.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/maybe_switch_current_tcp--quiet-thread-execve.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (maybe_switch_current_tcp--quiet-thread-execve -a30 -s48 -f -e trace=execveat --quiet=personality,thread-execve); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a30 -s48 -f -e trace=execveat --quiet=personality,thread-execve
diff -pruN 5.5-3/tests-m32/migrate_pages.c 5.9-0ubuntu2/tests-m32/migrate_pages.c
--- 5.5-3/tests-m32/migrate_pages.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/migrate_pages.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of migrate_pages syscall.
  *
  * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,6 +10,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #ifdef __NR_migrate_pages
 
@@ -19,11 +20,21 @@
 int
 main(void)
 {
-	const long pid = (long) 0xfacefeedffffffffULL;
+	PIDNS_TEST_INIT;
+
+	const long pid = (long) 0xfacefeed00000000ULL | getpid();
 	long rc = syscall(__NR_migrate_pages, pid, 0, 0, 0);
-	printf("migrate_pages(%d, 0, NULL, NULL) = %ld %s (%m)\n",
-	       (int) pid, rc, errno2name());
 
+	pidns_print_leader();
+	printf("migrate_pages(%d%s, 0, NULL, NULL) = %ld",
+		(int) pid, pidns_pid2str(PT_TGID), rc);
+
+	if (rc < 0)
+		printf(" %s (%m)\n", errno2name());
+	else
+		printf("\n");
+
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/migrate_pages--pidns-translation.c 5.9-0ubuntu2/tests-m32/migrate_pages--pidns-translation.c
--- 5.5-3/tests-m32/migrate_pages--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/migrate_pages--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "migrate_pages.c"
diff -pruN 5.5-3/tests-m32/migrate_pages--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/migrate_pages--pidns-translation.gen.test
--- 5.5-3/tests-m32/migrate_pages--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/migrate_pages--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (migrate_pages--pidns-translation test_pidns -a33 -e trace=migrate_pages); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a33 -e trace=migrate_pages
diff -pruN 5.5-3/tests-m32/mknod.c 5.9-0ubuntu2/tests-m32/mknod.c
--- 5.5-3/tests-m32/mknod.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/mknod.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -31,44 +31,44 @@ main(int ac, char **av)
 	sample = av[0];
 
 	long rc = call_mknod(0, dev);
-	printf("mknod(\"%s\", 000) = %ld %s (%m)\n",
-	       sample, rc, errno2name());
+	printf("mknod(\"%s\", 000) = %s\n",
+	       sample, sprintrc(rc));
 
 	rc = call_mknod(0xffff, dev);
-	printf("mknod(\"%s\", %#03ho) = %ld %s (%m)\n",
-	       sample, (unsigned short) -1, rc, errno2name());
+	printf("mknod(\"%s\", %#03ho) = %s\n",
+	       sample, (unsigned short) -1, sprintrc(rc));
 
 	rc = call_mknod(S_IFREG, 0);
-	printf("mknod(\"%s\", S_IFREG|000) = %ld %s (%m)\n",
-	       sample, rc, errno2name());
+	printf("mknod(\"%s\", S_IFREG|000) = %s\n",
+	       sample, sprintrc(rc));
 
 	rc = call_mknod(S_IFDIR | 06, 0);
-	printf("mknod(\"%s\", S_IFDIR|006) = %ld %s (%m)\n",
-	       sample, rc, errno2name());
+	printf("mknod(\"%s\", S_IFDIR|006) = %s\n",
+	       sample, sprintrc(rc));
 
 	rc = call_mknod(S_IFLNK | 060, 0);
-	printf("mknod(\"%s\", S_IFLNK|060) = %ld %s (%m)\n",
-	       sample, rc, errno2name());
+	printf("mknod(\"%s\", S_IFLNK|060) = %s\n",
+	       sample, sprintrc(rc));
 
 	rc = call_mknod(S_IFIFO | 0600, 0);
-	printf("mknod(\"%s\", S_IFIFO|0600) = %ld %s (%m)\n",
-	       sample, rc, errno2name());
+	printf("mknod(\"%s\", S_IFIFO|0600) = %s\n",
+	       sample, sprintrc(rc));
 
 	dev = (unsigned long) 0xdeadbeef00000000ULL | makedev(1, 7);
 
 	rc = call_mknod(S_IFCHR | 024, dev);
-	printf("mknod(\"%s\", S_IFCHR|024, makedev(0x1, 0x7)) = %ld %s (%m)\n",
-	       sample, rc, errno2name());
+	printf("mknod(\"%s\", S_IFCHR|024, makedev(0x1, 0x7)) = %s\n",
+	       sample, sprintrc(rc));
 
 	const unsigned short mode = (0xffff & ~S_IFMT) | S_IFBLK;
 	dev = (unsigned long) 0xdeadbeefbadc0dedULL;
 
 	rc = call_mknod(mode, dev);
 	printf("mknod(\"%s\", S_IFBLK|S_ISUID|S_ISGID|S_ISVTX|%#03ho"
-	       ", makedev(%#x, %#x)) = %ld %s (%m)\n",
+	       ", makedev(%#x, %#x)) = %s\n",
 	       sample, (short) (mode & ~(S_IFMT|S_ISUID|S_ISGID|S_ISVTX)),
 	       major((unsigned) dev), minor((unsigned) dev),
-	       rc, errno2name());
+	       sprintrc(rc));
 
 	puts("+++ exited with 0 +++");
 	return 0;
diff -pruN 5.5-3/tests-m32/move_pages.c 5.9-0ubuntu2/tests-m32/move_pages.c
--- 5.5-3/tests-m32/move_pages.c	2019-07-16 17:46:47.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/move_pages.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of move_pages syscall.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,6 +10,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #ifdef __NR_move_pages
 
@@ -122,15 +123,20 @@ print_status_array(const int *const stat
 }
 
 static void
-print_stat_pages(const unsigned long pid, const unsigned long count,
-		 const void **const pages, int *const status)
+print_stat_pages(const unsigned long pid,
+		 const char *pid_str,
+		 const unsigned long count,
+		 const void **const pages,
+		 int *const status)
 {
 	const unsigned long flags = (unsigned long) 0xfacefeed00000002ULL;
 
 	long rc = syscall(__NR_move_pages,
 			  pid, count, pages, NULL, status, flags);
 	const char *errstr = sprintrc(rc);
-	printf("move_pages(%d, %lu, ", (int) pid, count);
+	pidns_print_leader();
+	printf("move_pages(%d%s, %lu, ", (int) pid, pid_str,
+		count);
 	print_page_array(pages, count, 0);
 	printf(", NULL, ");
 	if (rc) {
@@ -152,6 +158,7 @@ print_stat_pages(const unsigned long pid
 
 static void
 print_move_pages(const unsigned long pid,
+		 const char *pid_str,
 		 unsigned long count,
 		 const unsigned int offset,
 		 const void **const pages,
@@ -164,7 +171,9 @@ print_move_pages(const unsigned long pid
 	long rc = syscall(__NR_move_pages,
 			  pid, count, pages, nodes, status, flags);
 	const char *errstr = sprintrc(rc);
-	printf("move_pages(%d, %lu, ", (int) pid, count);
+	pidns_print_leader();
+	printf("move_pages(%d%s, %lu, ", (int) pid, pid_str,
+		count);
 	print_page_array(pages, count, offset);
 	printf(", ");
 	print_node_array(nodes, count, offset);
@@ -185,8 +194,11 @@ print_move_pages(const unsigned long pid
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	const unsigned long pid =
 		(unsigned long) 0xfacefeed00000000ULL | getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
 	unsigned long count = 1;
 	const unsigned page_size = get_page_size();
 	const void *const page = tail_alloc(page_size);
@@ -195,40 +207,41 @@ main(void)
 	TAIL_ALLOC_OBJECT_VAR_PTR(int, nodes);
 	TAIL_ALLOC_OBJECT_VAR_PTR(int, status);
 
-	print_stat_pages(pid, 0, pages, status);
-	print_move_pages(pid, 0, 0, pages, nodes, status);
-	print_move_pages(pid, 0, 1, pages + 1, nodes + 1, status + 1);
+	print_stat_pages(pid, pid_str, 0, pages, status);
+	print_move_pages(pid, pid_str, 0, 0, pages, nodes, status);
+	print_move_pages(pid, pid_str, 0, 1, pages + 1, nodes + 1, status + 1);
 
 	*pages = page;
-	print_stat_pages(pid, count, pages, status);
+	print_stat_pages(pid, pid_str, count, pages, status);
 	*nodes = 0xdeadbee1;
-	print_move_pages(pid, count, 0, pages, nodes, status);
-	print_move_pages(pid, count, 1, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 0, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 1, pages, nodes, status);
 
 	++count;
 	--status;
 	*(--pages) = efault;
-	print_stat_pages(pid, count, pages, status);
+	print_stat_pages(pid, pid_str, count, pages, status);
 	*(--nodes) = 0xdeadbee2;
-	print_move_pages(pid, count, 0, pages, nodes, status);
-	print_move_pages(pid, count, 1, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 0, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 1, pages, nodes, status);
 
 	++count;
 	--status;
 	*(--pages) = nodes;
-	print_stat_pages(pid, count, pages, status);
+	print_stat_pages(pid, pid_str, count, pages, status);
 	*(--nodes) = 0xdeadbee3;
-	print_move_pages(pid, count, 0, pages, nodes, status);
-	print_move_pages(pid, count, 1, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 0, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 1, pages, nodes, status);
 
 	++count;
 	--status;
 	*(--pages) = status;
-	print_stat_pages(pid, count, pages, status);
+	print_stat_pages(pid, pid_str, count, pages, status);
 	*(--nodes) = 0xdeadbee4;
-	print_move_pages(pid, count, 0, pages, nodes, status);
-	print_move_pages(pid, count, 1, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 0, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 1, pages, nodes, status);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/move_pages--pidns-translation.c 5.9-0ubuntu2/tests-m32/move_pages--pidns-translation.c
--- 5.5-3/tests-m32/move_pages--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/move_pages--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "move_pages.c"
diff -pruN 5.5-3/tests-m32/move_pages--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/move_pages--pidns-translation.gen.test
--- 5.5-3/tests-m32/move_pages--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/move_pages--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (move_pages--pidns-translation test_pidns -s3 -e trace=move_pages); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -s3 -e trace=move_pages
diff -pruN 5.5-3/tests-m32/msg_control.c 5.9-0ubuntu2/tests-m32/msg_control.c
--- 5.5-3/tests-m32/msg_control.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/msg_control.c	2020-04-19 01:22:29.000000000 +0000
@@ -25,6 +25,9 @@
 # include <linux/time_types.h>
 #endif
 
+#include "kernel_timeval.h"
+#include "kernel_old_timespec.h"
+
 #include "xlat.h"
 #define XLAT_MACROS_ONLY
 #include "xlat/sock_options.h"
@@ -214,7 +217,7 @@ test_scm_rights3(struct msghdr *const mh
 static void
 test_scm_timestamp_old(struct msghdr *const mh, void *const page)
 {
-	static const struct timeval tv = {
+	static const kernel_old_timeval_t tv = {
 		.tv_sec = 123456789,
 		.tv_usec = 987654
 	};
@@ -261,7 +264,7 @@ test_scm_timestamp_old(struct msghdr *co
 static void
 test_scm_timestampns_old(struct msghdr *const mh, void *const page)
 {
-	static const struct timespec ts = {
+	static const kernel_old_timespec_t ts = {
 		.tv_sec = 123456789,
 		.tv_nsec = 987654321
 	};
@@ -309,7 +312,7 @@ test_scm_timestampns_old(struct msghdr *
 static void
 test_scm_timestamping_old(struct msghdr *const mh, void *const page)
 {
-	static const struct timespec ts[] = {
+	static const kernel_old_timespec_t ts[] = {
 		{ .tv_sec = 123456789, .tv_nsec = 987654321 },
 		{ .tv_sec = 123456790, .tv_nsec = 987654320 },
 		{ .tv_sec = 123456791, .tv_nsec = 987654319 }
diff -pruN 5.5-3/tests-m32/net--decode-fds-dev-netlink.c 5.9-0ubuntu2/tests-m32/net--decode-fds-dev-netlink.c
--- 5.5-3/tests-m32/net--decode-fds-dev-netlink.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/net--decode-fds-dev-netlink.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_SOCK 1
+#include "net-yy-netlink.c"
diff -pruN 5.5-3/tests-m32/net--decode-fds-dev-netlink.gen.test 5.9-0ubuntu2/tests-m32/net--decode-fds-dev-netlink.gen.test
--- 5.5-3/tests-m32/net--decode-fds-dev-netlink.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/net--decode-fds-dev-netlink.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (net--decode-fds-dev-netlink +net-yy-netlink.test --decode-fds=dev); do not edit.
+set -- --decode-fds=dev
+. "${srcdir=.}/net-yy-netlink.test"
diff -pruN 5.5-3/tests-m32/net--decode-fds-none-netlink.c 5.9-0ubuntu2/tests-m32/net--decode-fds-none-netlink.c
--- 5.5-3/tests-m32/net--decode-fds-none-netlink.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/net--decode-fds-none-netlink.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_SOCK 0
+#include "net-yy-netlink.c"
diff -pruN 5.5-3/tests-m32/net--decode-fds-none-netlink.gen.test 5.9-0ubuntu2/tests-m32/net--decode-fds-none-netlink.gen.test
--- 5.5-3/tests-m32/net--decode-fds-none-netlink.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/net--decode-fds-none-netlink.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (net--decode-fds-none-netlink +net-yy-netlink.test --decode-fds=none -a9); do not edit.
+set -- --decode-fds=none -a9
+. "${srcdir=.}/net-yy-netlink.test"
diff -pruN 5.5-3/tests-m32/net--decode-fds-path-netlink.c 5.9-0ubuntu2/tests-m32/net--decode-fds-path-netlink.c
--- 5.5-3/tests-m32/net--decode-fds-path-netlink.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/net--decode-fds-path-netlink.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_SOCK 1
+#include "net-yy-netlink.c"
diff -pruN 5.5-3/tests-m32/net--decode-fds-path-netlink.gen.test 5.9-0ubuntu2/tests-m32/net--decode-fds-path-netlink.gen.test
--- 5.5-3/tests-m32/net--decode-fds-path-netlink.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/net--decode-fds-path-netlink.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (net--decode-fds-path-netlink +net-yy-netlink.test --decode-fds=path); do not edit.
+set -- --decode-fds=path
+. "${srcdir=.}/net-yy-netlink.test"
diff -pruN 5.5-3/tests-m32/net--decode-fds-socket-netlink.c 5.9-0ubuntu2/tests-m32/net--decode-fds-socket-netlink.c
--- 5.5-3/tests-m32/net--decode-fds-socket-netlink.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/net--decode-fds-socket-netlink.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_SOCK 2
+#include "net-yy-netlink.c"
diff -pruN 5.5-3/tests-m32/net--decode-fds-socket-netlink.gen.test 5.9-0ubuntu2/tests-m32/net--decode-fds-socket-netlink.gen.test
--- 5.5-3/tests-m32/net--decode-fds-socket-netlink.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/net--decode-fds-socket-netlink.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (net--decode-fds-socket-netlink +net-yy-netlink.test --decode-fds=socket); do not edit.
+set -- --decode-fds=socket
+. "${srcdir=.}/net-yy-netlink.test"
diff -pruN 5.5-3/tests-m32/netlink_audit.c 5.9-0ubuntu2/tests-m32/netlink_audit.c
--- 5.5-3/tests-m32/netlink_audit.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/netlink_audit.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,12 +1,13 @@
 /*
  * Copyright (c) 2017 JingPiao Chen <chenjingpiao@gmail.com>
- * Copyright (c) 2017-2018 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include "pidns.h"
 #include <stdio.h>
 #include <string.h>
 #include <unistd.h>
@@ -17,18 +18,23 @@
 static void
 test_nlmsg_type(const int fd)
 {
+	PIDNS_TEST_INIT;
+
 	long rc;
 	struct nlmsghdr nlh = {
 		.nlmsg_len = sizeof(nlh),
 		.nlmsg_type = AUDIT_GET,
 		.nlmsg_flags = NLM_F_REQUEST,
+		.nlmsg_pid = getpid(),
 	};
 
 	rc = sendto(fd, &nlh, sizeof(nlh), MSG_DONTWAIT, NULL, 0);
+	pidns_print_leader();
 	printf("sendto(%d, {len=%u, type=AUDIT_GET"
-	       ", flags=NLM_F_REQUEST, seq=0, pid=0}"
+	       ", flags=NLM_F_REQUEST, seq=0, pid=%d%s}"
 	       ", %u, MSG_DONTWAIT, NULL, 0) = %s\n",
-	       fd, nlh.nlmsg_len, (unsigned) sizeof(nlh), sprintrc(rc));
+	       fd, nlh.nlmsg_len, nlh.nlmsg_pid, pidns_pid2str(PT_TGID),
+	       (unsigned) sizeof(nlh), sprintrc(rc));
 }
 
 int main(void)
@@ -39,6 +45,7 @@ int main(void)
 
 	test_nlmsg_type(fd);
 
+	pidns_print_leader();
 	printf("+++ exited with 0 +++\n");
 
 	return 0;
diff -pruN 5.5-3/tests-m32/netlink_audit--pidns-translation.c 5.9-0ubuntu2/tests-m32/netlink_audit--pidns-translation.c
--- 5.5-3/tests-m32/netlink_audit--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/netlink_audit--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "netlink_audit.c"
diff -pruN 5.5-3/tests-m32/netlink_audit--pidns-translation.test 5.9-0ubuntu2/tests-m32/netlink_audit--pidns-translation.test
--- 5.5-3/tests-m32/netlink_audit--pidns-translation.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/netlink_audit--pidns-translation.test	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,13 @@
+#!/bin/sh
+#
+# Check pidns translation of NETLINK_SOCK_DIAG protocol decoding
+#
+# Copyright (c) 2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: LGPL-2.1-or-later
+
+. "${srcdir=.}/init.sh"
+
+run_prog ../netlink_netlink_diag
+test_pidns -e trace=sendto "$@"
diff -pruN 5.5-3/tests-m32/netlink_protocol.c 5.9-0ubuntu2/tests-m32/netlink_protocol.c
--- 5.5-3/tests-m32/netlink_protocol.c	2018-12-30 15:35:21.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/netlink_protocol.c	2020-08-03 08:00:00.000000000 +0000
@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2014-2017 Dmitry V. Levin <ldv@altlinux.org>
  * Copyright (c) 2016 Fabien Siron <fabien.siron@epita.fr>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -264,7 +264,7 @@ test_nlmsgerr(const int fd)
 	printf("sendto(%d, {{len=%u, type=NLMSG_ERROR, flags=NLM_F_REQUEST"
 	       ", seq=0, pid=0}, {error=-EACCES"
 	       ", msg={len=%u, type=NLMSG_NOOP, flags=NLM_F_REQUEST|0x%x"
-	       ", seq=%u, pid=%u}}}, %u, MSG_DONTWAIT, NULL, 0) = %s\n",
+	       ", seq=%u, pid=%d}}}, %u, MSG_DONTWAIT, NULL, 0) = %s\n",
 	       fd, nlh->nlmsg_len, err->msg.nlmsg_len, NLM_F_DUMP,
 	       err->msg.nlmsg_seq, err->msg.nlmsg_pid,
 	       nlh->nlmsg_len, sprintrc(rc));
@@ -289,7 +289,7 @@ test_nlmsgerr(const int fd)
 	printf("sendto(%d, {{len=%u, type=NLMSG_ERROR, flags=NLM_F_REQUEST"
 	       ", seq=0, pid=0}, {error=-EACCES"
 	       ", msg={{len=%u, type=NLMSG_NOOP, flags=NLM_F_REQUEST|0x%x"
-	       ", seq=%u, pid=%u}, \"\\x61\\x62\\x63\\x64\"}}}"
+	       ", seq=%u, pid=%d}, \"\\x61\\x62\\x63\\x64\"}}}"
 	       ", %u, MSG_DONTWAIT, NULL, 0) = %s\n",
 	       fd, nlh->nlmsg_len, err->msg.nlmsg_len, NLM_F_DUMP,
 	       err->msg.nlmsg_seq, err->msg.nlmsg_pid,
diff -pruN 5.5-3/tests-m32/netlink_sock_diag.test 5.9-0ubuntu2/tests-m32/netlink_sock_diag.test
--- 5.5-3/tests-m32/netlink_sock_diag.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/netlink_sock_diag.test	2020-06-01 14:15:16.000000000 +0000
@@ -2,7 +2,7 @@
 #
 # Check decoding of NETLINK_SOCK_DIAG protocol
 #
-# Copyright (c) 2017-2018 The strace developers.
+# Copyright (c) 2017-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,4 +10,4 @@
 . "${srcdir=.}/init.sh"
 
 run_prog ../netlink_netlink_diag
-run_strace_match_diff -e trace=sendto
+run_strace_match_diff -e trace=sendto "$@"
diff -pruN 5.5-3/tests-m32/netlink_sock_diag-v.sh 5.9-0ubuntu2/tests-m32/netlink_sock_diag-v.sh
--- 5.5-3/tests-m32/netlink_sock_diag-v.sh	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/netlink_sock_diag-v.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,13 +0,0 @@
-#!/bin/sh
-#
-# Check verbose decoding of NETLINK_SOCK_DIAG protocol
-#
-# Copyright (c) 2017-2018 The strace developers.
-# All rights reserved.
-#
-# SPDX-License-Identifier: GPL-2.0-or-later
-
-. "${srcdir=.}/init.sh"
-
-run_prog ../netlink_netlink_diag
-run_strace_match_diff -v -e trace=sendto
diff -pruN 5.5-3/tests-m32/net-sockaddr.c 5.9-0ubuntu2/tests-m32/net-sockaddr.c
--- 5.5-3/tests-m32/net-sockaddr.c	2019-08-29 17:20:57.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/net-sockaddr.c	2020-08-25 14:29:30.000000000 +0000
@@ -2,13 +2,14 @@
  * Check decoding of sockaddr structures
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include "pidns.h"
 #include <stddef.h>
 #include <stdio.h>
 #include <string.h>
@@ -40,18 +41,21 @@ check_un(void)
 	memset(un->sun_path, '0', sizeof(un->sun_path));
 	unsigned int len = sizeof(*un);
 	int ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=\"%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n",
 	       (int) sizeof(un->sun_path), 0, len, ret);
 
 	un->sun_path[1] = 0;
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=\"%u\"}, %u)"
 	       " = %d EBADF (%m)\n", 0, len, ret);
 
 	un->sun_path[0] = 0;
 	un->sun_path[2] = 1;
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=@\"\\0\\001%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n",
 	       (int) sizeof(un->sun_path) - 3, 0, len, ret);
@@ -61,12 +65,14 @@ check_un(void)
 	memset(un->sun_path, '0', sizeof(un->sun_path));
 	len = sizeof(*un) + 2;
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=\"%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n",
 	       (int) sizeof(un->sun_path), 0, len, ret);
 
 	un->sun_path[0] = 0;
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=@\"%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n",
 	       (int) sizeof(un->sun_path) - 1, 0, len, ret);
@@ -75,18 +81,21 @@ check_un(void)
 	un->sun_family = AF_UNIX;
 	len = sizeof(*un) - 2;
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=\"%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n",
 	       (int) sizeof(un->sun_path) - 2, 0, len, ret);
 
 	un->sun_path[0] = 0;
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=@\"%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n",
 	       (int) sizeof(un->sun_path) - 3, 0, len, ret);
 
 	len = sizeof(*un);
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, %p, %u) = %d EBADF (%m)\n", un, len, ret);
 
 	un = tail_alloc(sizeof(struct sockaddr_storage));
@@ -94,12 +103,14 @@ check_un(void)
 	memset(un->sun_path, '0', sizeof(un->sun_path));
 	len = sizeof(struct sockaddr_storage) + 1;
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=\"%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n",
 	       (int) sizeof(un->sun_path), 0, len, ret);
 
 	un->sun_path[0] = 0;
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=@\"%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n",
 	       (int) sizeof(un->sun_path) - 1, 0, len, ret);
@@ -117,6 +128,7 @@ check_in(void)
 	in->sin_addr.s_addr = inet_addr(h_addr);
 	unsigned int len = sizeof(*in);
 	int ret = connect(-1, (void *) in, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_INET, sin_port=htons(%hu)"
 	       ", sin_addr=inet_addr(\"%s\")}, %u) = %d EBADF (%m)\n",
 	       h_port, h_addr, len, ret);
@@ -127,6 +139,7 @@ check_in(void)
 	in->sin_addr.s_addr = inet_addr(h_addr);
 	len = sizeof(*in) + 4;
 	ret = connect(-1, (void *) in, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_INET, sin_port=htons(%hu)"
 	       ", sin_addr=inet_addr(\"%s\")}, %u) = %d EBADF (%m)\n",
 	       h_port, h_addr, len, ret);
@@ -137,6 +150,7 @@ check_in(void)
 	in->sin_addr.s_addr = 0;
 	len = sizeof(*in) - 4;
 	ret = connect(-1, (void *) in, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_INET, sa_data=\"%s\"}, %u)"
 	       " = %d EBADF (%m)\n",
 	       "\\0\\0\\0\\0\\0\\0\\377\\377\\377\\377",
@@ -144,6 +158,7 @@ check_in(void)
 
 	len = sizeof(*in);
 	ret = connect(-1, (void *) in, len);
+	pidns_print_leader();
 	printf("connect(-1, %p, %u) = %d EBADF (%m)\n", in, len, ret);
 }
 
@@ -155,6 +170,7 @@ check_in6_linklocal(struct sockaddr_in6
 	in6->sin6_scope_id = 0xfacefeed;
 	unsigned int len = sizeof(*in6);
 	int ret = connect(-1, (void *) in6, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_INET6, sin6_port=htons(%hu)"
 	       ", sin6_flowinfo=htonl(%u)"
 	       ", inet_pton(AF_INET6, \"%s\", &sin6_addr)"
@@ -166,7 +182,8 @@ check_in6_linklocal(struct sockaddr_in6
 	in6->sin6_scope_id = ifindex_lo();
 	if (in6->sin6_scope_id) {
 		ret = connect(-1, (void *) in6, len);
-		printf("connect(-1, {sa_family=AF_INET6, sin6_port=htons(%hu)"
+		pidns_print_leader();
+	printf("connect(-1, {sa_family=AF_INET6, sin6_port=htons(%hu)"
 		       ", sin6_flowinfo=htonl(%u)"
 		       ", inet_pton(AF_INET6, \"%s\", &sin6_addr)"
 		       ", sin6_scope_id=%s}, %u)"
@@ -191,6 +208,7 @@ check_in6(void)
 	in6->sin6_scope_id = 0xfacefeed;
 	unsigned int len = sizeof(*in6);
 	int ret = connect(-1, (void *) in6, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_INET6, sin6_port=htons(%hu)"
 	       ", sin6_flowinfo=htonl(%u)"
 	       ", inet_pton(AF_INET6, \"%s\", &sin6_addr)"
@@ -209,6 +227,7 @@ check_in6(void)
 	in6->sin6_scope_id = 0xfacefeed;
 	len = sizeof(*in6) + 4;
 	ret = connect(-1, (void *) in6, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_INET6, sin6_port=htons(%hu)"
 	       ", sin6_flowinfo=htonl(%u)"
 	       ", inet_pton(AF_INET6, \"%s\", &sin6_addr)"
@@ -223,6 +242,7 @@ check_in6(void)
 	inet_pton(AF_INET6, h_addr, &in6->sin6_addr);
 	len = sizeof(*in6) - sizeof(in6->sin6_scope_id);
 	ret = connect(-1, (void *) in6, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_INET6, sin6_port=htons(%hu)"
 	       ", sin6_flowinfo=htonl(%u)"
 	       ", inet_pton(AF_INET6, \"%s\", &sin6_addr)}, %u)"
@@ -236,6 +256,7 @@ check_in6(void)
 	memset(&in6->sin6_addr, '0', sizeof(in6->sin6_addr) - 4);
 	len = sizeof(*in6) - sizeof(in6->sin6_scope_id) - 4;
 	ret = connect(-1, (void *) in6, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_INET6"
 	       ", sa_data=\"\\0\\0\\0\\0\\0\\000%.*u\"}, %u)"
 	       " = %d EBADF (%m)\n",
@@ -244,6 +265,7 @@ check_in6(void)
 
 	len = sizeof(*in6) - sizeof(in6->sin6_scope_id);
 	ret = connect(-1, (void *) in6, len);
+	pidns_print_leader();
 	printf("connect(-1, %p, %u) = %d EBADF (%m)\n", in6, len, ret);
 }
 
@@ -262,6 +284,7 @@ check_ipx(void)
 	void *ipx = tail_memdup(&c_ipx, sizeof(c_ipx));
 	unsigned int len = sizeof(c_ipx);
 	int ret = connect(-1, ipx, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_IPX, sipx_port=htons(%u)"
 	       ", sipx_network=htonl(%#x)"
 	       ", sipx_node=[%#02x, %#02x, %#02x, %#02x, %#02x, %#02x]"
@@ -316,18 +339,21 @@ check_ax25(void)
 	fill_memory(sax, size);
 	sax->fsa_ax25.sax25_family = AF_AX25;
 	rc = connect(-1, sax_void, sizeof(struct sockaddr_ax25) - 1);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_AX25, sa_data=\"\\202\\203\\204\\205"
 	       "\\206\\207\\210\\211\\212\\213\\214\\215\\216\"}, %zu) = %s\n",
 	       sizeof(struct sockaddr_ax25) - 1, sprintrc(rc));
 
 	memcpy(sax, &ax25, sizeof(ax25));
 	rc = connect(-1, sax_void, sizeof(struct sockaddr_ax25));
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_AX25, fsa_ax25={sax25_call=VALID-13"
 	       ", sax25_ndigis=8}, fsa_digipeater=[/* ??? */]}, %zu) = %s\n",
 	       sizeof(struct sockaddr_ax25), sprintrc(rc));
 
 	sax->fsa_ax25.sax25_ndigis = 0;
 	rc = connect(-1, sax_void, sizeof(struct sockaddr_ax25));
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_AX25, sax25_call=VALID-13"
 	       ", sax25_ndigis=0}, %zu) = %s\n",
 	       sizeof(struct sockaddr_ax25), sprintrc(rc));
@@ -335,6 +361,7 @@ check_ax25(void)
 	sax->fsa_ax25.sax25_ndigis = 8;
 	size = sizeof(struct sockaddr_ax25) + sizeof(ax25_address) * 3 + 1;
 	rc = connect(-1, sax_void, size);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_AX25, fsa_ax25={sax25_call=VALID-13"
 	       ", sax25_ndigis=8}, fsa_digipeater"
 	       "=[{ax25_call=\"\\xa6\\xa0\\x82\\x40\\x86\\x8a\\x00\""
@@ -348,6 +375,7 @@ check_ax25(void)
 	sax->fsa_digipeater[2].ax25_call[6] = 0x4;
 	size = sizeof(struct sockaddr_ax25) + sizeof(ax25_address) * 4;
 	rc = connect(-1, sax_void, size);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_AX25, fsa_ax25={sax25_call=VALID-13"
 	       ", sax25_ndigis=8}, fsa_digipeater"
 	       "=[{ax25_call=\"\\xa6\\xa0\\x82\\x40\\x86\\x8a\\x00\""
@@ -365,6 +393,7 @@ check_ax25(void)
 	for (size_t i = 0; i < 3; i++) {
 		size = sizeof(ax25) + sizeof(ax25_address) * (i / 2);
 		rc = connect(-1, sax_void, size);
+		pidns_print_leader();
 		printf("connect(-1, {sa_family=AF_AX25"
 		       ", fsa_ax25={sax25_call=VALID-13, sax25_ndigis=%d}"
 		       ", fsa_digipeater=[VALID2-7, OK-15, %s /* FINE-2 */"
@@ -423,25 +452,28 @@ check_x25(void)
 		.sx25_family = AF_X25,
 		.sx25_addr = { "0123456789abcdef" },
 	};
-	void *x25_void = tail_memdup(&c_x25, sizeof(c_x25) + 1);
-	struct sockaddr_x25 *x25 = x25_void;
+	void *const x25_void = tail_memdup(&c_x25, sizeof(c_x25) + 1);
 	long rc;
 
-	rc = connect(-1, x25, sizeof(c_x25) - 1);
+	rc = connect(-1, x25_void, sizeof(c_x25) - 1);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_X25"
 	       ", sa_data=\"0123456789abcde\"}, %zu) = %s\n",
 	       sizeof(c_x25) - 1, sprintrc(rc));
 
 	for (size_t i = 0; i < 2; i++) {
-		rc = connect(-1, x25, sizeof(c_x25) + i);
+		rc = connect(-1, x25_void, sizeof(c_x25) + i);
+		pidns_print_leader();
 		printf("connect(-1, {sa_family=AF_X25"
 		       ", sx25_addr={x25_addr=\"0123456789abcde\"...}"
 		       "}, %zu) = %s\n",
 		       sizeof(c_x25) + i, sprintrc(rc));
 	}
 
+	struct sockaddr_x25 *const x25 = x25_void;
 	x25->sx25_addr.x25_addr[10] = '\0';
-	rc = connect(-1, x25, sizeof(c_x25));
+	rc = connect(-1, x25_void, sizeof(c_x25));
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_X25"
 	       ", sx25_addr={x25_addr=\"0123456789\"}"
 	       "}, %zu) = %s\n",
@@ -457,19 +489,21 @@ check_nl(void)
 	nl->nl_groups = 0xfacefeed;
 	unsigned int len = sizeof(*nl);
 	int ret = connect(-1, (void *) nl, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_NETLINK, nl_pid=%d"
 	       ", nl_groups=%#08x}, %u) = %d EBADF (%m)\n",
 	       nl->nl_pid, nl->nl_groups, len, ret);
 
 	nl = ((void *) nl) - 4;
 	nl->nl_family = AF_NETLINK;
-	nl->nl_pid = 1234567890;
+	nl->nl_pid = getpid();
 	nl->nl_groups = 0xfacefeed;
 	len = sizeof(*nl) + 4;
 	ret = connect(-1, (void *) nl, len);
-	printf("connect(-1, {sa_family=AF_NETLINK, nl_pid=%d"
+	pidns_print_leader();
+	printf("connect(-1, {sa_family=AF_NETLINK, nl_pid=%d%s"
 	       ", nl_groups=%#08x}, %u) = %d EBADF (%m)\n",
-	       nl->nl_pid, nl->nl_groups, len, ret);
+	       nl->nl_pid, pidns_pid2str(PT_TGID), nl->nl_groups, len, ret);
 }
 
 static void
@@ -487,6 +521,7 @@ check_ll(void)
 	void *ll = tail_memdup(&c_ll, sizeof(c_ll));
 	unsigned int len = sizeof(c_ll);
 	int ret = connect(-1, ll, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_PACKET"
 	       ", sll_protocol=htons(ETH_P_ALL)"
 	       ", sll_ifindex=%u, sll_hatype=ARPHRD_ETHER"
@@ -502,6 +537,7 @@ check_ll(void)
 
 	((struct sockaddr_ll *) ll)->sll_halen++;
 	ret = connect(-1, ll, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_PACKET"
 	       ", sll_protocol=htons(ETH_P_ALL)"
 	       ", sll_ifindex=%u, sll_hatype=ARPHRD_ETHER"
@@ -517,6 +553,7 @@ check_ll(void)
 
 	((struct sockaddr_ll *) ll)->sll_halen = 0;
 	ret = connect(-1, ll, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_PACKET"
 	       ", sll_protocol=htons(ETH_P_ALL)"
 	       ", sll_ifindex=%u, sll_hatype=ARPHRD_ETHER"
@@ -526,6 +563,7 @@ check_ll(void)
 	((struct sockaddr_ll *) ll)->sll_ifindex = ifindex_lo();
 	if (((struct sockaddr_ll *) ll)->sll_ifindex) {
 		ret = connect(-1, ll, len);
+	pidns_print_leader();
 		printf("connect(-1, {sa_family=AF_PACKET"
 		       ", sll_protocol=htons(ETH_P_ALL)"
 		       ", sll_ifindex=%s"
@@ -549,11 +587,13 @@ check_hci(void)
 	unsigned int len = sizeof(*hci);
 
 	int ret = connect(-1, (void *) hci, 4);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH, hci_dev=htobs(%hu)"
 	       "}, 4) = %d EBADF (%m)\n",
 	       h_port, ret);
 
 	ret = connect(-1, (void *) hci, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH, hci_dev=htobs(%hu)"
 # ifdef HAVE_STRUCT_SOCKADDR_HCI_HCI_CHANNEL
 	       ", hci_channel=HCI_CHANNEL_RAW"
@@ -572,6 +612,7 @@ check_sco(void)
 	void *sco = tail_memdup(&c_sco, sizeof(c_sco));
 	unsigned int len = sizeof(c_sco);
 	int ret = connect(-1, sco, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH"
 	       ", sco_bdaddr=%02x:%02x:%02x:%02x:%02x:%02x"
 	       "}, %u) = %d EBADF (%m)\n",
@@ -592,6 +633,7 @@ check_rc(void)
 	void *rc = tail_memdup(&c_rc, sizeof(c_rc));
 	unsigned int len = sizeof(c_rc);
 	int ret = connect(-1, rc, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH"
 	       ", rc_bdaddr=%02x:%02x:%02x:%02x:%02x:%02x"
 	       ", rc_channel=%u}, %u) = %d EBADF (%m)\n",
@@ -619,6 +661,7 @@ check_l2(void)
 	unsigned int len = sizeof(c_l2);
 
 	int ret = connect(-1, l2, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH"
 	       ", l2_psm=htobs(L2CAP_PSM_DYN_START + %hu)"
 	       ", l2_bdaddr=%02x:%02x:%02x:%02x:%02x:%02x"
@@ -640,6 +683,7 @@ check_l2(void)
 # endif
 	memcpy(l2, &c_l2, sizeof(c_l2));
 	ret = connect(-1, l2, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH"
 	       ", l2_psm=htobs(L2CAP_PSM_SDP)"
 	       ", l2_bdaddr=%02x:%02x:%02x:%02x:%02x:%02x"
@@ -660,6 +704,7 @@ check_l2(void)
 # endif
 	memcpy(l2, &c_l2, sizeof(c_l2));
 	ret = connect(-1, l2, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH"
 	       ", l2_psm=htobs(0xbad /* L2CAP_PSM_??? */)"
 	       ", l2_bdaddr=%02x:%02x:%02x:%02x:%02x:%02x"
@@ -677,6 +722,7 @@ check_l2(void)
 	c_l2.l2_cid = htobs(0xffff);
 	memcpy(l2, &c_l2, 12);
 	ret = connect(-1, l2, 12);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH"
 	       ", l2_psm=htobs(L2CAP_PSM_AUTO_END)"
 	       ", l2_bdaddr=%02x:%02x:%02x:%02x:%02x:%02x"
@@ -700,6 +746,7 @@ check_raw(void)
 	u.sa->sa_family = 0xff;
 	unsigned int len = sizeof(*u.st) + 8;
 	int ret = connect(-1, (void *) u.st, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=%#x /* AF_??? */, sa_data=\"%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n", u.sa->sa_family,
 	       (int) (sizeof(*u.st) - sizeof(u.sa->sa_family)), 0, len, ret);
@@ -707,11 +754,13 @@ check_raw(void)
 	u.sa->sa_family = 0;
 	len = sizeof(u.sa->sa_family) + 1;
 	ret = connect(-1, (void *) u.st, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNSPEC, sa_data=\"0\"}, %u)"
 	       " = %d EBADF (%m)\n", len, ret);
 
 	u.sa->sa_family = AF_BLUETOOTH;
 	ret = connect(-1, (void *) u.st, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH, sa_data=\"0\"}, %u)"
 	       " = %d EBADF (%m)\n", len, ret);
 }
@@ -719,6 +768,8 @@ check_raw(void)
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	check_un();
 	check_in();
 	check_in6();
@@ -735,6 +786,7 @@ main(void)
 #endif
 	check_raw();
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/net-sockaddr--pidns-translation.c 5.9-0ubuntu2/tests-m32/net-sockaddr--pidns-translation.c
--- 5.5-3/tests-m32/net-sockaddr--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/net-sockaddr--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "net-sockaddr.c"
diff -pruN 5.5-3/tests-m32/net-sockaddr--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/net-sockaddr--pidns-translation.gen.test
--- 5.5-3/tests-m32/net-sockaddr--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/net-sockaddr--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (net-sockaddr--pidns-translation test_pidns -a24 -e trace=connect); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a24 -e trace=connect
diff -pruN 5.5-3/tests-m32/net-yy-netlink.c 5.9-0ubuntu2/tests-m32/net-yy-netlink.c
--- 5.5-3/tests-m32/net-yy-netlink.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/net-yy-netlink.c	2020-07-18 08:00:00.000000000 +0000
@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2013-2017 Dmitry V. Levin <ldv@altlinux.org>
  * Copyright (c) 2016 Fabien Siron <fabien.siron@epita.fr>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -21,6 +21,27 @@
 #include <linux/sock_diag.h>
 #include <linux/netlink_diag.h>
 
+#ifndef PRINT_SOCK
+# define PRINT_SOCK 2
+#endif
+
+#if PRINT_SOCK == 2
+# define FMT_UNBOUND "<NETLINK:[%lu]>"
+# define FMT_BOUND   "<NETLINK:[SOCK_DIAG:%u]>"
+# define ARG_UNBOUND inode
+# define ARG_BOUND   addr.nl_pid
+#elif PRINT_SOCK == 1
+# define FMT_UNBOUND "<socket:[%lu]>"
+# define FMT_BOUND   "<socket:[%lu]>"
+# define ARG_UNBOUND inode
+# define ARG_BOUND   inode
+#else
+# define FMT_UNBOUND "%s"
+# define FMT_BOUND   "%s"
+# define ARG_UNBOUND ""
+# define ARG_BOUND   ""
+#endif
+
 int
 main(void)
 {
@@ -37,25 +58,27 @@ main(void)
 	const int fd = socket(AF_NETLINK, SOCK_RAW, NETLINK_SOCK_DIAG);
 	if (fd < 0)
 		perror_msg_and_skip("socket");
+#if PRINT_SOCK
 	const unsigned long inode = inode_of_sockfd(fd);
+#endif
 	printf("socket(AF_NETLINK, SOCK_RAW, NETLINK_SOCK_DIAG) = "
-	       "%d<NETLINK:[%lu]>\n", fd, inode);
+	       "%d" FMT_UNBOUND "\n", fd, ARG_UNBOUND);
 
 	if (bind(fd, sa, *len))
 		perror_msg_and_skip("bind");
-	printf("bind(%d<NETLINK:[%lu]>, {sa_family=AF_NETLINK"
-	       ", nl_pid=%u, nl_groups=00000000}, %u) = 0\n",
-	       fd, inode, addr.nl_pid, (unsigned) *len);
+	printf("bind(%d" FMT_UNBOUND ", {sa_family=AF_NETLINK"
+	       ", nl_pid=%d, nl_groups=00000000}, %u) = 0\n",
+	       fd, ARG_UNBOUND, addr.nl_pid, (unsigned) *len);
 
 	if (getsockname(fd, sa, len))
 		perror_msg_and_fail("getsockname");
-	printf("getsockname(%d<NETLINK:[SOCK_DIAG:%u]>, {sa_family=AF_NETLINK"
-	       ", nl_pid=%u, nl_groups=00000000}, [%u]) = 0\n",
-	       fd, addr.nl_pid, addr.nl_pid, (unsigned) *len);
+	printf("getsockname(%d" FMT_BOUND ", {sa_family=AF_NETLINK"
+	       ", nl_pid=%d, nl_groups=00000000}, [%u]) = 0\n",
+	       fd, ARG_BOUND, addr.nl_pid, (unsigned) *len);
 
 	if (close(fd))
 		perror_msg_and_fail("close");
-	printf("close(%d<NETLINK:[SOCK_DIAG:%u]>) = 0\n", fd, addr.nl_pid);
+	printf("close(%d" FMT_BOUND ") = 0\n", fd, ARG_BOUND);
 
 	puts("+++ exited with 0 +++");
 	return 0;
diff -pruN 5.5-3/tests-m32/net-yy-netlink.test 5.9-0ubuntu2/tests-m32/net-yy-netlink.test
--- 5.5-3/tests-m32/net-yy-netlink.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/net-yy-netlink.test	2020-04-03 22:58:26.000000000 +0000
@@ -6,7 +6,7 @@
 # Copyright (c) 2014 Masatake YAMATO <yamato@redhat.com>
 # Copyright (c) 2014-2016 Dmitry V. Levin <ldv@altlinux.org>
 # Copyright (c) 2016 Fabien Siron <fabien.siron@epita.fr>
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -15,9 +15,11 @@
 
 check_prog sed
 
+opts="${*:--yy}"
+
 run_prog ../netlink_netlink_diag
 run_prog > /dev/null
-run_strace -a22 -yy -eclose,network $args > "$EXP"
+run_strace -a22 ${opts} -eclose,network $args > "$EXP"
 
 # Filter out close() calls made by ld.so and libc.
 sed -n '/socket/,$p' < "$LOG" > "$OUT"
diff -pruN 5.5-3/tests-m32/nlattr_ifinfomsg.c 5.9-0ubuntu2/tests-m32/nlattr_ifinfomsg.c
--- 5.5-3/tests-m32/nlattr_ifinfomsg.c	2019-11-28 19:30:05.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/nlattr_ifinfomsg.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2017 JingPiao Chen <chenjingpiao@gmail.com>
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -27,6 +27,8 @@
 #endif
 #define IFLA_LINK_NETNSID 37
 #define IFLA_EVENT 44
+#define IFLA_PROP_LIST 52
+#define IFLA_ALT_IFNAME 53
 
 #ifndef IFLA_INFO_KIND
 # define IFLA_INFO_KIND 1
@@ -36,6 +38,8 @@
 # define IFLA_VF_PORT 1
 #endif
 
+static const unsigned int hdrlen = sizeof(struct ifinfomsg);
+
 static void
 init_ifinfomsg(struct nlmsghdr *const nlh, const unsigned int msg_len)
 {
@@ -65,6 +69,27 @@ print_ifinfomsg(const unsigned int msg_l
 	       msg_len);
 }
 
+static void
+init_prop_list_msg(struct nlmsghdr *const nlh,
+		     const unsigned int msg_len)
+{
+	init_ifinfomsg(nlh, msg_len);
+
+	struct nlattr *nla = NLMSG_ATTR(nlh, hdrlen);
+	SET_STRUCT(struct nlattr, nla,
+		.nla_len = msg_len - NLMSG_SPACE(hdrlen),
+		.nla_type = IFLA_PROP_LIST,
+	);
+}
+
+static void
+print_prop_list_msg(const unsigned int msg_len)
+{
+	print_ifinfomsg(msg_len);
+	printf(", {{nla_len=%u, nla_type=IFLA_PROP_LIST}",
+	       msg_len - NLMSG_SPACE(hdrlen));
+}
+
 int
 main(void)
 {
@@ -96,9 +121,8 @@ main(void)
 		.tx_compressed = 0xefdadfab
 	};
 	const int fd = create_nl_socket(NETLINK_ROUTE);
-	const unsigned int hdrlen = sizeof(struct ifinfomsg);
 	void *nlh0 = midtail_alloc(NLMSG_SPACE(hdrlen),
-				   NLA_HDRLEN + sizeof(st));
+				   2 * NLA_HDRLEN + MAX(sizeof(st), 20));
 
 	static char pattern[4096];
 	fill_memory_ex(pattern, sizeof(pattern), 'a', 'z' - 'a' + 1);
@@ -339,6 +363,33 @@ main(void)
 				   printf("%s", ifla_events[i].str));
 	}
 
+	/* IFLA_PROP_LIST */
+	struct {
+		char p1[20];
+	} buf;
+	fill_memory(&buf, sizeof(buf));
+	TEST_NESTED_NLATTR_OBJECT_EX_(fd, nlh0, hdrlen,
+				      init_prop_list_msg, print_prop_list_msg,
+				      IFLA_ALT_IFNAME, "IFLA_ALT_IFNAME",
+				      pattern, buf, print_quoted_stringn, 1,
+				      print_quoted_memory(&buf, sizeof(buf));
+				      printf("..."));
+
+	/* IFLA_ALT_IFNAME */
+	static const char alt_ifname[] = "OH HAI THAR\r\n\t\377\0\v\x7e";
+	TEST_NLATTR(fd, nlh0, hdrlen,
+		    init_ifinfomsg, print_ifinfomsg,
+		    IFLA_ALT_IFNAME,
+		    sizeof(alt_ifname), alt_ifname, sizeof(alt_ifname),
+		    print_quoted_memory(alt_ifname, sizeof(alt_ifname) - 1));
+
+	TEST_NLATTR(fd, nlh0, hdrlen,
+		    init_ifinfomsg, print_ifinfomsg,
+		    IFLA_ALT_IFNAME,
+		    sizeof(alt_ifname) - 1, alt_ifname, sizeof(alt_ifname) - 1,
+		    print_quoted_memory(alt_ifname, sizeof(alt_ifname) - 1);
+		    printf("..."));
+
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/nlattr_ifla_linkinfo.c 5.9-0ubuntu2/tests-m32/nlattr_ifla_linkinfo.c
--- 5.5-3/tests-m32/nlattr_ifla_linkinfo.c	2019-03-18 02:40:16.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/nlattr_ifla_linkinfo.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * IFLA_LINKINFO netlink attribute decoding check.
  *
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -347,7 +347,6 @@ main(void)
 	/* bridge attrs */
 	static const struct val_name und_br_attrs[] = {
 		{ 0, "IFLA_BR_UNSPEC" },
-		{ 20, "IFLA_BR_GROUP_ADDR" },
 		{ 21, "IFLA_BR_FDB_FLUSH" },
 		{ 40, "IFLA_BR_PAD" },
 		{ 47, "0x2f /* IFLA_BR_??? */" },
@@ -367,6 +366,21 @@ main(void)
 					"\\x63\\x64\\x65\\x66\"" });
 	}
 
+	static const struct val_name hwa_br_attrs[] = {
+		{ 20, "IFLA_BR_GROUP_ADDR" },
+	};
+
+	for (size_t k = 0; k < ARRAY_SIZE(hwa_br_attrs); k++) {
+		TEST_NESTED_LINKINFO(fd, nlh0, 2, "IFLA_INFO_DATA", "bridge",
+				     hwa_br_attrs[k].val, hwa_br_attrs[k].name,
+				     unknown_msg, pattern,
+				     { 2, "ab:ac" },
+				     { 4, "ab:ac:db:cd" },
+				     { 6, "ab:ac:db:cd:61:62" },
+				     { 8, "ab:ac:db:cd:61:62:63:64" },
+				     { 10, "ab:ac:db:cd:61:62:63:64:65:66" });
+	}
+
 	static const struct val_name u64_br_attrs[] = {
 		{ 16, "IFLA_BR_HELLO_TIMER" },
 		{ 17, "IFLA_BR_TCN_TIMER" },
diff -pruN 5.5-3/tests-m32/nlattr_ifla_xdp.c 5.9-0ubuntu2/tests-m32/nlattr_ifla_xdp.c
--- 5.5-3/tests-m32/nlattr_ifla_xdp.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/nlattr_ifla_xdp.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2017 JingPiao Chen <chenjingpiao@gmail.com>
- * Copyright (c) 2017-2018 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -17,44 +17,28 @@
 #endif
 #include <linux/rtnetlink.h>
 
+#define XLAT_MACROS_ONLY
+# include "xlat/rtnl_ifla_xdp_attrs.h"
+#undef XLAT_MACROS_ONLY
+
 #if !HAVE_DECL_IFLA_XDP
 enum { IFLA_XDP = 43 };
 #endif
-#ifndef IFLA_XDP_FD
-# define IFLA_XDP_FD 1
-#endif
-
-#ifndef IFLA_XDP_ATTACHED
-# define IFLA_XDP_ATTACHED 2
-#endif
-
-#ifndef IFLA_XDP_PROG_ID
-# define IFLA_XDP_PROG_ID 4
-#endif
-
-#ifndef IFLA_XDP_DRV_PROG_ID
-# define IFLA_XDP_DRV_PROG_ID 5
-#endif
 
-#ifndef IFLA_XDP_SKB_PROG_ID
-# define IFLA_XDP_SKB_PROG_ID 6
+#if !HAVE_DECL_XDP_ATTACHED_NONE
+enum { XDP_ATTACHED_NONE = 0 };
 #endif
-
-#ifndef IFLA_XDP_HW_PROG_ID
-# define IFLA_XDP_HW_PROG_ID 7
-#endif
-
-#ifndef XDP_ATTACHED_NONE
-# define XDP_ATTACHED_NONE 0
-#endif
-
-#ifndef XDP_ATTACHED_MULTI
-# define XDP_ATTACHED_MULTI 4
+#if !HAVE_DECL_XDP_ATTACHED_MULTI
+enum { XDP_ATTACHED_MULTI = 4 };
 #endif
 
 #define IFLA_ATTR IFLA_XDP
 #include "nlattr_ifla.h"
 
+#ifndef FD9_PATH
+# define FD9_PATH ""
+#endif
+
 int
 main(void)
 {
@@ -118,6 +102,18 @@ main(void)
 					      printf("%u", num));
 	}
 
+	/* IFLA_XDP_EXPECTED_FD */
+	TEST_NESTED_NLATTR_OBJECT_EX(fd, nlh0, hdrlen,
+				     init_ifinfomsg, print_ifinfomsg,
+				     IFLA_XDP_EXPECTED_FD, pattern, num, 1,
+				     printf("%d", num));
+
+	int exp_fd = 9;
+	TEST_NESTED_NLATTR_OBJECT_EX(fd, nlh0, hdrlen,
+				     init_ifinfomsg, print_ifinfomsg,
+				     IFLA_XDP_EXPECTED_FD, pattern, exp_fd, 1,
+				     printf("9" FD9_PATH));
+
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/nlattr_ifla_xdp-y.c 5.9-0ubuntu2/tests-m32/nlattr_ifla_xdp-y.c
--- 5.5-3/tests-m32/nlattr_ifla_xdp-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/nlattr_ifla_xdp-y.c	2020-05-30 08:00:00.000000000 +0000
@@ -0,0 +1,3 @@
+#define PRINT_SOCK 1
+#define FD9_PATH "</dev/full>"
+#include "nlattr_ifla_xdp.c"
diff -pruN 5.5-3/tests-m32/nlattr_ifla_xdp-y.gen.test 5.9-0ubuntu2/tests-m32/nlattr_ifla_xdp-y.gen.test
--- 5.5-3/tests-m32/nlattr_ifla_xdp-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/nlattr_ifla_xdp-y.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (nlattr_ifla_xdp-y +netlink_sock_diag.test -y; exec 9</dev/full); do not edit.
+set -- -y; exec 9</dev/full
+. "${srcdir=.}/netlink_sock_diag.test"
diff -pruN 5.5-3/tests-m32/nlattr_inet_diag_req_compat.c 5.9-0ubuntu2/tests-m32/nlattr_inet_diag_req_compat.c
--- 5.5-3/tests-m32/nlattr_inet_diag_req_compat.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/nlattr_inet_diag_req_compat.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2017 JingPiao Chen <chenjingpiao@gmail.com>
- * Copyright (c) 2017-2018 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -73,10 +73,10 @@ main(void)
 
 	char nla_type_str[256];
 	sprintf(nla_type_str, "%#x /* INET_DIAG_REQ_??? */",
-		INET_DIAG_REQ_BYTECODE + 1);
+		INET_DIAG_REQ_PROTOCOL + 1);
 	TEST_NLATTR_(fd, nlh0, hdrlen,
 		     init_inet_diag_req, print_inet_diag_req,
-		     INET_DIAG_REQ_BYTECODE + 1, nla_type_str,
+		     INET_DIAG_REQ_PROTOCOL + 1, nla_type_str,
 		     4, pattern, 4,
 		     print_quoted_hex(pattern, 4));
 
diff -pruN 5.5-3/tests-m32/nlattr_ndmsg.c 5.9-0ubuntu2/tests-m32/nlattr_ndmsg.c
--- 5.5-3/tests-m32/nlattr_ndmsg.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/nlattr_ndmsg.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2017 JingPiao Chen <chenjingpiao@gmail.com>
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -100,11 +100,15 @@ main(void)
 			   printf("htons(%u)", ntohs(port)));
 
 	static const uint8_t mac[6] = "\xf8\xc2\x49\x13\x57\xbd";
-	TEST_NLATTR_OBJECT(fd, nlh0, hdrlen,
-			   init_ndmsg, print_ndmsg,
-			   NDA_LLADDR, pattern, mac,
-			   for (unsigned int i = 0; i < sizeof(mac); ++i)
-				printf("%s%02x", i ? ":" : "", mac[i]));
+	TEST_NLATTR(fd, nlh0, hdrlen, init_ndmsg, print_ndmsg,
+		    NDA_LLADDR, sizeof(mac) - 1, mac, sizeof(mac) - 1,
+		    for (unsigned int i = 0; i < sizeof(mac) - 1; ++i)
+			printf("%s%02x", i ? ":" : "", mac[i]));
+
+	TEST_NLATTR(fd, nlh0, hdrlen, init_ndmsg, print_ndmsg,
+		    NDA_LLADDR, sizeof(mac), mac, sizeof(mac),
+		    for (unsigned int i = 0; i < sizeof(mac); ++i)
+			printf("%s%02x", i ? ":" : "", mac[i]));
 
 	puts("+++ exited with 0 +++");
 	return 0;
diff -pruN 5.5-3/tests-m32/nlattr_packet_diag_msg.gen.test 5.9-0ubuntu2/tests-m32/nlattr_packet_diag_msg.gen.test
--- 5.5-3/tests-m32/nlattr_packet_diag_msg.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/nlattr_packet_diag_msg.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -1,4 +1,4 @@
 #!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (nlattr_packet_diag_msg +netlink_sock_diag-v.sh ); do not edit.
-set -- 
-. "${srcdir=.}/netlink_sock_diag-v.sh"
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (nlattr_packet_diag_msg +netlink_sock_diag.test -v); do not edit.
+set -- -v
+. "${srcdir=.}/netlink_sock_diag.test"
diff -pruN 5.5-3/tests-m32/nlattr_tcamsg.c 5.9-0ubuntu2/tests-m32/nlattr_tcamsg.c
--- 5.5-3/tests-m32/nlattr_tcamsg.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/nlattr_tcamsg.c	2020-05-30 08:00:00.000000000 +0000
@@ -22,6 +22,12 @@ enum { TCA_ACT_COOKIE = 6 };
 #if !HAVE_DECL_TCA_ACT_FLAGS
 enum { TCA_ACT_FLAGS = 7 };
 #endif
+#if !HAVE_DECL_TCA_ACT_HW_STATS
+enum { TCA_ACT_HW_STATS = 8 };
+#endif
+#if !HAVE_DECL_TCA_ACT_USED_HW_STATS
+enum { TCA_ACT_USED_HW_STATS = 9 };
+#endif
 
 
 static void
@@ -60,7 +66,7 @@ main(void)
 	fill_memory_ex(pattern, sizeof(pattern), 'a', 'z' - 'a' + 1);
 
 	/* Invalid */
-	static const unsigned int nla_invalid[] = { 8, 0xffff & NLA_TYPE_MASK };
+	static const unsigned int nla_invalid[] = { 10, 0xffff & NLA_TYPE_MASK };
 	for (size_t i = 0; i < ARRAY_SIZE(nla_invalid); i++) {
 		char nla_type_str[256];
 		sprintf(nla_type_str, "%#x /* TCA_ACT_??? */", nla_invalid[i]);
@@ -111,6 +117,21 @@ main(void)
 		    TCA_ACT_FLAGS, sizeof(flags), &flags, sizeof(flags),
 		    printf("TCA_ACT_FLAGS_NO_PERCPU_STATS|0xfacebeee"));
 
+	/* TCA_ACT_HW_STATS, TCA_ACT_USED_HW_STATS */
+	static const struct strval32 nla_hw_st[] = {
+		{ ARG_STR(TCA_ACT_HW_STATS) },
+		{ ARG_STR(TCA_ACT_USED_HW_STATS) },
+	};
+
+	static uint32_t hw_st = 0xfacebeef;
+	for (size_t i = 0; i < ARRAY_SIZE(nla_hw_st); i++) {
+		TEST_NLATTR_(fd, nlh0, hdrlen, init_tcamsg, print_tcamsg,
+			     nla_hw_st[i].val, nla_hw_st[i].str,
+			     sizeof(hw_st), &hw_st, sizeof(hw_st),
+			     printf("TCA_ACT_HW_STATS_IMMEDIATE|"
+				    "TCA_ACT_HW_STATS_DELAYED|0xfacebeec"));
+	}
+
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/nlattr_tc_stats.c 5.9-0ubuntu2/tests-m32/nlattr_tc_stats.c
--- 5.5-3/tests-m32/nlattr_tc_stats.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/nlattr_tc_stats.c	2020-04-03 22:58:26.000000000 +0000
@@ -16,9 +16,9 @@
 # include <linux/gen_stats.h>
 # include <linux/rtnetlink.h>
 
-#if !HAVE_DECL_TCA_STATS_PKT64
+# if !HAVE_DECL_TCA_STATS_PKT64
 enum { TCA_STATS_PKT64 = 8 };
-#endif
+# endif
 
 const unsigned int hdrlen = sizeof(struct tcmsg);
 
diff -pruN 5.5-3/tests-m32/nsyscalls-d.test 5.9-0ubuntu2/tests-m32/nsyscalls-d.test
--- 5.5-3/tests-m32/nsyscalls-d.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/nsyscalls-d.test	2020-04-03 22:58:26.000000000 +0000
@@ -1,8 +1,8 @@
 #!/bin/sh
 #
-# Check decoding of out-of-range syscalls along with debug ouput
+# Check decoding of out-of-range syscalls along with debug output
 #
-# Copyright (c) 2017-2018 The strace developers.
+# Copyright (c) 2017-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
diff -pruN 5.5-3/tests-m32/openat2.c 5.9-0ubuntu2/tests-m32/openat2.c
--- 5.5-3/tests-m32/openat2.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/openat2.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,172 @@
+/*
+ * Check decoding of openat2 syscall.
+ *
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+
+#ifdef __NR_openat2
+
+# include <errno.h>
+# include <stdint.h>
+# include <inttypes.h>
+# include <stdio.h>
+# include <string.h>
+# include <unistd.h>
+# include <asm/fcntl.h>
+
+# ifdef HAVE_LINUX_OPENAT2
+#  include <linux/openat2.h>
+# endif
+
+# ifndef HAVE_LINUX_OPENAT2
+struct open_how {
+	uint64_t flags;
+	uint64_t mode;
+	uint64_t resolve;
+};
+# endif
+
+# ifndef AT_FDCWD
+#  define AT_FDCWD -100
+# endif
+# ifndef RESOLVE_NO_XDEV
+#  define RESOLVE_NO_XDEV 0x01
+# endif
+# ifndef RESOLVE_IN_ROOT
+#  define RESOLVE_IN_ROOT 0x10
+# endif
+
+# ifndef O_TMPFILE
+#  if defined __hppa__
+#   define __O_TMPFILE     040000000
+#  elif defined __alpha__
+#   define __O_TMPFILE     0100000000
+#  elif defined __sparc__
+#   define __O_TMPFILE     0200000000
+#  else
+#   define __O_TMPFILE     020000000
+#  endif
+# endif
+
+# ifndef VERBOSE
+#  define VERBOSE 0
+# endif
+# ifndef FD0_PATH
+#  define FD0_PATH ""
+# endif
+
+static const char sample[] = "openat2.sample";
+
+int
+main(void)
+{
+	long rc;
+	const char *rcstr;
+	struct open_how *how = tail_alloc(sizeof(*how));
+	struct open_how *how_big = tail_alloc(sizeof(*how_big) + 8);
+
+	rc = syscall(__NR_openat2, 0, NULL, NULL,
+		     (kernel_ulong_t) 0xdeadc0debadc0dedULL);
+	printf("openat2(0" FD0_PATH ", NULL, NULL, %llu) = %s\n",
+	       (unsigned long long) (kernel_ulong_t) 0xdeadc0debadc0dedULL,
+	       sprintrc(rc));
+
+	rc = syscall(__NR_openat2, -100, "", how + 1, sizeof(*how));
+	printf("openat2(%s, \"\", %p, %zu) = %s\n",
+	       XLAT_KNOWN(-100, "AT_FDCWD"), how + 1, sizeof(*how),
+	       sprintrc(rc));
+
+	rc = syscall(__NR_openat2, -1, sample, how, 11);
+	printf("openat2(-1, \"%s\", %p, 11) = %s\n", sample, how, sprintrc(rc));
+
+	static struct strval64 flags[] = {
+		{ ARG_STR(O_RDONLY|O_EXCL) },
+		{ ARG_STR(O_WRONLY|O_CREAT) },
+		{ ARG_STR(O_RDWR|O_LARGEFILE) },
+# ifdef O_TMPFILE
+		{ ARG_STR(O_ACCMODE|O_TMPFILE) },
+# else
+		{ ARG_STR(O_ACCMODE|__O_TMPFILE) },
+# endif
+		{ ARG_ULL_STR(O_RDONLY|0xdeadface80000000) },
+	};
+	static uint64_t modes[] = { 0, 0777, 0xbadc0dedfacebeefULL };
+	static struct strval64 resolve[] = {
+		{ 0, NULL },
+		{ ARG_STR(RESOLVE_NO_XDEV) },
+		{ ARG_ULL_STR(RESOLVE_NO_XDEV|RESOLVE_IN_ROOT|0xfeedfacedcaffee0) },
+		{ 0xdec0dedbeefface0, NULL },
+	};
+	const size_t iters = MAX(MAX(ARRAY_SIZE(flags), ARRAY_SIZE(modes)),
+				 ARRAY_SIZE(resolve));
+
+
+	for (size_t i = 0; i < iters * 4; i++) {
+		how->flags = flags[i % ARRAY_SIZE(flags)].val;
+		how->mode = modes[i % ARRAY_SIZE(modes)];
+		how->resolve = resolve[i % ARRAY_SIZE(resolve)].val;
+
+		fill_memory(how_big + 1, 8);
+		memcpy(how_big, how, sizeof(*how));
+
+		for (size_t j = 0; j < 4; j++) {
+			rc = syscall(__NR_openat2, -1, sample,
+				     j > 1 ? how_big : how,
+				     j ? sizeof(*how) + 8 : sizeof(*how));
+			rcstr = sprintrc(rc);
+			printf("openat2(-1, \"%s\", {flags=%s",
+			       sample,
+			       sprintxlat(flags[i % ARRAY_SIZE(flags)].str,
+					  flags[i % ARRAY_SIZE(flags)].val,
+					  NULL));
+
+			if (how->mode || (i % ARRAY_SIZE(flags) == 1)
+				      || (i % ARRAY_SIZE(flags) == 3)) {
+				printf(", mode=%#03" PRIo64,
+				       modes[i % ARRAY_SIZE(modes)]);
+			}
+
+			printf(", resolve=%s",
+			       sprintxlat(resolve[i % ARRAY_SIZE(resolve)].str,
+					  resolve[i % ARRAY_SIZE(resolve)].val,
+					  resolve[i % ARRAY_SIZE(resolve)].val
+						? "RESOLVE_???" : NULL));
+			if (j == 1)
+				printf(", ???");
+			if (j == 2) {
+				printf(", /* bytes %zu..%zu */ \"\\x80\\x81"
+				       "\\x82\\x83\\x84\\x85\\x86\\x87\"",
+				       sizeof(*how), sizeof(*how) + 7);
+			}
+			printf("}, %zu) = %s\n",
+			       j ? sizeof(*how) + 8 : sizeof(*how), rcstr);
+
+			if (j == 2)
+				memset(how_big + 1, 0, 8);
+		}
+	}
+
+	how->flags = O_RDONLY | O_NOCTTY;
+	how->mode = 0;
+	how->resolve = 0;
+	rc = syscall(__NR_openat2, -100, "/dev/full", how, sizeof(*how));
+	printf("openat2(%s, \"/dev/full\", {flags=%s, resolve=0}, %zu)"
+	       " = %s%s\n",
+	       XLAT_KNOWN(-100, "AT_FDCWD"), XLAT_STR(O_RDONLY|O_NOCTTY),
+	       sizeof(*how), sprintrc(rc), rc >= 0 ? FD0_PATH : "");
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_openat2");
+
+#endif
diff -pruN 5.5-3/tests-m32/openat2.gen.test 5.9-0ubuntu2/tests-m32/openat2.gen.test
--- 5.5-3/tests-m32/openat2.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/openat2.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2 -a35 ); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a35 
diff -pruN 5.5-3/tests-m32/openat2-v.c 5.9-0ubuntu2/tests-m32/openat2-v.c
--- 5.5-3/tests-m32/openat2-v.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/openat2-v.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define VERBOSE 1
+#include "openat2.c"
diff -pruN 5.5-3/tests-m32/openat2-v.gen.test 5.9-0ubuntu2/tests-m32/openat2-v.gen.test
--- 5.5-3/tests-m32/openat2-v.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/openat2-v.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-v --trace=openat2 -a35 -v); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a35 -v
diff -pruN 5.5-3/tests-m32/openat2-v-y.c 5.9-0ubuntu2/tests-m32/openat2-v-y.c
--- 5.5-3/tests-m32/openat2-v-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/openat2-v-y.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define FD0_PATH "</dev/full>"
+#include "openat2-v.c"
diff -pruN 5.5-3/tests-m32/openat2-v-y.gen.test 5.9-0ubuntu2/tests-m32/openat2-v-y.gen.test
--- 5.5-3/tests-m32/openat2-v-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/openat2-v-y.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-v-y --trace=openat2 -a36 -v -y </dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a36 -v -y </dev/full
diff -pruN 5.5-3/tests-m32/openat2-v-y-Xabbrev.c 5.9-0ubuntu2/tests-m32/openat2-v-y-Xabbrev.c
--- 5.5-3/tests-m32/openat2-v-y-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/openat2-v-y-Xabbrev.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "openat2-v-y.c"
diff -pruN 5.5-3/tests-m32/openat2-v-y-Xabbrev.gen.test 5.9-0ubuntu2/tests-m32/openat2-v-y-Xabbrev.gen.test
--- 5.5-3/tests-m32/openat2-v-y-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/openat2-v-y-Xabbrev.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-v-y-Xabbrev --trace=openat2 -a35 -v -y -Xabbrev </dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a35 -v -y -Xabbrev </dev/full
diff -pruN 5.5-3/tests-m32/openat2-v-y-Xraw.c 5.9-0ubuntu2/tests-m32/openat2-v-y-Xraw.c
--- 5.5-3/tests-m32/openat2-v-y-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/openat2-v-y-Xraw.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "openat2-v-y.c"
diff -pruN 5.5-3/tests-m32/openat2-v-y-Xraw.gen.test 5.9-0ubuntu2/tests-m32/openat2-v-y-Xraw.gen.test
--- 5.5-3/tests-m32/openat2-v-y-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/openat2-v-y-Xraw.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-v-y-Xraw --trace=openat2 -a32 -v -y -Xraw </dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a32 -v -y -Xraw </dev/full
diff -pruN 5.5-3/tests-m32/openat2-v-y-Xverbose.c 5.9-0ubuntu2/tests-m32/openat2-v-y-Xverbose.c
--- 5.5-3/tests-m32/openat2-v-y-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/openat2-v-y-Xverbose.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "openat2-v-y.c"
diff -pruN 5.5-3/tests-m32/openat2-v-y-Xverbose.gen.test 5.9-0ubuntu2/tests-m32/openat2-v-y-Xverbose.gen.test
--- 5.5-3/tests-m32/openat2-v-y-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/openat2-v-y-Xverbose.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-v-y-Xverbose --trace=openat2 -a44 -v -y -Xverbose </dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a44 -v -y -Xverbose </dev/full
diff -pruN 5.5-3/tests-m32/openat2-Xabbrev.c 5.9-0ubuntu2/tests-m32/openat2-Xabbrev.c
--- 5.5-3/tests-m32/openat2-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/openat2-Xabbrev.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "openat2.c"
diff -pruN 5.5-3/tests-m32/openat2-Xabbrev.gen.test 5.9-0ubuntu2/tests-m32/openat2-Xabbrev.gen.test
--- 5.5-3/tests-m32/openat2-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/openat2-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-Xabbrev --trace=openat2 -a35 -Xabbrev); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a35 -Xabbrev
diff -pruN 5.5-3/tests-m32/openat2-Xraw.c 5.9-0ubuntu2/tests-m32/openat2-Xraw.c
--- 5.5-3/tests-m32/openat2-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/openat2-Xraw.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "openat2.c"
diff -pruN 5.5-3/tests-m32/openat2-Xraw.gen.test 5.9-0ubuntu2/tests-m32/openat2-Xraw.gen.test
--- 5.5-3/tests-m32/openat2-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/openat2-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-Xraw --trace=openat2 -a32 -Xraw); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a32 -Xraw
diff -pruN 5.5-3/tests-m32/openat2-Xverbose.c 5.9-0ubuntu2/tests-m32/openat2-Xverbose.c
--- 5.5-3/tests-m32/openat2-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/openat2-Xverbose.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "openat2.c"
diff -pruN 5.5-3/tests-m32/openat2-Xverbose.gen.test 5.9-0ubuntu2/tests-m32/openat2-Xverbose.gen.test
--- 5.5-3/tests-m32/openat2-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/openat2-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-Xverbose --trace=openat2 -a35 -Xverbose); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a35 -Xverbose
diff -pruN 5.5-3/tests-m32/openat2-y.c 5.9-0ubuntu2/tests-m32/openat2-y.c
--- 5.5-3/tests-m32/openat2-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/openat2-y.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define FD0_PATH "</dev/full>"
+#include "openat2.c"
diff -pruN 5.5-3/tests-m32/openat2-y.gen.test 5.9-0ubuntu2/tests-m32/openat2-y.gen.test
--- 5.5-3/tests-m32/openat2-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/openat2-y.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-y --trace=openat2 -a36 -y </dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a36 -y </dev/full
diff -pruN 5.5-3/tests-m32/open_tree-P.gen.test 5.9-0ubuntu2/tests-m32/open_tree-P.gen.test
--- 5.5-3/tests-m32/open_tree-P.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/open_tree-P.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -1,4 +1,4 @@
 #!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (open_tree-P -a30 -y -P /dev/full -e trace=open_tree); do not edit.
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (open_tree-P -a30 --decode-fds -P /dev/full -e trace=open_tree); do not edit.
 . "${srcdir=.}/init.sh"
-run_strace_match_diff -a30 -y -P /dev/full -e trace=open_tree
+run_strace_match_diff -a30 --decode-fds -P /dev/full -e trace=open_tree
diff -pruN 5.5-3/tests-m32/options-syntax.test 5.9-0ubuntu2/tests-m32/options-syntax.test
--- 5.5-3/tests-m32/options-syntax.test	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/options-syntax.test	2020-08-21 16:39:24.000000000 +0000
@@ -30,55 +30,189 @@ check_e_using_grep "$ff_name: File *name
 check_e_using_grep "$ff_name: File *name too long" -ff --output="$ff_name" true
 
 check_h 'must have PROG [ARGS] or -p PID'
-check_h 'PROG [ARGS] must be specified with -D' -D -p $$
-check_h 'PROG [ARGS] must be specified with -D' -DD -p $$
-check_h 'PROG [ARGS] must be specified with -D' -DDD -p $$
-check_h 'PROG [ARGS] must be specified with -D' -DDDD -p $$
+check_h "must have PROG [ARGS] or -p PID" --absolute-timestamps
+check_h "must have PROG [ARGS] or -p PID" --absolute-timestamps=
+check_h "must have PROG [ARGS] or -p PID" --absolute-timestamps=,
+check_h "must have PROG [ARGS] or -p PID" --absolute-timestamps=,s
+check_h "must have PROG [ARGS] or -p PID" --absolute-timestamps=s,
+check_h "must have PROG [ARGS] or -p PID" --absolute-timestamps=,,
+check_h "must have PROG [ARGS] or -p PID" --absolute-timestamps=s,,none
+check_h "must have PROG [ARGS] or -p PID" --timestamps --absolute-timestamps=ns --timestamps=none --absolute-timestamps=format:time,precision:s --timestamps=ns,format:unix --absolute-timestamps=us,precision:ms,unix,precision:ns --timestamps=format:none,time,precision:us
+check_h "invalid --absolute-timestamps argument: 'ss'" --absolute-timestamps=ss
+check_h "invalid --timestamps argument: 'format:s'" --timestamps=format:s
+check_h "invalid --timestamps argument: 's,non'" --timestamps=s,non
+check_h "invalid --timestamps argument: 'precision:none'" --timestamps=precision:none
+check_e '-t and --absolute-timestamps cannot be provided simultaneously' -t --timestamps -p $$
+check_e '-t and --absolute-timestamps cannot be provided simultaneously' --absolute-timestamps -ttt -p $$
+check_e '-t and --absolute-timestamps cannot be provided simultaneously' -t --timestamps=ns -t -p $$
+check_e '-t and --absolute-timestamps cannot be provided simultaneously' --timestamps=ns -t --absolute-timestamps=unix -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' -D -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' -DD -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' -DDD -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' -DDDD -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' --daemonize -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' --daemonize=grandchild -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' --daemonize=pgroup -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' --daemonize=Pgrp -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' --daemonize=SESSION -p $$
 check_h 'Too many -D'\''s (4), maximum supported -D count is 3' -DDDD /bin/true
-check_h '-c and -C are mutually exclusive' -c -C true
-check_h '-c and -C are mutually exclusive' --summary-only --summary true
-check_h '-c and -C are mutually exclusive' -C -c true
-check_h '-c and -C are mutually exclusive' --summary --summary-only true
-check_h '(-c or -C) and -ff are mutually exclusive' -c -ff true
-check_h '(-c or -C) and -ff are mutually exclusive' --summary-only -ff true
-check_h '(-c or -C) and -ff are mutually exclusive' -C -ff true
-check_h '(-c or -C) and -ff are mutually exclusive' --summary -ff true
-check_h '-w must be given with (-c or -C)' -w true
-check_h '-w must be given with (-c or -C)' --summary-wall-clock true
-check_h 'piping the output and -ff are mutually exclusive' -o '|' -ff true
-check_h 'piping the output and -ff are mutually exclusive' --output='|' -ff true
-check_h 'piping the output and -ff are mutually exclusive' -o '!' -ff true
-check_h 'piping the output and -ff are mutually exclusive' --output='!' -ff true
+check_e '-D and --daemonize cannot be provided simultaneously' -D --daemonize -p $$
+check_e '-D and --daemonize cannot be provided simultaneously' --daemonize -D -p $$
+check_e '-D and --daemonize cannot be provided simultaneously' --daemonize -v -D /bit/true
+check_h "invalid --daemonize argument: 'pgr'" --daemonize=pgr
+check_h '-c/--summary-only and -C/--summary are mutually exclusive' -c -C true
+check_h '-c/--summary-only and -C/--summary are mutually exclusive' --summary-only --summary true
+check_h '-c/--summary-only and -C/--summary are mutually exclusive' -C -c true
+check_h '-c/--summary-only and -C/--summary are mutually exclusive' --summary --summary-only true
+check_h '(-c/--summary-only or -C/--summary) and -ff/--output-separately are mutually exclusive' -c -ff true
+check_h '(-c/--summary-only or -C/--summary) and -ff/--output-separately are mutually exclusive' --summary-only -ff true
+check_h '(-c/--summary-only or -C/--summary) and -ff/--output-separately are mutually exclusive' -C -ff true
+check_h '(-c/--summary-only or -C/--summary) and -ff/--output-separately are mutually exclusive' --summary -ff true
+check_h '-w/--summary-wall-clock must be given with (-c/--summary-only or -C/--summary)' -w true
+check_h '-w/--summary-wall-clock must be given with (-c/--summary-only or -C/--summary)' --summary-wall-clock true
+check_h '-U/--summary-columns must be given with (-c/--summary-only or -C/--summary)' -U name,time,count,errors true
+check_h '-U/--summary-columns must be given with (-c/--summary-only or -C/--summary)' --summary-columns=name,time,count,errors true
+check_h 'piping the output and -ff/--output-separately are mutually exclusive' -o '|' -ff true
+check_h 'piping the output and -ff/--output-separately are mutually exclusive' --output='|' -ff true
+check_h 'piping the output and -ff/--output-separately are mutually exclusive' -o '!' -ff true
+check_h 'piping the output and -ff/--output-separately are mutually exclusive' --output='!' -ff true
 check_h "invalid -a argument: '-42'" -a -42
 check_h "invalid -O argument: '-42'" -O -42
 check_h "invalid -s argument: '-42'" -s -42
-check_h "invalid -s argument: '-42'" --string-limit=-42
+check_h "invalid --string-limit argument: '-42'" --string-limit=-42
 check_h "invalid -s argument: '1073741824'" -s 1073741824
-check_h "invalid -s argument: '1073741824'" --string-limit=1073741824
+check_h "invalid --string-limit argument: '1073741824'" --string-limit=1073741824
+check_h "must have PROG [ARGS] or -p PID" --follow-forks
+check_h "must have PROG [ARGS] or -p PID" --follow-forks --output-separately
+check_h "must have PROG [ARGS] or -p PID" -f --output-separately
+check_h "must have PROG [ARGS] or -p PID" --output-separately
+check_e '-f and --follow-forks cannot be provided simultaneously' -f --follow-forks -p $$
+check_e '-ff and --output-separately cannot be provided simultaneously' --output-separately -ff -p $$
+check_h "invalid -I argument: '0x1'" -I 0x1
+check_h "invalid -I argument: '0'" -I 0
+check_h "must have PROG [ARGS] or -p PID" -I1
+check_h "must have PROG [ARGS] or -p PID" -I 2
+check_h "must have PROG [ARGS] or -p PID" -I3
+check_h "must have PROG [ARGS] or -p PID" -I 4
 check_h "invalid -I argument: '5'" -I 5
+check_h "must have PROG [ARGS] or -p PID" -I always
+check_h "must have PROG [ARGS] or -p PID" -I anywhere
+check_h "must have PROG [ARGS] or -p PID" -Iwaiting
+check_h "must have PROG [ARGS] or -p PID" -I never
+check_h "must have PROG [ARGS] or -p PID" -Inever_tstp
+check_h "invalid -I argument: '=never'" -I=never
+check_h "invalid -I argument: 'nevertheless'" -Inevertheless
+check_h "invalid -I argument: 'nev'" -Inev
+check_h "invalid --interruptible argument: '0x1'" --interruptible=0x1
+check_h "invalid --interruptible argument: '0'" --interruptible=0
+check_h "must have PROG [ARGS] or -p PID" --interruptible 1
+check_h "must have PROG [ARGS] or -p PID" --interruptible=2
+check_h "invalid --interruptible argument: '5'" --interruptible=5
+check_h "must have PROG [ARGS] or -p PID" --interruptible=anywhere
+check_h "must have PROG [ARGS] or -p PID" --interruptible=waiting
+check_h "must have PROG [ARGS] or -p PID" --interruptible=never
+check_h "must have PROG [ARGS] or -p PID" --interruptible=never_tstp
+check_h "invalid --interruptible argument: 'nevertheless'" --interruptible=nevertheless
+check_h "invalid --interruptible argument: 'nev'" --interruptible=nev
+check_h "must have PROG [ARGS] or -p PID" --relative-timestamps
+check_h "must have PROG [ARGS] or -p PID" --relative-timestamps=s
+check_h "must have PROG [ARGS] or -p PID" --relative-timestamps=ms
+check_h "must have PROG [ARGS] or -p PID" --relative-timestamps=us
+check_h "must have PROG [ARGS] or -p PID" --relative-timestamps=ns
+check_h "invalid --relative-timestamps argument: 'n'" --relative-timestamps=n
+check_h "invalid --relative-timestamps argument: 'ss'" --relative-timestamps=ss
+check_h "must have PROG [ARGS] or -p PID" --syscall-times
+check_h "must have PROG [ARGS] or -p PID" --syscall-times=s
+check_h "must have PROG [ARGS] or -p PID" --syscall-times=ms
+check_h "must have PROG [ARGS] or -p PID" --syscall-times=us
+check_h "must have PROG [ARGS] or -p PID" --syscall-times=ns
+check_h "invalid --syscall-times argument: 'n'" --syscall-times=n
+check_h "invalid --syscall-times argument: 'ss'" --syscall-times=ss
+check_h "must have PROG [ARGS] or -p PID" --strings-in-hex
+check_h "must have PROG [ARGS] or -p PID" --strings-in-hex=all
+check_h "must have PROG [ARGS] or -p PID" --strings-in-hex=non-ascii
+check_h "invalid --strings-in-hex argument: 'al'" --strings-in-hex=al
+check_h "invalid --strings-in-hex argument: 'alll'" --strings-in-hex=alll
+check_h "invalid --strings-in-hex argument: 'ascii'" --strings-in-hex=ascii
+check_h "must have PROG [ARGS] or -p PID" --quiet=all
+check_h "must have PROG [ARGS] or -p PID" --quiet=none
+check_h "must have PROG [ARGS] or -p PID" --quiet=\!attach
+check_h "must have PROG [ARGS] or -p PID" --quiet=exit,exits,personality
+check_e "invalid quiet 'detach'" --quiet=detach -p $$
+check_e "invalid quiet 'fds'" -q --quiet=fds -p $$
+check_e "invalid quiet 'detach'" --quiet=detach -p $$
+check_e '-q and -e quiet/--quiet cannot be provided simultaneously' -q --quiet -p $$
+check_e '-q and -e quiet/--quiet cannot be provided simultaneously' -q -e q=none -p $$
+check_e '-q and -e quiet/--quiet cannot be provided simultaneously' -q -e silent=attach,personality -p $$
+
+check_h 'must have PROG [ARGS] or -p PID' -P .
+check_h 'must have PROG [ARGS] or -p PID' -P . -P..
+check_h 'must have PROG [ARGS] or -p PID' --trace-path=.
+check_h 'must have PROG [ARGS] or -p PID' --trace-path=. --trace-path ..
+check_e "Requested path \"///\" resolved into \"/\"
+$STRACE_EXE: Requested path \"/.\" resolved into \"/\"
+$STRACE_EXE: -q and -e quiet/--quiet cannot be provided simultaneously" -q --quiet -P /// -P/. .
+
+for i in time time_percent time-percent time_total time-total total_time total-time min_time min-time time_min time-min shortest max_time max-time time_max time-max longest avg_time avg-time time_avg time-avg calls count error errors name syscall syscall_name syscall-name none nothing; do
+	check_h "must have PROG [ARGS] or -p PID" -S "$i"
+	check_h "must have PROG [ARGS] or -p PID" --summary-sort-by="$i"
+	if [ "x$i" != xnone -a "x$i" != xnothing ]; then
+		check_h "must have PROG [ARGS] or -p PID" -c -U "$i"
+		check_h "must have PROG [ARGS] or -p PID" --summary-only --summary-columns="$i"
+	fi
+done
+for i in time,time_total,avg_time,calls,errors,name time_percent,total_time,time_avg,count,error,syscall_name; do
+	check_h "must have PROG [ARGS] or -p PID" -c -U "$i"
+	check_h "must have PROG [ARGS] or -p PID" --summary-only --summary-columns="$i"
+done
+for i in non syscall_names; do
+	check_h "invalid sortby: '$i'" -S "$i"
+	check_h "invalid sortby: '$i'" --summary-sort-by="$i"
+	check_h "unknown column name: '$i'" -U "$i"
+	check_h "unknown column name: '$i'" --summary-columns="$i"
+done
+check_h "unknown column name: ''" -U time,,name
+check_h "call summary column has been provided more than once: 'time_percent' (-U option residual: 'time_percent,time_total')" -U time,time_percent,time_total
+
+check_e '-x and --strings-in-hex cannot be provided simultaneously' -x --strings-in-hex -p $$
+check_e '-x and --strings-in-hex cannot be provided simultaneously' --strings-in-hex -p $$ -xx
 check_h "invalid -X argument: 'test'" -Xtest
-check_h "invalid -X argument: 'test'" --const-print-style=test
+check_h "invalid --const-print-style argument: 'test'" --const-print-style=test
 check_h "invalid -X argument: 'a'" -Xa
-check_h "invalid -X argument: 'a'" --const-print-style=a
+check_h "invalid --const-print-style argument: 'a'" --const-print-style=a
 check_h "invalid -X argument: 'abbreviated'" -X abbreviated
-check_h "invalid -X argument: 'abbreviated'" --const-print-style=abbreviated
+check_h "invalid --const-print-style argument: 'abbreviated'" --const-print-style=abbreviated
+check_h "must have PROG [ARGS] or -p PID" --decode-fds
+check_h "must have PROG [ARGS] or -p PID" --decode-fds=all
+check_h "must have PROG [ARGS] or -p PID" --decode-fds=none
+check_h "must have PROG [ARGS] or -p PID" --decode-fds=path
+check_h "must have PROG [ARGS] or -p PID" --decode-fds=socket,dev
+check_h "must have PROG [ARGS] or -p PID" --decode-fds=\!path
+check_h "must have PROG [ARGS] or -p PID" --decode-fds=socket,path,dev
+check_e "invalid decode-fds 'p'" --decode-fds=p -p $$
+check_e "invalid decode-fds 'device'" -y --decode-fds=device -p $$
+check_e "invalid decode-fds 'name'" --decode-fds=path,name -p $$
+check_e "invalid decode-fds 'sock'" -e decode-fd=sock -y -p $$
+check_e '-y and --decode-fds cannot be provided simultaneously' -y --decode-fds -p $$
+check_e '-y and --decode-fds cannot be provided simultaneously' -e decode-fd=all -yy -p $$
+check_e '-y and --decode-fds cannot be provided simultaneously' --decode-fds=none -y -p $$
 
 check_h "incorrect personality designator '' in qualification 'getcwd@'" -e trace=getcwd@
 check_h "incorrect personality designator '42' in qualification 'getcwd@42'" -e trace=getcwd@42
 check_h "incorrect personality designator '42' in qualification 'getcwd@42'" -e trace=gettid,getcwd@42
 check_h "incorrect personality designator '42' in qualification '23@42'" -e trace=23@42,123
 
-check_h '--seccomp-bpf implies -f
--w must be given with (-c or -C)' --seccomp-bpf -w /
+check_h '--seccomp-bpf cannot be used without -f/--follow-forks, disabling
+-w/--summary-wall-clock must be given with (-c/--summary-only or -C/--summary)' --seccomp-bpf -w /
 check_h '--seccomp-bpf is not enabled for processes attached with -p
--w must be given with (-c or -C)' --seccomp-bpf -f -p 1 -w
+-w/--summary-wall-clock must be given with (-c/--summary-only or -C/--summary)' --seccomp-bpf -f -p 1 -w
 
-check_h 'option -F is deprecated, please use -f instead
--w must be given with (-c or -C)' -F -w /
-check_h 'option -F is deprecated, please use -f instead
--w must be given with (-c or -C)' -FF -w /
+check_h 'option -F is deprecated, please use -f/--follow-forks instead
+-w/--summary-wall-clock must be given with (-c/--summary-only or -C/--summary)' -F -w /
+check_h 'option -F is deprecated, please use -f/--follow-forks instead
+-w/--summary-wall-clock must be given with (-c/--summary-only or -C/--summary)' -FF -w /
 check_h 'deprecated option -F ignored
--w must be given with (-c or -C)' -fF -w /
+-w/--summary-wall-clock must be given with (-c/--summary-only or -C/--summary)' -fF -w /
 
 check_e "invalid system call '/getcwd@ohmy'" -e trace=/getcwd@ohmy
 check_e "invalid -e kvm= argument: 'chdir'" -e kvm=chdir
@@ -129,25 +263,51 @@ if [ "$uid" -ge 0 ]; then
 	if [ "$uid" -eq 0 ]; then
 		umsg="Cannot find user ':nosuchuser:'"
 	else
-		umsg='You must be root to use the -u option'
+		umsg='You must be root to use the -u/--username option'
 	fi
 
 	check_e "$umsg" -u :nosuchuser: true
 
-	for c in i r t T y; do
-		check_e "-$c has no effect with -c
-$STRACE_EXE: $umsg" -u :nosuchuser: -c -$c true
+	for c in i/--instruction-pointer n/--syscall-number r/--relative-timestamps t/--absolute-timestamps T/--syscall-times y/--decode-fds; do
+		check_e "-$c has no effect with -c/--summary-only
+$STRACE_EXE: $umsg" -u :nosuchuser: -c -${c%%/*} true
+	done
+
+	check_e "-i/--instruction-pointer has no effect with -c/--summary-only
+$STRACE_EXE: -n/--syscall-number has no effect with -c/--summary-only
+$STRACE_EXE: -r/--relative-timestamps has no effect with -c/--summary-only
+$STRACE_EXE: -t/--absolute-timestamps has no effect with -c/--summary-only
+$STRACE_EXE: -T/--syscall-times has no effect with -c/--summary-only
+$STRACE_EXE: -y/--decode-fds has no effect with -c/--summary-only
+$STRACE_EXE: Only the last of -z/--successful-only/-Z/--failed-only options will take effect. See status qualifier for more complex filters.
+$STRACE_EXE: $umsg" -u :nosuchuser: -cinrtTyzZ true
+
+	for c in --output-separately -A/--output-append-mode; do
+		check_e "$c has no effect without -o/--output
+$STRACE_EXE: $umsg" -u :nosuchuser: ${c%%/*} true
 	done
 
-	check_e "-i has no effect with -c
-$STRACE_EXE: -r has no effect with -c
-$STRACE_EXE: -t has no effect with -c
-$STRACE_EXE: -T has no effect with -c
-$STRACE_EXE: -y has no effect with -c
-$STRACE_EXE: Only the last of -z/-Z options will take effect. See status qualifier for more complex filters.
-$STRACE_EXE: $umsg" -u :nosuchuser: -cirtTyzZ true
+	check_e "-S/--summary-sort-by has no effect without (-c/--summary-only or -C/--summary)
+$STRACE_EXE: $umsg" -u :nosuchuser: --summary-sort-by errors true
+
+	check_e "--output-separately has no effect without -o/--output
+$STRACE_EXE: -A/--output-append-mode has no effect without -o/--output
+$STRACE_EXE: $umsg" -u :nosuchuser: --output-separately --output-append-mode true
+
+	check_e "$umsg" -u :nosuchuser: -ff true
+	check_e "$umsg" -u :nosuchuser: --output-separately --follow-forks true
+
+	check_e "Only the last of -z/--successful-only/-Z/--failed-only options will take effect. See status qualifier for more complex filters.
+$STRACE_EXE: $umsg" -u :nosuchuser: -z --successful-only true
+	check_e "Only the last of -z/--successful-only/-Z/--failed-only options will take effect. See status qualifier for more complex filters.
+$STRACE_EXE: $umsg" -u :nosuchuser: --successful-only -Z true
+	check_e "Only the last of -z/--successful-only/-Z/--failed-only options will take effect. See status qualifier for more complex filters.
+$STRACE_EXE: $umsg" -u :nosuchuser: --successful-only --failed-only true
+
+	check_e "-n/--syscall-number has no effect with -c/--summary-only
+$STRACE_EXE: $umsg" --user=:nosuchuser: --syscall-number --summary-only true
 
-	check_e "-i has no effect with -c
+	check_e "-i/--instruction-pointer has no effect with -c/--summary-only
 $STRACE_EXE: $umsg" --user=:nosuchuser: --instruction-pointer --summary-only true
 fi
 
diff -pruN 5.5-3/tests-m32/orphaned_process_group.c 5.9-0ubuntu2/tests-m32/orphaned_process_group.c
--- 5.5-3/tests-m32/orphaned_process_group.c	2019-03-06 16:02:38.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/orphaned_process_group.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check tracing of orphaned process group.
  *
- * Copyright (c) 2019 The strace developers.
+ * Copyright (c) 2019-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -139,7 +139,7 @@ main(void)
 	 */
 	leader = getpid();
 	printf("%-5d --- %s {si_signo=%s, si_code=SI_TKILL"
-	       ", si_pid=%d, si_uid=%u} ---\n",
+	       ", si_pid=%d, si_uid=%d} ---\n",
 	       stopped, "SIGSTOP", "SIGSTOP", stopped, geteuid());
 	printf("%-5d --- stopped by SIGSTOP ---\n", stopped);
 	printf("%-5d +++ exited with 0 +++\n", leader);
diff -pruN 5.5-3/tests-m32/pc.c 5.9-0ubuntu2/tests-m32/pc.c
--- 5.5-3/tests-m32/pc.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pc.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2015-2020 Dmitry V. Levin <ldv@altlinux.org>
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -27,7 +27,7 @@ int main(void)
 #endif
 
 	/* write instruction pointer length to the log */
-	assert(write(-1, NULL, 2 * sizeof(void *)) < 0);
+	assert(write(-1, (void *) 8UL, 2 * sizeof(void *)) < 0);
 
 	/* just a noticeable line in the log */
 	assert(munmap(&main, 0) < 0);
diff -pruN 5.5-3/tests-m32/pc.test 5.9-0ubuntu2/tests-m32/pc.test
--- 5.5-3/tests-m32/pc.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pc.test	2020-06-01 14:15:16.000000000 +0000
@@ -3,7 +3,7 @@
 # Check -i option.
 #
 # Copyright (c) 2015 Dmitry V. Levin <ldv@altlinux.org>
-# Copyright (c) 2015-2018 The strace developers.
+# Copyright (c) 2015-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -14,11 +14,11 @@ check_prog sed
 
 run_prog > /dev/null
 
-args="-if $args"
+args="--quiet=attach,personality -if $args"
 $STRACE $args 2> "$LOG" ||
 	dump_log_and_fail_with "$STRACE $args failed"
 
-len="$(sed -r -n 's/^\[[[:xdigit:]]+\] write\(-1, NULL, ([[:digit:]]{1,2})\)[[:space:]]+= -1 .*/\1/p' "$LOG")" &&
+len="$(sed -r -n 's/^\[[[:xdigit:]]+\] write\(-1, 0x8, ([[:digit:]]{1,2})\)[[:space:]]+= -1 .*/\1/p' "$LOG")" &&
 [ -n "$len" ] &&
 pid="$(sed -r -n 's/^\[[[:xdigit:]]{'"$len"'}\] --- SIGCHLD \{si_signo=SIGCHLD, si_code=CLD_(KILLED|DUMPED), si_pid=([[:digit:]]+), .*/\2/p' "$LOG")" &&
 [ -n "$pid" ] &&
diff -pruN 5.5-3/tests-m32/perf_event_open.c 5.9-0ubuntu2/tests-m32/perf_event_open.c
--- 5.5-3/tests-m32/perf_event_open.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/perf_event_open.c	2020-06-02 08:00:00.000000000 +0000
@@ -511,7 +511,7 @@ end:
 }
 
 /* These require aligned access, so no byte-grain checks possible */
-# if defined SPARC || defined SPARC64 || defined POWERPC || defined POWERPC64
+# if defined SPARC || defined SPARC64 || defined POWERPC || defined POWERPC64 || defined ARM
 #  define ATTR_REC(sz) { tail_alloc((sz + 7) & ~7), sz }
 # else
 #  define ATTR_REC(sz) { tail_alloc(sz), sz }
@@ -534,7 +534,8 @@ end:
 	"PERF_SAMPLE_BRANCH_CALL|" \
 	"PERF_SAMPLE_BRANCH_NO_FLAGS|" \
 	"PERF_SAMPLE_BRANCH_NO_CYCLES|" \
-	"PERF_SAMPLE_BRANCH_TYPE_SAVE"
+	"PERF_SAMPLE_BRANCH_TYPE_SAVE|" \
+	"PERF_SAMPLE_BRANCH_HW_INDEX"
 
 int
 main(void)
@@ -667,11 +668,11 @@ main(void)
 	static const struct u64_val_str branch_sample_types[] = {
 		{ ARG_STR(0) },
 		{ 0x80, "PERF_SAMPLE_BRANCH_ABORT_TX" },
-		{ 0x1ffff, BRANCH_TYPE_ALL },
+		{ 0x3ffff, BRANCH_TYPE_ALL },
 		{ ARG_ULL_STR(0xdeadcaffeeec0000)
 			" /* PERF_SAMPLE_BRANCH_??? */" },
 		{ 0xffffffffffffffffULL,
-			BRANCH_TYPE_ALL "|0xfffffffffffe0000" }
+			BRANCH_TYPE_ALL "|0xfffffffffffc0000" }
 	};
 	static const struct s32_val_str clockids[] = {
 		{ 11, "CLOCK_TAI" },
diff -pruN 5.5-3/tests-m32/pidfd_getfd.c 5.9-0ubuntu2/tests-m32/pidfd_getfd.c
--- 5.5-3/tests-m32/pidfd_getfd.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pidfd_getfd.c	2020-09-23 16:29:35.000000000 +0000
@@ -0,0 +1,103 @@
+/*
+ * Check decoding of pidfd_getfd syscall.
+ *
+ * Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+
+#ifdef __NR_pidfd_getfd
+
+# include <assert.h>
+# include <signal.h>
+# include <stdio.h>
+# include <stdlib.h>
+# include <unistd.h>
+# include <sys/wait.h>
+
+# ifndef PIDFD_PATH
+#  define PIDFD_PATH ""
+# endif
+# ifndef FD0_PATH
+#  define FD0_PATH ""
+# endif
+# ifndef PRINT_PIDFD
+#  define PRINT_PIDFD 0
+# endif
+
+static const char *errstr;
+
+static long
+k_pidfd_getfd(const unsigned int pidfd, const unsigned int fd,
+	      const unsigned int flags)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+	const kernel_ulong_t arg1 = fill | pidfd;
+	const kernel_ulong_t arg2 = fill | fd;
+	const kernel_ulong_t arg3 = fill | flags;
+	const long rc = syscall(__NR_pidfd_getfd,
+				arg1, arg2, arg3, bad, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
+
+int
+main(void)
+{
+	long rc;
+
+	rc = k_pidfd_getfd(-1U, -1U, 0);
+	printf("pidfd_getfd(-1, -1, 0) = %s\n", errstr);
+
+	rc = k_pidfd_getfd(0, 0, 0xbadc0ded);
+	printf("pidfd_getfd(0" FD0_PATH ", 0, 0xbadc0ded) = %s\n", errstr);
+
+	int child_wait_fds[2];
+	if (pipe(child_wait_fds))
+		perror_msg_and_fail("pipe");
+
+	int dupfd = dup(0);
+	int pid = fork();
+	if (pid == 0) {
+		close(0);
+		close(child_wait_fds[1]);
+		if (read(child_wait_fds[0], &child_wait_fds[1], sizeof(int)))
+			_exit(2);
+		_exit(0);
+	}
+	close(dupfd);
+
+	int pidfd = syscall(__NR_pidfd_open, pid, 0);
+# if PRINT_PIDFD
+	char pidfd_str[sizeof("<pid:>") + 3 * sizeof(int)];
+	snprintf(pidfd_str, sizeof(pidfd_str), "<pid:%d>", pid);
+# else
+	const char *pidfd_str = PIDFD_PATH;
+# endif
+	rc = k_pidfd_getfd(pidfd, dupfd, 0);
+	printf("pidfd_getfd(%d%s, %d%s, 0) = %s%s\n",
+	       pidfd, pidfd >= 0 ? pidfd_str : "",
+	       dupfd, pidfd >= 0 ? FD0_PATH : "",
+	       errstr, rc >= 0 ? FD0_PATH : "");
+
+	puts("+++ exited with 0 +++");
+
+	close(child_wait_fds[1]);
+	int status;
+	assert(wait(&status) == pid);
+	assert(status == 0);
+
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_pidfd_getfd");
+
+#endif
diff -pruN 5.5-3/tests-m32/pidfd_getfd.gen.test 5.9-0ubuntu2/tests-m32/pidfd_getfd.gen.test
--- 5.5-3/tests-m32/pidfd_getfd.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pidfd_getfd.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_getfd -a18 -Xverbose -e signal=none </dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a18 -Xverbose -e signal=none </dev/full
diff -pruN 5.5-3/tests-m32/pidfd_getfd-y.c 5.9-0ubuntu2/tests-m32/pidfd_getfd-y.c
--- 5.5-3/tests-m32/pidfd_getfd-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pidfd_getfd-y.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,3 @@
+#define PIDFD_PATH "<anon_inode:[pidfd]>"
+#define FD0_PATH "</dev/full>"
+#include "pidfd_getfd.c"
diff -pruN 5.5-3/tests-m32/pidfd_getfd-y.gen.test 5.9-0ubuntu2/tests-m32/pidfd_getfd-y.gen.test
--- 5.5-3/tests-m32/pidfd_getfd-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pidfd_getfd-y.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_getfd-y --trace=pidfd_getfd -a18 -e signal=none -y </dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=pidfd_getfd -a18 -e signal=none -y </dev/full
diff -pruN 5.5-3/tests-m32/pidfd_getfd-yy.c 5.9-0ubuntu2/tests-m32/pidfd_getfd-yy.c
--- 5.5-3/tests-m32/pidfd_getfd-yy.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pidfd_getfd-yy.c	2020-04-05 13:28:30.000000000 +0000
@@ -0,0 +1,3 @@
+#define PRINT_PIDFD 1
+#define FD0_PATH "</dev/full<char 1:7>>"
+#include "pidfd_getfd.c"
diff -pruN 5.5-3/tests-m32/pidfd_getfd-yy.gen.test 5.9-0ubuntu2/tests-m32/pidfd_getfd-yy.gen.test
--- 5.5-3/tests-m32/pidfd_getfd-yy.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pidfd_getfd-yy.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_getfd-yy --trace=pidfd_getfd -a18 -e signal=none -yy </dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=pidfd_getfd -a18 -e signal=none -yy </dev/full
diff -pruN 5.5-3/tests-m32/pidfd_open.c 5.9-0ubuntu2/tests-m32/pidfd_open.c
--- 5.5-3/tests-m32/pidfd_open.c	2019-08-15 11:54:22.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pidfd_open.c	2020-08-25 14:29:30.000000000 +0000
@@ -2,6 +2,7 @@
  * Check decoding of pidfd_open syscall.
  *
  * Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2019-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -9,6 +10,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #ifdef __NR_pidfd_open
 
@@ -36,6 +38,8 @@ k_pidfd_open(const unsigned int pid, con
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 # if defined PATH_TRACING || defined PRINT_PATHS
 	skip_if_unavailable("/proc/self/fd/");
 # endif
@@ -49,16 +53,19 @@ main(void)
 
 	k_pidfd_open(0, 0);
 # ifndef PATH_TRACING
+	pidns_print_leader();
 	printf("pidfd_open(0, 0) = %s\n", errstr);
 # endif
 
 	k_pidfd_open(-1U, 0);
 # ifndef PATH_TRACING
+	pidns_print_leader();
 	printf("pidfd_open(-1, 0) = %s\n", errstr);
 # endif
 
 	k_pidfd_open(0, -1U);
 # ifndef PATH_TRACING
+	pidns_print_leader();
 	printf("pidfd_open(0, %#x) = %s\n", -1U, errstr);
 # endif
 
@@ -67,7 +74,10 @@ main(void)
 
 	k_pidfd_open(pid, flags);
 # ifndef PATH_TRACING
-	printf("pidfd_open(%d, %#x) = %s\n", pid, flags, errstr);
+	const char *pid_str = pidns_pid2str(PT_TGID);
+	pidns_print_leader();
+	printf("pidfd_open(%d%s, %#x) = %s\n",
+		pid, pid_str, flags, errstr);
 # endif
 
 # ifdef PRINT_PATHS
@@ -79,15 +89,19 @@ main(void)
 # endif
 
 # ifndef PATH_TRACING
-	printf("pidfd_open(%d, 0) = "
-#  ifdef PRINT_PATHS
-	       "%ld<anon_inode:[pidfd]>\n", pid, rc
+	pidns_print_leader();
+	printf("pidfd_open(%d%s, 0) = "
+#  if defined PRINT_PIDFD
+	       "%ld<pid:%d>\n", pid, pid_str, rc, pid
+#  elif defined PRINT_PATHS
+	       "%ld<anon_inode:[pidfd]>\n", pid, pid_str, rc
 #  else
-	       "%s\n", pid, errstr
+	       "%s\n", pid, pid_str, errstr
 #  endif
 	       );
 # endif
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/pidfd_open--decode-fd-path.c 5.9-0ubuntu2/tests-m32/pidfd_open--decode-fd-path.c
--- 5.5-3/tests-m32/pidfd_open--decode-fd-path.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pidfd_open--decode-fd-path.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1 @@
+#include "pidfd_open-y.c"
diff -pruN 5.5-3/tests-m32/pidfd_open--decode-fd-path.gen.test 5.9-0ubuntu2/tests-m32/pidfd_open--decode-fd-path.gen.test
--- 5.5-3/tests-m32/pidfd_open--decode-fd-path.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pidfd_open--decode-fd-path.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_open--decode-fd-path -a17 -e decode-fd=path -e trace=pidfd_open); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a17 -e decode-fd=path -e trace=pidfd_open
diff -pruN 5.5-3/tests-m32/pidfd_open--decode-fd-pidfd.c 5.9-0ubuntu2/tests-m32/pidfd_open--decode-fd-pidfd.c
--- 5.5-3/tests-m32/pidfd_open--decode-fd-pidfd.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pidfd_open--decode-fd-pidfd.c	2020-04-05 13:28:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_PIDFD 1
+#include "pidfd_open-y.c"
diff -pruN 5.5-3/tests-m32/pidfd_open--decode-fd-pidfd.gen.test 5.9-0ubuntu2/tests-m32/pidfd_open--decode-fd-pidfd.gen.test
--- 5.5-3/tests-m32/pidfd_open--decode-fd-pidfd.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pidfd_open--decode-fd-pidfd.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_open--decode-fd-pidfd -a17 -e decode-fd=pidfd -e trace=pidfd_open); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a17 -e decode-fd=pidfd -e trace=pidfd_open
diff -pruN 5.5-3/tests-m32/pidfd_open--decode-fd-socket.c 5.9-0ubuntu2/tests-m32/pidfd_open--decode-fd-socket.c
--- 5.5-3/tests-m32/pidfd_open--decode-fd-socket.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pidfd_open--decode-fd-socket.c	2020-04-05 13:28:30.000000000 +0000
@@ -0,0 +1 @@
+#include "pidfd_open-y.c"
diff -pruN 5.5-3/tests-m32/pidfd_open--decode-fd-socket.gen.test 5.9-0ubuntu2/tests-m32/pidfd_open--decode-fd-socket.gen.test
--- 5.5-3/tests-m32/pidfd_open--decode-fd-socket.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pidfd_open--decode-fd-socket.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_open--decode-fd-socket -a17 -e decode-fd=socket -e trace=pidfd_open); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a17 -e decode-fd=socket -e trace=pidfd_open
diff -pruN 5.5-3/tests-m32/pidfd_open--pidns-translation.c 5.9-0ubuntu2/tests-m32/pidfd_open--pidns-translation.c
--- 5.5-3/tests-m32/pidfd_open--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pidfd_open--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "pidfd_open.c"
diff -pruN 5.5-3/tests-m32/pidfd_open--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/pidfd_open--pidns-translation.gen.test
--- 5.5-3/tests-m32/pidfd_open--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pidfd_open--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_open--pidns-translation test_pidns -a17 -e trace=pidfd_open); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a17 -e trace=pidfd_open
diff -pruN 5.5-3/tests-m32/pidfd_open-yy.c 5.9-0ubuntu2/tests-m32/pidfd_open-yy.c
--- 5.5-3/tests-m32/pidfd_open-yy.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pidfd_open-yy.c	2020-04-05 13:28:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_PIDFD 1
+#include "pidfd_open-y.c"
diff -pruN 5.5-3/tests-m32/pidfd_open-yy.gen.test 5.9-0ubuntu2/tests-m32/pidfd_open-yy.gen.test
--- 5.5-3/tests-m32/pidfd_open-yy.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pidfd_open-yy.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_open-yy -a17 -yy -e trace=pidfd_open); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a17 -yy -e trace=pidfd_open
diff -pruN 5.5-3/tests-m32/pidfd_send_signal.c 5.9-0ubuntu2/tests-m32/pidfd_send_signal.c
--- 5.5-3/tests-m32/pidfd_send_signal.c	2019-08-14 11:22:32.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pidfd_send_signal.c	2020-08-25 14:29:30.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check decoding of pidfd_send_signal syscall.
  *
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,6 +10,7 @@
 #include "tests.h"
 #include <unistd.h>
 #include "scno.h"
+#include "pidns.h"
 
 #ifdef __NR_pidfd_send_signal
 
@@ -36,6 +37,8 @@ sys_pidfd_send_signal(int pidfd, int sig
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	static const char null_path[] = "/dev/null";
 
 	int fd = open(null_path, O_RDONLY);
@@ -46,19 +49,23 @@ main(void)
 	const void *esi = (const void *) si + 1;
 
 	sys_pidfd_send_signal(fd, SIGUSR1, esi, 0);
+	pidns_print_leader();
 	printf("pidfd_send_signal(%d, SIGUSR1, %p, 0) = %s\n",
 	       fd, esi, errstr);
 
 	si->si_signo = SIGUSR1;
 	si->si_code = SI_QUEUE;
+	si->si_pid = getpid();
 
 	sys_pidfd_send_signal(fd, SIGUSR2, si, -1);
+	pidns_print_leader();
 	printf("pidfd_send_signal(%d, SIGUSR2, {si_signo=SIGUSR1"
-	       ", si_code=SI_QUEUE, si_errno=%u, si_pid=%u, si_uid=%u"
+	       ", si_code=SI_QUEUE, si_errno=%u, si_pid=%d%s, si_uid=%d"
 	       ", si_value={int=%d, ptr=%p}}, %#x) = %s\n",
-	       fd, si->si_errno, si->si_pid, si->si_uid, si->si_int, si->si_ptr,
-	       -1U, errstr);
+	       fd, si->si_errno, si->si_pid, pidns_pid2str(PT_TGID), si->si_uid,
+	       si->si_int, si->si_ptr, -1U, errstr);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/pidfd_send_signal--pidns-translation.c 5.9-0ubuntu2/tests-m32/pidfd_send_signal--pidns-translation.c
--- 5.5-3/tests-m32/pidfd_send_signal--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pidfd_send_signal--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "pidfd_send_signal.c"
diff -pruN 5.5-3/tests-m32/pidfd_send_signal--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/pidfd_send_signal--pidns-translation.gen.test
--- 5.5-3/tests-m32/pidfd_send_signal--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pidfd_send_signal--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_send_signal--pidns-translation test_pidns -e trace=pidfd_send_signal); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -e trace=pidfd_send_signal
diff -pruN 5.5-3/tests-m32/pidns.c 5.9-0ubuntu2/tests-m32/pidns.c
--- 5.5-3/tests-m32/pidns.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pidns.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,237 @@
+/*
+ * Testing framework for PID namespace translation
+ *
+ * Copyright (c) 2020 Ákos Uzonyi <uzonyi.akos@gmail.com>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+#include "tests.h"
+#include "pidns.h"
+#include "nsfs.h"
+
+#include <errno.h>
+#include <stdio.h>
+#include <string.h>
+#include <sys/types.h>
+#include <signal.h>
+#include <stdlib.h>
+#include <sched.h>
+#include <unistd.h>
+#include <sys/wait.h>
+#include <linux/sched.h>
+#include <fcntl.h>
+#include <sys/ioctl.h>
+
+#ifndef CLONE_NEWUSER
+# define CLONE_NEWUSER 0x10000000
+#endif
+
+#ifndef CLONE_NEWPID
+# define CLONE_NEWPID 0x20000000
+#endif
+
+static bool pidns_translation = false;
+static bool pidns_unshared = false;
+
+/* Our PIDs in strace's namespace */
+static pid_t pidns_strace_ids[PT_COUNT];
+
+void
+pidns_print_leader(void)
+{
+	if (pidns_translation)
+		printf("%-5d ", pidns_strace_ids[PT_TID]);
+}
+
+const char *
+pidns_pid2str(enum pid_type type)
+{
+	static const char format[] = " /* %d in strace's PID NS */";
+	static char buf[PT_COUNT][sizeof(format) + sizeof(int) * 3];
+
+	if (type < 0 || type >= PT_COUNT)
+		return "";
+
+	if (!pidns_unshared || !pidns_strace_ids[type])
+		return "";
+
+	snprintf(buf[type], sizeof(buf[type]), format, pidns_strace_ids[type]);
+	return buf[type];
+}
+
+/**
+ * This function is like fork, but does a few more things. It sets up the
+ * child's PGID and SID according to the parameters. Also it fills the
+ * pidns_strace_ids array in the child's memory with the PIDs of the child in
+ * parent's PID namespace. In the parent it waits for the child to terminate
+ * (but leaves the zombie to use it later as a process group). If the child
+ * terminates with nonzero exit status, the test is failed.
+ *
+ * @param pgid     The process group the child should be moved to. It's expected
+ *                 to be a PID of a zombie process (will be reaped). If
+ *                 negative, leave the child in the process group of the parent.
+ *                 If 0, move the process to its own process group.
+ * @param new_sid  Wheather child should be moved to a new session.
+ */
+static pid_t
+pidns_fork(pid_t pgid, bool new_sid)
+{
+	int strace_ids_pipe[2];
+	if (pipe(strace_ids_pipe) < 0)
+		perror_msg_and_fail("pipe");
+
+	fflush(stdout);
+	pid_t pid = fork();
+	if (pid < 0)
+		perror_msg_and_fail("fork");
+
+	if (!pid) {
+		close(strace_ids_pipe[1]);
+
+		ssize_t len = read(strace_ids_pipe[0], pidns_strace_ids,
+				sizeof(pidns_strace_ids));
+		if (len < 0)
+			perror_msg_and_fail("read");
+		if (len != sizeof(pidns_strace_ids))
+			error_msg_and_fail("read returned < sizeof(pidns_strace_ids)");
+
+		close(strace_ids_pipe[0]);
+
+		if (pidns_strace_ids[PT_SID])
+			setsid();
+
+		return 0;
+	}
+
+	pidns_strace_ids[PT_TID] = pid;
+	pidns_strace_ids[PT_TGID] = pid;
+	pidns_strace_ids[PT_PGID] = 0;
+	pidns_strace_ids[PT_SID] = 0;
+
+	if (!pgid)
+		pgid = pid;
+
+	if (pgid > 0) {
+		if (setpgid(pid, pgid) < 0)
+			perror_msg_and_fail("setpgid");
+
+		pidns_strace_ids[PT_PGID] = pgid;
+	}
+
+	/* Reap group leader to test PGID decoding */
+	if (pgid > 0 && pgid != pid) {
+		int ret = waitpid(pgid, NULL, WNOHANG);
+		if (ret < 0)
+			perror_msg_and_fail("wait");
+		if (!ret)
+			error_msg_and_fail("could not reap group leader");
+	}
+
+	if (new_sid) {
+		pidns_strace_ids[PT_SID] = pid;
+		pidns_strace_ids[PT_PGID] = pid;
+	}
+
+	ssize_t len = write(strace_ids_pipe[1], pidns_strace_ids,
+	                     sizeof(pidns_strace_ids));
+	if (len < 0)
+		perror_msg_and_fail("write");
+	if (len != sizeof(pidns_strace_ids))
+		error_msg_and_fail("write returned < sizeof(pidns_strace_ids)");
+
+	close(strace_ids_pipe[0]);
+	close(strace_ids_pipe[1]);
+
+	/* WNOWAIT: leave the zombie, to be able to use it as a process group */
+	siginfo_t siginfo;
+	if (waitid(P_PID, pid, &siginfo, WEXITED | WNOWAIT) < 0)
+		perror_msg_and_fail("wait");
+	if (siginfo.si_code != CLD_EXITED || siginfo.si_status)
+		error_msg_and_fail("child terminated with nonzero exit status");
+
+	return pid;
+}
+
+static void
+create_init_process(void)
+{
+	int child_pipe[2];
+	if (pipe(child_pipe) < 0)
+		perror_msg_and_fail("pipe");
+
+	pid_t pid = fork();
+	if (pid < 0)
+		perror_msg_and_fail("fork");
+
+	if (!pid) {
+		close(child_pipe[1]);
+		if (read(child_pipe[0], &child_pipe[1], sizeof(int)) != 0)
+			_exit(1);
+		_exit(0);
+	}
+
+	close(child_pipe[0]);
+}
+
+void
+check_ns_ioctl(void)
+{
+	int fd = open("/proc/self/ns/pid", O_RDONLY);
+	if (fd < 0) {
+		if (errno == ENOENT)
+			perror_msg_and_skip("opening /proc/self/ns/pid");
+		else
+			perror_msg_and_fail("opening /proc/self/ns/pid");
+	}
+
+	int userns_fd = ioctl(fd, NS_GET_USERNS);
+	if (userns_fd < 0) {
+		if (errno == ENOTTY)
+			error_msg_and_skip("NS_* ioctl commands are not "
+			                   "supported by the kernel");
+		else
+			perror_msg_and_fail("ioctl(NS_GET_USERNS)");
+	}
+
+	close(userns_fd);
+	close(fd);
+}
+
+void
+pidns_test_init(void)
+{
+	pidns_translation = true;
+
+	check_ns_ioctl();
+
+	if (!pidns_fork(-1, false))
+		return;
+
+	/* Unshare user namespace too, so we do not need to be root */
+	if (unshare(CLONE_NEWUSER | CLONE_NEWPID) < 0) {
+		if (errno == EPERM)
+			perror_msg_and_skip("unshare");
+
+		perror_msg_and_fail("unshare");
+	}
+
+	pidns_unshared = true;
+
+	create_init_process();
+
+	if (!pidns_fork(-1, false))
+		return;
+
+	if (!pidns_fork(-1, true))
+		return;
+
+	pid_t pgid;
+	if (!(pgid = pidns_fork(0, false)))
+		return;
+
+	if (!pidns_fork(pgid, false))
+		return;
+
+	exit(0);
+}
diff -pruN 5.5-3/tests-m32/pidns-cache.c 5.9-0ubuntu2/tests-m32/pidns-cache.c
--- 5.5-3/tests-m32/pidns-cache.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pidns-cache.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,62 @@
+/*
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+#include "pidns.h"
+
+#if defined __NR_getpid && (!defined __NR_getxpid || __NR_getxpid != __NR_getpid)
+
+# include <stdio.h>
+# include <unistd.h>
+# include <sys/time.h>
+
+# define SYSCALL_COUNT 1000
+
+/**
+ * Max ratio of the execution time with and without pidns translation.
+ */
+# define MAX_TIME_RATIO 20
+
+static long
+execute_syscalls(void)
+{
+	/* Load our PID in the cache */
+	syscall(__NR_getpid);
+
+	struct timeval stop, start;
+	gettimeofday(&start, NULL);
+
+	for (int i = 0; i < SYSCALL_COUNT; i++)
+	       syscall(__NR_getpid);
+
+	gettimeofday(&stop, NULL);
+
+	return (stop.tv_usec - start.tv_usec) +
+		(stop.tv_sec - start.tv_sec) * 1000000;
+}
+
+int
+main(void)
+{
+	long max_us = execute_syscalls() * MAX_TIME_RATIO;
+
+	pidns_test_init();
+
+	long us = execute_syscalls();
+	if (us > max_us)
+		error_msg_and_fail("pidns translation took too long: %ld us "
+		                   "(max: %ld us)", us, max_us);
+
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_getpid")
+
+#endif
diff -pruN 5.5-3/tests-m32/pidns-cache.test 5.9-0ubuntu2/tests-m32/pidns-cache.test
--- 5.5-3/tests-m32/pidns-cache.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pidns-cache.test	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,15 @@
+#!/bin/sh
+#
+# Test pidns translation cache.
+#
+# Copyright (c) 2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: GPL-2.0-or-later
+
+. "${srcdir=.}/init.sh"
+
+check_prog timeout
+
+run_prog > /dev/null
+run_strace --pidns-translation -f -e trace=getpid $args
diff -pruN 5.5-3/tests-m32/pidns.h 5.9-0ubuntu2/tests-m32/pidns.h
--- 5.5-3/tests-m32/pidns.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pidns.h	2020-09-23 16:29:35.000000000 +0000
@@ -0,0 +1,56 @@
+/*
+ * Test PID namespace translation
+ *
+ * Copyright (c) 2020 Ákos Uzonyi <uzonyi.akos@gmail.com>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+#ifndef STRACE_PIDNS_H
+# define STRACE_PIDNS_H
+
+# ifdef PIDNS_TRANSLATION
+#  define PIDNS_TEST_INIT pidns_test_init()
+# else
+#  define PIDNS_TEST_INIT
+# endif
+
+# include <sys/types.h>
+
+enum pid_type {
+	PT_TID,
+	PT_TGID,
+	PT_PGID,
+	PT_SID,
+
+	PT_COUNT,
+	PT_NONE = -1
+};
+
+/* Prints leader (process tid) if pidns_test_init was called */
+void pidns_print_leader(void);
+
+/*
+ * Returns a static buffer containing the translation string of our PID.
+ */
+const char *pidns_pid2str(enum pid_type type);
+
+/**
+ * Skips the test if NS_* ioctl commands are not supported by the kernel.
+ */
+void check_ns_ioctl(void);
+
+/**
+ * Init pidns testing.
+ *
+ * Should be called at the beginning of the test's main function
+ *
+ * This function calls fork a couple of times, and returns in the child
+ * processes. These child processes are in a new PID namespace with different
+ * PID configurations (group leader, session leader, ...). If any child
+ * terminates with nonzero exit status the test is failed. Otherwise the test is
+ * succesful, and the parent process exits with 0.
+ */
+void pidns_test_init(void);
+
+#endif
\ No newline at end of file
diff -pruN 5.5-3/tests-m32/poll-P.test 5.9-0ubuntu2/tests-m32/poll-P.test
--- 5.5-3/tests-m32/poll-P.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/poll-P.test	2020-04-06 16:22:20.000000000 +0000
@@ -2,20 +2,20 @@
 #
 # Check path tracing of poll syscall.
 #
-# Copyright (c) 2018 The strace developers.
+# Copyright (c) 2018-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/init.sh"
 
-run_prog > /dev/null
+run_prog > /dev/null 9>>/dev/full
 run_strace -a16 -vepoll -P /dev/full 9>>/dev/full \
 	$args > "$EXP"
 match_diff "$LOG" "$EXP"
 
 for abbrev in 0 1 2 3 4 5; do
-	run_prog "../$NAME" $abbrev > /dev/null
+	run_prog "../$NAME" $abbrev > /dev/null 9>>/dev/full
 	run_strace -a16 -epoll -s$abbrev -P /dev/full 9>>/dev/full \
 		$args > "$EXP"
 	match_diff "$LOG" "$EXP"
diff -pruN 5.5-3/tests-m32/prctl-name.c 5.9-0ubuntu2/tests-m32/prctl-name.c
--- 5.5-3/tests-m32/prctl-name.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/prctl-name.c	2020-04-03 22:58:26.000000000 +0000
@@ -3,19 +3,16 @@
  *
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include <sys/prctl.h>
 
-#ifdef HAVE_PRCTL
-# include <sys/prctl.h>
-#endif
-
-#if defined HAVE_PRCTL && defined PR_GET_NAME && defined PR_SET_NAME
+#if defined PR_GET_NAME && defined PR_SET_NAME
 
 # include <stdio.h>
 # include <string.h>
@@ -79,6 +76,6 @@ main(void)
 
 #else
 
-SKIP_MAIN_UNDEFINED("HAVE_PRCTL && PR_GET_NAME && PR_SET_NAME")
+SKIP_MAIN_UNDEFINED("PR_GET_NAME && PR_SET_NAME")
 
 #endif
diff -pruN 5.5-3/tests-m32/prctl-pdeathsig.c 5.9-0ubuntu2/tests-m32/prctl-pdeathsig.c
--- 5.5-3/tests-m32/prctl-pdeathsig.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/prctl-pdeathsig.c	2020-04-03 22:58:26.000000000 +0000
@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2016 JingPiao Chen <chenjingpiao@foxmail.com>
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -17,7 +17,7 @@
 
 # include <stdio.h>
 # include <unistd.h>
-# include <sys/signal.h>
+# include <signal.h>
 
 int
 main(void)
diff -pruN 5.5-3/tests-m32/prctl-seccomp-filter-v.c 5.9-0ubuntu2/tests-m32/prctl-seccomp-filter-v.c
--- 5.5-3/tests-m32/prctl-seccomp-filter-v.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/prctl-seccomp-filter-v.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
  * Check verbose decoding of prctl PR_SET_SECCOMP SECCOMP_MODE_FILTER.
  *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -13,18 +13,14 @@
 #include <unistd.h>
 #include <stdio.h>
 #include <errno.h>
-#include "scno.h"
-
-#ifdef HAVE_PRCTL
-# include <sys/prctl.h>
-#endif
+#include <sys/prctl.h>
 #ifdef HAVE_LINUX_SECCOMP_H
 # include <linux/seccomp.h>
 #endif
 #include <linux/filter.h>
+#include "scno.h"
 
-#if defined HAVE_PRCTL \
- && defined PR_SET_NO_NEW_PRIVS \
+#if defined PR_SET_NO_NEW_PRIVS \
  && defined PR_SET_SECCOMP \
  && defined SECCOMP_MODE_FILTER \
  && defined SECCOMP_RET_ERRNO \
@@ -117,7 +113,7 @@ main(void)
 
 #else
 
-SKIP_MAIN_UNDEFINED("HAVE_PRCTL && PR_SET_NO_NEW_PRIVS && PR_SET_SECCOMP"
+SKIP_MAIN_UNDEFINED("PR_SET_NO_NEW_PRIVS && PR_SET_SECCOMP"
 		    " && SECCOMP_MODE_FILTER && SECCOMP_RET_ERRNO"
 		    " && BPF_JUMP && BPF_STMT")
 
diff -pruN 5.5-3/tests-m32/prctl-seccomp-strict.c 5.9-0ubuntu2/tests-m32/prctl-seccomp-strict.c
--- 5.5-3/tests-m32/prctl-seccomp-strict.c	2019-12-15 16:29:06.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/prctl-seccomp-strict.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,18 +1,16 @@
 /*
  * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include <sys/prctl.h>
 #include "scno.h"
-#ifdef HAVE_PRCTL
-# include <sys/prctl.h>
-#endif
 
-#if defined HAVE_PRCTL && defined PR_SET_SECCOMP && defined __NR_exit
+#if defined PR_SET_SECCOMP && defined __NR_exit
 
 # include <stdio.h>
 # include <unistd.h>
@@ -49,6 +47,6 @@ main(void)
 
 #else
 
-SKIP_MAIN_UNDEFINED("HAVE_PRCTL && PR_SET_SECCOMP && __NR_exit")
+SKIP_MAIN_UNDEFINED("PR_SET_SECCOMP && __NR_exit")
 
 #endif
diff -pruN 5.5-3/tests-m32/preadv.c 5.9-0ubuntu2/tests-m32/preadv.c
--- 5.5-3/tests-m32/preadv.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/preadv.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2014-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -74,12 +74,7 @@ main(void)
 		perror_msg_and_fail("preadv");
 	printf("preadv(0, [], 0, -3) = -1 EINVAL (%m)\n");
 
-	static const char tmp[] = "preadv-tmpfile";
-	int fd = open(tmp, O_RDWR | O_CREAT | O_TRUNC, 0600);
-	if (fd < 0)
-		perror_msg_and_fail("open");
-	if (unlink(tmp))
-		perror_msg_and_fail("unlink");
+	int fd = create_tmpfile(O_RDWR);
 
 	static const char w[] = "0123456789abcde";
 	if (write(fd, w, LENGTH_OF(w)) != LENGTH_OF(w))
diff -pruN 5.5-3/tests-m32/printpath-umovestr-undumpable.c 5.9-0ubuntu2/tests-m32/printpath-umovestr-undumpable.c
--- 5.5-3/tests-m32/printpath-umovestr-undumpable.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/printpath-umovestr-undumpable.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,19 +1,16 @@
 /*
  * Force legacy printpath/umovestr using PR_SET_DUMPABLE.
  *
- * Copyright (c) 2017-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2017-2020 Dmitry V. Levin <ldv@altlinux.org>
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include <sys/prctl.h>
 
-#ifdef HAVE_PRCTL
-# include <sys/prctl.h>
-#endif
-
-#if defined HAVE_PRCTL && defined PR_SET_DUMPABLE
+#ifdef PR_SET_DUMPABLE
 
 # include <stdio.h>
 # include <unistd.h>
@@ -46,6 +43,6 @@ main(void)
 
 #else
 
-SKIP_MAIN_UNDEFINED("HAVE_PRCTL && PR_SET_DUMPABLE")
+SKIP_MAIN_UNDEFINED("PR_SET_DUMPABLE")
 
 #endif
diff -pruN 5.5-3/tests-m32/print_ppid_tracerpid.c 5.9-0ubuntu2/tests-m32/print_ppid_tracerpid.c
--- 5.5-3/tests-m32/print_ppid_tracerpid.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/print_ppid_tracerpid.c	2020-05-27 08:00:00.000000000 +0000
@@ -0,0 +1,42 @@
+/*
+ * Helper program for strace-D.test
+ *
+ * Copyright (c) 2019-2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <unistd.h>
+
+int
+main(void)
+{
+	static const char status[] = "/proc/self/status";
+	FILE *fp = fopen(status, "r");
+	if (!fp)
+		perror_msg_and_fail("fopen: %s", status);
+
+	static const char prefix1[] = "PPid:";
+	static const char prefix2[] = "TracerPid:";
+	char *line = NULL;
+	size_t n = 0;
+
+	while (getline(&line, &n, fp) > 0) {
+		if (strncmp(line, prefix1, sizeof(prefix1) - 1) == 0 ||
+		    strncmp(line, prefix2, sizeof(prefix2) - 1) == 0)
+			fputs(line, stdout);
+	}
+
+	if (!line)
+		perror_msg_and_fail("getline");
+
+	free(line);
+	fclose(fp);
+
+	return 0;
+}
diff -pruN 5.5-3/tests-m32/printstrn-umoven-undumpable.c 5.9-0ubuntu2/tests-m32/printstrn-umoven-undumpable.c
--- 5.5-3/tests-m32/printstrn-umoven-undumpable.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/printstrn-umoven-undumpable.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,19 +1,16 @@
 /*
  * Force legacy printpath/umovestr using PR_SET_DUMPABLE.
  *
- * Copyright (c) 2017-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2017-2020 Dmitry V. Levin <ldv@altlinux.org>
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include <sys/prctl.h>
 
-#ifdef HAVE_PRCTL
-# include <sys/prctl.h>
-#endif
-
-#if defined HAVE_PRCTL && defined PR_SET_DUMPABLE
+#ifdef PR_SET_DUMPABLE
 
 # include <stdio.h>
 # include <unistd.h>
@@ -46,6 +43,6 @@ main(void)
 
 #else
 
-SKIP_MAIN_UNDEFINED("HAVE_PRCTL && PR_SET_DUMPABLE")
+SKIP_MAIN_UNDEFINED("PR_SET_DUMPABLE")
 
 #endif
diff -pruN 5.5-3/tests-m32/prlimit64.c 5.9-0ubuntu2/tests-m32/prlimit64.c
--- 5.5-3/tests-m32/prlimit64.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/prlimit64.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of prlimit64 syscall.
  *
  * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -19,6 +19,7 @@
 # include <sys/resource.h>
 # include <unistd.h>
 
+# include "pidns.h"
 # include "xlat.h"
 # include "xlat/resources.h"
 
@@ -42,8 +43,11 @@ sprint_rlim(uint64_t lim)
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	unsigned long pid =
 		(unsigned long) 0xdefaced00000000ULL | (unsigned) getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
 	uint64_t *const rlimit = tail_alloc(sizeof(*rlimit) * 2);
 	const struct xlat_data *xlat;
 	size_t i = 0;
@@ -54,18 +58,23 @@ main(void)
 
 		unsigned long res = 0xfacefeed00000000ULL | xlat->val;
 		long rc = syscall(__NR_prlimit64, pid, res, 0, rlimit);
+		pidns_print_leader();
 		if (rc)
-			printf("prlimit64(%d, %s, NULL, %p) = %ld %s (%m)\n",
-			       (unsigned) pid, xlat->str, rlimit,
+			printf("prlimit64(%d%s, %s, NULL, %p) ="
+				     " %ld %s (%m)\n",
+			       (unsigned) pid, pid_str,
+			       xlat->str, rlimit,
 			       rc, errno2name());
 		else
-			printf("prlimit64(%d, %s, NULL"
+			printf("prlimit64(%d%s, %s, NULL"
 			       ", {rlim_cur=%s, rlim_max=%s}) = 0\n",
-			       (unsigned) pid, xlat->str,
+			       (unsigned) pid, pid_str,
+			       xlat->str,
 			       sprint_rlim(rlimit[0]),
 			       sprint_rlim(rlimit[1]));
 	}
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/prlimit64--pidns-translation.c 5.9-0ubuntu2/tests-m32/prlimit64--pidns-translation.c
--- 5.5-3/tests-m32/prlimit64--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/prlimit64--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "prlimit64.c"
diff -pruN 5.5-3/tests-m32/prlimit64--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/prlimit64--pidns-translation.gen.test
--- 5.5-3/tests-m32/prlimit64--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/prlimit64--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (prlimit64--pidns-translation test_pidns -e trace=prlimit64); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -e trace=prlimit64
diff -pruN 5.5-3/tests-m32/process_vm_readv--pidns-translation.c 5.9-0ubuntu2/tests-m32/process_vm_readv--pidns-translation.c
--- 5.5-3/tests-m32/process_vm_readv--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/process_vm_readv--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "process_vm_readv.c"
diff -pruN 5.5-3/tests-m32/process_vm_readv--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/process_vm_readv--pidns-translation.gen.test
--- 5.5-3/tests-m32/process_vm_readv--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/process_vm_readv--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (process_vm_readv--pidns-translation test_pidns -s5 -a37 -e trace=process_vm_readv); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -s5 -a37 -e trace=process_vm_readv
diff -pruN 5.5-3/tests-m32/process_vm_readv_writev.c 5.9-0ubuntu2/tests-m32/process_vm_readv_writev.c
--- 5.5-3/tests-m32/process_vm_readv_writev.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/process_vm_readv_writev.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of process_vm_readv/process_vm_writev syscall.
  *
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -12,6 +12,7 @@
 #include <stdio.h>
 #include <unistd.h>
 #include <sys/uio.h>
+#include "pidns.h"
 
 #if OP_WR
 # define in_iovec  rmt_iovec
@@ -121,7 +122,7 @@ print_iov(const struct iovec *iov, const
 }
 
 static void
-do_call(kernel_ulong_t pid,
+do_call(kernel_ulong_t pid, enum pid_type pid_type,
 	kernel_ulong_t local_iov, const char *local_arg,
 	kernel_ulong_t liovcnt,
 	kernel_ulong_t remote_iov, const char *remote_arg,
@@ -135,7 +136,8 @@ do_call(kernel_ulong_t pid,
 		flags);
 	errstr = sprintrc(rc);
 
-	printf("%s(%d, ", OP_STR, (int) pid);
+	pidns_print_leader();
+	printf("%s(%d%s, ", OP_STR, (int) pid, pidns_pid2str(pid_type));
 
 	if (pr_iov)
 		pr_iov((const struct iovec *) (uintptr_t) local_iov, local_arg,
@@ -164,6 +166,8 @@ ptr_cast(void *ptr)
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	enum {
 		SIZE_11 = 2,
 		SIZE_12 = 3,
@@ -243,18 +247,18 @@ main(void)
 	fill_memory_ex(data2_out, SIZE_2, SEGM2_BASE, SIZE_2);
 
 
-	do_call(bogus_pid, (kernel_ulong_t) (uintptr_t) ARG_STR(NULL),
+	do_call(bogus_pid, PT_NONE, (kernel_ulong_t) (uintptr_t) ARG_STR(NULL),
 		bogus_iovcnt1, (kernel_ulong_t) (uintptr_t) ARG_STR(NULL),
 		bogus_iovcnt2, bogus_flags, NULL);
 
-	do_call(my_pid, ptr_cast(bogus_iov + ARRAY_SIZE(bogus_iovec)),
+	do_call(my_pid, PT_TGID, ptr_cast(bogus_iov + ARRAY_SIZE(bogus_iovec)),
 		"[]", 0, ptr_cast(in_iov + ARRAY_SIZE(in_iovec)), "[]",
 		0, 0, NULL);
-	do_call(my_pid, ptr_cast(bogus_iov + ARRAY_SIZE(bogus_iovec)), NULL,
-		bogus_iovcnt1, ptr_cast(in_iov + ARRAY_SIZE(in_iovec)), NULL,
-		bogus_iovcnt2, 0, print_iov);
+	do_call(my_pid, PT_TGID, ptr_cast(bogus_iov + ARRAY_SIZE(bogus_iovec)),
+		NULL, bogus_iovcnt1, ptr_cast(in_iov + ARRAY_SIZE(in_iovec)),
+		NULL, bogus_iovcnt2, 0, print_iov);
 
-	do_call(my_pid, ptr_cast(bogus_iov), (char *) &bogus_arg,
+	do_call(my_pid, PT_TGID, ptr_cast(bogus_iov), (char *) &bogus_arg,
 		ARRAY_SIZE(bogus_iovec), ptr_cast(rmt_iov + 2),
 		(char *) &rmt_arg_cut, ARRAY_SIZE(rmt_iovec) - 2, 0, print_iov);
 
@@ -263,7 +267,7 @@ main(void)
 	lcl_arg_cut.check_rc = 1;
 #endif
 
-	do_call(my_pid, ptr_cast(lcl_iov + 2), (char *) &lcl_arg_cut,
+	do_call(my_pid, PT_TGID, ptr_cast(lcl_iov + 2), (char *) &lcl_arg_cut,
 		ARRAY_SIZE(lcl_iovec) - 1, ptr_cast(bogus_iov + 2),
 		(char *) &bogus_arg_cut, ARRAY_SIZE(bogus_iovec) - 1, 0,
 		print_iov);
@@ -273,15 +277,16 @@ main(void)
 	rmt_arg_cut.addr_term = 1;
 	rmt_arg_cut.count = 5;
 
-	do_call(my_pid, ptr_cast(lcl_iov + 2), (char *) &lcl_arg_cut,
+	do_call(my_pid, PT_TGID, ptr_cast(lcl_iov + 2), (char *) &lcl_arg_cut,
 		ARRAY_SIZE(lcl_iovec) - 2, ptr_cast(rmt_iov + 1),
 		(char *) &rmt_arg_cut, ARRAY_SIZE(rmt_iovec), 0, print_iov);
 
 	/* Correct call */
-	do_call(my_pid, ptr_cast(lcl_iov), (char *) &lcl_arg,
+	do_call(my_pid, PT_TGID, ptr_cast(lcl_iov), (char *) &lcl_arg,
 		ARRAY_SIZE(lcl_iovec), ptr_cast(rmt_iov), (char *) &rmt_arg,
 		ARRAY_SIZE(rmt_iovec), 0, print_iov);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 
 	return 0;
diff -pruN 5.5-3/tests-m32/process_vm_writev--pidns-translation.c 5.9-0ubuntu2/tests-m32/process_vm_writev--pidns-translation.c
--- 5.5-3/tests-m32/process_vm_writev--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/process_vm_writev--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "process_vm_writev.c"
diff -pruN 5.5-3/tests-m32/process_vm_writev--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/process_vm_writev--pidns-translation.gen.test
--- 5.5-3/tests-m32/process_vm_writev--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/process_vm_writev--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (process_vm_writev--pidns-translation test_pidns -s5 -a38 -e trace=process_vm_writev); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -s5 -a38 -e trace=process_vm_writev
diff -pruN 5.5-3/tests-m32/ptrace.c 5.9-0ubuntu2/tests-m32/ptrace.c
--- 5.5-3/tests-m32/ptrace.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ptrace.c	2020-08-03 08:00:00.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of ptrace syscall.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -127,16 +127,16 @@ test_peeksiginfo(unsigned long pid, cons
 			printf("ptrace(PTRACE_PEEKSIGINFO, %u"
 			       ", {off=%llu, flags=0, nr=%u}"
 			       ", [{si_signo=SIGUSR1, si_code=SI_TKILL"
-			       ", si_pid=%u, si_uid=%u}"
+			       ", si_pid=%d, si_uid=%d}"
 			       ", {si_signo=SIGUSR2, si_code=SI_TKILL"
-			       ", si_pid=%u, si_uid=%u}"
+			       ", si_pid=%d, si_uid=%d}"
 			       ", {si_signo=SIGALRM, si_code=SI_TKILL"
-			       ", si_pid=%u, si_uid=%u}"
+			       ", si_pid=%d, si_uid=%d}"
 			       "]) = %s\n",
 			       (unsigned) pid, psi->off, psi->nr,
-			       (unsigned) pid, (unsigned) uid,
-			       (unsigned) pid, (unsigned) uid,
-			       (unsigned) pid, (unsigned) uid,
+			       (int) pid, (int) uid,
+			       (int) pid, (int) uid,
+			       (int) pid, (int) uid,
 			       errstr);
 		}
 
diff -pruN 5.5-3/tests-m32/ptrace_syscall_info.c 5.9-0ubuntu2/tests-m32/ptrace_syscall_info.c
--- 5.5-3/tests-m32/ptrace_syscall_info.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/ptrace_syscall_info.c	2020-05-27 08:00:00.000000000 +0000
@@ -247,7 +247,12 @@ test_entry(void)
 					break;
 				goto printed_entry_nr;
 			}
-			if (info.entry.args[i] != exp_args[i + 1])
+#if SIZEOF_KERNEL_LONG_T > SIZEOF_LONG
+# define CAST (unsigned long)
+#else
+# define CAST
+#endif
+			if (CAST info.entry.args[i] != exp_args[i + 1])
 				FAIL("#%d: entry stop mismatch", ptrace_stop);
 			printf("%s%#llx", (i ? ", " : ", arg=["),
 			       (unsigned long long) info.entry.args[i]);
diff -pruN 5.5-3/tests-m32/pure_executables.am 5.9-0ubuntu2/tests-m32/pure_executables.am
--- 5.5-3/tests-m32/pure_executables.am	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pure_executables.am	2020-09-24 09:18:49.000000000 +0000
@@ -27,13 +27,29 @@ PURE_EXECUTABLES = \
   clone3-Xabbrev \
   clone3-Xraw \
   clone3-Xverbose \
+  close_range \
+  close_range-P \
+  close_range-y \
+  close_range-yy \
   copy_file_range \
   creat \
   delete_module \
+  dev--decode-fds-dev \
+  dev--decode-fds-path \
+  dev--decode-fds-socket \
   dev-yy \
   dup \
+  dup-P \
+  dup-y \
+  dup-yy \
   dup2 \
+  dup2-P \
+  dup2-y \
+  dup2-yy \
   dup3 \
+  dup3-P \
+  dup3-y \
+  dup3-yy \
   epoll_create \
   epoll_create1 \
   epoll_ctl \
@@ -44,6 +60,13 @@ PURE_EXECUTABLES = \
   execve \
   execveat \
   faccessat \
+  faccessat-P \
+  faccessat-y \
+  faccessat-yy \
+  faccessat2 \
+  faccessat2-P \
+  faccessat2-y \
+  faccessat2-yy \
   fadvise64 \
   fadvise64_64 \
   fallocate \
@@ -92,7 +115,9 @@ PURE_EXECUTABLES = \
   getcpu \
   getcwd \
   getdents \
+  getdents-v \
   getdents64 \
+  getdents64-v \
   getegid \
   getegid32 \
   geteuid \
@@ -116,7 +141,9 @@ PURE_EXECUTABLES = \
   getsockname \
   getuid \
   getuid32 \
-  getxxid \
+  getxgid \
+  getxpid \
+  getxuid \
   group_req \
   inet-cmsg \
   init_module \
@@ -139,6 +166,14 @@ PURE_EXECUTABLES = \
   ioctl_evdev-v-Xabbrev \
   ioctl_evdev-v-Xraw \
   ioctl_evdev-v-Xverbose \
+  ioctl_hdio \
+  ioctl_hdio-Xabbrev \
+  ioctl_hdio-Xraw \
+  ioctl_hdio-Xverbose \
+  ioctl_hdio-v \
+  ioctl_hdio-v-Xabbrev \
+  ioctl_hdio-v-Xraw \
+  ioctl_hdio-v-Xverbose \
   ioctl_inotify \
   ioctl_kvm_run \
   ioctl_kvm_run-v \
@@ -154,8 +189,16 @@ PURE_EXECUTABLES = \
   ioctl_sg_io_v3 \
   ioctl_sg_io_v4 \
   ioctl_sock_gifconf \
+  ioctl_tee \
   ioctl_uffdio \
   ioctl_v4l2 \
+  ioctl_v4l2-Xabbrev \
+  ioctl_v4l2-Xraw \
+  ioctl_v4l2-Xverbose \
+  ioctl_v4l2-v \
+  ioctl_v4l2-v-Xabbrev \
+  ioctl_v4l2-v-Xraw \
+  ioctl_v4l2-v-Xverbose \
   ioctl_watchdog \
   ioperm \
   iopl \
@@ -206,6 +249,7 @@ PURE_EXECUTABLES = \
   lstat64 \
   madvise \
   maybe_switch_current_tcp \
+  maybe_switch_current_tcp--quiet-thread-execve \
   mbind \
   mbind-Xabbrev \
   mbind-Xraw \
@@ -253,6 +297,10 @@ PURE_EXECUTABLES = \
   msg_name \
   munlockall \
   nanosleep \
+  net--decode-fds-dev-netlink \
+  net--decode-fds-none-netlink \
+  net--decode-fds-path-netlink \
+  net--decode-fds-socket-netlink \
   net-icmp_filter \
   net-packet_mreq \
   net-packet_mreq-Xabbrev \
@@ -335,6 +383,16 @@ PURE_EXECUTABLES = \
   open_tree \
   open_tree-P \
   openat \
+  openat2 \
+  openat2-Xabbrev \
+  openat2-Xraw \
+  openat2-Xverbose \
+  openat2-v \
+  openat2-v-y \
+  openat2-v-y-Xabbrev \
+  openat2-v-y-Xraw \
+  openat2-v-y-Xverbose \
+  openat2-y \
   osf_utimes \
   pause \
   perf_event_open \
@@ -342,9 +400,16 @@ PURE_EXECUTABLES = \
   personality-Xabbrev \
   personality-Xraw \
   personality-Xverbose \
+  pidfd_getfd \
+  pidfd_getfd-y \
+  pidfd_getfd-yy \
   pidfd_open \
+  pidfd_open--decode-fd-path \
+  pidfd_open--decode-fd-pidfd \
+  pidfd_open--decode-fd-socket \
   pidfd_open-P \
   pidfd_open-y \
+  pidfd_open-yy \
   pidfd_send_signal \
   pipe \
   pipe2 \
@@ -352,9 +417,7 @@ PURE_EXECUTABLES = \
   pkey_free \
   pkey_mprotect \
   poll \
-  poll-P \
   ppoll \
-  ppoll-P \
   prctl-arg2-intptr \
   prctl-dumpable \
   prctl-name \
@@ -503,11 +566,21 @@ PURE_EXECUTABLES = \
   statfs64 \
   status-all \
   status-failed \
+  status-failed-long \
+  status-failed-status \
   status-none \
   status-none-f \
   status-successful \
+  status-successful-long \
+  status-successful-status \
   status-unfinished \
   statx \
+  strace--strings-in-hex \
+  strace--strings-in-hex-all \
+  strace--strings-in-hex-non-ascii \
+  strace-n \
+  strace-x \
+  strace-xx \
   swap \
   sxetmask \
   symlink \
@@ -518,12 +591,14 @@ PURE_EXECUTABLES = \
   sysinfo \
   syslog \
   tee \
+  tgkill \
   time \
   timer_create \
   timer_xettime \
   timerfd_xettime \
   times \
   times-fail \
+  tkill \
   truncate \
   truncate64 \
   ugetrlimit \
@@ -537,6 +612,7 @@ PURE_EXECUTABLES = \
   umovestr2 \
   umovestr3 \
   umovestr_cached \
+  umovestr_cached_adjacent \
   uname \
   unlink \
   unlinkat \
diff -pruN 5.5-3/tests-m32/pure_executables.list 5.9-0ubuntu2/tests-m32/pure_executables.list
--- 5.5-3/tests-m32/pure_executables.list	2019-12-11 22:44:53.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/pure_executables.list	2020-09-23 12:56:26.000000000 +0000
@@ -1,6 +1,6 @@
 # Executables without side effects.
 #
-# Copyright (c) 2017-2019 The strace developers.
+# Copyright (c) 2017-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -32,13 +32,29 @@ clone3
 clone3-Xabbrev
 clone3-Xraw
 clone3-Xverbose
+close_range
+close_range-P
+close_range-y
+close_range-yy
 copy_file_range
 creat
 delete_module
+dev--decode-fds-dev
+dev--decode-fds-path
+dev--decode-fds-socket
 dev-yy
 dup
+dup-P
+dup-y
+dup-yy
 dup2
+dup2-P
+dup2-y
+dup2-yy
 dup3
+dup3-P
+dup3-y
+dup3-yy
 epoll_create
 epoll_create1
 epoll_ctl
@@ -49,6 +65,13 @@ eventfd
 execve
 execveat
 faccessat
+faccessat-P
+faccessat-y
+faccessat-yy
+faccessat2
+faccessat2-P
+faccessat2-y
+faccessat2-yy
 fadvise64
 fadvise64_64
 fallocate
@@ -97,7 +120,9 @@ get_mempolicy
 getcpu
 getcwd
 getdents
+getdents-v
 getdents64
+getdents64-v
 getegid
 getegid32
 geteuid
@@ -121,7 +146,9 @@ getsid
 getsockname
 getuid
 getuid32
-getxxid
+getxgid
+getxpid
+getxuid
 group_req
 inet-cmsg
 init_module
@@ -144,6 +171,14 @@ ioctl_evdev-v
 ioctl_evdev-v-Xabbrev
 ioctl_evdev-v-Xraw
 ioctl_evdev-v-Xverbose
+ioctl_hdio
+ioctl_hdio-Xabbrev
+ioctl_hdio-Xraw
+ioctl_hdio-Xverbose
+ioctl_hdio-v
+ioctl_hdio-v-Xabbrev
+ioctl_hdio-v-Xraw
+ioctl_hdio-v-Xverbose
 ioctl_inotify
 ioctl_kvm_run
 ioctl_kvm_run-v
@@ -159,8 +194,16 @@ ioctl_scsi
 ioctl_sg_io_v3
 ioctl_sg_io_v4
 ioctl_sock_gifconf
+ioctl_tee
 ioctl_uffdio
 ioctl_v4l2
+ioctl_v4l2-Xabbrev
+ioctl_v4l2-Xraw
+ioctl_v4l2-Xverbose
+ioctl_v4l2-v
+ioctl_v4l2-v-Xabbrev
+ioctl_v4l2-v-Xraw
+ioctl_v4l2-v-Xverbose
 ioctl_watchdog
 ioperm
 iopl
@@ -211,6 +254,7 @@ lstat
 lstat64
 madvise
 maybe_switch_current_tcp
+maybe_switch_current_tcp--quiet-thread-execve
 mbind
 mbind-Xabbrev
 mbind-Xraw
@@ -258,6 +302,10 @@ msg_control
 msg_name
 munlockall
 nanosleep
+net--decode-fds-dev-netlink
+net--decode-fds-none-netlink
+net--decode-fds-path-netlink
+net--decode-fds-socket-netlink
 net-icmp_filter
 net-packet_mreq
 net-packet_mreq-Xabbrev
@@ -340,6 +388,16 @@ open
 open_tree
 open_tree-P
 openat
+openat2
+openat2-Xabbrev
+openat2-Xraw
+openat2-Xverbose
+openat2-v
+openat2-v-y
+openat2-v-y-Xabbrev
+openat2-v-y-Xraw
+openat2-v-y-Xverbose
+openat2-y
 osf_utimes
 pause
 perf_event_open
@@ -347,9 +405,16 @@ personality
 personality-Xabbrev
 personality-Xraw
 personality-Xverbose
+pidfd_getfd
+pidfd_getfd-y
+pidfd_getfd-yy
 pidfd_open
+pidfd_open--decode-fd-path
+pidfd_open--decode-fd-pidfd
+pidfd_open--decode-fd-socket
 pidfd_open-P
 pidfd_open-y
+pidfd_open-yy
 pidfd_send_signal
 pipe
 pipe2
@@ -357,9 +422,7 @@ pkey_alloc
 pkey_free
 pkey_mprotect
 poll
-poll-P
 ppoll
-ppoll-P
 prctl-arg2-intptr
 prctl-dumpable
 prctl-name
@@ -508,11 +571,21 @@ statfs
 statfs64
 status-all
 status-failed
+status-failed-long
+status-failed-status
 status-none
 status-none-f
 status-successful
+status-successful-long
+status-successful-status
 status-unfinished
 statx
+strace--strings-in-hex
+strace--strings-in-hex-all
+strace--strings-in-hex-non-ascii
+strace-n
+strace-x
+strace-xx
 swap
 sxetmask
 symlink
@@ -523,12 +596,14 @@ sync_file_range2
 sysinfo
 syslog
 tee
+tgkill
 time
 timer_create
 timer_xettime
 timerfd_xettime
 times
 times-fail
+tkill
 truncate
 truncate64
 ugetrlimit
@@ -542,6 +617,7 @@ umovestr-illptr
 umovestr2
 umovestr3
 umovestr_cached
+umovestr_cached_adjacent
 uname
 unlink
 unlinkat
diff -pruN 5.5-3/tests-m32/qual_fault.c 5.9-0ubuntu2/tests-m32/qual_fault.c
--- 5.5-3/tests-m32/qual_fault.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/qual_fault.c	2020-06-01 14:15:16.000000000 +0000
@@ -2,7 +2,7 @@
  * Check that fault injection works properly.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -29,7 +29,7 @@ static int out_fd;
 #define DEFAULT_ERRNO ENOSYS
 
 static const char *errstr;
-static int is_raw, err, first, step, iter, try;
+static int is_raw, err, first, last, step, iter, try;
 
 static void
 invoke(int fail)
@@ -99,7 +99,7 @@ open_file(const char *prefix, int proc)
 int
 main(int argc, char *argv[])
 {
-	assert(argc == 11);
+	assert(argc == 12);
 
 	is_raw = !strcmp("raw", argv[1]);
 
@@ -120,13 +120,14 @@ main(int argc, char *argv[])
 	errstr = errno2name();
 
 	first = atoi(argv[3]);
-	step = atoi(argv[4]);
-	iter = atoi(argv[5]);
-	int num_procs = atoi(argv[6]);
-	char *exp_prefix = argv[7];
-	char *got_prefix = argv[8];
-	char *out_prefix = argv[9];
-	char *pid_prefix = argv[10];
+	last = atoi(argv[4]);
+	step = atoi(argv[5]);
+	iter = atoi(argv[6]);
+	int num_procs = atoi(argv[7]);
+	char *exp_prefix = argv[8];
+	char *got_prefix = argv[9];
+	char *out_prefix = argv[10];
+	char *pid_prefix = argv[11];
 
 	assert(first > 0);
 	assert(step >= 0);
@@ -164,8 +165,10 @@ main(int argc, char *argv[])
 		int i;
 		for (i = 1; i <= iter; ++i) {
 			int fail = 0;
-			if (first > 0) {
+			if (last != 0) {
 				--first;
+				if (last != -1)
+					--last;
 				if (first == 0) {
 					fail = 1;
 					first = step;
diff -pruN 5.5-3/tests-m32/qual_fault-syntax.test 5.9-0ubuntu2/tests-m32/qual_fault-syntax.test
--- 5.5-3/tests-m32/qual_fault-syntax.test	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/qual_fault-syntax.test	2020-06-01 14:15:16.000000000 +0000
@@ -3,6 +3,7 @@
 # Check -e fault= syntax.
 #
 # Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
+# Copyright (c) 2017-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -72,6 +73,27 @@ for arg in chdir:42 \!chdir:42 \
 	   chdir:syscall=-42 \
 	   chdir:syscall=42 \
 	   chdir:syscall=gettid:syscall=gettid \
+	   chdir:when=. \
+	   chdir:when=.+ \
+	   chdir:when=..+ \
+	   chdir:when=+ \
+	   chdir:when=++ \
+	   chdir:when=10. \
+	   chdir:when=11.12 \
+	   chdir:when=13.14+ \
+	   chdir:when=15.. \
+	   chdir:when=16... \
+	   chdir:when=17...18 \
+	   chdir:when=.19 \
+	   chdir:when=..20 \
+	   chdir:when=..21+ \
+	   chdir:when=..22+3 \
+	   chdir:when=24..23 \
+	   chdir:when=25..26+0 \
+	   chdir:when=27..65535 \
+	   chdir:when=28..65535+ \
+	   chdir:when=65535..65535 \
+	   chdir:when=65535..65535+ \
 	   ; do
 	$STRACE -e fault="$arg" true 2> "$LOG" &&
 		fail_with "$arg"
diff -pruN 5.5-3/tests-m32/qual_fault.test 5.9-0ubuntu2/tests-m32/qual_fault.test
--- 5.5-3/tests-m32/qual_fault.test	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/qual_fault.test	2020-06-01 14:15:16.000000000 +0000
@@ -3,7 +3,7 @@
 # Check that fault injection works properly.
 #
 # Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -22,24 +22,32 @@ N=100
 
 check_fault_injection()
 {
-	local trace fault err first step procs extra
+	local trace fault err first last step procs extra
 	trace=$1; shift
 	fault=$1; shift
 	err=$1; shift
 	first=$1; shift
+	last=$1; shift
 	step=$1; shift
 	procs=$1; shift
 	extra="$*"
 
 	local when=
-	if [ -z "$first$step" ]; then
+	if [ -z "$first$last$step" ]; then
 		first=1
+		last=-1
 		step=1
+	elif [ -z "$last" ]; then
+		case "$step" in
+			'') when=":when=$first"; step=1; last=$first ;;
+			+) when=":when=$first+"; step=1; last=-1 ;;
+			*) when=":when=$first+$step"; last=-1; ;;
+		esac
 	else
 		case "$step" in
-			'') when=":when=$first"; step=0 ;;
-			+) when=":when=$first+"; step=1 ;;
-			*) when=":when=$first+$step" ;;
+			'') when=":when=${first}..${last}"; step=1 ;;
+			+) when=":when=${first}..${last}+"; step=1 ;;
+			*) when=":when=${first}..${last}+${step}" ;;
 		esac
 	fi
 
@@ -63,7 +71,7 @@ check_fault_injection()
 
 	run_strace -a11 -ff -e trace=$trace \
 		"$@" -e fault=$fault$when$error$suffix $extra \
-		../$NAME $raw "$err" "$first" "$step" $N \
+		../$NAME $raw "$err" "$first" "$last" "$step" $N \
 		"$procs" "$outexp" "$outgot" "$outout" "$outpid"
 
 	for i in $(seq 0 $((procs - 1)) )
@@ -78,19 +86,37 @@ check_fault_injection()
 for err in '' ENOSYS 22 einval; do
 	for fault in writev desc,51; do
 		check_fault_injection \
-			writev $fault "$err" '' '' 1 -efault=chdir
+			writev $fault "$err" '' '' '' 1 -efault=chdir
 		check_fault_injection \
-			writev $fault "$err" '' '' 1 -efault=chdir -efault=none
+			writev $fault "$err" '' '' '' 1 -efault=chdir -efault=none
 		for F in 1 2 3 5 7 11; do
 			check_fault_injection \
-				writev $fault "$err" $F '' 1
+				writev $fault "$err" $F '' '' 1
 			check_fault_injection \
-				writev $fault "$err" $F + 1
+				writev $fault "$err" $F '' + 1
+
+			for L in 1 2 3 5 7 11; do
+				[ "$L" -ge "$F" ] ||
+					continue
+				check_fault_injection \
+					writev $fault "$err" $F $L '' 1
+				check_fault_injection \
+					writev $fault "$err" $F $L + 1
+			done
+
 			for S in 1 2 3 5 7 11; do
 				check_fault_injection \
-					writev $fault "$err" $F $S 1
+					writev $fault "$err" $F '' $S 1
 				check_fault_injection \
-					writev $fault "$err" $F $S 4
+					writev $fault "$err" $F '' $S 4
+				for L in 1 2 3 5 7 11; do
+					[ "$L" -ge "$F" ] ||
+						continue
+					check_fault_injection \
+						writev $fault "$err" $F $L $S 1
+					check_fault_injection \
+						writev $fault "$err" $F $L $S 4
+				done
 			done
 		done
 	done
diff -pruN 5.5-3/tests-m32/qual_inject-syntax.test 5.9-0ubuntu2/tests-m32/qual_inject-syntax.test
--- 5.5-3/tests-m32/qual_inject-syntax.test	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/qual_inject-syntax.test	2020-06-01 14:15:16.000000000 +0000
@@ -3,6 +3,7 @@
 # Check -e inject= syntax.
 #
 # Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
+# Copyright (c) 2017-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -88,6 +89,27 @@ for arg in 42 chdir \
 	   chdir:syscall=-42 \
 	   chdir:syscall=42 \
 	   chdir:syscall=gettid:syscall=gettid \
+	   chdir:when=. \
+	   chdir:when=.+ \
+	   chdir:when=..+ \
+	   chdir:when=+ \
+	   chdir:when=++ \
+	   chdir:when=10. \
+	   chdir:when=11.12 \
+	   chdir:when=13.14+ \
+	   chdir:when=15.. \
+	   chdir:when=16... \
+	   chdir:when=17...18 \
+	   chdir:when=.19 \
+	   chdir:when=..20 \
+	   chdir:when=..21+ \
+	   chdir:when=..22+3 \
+	   chdir:when=24..23 \
+	   chdir:when=25..26+0 \
+	   chdir:when=27..65535 \
+	   chdir:when=28..65535+ \
+	   chdir:when=65535..65535 \
+	   chdir:when=65535..65535+ \
 	   ; do
 	$STRACE -e inject="$arg" true 2> "$LOG" &&
 		fail_with "$arg"
diff -pruN 5.5-3/tests-m32/readahead.c 5.9-0ubuntu2/tests-m32/readahead.c
--- 5.5-3/tests-m32/readahead.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/readahead.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -11,24 +11,20 @@
 
 #ifdef HAVE_READAHEAD
 /* Check for glibc readahead argument passing bugs. */
-# ifdef __GLIBC__
 /*
  * glibc < 2.8 had an incorrect order of higher and lower parts of offset,
  * see https://sourceware.org/bugzilla/show_bug.cgi?id=5208
  */
-#  if !(defined __GLIBC_MINOR__ && \
-	(__GLIBC__ << 16) + __GLIBC_MINOR__ >= (2 << 16) + 8)
-#   undef HAVE_READAHEAD
-#  endif /* glibc < 2.8 */
+# if GLIBC_PREREQ_LT(2, 8)
+#  undef HAVE_READAHEAD
+# endif /* glibc < 2.8 */
 /*
  * glibc < 2.25 had an incorrect implementation on mips n64,
  * see https://sourceware.org/bugzilla/show_bug.cgi?id=21026
  */
-#  if defined LINUX_MIPSN64 && !(defined __GLIBC_MINOR__ && \
-	(__GLIBC__ << 16) + __GLIBC_MINOR__ >= (2 << 16) + 25)
-#   undef HAVE_READAHEAD
-#  endif /* LINUX_MIPSN64 && glibc < 2.25 */
-# endif /* __GLIBC__ */
+# if GLIBC_PREREQ_LT(2, 25) && defined LINUX_MIPSN64
+#  undef HAVE_READAHEAD
+# endif /* LINUX_MIPSN64 && glibc < 2.25 */
 #endif /* HAVE_READAHEAD */
 
 #ifdef HAVE_READAHEAD
diff -pruN 5.5-3/tests-m32/read-write.c 5.9-0ubuntu2/tests-m32/read-write.c
--- 5.5-3/tests-m32/read-write.c	2019-07-16 17:46:47.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/read-write.c	2020-04-07 00:57:01.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding and dumping of read and write syscalls.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -153,9 +153,17 @@ main(void)
 	skip_if_unavailable("/proc/self/fd/");
 
 	static const char tmp[] = "read-write-tmpfile";
-	if (open(tmp, O_CREAT|O_RDONLY|O_TRUNC, 0600) != 0)
+	bool need_cleanup = true;
+	long rc;
+
+	rc = open(tmp, O_RDONLY, 0600);
+	if (rc < 0) {
+		rc = open(tmp, O_CREAT|O_EXCL|O_RDONLY, 0600);
+		need_cleanup = false;
+	}
+	if (rc != 0)
 		perror_msg_and_fail("creat: %s", tmp);
-	if (open(tmp, O_WRONLY) != 1)
+	if (open(tmp, O_TRUNC|O_WRONLY) != 1)
 		perror_msg_and_fail("open: %s", tmp);
 
 	static const char w_c[] = "0123456789abcde";
@@ -175,8 +183,6 @@ main(void)
 
 	void *efault = r1 - get_page_size();
 
-	long rc;
-
 	rc = k_write(1, w, 0);
 	if (rc)
 		perror_msg_and_fail("write: expected 0, returned %ld", rc);
@@ -270,9 +276,11 @@ main(void)
 	if (open("/dev/null", O_WRONLY) != 1)
 		perror_msg_and_fail("open");
 
+	(void) close(4);
 	if (open("/dev/zero", O_RDONLY) != 4)
 		perror_msg_and_fail("open");
 
+	(void) close(5);
 	if (open("/dev/null", O_WRONLY) != 5)
 		perror_msg_and_fail("open");
 
@@ -282,6 +290,9 @@ main(void)
 
 	test_dump(256, true);
 
+	if (need_cleanup && unlink(tmp))
+		perror_msg_and_fail("unlink: %s", tmp);
+
 	tprintf("+++ exited with 0 +++\n");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/redirect.test 5.9-0ubuntu2/tests-m32/redirect.test
--- 5.5-3/tests-m32/redirect.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/redirect.test	2020-04-07 00:57:01.000000000 +0000
@@ -3,7 +3,7 @@
 # Ensure that strace does not retain stdin and stdout descriptors.
 #
 # Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -16,42 +16,34 @@ run_prog_skip_if_failed \
 check_prog sleep
 check_prog yes
 
+SLEEP_3_BITS="$SLEEP_A_BIT; $SLEEP_A_BIT; $SLEEP_A_BIT"
 > "$OUT"
-> "$LOG"
+
+> lock1
+> lock2
 (
-	while [ -f "$LOG" ]; do
-		:
+	while [ -f lock1 ]; do
+		$SLEEP_A_BIT
 	done
-	$SLEEP_A_BIT &
 	yes
-	if kill -0 $! 2> /dev/null; then
-		wait
-	else
-		echo TIMEOUT >> "$OUT"
-	fi
+	[ -f lock2 ] ||
+		printf ' input' >> "$OUT"
 ) | $STRACE -qq -enone -esignal=none \
-	sh -c "exec <&- >&-; rm -f -- $LOG; $SLEEP_A_BIT; $SLEEP_A_BIT"
-
-if [ -s "$OUT" ]; then
-	fail_ "$STRACE failed to redirect standard input"
-fi
+	sh -c "exec <&- >&-; rm -f lock1; $SLEEP_3_BITS; rm -f lock2"
 
-> "$LOG"
+> lock1
+> lock2
 $STRACE -qq -enone -esignal=none \
-	sh -c "exec <&- >&-; rm -f -- $LOG; $SLEEP_A_BIT; $SLEEP_A_BIT" |
+	sh -c "exec <&- >&-; rm -f lock1; $SLEEP_3_BITS; rm -f lock2" |
 (
-	while [ -f "$LOG" ]; do
-		:
+	while [ -f lock1 ]; do
+		$SLEEP_A_BIT
 	done
-	$SLEEP_A_BIT &
 	cat > /dev/null
-	if kill -0 $! 2> /dev/null; then
-		wait
-	else
-		echo TIMEOUT >> "$OUT"
-	fi
+	[ -f lock2 ] ||
+		printf ' output' >> "$OUT"
 )
 
 if [ -s "$OUT" ]; then
-	fail_ "$STRACE failed to redirect standard output"
+	fail_ "$STRACE failed to redirect standard descriptors:$(cat "$OUT")"
 fi
diff -pruN 5.5-3/tests-m32/rt_sigqueueinfo.c 5.9-0ubuntu2/tests-m32/rt_sigqueueinfo.c
--- 5.5-3/tests-m32/rt_sigqueueinfo.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/rt_sigqueueinfo.c	2020-08-25 14:29:30.000000000 +0000
@@ -1,12 +1,13 @@
 /*
  * Copyright (c) 2015 Elvira Khabirova <lineprinter0@gmail.com>
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include "pidns.h"
 #include <assert.h>
 #include <stdio.h>
 #include <signal.h>
@@ -15,6 +16,8 @@
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	struct sigaction sa = {
 		.sa_handler = SIG_IGN
 	};
@@ -22,15 +25,19 @@ main(void)
 		.sival_ptr = (void *) (unsigned long) 0xdeadbeefbadc0dedULL
 	};
 	pid_t pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
 
 	assert(sigaction(SIGUSR1, &sa, NULL) == 0);
 	if (sigqueue(pid, SIGUSR1, value))
 		perror_msg_and_skip("sigqueue");
-	printf("rt_sigqueueinfo(%u, SIGUSR1, {si_signo=SIGUSR1, "
-		"si_code=SI_QUEUE, si_pid=%u, si_uid=%u, "
+	pidns_print_leader();
+	printf("rt_sigqueueinfo(%d%s, SIGUSR1, {si_signo=SIGUSR1, "
+		"si_code=SI_QUEUE, si_pid=%d%s, si_uid=%u, "
 		"si_value={int=%d, ptr=%p}}) = 0\n",
-		pid, pid, getuid(), value.sival_int, value.sival_ptr);
-	printf("+++ exited with 0 +++\n");
+		pid, pid_str, pid, pid_str,
+		getuid(), value.sival_int, value.sival_ptr);
+	pidns_print_leader();
+	puts("+++ exited with 0 +++");
 
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/rt_sigqueueinfo--pidns-translation.c 5.9-0ubuntu2/tests-m32/rt_sigqueueinfo--pidns-translation.c
--- 5.5-3/tests-m32/rt_sigqueueinfo--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/rt_sigqueueinfo--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "rt_sigqueueinfo.c"
diff -pruN 5.5-3/tests-m32/rt_sigqueueinfo--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/rt_sigqueueinfo--pidns-translation.gen.test
--- 5.5-3/tests-m32/rt_sigqueueinfo--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/rt_sigqueueinfo--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (rt_sigqueueinfo--pidns-translation test_pidns -esignal=none -e trace=rt_sigqueueinfo); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -esignal=none -e trace=rt_sigqueueinfo
diff -pruN 5.5-3/tests-m32/rt_tgsigqueueinfo.c 5.9-0ubuntu2/tests-m32/rt_tgsigqueueinfo.c
--- 5.5-3/tests-m32/rt_tgsigqueueinfo.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/rt_tgsigqueueinfo.c	2020-08-25 14:29:30.000000000 +0000
@@ -2,7 +2,7 @@
  * This file is part of rt_tgsigqueueinfo strace test.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,8 +10,9 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
-#ifdef __NR_rt_tgsigqueueinfo
+#if defined __NR_rt_tgsigqueueinfo && defined __NR_gettid
 
 # include <errno.h>
 # include <signal.h>
@@ -20,11 +21,11 @@
 # include <unistd.h>
 
 static long
-k_tgsigqueueinfo(const pid_t pid, const int sig, const void *const info)
+k_tgsigqueueinfo(const pid_t tgid, const int tid, const int sig, const void *const info)
 {
 	return syscall(__NR_rt_tgsigqueueinfo,
-		       F8ILL_KULONG_MASK | pid,
-		       F8ILL_KULONG_MASK | pid,
+		       F8ILL_KULONG_MASK | tgid,
+		       F8ILL_KULONG_MASK | tid,
 		       F8ILL_KULONG_MASK | sig,
 		       info);
 }
@@ -32,6 +33,8 @@ k_tgsigqueueinfo(const pid_t pid, const
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	const struct sigaction sa = {
 		.sa_handler = SIG_IGN
 	};
@@ -48,17 +51,22 @@ main(void)
 	info->si_value.sival_ptr =
 		(void *) (unsigned long) 0xdeadbeeffacefeedULL;
 
-	if (k_tgsigqueueinfo(info->si_pid, SIGUSR1, info))
+	if (k_tgsigqueueinfo(getpid(), syscall(__NR_gettid), SIGUSR1, info))
 		(errno == ENOSYS ? perror_msg_and_skip : perror_msg_and_fail)(
 			"rt_tgsigqueueinfo");
 
-	printf("rt_tgsigqueueinfo(%u, %u, %s, {si_signo=%s"
-		", si_code=SI_QUEUE, si_errno=ENOENT, si_pid=%u"
-		", si_uid=%u, si_value={int=%d, ptr=%p}}) = 0\n",
-		info->si_pid, info->si_pid, "SIGUSR1", "SIGUSR1",
-		info->si_pid, info->si_uid, info->si_value.sival_int,
+	pidns_print_leader();
+	printf("rt_tgsigqueueinfo(%d%s, %d%s, %s, {si_signo=%s"
+		", si_code=SI_QUEUE, si_errno=ENOENT, si_pid=%d%s"
+		", si_uid=%d, si_value={int=%d, ptr=%p}}) = 0\n",
+		info->si_pid, pidns_pid2str(PT_TGID),
+		info->si_pid, pidns_pid2str(PT_TID),
+		"SIGUSR1", "SIGUSR1",
+		info->si_pid, pidns_pid2str(PT_TGID),
+		info->si_uid, info->si_value.sival_int,
 		info->si_value.sival_ptr);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/rt_tgsigqueueinfo--pidns-translation.c 5.9-0ubuntu2/tests-m32/rt_tgsigqueueinfo--pidns-translation.c
--- 5.5-3/tests-m32/rt_tgsigqueueinfo--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/rt_tgsigqueueinfo--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "rt_tgsigqueueinfo.c"
diff -pruN 5.5-3/tests-m32/rt_tgsigqueueinfo--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/rt_tgsigqueueinfo--pidns-translation.gen.test
--- 5.5-3/tests-m32/rt_tgsigqueueinfo--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/rt_tgsigqueueinfo--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (rt_tgsigqueueinfo--pidns-translation test_pidns -esignal=none -e trace=rt_tgsigqueueinfo); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -esignal=none -e trace=rt_tgsigqueueinfo
diff -pruN 5.5-3/tests-m32/s390_sthyi.c 5.9-0ubuntu2/tests-m32/s390_sthyi.c
--- 5.5-3/tests-m32/s390_sthyi.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/s390_sthyi.c	2020-07-24 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check decoding of s390_sthyi syscall.
  *
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -113,7 +113,7 @@ ebcdic2ascii(unsigned char *ebcdic, size
 				   size, sizeof(ascii_buf));
 	if (cd == (iconv_t) -1)
 		perror_msg_and_fail("ebcdic2ascii: unable to allocate a "
-				    "conversion descriptior for converting "
+				    "conversion descriptor for converting "
 				    "EBCDIC to ASCII");
 
 	while ((ret = iconv(cd, &ebcdic_pos, &ebcdic_left,
@@ -509,7 +509,7 @@ print_sthyi(unsigned char *buf)
 	hdr_size = *(uint16_t *) (buf + 10);
 	if (hdr_size < 44)
 		error_msg_and_fail("sthyi: header section is too small "
-			           "(got %hu, 44 expected)", hdr_size);
+				   "(got %hu, >=44 expected)", hdr_size);
 
 	/* INFHFLG1 */
 	print_0x8("{/* header */ {infhflg1", buf, 0, true);
@@ -598,7 +598,7 @@ print_sthyi(unsigned char *buf)
 	hdr_size = *(uint16_t *) (buf + 14);
 	if (hdr_size < 60)
 		error_msg_and_fail("sthyi: machine section is too small "
-			           "(got %hu, 60 expected)", hdr_size);
+				   "(got %hu, >=60 expected)", hdr_size);
 
 	cur = buf + offs;
 
@@ -670,9 +670,9 @@ partition_hdr:
 		goto hv_hdr;
 
 	hdr_size = *(uint16_t *) (buf + 18);
-	if (hdr_size < 56)
+	if (hdr_size < 40)
 		error_msg_and_fail("sthyi: partition section is too small "
-			           "(got %hu, 56 expected)", hdr_size);
+				   "(got %hu, >=40 expected)", hdr_size);
 
 	cur = buf + offs;
 
@@ -741,18 +741,18 @@ partition_hdr:
 	print_weight(", infpwbif", cur, 32, pwcap_valid);
 	print_weight(", infpabif", cur, 36, pacap_valid);
 
-	if (print_ebcdic(", infplgnm", cur, 40, 8, false, false)) {
-
-		print_weight(", infplgcp", cur, 48, false);
-		print_weight(", infplgif", cur, 52, false);
-	} else {
-		if (lpar_valid) {
-			printf(", infplgnm=");
-			print_quoted_hex((char *) (cur + 40), 8);
+	if (hdr_size >= 56) {
+		if (print_ebcdic(", infplgnm", cur, 40, 8, false, false)) {
+			print_weight(", infplgcp", cur, 48, false);
+			print_weight(", infplgif", cur, 52, false);
+		} else {
+			if (lpar_valid) {
+				printf(", infplgnm=");
+				print_quoted_hex((char *) (cur + 40), 8);
+			}
+			print_x32(", infplgcp", cur, 48, false);
+			print_x32(", infplgif", cur, 52, false);
 		}
-
-		print_x32(", infplgcp", cur, 48, false);
-		print_x32(", infplgif", cur, 52, false);
 	}
 
 	if (hdr_size >= 64) {
diff -pruN 5.5-3/tests-m32/sched_xetaffinity.c 5.9-0ubuntu2/tests-m32/sched_xetaffinity.c
--- 5.5-3/tests-m32/sched_xetaffinity.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/sched_xetaffinity.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,7 +2,7 @@
  * This file is part of sched_xetaffinity strace test.
  *
  * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,6 +10,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 #include <sched.h>
 
 #if defined __NR_sched_getaffinity && defined __NR_sched_setaffinity \
@@ -41,8 +42,11 @@ setaffinity(unsigned long pid, unsigned
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	unsigned int cpuset_size = 1;
 	const pid_t pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
 
 	while (cpuset_size) {
 		assert(getaffinity(pid, cpuset_size, NULL) == -1);
@@ -50,18 +54,21 @@ main(void)
 			break;
 		if (EINVAL != errno)
 			perror_msg_and_skip("sched_getaffinity");
-		printf("sched_getaffinity(%d, %u, NULL) = %s\n",
-		       pid, cpuset_size, errstr);
+		pidns_print_leader();
+		printf("sched_getaffinity(%d%s, %u, NULL) = %s\n",
+		       pid, pid_str, cpuset_size, errstr);
 		cpuset_size <<= 1;
 	}
 	assert(cpuset_size);
-	printf("sched_getaffinity(%d, %u, NULL) = %s\n",
-	       pid, cpuset_size, errstr);
+	pidns_print_leader();
+	printf("sched_getaffinity(%d%s, %u, NULL) = %s\n",
+	       pid, pid_str, cpuset_size, errstr);
 
 	cpu_set_t *cpuset = tail_alloc(cpuset_size);
 	getaffinity(pid, cpuset_size, cpuset + 1);
-	printf("sched_getaffinity(%d, %u, %p) = %s\n",
-	       pid, cpuset_size, cpuset + 1, errstr);
+	pidns_print_leader();
+	printf("sched_getaffinity(%d%s, %u, %p) = %s\n",
+	       pid, pid_str, cpuset_size, cpuset + 1, errstr);
 
 	int ret_size = getaffinity(pid, cpuset_size, cpuset);
 	if (ret_size < 0)
@@ -69,7 +76,8 @@ main(void)
 				    pid, (unsigned) cpuset_size, cpuset, errstr);
 	assert(ret_size <= (int) cpuset_size);
 
-	printf("sched_getaffinity(%d, %u, [", pid, cpuset_size);
+	pidns_print_leader();
+	printf("sched_getaffinity(%d%s, %u, [", pid, pid_str, cpuset_size);
 	const char *sep;
 	unsigned int i, cpu;
 	for (i = 0, cpu = 0, sep = ""; i < (unsigned) ret_size * 8; ++i) {
@@ -85,8 +93,9 @@ main(void)
 	CPU_SET_S(cpu, cpuset_size, cpuset);
 	if (setaffinity(pid, cpuset_size, cpuset))
 		perror_msg_and_skip("sched_setaffinity");
-	printf("sched_setaffinity(%d, %u, [%u]) = 0\n",
-	       pid, cpuset_size, cpu);
+	pidns_print_leader();
+	printf("sched_setaffinity(%d%s, %u, [%u]) = 0\n",
+	       pid, pid_str, cpuset_size, cpu);
 
 	const unsigned int big_size = cpuset_size < 128 ? 128 : cpuset_size * 2;
 	cpuset = tail_alloc(big_size);
@@ -95,7 +104,8 @@ main(void)
 		perror_msg_and_fail("sched_getaffinity(%d, %u, %p) = %s\n",
 				    pid, big_size, cpuset, errstr);
 	assert(ret_size <= (int) big_size);
-	printf("sched_getaffinity(%d, %u, [", pid, big_size);
+	pidns_print_leader();
+	printf("sched_getaffinity(%d%s, %u, [", pid, pid_str, big_size);
 	for (i = 0, sep = ""; i < (unsigned) ret_size * 8; ++i) {
 		if (CPU_ISSET_S(i, (unsigned) ret_size, cpuset)) {
 			printf("%s%u", sep, i);
@@ -104,6 +114,7 @@ main(void)
 	}
 	printf("]) = %s\n", errstr);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/sched_xetaffinity--pidns-translation.c 5.9-0ubuntu2/tests-m32/sched_xetaffinity--pidns-translation.c
--- 5.5-3/tests-m32/sched_xetaffinity--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/sched_xetaffinity--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "sched_xetaffinity.c"
diff -pruN 5.5-3/tests-m32/sched_xetaffinity--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/sched_xetaffinity--pidns-translation.gen.test
--- 5.5-3/tests-m32/sched_xetaffinity--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/sched_xetaffinity--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (sched_xetaffinity--pidns-translation test_pidns -a28 -e trace=sched_getaffinity,sched_setaffinity); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a28 -e trace=sched_getaffinity,sched_setaffinity
diff -pruN 5.5-3/tests-m32/sched_xetattr.c 5.9-0ubuntu2/tests-m32/sched_xetattr.c
--- 5.5-3/tests-m32/sched_xetattr.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/sched_xetattr.c	2020-08-25 14:29:30.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2017 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -15,6 +15,7 @@
 # include <stdio.h>
 # include <sched.h>
 # include <unistd.h>
+# include "pidns.h"
 # include "sched_attr.h"
 # include "xlat.h"
 # include "xlat/schedulers.h"
@@ -41,6 +42,8 @@ sys_sched_setattr(kernel_ulong_t pid, ke
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	static const kernel_ulong_t bogus_pid =
 		(kernel_ulong_t) 0xdefacedfacefeedULL;
 	static const kernel_ulong_t bogus_size =
@@ -48,20 +51,28 @@ main(void)
 	static const kernel_ulong_t bogus_flags =
 		(kernel_ulong_t) 0xdefaceddeadc0deULL;
 
+	const int pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
+
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct sched_attr, attr);
 	TAIL_ALLOC_OBJECT_CONST_PTR(unsigned int, psize);
 	void *const efault = attr + 1;
 
-	sys_sched_getattr(0, 0, 0, 0);
-	printf("sched_getattr(0, NULL, 0, 0) = %s\n", errstr);
+	sys_sched_getattr(pid, 0, 0, 0);
+	pidns_print_leader();
+	printf("sched_getattr(%d%s, NULL, 0, 0) = %s\n",
+		pid, pid_str, errstr);
 
 	sys_sched_getattr(0, (unsigned long) attr, 0, 0);
+	pidns_print_leader();
 	printf("sched_getattr(0, %p, 0, 0) = %s\n", attr, errstr);
 
 	sys_sched_getattr(bogus_pid, 0, 0, 0);
+	pidns_print_leader();
 	printf("sched_getattr(%d, NULL, 0, 0) = %s\n", (int) bogus_pid, errstr);
 
 	sys_sched_getattr(-1U, (unsigned long) attr, bogus_size, bogus_flags);
+	pidns_print_leader();
 	printf("sched_getattr(-1, %p, %s%u, %u) = %s\n",
 	       attr,
 # if defined __arm64__ || defined __aarch64__
@@ -71,24 +82,52 @@ main(void)
 # endif
 	       (unsigned) bogus_size, (unsigned) bogus_flags, errstr);
 
+	sys_sched_getattr(0, (unsigned long) efault, SCHED_ATTR_MIN_SIZE, 0);
+	pidns_print_leader();
+	printf("sched_getattr(0, %p, %u, 0) = %s\n",
+	       efault, (unsigned) SCHED_ATTR_MIN_SIZE, errstr);
+
+	if (sys_sched_getattr(0, (unsigned long) attr, SCHED_ATTR_MIN_SIZE, 0))
+		perror_msg_and_skip("sched_getattr");
+	pidns_print_leader();
+	printf("sched_getattr(0, {size=%u, sched_policy=", attr->size);
+	printxval(schedulers, attr->sched_policy, NULL);
+	printf(", sched_flags=%s, sched_nice=%d, sched_priority=%u"
+	       ", sched_runtime=%" PRIu64 ", sched_deadline=%" PRIu64
+	       ", sched_period=%" PRIu64 "}, %u, 0) = 0\n",
+	       attr->sched_flags ? "SCHED_FLAG_RESET_ON_FORK" : "0",
+	       attr->sched_nice,
+	       attr->sched_priority,
+	       attr->sched_runtime,
+	       attr->sched_deadline,
+	       attr->sched_period,
+	       (unsigned) SCHED_ATTR_MIN_SIZE);
+
 	sys_sched_getattr(0, (unsigned long) efault, sizeof(*attr), 0);
+	pidns_print_leader();
 	printf("sched_getattr(0, %p, %u, 0) = %s\n",
 	       efault, (unsigned) sizeof(*attr), errstr);
 
 	if (sys_sched_getattr(0, (unsigned long) attr, sizeof(*attr), 0))
 		perror_msg_and_skip("sched_getattr");
+	pidns_print_leader();
 	printf("sched_getattr(0, {size=%u, sched_policy=", attr->size);
 	printxval(schedulers, attr->sched_policy, NULL);
 	printf(", sched_flags=%s, sched_nice=%d, sched_priority=%u"
 	       ", sched_runtime=%" PRIu64 ", sched_deadline=%" PRIu64
-	       ", sched_period=%" PRIu64 "}, %u, 0) = 0\n",
+	       ", sched_period=%" PRIu64,
 	       attr->sched_flags ? "SCHED_FLAG_RESET_ON_FORK" : "0",
 	       attr->sched_nice,
 	       attr->sched_priority,
 	       attr->sched_runtime,
 	       attr->sched_deadline,
-	       attr->sched_period,
-	       (unsigned) sizeof(*attr));
+	       attr->sched_period);
+	if (attr->size >= SCHED_ATTR_SIZE_VER1) {
+		printf(", sched_util_min=%u, sched_util_max=%u",
+		       attr->sched_util_min,
+		       attr->sched_util_max);
+	}
+	printf("}, %u, 0) = 0\n", (unsigned) sizeof(*attr));
 
 # if defined __arm64__ || defined __aarch64__
 	long rc =
@@ -97,66 +136,91 @@ main(void)
 			  F8ILL_KULONG_MASK | sizeof(*attr), F8ILL_KULONG_MASK);
 # if defined __arm64__ || defined __aarch64__
 	if (rc) {
+		pidns_print_leader();
 		printf("sched_getattr(0, %p, 0xffffffff<<32|%u, 0) = %s\n",
 		       attr, (unsigned) sizeof(*attr), errstr);
 	} else
 # endif
 	{
+		pidns_print_leader();
 		printf("sched_getattr(0, {size=%u, sched_policy=", attr->size);
 		printxval(schedulers, attr->sched_policy, NULL);
 		printf(", sched_flags=%s, sched_nice=%d, sched_priority=%u"
 		       ", sched_runtime=%" PRIu64 ", sched_deadline=%" PRIu64
-		       ", sched_period=%" PRIu64 "}, %u, 0) = 0\n",
+		       ", sched_period=%" PRIu64,
 		       attr->sched_flags ? "SCHED_FLAG_RESET_ON_FORK" : "0",
 		       attr->sched_nice,
 		       attr->sched_priority,
 		       attr->sched_runtime,
 		       attr->sched_deadline,
-		       attr->sched_period,
-		       (unsigned) sizeof(*attr));
+		       attr->sched_period);
+		if (attr->size >= SCHED_ATTR_SIZE_VER1) {
+			printf(", sched_util_min=%u, sched_util_max=%u",
+			       attr->sched_util_min,
+			       attr->sched_util_max);
+		}
+		printf("}, %u, 0) = 0\n", (unsigned) sizeof(*attr));
 	}
 
 	sys_sched_setattr(bogus_pid, 0, 0);
+	pidns_print_leader();
 	printf("sched_setattr(%d, NULL, 0) = %s\n", (int) bogus_pid, errstr);
 
 	attr->sched_flags |= 1;
 
-	if (sys_sched_setattr(0, (unsigned long) attr, 0))
+	if (sys_sched_setattr(pid, (unsigned long) attr, 0))
 		perror_msg_and_skip("sched_setattr");
-	printf("sched_setattr(0, {size=%u, sched_policy=", attr->size);
+	pidns_print_leader();
+	printf("sched_setattr(%d%s, {size=%u, sched_policy=",
+		pid, pid_str, attr->size);
 	printxval(schedulers, attr->sched_policy, NULL);
 	printf(", sched_flags=%s, sched_nice=%d, sched_priority=%u"
 	       ", sched_runtime=%" PRIu64 ", sched_deadline=%" PRIu64
-	       ", sched_period=%" PRIu64 "}, 0) = 0\n",
+	       ", sched_period=%" PRIu64,
 	       "SCHED_FLAG_RESET_ON_FORK",
 	       attr->sched_nice,
 	       attr->sched_priority,
 	       attr->sched_runtime,
 	       attr->sched_deadline,
 	       attr->sched_period);
+	if (attr->size >= SCHED_ATTR_SIZE_VER1) {
+		printf(", sched_util_min=%u, sched_util_max=%u",
+		       attr->sched_util_min,
+		       attr->sched_util_max);
+	}
+	printf("}, 0) = 0\n");
 
 	sys_sched_setattr(F8ILL_KULONG_MASK, (unsigned long) attr,
 			  F8ILL_KULONG_MASK);
+	pidns_print_leader();
 	printf("sched_setattr(0, {size=%u, sched_policy=", attr->size);
 	printxval(schedulers, attr->sched_policy, NULL);
 	printf(", sched_flags=%s, sched_nice=%d, sched_priority=%u"
 	       ", sched_runtime=%" PRIu64 ", sched_deadline=%" PRIu64
-	       ", sched_period=%" PRIu64 "}, 0) = 0\n",
+	       ", sched_period=%" PRIu64,
 	       "SCHED_FLAG_RESET_ON_FORK",
 	       attr->sched_nice,
 	       attr->sched_priority,
 	       attr->sched_runtime,
 	       attr->sched_deadline,
 	       attr->sched_period);
+	if (attr->size >= SCHED_ATTR_SIZE_VER1) {
+		printf(", sched_util_min=%u, sched_util_max=%u",
+		       attr->sched_util_min,
+		       attr->sched_util_max);
+	}
+	printf("}, 0) = 0\n");
 
 	*psize = attr->size;
 
 	sys_sched_setattr(0, (unsigned long) psize, 0);
+	pidns_print_leader();
 	printf("sched_setattr(0, %p, 0) = %s\n", psize, errstr);
 
 	attr->size = 0;
 
 	sys_sched_setattr(0, (unsigned long) attr, 0);
+	pidns_print_leader();
 	printf("sched_setattr(0, {size=%u, sched_policy=", attr->size);
 	printxval(schedulers, attr->sched_policy, NULL);
 	printf(", sched_flags=%s, sched_nice=%d, sched_priority=%u"
@@ -172,18 +236,20 @@ main(void)
 	attr->size = 1;
 
 	sys_sched_setattr(0, (unsigned long) attr, 0);
+	pidns_print_leader();
 	printf("sched_setattr(0, {size=%u} => {size=%u}, 0) = %s\n",
 	       1, attr->size, errstr);
 
 	attr->size = SCHED_ATTR_MIN_SIZE - 1;
 
 	sys_sched_setattr(0, (unsigned long) attr, 0);
+	pidns_print_leader();
 	printf("sched_setattr(0, {size=%u} => {size=%u}, 0) = %s\n",
 	       SCHED_ATTR_MIN_SIZE - 1, attr->size, errstr);
 
 	attr->size = 0x90807060;
 	attr->sched_policy = 0xca7faced;
-	attr->sched_flags = 0xbadc0ded1057da78ULL;
+	attr->sched_flags = 0xbadc0ded1057da80ULL;
 	attr->sched_nice = 0xafbfcfdf;
 	attr->sched_priority = 0xb8c8d8e8;
 	attr->sched_runtime = 0xbadcaffedeadf157ULL;
@@ -191,11 +257,12 @@ main(void)
 	attr->sched_period = 0xded1ca7edda7aca7ULL;
 
 	sys_sched_setattr(bogus_pid, (unsigned long) attr, bogus_flags);
+	pidns_print_leader();
 	printf("sched_setattr(%d, {size=%u, sched_policy=%#x /* SCHED_??? */, "
 	       "sched_flags=%#" PRIx64 " /* SCHED_FLAG_??? */, "
 	       "sched_nice=%d, sched_priority=%u, sched_runtime=%" PRIu64 ", "
-	       "sched_deadline=%" PRIu64 ", sched_period=%" PRIu64 ", ...}, %u)"
-	       " = %s\n",
+	       "sched_deadline=%" PRIu64 ", sched_period=%" PRIu64 ", "
+	       "sched_util_min=%u, sched_util_max=%u, ...}, %u) = %s\n",
 	       (int) bogus_pid,
 	       attr->size,
 	       attr->sched_policy,
@@ -205,6 +272,8 @@ main(void)
 	       attr->sched_runtime,
 	       attr->sched_deadline,
 	       attr->sched_period,
+	       attr->sched_util_min,
+	       attr->sched_util_max,
 	       (unsigned) bogus_flags, errstr);
 
 	if (F8ILL_KULONG_SUPPORTED) {
@@ -223,7 +292,7 @@ main(void)
 
 	attr->size = 0x90807060;
 	attr->sched_policy = 0xca7faced;
-	attr->sched_flags = 0xfULL;
+	attr->sched_flags = 0x87ULL;
 	attr->sched_nice = 0xafbfcfdf;
 	attr->sched_priority = 0xb8c8d8e8;
 	attr->sched_runtime = 0xbadcaffedeadf157ULL;
@@ -231,35 +300,143 @@ main(void)
 	attr->sched_period = 0xded1ca7edda7aca7ULL;
 
 	sys_sched_setattr(bogus_pid, (unsigned long) attr, bogus_flags);
+	pidns_print_leader();
 	printf("sched_setattr(%d, {size=%u, sched_policy=%#x /* SCHED_??? */, "
 	       "sched_flags=SCHED_FLAG_RESET_ON_FORK|SCHED_FLAG_RECLAIM|"
-	       "SCHED_FLAG_DL_OVERRUN|0x8, "
+	       "SCHED_FLAG_DL_OVERRUN|0x80, "
+	       "sched_nice=%d, sched_priority=%u, sched_runtime=%" PRIu64 ", "
+	       "sched_deadline=%" PRIu64 ", sched_period=%" PRIu64 ", "
+	       "sched_util_min=%u, sched_util_max=%u, ...}, %u) = %s\n",
+	       (int) bogus_pid,
+	       attr->size,
+	       attr->sched_policy,
+	       attr->sched_nice,
+	       attr->sched_priority,
+	       attr->sched_runtime,
+	       attr->sched_deadline,
+	       attr->sched_period,
+	       attr->sched_util_min,
+	       attr->sched_util_max,
+	       (unsigned) bogus_flags, errstr);
+
+	if (F8ILL_KULONG_SUPPORTED) {
+		const kernel_ulong_t ill = f8ill_ptr_to_kulong(attr);
+
+		sys_sched_getattr(0, ill, sizeof(*attr), 0);
+		pidns_print_leader();
+		printf("sched_getattr(0, %#llx, %u, 0) = %s\n",
+		       (unsigned long long) ill, (unsigned) sizeof(*attr),
+		       errstr);
+
+		sys_sched_setattr(0, ill, 0);
+		pidns_print_leader();
+		printf("sched_setattr(0, %#llx, 0) = %s\n",
+		       (unsigned long long) ill, errstr);
+	}
+
+	attr->size = SCHED_ATTR_MIN_SIZE;
+	attr->sched_policy = 0xdefaced;
+	attr->sched_flags = 0x8fULL;
+
+	sys_sched_setattr(bogus_pid, (unsigned long) attr, bogus_flags);
+	pidns_print_leader();
+	printf("sched_setattr(%d, {size=%u, "
+	       "sched_flags=SCHED_FLAG_RESET_ON_FORK|SCHED_FLAG_RECLAIM|"
+	       "SCHED_FLAG_DL_OVERRUN|SCHED_FLAG_KEEP_POLICY|0x80, "
 	       "sched_nice=%d, sched_priority=%u, sched_runtime=%" PRIu64 ", "
-	       "sched_deadline=%" PRIu64 ", sched_period=%" PRIu64 ", ...}, %u)"
+	       "sched_deadline=%" PRIu64 ", sched_period=%" PRIu64 "}, %u)"
 	       " = %s\n",
 	       (int) bogus_pid,
 	       attr->size,
+	       attr->sched_nice,
+	       attr->sched_priority,
+	       attr->sched_runtime,
+	       attr->sched_deadline,
+	       attr->sched_period,
+	       (unsigned) bogus_flags, errstr);
+
+	if (F8ILL_KULONG_SUPPORTED) {
+		const kernel_ulong_t ill = f8ill_ptr_to_kulong(attr);
+
+		sys_sched_getattr(0, ill, sizeof(*attr), 0);
+		pidns_print_leader();
+		printf("sched_getattr(0, %#llx, %u, 0) = %s\n",
+		       (unsigned long long) ill, (unsigned) sizeof(*attr),
+		       errstr);
+
+		sys_sched_setattr(0, ill, 0);
+		pidns_print_leader();
+		printf("sched_setattr(0, %#llx, 0) = %s\n",
+		       (unsigned long long) ill, errstr);
+	}
+
+	attr->size = SCHED_ATTR_SIZE_VER1;
+	attr->sched_flags = 0xe7ULL;
+
+	sys_sched_setattr(bogus_pid, (unsigned long) attr, bogus_flags);
+	pidns_print_leader();
+	printf("sched_setattr(%d, {size=%u, sched_policy=%#x /* SCHED_??? */, "
+	       "sched_flags=SCHED_FLAG_RESET_ON_FORK|SCHED_FLAG_RECLAIM|"
+	       "SCHED_FLAG_DL_OVERRUN|SCHED_FLAG_UTIL_CLAMP_MIN"
+	       "|SCHED_FLAG_UTIL_CLAMP_MAX|0x80, "
+	       "sched_nice=%d, sched_priority=%u, sched_runtime=%" PRIu64 ", "
+	       "sched_deadline=%" PRIu64 ", sched_period=%" PRIu64 ", "
+	       "sched_util_min=%u, sched_util_max=%u}, %u) = %s\n",
+	       (int) bogus_pid,
+	       attr->size,
 	       attr->sched_policy,
 	       attr->sched_nice,
 	       attr->sched_priority,
 	       attr->sched_runtime,
 	       attr->sched_deadline,
 	       attr->sched_period,
+	       attr->sched_util_min,
+	       attr->sched_util_max,
+	       (unsigned) bogus_flags, errstr);
+
+	if (F8ILL_KULONG_SUPPORTED) {
+		const kernel_ulong_t ill = f8ill_ptr_to_kulong(attr);
+
+		sys_sched_getattr(0, ill, sizeof(*attr), 0);
+		pidns_print_leader();
+		printf("sched_getattr(0, %#llx, %u, 0) = %s\n",
+		       (unsigned long long) ill, (unsigned) sizeof(*attr),
+		       errstr);
+
+		sys_sched_setattr(0, ill, 0);
+		pidns_print_leader();
+		printf("sched_setattr(0, %#llx, 0) = %s\n",
+		       (unsigned long long) ill, errstr);
+	}
+
+	attr->sched_flags = 0xcaffee90LL;
+
+	sys_sched_setattr(bogus_pid, (unsigned long) attr, bogus_flags);
+	pidns_print_leader();
+	printf("sched_setattr(%d, {size=%u, sched_flags=SCHED_FLAG_KEEP_PARAMS"
+	       "|0xcaffee80, sched_util_min=%u, sched_util_max=%u}, %u) = %s\n",
+	       (int) bogus_pid,
+	       attr->size,
+	       attr->sched_util_min,
+	       attr->sched_util_max,
 	       (unsigned) bogus_flags, errstr);
 
 	if (F8ILL_KULONG_SUPPORTED) {
 		const kernel_ulong_t ill = f8ill_ptr_to_kulong(attr);
 
 		sys_sched_getattr(0, ill, sizeof(*attr), 0);
+		pidns_print_leader();
 		printf("sched_getattr(0, %#llx, %u, 0) = %s\n",
 		       (unsigned long long) ill, (unsigned) sizeof(*attr),
 		       errstr);
 
 		sys_sched_setattr(0, ill, 0);
+		pidns_print_leader();
 		printf("sched_setattr(0, %#llx, 0) = %s\n",
 		       (unsigned long long) ill, errstr);
 	}
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/sched_xetattr--pidns-translation.c 5.9-0ubuntu2/tests-m32/sched_xetattr--pidns-translation.c
--- 5.5-3/tests-m32/sched_xetattr--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/sched_xetattr--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "sched_xetattr.c"
diff -pruN 5.5-3/tests-m32/sched_xetattr--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/sched_xetattr--pidns-translation.gen.test
--- 5.5-3/tests-m32/sched_xetattr--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/sched_xetattr--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (sched_xetattr--pidns-translation test_pidns -a29 -e trace=sched_getattr,sched_setattr); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a29 -e trace=sched_getattr,sched_setattr
diff -pruN 5.5-3/tests-m32/sched_xetparam.c 5.9-0ubuntu2/tests-m32/sched_xetparam.c
--- 5.5-3/tests-m32/sched_xetparam.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/sched_xetparam.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -7,6 +7,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #if defined __NR_sched_getparam && defined __NR_sched_setparam
 
@@ -17,18 +18,27 @@
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	struct sched_param *const param =
 		tail_alloc(sizeof(struct sched_param));
 
-	long rc = syscall(__NR_sched_getparam, 0, param);
-	printf("sched_getparam(0, [%d]) = %ld\n",
-	       param->sched_priority, rc);
+	const int pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
+
+	long rc = syscall(__NR_sched_getparam, pid, param);
+	pidns_print_leader();
+	printf("sched_getparam(%d%s, [%d]) = %ld\n",
+	       pid, pid_str, param->sched_priority, rc);
 
 	param->sched_priority = -1;
-	rc = syscall(__NR_sched_setparam, 0, param);
-	printf("sched_setparam(0, [%d]) = %ld %s (%m)\n",
+	rc = syscall(__NR_sched_setparam, pid, param);
+	pidns_print_leader();
+	printf("sched_setparam(%d%s, [%d]) = %ld %s (%m)\n",
+	       pid, pid_str,
 	       param->sched_priority, rc, errno2name());
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/sched_xetparam--pidns-translation.c 5.9-0ubuntu2/tests-m32/sched_xetparam--pidns-translation.c
--- 5.5-3/tests-m32/sched_xetparam--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/sched_xetparam--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "sched_xetparam.c"
diff -pruN 5.5-3/tests-m32/sched_xetparam--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/sched_xetparam--pidns-translation.gen.test
--- 5.5-3/tests-m32/sched_xetparam--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/sched_xetparam--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (sched_xetparam--pidns-translation test_pidns -a23 -e trace=sched_getparam,sched_setparam); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a23 -e trace=sched_getparam,sched_setparam
diff -pruN 5.5-3/tests-m32/sched_xetscheduler.c 5.9-0ubuntu2/tests-m32/sched_xetscheduler.c
--- 5.5-3/tests-m32/sched_xetscheduler.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/sched_xetscheduler.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -7,6 +7,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #if defined __NR_sched_getscheduler && defined __NR_sched_setscheduler
 
@@ -17,8 +18,13 @@
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct sched_param, param);
-	long rc = syscall(__NR_sched_getscheduler, 0);
+	const int pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
+
+	long rc = syscall(__NR_sched_getscheduler, pid);
 	const char *scheduler;
 	switch (rc) {
 		case SCHED_FIFO:
@@ -50,33 +56,43 @@ main(void)
 		default:
 			scheduler = "SCHED_OTHER";
 	}
-	printf("sched_getscheduler(0) = %ld (%s)\n",
-	       rc, scheduler);
+	pidns_print_leader();
+	printf("sched_getscheduler(%d%s) = %ld (%s)\n",
+	       pid, pid_str, rc, scheduler);
 
 	rc = syscall(__NR_sched_getscheduler, -1);
+	pidns_print_leader();
 	printf("sched_getscheduler(-1) = %s\n", sprintrc(rc));
 
 	param->sched_priority = -1;
 
-	rc = syscall(__NR_sched_setscheduler, 0, SCHED_FIFO, NULL);
-	printf("sched_setscheduler(0, SCHED_FIFO, NULL) = %s\n", sprintrc(rc));
-
-	rc = syscall(__NR_sched_setscheduler, 0, SCHED_FIFO, param + 1);
-	printf("sched_setscheduler(0, SCHED_FIFO, %p) = %s\n", param + 1,
-	       sprintrc(rc));
-
-	rc = syscall(__NR_sched_setscheduler, 0, 0xfaceda7a, param);
-	printf("sched_setscheduler(0, %#x /* SCHED_??? */, [%d]) = %s\n",
-	       0xfaceda7a, param->sched_priority, sprintrc(rc));
+	rc = syscall(__NR_sched_setscheduler, pid, SCHED_FIFO, NULL);
+	pidns_print_leader();
+	printf("sched_setscheduler(%d%s, SCHED_FIFO, NULL) = %s\n",
+	       pid, pid_str, sprintrc(rc));
+
+	rc = syscall(__NR_sched_setscheduler, pid, SCHED_FIFO, param + 1);
+	pidns_print_leader();
+	printf("sched_setscheduler(%d%s, SCHED_FIFO, %p) = %s\n",
+	       pid, pid_str, param + 1, sprintrc(rc));
+
+	rc = syscall(__NR_sched_setscheduler, pid, 0xfaceda7a, param);
+	pidns_print_leader();
+	printf("sched_setscheduler(%d%s, %#x /* SCHED_??? */, [%d]) = %s\n",
+	       pid, pid_str, 0xfaceda7a,
+	       param->sched_priority, sprintrc(rc));
 
 	rc = syscall(__NR_sched_setscheduler, -1, SCHED_FIFO, param);
+	pidns_print_leader();
 	printf("sched_setscheduler(-1, SCHED_FIFO, [%d]) = %s\n",
 	       param->sched_priority, sprintrc(rc));
 
-	rc = syscall(__NR_sched_setscheduler, 0, SCHED_FIFO, param);
-	printf("sched_setscheduler(0, SCHED_FIFO, [%d]) = %s\n",
-	       param->sched_priority, sprintrc(rc));
+	rc = syscall(__NR_sched_setscheduler, pid, SCHED_FIFO, param);
+	pidns_print_leader();
+	printf("sched_setscheduler(%d%s, SCHED_FIFO, [%d]) = %s\n",
+	       pid, pid_str, param->sched_priority, sprintrc(rc));
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/sched_xetscheduler--pidns-translation.c 5.9-0ubuntu2/tests-m32/sched_xetscheduler--pidns-translation.c
--- 5.5-3/tests-m32/sched_xetscheduler--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/sched_xetscheduler--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "sched_xetscheduler.c"
diff -pruN 5.5-3/tests-m32/sched_xetscheduler--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/sched_xetscheduler--pidns-translation.gen.test
--- 5.5-3/tests-m32/sched_xetscheduler--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/sched_xetscheduler--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (sched_xetscheduler--pidns-translation test_pidns -a22 -e trace=sched_getscheduler,sched_setscheduler); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a22 -e trace=sched_getscheduler,sched_setscheduler
diff -pruN 5.5-3/tests-m32/seccomp-filter.c 5.9-0ubuntu2/tests-m32/seccomp-filter.c
--- 5.5-3/tests-m32/seccomp-filter.c	2019-07-16 17:46:47.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/seccomp-filter.c	2020-06-01 14:15:16.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of seccomp SECCOMP_SET_MODE_FILTER.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -38,12 +38,13 @@ main(void)
 	       " = %ld %s (%m)\n",
 	       "SECCOMP_FILTER_FLAG_TSYNC|SECCOMP_FILTER_FLAG_LOG|"
 	       "SECCOMP_FILTER_FLAG_SPEC_ALLOW|"
-	       "SECCOMP_FILTER_FLAG_NEW_LISTENER|0xfffffff0",
+	       "SECCOMP_FILTER_FLAG_NEW_LISTENER|"
+	       "SECCOMP_FILTER_FLAG_TSYNC_ESRCH|0xffffffe0",
 	       prog->len, prog->filter, rc, errno2name());
 
-	rc = syscall(__NR_seccomp, SECCOMP_SET_MODE_FILTER, -16L, efault);
+	rc = syscall(__NR_seccomp, SECCOMP_SET_MODE_FILTER, -32L, efault);
 	printf("seccomp(SECCOMP_SET_MODE_FILTER, %s, %p) = %ld %s (%m)\n",
-	       "0xfffffff0 /* SECCOMP_FILTER_FLAG_??? */",
+	       "0xffffffe0 /* SECCOMP_FILTER_FLAG_??? */",
 	       efault, rc, errno2name());
 
 	puts("+++ exited with 0 +++");
diff -pruN 5.5-3/tests-m32/seccomp-filter-v.c 5.9-0ubuntu2/tests-m32/seccomp-filter-v.c
--- 5.5-3/tests-m32/seccomp-filter-v.c	2019-09-15 15:47:01.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/seccomp-filter-v.c	2020-04-15 13:39:57.000000000 +0000
@@ -2,7 +2,7 @@
  * Check verbose decoding of seccomp SECCOMP_SET_MODE_FILTER.
  *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -13,16 +13,13 @@
 #include <errno.h>
 #include <stddef.h>
 #include <stdio.h>
-#include "scno.h"
 #include <unistd.h>
-
-#ifdef HAVE_PRCTL
-# include <sys/prctl.h>
-#endif
+#include <sys/prctl.h>
 #ifdef HAVE_LINUX_SECCOMP_H
 # include <linux/seccomp.h>
 #endif
 #include <linux/filter.h>
+#include "scno.h"
 
 #if defined __NR_seccomp \
  && defined PR_SET_NO_NEW_PRIVS \
@@ -118,7 +115,8 @@ main(void)
 	tprintf("seccomp(SECCOMP_SET_MODE_FILTER, %s, {len=%u, filter=[",
 		"SECCOMP_FILTER_FLAG_TSYNC|SECCOMP_FILTER_FLAG_LOG|"
 		"SECCOMP_FILTER_FLAG_SPEC_ALLOW|"
-		"SECCOMP_FILTER_FLAG_NEW_LISTENER|0xfffffff0",
+		"SECCOMP_FILTER_FLAG_NEW_LISTENER|"
+		"SECCOMP_FILTER_FLAG_TSYNC_ESRCH|0xffffffe0",
 		prog->len);
 	for (i = 0; i < BPF_MAXINSNS; ++i) {
 		if (i)
diff -pruN 5.5-3/tests-m32/semtimedop.c 5.9-0ubuntu2/tests-m32/semtimedop.c
--- 5.5-3/tests-m32/semtimedop.c	2019-11-18 13:31:57.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/semtimedop.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,21 +1,25 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-#include <sys/ipc.h>
-#include <sys/sem.h>
-#include <stdint.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-
-#define XLAT_MACROS_ONLY
-#include "xlat/semop_flags.h"
-#undef XLAT_MACROS_ONLY
+#include "scno.h"
+
+#if defined __NR_semtimedop || defined __NR_socketcall
+
+# include <sys/ipc.h>
+# include <sys/sem.h>
+# include <stdint.h>
+# include <stdio.h>
+# include <stdlib.h>
+# include <unistd.h>
+
+# define XLAT_MACROS_ONLY
+#  include "xlat/semop_flags.h"
+# undef XLAT_MACROS_ONLY
 
 union semun {
 	int val;
@@ -143,3 +147,9 @@ main(void)
 	puts("+++ exited with 0 +++");
 	return 0;
 }
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_semtimedop || __NR_socketcall")
+
+#endif
diff -pruN 5.5-3/tests-m32/sendfile64.c 5.9-0ubuntu2/tests-m32/sendfile64.c
--- 5.5-3/tests-m32/sendfile64.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/sendfile64.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -50,14 +50,9 @@ main(void)
 	const unsigned int blen = file_size / 3;
 	const unsigned int alen = file_size - blen;
 
-	static const char fname[] = "sendfile64-tmpfile";
-	int reg_in = open(fname, O_RDWR | O_CREAT | O_TRUNC, 0600);
-	if (reg_in < 0)
-		perror_msg_and_fail("open: %s", fname);
-	if (unlink(fname))
-		perror_msg_and_fail("unlink: %s", fname);
+	int reg_in = create_tmpfile(O_RDWR);
 	if (ftruncate(reg_in, file_size))
-		perror_msg_and_fail("ftruncate: %s", fname);
+		perror_msg_and_fail("ftruncate(%d, %u)", reg_in, file_size);
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(uint64_t, p_off);
 	void *p = p_off + 1;
diff -pruN 5.5-3/tests-m32/sendfile.c 5.9-0ubuntu2/tests-m32/sendfile.c
--- 5.5-3/tests-m32/sendfile.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/sendfile.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -50,14 +50,9 @@ main(void)
 	const unsigned int blen = file_size / 3;
 	const unsigned int alen = file_size - blen;
 
-	static const char fname[] = "sendfile-tmpfile";
-	int reg_in = open(fname, O_RDWR | O_CREAT | O_TRUNC, 0600);
-	if (reg_in < 0)
-		perror_msg_and_fail("open: %s", fname);
-	if (unlink(fname))
-		perror_msg_and_fail("unlink: %s", fname);
+	int reg_in = create_tmpfile(O_RDWR);
 	if (ftruncate(reg_in, file_size))
-		perror_msg_and_fail("ftruncate: %s", fname);
+		perror_msg_and_fail("ftruncate(%d, %u)", reg_in, file_size);
 
 	TAIL_ALLOC_OBJECT_VAR_PTR(uint32_t, p_off);
 	void *p = p_off + 1;
diff -pruN 5.5-3/tests-m32/setpgrp-exec.c 5.9-0ubuntu2/tests-m32/setpgrp-exec.c
--- 5.5-3/tests-m32/setpgrp-exec.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/setpgrp-exec.c	2020-04-02 11:10:14.000000000 +0000
@@ -0,0 +1,22 @@
+/*
+ * Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include <unistd.h>
+
+int main(int argc, char **argv)
+{
+	if (argc < 2)
+		error_msg_and_fail("argc < 2");
+
+	if (setpgid(0, 0))
+		perror_msg_and_fail("setpgid");
+
+	(void) execvp(argv[1], argv + 1);
+
+	perror_msg_and_fail("execvp: %s", argv[1]);
+}
diff -pruN 5.5-3/tests-m32/set_ptracer_any.c 5.9-0ubuntu2/tests-m32/set_ptracer_any.c
--- 5.5-3/tests-m32/set_ptracer_any.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/set_ptracer_any.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2013-2015 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2013-2018 The strace developers.
+ * Copyright (c) 2013-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -9,25 +9,21 @@
 #include "tests.h"
 #include <stdio.h>
 #include <unistd.h>
-#ifdef HAVE_PRCTL
-# include <sys/prctl.h>
-#endif
+#include <sys/prctl.h>
 
 int main(int argc, char **argv)
 {
 	if (argc < 2)
 		return 99;
-#ifdef HAVE_PRCTL
 	/* Turn off restrictions on tracing if applicable.  If the command
 	 * aren't available on this system, that's OK too.  */
-# ifndef PR_SET_PTRACER
-#  define PR_SET_PTRACER 0x59616d61
-# endif
-# ifndef PR_SET_PTRACER_ANY
-#  define PR_SET_PTRACER_ANY -1UL
-# endif
-	(void) prctl(PR_SET_PTRACER, PR_SET_PTRACER_ANY, 0, 0, 0);
+#ifndef PR_SET_PTRACER
+# define PR_SET_PTRACER 0x59616d61
 #endif
+#ifndef PR_SET_PTRACER_ANY
+# define PR_SET_PTRACER_ANY -1UL
+#endif
+	(void) prctl(PR_SET_PTRACER, PR_SET_PTRACER_ANY, 0, 0, 0);
 	if (write(1, "\n", 1) != 1) {
 		perror("write");
 		return 99;
diff -pruN 5.5-3/tests-m32/sigblock.test 5.9-0ubuntu2/tests-m32/sigblock.test
--- 5.5-3/tests-m32/sigblock.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/sigblock.test	2020-04-03 22:58:26.000000000 +0000
@@ -4,7 +4,7 @@
 # Starting with commit v4.17-5-gf83b49b strace is expected
 # to forward the signal mask to tracees unchanged.
 #
-# Copyright (c) 2017-2018 The strace developers.
+# Copyright (c) 2017-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -20,7 +20,7 @@ for sig in $(../list_sigaction_signum);
 		check_cmd="../check_sigblock $block $sig"
 		run_prog $set_cmd $check_cmd
 		STRACE="$set_cmd $saved_STRACE"
-		for i in '' -I1 -I2 -I3 -I4; do
+		for i in '' -I1 -Iwaiting --interruptible=3 --interruptible=never_tstp; do
 			run_strace $i -enone $check_cmd
 		done
 	done
diff -pruN 5.5-3/tests-m32/sigign.test 5.9-0ubuntu2/tests-m32/sigign.test
--- 5.5-3/tests-m32/sigign.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/sigign.test	2020-04-03 22:58:26.000000000 +0000
@@ -4,7 +4,7 @@
 # Starting with commit v4.17-8-ge97a66f strace is expected
 # to forward the signal disposition to tracees unchanged.
 #
-# Copyright (c) 2017-2018 The strace developers.
+# Copyright (c) 2017-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -20,7 +20,7 @@ for sig in $(../list_sigaction_signum);
 		check_cmd="../check_sigign $ign $sig"
 		run_prog $set_cmd $check_cmd
 		STRACE="$set_cmd $saved_STRACE"
-		for i in '' -I1 -I2 -I3 -I4; do
+		for i in '' --interruptible=always --interruptible=2 -Inever -I4; do
 			run_strace $i -enone $check_cmd
 		done
 	done
diff -pruN 5.5-3/tests-m32/siginfo.c 5.9-0ubuntu2/tests-m32/siginfo.c
--- 5.5-3/tests-m32/siginfo.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/siginfo.c	2020-08-03 08:00:00.000000000 +0000
@@ -2,6 +2,7 @@
  * Check SIGCHLD siginfo_t decoding.
  *
  * Copyright (c) 2015-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -63,7 +64,7 @@ main(void)
 
 	sigsuspend(&unblock_mask);
 	tprintf("--- SIGCHLD {si_signo=SIGCHLD, si_code=CLD_EXITED"
-		", si_pid=%d, si_uid=%u, si_status=%d"
+		", si_pid=%d, si_uid=%d, si_status=%d"
 		", si_utime=%llu, si_stime=%llu} ---\n",
 		sinfo.si_pid, sinfo.si_uid, sinfo.si_status,
 		zero_extend_signed_to_ull(sinfo.si_utime),
@@ -94,7 +95,7 @@ main(void)
 
 	sigsuspend(&unblock_mask);
 	tprintf("--- SIGCHLD {si_signo=SIGCHLD, si_code=CLD_KILLED"
-		", si_pid=%d, si_uid=%u, si_status=SIGUSR1"
+		", si_pid=%d, si_uid=%d, si_status=SIGUSR1"
 		", si_utime=%llu, si_stime=%llu} ---\n",
 		sinfo.si_pid, sinfo.si_uid,
 		zero_extend_signed_to_ull(sinfo.si_utime),
@@ -121,7 +122,7 @@ main(void)
 
 	sigsuspend(&unblock_mask);
 	tprintf("--- SIGCHLD {si_signo=SIGCHLD, si_code=CLD_STOPPED"
-		", si_pid=%d, si_uid=%u, si_status=SIGSTOP"
+		", si_pid=%d, si_uid=%d, si_status=SIGSTOP"
 		", si_utime=%llu, si_stime=%llu} ---\n",
 		sinfo.si_pid, sinfo.si_uid,
 		zero_extend_signed_to_ull(sinfo.si_utime),
@@ -131,7 +132,7 @@ main(void)
 
 	sigsuspend(&unblock_mask);
 	tprintf("--- SIGCHLD {si_signo=SIGCHLD, si_code=CLD_CONTINUED"
-		", si_pid=%d, si_uid=%u, si_status=SIGCONT"
+		", si_pid=%d, si_uid=%d, si_status=SIGCONT"
 		", si_utime=%llu, si_stime=%llu} ---\n",
 		sinfo.si_pid, sinfo.si_uid,
 		zero_extend_signed_to_ull(sinfo.si_utime),
@@ -142,7 +143,7 @@ main(void)
 
 	sigsuspend(&unblock_mask);
 	tprintf("--- SIGCHLD {si_signo=SIGCHLD, si_code=CLD_EXITED"
-		", si_pid=%d, si_uid=%u, si_status=0"
+		", si_pid=%d, si_uid=%d, si_status=0"
 		", si_utime=%llu, si_stime=%llu} ---\n",
 		sinfo.si_pid, sinfo.si_uid,
 		zero_extend_signed_to_ull(sinfo.si_utime),
diff -pruN 5.5-3/tests-m32/signal_receive.c 5.9-0ubuntu2/tests-m32/signal_receive.c
--- 5.5-3/tests-m32/signal_receive.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/signal_receive.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,13 +1,14 @@
 /*
  * Check decoding of signal delivery.
  *
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include "pidns.h"
 #include <signal.h>
 #include <stdio.h>
 #include <unistd.h>
@@ -26,10 +27,13 @@ handler(int sig, siginfo_t *info, void *
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	static const char prefix[] = "KERNEL BUG";
 	int printed = 0;
 
 	const int pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
 	const int uid = geteuid();
 
 	for (int sig = 1; sig <= 31; ++sig) {
@@ -73,10 +77,13 @@ main(void)
 		const int e_pid = s_pid;
 		const int e_uid = s_uid;
 #endif
-		printf("kill(%d, %s) = 0\n", pid, signal2name(sig));
-		printf("--- %s {si_signo=%s, si_code=SI_USER, si_pid=%d"
+		pidns_print_leader();
+		printf("kill(%d%s, %s) = 0\n", pid, pid_str, signal2name(sig));
+		pidns_print_leader();
+		printf("--- %s {si_signo=%s, si_code=SI_USER, si_pid=%d%s"
 		       ", si_uid=%d} ---\n",
-		       signal2name(sig), signal2name(e_sig), e_pid, e_uid);
+		       signal2name(sig), signal2name(e_sig),
+		       e_pid, pid_str, e_uid);
 
 		if (s_code || sig != s_sig || pid != s_pid || uid != s_uid) {
 			/*
@@ -91,11 +98,11 @@ main(void)
 			}
 			fprintf(stderr,
 				"%s: expected: si_signo=%d, si_code=%d"
-				", si_pid=%d, si_uid=%d\n"
+				", si_pid=%d%s, si_uid=%d\n"
 				"%s: received: si_signo=%d, si_code=%d"
-				", si_pid=%d, si_uid=%d\n",
-				prefix, sig, SI_USER, pid, uid,
-				prefix, sig, s_code, s_pid, s_uid);
+				", si_pid=%d%s, si_uid=%d\n",
+				prefix, sig, SI_USER, pid, pid_str, uid,
+				prefix, sig, s_code, s_pid, pid_str, s_uid);
 		}
 	}
 
@@ -104,6 +111,7 @@ main(void)
 			"*** PLEASE FIX THE KERNEL ***\n", prefix);
 	}
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/signal_receive--pidns-translation.c 5.9-0ubuntu2/tests-m32/signal_receive--pidns-translation.c
--- 5.5-3/tests-m32/signal_receive--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/signal_receive--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "signal_receive.c"
diff -pruN 5.5-3/tests-m32/signal_receive--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/signal_receive--pidns-translation.gen.test
--- 5.5-3/tests-m32/signal_receive--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/signal_receive--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (signal_receive--pidns-translation test_pidns -a16 -e trace=kill); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a16 -e trace=kill
diff -pruN 5.5-3/tests-m32/sock_filter-v.c 5.9-0ubuntu2/tests-m32/sock_filter-v.c
--- 5.5-3/tests-m32/sock_filter-v.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/sock_filter-v.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of socket filters.
  *
  * Copyright (c) 2017 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2017-2018 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -23,17 +23,6 @@
 
 #define HEX_FMT "%#x"
 
-#if XLAT_RAW
-# define XLAT_FMT HEX_FMT
-# define XLAT_ARGS(a_) (a_)
-#elif XLAT_VERBOSE
-# define XLAT_FMT HEX_FMT " /* %s */"
-# define XLAT_ARGS(a_) (a_), #a_
-#else
-# define XLAT_FMT "%s"
-# define XLAT_ARGS(a_) #a_
-#endif
-
 #define PRINT_STMT(pfx, code_fmt, k_fmt, ...)	\
 	printf("%sBPF_STMT(" code_fmt ", " k_fmt ")", pfx, __VA_ARGS__)
 
diff -pruN 5.5-3/tests-m32/sockopt-timestamp.c 5.9-0ubuntu2/tests-m32/sockopt-timestamp.c
--- 5.5-3/tests-m32/sockopt-timestamp.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/sockopt-timestamp.c	2020-09-23 16:29:35.000000000 +0000
@@ -19,6 +19,9 @@
 # include <linux/time_types.h>
 #endif
 
+#include "kernel_timeval.h"
+#include "kernel_old_timespec.h"
+
 #define XLAT_MACROS_ONLY
 #include "xlat/sock_options.h"
 #undef XLAT_MACROS_ONLY
@@ -28,7 +31,7 @@ print_timestamp_old(const struct cmsghdr
 {
 	const void *cmsg_header = c;
 	const void *cmsg_data = CMSG_DATA(c);
-	struct timeval tv;
+	kernel_old_timeval_t tv;
 	const unsigned int expected_len = sizeof(tv);
 	const unsigned int data_len = c->cmsg_len - (cmsg_data - cmsg_header);
 
@@ -47,7 +50,7 @@ print_timestampns_old(const struct cmsgh
 {
 	const void *cmsg_header = c;
 	const void *cmsg_data = CMSG_DATA(c);
-	struct timespec ts;
+	kernel_old_timespec_t ts;
 	const unsigned int expected_len = sizeof(ts);
 	const unsigned int data_len = c->cmsg_len - (cmsg_data - cmsg_header);
 
diff -pruN 5.5-3/tests-m32/so_error.c 5.9-0ubuntu2/tests-m32/so_error.c
--- 5.5-3/tests-m32/so_error.c	2018-12-17 19:19:23.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/so_error.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,6 +2,7 @@
  * Check decoding of SO_ERROR socket option.
  *
  * Copyright (c) 2018 Masatake YAMATO <yamato@redhat.com>
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -37,7 +38,7 @@ reserve_ephemeral_port(void)
 	for (in_port_t port = 49152; port < 61000; port++) {
 		/* Just bind here. No listen. */
 		addr.sin_port = htons(port);
-		if (bind(sd, &addr, sizeof(addr)) == 0)
+		if (bind(sd, (void *) &addr, sizeof(addr)) == 0)
 			return port;
 	}
 	error_msg_and_skip("no ephemeral port available for test purposes");
@@ -69,7 +70,7 @@ main(void)
 		.sin_addr.s_addr = htonl(INADDR_LOOPBACK),
 		.sin_port = htons(port),
 	};
-	if (connect(fd, &addr, sizeof(addr)) == 0)
+	if (connect(fd, (void *) &addr, sizeof(addr)) == 0)
 		error_msg_and_skip("connect unexpectedly succeeded");
 	if (errno != EINPROGRESS)
 		perror_msg_and_skip("connect failed for unexpected reason");
diff -pruN 5.5-3/tests-m32/so_peercred.c 5.9-0ubuntu2/tests-m32/so_peercred.c
--- 5.5-3/tests-m32/so_peercred.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/so_peercred.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,13 +2,14 @@
  * Check decoding of SO_PEERCRED socket option.
  *
  * Copyright (c) 2017 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2017-2018 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include "pidns.h"
 
 #include <stddef.h>
 #include <stdio.h>
@@ -53,6 +54,8 @@ so_str(void)
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct ucred, peercred);
 	TAIL_ALLOC_OBJECT_CONST_PTR(socklen_t, len);
 
@@ -75,6 +78,8 @@ main(void)
 	struct ucred *const gid_truncated =
 		tail_alloc(sizeof_gid_truncated);
 
+	const char *pid_str = pidns_pid2str(PT_TGID);
+
 	int sv[2];
 	if (socketpair(AF_UNIX, SOCK_STREAM, 0, sv))
                 perror_msg_and_skip("socketpair AF_UNIX SOCK_STREAM");
@@ -82,8 +87,10 @@ main(void)
 	/* classic getsockopt */
 	*len = sizeof(*peercred);
 	get_peercred(sv[0], peercred, len);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s", sv[0], so_str());
 	PRINT_FIELD_D(", {", *peercred, pid);
+	printf("%s", pid_str);
 	PRINT_FIELD_UID(", ", *peercred, uid);
 	PRINT_FIELD_UID(", ", *peercred, gid);
 	printf("}, [%d]) = %s\n", *len, errstr);
@@ -91,14 +98,17 @@ main(void)
 	/* getsockopt with zero optlen */
 	*len = 0;
 	get_peercred(sv[0], peercred, len);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s, %p, [0]) = %s\n",
 	       sv[0], so_str(), peercred, errstr);
 
 	/* getsockopt with optlen larger than necessary - shortened */
 	*len = sizeof(*peercred) + 1;
 	get_peercred(sv[0], peercred, len);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s", sv[0], so_str());
 	PRINT_FIELD_D(", {", *peercred, pid);
+	printf("%s", pid_str);
 	PRINT_FIELD_UID(", ", *peercred, uid);
 	PRINT_FIELD_UID(", ", *peercred, gid);
 	printf("}, [%u->%d]) = %s\n",
@@ -110,6 +120,7 @@ main(void)
 	 */
 	*len = sizeof_pid_truncated;
 	get_peercred(sv[0], pid_truncated, len);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s, {pid=", sv[0], so_str());
 	print_quoted_hex(pid_truncated, *len);
 	printf("}, [%d]) = %s\n", *len, errstr);
@@ -120,8 +131,10 @@ main(void)
 	 */
 	*len = sizeof_pid;
 	get_peercred(sv[0], pid, len);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s", sv[0], so_str());
 	PRINT_FIELD_D(", {", *pid, pid);
+	printf("%s", pid_str);
 	printf("}, [%d]) = %s\n", *len, errstr);
 
 	/*
@@ -136,8 +149,10 @@ main(void)
 	 * to struct ucred.pid field.
 	 */
 	memcpy(uid, uid_truncated, sizeof_uid_truncated);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s", sv[0], so_str());
 	PRINT_FIELD_D(", {", *uid, pid);
+	printf("%s", pid_str);
 	printf(", uid=");
 	print_quoted_hex(&uid->uid, sizeof_uid_truncated -
 				    offsetof(struct ucred, uid));
@@ -149,8 +164,10 @@ main(void)
 	 */
 	*len = sizeof_uid;
 	get_peercred(sv[0], uid, len);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s", sv[0], so_str());
 	PRINT_FIELD_D(", {", *uid, pid);
+	printf("%s", pid_str);
 	PRINT_FIELD_UID(", ", *uid, uid);
 	printf("}, [%d]) = %s\n", *len, errstr);
 
@@ -166,8 +183,10 @@ main(void)
 	 * to struct ucred.pid and struct ucred.uid fields.
 	 */
 	memcpy(peercred, gid_truncated, sizeof_gid_truncated);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s", sv[0], so_str());
 	PRINT_FIELD_D(", {", *peercred, pid);
+	printf("%s", pid_str);
 	PRINT_FIELD_UID(", ", *peercred, uid);
 	printf(", gid=");
 	print_quoted_hex(&peercred->gid, sizeof_gid_truncated -
@@ -177,14 +196,17 @@ main(void)
 	/* getsockopt optval EFAULT */
 	*len = sizeof(*peercred);
 	get_peercred(sv[0], &peercred->uid, len);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s, %p, [%d]) = %s\n",
 	       sv[0], so_str(), &peercred->uid, *len, errstr);
 
 	/* getsockopt optlen EFAULT */
 	get_peercred(sv[0], peercred, len + 1);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s, %p, %p) = %s\n",
 	       sv[0], so_str(), peercred, len + 1, errstr);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/so_peercred--pidns-translation.c 5.9-0ubuntu2/tests-m32/so_peercred--pidns-translation.c
--- 5.5-3/tests-m32/so_peercred--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/so_peercred--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "so_peercred.c"
diff -pruN 5.5-3/tests-m32/so_peercred--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/so_peercred--pidns-translation.gen.test
--- 5.5-3/tests-m32/so_peercred--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/so_peercred--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (so_peercred--pidns-translation test_pidns -e trace=getsockopt); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -e trace=getsockopt
diff -pruN 5.5-3/tests-m32/stack-fcall-0.c 5.9-0ubuntu2/tests-m32/stack-fcall-0.c
--- 5.5-3/tests-m32/stack-fcall-0.c	2019-07-11 17:51:22.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/stack-fcall-0.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2019 The strace developers.
+ * Copyright (c) 2014-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -7,7 +7,10 @@
 
 #include "stack-fcall.h"
 
-int f0(int i, unsigned long f)
+int
+f0(int i, unsigned long f)
 {
-	return f1(i, f ^ (unsigned long) (void *) f0) - i;
+	f ^= (unsigned long) (void *) f0;
+	COMPLEX_BODY(i, f);
+	return f1(i, f) - i;
 }
diff -pruN 5.5-3/tests-m32/stack-fcall-1.c 5.9-0ubuntu2/tests-m32/stack-fcall-1.c
--- 5.5-3/tests-m32/stack-fcall-1.c	2019-07-11 17:51:22.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/stack-fcall-1.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2019 The strace developers.
+ * Copyright (c) 2014-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -7,7 +7,10 @@
 
 #include "stack-fcall.h"
 
-int f1(int i, unsigned long f)
+int
+f1(int i, unsigned long f)
 {
-	return f2(i, f ^ (unsigned long) (void *) f1) + i;
+	f ^= (unsigned long) (void *) f1;
+	COMPLEX_BODY(i, f);
+	return f2(i, f) + i;
 }
diff -pruN 5.5-3/tests-m32/stack-fcall-2.c 5.9-0ubuntu2/tests-m32/stack-fcall-2.c
--- 5.5-3/tests-m32/stack-fcall-2.c	2019-07-11 17:51:22.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/stack-fcall-2.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2019 The strace developers.
+ * Copyright (c) 2014-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -7,7 +7,10 @@
 
 #include "stack-fcall.h"
 
-int f2(int i, unsigned long f)
+int
+f2(int i, unsigned long f)
 {
-	return f3(i, f ^ (unsigned long) (void *) f2) - i;
+	f ^= (unsigned long) (void *) f2;
+	COMPLEX_BODY(i, f);
+	return f3(i, f) - i;
 }
diff -pruN 5.5-3/tests-m32/stack-fcall-3.c 5.9-0ubuntu2/tests-m32/stack-fcall-3.c
--- 5.5-3/tests-m32/stack-fcall-3.c	2019-07-16 17:46:47.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/stack-fcall-3.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,25 +1,28 @@
 /*
- * Copyright (c) 2014-2019 The strace developers.
+ * Copyright (c) 2014-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include <signal.h>
-#include <unistd.h>
-#include "scno.h"
-
 #include "stack-fcall.h"
 
-int f3(int i, unsigned long f)
+int
+f3(int i, unsigned long f)
 {
-	syscall(__NR_gettid, f ^ (unsigned long) (void *) f3);
+	f ^= (unsigned long) (void *) f3;
+	COMPLEX_BODY(i, f);
 	switch (i) {
 	case 1:
-		return kill(getpid(), SIGURG);
-
+		i -= chdir("");
+		break;
+	case 2:
+		i -= kill(getpid(), SIGURG) - 1;
+		break;
 	default:
-		return chdir("") + i;
+		i -= syscall(__NR_exit, i - 3);
+		break;
 	}
-
+	return i;
 }
diff -pruN 5.5-3/tests-m32/stack-fcall.c 5.9-0ubuntu2/tests-m32/stack-fcall.c
--- 5.5-3/tests-m32/stack-fcall.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/stack-fcall.c	2020-06-27 08:00:00.000000000 +0000
@@ -13,14 +13,14 @@
 # define ATTACH_MODE 0
 #endif
 
-int main(void)
+int
+main(int ac, char **av)
 {
 #if ATTACH_MODE
 	/* sleep a bit to let the tracer time to catch up */
 	sleep(1);
 #endif
 
-	f0(0, (unsigned long) (void *) main);
-	f0(1, (unsigned long) (void *) main);
-	return 0;
+	for (;;)
+		ac += f0(ac, (unsigned long) (void *) main);
 }
diff -pruN 5.5-3/tests-m32/stack-fcall.h 5.9-0ubuntu2/tests-m32/stack-fcall.h
--- 5.5-3/tests-m32/stack-fcall.h	2019-07-11 17:51:22.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/stack-fcall.h	2020-08-03 08:00:00.000000000 +0000
@@ -1,10 +1,13 @@
 /*
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
+#include <unistd.h>
+#include "scno.h"
+
 #ifdef MANGLE
 
 # define f0 _ZN2ns2f0Ei
@@ -18,3 +21,24 @@ int f0(int i, unsigned long);
 int f1(int i, unsigned long);
 int f2(int i, unsigned long);
 int f3(int i, unsigned long);
+
+#define COMPLEX_BODY(i, f)				\
+	do {						\
+		int tid = syscall(__NR_gettid, f);	\
+		if (i == tid)				\
+			return 0;			\
+		switch ((unsigned int) tid & 3) {	\
+			case 0:				\
+				i += f0(tid, f);	\
+				break;			\
+			case 1:				\
+				i += f1(tid, f);	\
+				break;			\
+			case 2:				\
+				i += f2(tid, f);	\
+				break;			\
+			case 3:				\
+				i += f3(tid, f);	\
+				break;			\
+		}					\
+	} while (0)
diff -pruN 5.5-3/tests-m32/status-failed-long.c 5.9-0ubuntu2/tests-m32/status-failed-long.c
--- 5.5-3/tests-m32/status-failed-long.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/status-failed-long.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1 @@
+#include "status-failed.c"
diff -pruN 5.5-3/tests-m32/status-failed-long.gen.test 5.9-0ubuntu2/tests-m32/status-failed-long.gen.test
--- 5.5-3/tests-m32/status-failed-long.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/status-failed-long.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (status-failed-long -a10 -e trace=chdir --failed-only); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a10 -e trace=chdir --failed-only
diff -pruN 5.5-3/tests-m32/status-failed-status.c 5.9-0ubuntu2/tests-m32/status-failed-status.c
--- 5.5-3/tests-m32/status-failed-status.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/status-failed-status.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1 @@
+#include "status-failed.c"
diff -pruN 5.5-3/tests-m32/status-failed-status.gen.test 5.9-0ubuntu2/tests-m32/status-failed-status.gen.test
--- 5.5-3/tests-m32/status-failed-status.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/status-failed-status.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (status-failed-status -a10 -e trace=chdir -e status=failed); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a10 -e trace=chdir -e status=failed
diff -pruN 5.5-3/tests-m32/status-successful-long.c 5.9-0ubuntu2/tests-m32/status-successful-long.c
--- 5.5-3/tests-m32/status-successful-long.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/status-successful-long.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1 @@
+#include "status-successful.c"
diff -pruN 5.5-3/tests-m32/status-successful-long.gen.test 5.9-0ubuntu2/tests-m32/status-successful-long.gen.test
--- 5.5-3/tests-m32/status-successful-long.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/status-successful-long.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (status-successful-long -a10 -e trace=chdir --successful-only); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a10 -e trace=chdir --successful-only
diff -pruN 5.5-3/tests-m32/status-successful-status.c 5.9-0ubuntu2/tests-m32/status-successful-status.c
--- 5.5-3/tests-m32/status-successful-status.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/status-successful-status.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1 @@
+#include "status-successful.c"
diff -pruN 5.5-3/tests-m32/status-successful-status.gen.test 5.9-0ubuntu2/tests-m32/status-successful-status.gen.test
--- 5.5-3/tests-m32/status-successful-status.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/status-successful-status.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (status-successful-status -a10 -e trace=chdir --status=successful); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a10 -e trace=chdir --status=successful
diff -pruN 5.5-3/tests-m32/strace--absolute-timestamps-format-time.gen.test 5.9-0ubuntu2/tests-m32/strace--absolute-timestamps-format-time.gen.test
--- 5.5-3/tests-m32/strace--absolute-timestamps-format-time.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--absolute-timestamps-format-time.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-time +strace-t.test --absolute-timestamps=format:time); do not edit.
+set -- --absolute-timestamps=format:time
+. "${srcdir=.}/strace-t.test"
diff -pruN 5.5-3/tests-m32/strace--absolute-timestamps-format-time-precision-ms.gen.test 5.9-0ubuntu2/tests-m32/strace--absolute-timestamps-format-time-precision-ms.gen.test
--- 5.5-3/tests-m32/strace--absolute-timestamps-format-time-precision-ms.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--absolute-timestamps-format-time-precision-ms.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-time-precision-ms +strace-tt.test 3 --absolute-timestamps=format:time --absolute-timestamps=precision:ms); do not edit.
+set -- 3 --absolute-timestamps=format:time --absolute-timestamps=precision:ms
+. "${srcdir=.}/strace-tt.test"
diff -pruN 5.5-3/tests-m32/strace--absolute-timestamps-format-time-precision-ns.gen.test 5.9-0ubuntu2/tests-m32/strace--absolute-timestamps-format-time-precision-ns.gen.test
--- 5.5-3/tests-m32/strace--absolute-timestamps-format-time-precision-ns.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--absolute-timestamps-format-time-precision-ns.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-time-precision-ns +strace-tt.test 9 --absolute-timestamps=format:time --absolute-timestamps=precision:ns); do not edit.
+set -- 9 --absolute-timestamps=format:time --absolute-timestamps=precision:ns
+. "${srcdir=.}/strace-tt.test"
diff -pruN 5.5-3/tests-m32/strace--absolute-timestamps-format-time-precision-s.gen.test 5.9-0ubuntu2/tests-m32/strace--absolute-timestamps-format-time-precision-s.gen.test
--- 5.5-3/tests-m32/strace--absolute-timestamps-format-time-precision-s.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--absolute-timestamps-format-time-precision-s.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-time-precision-s +strace-t.test --absolute-timestamps=format:time --absolute-timestamps=precision:s); do not edit.
+set -- --absolute-timestamps=format:time --absolute-timestamps=precision:s
+. "${srcdir=.}/strace-t.test"
diff -pruN 5.5-3/tests-m32/strace--absolute-timestamps-format-time-precision-us.gen.test 5.9-0ubuntu2/tests-m32/strace--absolute-timestamps-format-time-precision-us.gen.test
--- 5.5-3/tests-m32/strace--absolute-timestamps-format-time-precision-us.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--absolute-timestamps-format-time-precision-us.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-time-precision-us +strace-tt.test 6 --absolute-timestamps=format:time --absolute-timestamps=precision:us); do not edit.
+set -- 6 --absolute-timestamps=format:time --absolute-timestamps=precision:us
+. "${srcdir=.}/strace-tt.test"
diff -pruN 5.5-3/tests-m32/strace--absolute-timestamps-format-unix-precision-ms.gen.test 5.9-0ubuntu2/tests-m32/strace--absolute-timestamps-format-unix-precision-ms.gen.test
--- 5.5-3/tests-m32/strace--absolute-timestamps-format-unix-precision-ms.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--absolute-timestamps-format-unix-precision-ms.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-unix-precision-ms +strace-ttt.test 3 --absolute-timestamps=precision:ms --absolute-timestamps=format:unix); do not edit.
+set -- 3 --absolute-timestamps=precision:ms --absolute-timestamps=format:unix
+. "${srcdir=.}/strace-ttt.test"
diff -pruN 5.5-3/tests-m32/strace--absolute-timestamps-format-unix-precision-ns.gen.test 5.9-0ubuntu2/tests-m32/strace--absolute-timestamps-format-unix-precision-ns.gen.test
--- 5.5-3/tests-m32/strace--absolute-timestamps-format-unix-precision-ns.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--absolute-timestamps-format-unix-precision-ns.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-unix-precision-ns +strace-ttt.test 9 --absolute-timestamps=format:unix --absolute-timestamps=precision:ns); do not edit.
+set -- 9 --absolute-timestamps=format:unix --absolute-timestamps=precision:ns
+. "${srcdir=.}/strace-ttt.test"
diff -pruN 5.5-3/tests-m32/strace--absolute-timestamps-format-unix-precision-s.gen.test 5.9-0ubuntu2/tests-m32/strace--absolute-timestamps-format-unix-precision-s.gen.test
--- 5.5-3/tests-m32/strace--absolute-timestamps-format-unix-precision-s.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--absolute-timestamps-format-unix-precision-s.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-unix-precision-s +strace-ttt.test 0 --absolute-timestamps=format:unix --absolute-timestamps=precision:s); do not edit.
+set -- 0 --absolute-timestamps=format:unix --absolute-timestamps=precision:s
+. "${srcdir=.}/strace-ttt.test"
diff -pruN 5.5-3/tests-m32/strace--absolute-timestamps-format-unix-precision-us.gen.test 5.9-0ubuntu2/tests-m32/strace--absolute-timestamps-format-unix-precision-us.gen.test
--- 5.5-3/tests-m32/strace--absolute-timestamps-format-unix-precision-us.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--absolute-timestamps-format-unix-precision-us.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-unix-precision-us +strace-ttt.test 6 --absolute-timestamps=precision:us --absolute-timestamps=format:unix); do not edit.
+set -- 6 --absolute-timestamps=precision:us --absolute-timestamps=format:unix
+. "${srcdir=.}/strace-ttt.test"
diff -pruN 5.5-3/tests-m32/strace--absolute-timestamps.gen.test 5.9-0ubuntu2/tests-m32/strace--absolute-timestamps.gen.test
--- 5.5-3/tests-m32/strace--absolute-timestamps.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--absolute-timestamps.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps +strace-t.test --absolute-timestamps); do not edit.
+set -- --absolute-timestamps
+. "${srcdir=.}/strace-t.test"
diff -pruN 5.5-3/tests-m32/strace-DDD.test 5.9-0ubuntu2/tests-m32/strace-DDD.test
--- 5.5-3/tests-m32/strace-DDD.test	2019-11-07 19:58:36.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace-DDD.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
 #
 # Check -DDD option.
 #
-# Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
+# Copyright (c) 2019-2020 Dmitry V. Levin <ldv@altlinux.org>
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,6 +10,8 @@
 . "${srcdir=.}/init.sh"
 
 check_prog sed
+run_prog_skip_if_failed \
+	kill -0 $$
 
 status_file=/proc/self/status
 [ -f "$status_file" ] ||
@@ -19,10 +21,16 @@ stat_file=/proc/self/stat
 [ -f "$stat_file" ] ||
 	framework_skip_ "$stat_file is not available"
 
+reapid="$(../get_process_reaper)" && [ "$reapid" -ge 1 ] ||
+	fail_ 'get_process_reaper failed'
+
 set -- -enone -esignal=none ../tracer_ppid_pgid_sid
 run_strace "$@" > "$OUT"
-read -r ppid pgid sid < "$OUT" &&
+read -r tracer_pid ppid pgid sid < "$OUT" &&
+[ "$tracer_pid" -gt 1 ] &&
+[ "$tracer_pid" -ne "$reapid" ] &&
 [ "$ppid" -gt 1 ] &&
+[ "$ppid" -ne "$reapid" ] &&
 [ "$pgid" -ge 0 ] &&
 [ "$sid" -ge 0 ] || {
 	cat < "$OUT" > "$LOG"
@@ -34,35 +42,52 @@ pgid0="$pgid"
 sid0="$sid"
 
 run_strace -D "$@" > "$OUT"
-read -r ppid pgid sid < "$OUT" &&
-[ "$ppid" -eq 1 ] &&
+read -r tracer_pid ppid pgid sid < "$OUT" &&
+[ "$tracer_pid" -gt 1 ] &&
+[ "$tracer_pid" -ne "$reapid" ] &&
+[ "$ppid" -eq "$reapid" ] &&
 [ "$pgid" = "$pgid0" ] &&
 [ "$sid" = "$sid0" ] || {
 	cat < "$OUT" > "$LOG"
 	dump_log_and_fail_with "$STRACE $args: unexpected output"
 }
+while kill -0 "$tracer_pid" 2> /dev/null; do
+	$SLEEP_A_BIT
+done
 match_diff
 
 run_strace -DD "$@" > "$OUT"
-read -r ppid pgid sid < "$OUT" &&
-[ "$ppid" -eq 1 ] &&
+read -r tracer_pid ppid pgid sid < "$OUT" &&
+[ "$tracer_pid" -gt 1 ] &&
+[ "$tracer_pid" -ne "$reapid" ] &&
+[ "$ppid" -eq "$reapid" ] &&
 [ "$pgid" -gt 1 ] &&
+[ "$pgid" -ne "$reapid" ] &&
 [ "$pgid" != "$pgid0" ] &&
 [ "$pgid" != "$sid" ] &&
 [ "$sid" = "$sid0" ] || {
 	cat < "$OUT" > "$LOG"
 	dump_log_and_fail_with "$STRACE $args: unexpected output"
 }
+while kill -0 "$tracer_pid" 2> /dev/null; do
+	$SLEEP_A_BIT
+done
 match_diff
 
 run_strace -DDD "$@" > "$OUT"
-read -r ppid pgid sid < "$OUT" &&
-[ "$ppid" -eq 1 ] &&
+read -r tracer_pid ppid pgid sid < "$OUT" &&
+[ "$tracer_pid" -gt 1 ] &&
+[ "$tracer_pid" -ne "$reapid" ] &&
+[ "$ppid" -eq "$reapid" ] &&
 [ "$pgid" -gt 1 ] &&
+[ "$pgid" -ne "$reapid" ] &&
 [ "$pgid" != "$pgid0" ] &&
 [ "$sid" = "$pgid" ] &&
 [ "$sid" != "$sid0" ] || {
 	cat < "$OUT" > "$LOG"
 	dump_log_and_fail_with "$STRACE $args: unexpected output"
 }
+while kill -0 "$tracer_pid" 2> /dev/null; do
+	$SLEEP_A_BIT
+done
 match_diff
diff -pruN 5.5-3/tests-m32/strace-DD.expected 5.9-0ubuntu2/tests-m32/strace-DD.expected
--- 5.5-3/tests-m32/strace-DD.expected	2019-10-07 11:33:37.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace-DD.expected	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-nanosleep({tv_sec=2, tv_nsec=0}, NULL)  = ? ERESTART_RESTARTBLOCK (Interrupted by signal)
diff -pruN 5.5-3/tests-m32/strace-DD.test 5.9-0ubuntu2/tests-m32/strace-DD.test
--- 5.5-3/tests-m32/strace-DD.test	2019-11-19 23:17:53.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace-DD.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
 #
 # Check -DD option.
 #
-# Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
+# Copyright (c) 2019-2020 Dmitry V. Levin <ldv@altlinux.org>
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -12,27 +12,62 @@
 [ "$STRACE" = "$STRACE_EXE" ] ||
 	skip_ 'Not applicable: $STRACE != $STRACE_EXE'
 
-check_prog timeout
+run_prog_skip_if_failed \
+        kill -0 $$
+
+status_file=/proc/self/status
+get_tracer_pid()
+{
+	sed '/^TracerPid:[[:space:]]*/!d;s///' "$@"
+}
+[ "$(get_tracer_pid "$status_file")" -ge 0 ] ||
+        framework_skip_ "$status_file is not available"
+
 run_prog ../sleep 0
 
+sleep_duration="$(($TIMEOUT_DURATION/2))"
+
 test_D()
 {
-	local exp args
-	exp="$1"; shift
+	local tracee_pid tracer_pid rc sig=15
 
-	set -- -e signal=none -e trace=nanosleep "$@" ../sleep 2
-	args="$*"
-	set -- timeout -s XCPU 1 $STRACE -o "$LOG" "$@"
+	set -- $STRACE --output="$LOG" --columns=39 \
+		--interruptible=anywhere --trace=nanosleep "$@" -- \
+		../sleep "$sleep_duration"
 	> "$LOG"
-	"$@" && rc=0 || rc=$?
-	[ "$rc" = 124 ] ||
-		dump_log_and_fail_with \
-			"$* failed with unexpected exit code $rc"
+
+	../setpgrp-exec "$@" &
+	tracee_pid=$!
+
+	while tracer_pid="$(get_tracer_pid "/proc/$tracee_pid/status")"; do
+		[ "$tracer_pid" = 0 ] ||
+			break
+		$SLEEP_A_BIT
+	done
+
 	$SLEEP_A_BIT
-	match_diff "$LOG" "$exp"
+	kill -$sig -$tracee_pid
+
+	wait $tracee_pid && rc=0 || rc=$?
+	[ "$rc" -eq $((128 + $sig)) ] ||
+		dump_log_and_fail_with \
+			"$* failed with unexpected exit status $rc"
+
+	while kill -0 "$tracer_pid" 2> /dev/null; do
+		$SLEEP_A_BIT
+	done
+	match_diff "$LOG" "$EXP"
 }
 
-printf %s 'nanosleep({tv_sec=2, tv_nsec=0}, ' > "$EXP"
-test_D "$EXP" -D
-test_D "$srcdir/$NAME.expected" -DD
-test_D "$srcdir/$NAME.expected" -DDD
+printf 'nanosleep({tv_sec=%s, tv_nsec=0}, ' "$sleep_duration" > "$EXP"
+test_D -D
+
+uid="${UID:-`id -u`}"
+cat > "$EXP" <<__EOF__
+nanosleep({tv_sec=$sleep_duration, tv_nsec=0}, NULL) = ? ERESTART_RESTARTBLOCK (Interrupted by signal)
+--- SIGTERM {si_signo=SIGTERM, si_code=SI_USER, si_pid=$$, si_uid=$uid} ---
++++ killed by SIGTERM +++
+__EOF__
+
+test_D -DD
+test_D -DDD
diff -pruN 5.5-3/tests-m32/strace-D.test 5.9-0ubuntu2/tests-m32/strace-D.test
--- 5.5-3/tests-m32/strace-D.test	2019-10-21 00:07:20.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace-D.test	2020-05-27 08:00:00.000000000 +0000
@@ -3,6 +3,7 @@
 # Check -D option.
 #
 # Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
+# Copyright (c) 2019-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,6 +11,8 @@
 . "${srcdir=.}/init.sh"
 
 check_prog sed
+run_prog_skip_if_failed \
+	kill -0 $$
 
 get_parent_pid()
 {
@@ -21,11 +24,7 @@ get_tracer_pid()
 	sed '/^TracerPid:[[:space:]]*/!d;s///'
 }
 
-status_file=/proc/self/status
-[ -f "$status_file" ] ||
-	framework_skip_ "$status_file is not available"
-
-set -- sed -r -n '/^(P|Tracer)Pid:/p' "$status_file"
+set -- ../print_ppid_tracerpid
 "$@" > "$LOG" ||
 	framework_skip_ "$* does not work"
 
@@ -35,7 +34,7 @@ set -- sed -r -n '/^(P|Tracer)Pid:/p' "$
 	dump_log_and_fail_with "$*: unexpected output"
 
 # !-D: PPid > 0, TracerPid > 0, PPid == TracerPid
-run_strace -q -enone "$@" > "$OUT"
+run_strace -e q=attach,personality -enone "$@" > "$OUT"
 [ "$(get_parent_pid < "$OUT")" -gt 0 ] &&
 [ "$(get_tracer_pid < "$OUT")" -gt 0 ] &&
 [ "$(get_parent_pid < "$OUT")" = "$(get_tracer_pid < "$OUT")" ] || {
@@ -46,17 +45,25 @@ match_diff
 
 test_parent_tracer_pid()
 {
-	local d
+	local d parent_pid tracer_pid
 	d="$1"; shift
 
 	# -D/-DD/-DDD: PPid > 0, TracerPid > 0, PPid != TracerPid
 	run_strace $d -q -enone "$@" > "$OUT"
-	[ "$(get_parent_pid < "$OUT")" -gt 0 ] &&
-	[ "$(get_tracer_pid < "$OUT")" -gt 0 ] &&
-	[ "$(get_parent_pid < "$OUT")" != "$(get_tracer_pid < "$OUT")" ] || {
+
+	parent_pid="$(get_parent_pid < "$OUT")" &&
+	[ "$parent_pid" -gt 0 ] &&
+	tracer_pid="$(get_tracer_pid < "$OUT")" &&
+	[ "$tracer_pid" -gt 0 ] &&
+	[ "$parent_pid" != "$tracer_pid" ] || {
 		cat < "$OUT" > "$LOG"
 		dump_log_and_fail_with "$STRACE $args: unexpected output"
 	}
+
+	while kill -0 "$tracer_pid" 2> /dev/null; do
+		$SLEEP_A_BIT
+	done
+
 	match_diff
 }
 
diff -pruN 5.5-3/tests-m32/strace-E-override.test 5.9-0ubuntu2/tests-m32/strace-E-override.test
--- 5.5-3/tests-m32/strace-E-override.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace-E-override.test	2020-08-03 08:00:00.000000000 +0000
@@ -0,0 +1,14 @@
+#!/bin/sh
+#
+# Check that --env option does not affect strace's own environment.
+#
+# Copyright (c) 2019-2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: GPL-2.0-or-later
+
+. "${srcdir=.}/init.sh"
+
+check_prog true
+run_prog true
+run_strace --quiet=all --trace=none --signal=none --env=PATH=/ $args
diff -pruN 5.5-3/tests-m32/strace-E-unset.expected 5.9-0ubuntu2/tests-m32/strace-E-unset.expected
--- 5.5-3/tests-m32/strace-E-unset.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace-E-unset.expected	2020-04-09 12:00:00.000000000 +0000
@@ -0,0 +1,5 @@
+execve\("\.\./sleep", \["\.\./sleep", "0"\], \[.*"option_E_var=OPTION_E_VAL".*\]\) = 0
+execve\("\.\./sleep", \["\.\./sleep", "0"\], \[.*"option_E_unsets=OPTION_E_UNSETS".*\]\) = 0
+execve\("\.\./sleep", \["\.\./sleep", "0"\], \[.*"option_E_mod=OPTION_E_NEW".*\]\) = 0
+execve\("\.\./sleep", \["\.\./sleep", "0"\], \[.*"option_E_mods=OPTION_E_MODS".*\]\) = 0
+!execve\("\.\./sleep", \["\.\./sleep", "0"\], \[.*"option_E_unset=.*\]\) = 0
diff -pruN 5.5-3/tests-m32/strace-E-unset.test 5.9-0ubuntu2/tests-m32/strace-E-unset.test
--- 5.5-3/tests-m32/strace-E-unset.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace-E-unset.test	2020-08-03 08:00:00.000000000 +0000
@@ -0,0 +1,32 @@
+#!/bin/sh
+#
+# Check modify/unset behaviour of -E/--env option.
+#
+# Copyright (c) 2016-2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: GPL-2.0-or-later
+
+. "${srcdir=.}/init.sh"
+
+export option_E_var=OPTION_E_VAL
+export option_E_mod=OPTION_E_MOD
+export option_E_mods=OPTION_E_MODS
+export option_E_unset=OPTION_E_UNSET
+export option_E_unsets=OPTION_E_UNSETS
+
+run_prog ../sleep 0
+run_strace -qqq -e signal=none -e trace=execve -v \
+	-E option_E_mod=OPTION_E_NEW \
+	-E option_E_unset \
+	-E option_E_missing \
+	$args
+match_grep
+
+run_prog ../sleep 0
+run_strace --quiet=all --signal=none --trace=execve --no-abbrev \
+	--env=option_E_mod=OPTION_E_NEW \
+	--env=option_E_unset \
+	--env=option_E_missing \
+	$args
+match_grep
diff -pruN 5.5-3/tests-m32/strace-ff.test 5.9-0ubuntu2/tests-m32/strace-ff.test
--- 5.5-3/tests-m32/strace-ff.test	2019-11-28 19:30:05.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace-ff.test	2020-04-03 22:58:26.000000000 +0000
@@ -1,14 +1,16 @@
-#!/bin/sh
+#!/bin/sh -efu
 #
 # Check -ff option.
 #
-# Copyright (c) 2016-2019 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/init.sh"
 
+ff_opt="${*:--ff}"
+
 run_prog_skip_if_failed \
 	kill -0 $$
 
@@ -22,12 +24,13 @@ while ! [ -s "$OUT" ]; do
 		fail_ 'set_ptracer_any sleep failed'
 done
 
-run_strace -a14 -eexit_group -ff -p $tracee_pid
+run_strace --quiet=personality -a14 -eexit_group ${ff_opt} -p $tracee_pid
 
 # check that output matches
 match_diff "$LOG.$tracee_pid"
 
 # check that no other output files have been created
+set +f
 set -- "$LOG".*
 [ "$LOG.$tracee_pid" = "$*" ] ||
 	fail_ "too many output files: $*"
diff -pruN 5.5-3/tests-m32/strace--follow-forks-output-separately.expected 5.9-0ubuntu2/tests-m32/strace--follow-forks-output-separately.expected
--- 5.5-3/tests-m32/strace--follow-forks-output-separately.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--follow-forks-output-separately.expected	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+exit_group(0) = ?
++++ exited with 0 +++
diff -pruN 5.5-3/tests-m32/strace--follow-forks-output-separately.gen.test 5.9-0ubuntu2/tests-m32/strace--follow-forks-output-separately.gen.test
--- 5.5-3/tests-m32/strace--follow-forks-output-separately.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--follow-forks-output-separately.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--follow-forks-output-separately +strace-ff.test --follow-forks --output-separately); do not edit.
+set -- --follow-forks --output-separately
+. "${srcdir=.}/strace-ff.test"
diff -pruN 5.5-3/tests-m32/strace-n.c 5.9-0ubuntu2/tests-m32/strace-n.c
--- 5.5-3/tests-m32/strace-n.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace-n.c	2020-08-21 16:39:53.000000000 +0000
@@ -0,0 +1,40 @@
+/*
+ * Test strace's -n option.
+ *
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+
+#include <stdio.h>
+#include <unistd.h>
+#include <errno.h>
+
+#define SC_listen 4
+
+int
+main(void)
+{
+	int rc;
+
+#if defined __NR_socketcall
+	if (syscall(__NR_socketcall, 0L, 0L, 0L, 0L, 0L) < 0
+		&& EINVAL == errno)
+	{
+		const long args[] = { 0, 0 };
+		rc = syscall(__NR_socketcall, SC_listen, args);
+		printf("[%4u] listen(0, 0) = %s\n", __NR_socketcall, sprintrc(rc));
+	}
+#endif
+
+#if defined __NR_listen
+	rc = syscall(__NR_listen, 0, 0);
+	printf("[%4u] listen(0, 0) = %s\n", __NR_listen, sprintrc(rc));
+#endif
+
+	return 0;
+}
diff -pruN 5.5-3/tests-m32/strace-n.gen.test 5.9-0ubuntu2/tests-m32/strace-n.gen.test
--- 5.5-3/tests-m32/strace-n.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace-n.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace-n -e trace=listen -n -qq -a 12); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -e trace=listen -n -qq -a 12
diff -pruN 5.5-3/tests-m32/strace--relative-timestamps.expected 5.9-0ubuntu2/tests-m32/strace--relative-timestamps.expected
--- 5.5-3/tests-m32/strace--relative-timestamps.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--relative-timestamps.expected	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+[ ]{5}0\.0{6} execve\("\.\./sleep", \["\.\./sleep", "1"\], 0x[[:xdigit:]]* /\* [[:digit:]]* vars \*/\) = 0
+[ ]{5}(1\.[01]|0\.9)[[:digit:]]{5} \+\+\+ exited with 0 \+\+\+
diff -pruN 5.5-3/tests-m32/strace--relative-timestamps.gen.test 5.9-0ubuntu2/tests-m32/strace--relative-timestamps.gen.test
--- 5.5-3/tests-m32/strace--relative-timestamps.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--relative-timestamps.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--relative-timestamps +strace-r.test --relative-timestamps); do not edit.
+set -- --relative-timestamps
+. "${srcdir=.}/strace-r.test"
diff -pruN 5.5-3/tests-m32/strace--relative-timestamps-ms.expected 5.9-0ubuntu2/tests-m32/strace--relative-timestamps-ms.expected
--- 5.5-3/tests-m32/strace--relative-timestamps-ms.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--relative-timestamps-ms.expected	2020-02-19 17:26:58.000000000 +0000
@@ -0,0 +1,2 @@
+[ ]{5}0\.0{3} execve\("\.\./sleep", \["\.\./sleep", "1"\], 0x[[:xdigit:]]* /\* [[:digit:]]* vars \*/\) = 0
+[ ]{5}(1\.[01]|0\.9)[[:digit:]]{2} \+\+\+ exited with 0 \+\+\+
diff -pruN 5.5-3/tests-m32/strace--relative-timestamps-ms.gen.test 5.9-0ubuntu2/tests-m32/strace--relative-timestamps-ms.gen.test
--- 5.5-3/tests-m32/strace--relative-timestamps-ms.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--relative-timestamps-ms.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--relative-timestamps-ms +strace-r.test --relative-timestamps=ms); do not edit.
+set -- --relative-timestamps=ms
+. "${srcdir=.}/strace-r.test"
diff -pruN 5.5-3/tests-m32/strace--relative-timestamps-ns.expected 5.9-0ubuntu2/tests-m32/strace--relative-timestamps-ns.expected
--- 5.5-3/tests-m32/strace--relative-timestamps-ns.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--relative-timestamps-ns.expected	2020-02-19 17:26:58.000000000 +0000
@@ -0,0 +1,2 @@
+[ ]{5}0\.0{9} execve\("\.\./sleep", \["\.\./sleep", "1"\], 0x[[:xdigit:]]* /\* [[:digit:]]* vars \*/\) = 0
+[ ]{5}(1\.[01]|0\.9)[[:digit:]]{8} \+\+\+ exited with 0 \+\+\+
diff -pruN 5.5-3/tests-m32/strace--relative-timestamps-ns.gen.test 5.9-0ubuntu2/tests-m32/strace--relative-timestamps-ns.gen.test
--- 5.5-3/tests-m32/strace--relative-timestamps-ns.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--relative-timestamps-ns.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--relative-timestamps-ns +strace-r.test --relative-timestamps=ns); do not edit.
+set -- --relative-timestamps=ns
+. "${srcdir=.}/strace-r.test"
diff -pruN 5.5-3/tests-m32/strace--relative-timestamps-s.expected 5.9-0ubuntu2/tests-m32/strace--relative-timestamps-s.expected
--- 5.5-3/tests-m32/strace--relative-timestamps-s.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--relative-timestamps-s.expected	2020-02-19 17:26:58.000000000 +0000
@@ -0,0 +1,2 @@
+[ ]{5}0 execve\("\.\./sleep", \["\.\./sleep", "1"\], 0x[[:xdigit:]]* /\* [[:digit:]]* vars \*/\) = 0
+[ ]{5}[01] \+\+\+ exited with 0 \+\+\+
diff -pruN 5.5-3/tests-m32/strace--relative-timestamps-s.gen.test 5.9-0ubuntu2/tests-m32/strace--relative-timestamps-s.gen.test
--- 5.5-3/tests-m32/strace--relative-timestamps-s.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--relative-timestamps-s.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--relative-timestamps-s +strace-r.test --relative-timestamps=s); do not edit.
+set -- --relative-timestamps=s
+. "${srcdir=.}/strace-r.test"
diff -pruN 5.5-3/tests-m32/strace--relative-timestamps-us.expected 5.9-0ubuntu2/tests-m32/strace--relative-timestamps-us.expected
--- 5.5-3/tests-m32/strace--relative-timestamps-us.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--relative-timestamps-us.expected	2020-02-19 17:26:58.000000000 +0000
@@ -0,0 +1,2 @@
+[ ]{5}0\.0{6} execve\("\.\./sleep", \["\.\./sleep", "1"\], 0x[[:xdigit:]]* /\* [[:digit:]]* vars \*/\) = 0
+[ ]{5}(1\.[01]|0\.9)[[:digit:]]{5} \+\+\+ exited with 0 \+\+\+
diff -pruN 5.5-3/tests-m32/strace--relative-timestamps-us.gen.test 5.9-0ubuntu2/tests-m32/strace--relative-timestamps-us.gen.test
--- 5.5-3/tests-m32/strace--relative-timestamps-us.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--relative-timestamps-us.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--relative-timestamps-us +strace-r.test --relative-timestamps=us); do not edit.
+set -- --relative-timestamps=us
+. "${srcdir=.}/strace-r.test"
diff -pruN 5.5-3/tests-m32/strace-r.test 5.9-0ubuntu2/tests-m32/strace-r.test
--- 5.5-3/tests-m32/strace-r.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace-r.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,13 +2,15 @@
 #
 # Check -r option.
 #
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/init.sh"
 
+r_opt="${1:--r}"
+
 run_prog ../sleep 0
-run_strace -r -eexecve ../sleep 1
+run_strace "${r_opt}" -eexecve ../sleep 1
 match_grep
diff -pruN 5.5-3/tests-m32/strace-S.test 5.9-0ubuntu2/tests-m32/strace-S.test
--- 5.5-3/tests-m32/strace-S.test	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace-S.test	2020-03-23 03:19:09.000000000 +0000
@@ -35,6 +35,10 @@ for s in '' '-S time' --summary-sort-by=
 	test_c "$s" '-n -r' \
 		's/^[[:space:]]+([0-9]+)[.,]([0-9]+)[[:space:]].*/\1\t\2/p'
 done
+for s in '-S avg_time' --summary-sort-by=time_avg; do
+	test_c "$s" '-n -r' \
+		'/^[[:space:]]+[0-9]/ s/^'"$c$c$c$c"'[[:space:]].*/\3/p'
+done
 for s in '-S calls' --summary-sort-by=count; do
 	test_c "$s" '-n -r' \
 		'/^[[:space:]]+[0-9]/ s/^'"$c$c$c$c"'[[:space:]].*/\4/p'
@@ -47,3 +51,11 @@ for s in '-S error' --summary-sort-by=er
 	test_c "$s" '-n -r' \
 		'/^[[:space:]]+[0-9]/ s/^'"$c$c$c$c"'([[:space:]]+([0-9]+))?'"$c"'$/\6/p'
 done
+for s in '--summary-columns=time,time-max,name -S max_time' '-U time-percent,max_time,syscall_name --summary-sort-by=longest'; do
+	test_c "$s" '-n -r' \
+		'/^[[:space:]]+[0-9]/ s/^'"$c$c"'[[:space:]].*/\2/p'
+done
+for s in '--summary-columns=time,time_min,name -S min-time' '-U time_percent,min_time,syscall-name --summary-sort-by=shortest'; do
+	test_c "$s" '-n -r' \
+		'/^[[:space:]]+[0-9]/ s/^'"$c$c"'[[:space:]].*/\2/p'
+done
diff -pruN 5.5-3/tests-m32/strace--strings-in-hex-all.c 5.9-0ubuntu2/tests-m32/strace--strings-in-hex-all.c
--- 5.5-3/tests-m32/strace--strings-in-hex-all.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--strings-in-hex-all.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define STRACE_XX 1
+#include "strace-x.c"
diff -pruN 5.5-3/tests-m32/strace--strings-in-hex-all.gen.test 5.9-0ubuntu2/tests-m32/strace--strings-in-hex-all.gen.test
--- 5.5-3/tests-m32/strace--strings-in-hex-all.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--strings-in-hex-all.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--strings-in-hex-all --trace=chdir --strings-in-hex=all --columns=18); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=chdir --strings-in-hex=all --columns=18
diff -pruN 5.5-3/tests-m32/strace--strings-in-hex.c 5.9-0ubuntu2/tests-m32/strace--strings-in-hex.c
--- 5.5-3/tests-m32/strace--strings-in-hex.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--strings-in-hex.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define STRACE_XX 1
+#include "strace-x.c"
diff -pruN 5.5-3/tests-m32/strace--strings-in-hex.gen.test 5.9-0ubuntu2/tests-m32/strace--strings-in-hex.gen.test
--- 5.5-3/tests-m32/strace--strings-in-hex.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--strings-in-hex.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--strings-in-hex --trace=chdir --strings-in-hex --columns=18); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=chdir --strings-in-hex --columns=18
diff -pruN 5.5-3/tests-m32/strace--strings-in-hex-non-ascii.c 5.9-0ubuntu2/tests-m32/strace--strings-in-hex-non-ascii.c
--- 5.5-3/tests-m32/strace--strings-in-hex-non-ascii.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--strings-in-hex-non-ascii.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define STRACE_XX 0
+#include "strace-x.c"
diff -pruN 5.5-3/tests-m32/strace--strings-in-hex-non-ascii.gen.test 5.9-0ubuntu2/tests-m32/strace--strings-in-hex-non-ascii.gen.test
--- 5.5-3/tests-m32/strace--strings-in-hex-non-ascii.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--strings-in-hex-non-ascii.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--strings-in-hex-non-ascii --trace=chdir --strings-in-hex=non-ascii --columns=12); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=chdir --strings-in-hex=non-ascii --columns=12
diff -pruN 5.5-3/tests-m32/strace--syscall-times.expected 5.9-0ubuntu2/tests-m32/strace--syscall-times.expected
--- 5.5-3/tests-m32/strace--syscall-times.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--syscall-times.expected	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1 @@
+nanosleep\(\{tv_sec=1, tv_nsec=0\}, NULL\) = 0 <(1\.[01]|0\.9)[[:digit:]]{5}>
diff -pruN 5.5-3/tests-m32/strace--syscall-times.gen.test 5.9-0ubuntu2/tests-m32/strace--syscall-times.gen.test
--- 5.5-3/tests-m32/strace--syscall-times.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--syscall-times.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--syscall-times +strace-T.test --syscall-times); do not edit.
+set -- --syscall-times
+. "${srcdir=.}/strace-T.test"
diff -pruN 5.5-3/tests-m32/strace--syscall-times-ms.expected 5.9-0ubuntu2/tests-m32/strace--syscall-times-ms.expected
--- 5.5-3/tests-m32/strace--syscall-times-ms.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--syscall-times-ms.expected	2020-02-19 17:26:58.000000000 +0000
@@ -0,0 +1 @@
+nanosleep\(\{tv_sec=1, tv_nsec=0\}, NULL\) = 0 <(1\.[01]|0\.9)[[:digit:]]{2}>
diff -pruN 5.5-3/tests-m32/strace--syscall-times-ms.gen.test 5.9-0ubuntu2/tests-m32/strace--syscall-times-ms.gen.test
--- 5.5-3/tests-m32/strace--syscall-times-ms.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--syscall-times-ms.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--syscall-times-ms +strace-T.test --syscall-times=ms); do not edit.
+set -- --syscall-times=ms
+. "${srcdir=.}/strace-T.test"
diff -pruN 5.5-3/tests-m32/strace--syscall-times-ns.expected 5.9-0ubuntu2/tests-m32/strace--syscall-times-ns.expected
--- 5.5-3/tests-m32/strace--syscall-times-ns.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--syscall-times-ns.expected	2020-02-19 17:26:58.000000000 +0000
@@ -0,0 +1 @@
+nanosleep\(\{tv_sec=1, tv_nsec=0\}, NULL\) = 0 <(1\.[01]|0\.9)[[:digit:]]{8}>
diff -pruN 5.5-3/tests-m32/strace--syscall-times-ns.gen.test 5.9-0ubuntu2/tests-m32/strace--syscall-times-ns.gen.test
--- 5.5-3/tests-m32/strace--syscall-times-ns.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--syscall-times-ns.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--syscall-times-ns +strace-T.test --syscall-times=ns); do not edit.
+set -- --syscall-times=ns
+. "${srcdir=.}/strace-T.test"
diff -pruN 5.5-3/tests-m32/strace--syscall-times-s.expected 5.9-0ubuntu2/tests-m32/strace--syscall-times-s.expected
--- 5.5-3/tests-m32/strace--syscall-times-s.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--syscall-times-s.expected	2020-02-19 17:26:58.000000000 +0000
@@ -0,0 +1 @@
+nanosleep\(\{tv_sec=1, tv_nsec=0\}, NULL\) = 0 <[01]>
diff -pruN 5.5-3/tests-m32/strace--syscall-times-s.gen.test 5.9-0ubuntu2/tests-m32/strace--syscall-times-s.gen.test
--- 5.5-3/tests-m32/strace--syscall-times-s.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--syscall-times-s.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--syscall-times-s +strace-T.test --syscall-times=s); do not edit.
+set -- --syscall-times=s
+. "${srcdir=.}/strace-T.test"
diff -pruN 5.5-3/tests-m32/strace--syscall-times-us.expected 5.9-0ubuntu2/tests-m32/strace--syscall-times-us.expected
--- 5.5-3/tests-m32/strace--syscall-times-us.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--syscall-times-us.expected	2020-02-19 17:26:58.000000000 +0000
@@ -0,0 +1 @@
+nanosleep\(\{tv_sec=1, tv_nsec=0\}, NULL\) = 0 <(1\.[01]|0\.9)[[:digit:]]{5}>
diff -pruN 5.5-3/tests-m32/strace--syscall-times-us.gen.test 5.9-0ubuntu2/tests-m32/strace--syscall-times-us.gen.test
--- 5.5-3/tests-m32/strace--syscall-times-us.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--syscall-times-us.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--syscall-times-us +strace-T.test --syscall-times=us); do not edit.
+set -- --syscall-times=us
+. "${srcdir=.}/strace-T.test"
diff -pruN 5.5-3/tests-m32/strace--timestamps.gen.test 5.9-0ubuntu2/tests-m32/strace--timestamps.gen.test
--- 5.5-3/tests-m32/strace--timestamps.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--timestamps.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps +strace-t.test --timestamps); do not edit.
+set -- --timestamps
+. "${srcdir=.}/strace-t.test"
diff -pruN 5.5-3/tests-m32/strace--timestamps-time.gen.test 5.9-0ubuntu2/tests-m32/strace--timestamps-time.gen.test
--- 5.5-3/tests-m32/strace--timestamps-time.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--timestamps-time.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-time +strace-t.test --timestamps=time); do not edit.
+set -- --timestamps=time
+. "${srcdir=.}/strace-t.test"
diff -pruN 5.5-3/tests-m32/strace--timestamps-time-ms.gen.test 5.9-0ubuntu2/tests-m32/strace--timestamps-time-ms.gen.test
--- 5.5-3/tests-m32/strace--timestamps-time-ms.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--timestamps-time-ms.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-time-ms +strace-tt.test 3 --timestamps=time,ms); do not edit.
+set -- 3 --timestamps=time,ms
+. "${srcdir=.}/strace-tt.test"
diff -pruN 5.5-3/tests-m32/strace--timestamps-time-ns.gen.test 5.9-0ubuntu2/tests-m32/strace--timestamps-time-ns.gen.test
--- 5.5-3/tests-m32/strace--timestamps-time-ns.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--timestamps-time-ns.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-time-ns +strace-tt.test 9 --timestamps=time,ns); do not edit.
+set -- 9 --timestamps=time,ns
+. "${srcdir=.}/strace-tt.test"
diff -pruN 5.5-3/tests-m32/strace--timestamps-time-s.gen.test 5.9-0ubuntu2/tests-m32/strace--timestamps-time-s.gen.test
--- 5.5-3/tests-m32/strace--timestamps-time-s.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--timestamps-time-s.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-time-s +strace-t.test --timestamps=time,s); do not edit.
+set -- --timestamps=time,s
+. "${srcdir=.}/strace-t.test"
diff -pruN 5.5-3/tests-m32/strace--timestamps-time-us.gen.test 5.9-0ubuntu2/tests-m32/strace--timestamps-time-us.gen.test
--- 5.5-3/tests-m32/strace--timestamps-time-us.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--timestamps-time-us.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-time-us +strace-tt.test 6 --timestamps=time,us); do not edit.
+set -- 6 --timestamps=time,us
+. "${srcdir=.}/strace-tt.test"
diff -pruN 5.5-3/tests-m32/strace--timestamps-unix-ms.gen.test 5.9-0ubuntu2/tests-m32/strace--timestamps-unix-ms.gen.test
--- 5.5-3/tests-m32/strace--timestamps-unix-ms.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--timestamps-unix-ms.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-unix-ms +strace-ttt.test 3 --timestamps=unix,ms); do not edit.
+set -- 3 --timestamps=unix,ms
+. "${srcdir=.}/strace-ttt.test"
diff -pruN 5.5-3/tests-m32/strace--timestamps-unix-ns.gen.test 5.9-0ubuntu2/tests-m32/strace--timestamps-unix-ns.gen.test
--- 5.5-3/tests-m32/strace--timestamps-unix-ns.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--timestamps-unix-ns.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-unix-ns +strace-ttt.test 9 --timestamps=unix,ns); do not edit.
+set -- 9 --timestamps=unix,ns
+. "${srcdir=.}/strace-ttt.test"
diff -pruN 5.5-3/tests-m32/strace--timestamps-unix-s.gen.test 5.9-0ubuntu2/tests-m32/strace--timestamps-unix-s.gen.test
--- 5.5-3/tests-m32/strace--timestamps-unix-s.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--timestamps-unix-s.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-unix-s +strace-ttt.test 0 --timestamps=unix,s); do not edit.
+set -- 0 --timestamps=unix,s
+. "${srcdir=.}/strace-ttt.test"
diff -pruN 5.5-3/tests-m32/strace--timestamps-unix-us.gen.test 5.9-0ubuntu2/tests-m32/strace--timestamps-unix-us.gen.test
--- 5.5-3/tests-m32/strace--timestamps-unix-us.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace--timestamps-unix-us.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-unix-us +strace-ttt.test 6 --timestamps=unix,us); do not edit.
+set -- 6 --timestamps=unix,us
+. "${srcdir=.}/strace-ttt.test"
diff -pruN 5.5-3/tests-m32/strace-t.test 5.9-0ubuntu2/tests-m32/strace-t.test
--- 5.5-3/tests-m32/strace-t.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace-t.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,19 +2,21 @@
 #
 # Check -t option.
 #
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/init.sh"
 
+opts="${*:--t}"
+
 run_prog_skip_if_failed date +%s > "$LOG"
 run_prog_skip_if_failed date +%T --date "@$(cat "$LOG")" > /dev/null
 run_prog ../sleep 0
 
 s0="$(date +%s)"
-run_strace -t -eexecve $args
+run_strace $opts -eexecve $args
 s1="$(date +%s)"
 
 s="$s0"
diff -pruN 5.5-3/tests-m32/strace-T.test 5.9-0ubuntu2/tests-m32/strace-T.test
--- 5.5-3/tests-m32/strace-T.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace-T.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,13 +2,15 @@
 #
 # Check -T option.
 #
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/init.sh"
 
+T_opt="${1:--T}"
+
 run_prog ../sleep 0
-run_strace -a24 -T -enanosleep ../sleep 1
+run_strace -a24 "${T_opt}" -enanosleep ../sleep 1
 match_grep
diff -pruN 5.5-3/tests-m32/strace-tt.test 5.9-0ubuntu2/tests-m32/strace-tt.test
--- 5.5-3/tests-m32/strace-tt.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace-tt.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,19 +2,23 @@
 #
 # Check -tt option.
 #
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/init.sh"
 
+precision="${1:-6}"
+[ x0 = "x$#" ] || shift
+opts="${*:--tt}"
+
 run_prog_skip_if_failed date +%s > "$LOG"
 run_prog_skip_if_failed date +%T --date "@$(cat "$LOG")" > /dev/null
 run_prog ../sleep 0
 
 s0="$(date +%s)"
-run_strace -tt -eexecve $args
+run_strace $opts -eexecve $args
 s1="$(date +%s)"
 
 s="$s0"
@@ -26,7 +30,7 @@ while [ "$s" -le "$s1" ]; do
 done
 
 cat > "$EXP" << __EOF__
-($t_reg)\\.[[:digit:]]{6} execve\\("\\.\\./sleep", \\["\\.\\./sleep", "0"\\], 0x[[:xdigit:]]* /\\* [[:digit:]]* vars \\*/\\) = 0
+($t_reg)\\.[[:digit:]]{${precision}} execve\\("\\.\\./sleep", \\["\\.\\./sleep", "0"\\], 0x[[:xdigit:]]* /\\* [[:digit:]]* vars \\*/\\) = 0
 __EOF__
 
 match_grep "$LOG" "$EXP"
diff -pruN 5.5-3/tests-m32/strace-ttt.test 5.9-0ubuntu2/tests-m32/strace-ttt.test
--- 5.5-3/tests-m32/strace-ttt.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace-ttt.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,18 +2,22 @@
 #
 # Check -ttt option.
 #
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/init.sh"
 
+precision="${1:-6}"
+[ x0 = "x$#" ] || shift
+opts="${*:--ttt}"
+
 run_prog_skip_if_failed date +%s > /dev/null
 run_prog ../sleep 0
 
 s0="$(date +%s)"
-run_strace -ttt -eexecve $args
+run_strace $opts -eexecve $args
 s1="$(date +%s)"
 
 s="$s0"
@@ -23,8 +27,14 @@ while [ "$s" -le "$s1" ]; do
 	s=$(($s + 1))
 done
 
+if [ x0 = "x${precision}" ]; then
+	subsec_re=""
+else
+	subsec_re="\\.[[:digit:]]{${precision}}"
+fi
+
 cat > "$EXP" << __EOF__
-($t_reg)\\.[[:digit:]]{6} execve\\("\\.\\./sleep", \\["\\.\\./sleep", "0"\\], 0x[[:xdigit:]]* /\\* [[:digit:]]+ vars \\*/\\) = 0
+($t_reg)${subsec_re} execve\\("\\.\\./sleep", \\["\\.\\./sleep", "0"\\], 0x[[:xdigit:]]* /\\* [[:digit:]]+ vars \\*/\\) = 0
 __EOF__
 
 match_grep "$LOG" "$EXP"
diff -pruN 5.5-3/tests-m32/strace-x.c 5.9-0ubuntu2/tests-m32/strace-x.c
--- 5.5-3/tests-m32/strace-x.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace-x.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,82 @@
+/*
+ * Test strace's -x option.
+ *
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+
+#include <stdio.h>
+#include <unistd.h>
+
+#ifndef STRACE_XX
+# define STRACE_XX 0
+#endif
+
+#if STRACE_XX
+# define XOUT(x_, xx_) xx_
+#else
+# define XOUT(x_, xx_) x_
+#endif
+
+int
+main(void)
+{
+	static const struct {
+		const char *path;
+		const char *out;
+	} test_vecs[] = {
+		{ "test", XOUT("test", "\\x74\\x65\\x73\\x74") },
+		{ "\t\n\v\f\r hi~", XOUT("\\t\\n\\v\\f\\r hi~",
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e") },
+		{ "\t\n\v\f\r\16 hi~", XOUT(
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x0e\\x20\\x68\\x69\\x7e",
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x0e\\x20\\x68\\x69\\x7e") },
+		{ "\10\t\n\v\f\r hi~", XOUT(
+		  "\\x08\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e",
+		  "\\x08\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e") },
+		{ "\t\n\v\f\r\37 hi~", XOUT(
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x1f\\x20\\x68\\x69\\x7e",
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x1f\\x20\\x68\\x69\\x7e") },
+		{ "\t\n\v\f\r hi~\177", XOUT(
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e\\x7f",
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e\\x7f") },
+		{ "\t\n\v\f\r hi~\222", XOUT(
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e\\x92",
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e\\x92") },
+		{ "\t\n\v\f\r hi~\377", XOUT(
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e\\xff",
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e\\xff") },
+	};
+	static char path[] = "  ";
+
+	const char *rc_str;
+
+	for (size_t i = 0; i < ARRAY_SIZE(test_vecs); i++) {
+		rc_str = sprintrc(chdir(test_vecs[i].path));
+		printf("chdir(\"%s\") = %s\n", test_vecs[i].out, rc_str);
+	}
+
+	for (unsigned char c = 1; c < 255; c++) {
+		path[1] = c;
+		rc_str = sprintrc(chdir(path));
+
+		printf("chdir(");
+#if STRACE_XX
+		print_quoted_hex(path, sizeof(path) - 1);
+#else
+		if (((c < ' ') || (c >= 0x7f)) && (c != '\t') && (c != '\n') &&
+		    (c != '\v') && (c != '\f') && (c != '\r'))
+			print_quoted_hex(path, sizeof(path) - 1);
+		else
+			print_quoted_string(path);
+#endif
+		printf(") = %s\n", rc_str);
+	}
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
diff -pruN 5.5-3/tests-m32/strace-x.gen.test 5.9-0ubuntu2/tests-m32/strace-x.gen.test
--- 5.5-3/tests-m32/strace-x.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace-x.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace-x -e trace=chdir -x -a 12); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -e trace=chdir -x -a 12
diff -pruN 5.5-3/tests-m32/strace-xx.c 5.9-0ubuntu2/tests-m32/strace-xx.c
--- 5.5-3/tests-m32/strace-xx.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace-xx.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define STRACE_XX 1
+#include "strace-x.c"
diff -pruN 5.5-3/tests-m32/strace-xx.gen.test 5.9-0ubuntu2/tests-m32/strace-xx.gen.test
--- 5.5-3/tests-m32/strace-xx.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/strace-xx.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace-xx -e trace=chdir -xx -a 18); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -e trace=chdir -xx -a 18
diff -pruN 5.5-3/tests-m32/syntax.sh 5.9-0ubuntu2/tests-m32/syntax.sh
--- 5.5-3/tests-m32/syntax.sh	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/syntax.sh	2020-02-24 13:08:32.000000000 +0000
@@ -10,45 +10,62 @@
 
 . "${srcdir=.}/init.sh"
 
+log_sfx()
+{
+	printf "%.128s" "$*" | tr -c '0-9A-Za-z-=,' '_'
+}
+
 check_exit_status_and_stderr()
 {
-	$STRACE "$@" 2> "$LOG" &&
-		dump_log_and_fail_with \
-			"strace $* failed to handle the error properly"
-	match_diff "$LOG" "$EXP" \
+	local sfx
+	sfx="$1"; shift
+	$STRACE "$@" 2> "$LOG.$sfx" && {
+		cat "$LOG.$sfx" >&2
+		fail_ "strace $* failed to handle the error properly"
+	}
+	match_diff "$LOG.$sfx" "$EXP.$sfx" \
 		"strace $* failed to print expected diagnostics"
 }
 
 check_exit_status_and_stderr_using_grep()
 {
-	$STRACE "$@" 2> "$LOG" &&
-		dump_log_and_fail_with \
-			"strace $* failed to handle the error properly"
-	match_grep "$LOG" "$EXP" \
+	local sfx
+	sfx="$1"; shift
+	$STRACE "$@" 2> "$LOG.$sfx" && {
+		cat "$LOG.$sfx" >&2
+		fail_ "strace $* failed to handle the error properly"
+	}
+	match_grep "$LOG.$sfx" "$EXP.$sfx" \
 		"strace $* failed to print expected diagnostics"
 }
 
 check_e()
 {
-	local pattern="$1"; shift
-	cat > "$EXP" << __EOF__
+	local pattern sfx
+	pattern="$1"; shift
+	sfx="$(log_sfx "$*")"
+	cat > "$EXP.$sfx" << __EOF__
 $STRACE_EXE: $pattern
 __EOF__
-	check_exit_status_and_stderr "$@"
+	check_exit_status_and_stderr "$sfx" "$@"
 }
 
 check_e_using_grep()
 {
-	local pattern="$1"; shift
-	cat > "$EXP" << __EOF__
+	local pattern sfx
+	pattern="$1"; shift
+	sfx="$(log_sfx "$*")"
+	cat > "$EXP.$sfx" << __EOF__
 $STRACE_EXE: $pattern
 __EOF__
-	check_exit_status_and_stderr_using_grep "$@"
+	check_exit_status_and_stderr_using_grep "$sfx" "$@"
 }
 
 check_h()
 {
-	local patterns="$1"; shift
+	local patterns sfx
+	patterns="$1"; shift
+	sfx="$(log_sfx "$*")"
 	{
 		local pattern
 		printf '%s\n' "$patterns" |
@@ -56,6 +73,6 @@ check_h()
 				printf '%s: %s\n' "$STRACE_EXE" "$pattern"
 			done
 		printf "Try '%s -h' for more information.\\n" "$STRACE_EXE"
-	} > "$EXP"
-	check_exit_status_and_stderr "$@"
+	} > "$EXP.$sfx"
+	check_exit_status_and_stderr "$sfx" "$@"
 }
diff -pruN 5.5-3/tests-m32/test_nlattr.h 5.9-0ubuntu2/tests-m32/test_nlattr.h
--- 5.5-3/tests-m32/test_nlattr.h	2019-11-28 19:30:05.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/test_nlattr.h	2020-06-01 14:15:16.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -15,6 +15,10 @@
 #include "netlink.h"
 #include <linux/rtnetlink.h>
 
+#ifndef PRINT_SOCK
+# define PRINT_SOCK 0
+#endif
+
 static void
 init_nlattr(struct nlattr *const nla,
 	    const uint16_t nla_len,
@@ -37,6 +41,29 @@ print_nlattr(const unsigned int nla_len,
 	       add_data ? "[" : "", nla_len, nla_type);
 }
 
+static void
+print_sockfd(int sockfd, const char *pfx, const char *sfx)
+{
+#if PRINT_SOCK
+	static int fd = -1;
+	static unsigned long inode;
+
+	if (sockfd < 0) {
+		printf("%s%d%s", pfx, sockfd, sfx);
+		return;
+	}
+
+	if (sockfd != fd) {
+		fd = sockfd;
+		inode = inode_of_sockfd(fd);
+	}
+
+	printf("%s%d<socket:[%lu]>%s", pfx, sockfd, inode, sfx);
+#else
+	printf("%s%d%s", pfx, sockfd, sfx);
+#endif
+}
+
 #define TEST_NLATTR_EX_(fd_, nlh0_, hdrlen_,				\
 		     init_msg_, print_msg_,				\
 		     nla_type_, nla_type_str_,				\
@@ -60,7 +87,7 @@ print_nlattr(const unsigned int nla_len,
 			sprintrc(sendto((fd_), nlh, msg_len,		\
 					MSG_DONTWAIT, NULL, 0));	\
 									\
-		printf("sendto(%d, {", (fd_));				\
+		print_sockfd((fd_), "sendto(", ", {");			\
 		(print_msg_)(msg_len);					\
 		print_nlattr(nla_len, (nla_type_str_),			\
 			     (nla_total_len_) > (nla_data_len_));	\
diff -pruN 5.5-3/tests-m32/tests.h 5.9-0ubuntu2/tests-m32/tests.h
--- 5.5-3/tests-m32/tests.h	2019-12-15 16:29:06.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/tests.h	2020-04-17 20:43:15.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -24,6 +24,7 @@
 # endif
 
 # include <stdbool.h>
+# include <stdint.h>
 # include <sys/types.h>
 # include "kernel_types.h"
 # include "gcc_compat.h"
@@ -55,21 +56,67 @@
 # if XLAT_RAW
 #  define XLAT_KNOWN(val_, str_) STRINGIFY_VAL(val_)
 #  define XLAT_UNKNOWN(val_, dflt_) STRINGIFY_VAL(val_)
+
+#  define XLAT_FMT "%#x"
+#  define XLAT_ARGS(a_) (a_)
+#  define XLAT_SEL(v_, s_) v_
+
+#  define ABBR(s_) ""
+#  define RAW(s_) s_
+#  define VERB(s_) ""
+#  define NABBR(s_) s_
+#  define NRAW(s_) ""
+#  define NVERB(s_) s_
 # elif XLAT_VERBOSE
 #  define XLAT_KNOWN(val_, str_) STRINGIFY_VAL(val_) " /* " str_ " */"
 #  define XLAT_UNKNOWN(val_, dflt_) STRINGIFY_VAL(val_) " /* " dflt_ " */"
-# else
+
+#  define XLAT_FMT "%#x /* %s */"
+#  define XLAT_ARGS(a_) a_, #a_
+#  define XLAT_SEL(v_, s_) v_, s_
+
+#  define ABBR(s_) ""
+#  define RAW(s_) ""
+#  define VERB(s_) s_
+#  define NABBR(s_) s_
+#  define NRAW(s_) s_
+#  define NVERB(s_) ""
+# else /* !XLAT_RAW && !XLAT_VERBOSE */
 #  define XLAT_KNOWN(val_, str_) str_
 #  define XLAT_UNKNOWN(val_, dflt_) STRINGIFY_VAL(val_) " /* " dflt_ " */"
-# endif
+
+#  define XLAT_FMT "%s"
+#  define XLAT_ARGS(a_) #a_
+#  define XLAT_SEL(v_, s_) s_
+
+#  define ABBR(s_) s_
+#  define RAW(s_) ""
+#  define VERB(s_) ""
+#  define NABBR(s_) ""
+#  define NRAW(s_) s_
+#  define NVERB(s_) s_
+# endif /* XLAT_RAW, XLAT_VERBOSE */
 
 # define XLAT_STR(v_) sprintxlat(#v_, v_, NULL)
 
+# define ARG_XLAT_KNOWN(val_, str_) val_, XLAT_KNOWN(val_, str_)
+# define ARG_XLAT_UNKNOWN(val_, str_) val_, XLAT_UNKNOWN(val_, str_)
+
 # ifndef DEFAULT_STRLEN
 /* Default maximum # of bytes printed in printstr et al. */
 #  define DEFAULT_STRLEN 32
 # endif
 
+struct strval32 {
+	uint32_t val;
+	const char *str;
+};
+
+struct strval64 {
+	uint64_t val;
+	const char *str;
+};
+
 /* Cached sysconf(_SC_PAGESIZE). */
 size_t get_page_size(void);
 
@@ -137,15 +184,26 @@ void *tail_memdup(const void *, const si
 # define TAIL_ALLOC_OBJECT_VAR_PTR(type_name, type_ptr)		\
 	type_name *type_ptr = tail_alloc(sizeof(*type_ptr))
 
-/*
+/**
  * Fill memory (pointed by ptr, having size bytes) with different bytes (with
  * values starting with start and resetting every period) in order to catch
  * sign, byte order and/or alignment errors.
  */
 void fill_memory_ex(void *ptr, size_t size, unsigned char start,
 		    unsigned int period);
-/* Shortcut for fill_memory_ex(ptr, size, 0x80, 0x80) */
+/** Shortcut for fill_memory_ex(ptr, size, 0x80, 0x80) */
 void fill_memory(void *ptr, size_t size);
+/** Variant of fill_memory_ex for arrays of 16-bit (2-byte) values. */
+void fill_memory16_ex(void *ptr, size_t size, uint16_t start,
+		      unsigned int period);
+/** Shortcut for fill_memory16_ex(ptr, size, 0x80c0, 0x8000) */
+void fill_memory16(void *ptr, size_t size);
+/** Variant of fill_memory_ex for arrays of 32-bit (4-byte) values. */
+void fill_memory32_ex(void *ptr, size_t size, uint32_t start,
+		      unsigned int period);
+/** Shortcut for fill_memory32_ex(ptr, size, 0x80a0c0e0, 0x80000000) */
+void fill_memory32(void *ptr, size_t size);
+
 
 /* Close stdin, move stdout to a non-standard descriptor, and print. */
 void tprintf(const char *, ...)
@@ -276,6 +334,9 @@ int send_mmsg(int, struct mmsghdr *, uns
 int create_nl_socket_ext(int proto, const char *name);
 # define create_nl_socket(proto)	create_nl_socket_ext((proto), #proto)
 
+/* Create a temporary file in the current directory. */
+int create_tmpfile(unsigned int flags);
+
 /* Create a pipe with maximized descriptor numbers. */
 void pipe_maxfd(int pipefd[2]);
 
diff -pruN 5.5-3/tests-m32/tgkill.c 5.9-0ubuntu2/tests-m32/tgkill.c
--- 5.5-3/tests-m32/tgkill.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/tgkill.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,88 @@
+/*
+ * Check decoding of tgkill syscall.
+ *
+ * Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+#include "pidns.h"
+
+#ifdef __NR_tgkill
+
+# include <signal.h>
+# include <stdio.h>
+# include <unistd.h>
+
+static const char *errstr;
+
+static long
+k_tgkill(const unsigned int tgid,
+	 const unsigned int tid,
+	 const unsigned int sig)
+{
+        const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+        const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+        const kernel_ulong_t arg1 = fill | tgid;
+        const kernel_ulong_t arg2 = fill | tid;
+        const kernel_ulong_t arg3 = fill | sig;
+        const long rc = syscall(__NR_tgkill, arg1, arg2, arg3, bad, bad, bad);
+        errstr = sprintrc(rc);
+        return rc;
+}
+
+int
+main(void)
+{
+	PIDNS_TEST_INIT;
+
+	const int pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
+	const int tid = syscall(__NR_gettid);
+	const char *tid_str = pidns_pid2str(PT_TID);
+	const int bad_pid = -1;
+	const int bad_sig = 0xface;
+
+	k_tgkill(pid, tid, 0);
+	pidns_print_leader();
+	printf("tgkill(%d%s, %d%s, 0) = %s\n",
+		pid, pid_str, tid, tid_str, errstr);
+
+	k_tgkill(pid, bad_pid, 0);
+	pidns_print_leader();
+	printf("tgkill(%d%s, %d, 0) = %s\n",
+		pid, pid_str, bad_pid, errstr);
+
+	k_tgkill(bad_pid, tid, 0);
+	pidns_print_leader();
+	printf("tgkill(%d, %d%s, 0) = %s\n",
+		bad_pid, tid, tid_str, errstr);
+
+	k_tgkill(pid, tid, SIGCONT);
+	pidns_print_leader();
+	printf("tgkill(%d%s, %d%s, SIGCONT) = %s\n",
+		pid, pid_str, tid, tid_str, errstr);
+
+	k_tgkill(pid, tid, bad_sig);
+	pidns_print_leader();
+	printf("tgkill(%d%s, %d%s, %d) = %s\n",
+		pid, pid_str, tid, tid_str, bad_sig, errstr);
+
+	k_tgkill(pid, tid, -bad_sig);
+	pidns_print_leader();
+	printf("tgkill(%d%s, %d%s, %d) = %s\n",
+		pid, pid_str, tid, tid_str, -bad_sig, errstr);
+
+	pidns_print_leader();
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_tgkill")
+
+#endif
diff -pruN 5.5-3/tests-m32/tgkill.gen.test 5.9-0ubuntu2/tests-m32/tgkill.gen.test
--- 5.5-3/tests-m32/tgkill.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/tgkill.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (tgkill -a15 --signal='!cont'); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a15 --signal='!cont'
diff -pruN 5.5-3/tests-m32/tgkill--pidns-translation.c 5.9-0ubuntu2/tests-m32/tgkill--pidns-translation.c
--- 5.5-3/tests-m32/tgkill--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/tgkill--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "tgkill.c"
diff -pruN 5.5-3/tests-m32/tgkill--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/tgkill--pidns-translation.gen.test
--- 5.5-3/tests-m32/tgkill--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/tgkill--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (tgkill--pidns-translation test_pidns -a15 --signal='!cont' -e trace=tgkill); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a15 --signal='!cont' -e trace=tgkill
diff -pruN 5.5-3/tests-m32/threads-execve.c 5.9-0ubuntu2/tests-m32/threads-execve.c
--- 5.5-3/tests-m32/threads-execve.c	2019-11-19 23:17:53.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/threads-execve.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of threads when a non-leader thread invokes execve.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -23,6 +23,13 @@
 
 # include "kernel_old_timespec.h"
 
+# ifndef PRINT_EXITED
+#  define PRINT_EXITED 1
+# endif
+# ifndef PRINT_SUPERSEDED
+#  define PRINT_SUPERSEDED 1
+# endif
+
 static pid_t leader;
 static pid_t tid;
 
@@ -145,10 +152,10 @@ thread(void *arg)
 			break;
 	}
 
-	printf("%-5d +++ superseded by execve in pid %u +++\n"
-	       "%-5d <... execve resumed>) = 0\n",
-	       leader, tid,
-	       leader);
+# if PRINT_SUPERSEDED
+	printf("%-5d +++ superseded by execve in pid %u +++\n", leader, tid);
+# endif
+	printf("%-5d <... execve resumed>) = 0\n", leader);
 
 	(void) syscall(__NR_nanosleep, (unsigned long) &ots, 0UL);
 	execve(argv[0], argv, environ);
@@ -183,7 +190,9 @@ main(int ac, char **av)
 	action = atoi(av[2]);
 
 	if (action >= NUMBER_OF_ACTIONS * NUMBER_OF_ITERATIONS) {
+# if PRINT_EXITED
 		printf("%-5d +++ exited with 0 +++\n", leader);
+# endif
 		return 0;
 	}
 
diff -pruN 5.5-3/tests-m32/threads-execve-q.c 5.9-0ubuntu2/tests-m32/threads-execve-q.c
--- 5.5-3/tests-m32/threads-execve-q.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/threads-execve-q.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1 @@
+#include "threads-execve.c"
diff -pruN 5.5-3/tests-m32/threads-execve-q.gen.test 5.9-0ubuntu2/tests-m32/threads-execve-q.gen.test
--- 5.5-3/tests-m32/threads-execve-q.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/threads-execve-q.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (threads-execve-q +threads-execve.test -q); do not edit.
+set -- -q
+. "${srcdir=.}/threads-execve.test"
diff -pruN 5.5-3/tests-m32/threads-execve-qq.c 5.9-0ubuntu2/tests-m32/threads-execve-qq.c
--- 5.5-3/tests-m32/threads-execve-qq.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/threads-execve-qq.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_EXITED 0
+#include "threads-execve.c"
diff -pruN 5.5-3/tests-m32/threads-execve-qq.gen.test 5.9-0ubuntu2/tests-m32/threads-execve-qq.gen.test
--- 5.5-3/tests-m32/threads-execve-qq.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/threads-execve-qq.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (threads-execve-qq +threads-execve.test -qq); do not edit.
+set -- -qq
+. "${srcdir=.}/threads-execve.test"
diff -pruN 5.5-3/tests-m32/threads-execve-qqq.c 5.9-0ubuntu2/tests-m32/threads-execve-qqq.c
--- 5.5-3/tests-m32/threads-execve-qqq.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/threads-execve-qqq.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,3 @@
+#define PRINT_SUPERSEDED 0
+#define PRINT_EXITED 0
+#include "threads-execve.c"
diff -pruN 5.5-3/tests-m32/threads-execve-qqq.gen.test 5.9-0ubuntu2/tests-m32/threads-execve-qqq.gen.test
--- 5.5-3/tests-m32/threads-execve-qqq.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/threads-execve-qqq.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (threads-execve-qqq +threads-execve.test -qqq); do not edit.
+set -- -qqq
+. "${srcdir=.}/threads-execve.test"
diff -pruN 5.5-3/tests-m32/threads-execve--quiet-thread-execve.c 5.9-0ubuntu2/tests-m32/threads-execve--quiet-thread-execve.c
--- 5.5-3/tests-m32/threads-execve--quiet-thread-execve.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/threads-execve--quiet-thread-execve.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_SUPERSEDED 0
+#include "threads-execve.c"
diff -pruN 5.5-3/tests-m32/threads-execve--quiet-thread-execve.gen.test 5.9-0ubuntu2/tests-m32/threads-execve--quiet-thread-execve.gen.test
--- 5.5-3/tests-m32/threads-execve--quiet-thread-execve.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/threads-execve--quiet-thread-execve.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (threads-execve--quiet-thread-execve +threads-execve.test -s40 --quiet=personality,thread-execve); do not edit.
+set -- -s40 --quiet=personality,thread-execve
+. "${srcdir=.}/threads-execve.test"
diff -pruN 5.5-3/tests-m32/threads-execve.test 5.9-0ubuntu2/tests-m32/threads-execve.test
--- 5.5-3/tests-m32/threads-execve.test	2019-10-28 19:52:59.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/threads-execve.test	2020-04-03 22:58:26.000000000 +0000
@@ -3,7 +3,7 @@
 # Check decoding of threads when a non-leader thread invokes execve.
 #
 # Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
-# Copyright (c) 2016-2019 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -17,13 +17,15 @@ require_min_kernel_version_or_skip 3.1
 # This test requires some concurrency between threads.
 require_min_nproc 2
 
+opts="${*:-}"
+
 check_prog diff
 run_prog_skip_if_failed date +%s > /dev/null
 s0="$(date +%s)"
 
 run_prog > /dev/null
 
-set -- -a21 -f -esignal=none -e trace=execve,exit,nanosleep,rt_sigsuspend $args
+set -- -a21 -f -esignal=none -e trace=execve,exit,nanosleep,rt_sigsuspend $opts $args
 
 # Due to probabilistic nature of the test, try it several times.
 while :; do
diff -pruN 5.5-3/tests-m32/tkill.c 5.9-0ubuntu2/tests-m32/tkill.c
--- 5.5-3/tests-m32/tkill.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/tkill.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,69 @@
+/*
+ * Check decoding of tkill syscall.
+ *
+ * Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+#include "pidns.h"
+
+#ifdef __NR_tkill
+
+# include <signal.h>
+# include <stdio.h>
+# include <unistd.h>
+
+static const char *errstr;
+
+static long
+k_tkill(const unsigned int tid, const unsigned int sig)
+{
+        const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+        const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+        const kernel_ulong_t arg1 = fill | tid;
+        const kernel_ulong_t arg2 = fill | sig;
+        const long rc = syscall(__NR_tkill, arg1, arg2, bad, bad, bad, bad);
+        errstr = sprintrc(rc);
+        return rc;
+}
+
+int
+main(void)
+{
+	PIDNS_TEST_INIT;
+
+	const int tid = syscall(__NR_gettid);
+	const char *tid_str = pidns_pid2str(PT_TID);
+	const int bad_pid = -1;
+	const int bad_sig = 0xface;
+
+	k_tkill(tid, 0);
+	pidns_print_leader();
+	printf("tkill(%d%s, 0) = %s\n", tid, tid_str, errstr);
+
+	k_tkill(tid, SIGCONT);
+	pidns_print_leader();
+	printf("tkill(%d%s, SIGCONT) = %s\n", tid, tid_str, errstr);
+
+	k_tkill(bad_pid, bad_sig);
+	pidns_print_leader();
+	printf("tkill(%d, %d) = %s\n", bad_pid, bad_sig, errstr);
+
+	k_tkill(bad_pid, -bad_sig);
+	pidns_print_leader();
+	printf("tkill(%d, %d) = %s\n", bad_pid, -bad_sig, errstr);
+
+	pidns_print_leader();
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_tkill")
+
+#endif
diff -pruN 5.5-3/tests-m32/tkill.gen.test 5.9-0ubuntu2/tests-m32/tkill.gen.test
--- 5.5-3/tests-m32/tkill.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/tkill.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (tkill -a12 --signal='!cont'); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a12 --signal='!cont'
diff -pruN 5.5-3/tests-m32/tkill--pidns-translation.c 5.9-0ubuntu2/tests-m32/tkill--pidns-translation.c
--- 5.5-3/tests-m32/tkill--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/tkill--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "tkill.c"
diff -pruN 5.5-3/tests-m32/tkill--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/tkill--pidns-translation.gen.test
--- 5.5-3/tests-m32/tkill--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/tkill--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (tkill--pidns-translation test_pidns --signal='!cont' -a12 -e trace=tkill); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns --signal='!cont' -a12 -e trace=tkill
diff -pruN 5.5-3/tests-m32/trace_clock.gen.test 5.9-0ubuntu2/tests-m32/trace_clock.gen.test
--- 5.5-3/tests-m32/trace_clock.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/trace_clock.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (trace_clock test_trace_expr 'clock_nanosleep|times' -e%clock); do not edit.
+. "${srcdir=.}/init.sh"
+test_trace_expr 'clock_nanosleep|times' -e%clock
diff -pruN 5.5-3/tests-m32/trace_clock.in 5.9-0ubuntu2/tests-m32/trace_clock.in
--- 5.5-3/tests-m32/trace_clock.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/trace_clock.in	2020-04-17 20:43:15.000000000 +0000
@@ -0,0 +1,5 @@
+adjtimex -a13
+clock_adjtime -a21
+clock_xettime -a21
+xettimeofday -a20
+time -a9
diff -pruN 5.5-3/tests-m32/trace_fstat.in 5.9-0ubuntu2/tests-m32/trace_fstat.in
--- 5.5-3/tests-m32/trace_fstat.in	2018-12-10 23:45:11.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/trace_fstat.in	2020-06-14 08:00:00.000000000 +0000
@@ -9,3 +9,4 @@ fstat64-Xverbose	-a17 -Xverbose
 fstatat64	-a32
 newfstatat	-a32
 oldfstat	-a21
+statx	-a32
diff -pruN 5.5-3/tests-m32/tracer_ppid_pgid_sid.c 5.9-0ubuntu2/tests-m32/tracer_ppid_pgid_sid.c
--- 5.5-3/tests-m32/tracer_ppid_pgid_sid.c	2019-10-07 11:33:37.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/tracer_ppid_pgid_sid.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Helper program for strace-DDD.test
  *
- * Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2019-2020 Dmitry V. Levin <ldv@altlinux.org>
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -86,7 +86,7 @@ main(void)
 
 	int ppid = 0, pgid = 0, sid = 0;
 	get_ppid_pgid_sid(tracer_pid, &ppid, &pgid, &sid);
-	printf("%d %d %d\n", ppid, pgid, sid);
+	printf("%d %d %d %d\n", tracer_pid, ppid, pgid, sid);
 
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/trie_for_tests.c 5.9-0ubuntu2/tests-m32/trie_for_tests.c
--- 5.5-3/tests-m32/trie_for_tests.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/trie_for_tests.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1 @@
+#include "trie.c"
diff -pruN 5.5-3/tests-m32/trie_test.c 5.9-0ubuntu2/tests-m32/trie_test.c
--- 5.5-3/tests-m32/trie_test.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/trie_test.c	2020-09-23 16:29:35.000000000 +0000
@@ -0,0 +1,121 @@
+/*
+ * Copyright (c) 2017-2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "trie.h"
+
+#include <stdio.h>
+#include <inttypes.h>
+
+static void
+assert_equals(const char *msg, uint64_t expected, uint64_t actual) {
+	if (actual != expected)
+		error_msg_and_fail("%s: expected: %" PRIu64
+		                   ", actual: %" PRIu64, msg, expected, actual);
+}
+
+static void
+iterate_fn(void *data, uint64_t key, uint64_t value)
+{
+	uint64_t expected = key < 256 && key % 10 == 0 ? key + 42 : -1ULL;
+	assert_equals("iterate_fn", expected, value);
+
+	int *count = (int *) data;
+	if (value != -1ULL)
+		(*count)++;
+}
+
+static void
+test_trie_iterate_fn(void)
+{
+	struct trie *t = trie_create(8, 6, 3, 3, -1);
+	for (int i = 0; i < 26; i++)
+		trie_set(t, i * 10, i * 10 + 42);
+
+	static const struct {
+		uint64_t start;
+		uint64_t end;
+		int expected_count;
+	} iterate_params[] = {
+		{0, 256, 26},
+		{0, UINT64_MAX, 26},
+		{20, 90, 8},
+		{99, 999, 16},
+		{10000, 100000, 0},
+		{200, 100, 0},
+	};
+
+	for (size_t i = 0; i < ARRAY_SIZE(iterate_params); i++) {
+		int count = 0;
+		trie_iterate_keys(t, iterate_params[i].start, iterate_params[i].end, iterate_fn, &count);
+		assert_equals("iteration count", iterate_params[i].expected_count, count);
+	}
+}
+
+struct key_value_pair {
+	uint64_t key, value;
+};
+
+static void
+test_trie_get(void)
+{
+	static const struct {
+		uint8_t key_size;
+		uint8_t item_size_lg;
+		uint8_t node_key_bits;
+		uint8_t data_block_key_bits;
+		uint64_t empty_value;
+
+		struct key_value_pair set_values[3], get_values[3];
+	} params[] = {
+		{64, 6, 10, 10, 0,
+			{{300, 1}, {0xfacefeed, 0xabcdef123456}, {-1ULL, -1ULL}},
+			{{301, 0}, {0xfacefeed, 0xabcdef123456}, {-1ULL, -1ULL}}},
+		{8, 2, 4, 4, 10,
+			{{0xab, 0xcd}, {0xface, 2}, {0, 3}},
+			{{0xab, 0xd}, {0xface, 10}, {0, 3}}},
+		{30, 0, 6, 3, -1,
+			{{0xaaaa, 127}, {0xface, 0}, {0, 0}},
+			{{0xaaaa, 1}, {0xface, 0}, {1, 1}}},
+		{16, 4, 5, 11, 0xffffff,
+			{{0xabcdef, 42}, {0xabcd, 42}, {0xffff, 0}},
+			{{0xabcdef, 0xffff}, {0xabcd, 42}, {0xffff, 0}}},
+		{41, 5, 1, 1, -1,
+			{{0xabcdef01, 0x22222222}, {-1, 0x33333333}, {10, 10}},
+			{{0xabcdef01, 0x22222222}, {-1, 0xffffffff}, {10, 10}}},
+	};
+
+	for (size_t i = 0; i < ARRAY_SIZE(params); i++) {
+		struct trie *t = trie_create(params[i].key_size,
+		                             params[i].item_size_lg,
+					     params[i].node_key_bits,
+					     params[i].data_block_key_bits,
+					     params[i].empty_value);
+
+		if (!t)
+			error_msg_and_fail("trie creation failed");
+
+		for (size_t j = 0; j < ARRAY_SIZE(params[i].set_values); j++) {
+			struct key_value_pair kv = params[i].set_values[j];
+			trie_set(t, kv.key, kv.value);
+		}
+		for (size_t j = 0; j < ARRAY_SIZE(params[i].get_values); j++) {
+			struct key_value_pair kv = params[i].get_values[j];
+			assert_equals("trie_get", kv.value, trie_get(t, kv.key));
+		}
+
+		trie_free(t);
+	}
+}
+
+int
+main(void)
+{
+	test_trie_get();
+	test_trie_iterate_fn();
+	return 0;
+}
diff -pruN 5.5-3/tests-m32/trie_test.gen.test 5.9-0ubuntu2/tests-m32/trie_test.gen.test
--- 5.5-3/tests-m32/trie_test.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/trie_test.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (trie_test run_prog ); do not edit.
+. "${srcdir=.}/init.sh"
+run_prog 
diff -pruN 5.5-3/tests-m32/umovestr_cached_adjacent.c 5.9-0ubuntu2/tests-m32/umovestr_cached_adjacent.c
--- 5.5-3/tests-m32/umovestr_cached_adjacent.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/umovestr_cached_adjacent.c	2020-04-16 00:04:10.000000000 +0000
@@ -0,0 +1,48 @@
+/*
+ * Check effectiveness of umovestr memory caching.
+ *
+ * Copyright (c) 2019-2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+
+#include <stdio.h>
+#include <string.h>
+#include <unistd.h>
+#include <sys/uio.h>
+
+int
+main(void)
+{
+	const size_t size = get_page_size() + (DEFAULT_STRLEN - 1);
+	char *const buf = tail_alloc(size);
+	fill_memory_ex(buf, DEFAULT_STRLEN * 2, 'a', 'z' - 'a' + 1);
+
+	struct iovec *const io = tail_alloc(sizeof(*io) * DEFAULT_STRLEN);
+	for (unsigned int i = 0; i < DEFAULT_STRLEN; ++i) {
+		io[i].iov_base = buf + i;
+		io[i].iov_len = DEFAULT_STRLEN;
+	}
+
+	tprintf("%s", "");
+
+	int rc = writev(-1, io, DEFAULT_STRLEN);
+	const char *errstr = sprintrc(rc);
+
+	tprintf("writev(-1, [");
+	for (unsigned int i = 0; i < DEFAULT_STRLEN; ++i) {
+		if (i)
+			tprintf(", ");
+		tprintf("{iov_base=\"%.*s\", iov_len=%u}",
+			(int) io[i].iov_len,
+			(char *) io[i].iov_base,
+			(unsigned int) io[i].iov_len);
+	}
+	tprintf("], %u) = %s\n", DEFAULT_STRLEN, errstr);
+
+	tprintf("+++ exited with 0 +++\n");
+	return 0;
+}
diff -pruN 5.5-3/tests-m32/umovestr_cached_adjacent.gen.test 5.9-0ubuntu2/tests-m32/umovestr_cached_adjacent.gen.test
--- 5.5-3/tests-m32/umovestr_cached_adjacent.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/umovestr_cached_adjacent.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (umovestr_cached_adjacent +umovestr_cached.test 3); do not edit.
+set -- 3
+. "${srcdir=.}/umovestr_cached.test"
diff -pruN 5.5-3/tests-m32/umovestr_cached.test 5.9-0ubuntu2/tests-m32/umovestr_cached.test
--- 5.5-3/tests-m32/umovestr_cached.test	2019-09-23 10:19:22.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/umovestr_cached.test	2020-04-16 00:04:10.000000000 +0000
@@ -2,22 +2,32 @@
 #
 # Check effectiveness of umovestr memory caching.
 #
-# Copyright (c) 2017-2019 Dmitry V. Levin <ldv@altlinux.org>
+# Copyright (c) 2017-2020 Dmitry V. Levin <ldv@altlinux.org>
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/init.sh"
 
-run_strace_match_diff -e trace=writev
-
-if [ "$STRACE_ARCH" = ia64 ]; then
-	# ia64 invokes extra process_vm_readv syscalls to obtain syscall
-	# arguments, see linux/ia64/get_syscall_args.c for details.
-	skip_ "the test is not supported on $STRACE_ARCH yet"
-fi
+expected_count="${1:-2}"
 
 check_prog grep
+$STRACE -d -enone / > /dev/null 2> "$LOG" ||:
+grep -x "[^:]*strace: PTRACE_GET_SYSCALL_INFO works" "$LOG" > /dev/null || {
+	# PTRACE_GET_SYSCALL_INFO does not work
+	case "$STRACE_ARCH:$MIPS_ABI" in
+		ia64:|mips:o32)
+		# ia64 invokes extra process_vm_readv syscalls to obtain syscall
+		# arguments, see linux/ia64/get_syscall_args.c for details.
+		# mips o32 obtains the first four syscalls arguments from registers
+		# and invokes extra process_vm_readv syscalls to obtain remaining
+		# syscall arguments, see linux/mips/get_syscall_args.c for details.
+		skip_ "the test is not supported on $STRACE_ARCH yet"
+		;;
+	esac
+}
+
+run_strace_match_diff -e trace=writev
 
 run_strace -qq -esignal=none -eprocess_vm_readv -z \
 	-o '|grep -c ^process_vm_readv > count' \
@@ -26,6 +36,6 @@ run_strace -qq -esignal=none -eprocess_v
 count="$(cat count)"
 case "$count" in
 	0) skip_ "$STRACE $args made no process_vm_readv syscall invocations" ;;
-	2) ;;
-	*) fail_ "$STRACE $args made $count != 2 process_vm_readv syscall invocations" ;;
+	$expected_count) ;;
+	*) fail_ "$STRACE $args made $count != $expected_count process_vm_readv syscall invocations" ;;
 esac
diff -pruN 5.5-3/tests-m32/unshare.c 5.9-0ubuntu2/tests-m32/unshare.c
--- 5.5-3/tests-m32/unshare.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/unshare.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of unshare syscall.
  *
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -28,12 +28,12 @@ main(void)
 		const char *str;
 	} unshare_flags[] = {
 		{ ARG_STR(0) },
-		{ 0xdeadca75,
-			"CLONE_THREAD|CLONE_FS|CLONE_SIGHAND|CLONE_SYSVSEM|"
-			"CLONE_NEWUTS|CLONE_NEWIPC|CLONE_NEWNET|CLONE_NEWUSER|"
-			"CLONE_NEWCGROUP|0x80a8c075" },
+		{ 0xdeadcaf5,
+			"CLONE_NEWTIME|CLONE_FS|CLONE_SIGHAND|CLONE_THREAD"
+			"|CLONE_SYSVSEM|CLONE_NEWCGROUP|CLONE_NEWUTS"
+			"|CLONE_NEWIPC|CLONE_NEWUSER|CLONE_NEWNET|0x80a8c075" },
 		{ 0x2000000, "CLONE_NEWCGROUP" },
-		{ ARG_STR(0x81f8f0ff) " /* CLONE_??? */" },
+		{ ARG_STR(0x81f8f07f) " /* CLONE_??? */" },
 	};
 
 	long rc;
diff -pruN 5.5-3/tests-m32/wait4.c 5.9-0ubuntu2/tests-m32/wait4.c
--- 5.5-3/tests-m32/wait4.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/wait4.c	2020-06-02 08:00:00.000000000 +0000
@@ -2,77 +2,98 @@
  * Check decoding of wait4 syscall.
  *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-#include <assert.h>
-#include <signal.h>
-#include <stdio.h>
-#include <unistd.h>
-#include <sys/wait.h>
-#include <sys/resource.h>
+#include "scno.h"
+
+#ifdef __NR_wait4
+
+# include <assert.h>
+# include <signal.h>
+# include <stdio.h>
+# include <unistd.h>
+# include <sys/wait.h>
+# include "kernel_rusage.h"
 
 static const char *
-sprint_rusage(const struct rusage *const ru)
+sprint_rusage(const kernel_rusage_t *const ru)
 {
 	static char buf[1024];
 	snprintf(buf, sizeof(buf),
-		 "{ru_utime={tv_sec=%lld, tv_usec=%llu}"
-		 ", ru_stime={tv_sec=%lld, tv_usec=%llu}"
-#if VERBOSE
-		 ", ru_maxrss=%lu"
-		 ", ru_ixrss=%lu"
-		 ", ru_idrss=%lu"
-		 ", ru_isrss=%lu"
-		 ", ru_minflt=%lu"
-		 ", ru_majflt=%lu"
-		 ", ru_nswap=%lu"
-		 ", ru_inblock=%lu"
-		 ", ru_oublock=%lu"
-		 ", ru_msgsnd=%lu"
-		 ", ru_msgrcv=%lu"
-		 ", ru_nsignals=%lu"
-		 ", ru_nvcsw=%lu"
-		 ", ru_nivcsw=%lu}"
-#else
+		 "{ru_utime={tv_sec=%llu, tv_usec=%llu}"
+		 ", ru_stime={tv_sec=%llu, tv_usec=%llu}"
+# if VERBOSE
+		 ", ru_maxrss=%llu"
+		 ", ru_ixrss=%llu"
+		 ", ru_idrss=%llu"
+		 ", ru_isrss=%llu"
+		 ", ru_minflt=%llu"
+		 ", ru_majflt=%llu"
+		 ", ru_nswap=%llu"
+		 ", ru_inblock=%llu"
+		 ", ru_oublock=%llu"
+		 ", ru_msgsnd=%llu"
+		 ", ru_msgrcv=%llu"
+		 ", ru_nsignals=%llu"
+		 ", ru_nvcsw=%llu"
+		 ", ru_nivcsw=%llu}"
+# else
 		 ", ...}"
-#endif
-		 , (long long) ru->ru_utime.tv_sec
+# endif
+		 , zero_extend_signed_to_ull(ru->ru_utime.tv_sec)
 		 , zero_extend_signed_to_ull(ru->ru_utime.tv_usec)
-		 , (long long) ru->ru_stime.tv_sec
+		 , zero_extend_signed_to_ull(ru->ru_stime.tv_sec)
 		 , zero_extend_signed_to_ull(ru->ru_stime.tv_usec)
-#if VERBOSE
-		 , (long) ru->ru_maxrss
-		 , (long) ru->ru_ixrss
-		 , (long) ru->ru_idrss
-		 , (long) ru->ru_isrss
-		 , (long) ru->ru_minflt
-		 , (long) ru->ru_majflt
-		 , (long) ru->ru_nswap
-		 , (long) ru->ru_inblock
-		 , (long) ru->ru_oublock
-		 , (long) ru->ru_msgsnd
-		 , (long) ru->ru_msgrcv
-		 , (long) ru->ru_nsignals
-		 , (long) ru->ru_nvcsw
-		 , (long) ru->ru_nivcsw
-#endif
+# if VERBOSE
+		 , zero_extend_signed_to_ull(ru->ru_maxrss)
+		 , zero_extend_signed_to_ull(ru->ru_ixrss)
+		 , zero_extend_signed_to_ull(ru->ru_idrss)
+		 , zero_extend_signed_to_ull(ru->ru_isrss)
+		 , zero_extend_signed_to_ull(ru->ru_minflt)
+		 , zero_extend_signed_to_ull(ru->ru_majflt)
+		 , zero_extend_signed_to_ull(ru->ru_nswap)
+		 , zero_extend_signed_to_ull(ru->ru_inblock)
+		 , zero_extend_signed_to_ull(ru->ru_oublock)
+		 , zero_extend_signed_to_ull(ru->ru_msgsnd)
+		 , zero_extend_signed_to_ull(ru->ru_msgrcv)
+		 , zero_extend_signed_to_ull(ru->ru_nsignals)
+		 , zero_extend_signed_to_ull(ru->ru_nvcsw)
+		 , zero_extend_signed_to_ull(ru->ru_nivcsw)
+# endif
 		 );
 	return buf;
 }
 
+static const char *errstr;
+
+static long
+k_wait4(const unsigned int pid, void const *wstatus,
+	const unsigned int options, void const *ru)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+	const kernel_ulong_t arg1 = fill | pid;
+	const kernel_ulong_t arg2 = (uintptr_t) wstatus;
+	const kernel_ulong_t arg3 = fill | options;
+	const kernel_ulong_t arg4 = (uintptr_t) ru;
+	const long rc = syscall(__NR_wait4, arg1, arg2, arg3, arg4, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
+
 static pid_t
-do_wait4(pid_t pid, int *wstatus, int options, struct rusage *ru)
+do_wait4(pid_t pid, int *wstatus, int options, kernel_rusage_t *ru)
 {
 	sigset_t mask = {};
 	sigaddset(&mask, SIGCHLD);
 
 	assert(sigprocmask(SIG_BLOCK, &mask, NULL) == 0);
-	pid_t rc = wait4(pid, wstatus, options, ru);
+	pid_t rc = k_wait4(pid, wstatus, options, ru);
 	assert(sigprocmask(SIG_UNBLOCK, &mask, NULL) == 0);
 	return rc;
 }
@@ -101,12 +122,12 @@ main(void)
 	(void) close(0);
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(int, s);
-	if (wait4(pid, s, WNOHANG|__WALL, NULL))
+	if (k_wait4(pid, s, WNOHANG|__WALL, NULL))
 		perror_msg_and_fail("wait4 #1");
 	tprintf("wait4(%d, %p, WNOHANG|__WALL, NULL) = 0\n", pid, s);
 
-	TAIL_ALLOC_OBJECT_CONST_PTR(struct rusage, rusage);
-	if (wait4(pid, s, WNOHANG|__WALL, rusage))
+	TAIL_ALLOC_OBJECT_CONST_PTR(kernel_rusage_t, rusage);
+	if (k_wait4(pid, s, WNOHANG|__WALL, rusage))
 		perror_msg_and_fail("wait4 #2");
 	tprintf("wait4(%d, %p, WNOHANG|__WALL, %p) = 0\n", pid, s, rusage);
 
@@ -156,12 +177,12 @@ main(void)
 	if (kill(pid, SIGCONT))
 		perror_msg_and_fail("kill(SIGCONT)");
 
-#if defined WCONTINUED && defined WIFCONTINUED
+# if defined WCONTINUED && defined WIFCONTINUED
 	assert(do_wait4(pid, s, WCONTINUED, rusage) == pid);
 	assert(WIFCONTINUED(*s));
 	tprintf("wait4(%d, [{WIFCONTINUED(s)}], WCONTINUED"
 		", %s) = %d\n", pid, sprint_rusage(rusage), pid);
-#endif /* WCONTINUED && WIFCONTINUED */
+# endif /* WCONTINUED && WIFCONTINUED */
 
 	assert(write(1, "", 1) == 1);
 	(void) close(1);
@@ -171,10 +192,16 @@ main(void)
 	tprintf("wait4(%d, [{WIFEXITED(s) && WEXITSTATUS(s) == 0}], 0"
 		", %s) = %d\n", pid, sprint_rusage(rusage), pid);
 
-	assert(wait4(-1, s, WNOHANG|WSTOPPED|__WALL, rusage) == -1);
-	tprintf("wait4(-1, %p, WNOHANG|WSTOPPED|__WALL, %p) = -1 %s (%m)\n",
-		s, rusage, errno2name());
+	assert(k_wait4(-1, s, WNOHANG|WSTOPPED|__WALL, rusage) == -1);
+	tprintf("wait4(-1, %p, WNOHANG|WSTOPPED|__WALL, %p) = %s\n",
+		s, rusage, errstr);
 
 	tprintf("%s\n", "+++ exited with 0 +++");
 	return 0;
 }
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_wait4")
+
+#endif /* __NR_wait4 */
diff -pruN 5.5-3/tests-m32/waitid.c 5.9-0ubuntu2/tests-m32/waitid.c
--- 5.5-3/tests-m32/waitid.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/waitid.c	2020-07-17 08:00:00.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of waitid syscall.
  *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -15,11 +15,11 @@
 #include <string.h>
 #include <unistd.h>
 #include <sys/wait.h>
-#include <sys/resource.h>
+#include "kernel_rusage.h"
 #include "scno.h"
 
 static const char *
-sprint_rusage(const struct rusage *const ru)
+sprint_rusage(const kernel_rusage_t *const ru)
 {
 	static char buf[1024];
 	snprintf(buf, sizeof(buf),
@@ -103,8 +103,8 @@ sprint_siginfo(const siginfo_t *const si
 	snprintf(buf, sizeof(buf),
 		 "{si_signo=SIGCHLD"
 		 ", si_code=%s"
-		 ", si_pid=%u"
-		 ", si_uid=%u"
+		 ", si_pid=%d"
+		 ", si_uid=%d"
 		 ", si_status=%s"
 		 ", si_utime=%llu"
 		 ", si_stime=%llu}",
@@ -128,7 +128,7 @@ do_waitid(const unsigned int idtype,
 	  const unsigned int id,
 	  const siginfo_t *const infop,
 	  const unsigned int options,
-	  const struct rusage *const rusage)
+	  const kernel_rusage_t *const rusage)
 {
 	sigset_t mask = {};
 	sigaddset(&mask, SIGCHLD);
@@ -169,7 +169,7 @@ main(void)
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(siginfo_t, sinfo);
 	memset(sinfo, 0, sizeof(*sinfo));
-	TAIL_ALLOC_OBJECT_CONST_PTR(struct rusage, rusage);
+	TAIL_ALLOC_OBJECT_CONST_PTR(kernel_rusage_t, rusage);
 	if (do_waitid(P_PID, pid, sinfo, WNOHANG|WEXITED|WSTOPPED, rusage))
 		perror_msg_and_fail("waitid #2");
 	tprintf("waitid(P_PID, %d, {}, WNOHANG|WEXITED|WSTOPPED, %s) = 0\n",
diff -pruN 5.5-3/tests-m32/xetitimer.c 5.9-0ubuntu2/tests-m32/xetitimer.c
--- 5.5-3/tests-m32/xetitimer.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/xetitimer.c	2020-06-01 14:15:16.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of setitimer and getitimer syscalls.
  *
  * Copyright (c) 2015-2018 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -14,11 +14,17 @@
 #include <sys/time.h>
 #include <unistd.h>
 #include "scno.h"
+#include "kernel_timeval.h"
+
+typedef struct {
+	kernel_old_timeval_t it_interval;
+	kernel_old_timeval_t it_value;
+} kernel_old_itimerval_t;
 
 int
 main(void)
 {
-	static const struct itimerval new = {
+	static const kernel_old_itimerval_t new = {
 		.it_interval = { 0xc0de1, 0xc0de2 },
 		.it_value = { 0xc0de3, 0xc0de4 }
 	};
@@ -27,12 +33,12 @@ main(void)
 	static const kernel_ulong_t bogus_timer =
 		(kernel_ulong_t) 0xfacefeeddeadbeefULL;
 
-	TAIL_ALLOC_OBJECT_CONST_PTR(struct itimerval, p_old);
-	struct itimerval *const p_new = tail_memdup(&new, sizeof(new));
+	TAIL_ALLOC_OBJECT_CONST_PTR(kernel_old_itimerval_t, p_old);
+	kernel_old_itimerval_t *const p_new = tail_memdup(&new, sizeof(new));
 	void *const efault = tail_alloc(sizeof(new) - 8);
 	long rc;
 
-	if (setitimer(ITIMER_REAL, p_new, NULL))
+	if (syscall(__NR_setitimer, ITIMER_REAL, p_new, NULL))
 		perror_msg_and_skip("setitimer");
 	printf("setitimer(ITIMER_REAL"
 	       ", {it_interval={tv_sec=%lld, tv_usec=%llu}"
@@ -44,7 +50,7 @@ main(void)
 	       zero_extend_signed_to_ull(new.it_value.tv_usec));
 
 	fill_memory(p_old, sizeof(*p_old));
-	if (getitimer(ITIMER_REAL, p_old))
+	if (syscall(__NR_getitimer, ITIMER_REAL, p_old))
 		perror_msg_and_skip("getitimer");
 	printf("getitimer(ITIMER_REAL"
 	       ", {it_interval={tv_sec=%lld, tv_usec=%llu}"
@@ -55,7 +61,7 @@ main(void)
 	       zero_extend_signed_to_ull(p_old->it_value.tv_usec));
 
 	fill_memory(p_old, sizeof(*p_old));
-	setitimer(ITIMER_REAL, p_new, p_old);
+	syscall(__NR_setitimer, ITIMER_REAL, p_new, p_old);
 	printf("setitimer(ITIMER_REAL"
 	       ", {it_interval={tv_sec=%lld, tv_usec=%llu}"
 	       ", it_value={tv_sec=%lld, tv_usec=%llu}}"
@@ -70,10 +76,10 @@ main(void)
 	       (long long) p_old->it_value.tv_sec,
 	       zero_extend_signed_to_ull(p_old->it_value.tv_usec));
 
-	rc = getitimer(ITIMER_REAL, efault);
+	rc = syscall(__NR_getitimer, ITIMER_REAL, efault);
 	printf("getitimer(ITIMER_REAL, %p) = %s\n", efault, sprintrc(rc));
 
-	rc = setitimer(ITIMER_REAL, p_new, efault);
+	rc = syscall(__NR_setitimer, ITIMER_REAL, p_new, efault);
 	printf("setitimer(ITIMER_REAL"
 	       ", {it_interval={tv_sec=%lld, tv_usec=%llu}"
 	       ", it_value={tv_sec=%lld, tv_usec=%llu}}, %p) = %s\n",
@@ -83,7 +89,7 @@ main(void)
 	       zero_extend_signed_to_ull(new.it_value.tv_usec),
 	       efault, sprintrc(rc));
 
-	rc = setitimer(ITIMER_REAL, efault, p_old);
+	rc = syscall(__NR_setitimer, ITIMER_REAL, efault, p_old);
 	printf("setitimer(ITIMER_REAL, %p, %p) = %s\n",
 	       efault, p_old, sprintrc(rc));
 
@@ -147,10 +153,12 @@ main(void)
 
 	p_new->it_interval.tv_sec = 0xdeadbeefU;
 	p_new->it_interval.tv_usec = 0xfacefeedU;
-	p_new->it_value.tv_sec = (time_t) 0xcafef00ddeadbeefLL;
-	p_new->it_value.tv_usec = (suseconds_t) 0xbadc0dedfacefeedLL;
+	p_new->it_value.tv_sec =
+		(typeof(p_new->it_value.tv_sec)) 0xcafef00ddeadbeefLL;
+	p_new->it_value.tv_usec =
+		(typeof(p_new->it_value.tv_usec)) 0xbadc0dedfacefeedLL;
 
-	rc = setitimer(ITIMER_REAL, p_new, p_old);
+	rc = syscall(__NR_setitimer, ITIMER_REAL, p_new, p_old);
 	printf("setitimer(ITIMER_REAL"
 	       ", {it_interval={tv_sec=%lld, tv_usec=%llu}"
 	       ", it_value={tv_sec=%lld, tv_usec=%llu}}, %p) = %s\n",
diff -pruN 5.5-3/tests-m32/xetpgid.c 5.9-0ubuntu2/tests-m32/xetpgid.c
--- 5.5-3/tests-m32/xetpgid.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/xetpgid.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,7 +2,7 @@
  * This file is part of xetpgid strace test.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,6 +10,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #if defined __NR_getpgid && defined __NR_setpgid
 
@@ -19,13 +20,21 @@
 int
 main(void)
 {
-	const int pid = getpid();
-	long rc = syscall(__NR_getpgid, F8ILL_KULONG_MASK | pid);
-	printf("getpgid(%d) = %ld\n", pid, rc);
+	PIDNS_TEST_INIT;
 
-	rc = syscall(__NR_setpgid, F8ILL_KULONG_MASK, F8ILL_KULONG_MASK | pid);
-	printf("setpgid(0, %d) = %ld\n", pid, rc);
+	const int pid = getpid();
+	long pgid = syscall(__NR_getpgid, F8ILL_KULONG_MASK | pid);
+	pidns_print_leader();
+	printf("getpgid(%d%s) = %ld%s\n", pid, pidns_pid2str(PT_TGID),
+		pgid, pidns_pid2str(PT_PGID));
+
+	long rc = syscall(__NR_setpgid, F8ILL_KULONG_MASK,
+		F8ILL_KULONG_MASK | pgid);
+	pidns_print_leader();
+	printf("setpgid(0, %ld%s) = %s\n", pgid, pidns_pid2str(PT_PGID),
+		sprintrc(rc));
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/xetpgid--pidns-translation.c 5.9-0ubuntu2/tests-m32/xetpgid--pidns-translation.c
--- 5.5-3/tests-m32/xetpgid--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/xetpgid--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "xetpgid.c"
diff -pruN 5.5-3/tests-m32/xetpgid--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/xetpgid--pidns-translation.gen.test
--- 5.5-3/tests-m32/xetpgid--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/xetpgid--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (xetpgid--pidns-translation test_pidns -a11 -e trace=getpgid,setpgid); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a11 -e trace=getpgid,setpgid
diff -pruN 5.5-3/tests-m32/xetpriority.c 5.9-0ubuntu2/tests-m32/xetpriority.c
--- 5.5-3/tests-m32/xetpriority.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/xetpriority.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -7,6 +7,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #if defined __NR_getpriority && defined __NR_setpriority
 
@@ -17,15 +18,30 @@
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	const int pid = getpid();
+	const int pgid = getpgid(0);
+
 	long rc = syscall(__NR_getpriority, PRIO_PROCESS,
 			  F8ILL_KULONG_MASK | pid);
-	printf("getpriority(PRIO_PROCESS, %d) = %ld\n", pid, rc);
+	pidns_print_leader();
+	printf("getpriority(PRIO_PROCESS, %d%s) = %ld\n",
+		pid, pidns_pid2str(PT_TGID), rc);
 
 	rc = syscall(__NR_setpriority, PRIO_PROCESS,
 		     F8ILL_KULONG_MASK | pid, F8ILL_KULONG_MASK);
-	printf("setpriority(PRIO_PROCESS, %d, 0) = %s\n", pid, sprintrc(rc));
+	pidns_print_leader();
+	printf("setpriority(PRIO_PROCESS, %d%s, 0) = %s\n",
+		pid, pidns_pid2str(PT_TGID), sprintrc(rc));
+
+	rc = syscall(__NR_getpriority, PRIO_PGRP,
+			  F8ILL_KULONG_MASK | pgid);
+	pidns_print_leader();
+	printf("getpriority(PRIO_PGRP, %d%s) = %ld\n",
+		pgid, pidns_pid2str(PT_PGID), rc);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/xetpriority.gen.test 5.9-0ubuntu2/tests-m32/xetpriority.gen.test
--- 5.5-3/tests-m32/xetpriority.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/xetpriority.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -1,4 +1,4 @@
 #!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (xetpriority -a29 -e trace=getpriority,setpriority); do not edit.
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (xetpriority -a27 -e trace=getpriority,setpriority); do not edit.
 . "${srcdir=.}/init.sh"
-run_strace_match_diff -a29 -e trace=getpriority,setpriority
+run_strace_match_diff -a27 -e trace=getpriority,setpriority
diff -pruN 5.5-3/tests-m32/xetpriority--pidns-translation.c 5.9-0ubuntu2/tests-m32/xetpriority--pidns-translation.c
--- 5.5-3/tests-m32/xetpriority--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/xetpriority--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "xetpriority.c"
diff -pruN 5.5-3/tests-m32/xetpriority--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/xetpriority--pidns-translation.gen.test
--- 5.5-3/tests-m32/xetpriority--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/xetpriority--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (xetpriority--pidns-translation test_pidns -a27 -e trace=getpriority,setpriority); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a27 -e trace=getpriority,setpriority
diff -pruN 5.5-3/tests-m32/xet_robust_list.c 5.9-0ubuntu2/tests-m32/xet_robust_list.c
--- 5.5-3/tests-m32/xet_robust_list.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/xet_robust_list.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -8,6 +8,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #if defined __NR_get_robust_list && defined __NR_set_robust_list
 
@@ -30,27 +31,36 @@ sprintaddr(void *addr)
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	const pid_t pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
 	const long long_pid = (unsigned long) (0xdeadbeef00000000LL | pid);
 	TAIL_ALLOC_OBJECT_CONST_PTR(void *, p_head);
 	TAIL_ALLOC_OBJECT_CONST_PTR(size_t, p_len);
 
 	if (syscall(__NR_get_robust_list, long_pid, p_head, p_len))
 		perror_msg_and_skip("get_robust_list");
-	printf("get_robust_list(%d, [%s], [%lu]) = 0\n",
-	       (int) pid, sprintaddr(*p_head), (unsigned long) *p_len);
+	pidns_print_leader();
+	printf("get_robust_list(%d%s, [%s], [%lu]) = 0\n",
+	       pid, pid_str, sprintaddr(*p_head),
+	       (unsigned long) *p_len);
 
 	void *head = tail_alloc(*p_len);
 	if (syscall(__NR_set_robust_list, head, *p_len))
 		perror_msg_and_skip("set_robust_list");
+	pidns_print_leader();
 	printf("set_robust_list(%p, %lu) = 0\n",
 	       head, (unsigned long) *p_len);
 
 	if (syscall(__NR_get_robust_list, long_pid, p_head, p_len))
 		perror_msg_and_skip("get_robust_list");
-	printf("get_robust_list(%d, [%s], [%lu]) = 0\n",
-	       (int) pid, sprintaddr(*p_head), (unsigned long) *p_len);
+	pidns_print_leader();
+	printf("get_robust_list(%d%s, [%s], [%lu]) = 0\n",
+	       pid, pid_str, sprintaddr(*p_head),
+	       (unsigned long) *p_len);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-m32/xet_robust_list--pidns-translation.c 5.9-0ubuntu2/tests-m32/xet_robust_list--pidns-translation.c
--- 5.5-3/tests-m32/xet_robust_list--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/xet_robust_list--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "xet_robust_list.c"
diff -pruN 5.5-3/tests-m32/xet_robust_list--pidns-translation.gen.test 5.9-0ubuntu2/tests-m32/xet_robust_list--pidns-translation.gen.test
--- 5.5-3/tests-m32/xet_robust_list--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/xet_robust_list--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (xet_robust_list--pidns-translation test_pidns -a24 -e trace=get_robust_list,set_robust_list); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a24 -e trace=get_robust_list,set_robust_list
diff -pruN 5.5-3/tests-m32/xettimeofday.c 5.9-0ubuntu2/tests-m32/xettimeofday.c
--- 5.5-3/tests-m32/xettimeofday.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/xettimeofday.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,19 +1,23 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-#include <assert.h>
-#include <stdio.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <sys/time.h>
 #include "scno.h"
 
+#ifdef __NR_gettimeofday
+
+# include <assert.h>
+# include <stdio.h>
+# include <stdint.h>
+# include <unistd.h>
+# include <sys/time.h>
+# include "scno.h"
+
 int
 main(void)
 {
@@ -64,3 +68,9 @@ main(void)
 	puts("+++ exited with 0 +++");
 	return 0;
 }
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_gettimeofday")
+
+#endif /* __NR_gettimeofday */
diff -pruN 5.5-3/tests-m32/xgetdents.c 5.9-0ubuntu2/tests-m32/xgetdents.c
--- 5.5-3/tests-m32/xgetdents.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/xgetdents.c	2020-04-11 18:09:11.000000000 +0000
@@ -0,0 +1,141 @@
+/*
+ * Check decoding of getdents and getdents64 syscalls.
+ *
+ * Copyright (c) 2015-2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include <dirent.h>
+#include <fcntl.h>
+#include <stdio.h>
+#include <unistd.h>
+#include <sys/stat.h>
+#include "kernel_dirent.h"
+#include "print_fields.h"
+
+#if VERBOSE
+static const char *
+str_d_type(const unsigned char d_type)
+{
+	switch (d_type) {
+		case DT_DIR:
+			return "DT_DIR";
+		case DT_REG:
+			return "DT_REG";
+		default:
+			return "DT_UNKNOWN";
+	}
+}
+
+static void
+print_dirent(const kernel_dirent_type *d);
+#endif
+
+static const char *errstr;
+
+static long
+k_getdents(const unsigned int fd,
+	   const void *dirp,
+	   const unsigned int count)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+	const kernel_ulong_t arg1 = fill | fd;
+	const kernel_ulong_t arg2 = (uintptr_t) dirp;
+	const kernel_ulong_t arg3 = fill | count;
+	const long rc = syscall(NR_getdents, arg1, arg2, arg3, bad, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
+
+static void
+ls(int fd, char *buf, unsigned int size)
+{
+	long rc;
+	while ((rc = k_getdents(fd, buf, size))) {
+		if (rc < 0)
+			perror_msg_and_skip(STR_getdents);
+		printf("%s(%d, ", STR_getdents, fd);
+#if VERBOSE
+		printf("[");
+#else
+		unsigned long entries = 0;
+#endif
+		kernel_dirent_type *d;
+		for (long i = 0; i < rc; i += d->d_reclen) {
+			d = (kernel_dirent_type *) &buf[i];
+#if VERBOSE
+			if (i)
+				printf(", ");
+			print_dirent(d);
+#else
+			++entries;
+#endif
+		}
+#if VERBOSE
+		printf("]");
+#else
+		printf("%p /* %lu entries */", buf, entries);
+#endif
+		printf(", %u) = %ld\n", size, rc);
+	}
+#if VERBOSE
+	printf("%s(%d, [], %u) = 0\n", STR_getdents, fd, size);
+#else
+	printf("%s(%d, %p /* 0 entries */, %u) = 0\n",
+	       STR_getdents, fd, buf, size);
+#endif
+}
+
+int
+main(void)
+{
+	static const char dot[] = ".";
+	static const char dot_dot[] = "..";
+	static const char dname[] = STR_getdents
+#if VERBOSE
+		"-v"
+#endif
+		".test.tmp.dir";
+	static const char fname[] =
+		"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
+		"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
+		"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
+		"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
+		"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
+		"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
+		"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
+		"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nZ";
+
+	if (mkdir(dname, 0700))
+		perror_msg_and_fail("mkdir: %s", dname);
+	if (chdir(dname))
+		perror_msg_and_fail("chdir: %s", dname);
+	int fd = creat(fname, 0600);
+	if (fd < 0)
+		perror_msg_and_fail("creat: %s", fname);
+	if (close(fd))
+		perror_msg_and_fail("close: %s", fname);
+	fd = open(dot, O_RDONLY | O_DIRECTORY);
+	if (fd < 0)
+		perror_msg_and_fail("open: %s", dot);
+
+	unsigned int count = 0xdeadbeefU;
+	k_getdents(-1U, NULL, count);
+	printf("%s(-1, NULL, %u) = %s\n", STR_getdents, count, errstr);
+
+	static char buf[8192];
+	ls(fd, buf, sizeof(buf));
+
+	if (unlink(fname))
+		perror_msg_and_fail("unlink: %s", fname);
+	if (chdir(dot_dot))
+		perror_msg_and_fail("chdir: %s", dot_dot);
+	if (rmdir(dname))
+		perror_msg_and_fail("rmdir: %s", dname);
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
diff -pruN 5.5-3/tests-m32/xmalloc_for_tests.c 5.9-0ubuntu2/tests-m32/xmalloc_for_tests.c
--- 5.5-3/tests-m32/xmalloc_for_tests.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/xmalloc_for_tests.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define error_msg_and_die error_msg_and_fail
+#include "xmalloc.c"
diff -pruN 5.5-3/tests-m32/xstatx.c 5.9-0ubuntu2/tests-m32/xstatx.c
--- 5.5-3/tests-m32/xstatx.c	2019-07-11 17:51:22.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/xstatx.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -468,12 +468,12 @@ main(void)
 	TEST_SYSCALL_STATX_FLAGS_STR = old_flags_str;
 
 	SET_MASK_INVOKE(0, "0");
-	SET_MASK_INVOKE(0xfffff000U, "0xfffff000 /* STATX_??? */");
+	SET_MASK_INVOKE(0xffffe000U, "0xffffe000 /* STATX_??? */");
 
 	SET_MASK_INVOKE(0xfffffffbU,
 		"STATX_TYPE|STATX_MODE|STATX_UID|STATX_GID|STATX_ATIME|"
 		"STATX_MTIME|STATX_CTIME|STATX_INO|STATX_SIZE|STATX_BLOCKS|"
-		"STATX_BTIME|0xfffff000");
+		"STATX_BTIME|STATX_MNT_ID|0xffffe000");
 
 	SET_MASK_INVOKE(STATX_UID, "STATX_UID");
 
diff -pruN 5.5-3/tests-m32/zeroargc.c 5.9-0ubuntu2/tests-m32/zeroargc.c
--- 5.5-3/tests-m32/zeroargc.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-m32/zeroargc.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
  * Execute an executable with zero argc and specified environment.
  *
  * Copyright (c) 2017-2018 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
diff -pruN 5.5-3/tests-mx32/bexecve.test 5.9-0ubuntu2/tests-mx32/bexecve.test
--- 5.5-3/tests-mx32/bexecve.test	2019-11-28 19:30:05.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/bexecve.test	2020-04-03 22:58:26.000000000 +0000
@@ -3,7 +3,7 @@
 # Check -bexecve behavior.
 #
 # Copyright (c) 2015 Dmitry V. Levin <ldv@altlinux.org>
-# Copyright (c) 2015-2019 The strace developers.
+# Copyright (c) 2015-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -16,27 +16,26 @@ run_strace_redir()
 	$STRACE "$@" 2> "$LOG"
 }
 
-run_strace_redir -enone ../set_ptracer_any true ||
+run_strace_redir --quiet=personality -enone ../set_ptracer_any true ||
 	dump_log_and_fail_with "$STRACE $args: unexpected exit status"
 
-run_strace_redir -enone ../set_ptracer_any false
+run_strace_redir --quiet=personality -enone ../set_ptracer_any false
 [ $? -eq 1 ] ||
 	dump_log_and_fail_with "$STRACE $args: unexpected exit status"
 
-run_strace_redir -bexecve -enone ../set_ptracer_any false ||
+run_strace_redir --quiet=personality -bexecve -enone ../set_ptracer_any false ||
 	dump_log_and_fail_with "$STRACE $args: unexpected exit status"
 
 pattern_detached='[^:]*strace: Process [1-9][0-9]* detached'
-pattern_personality='[^:]*strace: \[ Process PID=[1-9][0-9]* runs in .* mode. \]'
 
 LC_ALL=C grep -x "$pattern_detached" "$LOG" > /dev/null ||
 	dump_log_and_fail_with "$STRACE $args: output mismatch"
 
-if LC_ALL=C grep -E -v -x "($pattern_detached|$pattern_personality)" "$LOG" > /dev/null; then
+if LC_ALL=C grep -E -v -x "$pattern_detached" "$LOG" > /dev/null; then
 	dump_log_and_fail_with "$STRACE $args: unexpected output"
 fi
 
-run_strace_redir --seccomp-bpf -bexecve -enone ../set_ptracer_any false ||
+run_strace_redir --quiet=personality --seccomp-bpf -bexecve -enone ../set_ptracer_any false ||
 	dump_log_and_fail_with "$STRACE $args: unexpected exit status"
 
 pattern_seccomp='[^:]*strace: --seccomp-bpf is not enabled because it is not compatible with -b'
@@ -45,7 +44,7 @@ LC_ALL=C grep -x "$pattern_detached" "$L
 LC_ALL=C grep -x "$pattern_seccomp" "$LOG" > /dev/null ||
 	dump_log_and_fail_with "$STRACE $args: output mismatch"
 
-pattern_all="$pattern_detached|$pattern_seccomp|$pattern_personality"
+pattern_all="$pattern_detached|$pattern_seccomp"
 if LC_ALL=C grep -E -v -x "$pattern_all" "$LOG" > /dev/null; then
 	dump_log_and_fail_with "$STRACE $args: unexpected output"
 fi
diff -pruN 5.5-3/tests-mx32/bpf.c 5.9-0ubuntu2/tests-mx32/bpf.c
--- 5.5-3/tests-mx32/bpf.c	2019-12-10 09:44:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/bpf.c	2020-09-06 08:00:00.000000000 +0000
@@ -2,7 +2,7 @@
  * Check bpf syscall decoding.
  *
  * Copyright (c) 2015-2017 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -27,6 +27,7 @@
 
 #include "xlat.h"
 #include "xlat/bpf_commands.h"
+#include "xlat/bpf_map_types.h"
 #include "xlat/bpf_prog_types.h"
 
 #if defined MPERS_IS_m32 || SIZEOF_KERNEL_LONG_T > 4
@@ -42,6 +43,10 @@
 # define BIG_ADDR_MAYBE(addr_)
 #endif
 
+#ifndef FD0_PATH
+# define FD0_PATH ""
+#endif
+
 #ifndef HAVE_STRUCT_BPF_INSN
 struct bpf_insn {
 	uint8_t	code;
@@ -75,6 +80,11 @@ union bpf_attr_data {
 	BPF_ATTR_DATA_FIELD(BPF_BTF_GET_FD_BY_ID);
 	BPF_ATTR_DATA_FIELD(BPF_TASK_FD_QUERY);
 	BPF_ATTR_DATA_FIELD(BPF_MAP_FREEZE);
+	BPF_ATTR_DATA_FIELD(BPF_MAP_LOOKUP_BATCH);
+	BPF_ATTR_DATA_FIELD(BPF_MAP_UPDATE_BATCH);
+	BPF_ATTR_DATA_FIELD(BPF_MAP_DELETE_BATCH);
+	BPF_ATTR_DATA_FIELD(BPF_LINK_CREATE);
+	BPF_ATTR_DATA_FIELD(BPF_LINK_UPDATE);
 	char char_data[256];
 };
 
@@ -109,8 +119,8 @@ sys_bpf(kernel_ulong_t cmd, kernel_ulong
 
 #ifdef INJECT_RETVAL
 	if (rc != INJECT_RETVAL)
-		error_msg_and_fail("Got a return value of %ld != %d",
-				   rc, INJECT_RETVAL);
+		error_msg_and_fail("Got a return value of %ld != %ld",
+				   rc, (long) INJECT_RETVAL);
 
 	static char inj_errstr[4096];
 
@@ -251,6 +261,8 @@ init_BPF_MAP_CREATE_attr7(struct bpf_att
 	attr->map_ifindex = ifindex_lo();
 }
 
+static_assert(ARRAY_SIZE(bpf_map_types_xdata) == 28,
+	      "The map_type for tests 1 and 2 below needs to be updated");
 static struct bpf_attr_check BPF_MAP_CREATE_checks[] = {
 	{
 		.data = { .BPF_MAP_CREATE_data = { .map_type = 2 } },
@@ -260,7 +272,7 @@ static struct bpf_attr_check BPF_MAP_CRE
 	},
 	{ /* 1 */
 		.data = { .BPF_MAP_CREATE_data = {
-			.map_type = 20,
+			.map_type = 27,
 			.key_size = 4,
 			.value_size = 8,
 			.max_entries = 256,
@@ -270,7 +282,7 @@ static struct bpf_attr_check BPF_MAP_CRE
 			.map_name = "0123456789abcde",
 		} },
 		.size = offsetof(struct BPF_MAP_CREATE_struct, map_name) + 8,
-		.str = "map_type=BPF_MAP_TYPE_REUSEPORT_SOCKARRAY, key_size=4"
+		.str = "map_type=BPF_MAP_TYPE_RINGBUF, key_size=4"
 		       ", value_size=8, max_entries=256"
 		       ", map_flags=BPF_F_NO_PREALLOC|BPF_F_NO_COMMON_LRU"
 				   "|BPF_F_NUMA_NODE|BPF_F_RDONLY|BPF_F_WRONLY"
@@ -282,7 +294,7 @@ static struct bpf_attr_check BPF_MAP_CRE
 	},
 	{ /* 2 */
 		.data = { .BPF_MAP_CREATE_data = {
-			.map_type = 26,
+			.map_type = 28,
 			.key_size = 0xface1e55,
 			.value_size = 0xbadc0ded,
 			.max_entries = 0xbeefcafe,
@@ -293,7 +305,7 @@ static struct bpf_attr_check BPF_MAP_CRE
 			.map_ifindex = 3141592653,
 		} },
 		.size = offsetofend(struct BPF_MAP_CREATE_struct, map_ifindex),
-		.str = "map_type=0x1a /* BPF_MAP_TYPE_??? */"
+		.str = "map_type=0x1c /* BPF_MAP_TYPE_??? */"
 		       ", key_size=4207812181, value_size=3134983661"
 		       ", max_entries=3203386110"
 		       ", map_flags=0xfffff800 /* BPF_F_??? */"
@@ -422,13 +434,35 @@ static struct bpf_attr_check BPF_MAP_CRE
 		       ", value_size=0"
 		       ", max_entries=0"
 		       ", map_flags=0"
-		       ", inner_map_fd=0"
+		       ", inner_map_fd=0" FD0_PATH
 		       ", map_name=\"\""
 		       ", map_ifindex=0"
 		       ", btf_fd=-1159983635"
 		       ", btf_key_type_id=4207869677"
 		       ", btf_value_type_id=3405705229"
 	},
+	{ /* 9 */
+		.data = { .BPF_MAP_CREATE_data = {
+			.btf_fd = 0xbadc0ded,
+			.btf_key_type_id = 0xfacefeed,
+			.btf_value_type_id = 0xcafef00d,
+			.btf_vmlinux_value_type_id = 0xdeadc0de,
+		} },
+		.size = offsetofend(struct BPF_MAP_CREATE_struct,
+				    btf_vmlinux_value_type_id),
+		.str = "map_type=BPF_MAP_TYPE_UNSPEC"
+		       ", key_size=0"
+		       ", value_size=0"
+		       ", max_entries=0"
+		       ", map_flags=0"
+		       ", inner_map_fd=0" FD0_PATH
+		       ", map_name=\"\""
+		       ", map_ifindex=0"
+		       ", btf_fd=-1159983635"
+		       ", btf_key_type_id=4207869677"
+		       ", btf_value_type_id=3405705229"
+		       ", btf_vmlinux_value_type_id=3735929054"
+	},
 };
 
 static const struct bpf_attr_check BPF_MAP_LOOKUP_ELEM_checks[] = {
@@ -606,7 +640,7 @@ print_BPF_PROG_LOAD_attr4(const struct b
 	       license, IFINDEX_LO_STR);
 }
 
-static_assert(ARRAY_SIZE(bpf_prog_types_xdata) == 27,
+static_assert(ARRAY_SIZE(bpf_prog_types_xdata) == 31,
 	      "The prog_type for test 5 below needs to be updated");
 static struct bpf_attr_check BPF_PROG_LOAD_checks[] = {
 	{
@@ -617,7 +651,7 @@ static struct bpf_attr_check BPF_PROG_LO
 	},
 	{ /* 1 */
 		.data = { .BPF_PROG_LOAD_data = {
-			.prog_type = 27,
+			.prog_type = 31,
 			.insn_cnt = 0xbadc0ded,
 			.insns = 0,
 			.license = 0,
@@ -628,7 +662,7 @@ static struct bpf_attr_check BPF_PROG_LO
 			.prog_flags = 0,
 		} },
 		.size = offsetofend(struct BPF_PROG_LOAD_struct, prog_flags),
-		.str = "prog_type=0x1b /* BPF_PROG_TYPE_??? */"
+		.str = "prog_type=0x1f /* BPF_PROG_TYPE_??? */"
 		       ", insn_cnt=3134983661, insns=NULL, license=NULL"
 		       ", log_level=42, log_size=3141592653, log_buf=NULL"
 		       ", kern_version=KERNEL_VERSION(51966, 240, 13)"
@@ -691,7 +725,7 @@ static struct bpf_attr_check BPF_PROG_LO
 	},
 	{ /* 5 */
 		.data = { .BPF_PROG_LOAD_data = {
-			.prog_type = 26,
+			.prog_type = 30,
 			.insn_cnt = 0xbadc0ded,
 			.insns = 0xffffffff00000000,
 			.license = 0xffffffff00000000,
@@ -703,7 +737,7 @@ static struct bpf_attr_check BPF_PROG_LO
 			.prog_name = "fedcba987654321",
 		} },
 		.size = offsetofend(struct BPF_PROG_LOAD_struct, prog_name),
-		.str = "prog_type=BPF_PROG_TYPE_TRACING"
+		.str = "prog_type=BPF_PROG_TYPE_SK_LOOKUP"
 		       ", insn_cnt=3134983661"
 		       ", insns=" BIG_ADDR("0xffffffff00000000", "NULL")
 		       ", license=" BIG_ADDR("0xffffffff00000000", "NULL")
@@ -764,7 +798,7 @@ static struct bpf_attr_check BPF_OBJ_PIN
 	{
 		.data = { .BPF_OBJ_PIN_data = { .pathname = 0 } },
 		.size = offsetofend(struct BPF_OBJ_PIN_struct, pathname),
-		.str = "pathname=NULL, bpf_fd=0"
+		.str = "pathname=NULL, bpf_fd=0" FD0_PATH
 	},
 	{
 		.data = { .BPF_OBJ_PIN_data = {
@@ -772,7 +806,7 @@ static struct bpf_attr_check BPF_OBJ_PIN
 		} },
 		.size = offsetofend(struct BPF_OBJ_PIN_struct, pathname),
 		.str = "pathname=" BIG_ADDR("0xffffffffffffffff", "0xffffffff")
-		       ", bpf_fd=0",
+		       ", bpf_fd=0" FD0_PATH,
 	},
 	{
 		.data = { .BPF_OBJ_PIN_data = { .bpf_fd = -1 } },
@@ -798,7 +832,7 @@ static const struct bpf_attr_check BPF_P
 	{
 		.data = { .BPF_PROG_ATTACH_data = { .target_fd = -1 } },
 		.size = offsetofend(struct BPF_PROG_ATTACH_struct, target_fd),
-		.str = "target_fd=-1, attach_bpf_fd=0"
+		.str = "target_fd=-1, attach_bpf_fd=0" FD0_PATH
 		       ", attach_type=BPF_CGROUP_INET_INGRESS, attach_flags=0"
 	},
 	{
@@ -806,13 +840,28 @@ static const struct bpf_attr_check BPF_P
 			.target_fd = -1,
 			.attach_bpf_fd = -2,
 			.attach_type = 2,
-			.attach_flags = 1
+			.attach_flags = 7
 		} },
 		.size = offsetofend(struct BPF_PROG_ATTACH_struct, attach_flags),
 		.str = "target_fd=-1, attach_bpf_fd=-2"
 		       ", attach_type=BPF_CGROUP_INET_SOCK_CREATE"
-		       ", attach_flags=BPF_F_ALLOW_OVERRIDE"
-	}
+		       ", attach_flags=BPF_F_ALLOW_OVERRIDE|BPF_F_ALLOW_MULTI"
+				       "|BPF_F_REPLACE"
+	},
+	{
+		.data = { .BPF_PROG_ATTACH_data = {
+			.target_fd = -1,
+			.attach_bpf_fd = -2,
+			.attach_type = 2,
+			.attach_flags = 0xf8,
+			.replace_bpf_fd = -3,
+		} },
+		.size = offsetofend(struct BPF_PROG_ATTACH_struct, replace_bpf_fd),
+		.str = "target_fd=-1, attach_bpf_fd=-2"
+		       ", attach_type=BPF_CGROUP_INET_SOCK_CREATE"
+		       ", attach_flags=0xf8 /* BPF_F_??? */"
+		       ", replace_bpf_fd=-3"
+	},
 };
 
 
@@ -1028,8 +1077,8 @@ print_BPF_PROG_QUERY_attr4(const struct
 	printf("query={target_fd=-1153374643"
 	       ", attach_type=0xfeedface /* BPF_??? */"
 	       ", query_flags=BPF_F_QUERY_EFFECTIVE|0xdeadf00c"
-	       ", attach_flags=BPF_F_ALLOW_MULTI|0xbeefcafc"
-#if defined(INJECT_RETVAL) && INJECT_RETVAL > 0
+	       ", attach_flags=BPF_F_ALLOW_MULTI|BPF_F_REPLACE|0xbeefcaf8"
+#if defined(INJECT_RETVAL)
 	       ", prog_ids=[0, 1, 4294967295, 2718281828], prog_cnt=4}"
 #else
 	       ", prog_ids=%p, prog_cnt=4}", prog_load_ids_ptr
@@ -1056,8 +1105,8 @@ print_BPF_PROG_QUERY_attr5(const struct
 	printf("query={target_fd=-1153374643"
 	       ", attach_type=0xfeedface /* BPF_??? */"
 	       ", query_flags=BPF_F_QUERY_EFFECTIVE|0xdeadf00c"
-	       ", attach_flags=BPF_F_ALLOW_MULTI|0xbeefcafc"
-#if defined(INJECT_RETVAL) && INJECT_RETVAL > 0
+	       ", attach_flags=BPF_F_ALLOW_MULTI|BPF_F_REPLACE|0xbeefcaf8"
+#if defined(INJECT_RETVAL)
 	       ", prog_ids=[0, 1, 4294967295, 2718281828, ... /* %p */]"
 	       ", prog_cnt=5}",
 	       prog_load_ids_ptr + ARRAY_SIZE(prog_load_ids)
@@ -1078,13 +1127,13 @@ static struct bpf_attr_check BPF_PROG_QU
 	{ /* 1 */
 		.data = { .BPF_PROG_QUERY_data = {
 			.target_fd = 3141592653U,
-			.attach_type = 16,
+			.attach_type = 37,
 			.query_flags = 1,
 			.attach_flags = 3,
 		} },
 		.size = offsetofend(struct BPF_PROG_QUERY_struct, attach_flags),
 		.str = "query={target_fd=-1153374643"
-		       ", attach_type=BPF_LIRC_MODE2"
+		       ", attach_type=BPF_XDP"
 		       ", query_flags=BPF_F_QUERY_EFFECTIVE"
 		       ", attach_flags=BPF_F_ALLOW_OVERRIDE|BPF_F_ALLOW_MULTI"
 		       ", prog_ids=NULL, prog_cnt=0}",
@@ -1092,17 +1141,17 @@ static struct bpf_attr_check BPF_PROG_QU
 	{ /* 2 */
 		.data = { .BPF_PROG_QUERY_data = {
 			.target_fd = 3141592653U,
-			.attach_type = 26,
+			.attach_type = 38,
 			.query_flags = 0xfffffffe,
-			.attach_flags = 0xfffffffc,
+			.attach_flags = 0xfffffff8,
 			.prog_ids = 0xffffffffffffffffULL,
 			.prog_cnt = 2718281828,
 		} },
 		.size = offsetofend(struct BPF_PROG_QUERY_struct, prog_cnt),
 		.str = "query={target_fd=-1153374643"
-		       ", attach_type=0x1a /* BPF_??? */"
+		       ", attach_type=0x26 /* BPF_??? */"
 		       ", query_flags=0xfffffffe /* BPF_F_QUERY_??? */"
-		       ", attach_flags=0xfffffffc /* BPF_F_??? */"
+		       ", attach_flags=0xfffffff8 /* BPF_F_??? */"
 		       ", prog_ids="
 		       BIG_ADDR("0xffffffffffffffff", "0xffffffff")
 		       ", prog_cnt=2718281828}",
@@ -1120,7 +1169,7 @@ static struct bpf_attr_check BPF_PROG_QU
 		.str = "query={target_fd=-1153374643"
 		       ", attach_type=0xfeedface /* BPF_??? */"
 		       ", query_flags=BPF_F_QUERY_EFFECTIVE|0xdeadf00c"
-		       ", attach_flags=BPF_F_ALLOW_MULTI|0xbeefcafc"
+		       ", attach_flags=BPF_F_ALLOW_MULTI|BPF_F_REPLACE|0xbeefcaf8"
 		       ", prog_ids=" BIG_ADDR_MAYBE("0xffffffffffffffff") "[]"
 		       ", prog_cnt=0}",
 	},
@@ -1166,7 +1215,7 @@ static struct bpf_attr_check BPF_RAW_TRA
 		.data = { .BPF_RAW_TRACEPOINT_OPEN_data = { .name = 0 } },
 		.size = offsetofend(struct BPF_RAW_TRACEPOINT_OPEN_struct,
 				    name),
-		.str = "raw_tracepoint={name=NULL, prog_fd=0}",
+		.str = "raw_tracepoint={name=NULL, prog_fd=0" FD0_PATH "}",
 	},
 	{ /* 1 */
 		.data = { .BPF_RAW_TRACEPOINT_OPEN_data = {
@@ -1240,16 +1289,16 @@ static const struct bpf_attr_check BPF_B
 
 static const struct bpf_attr_check BPF_TASK_FD_QUERY_checks[] = {
 	{
-		.data = { .BPF_TASK_FD_QUERY_data = { .pid = 0xdeadbeef } },
+		.data = { .BPF_TASK_FD_QUERY_data = { .pid = 1735928559 } },
 		.size = offsetofend(struct BPF_TASK_FD_QUERY_struct, pid),
-		.str = "task_fd_query={pid=3735928559, fd=0, flags=0"
-		       ", buf_len=0, buf=NULL, prog_id=0"
+		.str = "task_fd_query={pid=1735928559, fd=0" FD0_PATH
+		       ", flags=0, buf_len=0, buf=NULL, prog_id=0"
 		       ", fd_type=BPF_FD_TYPE_RAW_TRACEPOINT"
 		       ", probe_offset=0, probe_addr=0}"
 	},
 	{ /* 1 */
 		.data = { .BPF_TASK_FD_QUERY_data = {
-			.pid = 0xcafef00d,
+			.pid = 1405705229,
 			.fd = 0xdeadbeef,
 			.flags = 0xfacefeed,
 			.buf_len = 0xdefaced,
@@ -1260,7 +1309,7 @@ static const struct bpf_attr_check BPF_T
 			.probe_addr = 0xfac5fed5fac7fed8
 		} },
 		.size = offsetofend(struct BPF_TASK_FD_QUERY_struct, probe_addr),
-		.str = "task_fd_query={pid=3405705229"
+		.str = "task_fd_query={pid=1405705229"
 		       ", fd=-559038737"
 		       ", flags=4207869677"
 		       ", buf_len=233811181"
@@ -1272,6 +1321,117 @@ static const struct bpf_attr_check BPF_T
 	}
 };
 
+static const struct bpf_attr_check BPF_MAP_LOOKUP_BATCH_checks[] = {
+	{
+		.data = { .BPF_MAP_LOOKUP_BATCH_data = { .map_fd = -1 } },
+		.size = offsetofend(struct BPF_MAP_LOOKUP_BATCH_struct, map_fd ),
+		.str = "batch={in_batch=NULL, out_batch=NULL, keys=NULL"
+		       ", values=NULL, count=0, map_fd=-1, elem_flags=BPF_ANY"
+		       ", flags=0}"
+	},
+	{
+		.data = { .BPF_MAP_LOOKUP_BATCH_data = {
+			.in_batch = 0xfacefeed,
+			.out_batch = 0xbadc0ded,
+			.keys = 0xdeadf00d,
+			.values = 0xfffffffe,
+			.count = 3,
+			.map_fd = -1,
+			.elem_flags = 4,
+			.flags = 4
+		} },
+		.size = offsetofend(struct BPF_MAP_LOOKUP_BATCH_struct, flags),
+		.str = "batch={in_batch=0xfacefeed, out_batch=0xbadc0ded"
+		       ", keys=0xdeadf00d, values=0xfffffffe, count=3"
+		       ", map_fd=-1, elem_flags=BPF_F_LOCK, flags=0x4}"
+	}
+};
+
+static const struct bpf_attr_check BPF_MAP_UPDATE_BATCH_checks[] = {
+	{
+		.data = { .BPF_MAP_UPDATE_BATCH_data = { .map_fd = -1 } },
+		.size = offsetofend(struct BPF_MAP_UPDATE_BATCH_struct, map_fd ),
+		.str = "batch={keys=NULL, values=NULL, count=0, map_fd=-1"
+		       ", elem_flags=BPF_ANY, flags=0}"
+	},
+	{
+		.data = { .BPF_MAP_UPDATE_BATCH_data = {
+			.keys = 0xdeadf00d,
+			.values = 0xfffffffe,
+			.count = 3,
+			.map_fd = -1,
+			.elem_flags = 4,
+			.flags = 4
+		} },
+		.size = offsetofend(struct BPF_MAP_UPDATE_BATCH_struct, flags),
+		.str = "batch={keys=0xdeadf00d, values=0xfffffffe, count=3"
+		       ", map_fd=-1, elem_flags=BPF_F_LOCK, flags=0x4}"
+	}
+};
+
+static const struct bpf_attr_check BPF_MAP_DELETE_BATCH_checks[] = {
+	{
+		.data = { .BPF_MAP_DELETE_BATCH_data = { .map_fd = -1 } },
+		.size = offsetofend(struct BPF_MAP_DELETE_BATCH_struct, map_fd ),
+		.str = "batch={keys=NULL, count=0, map_fd=-1"
+		       ", elem_flags=BPF_ANY, flags=0}"
+	},
+	{
+		.data = { .BPF_MAP_DELETE_BATCH_data = {
+			.keys = 0xdeadf00d,
+			.count = 3,
+			.map_fd = -1,
+			.elem_flags = 4,
+			.flags = 4
+		} },
+		.size = offsetofend(struct BPF_MAP_DELETE_BATCH_struct, flags),
+		.str = "batch={keys=0xdeadf00d, count=3, map_fd=-1"
+		       ", elem_flags=BPF_F_LOCK, flags=0x4}"
+	}
+};
+
+static const struct bpf_attr_check BPF_LINK_CREATE_checks[] = {
+	{
+		.data = { .BPF_LINK_CREATE_data = { .prog_fd = -1, .target_fd = -2 } },
+		.size = offsetofend(struct BPF_LINK_CREATE_struct, flags),
+		.str = "link_create={prog_fd=-1, target_fd=-2"
+		       ", attach_type=BPF_CGROUP_INET_INGRESS, flags=0}"
+	},
+	{
+		.data = { .BPF_LINK_CREATE_data = {
+			.prog_fd = -1,
+			.target_fd = 0xdeadbeef,
+			.attach_type = 5,
+			.flags = 4
+		} },
+		.size = offsetofend(struct BPF_LINK_CREATE_struct, flags),
+		.str = "link_create={prog_fd=-1, target_fd=-559038737"
+		       ", attach_type=BPF_SK_SKB_STREAM_VERDICT, flags=0x4}"
+	}
+};
+
+static const struct bpf_attr_check BPF_LINK_UPDATE_checks[] = {
+	{
+		.data = { .BPF_LINK_UPDATE_data = {
+			.link_fd = -1,
+			.new_prog_fd = -2
+		} },
+		.size = offsetofend(struct BPF_LINK_UPDATE_struct, old_prog_fd),
+		.str = "link_update={link_fd=-1, new_prog_fd=-2, flags=0}"
+	},
+	{
+		.data = { .BPF_LINK_UPDATE_data = {
+			.link_fd = -1,
+			.new_prog_fd = 0xdeadbeef,
+			.flags = 4,
+			.old_prog_fd = 0xdeadf00d
+		} },
+		.size = offsetofend(struct BPF_LINK_UPDATE_struct, old_prog_fd),
+		.str = "link_update={link_fd=-1, new_prog_fd=-559038737"
+		       ", flags=BPF_F_REPLACE, old_prog_fd=-559026163}"
+	}
+};
+
 
 #define CHK(cmd_) \
 	{ \
@@ -1308,6 +1468,11 @@ main(void)
 		CHK(BPF_MAP_LOOKUP_AND_DELETE_ELEM),
 		CHK(BPF_MAP_FREEZE),
 		CHK(BPF_BTF_GET_NEXT_ID),
+		CHK(BPF_MAP_LOOKUP_BATCH),
+		CHK(BPF_MAP_UPDATE_BATCH),
+		CHK(BPF_MAP_DELETE_BATCH),
+		CHK(BPF_LINK_CREATE),
+		CHK(BPF_LINK_UPDATE),
 	};
 
 	page_size = get_page_size();
diff -pruN 5.5-3/tests-mx32/bpf-obj_get_info_by_fd.c 5.9-0ubuntu2/tests-mx32/bpf-obj_get_info_by_fd.c
--- 5.5-3/tests-mx32/bpf-obj_get_info_by_fd.c	2019-12-11 22:44:53.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/bpf-obj_get_info_by_fd.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check bpf(BPF_OBJ_GET_INFO_BY_FD) decoding.
  *
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -87,6 +87,10 @@ print_map_create(void *attr_void, size_t
 		printf(", btf_fd=0</dev/null>"
 		       ", btf_key_type_id=0, btf_value_type_id=0");
 	}
+	if (size > offsetof(struct BPF_MAP_CREATE_struct,
+			    btf_vmlinux_value_type_id)) {
+		printf(", btf_vmlinux_value_type_id=0");
+	}
 	printf("}, %zu) = ", size);
 	if (rc >= 0)
 		printf("%ld<anon_inode:bpf-map>\n", rc);
@@ -353,6 +357,10 @@ main(int ac, char **av)
 	    offsetof(struct bpf_map_info_struct, ifindex))
 		printf(", ifindex=%u", map_info->ifindex);
 	if (bpf_map_get_info_attr.info_len >
+	    offsetof(struct bpf_map_info_struct, btf_vmlinux_value_type_id))
+		printf(", btf_vmlinux_value_type_id=%u",
+		       map_info->btf_vmlinux_value_type_id);
+	if (bpf_map_get_info_attr.info_len >
 	    offsetof(struct bpf_map_info_struct, netns_dev))
 		printf(", netns_dev=makedev(%#x, %#x)",
 		       major(map_info->netns_dev), minor(map_info->netns_dev));
diff -pruN 5.5-3/tests-mx32/bpf-success-long-y.c 5.9-0ubuntu2/tests-mx32/bpf-success-long-y.c
--- 5.5-3/tests-mx32/bpf-success-long-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/bpf-success-long-y.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,3 @@
+#define INJECT_RETVAL ((long) 0xbadc0de1e55beefULL)
+#define FD0_PATH "</dev/full>"
+#include "bpf.c"
diff -pruN 5.5-3/tests-mx32/bpf-success-long-y.test 5.9-0ubuntu2/tests-mx32/bpf-success-long-y.test
--- 5.5-3/tests-mx32/bpf-success-long-y.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/bpf-success-long-y.test	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,16 @@
+:#!/bin/sh -efu
+#
+# Copyright (c) 2018-2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: GPL-2.0-or-later
+
+. "${srcdir=.}/scno_tampering.sh"
+
+case "$SIZEOF_LONG" in
+	4) rval=508935919;;
+	8) rval=841540765612359407;;
+esac
+
+run_strace -a20 -y -e trace=bpf -e inject=bpf:retval="${rval}" ../bpf-success-long-y < /dev/full > "$EXP"
+match_diff "$LOG" "$EXP"
diff -pruN 5.5-3/tests-mx32/btrfs.c 5.9-0ubuntu2/tests-mx32/btrfs.c
--- 5.5-3/tests-mx32/btrfs.c	2019-07-24 17:12:18.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/btrfs.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -815,7 +815,7 @@ btrfs_test_clone_ioctls(void)
 		args.dest_offset);
 }
 
-# define BTRFS_COMPRESS_TYPES 2
+# define BTRFS_COMPRESS_TYPES 3
 # define BTRFS_INVALID_COMPRESS (BTRFS_COMPRESS_TYPES + 1)
 
 static void
diff -pruN 5.5-3/tests-mx32/caps-abbrev.awk 5.9-0ubuntu2/tests-mx32/caps-abbrev.awk
--- 5.5-3/tests-mx32/caps-abbrev.awk	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/caps-abbrev.awk	2020-09-06 08:00:00.000000000 +0000
@@ -3,12 +3,13 @@
 # This file is part of caps strace test.
 #
 # Copyright (c) 2014-2018 Dmitry V. Levin <ldv@altlinux.org>
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 BEGIN {
-	cap = "(0|1<<CAP_[A-Z_]+(\\|1<<CAP_[A-Z_]+)*|1<<CAP_[A-Z_]+(\\|1<<CAP_[A-Z_]+){37}\\|0xffffffc0)"
+	cap = "(0|1<<CAP_[A-Z_]+(\\|1<<CAP_[A-Z_]+)*|1<<CAP_[A-Z_]+(\\|1<<CAP_[A-Z_]+){40}\\|0xfffffe00)"
 	s_efault = "-1 EFAULT (Bad address)"
 	r_efault = "-1 EFAULT \\(Bad address\\)"
 	r_einval = "-1 EINVAL \\(Invalid argument\\)"
diff -pruN 5.5-3/tests-mx32/caps.awk 5.9-0ubuntu2/tests-mx32/caps.awk
--- 5.5-3/tests-mx32/caps.awk	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/caps.awk	2020-09-06 08:00:00.000000000 +0000
@@ -2,13 +2,13 @@
 #
 # This file is part of caps strace test.
 #
-# Copyright (c) 2014-2018 Dmitry V. Levin <ldv@altlinux.org>
+# Copyright (c) 2014-2020 Dmitry V. Levin <ldv@altlinux.org>
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 BEGIN {
-	cap = "(0|1<<CAP_[A-Z_]+(\\|1<<CAP_[A-Z_]+)*|1<<CAP_[A-Z_]+(\\|1<<CAP_[A-Z_]+){37}\\|0xffffffc0)"
+	cap = "(0|1<<CAP_[A-Z_]+(\\|1<<CAP_[A-Z_]+)*|1<<CAP_[A-Z_]+(\\|1<<CAP_[A-Z_]+){40}\\|0xfffffe00)"
 	s_efault = "-1 EFAULT (Bad address)"
 	r_efault = "-1 EFAULT \\(Bad address\\)"
 	r_einval = "-1 EINVAL \\(Invalid argument\\)"
diff -pruN 5.5-3/tests-mx32/clock_nanosleep.c 5.9-0ubuntu2/tests-mx32/clock_nanosleep.c
--- 5.5-3/tests-mx32/clock_nanosleep.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/clock_nanosleep.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,22 +2,25 @@
  * Check decoding of clock_nanosleep and clock_gettime syscalls.
  *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-#include <assert.h>
-#include <stdio.h>
-#include <stdint.h>
-#include <signal.h>
-#include <time.h>
-#include <unistd.h>
-#include <sys/time.h>
 #include "scno.h"
 
+#ifdef __NR_clock_nanosleep
+
+# include <assert.h>
+# include <stdio.h>
+# include <stdint.h>
+# include <signal.h>
+# include <time.h>
+# include <unistd.h>
+# include <sys/time.h>
+
 static void
 handler(int signo)
 {
@@ -127,3 +130,9 @@ main(void)
 	puts("+++ exited with 0 +++");
 	return 0;
 }
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_clock_nanosleep")
+
+#endif
diff -pruN 5.5-3/tests-mx32/clone3.c 5.9-0ubuntu2/tests-mx32/clone3.c
--- 5.5-3/tests-mx32/clone3.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/clone3.c	2020-06-07 08:00:00.000000000 +0000
@@ -50,9 +50,10 @@ struct test_clone_args {
 	uint64_t tls;
 	uint64_t set_tid;
 	uint64_t set_tid_size;
+	uint64_t cgroup;
 };
 
-#ifdef HAVE_STRUCT_CLONE_ARGS_SET_TID_SIZE
+#ifdef HAVE_STRUCT_CLONE_ARGS_CGROUP
 typedef struct clone_args struct_clone_args;
 #else
 typedef struct test_clone_args struct_clone_args;
@@ -66,18 +67,14 @@ enum validity_flag_bits {
 	TLS_VALID_BIT,
 };
 
-#define _(x_) x_ = 1 << x_##_BIT
-
 enum validity_flags {
-	_(STRUCT_VALID),
-	_(PIDFD_VALID),
-	_(CHILD_TID_VALID),
-	_(PARENT_TID_VALID),
-	_(TLS_VALID),
+	FLAG(STRUCT_VALID),
+	FLAG(PIDFD_VALID),
+	FLAG(CHILD_TID_VALID),
+	FLAG(PARENT_TID_VALID),
+	FLAG(TLS_VALID),
 };
 
-#undef _
-
 #define MAX_SET_TID_SIZE 32
 
 static const int child_exit_status = 42;
@@ -267,6 +264,10 @@ print_clone3(struct_clone_args *const ar
 	    (arg->set_tid || arg->set_tid_size))
 		print_set_tid(arg->set_tid, arg->set_tid_size);
 
+	if (sz > offsetof(struct_clone_args, cgroup) &&
+	    (arg->cgroup || arg->flags & CLONE_INTO_CGROUP))
+		printf(", cgroup=%" PRIu64, (uint64_t) arg->cgroup);
+
 	printf("}");
 
 	if (rc < 0)
@@ -405,6 +406,19 @@ main(int argc, char *argv[])
 	printf(", %zu) = %s" INJ_STR, sizeof(*arg), sprintrc(rc));
 	memset(arg, 0, sizeof(*arg));
 
+	arg->cgroup = 0xfacefeedbadc0ded;
+	rc = do_clone3(arg, sizeof(*arg), ERR(0) | ERR(E2BIG));
+	print_clone3(arg, rc, sizeof(*arg), STRUCT_VALID, "0", "0");
+	printf(", %zu) = %s" INJ_STR, sizeof(*arg), sprintrc(rc));
+	memset(arg, 0, sizeof(*arg));
+
+	arg->flags = CLONE_INTO_CGROUP;
+	rc = do_clone3(arg, sizeof(*arg), ERR(0) | ERR(EINVAL) | ERR(EBADF));
+	print_clone3(arg, rc, sizeof(*arg), STRUCT_VALID,
+		     "CLONE_INTO_CGROUP", "0");
+	printf(", %zu) = %s" INJ_STR, sizeof(*arg), sprintrc(rc));
+	memset(arg, 0, sizeof(*arg));
+
 	/*
 	 * NB: the following check is purposefully fragile (it will break
 	 *     when system's struct clone_args has additional fields,
@@ -446,18 +460,20 @@ main(int argc, char *argv[])
 	       ", %zu) = %s" INJ_STR,
 	       sizeof(*arg) + 16, sprintrc(rc));
 
-	arg->flags = 0xfacefeedbeefc0de;
+	arg->flags = 0xface3eefbeefc0de;
 	arg->exit_signal = 0x1e55c0de;
 	rc = do_clone3(arg, 64, ERR(EINVAL));
 	printf("clone3({flags=%s, child_tid=NULL, exit_signal=508936414"
 	       ", stack=NULL, stack_size=0, tls=NULL}, 64) = %s" INJ_STR,
-	       XLAT_KNOWN(0xfacefeedbeefc0de, "CLONE_VFORK|CLONE_PARENT"
+	       XLAT_KNOWN(0xface3eefbeefc0de, "CLONE_VFORK|CLONE_PARENT"
 	       "|CLONE_THREAD|CLONE_NEWNS|CLONE_SYSVSEM|CLONE_SETTLS"
 	       "|CLONE_CHILD_CLEARTID|CLONE_UNTRACED|CLONE_NEWCGROUP"
 	       "|CLONE_NEWUTS|CLONE_NEWIPC|CLONE_NEWUSER|CLONE_NEWPID|CLONE_IO"
-	       "|CLONE_CLEAR_SIGHAND|0xfacefeec004000de"), sprintrc(rc));
+	       "|CLONE_NEWTIME|CLONE_CLEAR_SIGHAND|CLONE_INTO_CGROUP"
+	       "|0xface3eec0040005e"),
+	       sprintrc(rc));
 
-	arg->flags = 0xdec0deac004000ffULL;
+	arg->flags = 0xdec0deac0040007fULL;
 	arg->exit_signal = 250;
 	arg->stack = 0xface1e55beeff00dULL;
 	arg->stack_size = 0xcaffeedefacedca7ULL;
@@ -465,7 +481,7 @@ main(int argc, char *argv[])
 	printf("clone3({flags=%s, exit_signal=250"
 	       ", stack=0xface1e55beeff00d, stack_size=0xcaffeedefacedca7}, 64)"
 	       " = %s" INJ_STR,
-	       XLAT_UNKNOWN(0xdec0deac004000ff, "CLONE_???"),
+	       XLAT_UNKNOWN(0xdec0deac0040007f, "CLONE_???"),
 	       sprintrc(rc));
 
 	arg->exit_signal = SIGCHLD;
diff -pruN 5.5-3/tests-mx32/clone-flags.test 5.9-0ubuntu2/tests-mx32/clone-flags.test
--- 5.5-3/tests-mx32/clone-flags.test	2019-06-20 09:49:27.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/clone-flags.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
 #
 # Check decoding of clone flags.
 #
-# Copyright (c) 2019 The strace developers.
+# Copyright (c) 2019-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -15,10 +15,10 @@ case "$STRACE_ARCH" in
 esac
 
 # Find out the expected and reported child stack addresses.
-run_strace_match_grep -qq -e signal=none -e trace=$syscall
+run_strace_match_grep --silence=exits -e signal=none -e trace=$syscall
 CHILD_STACK_EXPECTED="$(sed -n 's/^clone[^(]*(child_stack=(\(0x[[:xdigit:]]\+\)|.*/\1/p' "$EXP")000"
 CHILD_STACK_REPORTED="$(sed -n 's/^clone[^(]*(child_stack=\(0x[[:xdigit:]]\+\),.*/\1/p' "$LOG")"
 export CHILD_STACK_EXPECTED CHILD_STACK_REPORTED
 
 # Use child stack addresses to check decoding.
-run_strace_match_diff -a35 -qq -y -e signal=none -e trace=$syscall
+run_strace_match_diff -a35 --silence=exits,personality -y -e signal=none -e trace=$syscall
diff -pruN 5.5-3/tests-mx32/clone_parent.c 5.9-0ubuntu2/tests-mx32/clone_parent.c
--- 5.5-3/tests-mx32/clone_parent.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/clone_parent.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check handling of CLONE_PARENT'ed processes.
  *
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -17,6 +17,10 @@
 #include <sys/wait.h>
 #include <unistd.h>
 
+#ifndef QUIET_MSG
+# define QUIET_MSG 0
+#endif
+
 static int
 child(void *const arg)
 {
@@ -56,10 +60,14 @@ main(void)
 	FILE *const fp = fdopen(3, "a");
 	if (!fp)
 		perror_msg_and_fail("fdopen");
+#if !QUIET_MSG
 	if (fprintf(fp, "%s: Exit of unknown pid %d ignored\n",
 		    getenv("STRACE_EXE") ?: "strace", pid) < 0)
 		perror_msg_and_fail("fprintf");
+#endif
 
+#if !QUIET_MSG
 	puts("+++ exited with 0 +++");
+#endif
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/clone_parent.gen.test 5.9-0ubuntu2/tests-mx32/clone_parent.gen.test
--- 5.5-3/tests-mx32/clone_parent.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/clone_parent.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (clone_parent +clone_ptrace.test ); do not edit.
+set -- 
+. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests-mx32/clone_parent-q.c 5.9-0ubuntu2/tests-mx32/clone_parent-q.c
--- 5.5-3/tests-mx32/clone_parent-q.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/clone_parent-q.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define QUIET_MSG 0
+#include "clone_parent.c"
diff -pruN 5.5-3/tests-mx32/clone_parent-q.gen.test 5.9-0ubuntu2/tests-mx32/clone_parent-q.gen.test
--- 5.5-3/tests-mx32/clone_parent-q.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/clone_parent-q.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (clone_parent-q +clone_ptrace.test -q); do not edit.
+set -- -q
+. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests-mx32/clone_parent-qq.c 5.9-0ubuntu2/tests-mx32/clone_parent-qq.c
--- 5.5-3/tests-mx32/clone_parent-qq.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/clone_parent-qq.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define QUIET_MSG 1
+#include "clone_parent.c"
diff -pruN 5.5-3/tests-mx32/clone_parent-qq.gen.test 5.9-0ubuntu2/tests-mx32/clone_parent-qq.gen.test
--- 5.5-3/tests-mx32/clone_parent-qq.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/clone_parent-qq.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (clone_parent-qq +clone_ptrace.test -qq); do not edit.
+set -- -qq
+. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests-mx32/clone_parent--quiet-exit.c 5.9-0ubuntu2/tests-mx32/clone_parent--quiet-exit.c
--- 5.5-3/tests-mx32/clone_parent--quiet-exit.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/clone_parent--quiet-exit.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define QUIET_MSG 1
+#include "clone_parent.c"
diff -pruN 5.5-3/tests-mx32/clone_parent--quiet-exit.gen.test 5.9-0ubuntu2/tests-mx32/clone_parent--quiet-exit.gen.test
--- 5.5-3/tests-mx32/clone_parent--quiet-exit.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/clone_parent--quiet-exit.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (clone_parent--quiet-exit +clone_ptrace.test --quiet=exit,personality); do not edit.
+set -- --quiet=exit,personality
+. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests-mx32/clone_parent.test 5.9-0ubuntu2/tests-mx32/clone_parent.test
--- 5.5-3/tests-mx32/clone_parent.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/clone_parent.test	1970-01-01 00:00:00.000000000 +0000
@@ -1,10 +0,0 @@
-#!/bin/sh -efu
-#
-# Check handling of CLONE_PARENT'ed processes.
-#
-# Copyright (c) 2017-2018 The strace developers.
-# All rights reserved.
-#
-# SPDX-License-Identifier: GPL-2.0-or-later
-
-. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests-mx32/clone_ptrace.c 5.9-0ubuntu2/tests-mx32/clone_ptrace.c
--- 5.5-3/tests-mx32/clone_ptrace.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/clone_ptrace.c	2020-07-17 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check handling of CLONE_PTRACE'ed processes.
  *
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -20,6 +20,13 @@
 
 static siginfo_t sinfo;
 
+#ifndef QUIET_ATTACH
+# define QUIET_ATTACH 0
+#endif
+#ifndef QUIET_EXIT
+# define QUIET_EXIT 0
+#endif
+
 static void
 handler(const int no, siginfo_t *const si, void *const uc)
 {
@@ -74,9 +81,11 @@ main(void)
 	FILE *const fp = fdopen(3, "a");
 	if (!fp)
 		perror_msg_and_fail("fdopen");
+#if !QUIET_ATTACH
 	if (fprintf(fp, "%s: Detached unknown pid %d\n",
 		    getenv("STRACE_EXE") ?: "strace", pid) < 0)
 		perror_msg_and_fail("fprintf");
+#endif
 
 	int status;
 	while (wait(&status) != pid) {
@@ -87,8 +96,11 @@ main(void)
 		error_msg_and_fail("unexpected child exit status %d", status);
 
 	printf("--- SIGCHLD {si_signo=SIGCHLD, si_code=CLD_KILLED, si_pid=%d"
-	       ", si_uid=%u, si_status=%s, si_utime=%u, si_stime=%u} ---\n"
-	       "+++ exited with 0 +++\n", pid, geteuid(), "SIGUSR1",
+	       ", si_uid=%d, si_status=%s, si_utime=%u, si_stime=%u} ---\n"
+#if !QUIET_EXIT
+	       "+++ exited with 0 +++\n"
+#endif
+	       , pid, geteuid(), "SIGUSR1",
 	       (unsigned int) sinfo.si_utime, (unsigned int) sinfo.si_stime);
 
 	return 0;
diff -pruN 5.5-3/tests-mx32/clone_ptrace-q.c 5.9-0ubuntu2/tests-mx32/clone_ptrace-q.c
--- 5.5-3/tests-mx32/clone_ptrace-q.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/clone_ptrace-q.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define QUIET_ATTACH 1
+#include "clone_ptrace.c"
diff -pruN 5.5-3/tests-mx32/clone_ptrace-q.gen.test 5.9-0ubuntu2/tests-mx32/clone_ptrace-q.gen.test
--- 5.5-3/tests-mx32/clone_ptrace-q.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/clone_ptrace-q.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (clone_ptrace-q +clone_ptrace.test -q); do not edit.
+set -- -q
+. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests-mx32/clone_ptrace-qq.c 5.9-0ubuntu2/tests-mx32/clone_ptrace-qq.c
--- 5.5-3/tests-mx32/clone_ptrace-qq.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/clone_ptrace-qq.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,3 @@
+#define QUIET_ATTACH 1
+#define QUIET_EXIT 1
+#include "clone_ptrace.c"
diff -pruN 5.5-3/tests-mx32/clone_ptrace-qq.gen.test 5.9-0ubuntu2/tests-mx32/clone_ptrace-qq.gen.test
--- 5.5-3/tests-mx32/clone_ptrace-qq.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/clone_ptrace-qq.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (clone_ptrace-qq +clone_ptrace.test -qq); do not edit.
+set -- -qq
+. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests-mx32/clone_ptrace--quiet-attach.c 5.9-0ubuntu2/tests-mx32/clone_ptrace--quiet-attach.c
--- 5.5-3/tests-mx32/clone_ptrace--quiet-attach.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/clone_ptrace--quiet-attach.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define QUIET_ATTACH 1
+#include "clone_ptrace.c"
diff -pruN 5.5-3/tests-mx32/clone_ptrace--quiet-attach.gen.test 5.9-0ubuntu2/tests-mx32/clone_ptrace--quiet-attach.gen.test
--- 5.5-3/tests-mx32/clone_ptrace--quiet-attach.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/clone_ptrace--quiet-attach.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (clone_ptrace--quiet-attach +clone_ptrace.test --quiet=attach,personality); do not edit.
+set -- --quiet=attach,personality
+. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests-mx32/clone_ptrace--quiet-exit.c 5.9-0ubuntu2/tests-mx32/clone_ptrace--quiet-exit.c
--- 5.5-3/tests-mx32/clone_ptrace--quiet-exit.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/clone_ptrace--quiet-exit.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define QUIET_EXIT 1
+#include "clone_ptrace.c"
diff -pruN 5.5-3/tests-mx32/clone_ptrace--quiet-exit.gen.test 5.9-0ubuntu2/tests-mx32/clone_ptrace--quiet-exit.gen.test
--- 5.5-3/tests-mx32/clone_ptrace--quiet-exit.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/clone_ptrace--quiet-exit.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (clone_ptrace--quiet-exit +clone_ptrace.test --quiet=exit,personality); do not edit.
+set -- --quiet=exit,personality
+. "${srcdir=.}/clone_ptrace.test"
diff -pruN 5.5-3/tests-mx32/clone_ptrace.test 5.9-0ubuntu2/tests-mx32/clone_ptrace.test
--- 5.5-3/tests-mx32/clone_ptrace.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/clone_ptrace.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
 #
 # Check handling of CLONE_PTRACE'ed processes.
 #
-# Copyright (c) 2017-2018 The strace developers.
+# Copyright (c) 2017-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,7 +10,7 @@
 . "${srcdir=.}/init.sh"
 
 run_prog > /dev/null 3>&1
-args="-e trace=none $args"
+args="-e trace=none ${1:---quiet=personality} $args"
 > "$LOG" || fail_ "failed to write $LOG"
 
 $STRACE -o "$LOG" $args > "$EXP" 2> "$OUT"-err 3> "$EXP"-err || {
diff -pruN 5.5-3/tests-mx32/close_range.c 5.9-0ubuntu2/tests-mx32/close_range.c
--- 5.5-3/tests-mx32/close_range.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/close_range.c	2020-09-23 16:29:35.000000000 +0000
@@ -0,0 +1,147 @@
+/*
+ * Check decoding of close_range syscall.
+ *
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+
+#ifdef __NR_close_range
+
+# include <fcntl.h>
+# include <stdio.h>
+# include <unistd.h>
+
+# ifdef HAVE_LINUX_CLOSE_RANGE_H
+#  include <linux/close_range.h>
+# else
+#  define CLOSE_RANGE_UNSHARE	(1U << 1)
+# endif
+
+# ifndef FD0_PATH
+#  define FD0_PATH ""
+# endif
+# ifndef FD7_PATH
+#  define FD7_PATH ""
+# endif
+# ifndef SKIP_IF_PROC_IS_UNAVAILABLE
+#  define SKIP_IF_PROC_IS_UNAVAILABLE
+# endif
+
+static const char *errstr;
+
+static long
+k_close_range(const unsigned int fd1, const unsigned int fd2, const unsigned int flags)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+	const kernel_ulong_t arg1 = fill | fd1;
+	const kernel_ulong_t arg2 = fill | fd2;
+	const kernel_ulong_t arg3 = fill | flags;
+	const long rc = syscall(__NR_close_range, arg1, arg2, arg3, bad, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
+
+static void
+xdup2(int fd1, int fd2)
+{
+	if (dup2(fd1, fd2) != fd2)
+		perror_msg_and_fail("dup2(%d, %d)", fd1, fd2);
+}
+
+int
+main(void)
+{
+	SKIP_IF_PROC_IS_UNAVAILABLE;
+
+	const int fd0 = dup(0);
+	const int fd7 = dup(7);
+	const int fd7_min = MIN(7, fd7);
+	const int fd7_max = MAX(7, fd7);
+
+	k_close_range(-2, -1, 1);
+# ifndef PATH_TRACING
+	printf("close_range(-2, -1, 0x1 /* CLOSE_RANGE_??? */) = %s\n", errstr);
+# endif
+
+	k_close_range(-1, -2, 2);
+# ifndef PATH_TRACING
+	printf("close_range(-1, -2, CLOSE_RANGE_UNSHARE) = %s\n", errstr);
+# endif
+
+	k_close_range(-3, 0, 4);
+# ifndef PATH_TRACING
+	printf("close_range(-3, 0" FD0_PATH ", 0x4 /* CLOSE_RANGE_??? */)"
+	       " = %s\n", errstr);
+# endif
+
+	k_close_range(0, -4, -1);
+# ifndef PATH_TRACING
+	printf("close_range(0" FD0_PATH ", -4, CLOSE_RANGE_UNSHARE|%#x) = %s\n",
+	       (-1U & ~CLOSE_RANGE_UNSHARE), errstr);
+# endif
+
+	k_close_range(-5, 7, 0);
+	printf("close_range(-5, 7" FD7_PATH ", 0) = %s\n", errstr);
+
+	k_close_range(7, -6, 1);
+	printf("close_range(7" FD7_PATH ", -6, 0x1 /* CLOSE_RANGE_??? */)"
+	       " = %s\n", errstr);
+
+	k_close_range(7, 7, 4);
+	printf("close_range(7" FD7_PATH ", 7" FD7_PATH
+	       ", 0x4 /* CLOSE_RANGE_??? */) = %s\n", errstr);
+
+	k_close_range(-7, -7, 7);
+# ifndef PATH_TRACING
+	printf("close_range(-7, -7, CLOSE_RANGE_UNSHARE|0x5) = %s\n", errstr);
+# endif
+
+	k_close_range(7, 0, 0);
+	printf("close_range(7" FD7_PATH ", 0" FD0_PATH ", 0) = %s\n", errstr);
+
+	k_close_range(fd7, fd0, 0);
+	printf("close_range(%d" FD7_PATH ", %d" FD0_PATH ", 0) = %s\n",
+	       fd7, fd0, errstr);
+
+	if (k_close_range(0, 0, 0) == 0)
+		xdup2(fd0, 0);
+# ifndef PATH_TRACING
+	printf("close_range(0" FD0_PATH ", 0" FD0_PATH ", 0) = %s\n", errstr);
+# endif
+
+	if (k_close_range(fd0, fd0, 0) == 0)
+		xdup2(0, fd0);
+# ifndef PATH_TRACING
+	printf("close_range(%d" FD0_PATH ", %d" FD0_PATH ", 0) = %s\n",
+	       fd0, fd0, errstr);
+# endif
+
+	if (k_close_range(7, 7, 0) == 0)
+		xdup2(fd7, 7);
+	printf("close_range(7" FD7_PATH ", 7" FD7_PATH ", 0) = %s\n", errstr);
+
+	if (k_close_range(fd7, fd7, 0) == 0)
+		xdup2(7, fd7);
+	printf("close_range(%d" FD7_PATH ", %d" FD7_PATH ", 0) = %s\n",
+	       fd7, fd7, errstr);
+
+	if (k_close_range(fd7_max, -1, 0) == 0)
+		xdup2(fd7_min, fd7_max);
+	printf("close_range(%d" FD7_PATH ", -1, 0) = %s\n",
+	       fd7_max, errstr);
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_close_range")
+
+#endif
diff -pruN 5.5-3/tests-mx32/close_range.gen.test 5.9-0ubuntu2/tests-mx32/close_range.gen.test
--- 5.5-3/tests-mx32/close_range.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/close_range.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (close_range -a21 7>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a21 7>>/dev/full
diff -pruN 5.5-3/tests-mx32/close_range-P.c 5.9-0ubuntu2/tests-mx32/close_range-P.c
--- 5.5-3/tests-mx32/close_range-P.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/close_range-P.c	2020-09-06 08:00:00.000000000 +0000
@@ -0,0 +1,4 @@
+#define PATH_TRACING
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "close_range.c"
diff -pruN 5.5-3/tests-mx32/close_range-P.gen.test 5.9-0ubuntu2/tests-mx32/close_range-P.gen.test
--- 5.5-3/tests-mx32/close_range-P.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/close_range-P.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (close_range-P -a21 --trace=close_range -P /dev/full 7>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a21 --trace=close_range -P /dev/full 7>>/dev/full
diff -pruN 5.5-3/tests-mx32/close_range-y.c 5.9-0ubuntu2/tests-mx32/close_range-y.c
--- 5.5-3/tests-mx32/close_range-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/close_range-y.c	2020-09-06 08:00:00.000000000 +0000
@@ -0,0 +1,5 @@
+#define FD0_PATH "</dev/null>"
+#define FD7_PATH "</dev/full>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "close_range.c"
diff -pruN 5.5-3/tests-mx32/close_range-y.gen.test 5.9-0ubuntu2/tests-mx32/close_range-y.gen.test
--- 5.5-3/tests-mx32/close_range-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/close_range-y.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (close_range-y -a33 --trace=close_range -y 7>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a33 --trace=close_range -y 7>>/dev/full
diff -pruN 5.5-3/tests-mx32/close_range-yy.c 5.9-0ubuntu2/tests-mx32/close_range-yy.c
--- 5.5-3/tests-mx32/close_range-yy.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/close_range-yy.c	2020-09-06 08:00:00.000000000 +0000
@@ -0,0 +1,5 @@
+#define FD0_PATH "</dev/null<char 1:3>>"
+#define FD7_PATH "</dev/full<char 1:7>>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "close_range.c"
diff -pruN 5.5-3/tests-mx32/close_range-yy.gen.test 5.9-0ubuntu2/tests-mx32/close_range-yy.gen.test
--- 5.5-3/tests-mx32/close_range-yy.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/close_range-yy.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (close_range-yy -a33 --trace=close_range -yy 7>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a33 --trace=close_range -yy 7>>/dev/full
diff -pruN 5.5-3/tests-mx32/count-f.test 5.9-0ubuntu2/tests-mx32/count-f.test
--- 5.5-3/tests-mx32/count-f.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/count-f.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
 #
 # Check whether -c counts through forks and clones properly.
 #
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,7 +10,7 @@
 . "${srcdir=.}/init.sh"
 
 run_prog
-run_strace -q -f -c $args
+run_strace -e silent=attach -f -c $args
 match_grep
 
 exit 0
diff -pruN 5.5-3/tests-mx32/count.test 5.9-0ubuntu2/tests-mx32/count.test
--- 5.5-3/tests-mx32/count.test	2019-08-06 13:38:20.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/count.test	2020-04-03 22:58:26.000000000 +0000
@@ -3,7 +3,7 @@
 # Check whether -c and -w options work.
 #
 # Copyright (c) 2014-2016 Dmitry V. Levin <ldv@altlinux.org>
-# Copyright (c) 2014-2018 The strace developers.
+# Copyright (c) 2014-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -36,6 +36,7 @@ HALFCLOCK=' *[^ ]+ +0\.[567][^n]*nanosle
 
 grep_log "$GENERIC"	-c
 grep_log "$GENERIC"	-c -O1
+grep_log "$GENERIC"	-c --summary-syscall-overhead=1
 grep_log "$GENERIC"	-c -enanosleep
 grep_log "$GENERIC"	-c -O1 -enanosleep
 grep_log "$WALLCLOCK"	-cw
@@ -43,7 +44,10 @@ grep_log "$WALLCLOCK"	-cw -O1
 grep_log "$WALLCLOCK1"	-cw -enanosleep
 grep_log "$WALLCLOCK1"	-cw -O1 -enanosleep
 grep_log "$HALFCLOCK"	-cw -O4.5e2ms -enanosleep
+grep_log "$HALFCLOCK"	-cw --summary-syscall-overhead=4.5e2ms -enanosleep
 grep_log "$HALFCLOCK"	-cw -O4.5e-1s -enanosleep
+grep_log "$HALFCLOCK"	-cw --summary-syscall-overhead=4.5e-1s -enanosleep
 grep_log "$HALFCLOCK"	-cw -O456789012ns -enanosleep
+grep_log "$HALFCLOCK"	-cw --summary-syscall-overhead=456789012ns -enanosleep
 
 exit 0
diff -pruN 5.5-3/tests-mx32/create_tmpfile.c 5.9-0ubuntu2/tests-mx32/create_tmpfile.c
--- 5.5-3/tests-mx32/create_tmpfile.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/create_tmpfile.c	2020-04-17 20:43:15.000000000 +0000
@@ -0,0 +1,46 @@
+/*
+ * Create a temporary file in the current directory.
+ *
+ * Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include <fcntl.h>
+#include <unistd.h>
+
+#ifndef O_TMPFILE
+# if defined __hppa__
+#  define O_TMPFILE	040000000
+# elif defined __alpha__
+#  define O_TMPFILE	0100000000
+# elif defined __sparc__
+#  define O_TMPFILE	0200000000
+# else
+#  define O_TMPFILE	020000000
+# endif
+#endif
+
+int
+create_tmpfile(unsigned int flags)
+{
+	int fd = open(".", O_TMPFILE | O_DIRECTORY | O_EXCL | flags, 0600);
+
+	if (fd < 0) {
+		/*
+		 * Since every test is executed in a separate directory,
+		 * there is no need to protect from race conditions.
+		 */
+		static const char fname[] = "create_tmpfile";
+
+		fd = open(fname, O_CREAT | O_EXCL | flags, 0600);
+		if (fd < 0)
+			perror_msg_and_fail("open: %s", fname);
+		if (unlink(fname))
+			perror_msg_and_fail("unlink: %s", fname);
+	}
+
+	return fd;
+}
diff -pruN 5.5-3/tests-mx32/delay.test 5.9-0ubuntu2/tests-mx32/delay.test
--- 5.5-3/tests-mx32/delay.test	2019-08-06 13:38:20.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/delay.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
 #
 # Check delay injection.
 #
-# Copyright (c) 2018 The strace developers.
+# Copyright (c) 2018-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -12,7 +12,7 @@
 while read -r denter dexit denter_us dexit_us; do
 	[ -n "$denter" ] || continue
 
-	run_strace -f -r -egettimeofday \
+	run_strace --follow-forks -r -egettimeofday \
 		-einject=gettimeofday:delay_enter=$denter:delay_exit=$dexit \
 		../delay 4 $denter_us $dexit_us
 done <<-EOF
diff -pruN 5.5-3/tests-mx32/dev--decode-fds-dev.c 5.9-0ubuntu2/tests-mx32/dev--decode-fds-dev.c
--- 5.5-3/tests-mx32/dev--decode-fds-dev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dev--decode-fds-dev.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_DEVNUM 1
+#include "dev-yy.c"
diff -pruN 5.5-3/tests-mx32/dev--decode-fds-dev.gen.test 5.9-0ubuntu2/tests-mx32/dev--decode-fds-dev.gen.test
--- 5.5-3/tests-mx32/dev--decode-fds-dev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dev--decode-fds-dev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dev--decode-fds-dev -a30 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" -e decode-fds=dev); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a30 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" -e decode-fds=dev
diff -pruN 5.5-3/tests-mx32/dev--decode-fds-path.c 5.9-0ubuntu2/tests-mx32/dev--decode-fds-path.c
--- 5.5-3/tests-mx32/dev--decode-fds-path.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dev--decode-fds-path.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_DEVNUM 0
+#include "dev-yy.c"
diff -pruN 5.5-3/tests-mx32/dev--decode-fds-path.gen.test 5.9-0ubuntu2/tests-mx32/dev--decode-fds-path.gen.test
--- 5.5-3/tests-mx32/dev--decode-fds-path.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dev--decode-fds-path.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dev--decode-fds-path -a19 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" -e decode-fds=path); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a19 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" -e decode-fds=path
diff -pruN 5.5-3/tests-mx32/dev--decode-fds-socket.c 5.9-0ubuntu2/tests-mx32/dev--decode-fds-socket.c
--- 5.5-3/tests-mx32/dev--decode-fds-socket.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dev--decode-fds-socket.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_DEVNUM 0
+#include "dev-yy.c"
diff -pruN 5.5-3/tests-mx32/dev--decode-fds-socket.gen.test 5.9-0ubuntu2/tests-mx32/dev--decode-fds-socket.gen.test
--- 5.5-3/tests-mx32/dev--decode-fds-socket.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dev--decode-fds-socket.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dev--decode-fds-socket -a19 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" --decode-fds=socket); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a19 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" --decode-fds=socket
diff -pruN 5.5-3/tests-mx32/dev-yy.c 5.9-0ubuntu2/tests-mx32/dev-yy.c
--- 5.5-3/tests-mx32/dev-yy.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dev-yy.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check printing of character/block device numbers in -yy mode.
  *
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -18,6 +18,16 @@
 
 #include <sys/sysmacros.h>
 
+#ifndef PRINT_DEVNUM
+# define PRINT_DEVNUM 1
+#endif
+
+#if PRINT_DEVNUM
+# define DEV_FMT "<%s<%s %u:%u>>"
+#else
+# define DEV_FMT "<%s>"
+#endif
+
 #if defined __NR_openat && defined O_PATH
 
 int
@@ -47,10 +57,13 @@ main(void)
 		printf("openat(AT_FDCWD, \"%s\", O_RDONLY|O_PATH) = %s",
 		       checks[i].path, sprintrc(fd));
 		if (fd >= 0)
-			printf("<%s<%s %u:%u>>",
-			       checks[i].path,
-			       checks[i].blk ? "block" : "char",
-			       checks[i].major, checks[i].minor);
+			printf(DEV_FMT,
+			       checks[i].path
+# if PRINT_DEVNUM
+			       , checks[i].blk ? "block" : "char",
+			       checks[i].major, checks[i].minor
+# endif
+			       );
 		puts("");
 
 		if (fd < 0) {
@@ -63,9 +76,13 @@ main(void)
 
 		int rc = fsync(fd);
 
-		printf("fsync(%ld<%s<%s %u:%u>>) = %s\n",
-		       fd, checks[i].path, checks[i].blk ? "block" : "char",
-		       checks[i].major, checks[i].minor, sprintrc(rc));
+		printf("fsync(%ld" DEV_FMT ") = %s\n",
+		       fd, checks[i].path,
+# if PRINT_DEVNUM
+		       checks[i].blk ? "block" : "char",
+		       checks[i].major, checks[i].minor,
+# endif
+		       sprintrc(rc));
 
 		close(fd);
 	}
diff -pruN 5.5-3/tests-mx32/dup2.c 5.9-0ubuntu2/tests-mx32/dup2.c
--- 5.5-3/tests-mx32/dup2.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dup2.c	2020-04-24 23:03:14.000000000 +0000
@@ -1,5 +1,7 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Check decoding of dup2 syscall.
+ *
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -13,15 +15,103 @@
 # include <stdio.h>
 # include <unistd.h>
 
+# ifndef FD0_PATH
+#  define FD0_PATH ""
+# endif
+# ifndef FD9_PATH
+#  define FD9_PATH ""
+# endif
+# ifndef SKIP_IF_PROC_IS_UNAVAILABLE
+#  define SKIP_IF_PROC_IS_UNAVAILABLE
+# endif
+
+static const char *errstr;
+
+static long
+k_dup2(const unsigned int fd1, const unsigned int fd2)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+	const kernel_ulong_t arg1 = fill | fd1;
+	const kernel_ulong_t arg2 = fill | fd2;
+	const long rc = syscall(__NR_dup2, arg1, arg2, bad, bad, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
+
 int
 main(void)
 {
-	const long int fd_old = (long int) 0xdeadbeefffffffffULL;
-	const long int fd_new = (long int) 0xdeadbeeffffffffeULL;
+	SKIP_IF_PROC_IS_UNAVAILABLE;
+
+	int fd0 = dup(0);
+	int fd9 = dup(9);
 
-	long rc = syscall(__NR_dup2, fd_old, fd_new);
-	printf("dup2(%d, %d) = %ld %s (%m)\n",
-	       (int) fd_old, (int) fd_new, rc, errno2name());
+	if (k_dup2(0, 0))
+		perror_msg_and_skip("dup2");
+# ifndef PATH_TRACING
+	printf("dup2(0" FD0_PATH ", 0" FD0_PATH ") = 0" FD0_PATH "\n");
+# endif
+
+	k_dup2(-1, -2);
+# ifndef PATH_TRACING
+	printf("dup2(-1, -2) = %s\n", errstr);
+# endif
+
+	k_dup2(-2, -1);
+# ifndef PATH_TRACING
+	printf("dup2(-2, -1) = %s\n", errstr);
+# endif
+
+	k_dup2(-3, 0);
+# ifndef PATH_TRACING
+	printf("dup2(-3, 0" FD0_PATH ") = %s\n", errstr);
+# endif
+
+	k_dup2(0, -4);
+# ifndef PATH_TRACING
+	printf("dup2(0" FD0_PATH ", -4) = %s\n", errstr);
+# endif
+
+	k_dup2(-5, 9);
+	printf("dup2(-5, 9" FD9_PATH ") = %s\n", errstr);
+
+	k_dup2(9, -6);
+	printf("dup2(9" FD9_PATH ", -6) = %s\n", errstr);
+
+	k_dup2(9, 9);
+	printf("dup2(9" FD9_PATH ", 9" FD9_PATH ") = 9" FD9_PATH "\n");
+
+	k_dup2(0, fd0);
+# ifndef PATH_TRACING
+	printf("dup2(0" FD0_PATH ", %d" FD0_PATH ") = %d" FD0_PATH "\n",
+	       fd0, fd0);
+# endif
+
+	k_dup2(9, fd9);
+	printf("dup2(9" FD9_PATH ", %d" FD9_PATH ") = %d" FD9_PATH "\n",
+	       fd9, fd9);
+
+	k_dup2(0, fd9);
+	printf("dup2(0" FD0_PATH ", %d" FD9_PATH ") = %d" FD0_PATH "\n",
+	       fd9, fd9);
+
+	k_dup2(9, fd0);
+	printf("dup2(9" FD9_PATH ", %d" FD0_PATH ") = %d" FD9_PATH "\n",
+	       fd0, fd0);
+
+	close(fd0);
+	close(fd9);
+
+	k_dup2(0, fd0);
+# ifndef PATH_TRACING
+	printf("dup2(0" FD0_PATH ", %d) = %d" FD0_PATH "\n",
+	       fd0, fd0);
+# endif
+
+	k_dup2(9, fd9);
+	printf("dup2(9" FD9_PATH ", %d) = %d" FD9_PATH "\n",
+	       fd9, fd9);
 
 	puts("+++ exited with 0 +++");
 	return 0;
diff -pruN 5.5-3/tests-mx32/dup2.gen.test 5.9-0ubuntu2/tests-mx32/dup2.gen.test
--- 5.5-3/tests-mx32/dup2.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dup2.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -1,4 +1,4 @@
 #!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup2 -a13 ); do not edit.
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup2 -a11 9>>/dev/full); do not edit.
 . "${srcdir=.}/init.sh"
-run_strace_match_diff -a13 
+run_strace_match_diff -a11 9>>/dev/full
diff -pruN 5.5-3/tests-mx32/dup2-P.c 5.9-0ubuntu2/tests-mx32/dup2-P.c
--- 5.5-3/tests-mx32/dup2-P.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dup2-P.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,4 @@
+#define PATH_TRACING
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup2.c"
diff -pruN 5.5-3/tests-mx32/dup2-P.gen.test 5.9-0ubuntu2/tests-mx32/dup2-P.gen.test
--- 5.5-3/tests-mx32/dup2-P.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dup2-P.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup2-P -a11 --trace=dup2 -P /dev/full 9>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a11 --trace=dup2 -P /dev/full 9>>/dev/full
diff -pruN 5.5-3/tests-mx32/dup2-y.c 5.9-0ubuntu2/tests-mx32/dup2-y.c
--- 5.5-3/tests-mx32/dup2-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dup2-y.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,5 @@
+#define FD0_PATH "</dev/null>"
+#define FD9_PATH "</dev/full>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup2.c"
diff -pruN 5.5-3/tests-mx32/dup2-y.gen.test 5.9-0ubuntu2/tests-mx32/dup2-y.gen.test
--- 5.5-3/tests-mx32/dup2-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dup2-y.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup2-y -a13 --trace=dup2 -y 9>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a13 --trace=dup2 -y 9>>/dev/full
diff -pruN 5.5-3/tests-mx32/dup2-yy.c 5.9-0ubuntu2/tests-mx32/dup2-yy.c
--- 5.5-3/tests-mx32/dup2-yy.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dup2-yy.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,5 @@
+#define FD0_PATH "</dev/null<char 1:3>>"
+#define FD9_PATH "</dev/full<char 1:7>>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup2.c"
diff -pruN 5.5-3/tests-mx32/dup2-yy.gen.test 5.9-0ubuntu2/tests-mx32/dup2-yy.gen.test
--- 5.5-3/tests-mx32/dup2-yy.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dup2-yy.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup2-yy -a13 --trace=dup2 -yy 9>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a13 --trace=dup2 -yy 9>>/dev/full
diff -pruN 5.5-3/tests-mx32/dup3.c 5.9-0ubuntu2/tests-mx32/dup3.c
--- 5.5-3/tests-mx32/dup3.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dup3.c	2020-04-24 23:03:14.000000000 +0000
@@ -1,28 +1,140 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Check decoding of dup3 syscall.
+ *
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-#include <fcntl.h>
 #include "scno.h"
 
-#if defined __NR_dup3 && defined O_CLOEXEC
+#ifdef __NR_dup3
 
+# include <fcntl.h>
 # include <stdio.h>
 # include <unistd.h>
 
+# ifndef O_CLOEXEC
+#  if defined __alpha__ || defined __hppa__
+#   define O_CLOEXEC	010000000
+#  elif defined __sparc__
+#   define O_CLOEXEC	020000000
+#  else
+#   define O_CLOEXEC	02000000
+#  endif
+# endif /* !O_CLOEXEC */
+
+# ifndef FD0_PATH
+#  define FD0_PATH ""
+# endif
+# ifndef FD7_PATH
+#  define FD7_PATH ""
+# endif
+# ifndef SKIP_IF_PROC_IS_UNAVAILABLE
+#  define SKIP_IF_PROC_IS_UNAVAILABLE
+# endif
+
+static const char *errstr;
+
+static long
+k_dup3(const unsigned int fd1, const unsigned int fd2, const unsigned int flags)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+	const kernel_ulong_t arg1 = fill | fd1;
+	const kernel_ulong_t arg2 = fill | fd2;
+	const kernel_ulong_t arg3 = fill | flags;
+	const long rc = syscall(__NR_dup3, arg1, arg2, arg3, bad, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
+
 int
 main(void)
 {
-	const long int fd_old = (long int) 0xdeadbeefffffffffULL;
-	const long int fd_new = (long int) 0xdeadbeeffffffffeULL;
+	SKIP_IF_PROC_IS_UNAVAILABLE;
+
+	int fd0 = dup(0);
+	int fd7 = dup(7);
 
-	long rc = syscall(__NR_dup3, fd_old, fd_new, O_CLOEXEC);
-	printf("dup3(%d, %d, O_CLOEXEC) = %ld %s (%m)\n",
-	       (int) fd_old, (int) fd_new, rc, errno2name());
+	k_dup3(0, 0, 0);
+# ifndef PATH_TRACING
+	printf("dup3(0" FD0_PATH ", 0" FD0_PATH ", 0) = %s\n", errstr);
+# endif
+
+	k_dup3(-1, -2, O_CLOEXEC);
+# ifndef PATH_TRACING
+	printf("dup3(-1, -2, O_CLOEXEC) = %s\n", errstr);
+# endif
+
+	k_dup3(-2, -1, O_TRUNC);
+# ifndef PATH_TRACING
+	printf("dup3(-2, -1, O_TRUNC) = %s\n", errstr);
+# endif
+
+	k_dup3(-3, 0, O_TRUNC | O_CLOEXEC);
+# ifndef PATH_TRACING
+	printf("dup3(-3, 0" FD0_PATH ", O_TRUNC|O_CLOEXEC) = %s\n", errstr);
+# endif
+
+	k_dup3(0, -4, O_RDONLY);
+# ifndef PATH_TRACING
+	printf("dup3(0" FD0_PATH ", -4, 0) = %s\n", errstr);
+# endif
+
+	k_dup3(-5, 7, O_WRONLY);
+	printf("dup3(-5, 7" FD7_PATH ", 0x1 /* O_??? */) = %s\n", errstr);
+
+	k_dup3(7, -6, O_RDWR);
+	printf("dup3(7" FD7_PATH ", -6, 0x2 /* O_??? */) = %s\n", errstr);
+
+	k_dup3(7, 7, O_CLOEXEC);
+	printf("dup3(7" FD7_PATH ", 7" FD7_PATH ", O_CLOEXEC) = %s\n", errstr);
+
+	k_dup3(-7, -7, 7);
+# ifndef PATH_TRACING
+	printf("dup3(-7, -7, %s) = %s\n",
+#  ifdef __sparc__
+	       "O_NDELAY|0x3"
+#  else
+	       "0x7 /* O_??? */"
+#  endif
+	       , errstr);
+# endif
+
+	if (k_dup3(0, fd0, O_CLOEXEC) != fd0)
+		perror_msg_and_skip("dup3");
+# ifndef PATH_TRACING
+	printf("dup3(0" FD0_PATH ", %d" FD0_PATH ", O_CLOEXEC) = %d" FD0_PATH
+	       "\n", fd0, fd0);
+# endif
+
+	k_dup3(7, fd7, 0);
+	printf("dup3(7" FD7_PATH ", %d" FD7_PATH ", 0) = %d" FD7_PATH
+	       "\n", fd7, fd7);
+
+	k_dup3(0, fd7, O_CLOEXEC);
+	printf("dup3(0" FD0_PATH ", %d" FD7_PATH ", O_CLOEXEC) = %d" FD0_PATH
+	       "\n", fd7, fd7);
+
+	k_dup3(7, fd0, 0);
+	printf("dup3(7" FD7_PATH ", %d" FD0_PATH ", 0) = %d" FD7_PATH
+	       "\n", fd0, fd0);
+
+	close(fd0);
+	close(fd7);
+
+	k_dup3(0, fd0, O_CLOEXEC);
+# ifndef PATH_TRACING
+	printf("dup3(0" FD0_PATH ", %d, O_CLOEXEC) = %d" FD0_PATH "\n",
+	       fd0, fd0);
+# endif
+
+	k_dup3(7, fd7, 0);
+	printf("dup3(7" FD7_PATH ", %d, 0) = %d" FD7_PATH "\n",
+	       fd7, fd7);
 
 	puts("+++ exited with 0 +++");
 	return 0;
@@ -30,6 +142,6 @@ main(void)
 
 #else
 
-SKIP_MAIN_UNDEFINED("__NR_dup3 && O_CLOEXEC")
+SKIP_MAIN_UNDEFINED("__NR_dup3")
 
 #endif
diff -pruN 5.5-3/tests-mx32/dup3.gen.test 5.9-0ubuntu2/tests-mx32/dup3.gen.test
--- 5.5-3/tests-mx32/dup3.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dup3.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -1,4 +1,4 @@
 #!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup3 -a24 ); do not edit.
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup3 -a13 7>>/dev/full); do not edit.
 . "${srcdir=.}/init.sh"
-run_strace_match_diff -a24 
+run_strace_match_diff -a13 7>>/dev/full
diff -pruN 5.5-3/tests-mx32/dup3-P.c 5.9-0ubuntu2/tests-mx32/dup3-P.c
--- 5.5-3/tests-mx32/dup3-P.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dup3-P.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,4 @@
+#define PATH_TRACING
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup3.c"
diff -pruN 5.5-3/tests-mx32/dup3-P.gen.test 5.9-0ubuntu2/tests-mx32/dup3-P.gen.test
--- 5.5-3/tests-mx32/dup3-P.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dup3-P.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup3-P -a13 --trace=dup3 -P /dev/full 7>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a13 --trace=dup3 -P /dev/full 7>>/dev/full
diff -pruN 5.5-3/tests-mx32/dup3-y.c 5.9-0ubuntu2/tests-mx32/dup3-y.c
--- 5.5-3/tests-mx32/dup3-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dup3-y.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,5 @@
+#define FD0_PATH "</dev/null>"
+#define FD7_PATH "</dev/full>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup3.c"
diff -pruN 5.5-3/tests-mx32/dup3-y.gen.test 5.9-0ubuntu2/tests-mx32/dup3-y.gen.test
--- 5.5-3/tests-mx32/dup3-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dup3-y.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup3-y -a15 --trace=dup3 -y 7>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a15 --trace=dup3 -y 7>>/dev/full
diff -pruN 5.5-3/tests-mx32/dup3-yy.c 5.9-0ubuntu2/tests-mx32/dup3-yy.c
--- 5.5-3/tests-mx32/dup3-yy.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dup3-yy.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,5 @@
+#define FD0_PATH "</dev/null<char 1:3>>"
+#define FD7_PATH "</dev/full<char 1:7>>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup3.c"
diff -pruN 5.5-3/tests-mx32/dup3-yy.gen.test 5.9-0ubuntu2/tests-mx32/dup3-yy.gen.test
--- 5.5-3/tests-mx32/dup3-yy.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dup3-yy.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup3-yy -a15 --trace=dup3 -yy 7>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a15 --trace=dup3 -yy 7>>/dev/full
diff -pruN 5.5-3/tests-mx32/dup.c 5.9-0ubuntu2/tests-mx32/dup.c
--- 5.5-3/tests-mx32/dup.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dup.c	2020-04-24 23:03:14.000000000 +0000
@@ -1,20 +1,72 @@
 /*
- * Copyright (c) 2016-2018 The strace developers.
+ * Check decoding of dup syscall.
+ *
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-#include <stdio.h>
-#include <unistd.h>
+#include "scno.h"
+
+#ifdef __NR_dup
+
+# include <stdio.h>
+# include <unistd.h>
+
+# ifndef FD0_PATH
+#  define FD0_PATH ""
+# endif
+# ifndef FD9_PATH
+#  define FD9_PATH ""
+# endif
+# ifndef SKIP_IF_PROC_IS_UNAVAILABLE
+#  define SKIP_IF_PROC_IS_UNAVAILABLE
+# endif
+
+static const char *errstr;
+
+static long
+k_dup(const unsigned int fd)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+	const kernel_ulong_t arg1 = fill | fd;
+	const long rc = syscall(__NR_dup, arg1, bad, bad, bad, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
 
 int
 main(void)
 {
-	int rc = dup(-1);
-	printf("dup(-1) = %d %s (%m)\n", rc, errno2name());
+	SKIP_IF_PROC_IS_UNAVAILABLE;
+
+	k_dup(-1);
+# ifndef PATH_TRACING
+	printf("dup(-1) = %s\n", errstr);
+# endif
+
+	int d1 = k_dup(0);
+# ifndef PATH_TRACING
+	printf("dup(0" FD0_PATH ") = %d" FD0_PATH "\n", d1);
+# endif
+
+	int d2 = k_dup(d1);
+# ifndef PATH_TRACING
+	printf("dup(%d" FD0_PATH ") = %d" FD0_PATH "\n", d1, d2);
+# endif
+
+	d2 = k_dup(9);
+	printf("dup(9" FD9_PATH ") = %d" FD9_PATH "\n", d2);
 
 	puts("+++ exited with 0 +++");
 	return 0;
 }
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_dup")
+
+#endif
diff -pruN 5.5-3/tests-mx32/dup.gen.test 5.9-0ubuntu2/tests-mx32/dup.gen.test
--- 5.5-3/tests-mx32/dup.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dup.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -1,4 +1,4 @@
 #!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup -a8 ); do not edit.
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup -a7 9>>/dev/full); do not edit.
 . "${srcdir=.}/init.sh"
-run_strace_match_diff -a8 
+run_strace_match_diff -a7 9>>/dev/full
diff -pruN 5.5-3/tests-mx32/dup-P.c 5.9-0ubuntu2/tests-mx32/dup-P.c
--- 5.5-3/tests-mx32/dup-P.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dup-P.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,4 @@
+#define PATH_TRACING
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup.c"
diff -pruN 5.5-3/tests-mx32/dup-P.gen.test 5.9-0ubuntu2/tests-mx32/dup-P.gen.test
--- 5.5-3/tests-mx32/dup-P.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dup-P.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup-P -a7 --trace=dup -P /dev/full 9>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a7 --trace=dup -P /dev/full 9>>/dev/full
diff -pruN 5.5-3/tests-mx32/dup-y.c 5.9-0ubuntu2/tests-mx32/dup-y.c
--- 5.5-3/tests-mx32/dup-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dup-y.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,5 @@
+#define FD0_PATH "</dev/null>"
+#define FD9_PATH "</dev/full>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup.c"
diff -pruN 5.5-3/tests-mx32/dup-y.gen.test 5.9-0ubuntu2/tests-mx32/dup-y.gen.test
--- 5.5-3/tests-mx32/dup-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dup-y.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup-y -a8 --trace=dup -y 9>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a8 --trace=dup -y 9>>/dev/full
diff -pruN 5.5-3/tests-mx32/dup-yy.c 5.9-0ubuntu2/tests-mx32/dup-yy.c
--- 5.5-3/tests-mx32/dup-yy.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dup-yy.c	2020-04-24 23:03:14.000000000 +0000
@@ -0,0 +1,5 @@
+#define FD0_PATH "</dev/null<char 1:3>>"
+#define FD9_PATH "</dev/full<char 1:7>>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "dup.c"
diff -pruN 5.5-3/tests-mx32/dup-yy.gen.test 5.9-0ubuntu2/tests-mx32/dup-yy.gen.test
--- 5.5-3/tests-mx32/dup-yy.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/dup-yy.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (dup-yy -a8 --trace=dup -yy 9>>/dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a8 --trace=dup -yy 9>>/dev/full
diff -pruN 5.5-3/tests-mx32/faccessat2.c 5.9-0ubuntu2/tests-mx32/faccessat2.c
--- 5.5-3/tests-mx32/faccessat2.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/faccessat2.c	2020-09-23 16:29:35.000000000 +0000
@@ -0,0 +1,174 @@
+/*
+ * Check decoding of faccessat2 syscall.
+ *
+ * Copyright (c) 2016-2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+
+#ifdef __NR_faccessat2
+
+# include <fcntl.h>
+# include <stdio.h>
+# include <unistd.h>
+
+# define XLAT_MACROS_ONLY
+#  include "xlat/faccessat_flags.h"
+# undef XLAT_MACROS_ONLY
+
+# ifndef FD_PATH
+#  define FD_PATH ""
+# endif
+# ifndef SKIP_IF_PROC_IS_UNAVAILABLE
+#  define SKIP_IF_PROC_IS_UNAVAILABLE
+# endif
+
+static const char *errstr;
+
+static long
+k_faccessat2(const unsigned int dirfd,
+	     const void *const pathname,
+	     const unsigned int mode,
+	     const unsigned int flags)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+
+	const kernel_ulong_t arg1 = fill | dirfd;
+	const kernel_ulong_t arg2 = (uintptr_t) pathname;
+	const kernel_ulong_t arg3 = fill | mode;
+	const kernel_ulong_t arg4 = fill | flags;
+	const long rc = syscall(__NR_faccessat2,
+				arg1, arg2, arg3, arg4, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
+
+int
+main(void)
+{
+	SKIP_IF_PROC_IS_UNAVAILABLE;
+
+	TAIL_ALLOC_OBJECT_CONST_PTR(const char, unterminated);
+	char *unterminated_str;
+	if (asprintf(&unterminated_str, "%p", unterminated) < 0)
+                perror_msg_and_fail("asprintf");
+	const void *const efault = unterminated + 1;
+	char *efault_str;
+	if (asprintf(&efault_str, "%p", efault) < 0)
+                perror_msg_and_fail("asprintf");
+
+	typedef struct {
+		char sym;
+		char null;
+	} sym_null;
+
+	TAIL_ALLOC_OBJECT_CONST_PTR(sym_null, dot);
+	dot->sym = '.';
+	dot->null = '\0';
+	const char *const null = &dot->null;
+
+	TAIL_ALLOC_OBJECT_CONST_PTR(sym_null, slash);
+	slash->sym = '/';
+	slash->null = '\0';
+
+	static const char path[] = "/dev/full";
+	const char *const fd_path = tail_memdup(path, sizeof(path));
+        int fd = open(path, O_WRONLY);
+        if (fd < 0)
+                perror_msg_and_fail("open: %s", path);
+	char *fd_str;
+	if (asprintf(&fd_str, "%d%s", fd, FD_PATH) < 0)
+                perror_msg_and_fail("asprintf");
+	char *path_quoted;
+	if (asprintf(&path_quoted, "\"%s\"", path) < 0)
+                perror_msg_and_fail("asprintf");
+
+	struct {
+		int val;
+		const char *str;
+	} dirfds[] = {
+		{ ARG_STR(-1) },
+		{ -100, "AT_FDCWD" },
+		{ fd, fd_str },
+	}, modes[] = {
+		{ ARG_STR(F_OK) },
+		{ ARG_STR(R_OK) },
+		{ ARG_STR(W_OK) },
+		{ ARG_STR(X_OK) },
+		{ ARG_STR(R_OK|W_OK) },
+		{ ARG_STR(R_OK|X_OK) },
+		{ ARG_STR(W_OK|X_OK) },
+		{ ARG_STR(R_OK|W_OK|X_OK) },
+		{ 8, "0x8 /* ?_OK */" },
+		{ -1, "R_OK|W_OK|X_OK|0xfffffff8" },
+	}, flags[] = {
+		{ ARG_STR(0) },
+		{ ARG_STR(AT_SYMLINK_NOFOLLOW) },
+		{ ARG_STR(AT_EACCESS) },
+		{ ARG_STR(AT_EMPTY_PATH) },
+		{ ARG_STR(AT_SYMLINK_NOFOLLOW|AT_EACCESS) },
+		{ ARG_STR(AT_SYMLINK_NOFOLLOW|AT_EMPTY_PATH) },
+		{ ARG_STR(AT_EACCESS|AT_EMPTY_PATH) },
+		{ ARG_STR(AT_SYMLINK_NOFOLLOW|AT_EACCESS|AT_EMPTY_PATH) },
+		{ 1, "0x1 /* AT_??? */" },
+		{ -1, "AT_SYMLINK_NOFOLLOW|AT_EACCESS|AT_EMPTY_PATH|0xffffecff" },
+	};
+
+	struct {
+		const void *val;
+		const char *str;
+	} paths[] = {
+		{ 0, "NULL" },
+		{ efault, efault_str },
+		{ unterminated, unterminated_str },
+		{ null, "\"\"" },
+		{ &dot->sym, "\".\"" },
+		{ &slash->sym, "\"/\"" },
+		{ fd_path, path_quoted },
+	};
+
+	for (unsigned int dirfd_i = 0;
+	     dirfd_i < ARRAY_SIZE(dirfds);
+	     ++dirfd_i) {
+		for (unsigned int path_i = 0;
+		     path_i < ARRAY_SIZE(paths);
+		     ++path_i) {
+			for (unsigned int mode_i = 0;
+			     mode_i < ARRAY_SIZE(modes);
+			     ++mode_i) {
+				for (unsigned int flag_i = 0;
+				     flag_i < ARRAY_SIZE(flags);
+				     ++flag_i) {
+					k_faccessat2(dirfds[dirfd_i].val,
+						    paths[path_i].val,
+						    modes[mode_i].val,
+						    flags[flag_i].val);
+# ifdef PATH_TRACING
+					if (dirfds[dirfd_i].val == fd ||
+					    paths[path_i].val == fd_path)
+# endif
+					printf("faccessat2(%s, %s, %s, %s) = %s\n",
+					       dirfds[dirfd_i].str,
+					       paths[path_i].str,
+					       modes[mode_i].str,
+					       flags[flag_i].str,
+					       errstr);
+				}
+			}
+		}
+	}
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_faccessat2")
+
+#endif
diff -pruN 5.5-3/tests-mx32/faccessat2-P.c 5.9-0ubuntu2/tests-mx32/faccessat2-P.c
--- 5.5-3/tests-mx32/faccessat2-P.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/faccessat2-P.c	2020-07-04 08:00:00.000000000 +0000
@@ -0,0 +1,4 @@
+#define PATH_TRACING
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "faccessat2.c"
diff -pruN 5.5-3/tests-mx32/faccessat2-P.gen.test 5.9-0ubuntu2/tests-mx32/faccessat2-P.gen.test
--- 5.5-3/tests-mx32/faccessat2-P.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/faccessat2-P.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (faccessat2-P -a27 --trace=faccessat2 -P /dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a27 --trace=faccessat2 -P /dev/full
diff -pruN 5.5-3/tests-mx32/faccessat2.test 5.9-0ubuntu2/tests-mx32/faccessat2.test
--- 5.5-3/tests-mx32/faccessat2.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/faccessat2.test	2020-07-04 08:00:00.000000000 +0000
@@ -0,0 +1,19 @@
+#!/bin/sh
+#
+# Check decoding of faccessat2 syscall.
+#
+# Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
+# All rights reserved.
+#
+# SPDX-License-Identifier: GPL-2.0-or-later
+
+. "${srcdir=.}/init.sh"
+
+check_prog sed
+
+run_prog > /dev/null
+run_strace -a27 --trace=faccessat2 "$@" $args > "$EXP"
+
+# Filter out faccessat2() calls made by ld.so and libc.
+sed -n '/^faccessat2(-1, NULL,/,$p' < "$LOG" > "$OUT"
+match_diff "$OUT" "$EXP"
diff -pruN 5.5-3/tests-mx32/faccessat2-y.c 5.9-0ubuntu2/tests-mx32/faccessat2-y.c
--- 5.5-3/tests-mx32/faccessat2-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/faccessat2-y.c	2020-07-04 08:00:00.000000000 +0000
@@ -0,0 +1,4 @@
+#define FD_PATH "</dev/full>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "faccessat2.c"
diff -pruN 5.5-3/tests-mx32/faccessat2-y.gen.test 5.9-0ubuntu2/tests-mx32/faccessat2-y.gen.test
--- 5.5-3/tests-mx32/faccessat2-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/faccessat2-y.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (faccessat2-y +faccessat2.test -a28 -y); do not edit.
+set -- -a28 -y
+. "${srcdir=.}/faccessat2.test"
diff -pruN 5.5-3/tests-mx32/faccessat2-yy.c 5.9-0ubuntu2/tests-mx32/faccessat2-yy.c
--- 5.5-3/tests-mx32/faccessat2-yy.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/faccessat2-yy.c	2020-07-04 08:00:00.000000000 +0000
@@ -0,0 +1,4 @@
+#define FD_PATH "</dev/full<char 1:7>>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "faccessat2.c"
diff -pruN 5.5-3/tests-mx32/faccessat2-yy.gen.test 5.9-0ubuntu2/tests-mx32/faccessat2-yy.gen.test
--- 5.5-3/tests-mx32/faccessat2-yy.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/faccessat2-yy.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (faccessat2-yy +faccessat2.test -a28 -yy); do not edit.
+set -- -a28 -yy
+. "${srcdir=.}/faccessat2.test"
diff -pruN 5.5-3/tests-mx32/faccessat.c 5.9-0ubuntu2/tests-mx32/faccessat.c
--- 5.5-3/tests-mx32/faccessat.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/faccessat.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,5 +1,7 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Check decoding of faccessat syscall.
+ *
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,18 +12,133 @@
 
 #ifdef __NR_faccessat
 
+# include <fcntl.h>
 # include <stdio.h>
 # include <unistd.h>
 
+# ifndef FD_PATH
+#  define FD_PATH ""
+# endif
+# ifndef SKIP_IF_PROC_IS_UNAVAILABLE
+#  define SKIP_IF_PROC_IS_UNAVAILABLE
+# endif
+
+static const char *errstr;
+
+static long
+k_faccessat(const unsigned int dirfd,
+	    const void *const pathname,
+	    const unsigned int mode)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+
+	const kernel_ulong_t arg1 = fill | dirfd;
+	const kernel_ulong_t arg2 = (uintptr_t) pathname;
+	const kernel_ulong_t arg3 = fill | mode;
+	const long rc = syscall(__NR_faccessat,
+				arg1, arg2, arg3, bad, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
+
 int
 main(void)
 {
-	static const char sample[] = "faccessat.sample";
-	const long int fd = (long int) 0xdeadbeefffffffffULL;
+	SKIP_IF_PROC_IS_UNAVAILABLE;
 
-	long rc = syscall(__NR_faccessat, fd, sample, F_OK);
-	printf("faccessat(%d, \"%s\", F_OK) = %ld %s (%m)\n",
-	       (int) fd, sample, rc, errno2name());
+	TAIL_ALLOC_OBJECT_CONST_PTR(const char, unterminated);
+	char *unterminated_str;
+	if (asprintf(&unterminated_str, "%p", unterminated) < 0)
+                perror_msg_and_fail("asprintf");
+	const void *const efault = unterminated + 1;
+	char *efault_str;
+	if (asprintf(&efault_str, "%p", efault) < 0)
+                perror_msg_and_fail("asprintf");
+
+	typedef struct {
+		char sym;
+		char null;
+	} sym_null;
+
+	TAIL_ALLOC_OBJECT_CONST_PTR(sym_null, dot);
+	dot->sym = '.';
+	dot->null = '\0';
+	const char *const null = &dot->null;
+
+	TAIL_ALLOC_OBJECT_CONST_PTR(sym_null, slash);
+	slash->sym = '/';
+	slash->null = '\0';
+
+	static const char path[] = "/dev/full";
+	const char *const fd_path = tail_memdup(path, sizeof(path));
+        int fd = open(path, O_WRONLY);
+        if (fd < 0)
+                perror_msg_and_fail("open: %s", path);
+	char *fd_str;
+	if (asprintf(&fd_str, "%d%s", fd, FD_PATH) < 0)
+                perror_msg_and_fail("asprintf");
+	char *path_quoted;
+	if (asprintf(&path_quoted, "\"%s\"", path) < 0)
+                perror_msg_and_fail("asprintf");
+
+	struct {
+		int val;
+		const char *str;
+	} dirfds[] = {
+		{ ARG_STR(-1) },
+		{ -100, "AT_FDCWD" },
+		{ fd, fd_str },
+	}, modes[] = {
+		{ ARG_STR(F_OK) },
+		{ ARG_STR(R_OK) },
+		{ ARG_STR(W_OK) },
+		{ ARG_STR(X_OK) },
+		{ ARG_STR(R_OK|W_OK) },
+		{ ARG_STR(R_OK|X_OK) },
+		{ ARG_STR(W_OK|X_OK) },
+		{ ARG_STR(R_OK|W_OK|X_OK) },
+		{ 8, "0x8 /* ?_OK */" },
+		{ -1, "R_OK|W_OK|X_OK|0xfffffff8" },
+	};
+
+	struct {
+		const void *val;
+		const char *str;
+	} paths[] = {
+		{ 0, "NULL" },
+		{ efault, efault_str },
+		{ unterminated, unterminated_str },
+		{ null, "\"\"" },
+		{ &dot->sym, "\".\"" },
+		{ &slash->sym, "\"/\"" },
+		{ fd_path, path_quoted },
+	};
+
+	for (unsigned int dirfd_i = 0;
+	     dirfd_i < ARRAY_SIZE(dirfds);
+	     ++dirfd_i) {
+		for (unsigned int path_i = 0;
+		     path_i < ARRAY_SIZE(paths);
+		     ++path_i) {
+			for (unsigned int mode_i = 0;
+			     mode_i < ARRAY_SIZE(modes);
+			     ++mode_i) {
+				k_faccessat(dirfds[dirfd_i].val,
+					    paths[path_i].val,
+					    modes[mode_i].val);
+# ifdef PATH_TRACING
+				if (dirfds[dirfd_i].val == fd ||
+				    paths[path_i].val == fd_path)
+# endif
+				printf("faccessat(%s, %s, %s) = %s\n",
+				       dirfds[dirfd_i].str,
+				       paths[path_i].str,
+				       modes[mode_i].str,
+				       errstr);
+			}
+		}
+	}
 
 	puts("+++ exited with 0 +++");
 	return 0;
diff -pruN 5.5-3/tests-mx32/faccessat.gen.test 5.9-0ubuntu2/tests-mx32/faccessat.gen.test
--- 5.5-3/tests-mx32/faccessat.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/faccessat.gen.test	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-#!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (faccessat -P $NAME.sample); do not edit.
-. "${srcdir=.}/init.sh"
-run_strace_match_diff -P $NAME.sample
diff -pruN 5.5-3/tests-mx32/faccessat-P.c 5.9-0ubuntu2/tests-mx32/faccessat-P.c
--- 5.5-3/tests-mx32/faccessat-P.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/faccessat-P.c	2020-07-04 08:00:00.000000000 +0000
@@ -0,0 +1,4 @@
+#define PATH_TRACING
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "faccessat.c"
diff -pruN 5.5-3/tests-mx32/faccessat-P.gen.test 5.9-0ubuntu2/tests-mx32/faccessat-P.gen.test
--- 5.5-3/tests-mx32/faccessat-P.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/faccessat-P.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (faccessat-P -a23 --trace=faccessat -P /dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a23 --trace=faccessat -P /dev/full
diff -pruN 5.5-3/tests-mx32/faccessat.test 5.9-0ubuntu2/tests-mx32/faccessat.test
--- 5.5-3/tests-mx32/faccessat.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/faccessat.test	2020-07-04 08:00:00.000000000 +0000
@@ -0,0 +1,19 @@
+#!/bin/sh
+#
+# Check decoding of faccessat syscall.
+#
+# Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
+# All rights reserved.
+#
+# SPDX-License-Identifier: GPL-2.0-or-later
+
+. "${srcdir=.}/init.sh"
+
+check_prog sed
+
+run_prog > /dev/null
+run_strace -a23 --trace=faccessat "$@" $args > "$EXP"
+
+# Filter out faccessat() calls made by ld.so and libc.
+sed -n '/^faccessat(-1, NULL,/,$p' < "$LOG" > "$OUT"
+match_diff "$OUT" "$EXP"
diff -pruN 5.5-3/tests-mx32/faccessat-y.c 5.9-0ubuntu2/tests-mx32/faccessat-y.c
--- 5.5-3/tests-mx32/faccessat-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/faccessat-y.c	2020-07-04 08:00:00.000000000 +0000
@@ -0,0 +1,4 @@
+#define FD_PATH "</dev/full>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "faccessat.c"
diff -pruN 5.5-3/tests-mx32/faccessat-y.gen.test 5.9-0ubuntu2/tests-mx32/faccessat-y.gen.test
--- 5.5-3/tests-mx32/faccessat-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/faccessat-y.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (faccessat-y +faccessat.test -a24 -y); do not edit.
+set -- -a24 -y
+. "${srcdir=.}/faccessat.test"
diff -pruN 5.5-3/tests-mx32/faccessat-yy.c 5.9-0ubuntu2/tests-mx32/faccessat-yy.c
--- 5.5-3/tests-mx32/faccessat-yy.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/faccessat-yy.c	2020-07-04 08:00:00.000000000 +0000
@@ -0,0 +1,4 @@
+#define FD_PATH "</dev/full<char 1:7>>"
+#define SKIP_IF_PROC_IS_UNAVAILABLE skip_if_unavailable("/proc/self/fd/")
+
+#include "faccessat.c"
diff -pruN 5.5-3/tests-mx32/faccessat-yy.gen.test 5.9-0ubuntu2/tests-mx32/faccessat-yy.gen.test
--- 5.5-3/tests-mx32/faccessat-yy.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/faccessat-yy.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (faccessat-yy +faccessat.test -a24 -yy); do not edit.
+set -- -a24 -yy
+. "${srcdir=.}/faccessat.test"
diff -pruN 5.5-3/tests-mx32/fanotify_init.c 5.9-0ubuntu2/tests-mx32/fanotify_init.c
--- 5.5-3/tests-mx32/fanotify_init.c	2019-07-16 17:46:47.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/fanotify_init.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of fanotify_init syscall.
  *
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -44,13 +44,14 @@ main(void)
 		{ F8ILL_KULONG_MASK, "FAN_CLASS_NOTIF" },
 		{ (kernel_ulong_t) 0xffffffff0000000cULL,
 			"0xc /* FAN_CLASS_??? */" },
-		{ (kernel_ulong_t) 0xdec0deddefacec04ULL,
-			"FAN_CLASS_CONTENT|0xefacec00 /* FAN_??? */" },
+		{ (kernel_ulong_t) 0xdec0deddeface004ULL,
+			"FAN_CLASS_CONTENT|0xeface000 /* FAN_??? */" },
 		{ (kernel_ulong_t) 0xffffffffffffffffULL,
 			"0xc /* FAN_CLASS_??? */|FAN_CLOEXEC|FAN_NONBLOCK|"
 			"FAN_UNLIMITED_QUEUE|FAN_UNLIMITED_MARKS|"
 			"FAN_ENABLE_AUDIT|FAN_REPORT_TID|FAN_REPORT_FID|"
-			"0xfffffc80" },
+			"FAN_REPORT_DIR_FID|FAN_REPORT_NAME|"
+			"0xfffff080" },
 	};
 	static const struct strval event_f_flags[] = {
 		{ F8ILL_KULONG_MASK, "O_RDONLY" },
diff -pruN 5.5-3/tests-mx32/fanotify_mark.c 5.9-0ubuntu2/tests-mx32/fanotify_mark.c
--- 5.5-3/tests-mx32/fanotify_mark.c	2019-07-16 17:46:47.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/fanotify_mark.c	2020-04-15 13:39:57.000000000 +0000
@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -68,11 +68,6 @@ struct strval {
 	const char *str;
 };
 
-struct strval64 {
-	uint64_t val;
-	const char *str;
-};
-
 # define STR16 "0123456789abcdef"
 # define STR64 STR16 STR16 STR16 STR16
 
@@ -150,15 +145,16 @@ main(void)
 			"FAN_OPEN_PERM|"
 			"FAN_ACCESS_PERM|"
 			"FAN_OPEN_EXEC_PERM|"
+			"FAN_DIR_MODIFY|"
 			"FAN_ONDIR|"
 			"FAN_EVENT_ON_CHILD|"
-			"0xdeadfeedb7f8a000"
+			"0xdeadfeedb7f0a000"
 # endif
 # if XLAT_VERBOSE
 			" */"
 # endif
 			},
-		{ ARG_ULL_STR(0xffffffffb7f8a000)
+		{ ARG_ULL_STR(0xffffffffb7f0a000)
 # if !XLAT_RAW
 			" /* FAN_??? */"
 # endif
diff -pruN 5.5-3/tests-mx32/fchmod.c 5.9-0ubuntu2/tests-mx32/fchmod.c
--- 5.5-3/tests-mx32/fchmod.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/fchmod.c	2020-06-01 14:15:16.000000000 +0000
@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2016 Fabien Siron <fabien.siron@epita.fr>
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -22,14 +22,7 @@
 int
 main(void)
 {
-	static const char fname[] = "fchmod_test_file";
-
-	int fd = open(fname, O_CREAT|O_RDONLY, 0400);
-	if (fd < 0)
-		perror_msg_and_fail("open");
-
-	if (unlink(fname))
-		perror_msg_and_fail("unlink");
+	int fd = create_tmpfile(O_RDWR);
 
 	long rc = syscall(__NR_fchmod, fd, 0600);
 	printf("fchmod(%d, 0600) = %s\n", fd, sprintrc(rc));
diff -pruN 5.5-3/tests-mx32/fcntl64.c 5.9-0ubuntu2/tests-mx32/fcntl64.c
--- 5.5-3/tests-mx32/fcntl64.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/fcntl64.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -27,6 +27,7 @@ test_flock64_lk64(void)
 	fl->l_len = FILE_LEN;
 
 	long rc = invoke_test_syscall(0, F_SETLK64, fl);
+	pidns_print_leader();
 	printf("%s(0, F_SETLK64, {l_type=F_RDLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d}) = %s\n",
 	       TEST_SYSCALL_STR, FILE_LEN, errstr);
@@ -35,11 +36,13 @@ test_flock64_lk64(void)
 		return;
 
 	invoke_test_syscall(0, F_GETLK64, fl);
+	pidns_print_leader();
 	printf("%s(0, F_GETLK64, {l_type=F_UNLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d, l_pid=0}) = 0\n",
 	       TEST_SYSCALL_STR, FILE_LEN);
 
 	invoke_test_syscall(0, F_SETLKW64, fl);
+	pidns_print_leader();
 	printf("%s(0, F_SETLKW64, {l_type=F_UNLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d}) = 0\n",
 	       TEST_SYSCALL_STR, FILE_LEN);
diff -pruN 5.5-3/tests-mx32/fcntl64--pidns-translation.c 5.9-0ubuntu2/tests-mx32/fcntl64--pidns-translation.c
--- 5.5-3/tests-mx32/fcntl64--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/fcntl64--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "fcntl64.c"
diff -pruN 5.5-3/tests-mx32/fcntl64--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/fcntl64--pidns-translation.gen.test
--- 5.5-3/tests-mx32/fcntl64--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/fcntl64--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (fcntl64--pidns-translation test_pidns -a8 -e trace=fcntl64); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a8 -e trace=fcntl64
diff -pruN 5.5-3/tests-mx32/fcntl.c 5.9-0ubuntu2/tests-mx32/fcntl.c
--- 5.5-3/tests-mx32/fcntl.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/fcntl.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -24,6 +24,7 @@ test_flock64_undecoded(const int cmd, co
 		.l_len = 0xdefaced2cafef00dULL
 	};
 	invoke_test_syscall(0, cmd, &fl);
+	pidns_print_leader();
 	printf("%s(0, %s, %p) = %s\n",
 	       TEST_SYSCALL_STR, name, &fl, errstr);
 }
diff -pruN 5.5-3/tests-mx32/fcntl-common.c 5.9-0ubuntu2/tests-mx32/fcntl-common.c
--- 5.5-3/tests-mx32/fcntl-common.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/fcntl-common.c	2020-08-25 14:29:30.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -13,6 +13,8 @@
 #include <unistd.h>
 #include <assert.h>
 #include "flock.h"
+#include "pidns.h"
+#include "scno.h"
 
 #define FILE_LEN 4096
 
@@ -48,12 +50,14 @@ test_flock_einval(const int cmd, const c
 	fl->l_len = (TYPEOF_FLOCK_OFF_T) 0xdefaced2cafef00dULL;
 
 	invoke_test_syscall(0, cmd, fl);
+	pidns_print_leader();
 	printf("%s(0, %s, {l_type=F_RDLCK, l_whence=SEEK_SET"
 	       ", l_start=%jd, l_len=%jd}) = %s\n", TEST_SYSCALL_STR, name,
 	       (intmax_t) fl->l_start, (intmax_t) fl->l_len, errstr);
 
 	void *const bad_addr = (void *) fl + 1;
 	invoke_test_syscall(0, cmd, bad_addr);
+	pidns_print_leader();
 	printf("%s(0, %s, %p) = %s\n",
 	       TEST_SYSCALL_STR, name, bad_addr, errstr);
 }
@@ -72,12 +76,14 @@ test_flock64_einval(const int cmd, const
 	fl->l_len = (TYPEOF_FLOCK_OFF_T) 0xdefaced2cafef00dULL;
 
 	invoke_test_syscall(0, cmd, fl);
+	pidns_print_leader();
 	printf("%s(0, %s, {l_type=F_RDLCK, l_whence=SEEK_SET"
 	       ", l_start=%jd, l_len=%jd}) = %s\n", TEST_SYSCALL_STR, name,
 	       (intmax_t) fl->l_start, (intmax_t) fl->l_len, errstr);
 
 	void *const bad_addr = (void *) fl + 1;
 	invoke_test_syscall(0, cmd, bad_addr);
+	pidns_print_leader();
 	printf("%s(0, %s, %p) = %s\n",
 	       TEST_SYSCALL_STR, name, bad_addr, errstr);
 }
@@ -94,6 +100,7 @@ test_flock(void)
 	fl->l_len = FILE_LEN;
 
 	long rc = invoke_test_syscall(0, F_SETLK, fl);
+	pidns_print_leader();
 	printf("%s(0, F_SETLK, {l_type=F_RDLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d}) = %s\n",
 	       TEST_SYSCALL_STR, FILE_LEN, errstr);
@@ -101,11 +108,13 @@ test_flock(void)
 		return;
 
 	invoke_test_syscall(0, F_GETLK, fl);
+	pidns_print_leader();
 	printf("%s(0, F_GETLK, {l_type=F_UNLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d, l_pid=0}) = 0\n",
 	       TEST_SYSCALL_STR, FILE_LEN);
 
 	invoke_test_syscall(0, F_SETLKW, fl);
+	pidns_print_leader();
 	printf("%s(0, F_SETLKW, {l_type=F_UNLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d}) = 0\n",
 	       TEST_SYSCALL_STR, FILE_LEN);
@@ -124,6 +133,7 @@ test_flock64_ofd(void)
 	fl->l_len = FILE_LEN;
 
 	long rc = invoke_test_syscall(0, F_OFD_SETLK, fl);
+	pidns_print_leader();
 	printf("%s(0, F_OFD_SETLK, {l_type=F_RDLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d}) = %s\n",
 	       TEST_SYSCALL_STR, FILE_LEN, errstr);
@@ -131,11 +141,13 @@ test_flock64_ofd(void)
 		return;
 
 	invoke_test_syscall(0, F_OFD_GETLK, fl);
+	pidns_print_leader();
 	printf("%s(0, F_OFD_GETLK, {l_type=F_UNLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d, l_pid=0}) = 0\n",
 	       TEST_SYSCALL_STR, FILE_LEN);
 
 	invoke_test_syscall(0, F_OFD_SETLKW, fl);
+	pidns_print_leader();
 	printf("%s(0, F_OFD_SETLKW, {l_type=F_UNLCK, l_whence=SEEK_SET"
 	       ", l_start=0, l_len=%d}) = 0\n",
 	       TEST_SYSCALL_STR, FILE_LEN);
@@ -167,18 +179,21 @@ test_flock64(void)
 static long
 test_f_owner_ex_type_pid(const int cmd, const char *const cmd_name,
 			 const int type, const char *const type_name,
-			 pid_t pid)
+			 enum pid_type pid_type, pid_t pid)
 {
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct_kernel_f_owner_ex, fo);
 
 	fo->type = type;
 	fo->pid = pid;
 	long rc = invoke_test_syscall(0, cmd, fo);
-	printf("%s(0, %s, {type=%s, pid=%d}) = %s\n",
-	       TEST_SYSCALL_STR, cmd_name, type_name, fo->pid, errstr);
+	pidns_print_leader();
+	printf("%s(0, %s, {type=%s, pid=%d%s}) = %s\n",
+	       TEST_SYSCALL_STR, cmd_name, type_name,
+	       fo->pid, pidns_pid2str(pid_type), errstr);
 
 	void *bad_addr = (void *) fo + 1;
 	invoke_test_syscall(0, cmd, bad_addr);
+	pidns_print_leader();
 	printf("%s(0, %s, %p) = %s\n",
 	       TEST_SYSCALL_STR, cmd_name, bad_addr, errstr);
 
@@ -187,35 +202,35 @@ test_f_owner_ex_type_pid(const int cmd,
 
 static void
 test_f_owner_ex_umove_or_printaddr(const int type, const char *const type_name,
-				   pid_t pid)
+				   enum pid_type pid_type, pid_t pid)
 {
 	long rc = test_f_owner_ex_type_pid(ARG_STR(F_SETOWN_EX),
-					   type, type_name, pid);
+					   type, type_name, pid_type, pid);
 	if (!rc)
 		test_f_owner_ex_type_pid(ARG_STR(F_GETOWN_EX),
-					 type, type_name, pid);
+					 type, type_name, pid_type, pid);
 }
 
 static void
 test_f_owner_ex(void)
 {
-	static const struct {
+	struct {
 		int type;
 		const char *type_name;
-		pid_t pid[2];
+		enum pid_type pid_type;
+		pid_t pid;
 	} a[] = {
-		{ ARG_STR(F_OWNER_TID), { 1234567890, 20 } },
-		{ ARG_STR(F_OWNER_PID), { 1298126790, 30 } },
-		{ ARG_STR(F_OWNER_PGRP), { 1294567890, 40 } }
+		{ ARG_STR(F_OWNER_TID), PT_NONE, 1234567890 },
+		{ ARG_STR(F_OWNER_PID), PT_NONE, 1234567890 },
+		{ ARG_STR(F_OWNER_PGRP), PT_NONE, 1234567890 },
+		{ ARG_STR(F_OWNER_TID), PT_TID, syscall(__NR_gettid) },
+		{ ARG_STR(F_OWNER_PID), PT_TGID, getpid() },
+		{ ARG_STR(F_OWNER_PGRP), PT_PGID, getpgid(0) },
 	};
 
-	for (unsigned int i = 0; i < ARRAY_SIZE(a); i++) {
-		for (unsigned int j = 0; j < ARRAY_SIZE(a[0].pid); j++) {
-			test_f_owner_ex_umove_or_printaddr(a[i].type,
-							   a[i].type_name,
-							   a[i].pid[j]);
-		}
-	}
+	for (unsigned int i = 0; i < ARRAY_SIZE(a); i++)
+		test_f_owner_ex_umove_or_printaddr(a[i].type, a[i].type_name,
+			a[i].pid_type, a[i].pid);
 }
 #endif /* TEST_F_OWNER_EX */
 
@@ -229,6 +244,23 @@ struct fcntl_cmd_check {
 };
 
 static void
+test_xetown(void)
+{
+	const int pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
+
+	invoke_test_syscall(0, F_SETOWN, (void *) (intptr_t) pid);
+	pidns_print_leader();
+	printf("%s(0, F_SETOWN, %d%s) = %s\n",
+		TEST_SYSCALL_STR, pid, pid_str, errstr);
+
+	invoke_test_syscall(0, F_GETOWN, NULL);
+	pidns_print_leader();
+	printf("%s(0, F_GETOWN) = %d%s\n",
+		TEST_SYSCALL_STR, pid, pid_str);
+}
+
+static void
 print_retval_flags(const struct fcntl_cmd_check *check, long rc)
 {
 	if (check->print_flags) {
@@ -243,12 +275,14 @@ static void
 test_other_set_cmd(const struct fcntl_cmd_check *check)
 {
 	invoke_test_syscall(check->fd, check->cmd, (void *) check->arg);
+	pidns_print_leader();
 	printf("%s(%d, %s, %s) = %s\n",
 	       TEST_SYSCALL_STR, check->fd,
 	       check->cmd_str, check->arg_str, errstr);
 
 	/* bad file fd */
 	invoke_test_syscall(-1, check->cmd, (void *) check->arg);
+	pidns_print_leader();
 	printf("%s(-1, %s, %s) = %s\n",
 	       TEST_SYSCALL_STR, check->cmd_str,
 	       check->arg_str, errstr);
@@ -258,12 +292,14 @@ static void
 test_other_get_cmd(const struct fcntl_cmd_check *check)
 {
 	long rc = invoke_test_syscall(check->fd, check->cmd, NULL);
+	pidns_print_leader();
 	printf("%s(%d, %s) = ",
 	       TEST_SYSCALL_STR, check->fd, check->cmd_str);
 	print_retval_flags(check, rc);
 
 	/* bad file fd */
 	invoke_test_syscall(-1, check->cmd, NULL);
+	pidns_print_leader();
 	printf("%s(-1, %s) = %s\n",
 	       TEST_SYSCALL_STR, check->cmd_str, errstr);
 }
@@ -315,7 +351,6 @@ test_fcntl_others(void)
 {
 	static const struct fcntl_cmd_check set_checks[] = {
 		{ 0, ARG_STR(F_SETFD), ARG_STR(FD_CLOEXEC) },
-		{ 0, ARG_STR(F_SETOWN), ARG_STR(20) },
 #ifdef F_SETPIPE_SZ
 		{ 0, ARG_STR(F_SETPIPE_SZ), ARG_STR(4097) },
 #endif
@@ -336,7 +371,6 @@ test_fcntl_others(void)
 	static const struct fcntl_cmd_check get_checks[] = {
 		{ 0, ARG_STR(F_GETFD), .print_flags = print_flags_getfd },
 		{ 1, ARG_STR(F_GETFD), .print_flags = print_flags_getfd },
-		{ 0, ARG_STR(F_GETOWN) },
 #ifdef F_GETPIPE_SZ
 		{ 0, ARG_STR(F_GETPIPE_SZ) },
 #endif
@@ -352,20 +386,16 @@ test_fcntl_others(void)
 static void
 create_sample(void)
 {
-	char fname[] = TEST_SYSCALL_STR "_XXXXXX";
-
 	(void) close(0);
-	if (mkstemp(fname))
-		perror_msg_and_fail("mkstemp: %s", fname);
-	if (unlink(fname))
-		perror_msg_and_fail("unlink: %s", fname);
-	if (ftruncate(0, FILE_LEN))
+	if (ftruncate(create_tmpfile(O_RDWR), FILE_LEN))
 		perror_msg_and_fail("ftruncate");
 }
 
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	create_sample();
 	test_flock();
 	test_flock64();
@@ -373,7 +403,9 @@ main(void)
 	test_f_owner_ex();
 #endif
 	test_fcntl_others();
+	test_xetown();
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/fcntl--pidns-translation.c 5.9-0ubuntu2/tests-mx32/fcntl--pidns-translation.c
--- 5.5-3/tests-mx32/fcntl--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/fcntl--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "fcntl.c"
diff -pruN 5.5-3/tests-mx32/fcntl--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/fcntl--pidns-translation.gen.test
--- 5.5-3/tests-mx32/fcntl--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/fcntl--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (fcntl--pidns-translation test_pidns -a8 -e trace=fcntl); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a8 -e trace=fcntl
diff -pruN 5.5-3/tests-mx32/file_ioctl.c 5.9-0ubuntu2/tests-mx32/file_ioctl.c
--- 5.5-3/tests-mx32/file_ioctl.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/file_ioctl.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -11,6 +11,7 @@
 
 # include <stdio.h>
 # include <sys/ioctl.h>
+# include <linux/types.h>
 # include <linux/fiemap.h>
 # include <linux/fs.h>
 # include "xlat.h"
diff -pruN 5.5-3/tests-mx32/fill_memory.c 5.9-0ubuntu2/tests-mx32/fill_memory.c
--- 5.5-3/tests-mx32/fill_memory.c	2019-03-18 02:40:16.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/fill_memory.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -24,3 +24,39 @@ fill_memory(void *ptr, size_t size)
 {
 	fill_memory_ex(ptr, size, 0x80, 0x80);
 }
+
+void
+fill_memory16_ex(void *ptr, size_t size, uint16_t start,
+	         unsigned int period)
+{
+	uint16_t *p = ptr;
+	size_t i;
+
+	for (i = 0; i < size / sizeof(uint16_t); i++) {
+		p[i] = start + i % period;
+	}
+}
+
+void
+fill_memory16(void *ptr, size_t size)
+{
+	fill_memory16_ex(ptr, size, 0x80c0, 0x8000);
+}
+
+void
+fill_memory32_ex(void *ptr, size_t size, uint32_t start,
+	         unsigned int period)
+{
+	uint32_t *p = ptr;
+	size_t i;
+
+	for (i = 0; i < size / sizeof(uint32_t); i++) {
+		p[i] = start + i % period;
+	}
+}
+
+void
+fill_memory32(void *ptr, size_t size)
+{
+	fill_memory32_ex(ptr, size, 0x80a0c0e0, 0x80000000);
+}
diff -pruN 5.5-3/tests-mx32/filter_seccomp-flag.c 5.9-0ubuntu2/tests-mx32/filter_seccomp-flag.c
--- 5.5-3/tests-mx32/filter_seccomp-flag.c	2019-11-15 22:33:53.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/filter_seccomp-flag.c	2020-04-15 13:39:57.000000000 +0000
@@ -2,7 +2,7 @@
  * Check that syscall numbers do not conflict with seccomp filter flags.
  *
  * Copyright (c) 2019 Paul Chaignon <paul.chaignon@gmail.com>
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -22,12 +22,6 @@
 # undef XLAT_MACROS_ONLY
 #endif
 
-#ifdef __x86_64__
-# ifndef __X32_SYSCALL_BIT
-#  define __X32_SYSCALL_BIT     0x40000000
-# endif
-#endif
-
 /* Define these shorthand notations to simplify the syscallent files. */
 #include "sysent_shorthand_defs.h"
 
@@ -36,13 +30,13 @@ const struct_sysent sysent0[] = {
 };
 
 #if SUPPORTED_PERSONALITIES > 1
-static const struct_sysent sysent1[] = {
+const struct_sysent sysent1[] = {
 # include "syscallent1.h"
 };
 #endif
 
 #if SUPPORTED_PERSONALITIES > 2
-static const struct_sysent sysent2[] = {
+const struct_sysent sysent2[] = {
 # include "syscallent2.h"
 };
 #endif
diff -pruN 5.5-3/tests-mx32/fork--pidns-translation.awk 5.9-0ubuntu2/tests-mx32/fork--pidns-translation.awk
--- 5.5-3/tests-mx32/fork--pidns-translation.awk	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/fork--pidns-translation.awk	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,15 @@
+/fork/ {
+        match($0, "([0-9]+) in strace\x27s PID NS", a);
+        if (a[1])
+                fork_pid = a[1]
+}
+
+/exited with 0/ {
+        if (!exit_pid)
+                exit_pid = $1
+}
+
+END {
+        if (!fork_pid || !exit_pid || fork_pid != exit_pid)
+                exit 1
+}
diff -pruN 5.5-3/tests-mx32/fork--pidns-translation.c 5.9-0ubuntu2/tests-mx32/fork--pidns-translation.c
--- 5.5-3/tests-mx32/fork--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/fork--pidns-translation.c	2020-09-23 16:29:35.000000000 +0000
@@ -0,0 +1,78 @@
+/*
+ * Test PID namespace translation
+ *
+ * Copyright (c) 2020 Ákos Uzonyi <uzonyi.akos@gmail.com>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+#include "pidns.h"
+
+#ifdef __NR_fork
+
+# include <errno.h>
+# include <limits.h>
+# include <sched.h>
+# include <signal.h>
+# include <stdio.h>
+# include <stdlib.h>
+# include <sys/wait.h>
+# include <unistd.h>
+# include <linux/sched.h>
+# include "nsfs.h"
+
+# ifndef CLONE_NEWUSER
+#  define CLONE_NEWUSER 0x10000000
+# endif
+
+# ifndef CLONE_NEWPID
+#  define CLONE_NEWPID 0x20000000
+# endif
+
+static int
+fork_chain(int depth)
+{
+	if (!depth)
+		return 0;
+
+	int pid = syscall(__NR_fork);
+	if (pid < 0)
+		return errno;
+
+	if (!pid)
+		_exit(fork_chain(depth - 1));
+
+	int status;
+	if (wait(&status) < 0)
+		return errno;
+
+	if (!WIFEXITED(status))
+		return -1;
+
+	return WEXITSTATUS(status);
+}
+
+int main(void)
+{
+	check_ns_ioctl();
+
+	if (unshare(CLONE_NEWPID | CLONE_NEWUSER) < 0) {
+		if (errno == EPERM)
+			perror_msg_and_skip("unshare");
+
+		perror_msg_and_fail("unshare");
+	}
+
+	errno = fork_chain(2);
+	if (errno)
+		perror("fork_chain");
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_fork")
+
+#endif
diff -pruN 5.5-3/tests-mx32/fork--pidns-translation.test 5.9-0ubuntu2/tests-mx32/fork--pidns-translation.test
--- 5.5-3/tests-mx32/fork--pidns-translation.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/fork--pidns-translation.test	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,14 @@
+#!/bin/sh
+#
+# Check pidns translation of fork's return value.
+#
+# Copyright (c) 2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: LGPL-2.1-or-later
+
+. "${srcdir=.}/init.sh"
+
+run_prog
+run_strace -a6 --pidns-translation -f -e trace=fork $args
+match_awk
diff -pruN 5.5-3/tests-mx32/futex.c 5.9-0ubuntu2/tests-mx32/futex.c
--- 5.5-3/tests-mx32/futex.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/futex.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -495,7 +495,7 @@ main(int argc, char *argv[])
 	 *                 wake val2 processes waiting for uaddr2 in case
 	 *                 operation encoded in val3 (change of value at uaddr2
 	 *                 and comparison of previous value against provided
-	 *                 constant) succeedes with value at uaddr2. Operation
+	 *                 constant) succeeds with value at uaddr2. Operation
 	 *                 result is written to value of uaddr2 (in any case).
 	 * 1. uaddr   - futex address
 	 * 2. op      - FUTEX_WAKE_OP
diff -pruN 5.5-3/tests-mx32/gen_tests.am 5.9-0ubuntu2/tests-mx32/gen_tests.am
--- 5.5-3/tests-mx32/gen_tests.am	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/gen_tests.am	2020-09-24 09:18:50.000000000 +0000
@@ -1,5 +1,5 @@
 # Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in; do not edit.
-GEN_TESTS = _newselect.gen.test _newselect-P.gen.test accept.gen.test accept4.gen.test access.gen.test acct.gen.test add_key.gen.test adjtimex.gen.test aio.gen.test aio_pgetevents.gen.test alarm.gen.test bpf.gen.test bpf-obj_get_info_by_fd.gen.test bpf-obj_get_info_by_fd-prog.gen.test bpf-obj_get_info_by_fd-prog-v.gen.test bpf-obj_get_info_by_fd-v.gen.test bpf-v.gen.test btrfs.gen.test chmod.gen.test chown.gen.test chown32.gen.test chroot.gen.test clock.gen.test clock_adjtime.gen.test clock_nanosleep.gen.test clock_xettime.gen.test clone3.gen.test clone3-Xabbrev.gen.test clone3-Xraw.gen.test clone3-Xverbose.gen.test clone3-success-Xabbrev.gen.test clone3-success-Xraw.gen.test clone3-success-Xverbose.gen.test copy_file_range.gen.test creat.gen.test delete_module.gen.test dev-yy.gen.test dup.gen.test dup2.gen.test dup3.gen.test epoll_create.gen.test epoll_create1.gen.test epoll_ctl.gen.test epoll_pwait.gen.test epoll_wait.gen.test erestartsys.gen.test execveat.gen.test execveat-v.gen.test faccessat.gen.test fadvise64_64.gen.test fallocate.gen.test fanotify_init.gen.test fanotify_mark.gen.test fanotify_mark-Xabbrev.gen.test fanotify_mark-Xraw.gen.test fanotify_mark-Xverbose.gen.test fchdir.gen.test fchmod.gen.test fchmodat.gen.test fchown.gen.test fchown32.gen.test fchownat.gen.test fcntl.gen.test fcntl64.gen.test fdatasync.gen.test file_handle.gen.test file_ioctl.gen.test filter_seccomp.gen.test filter_seccomp-flag.gen.test finit_module.gen.test flock.gen.test fork-f.gen.test fsconfig.gen.test fsconfig-P.gen.test fsmount.gen.test fsopen.gen.test fspick.gen.test fspick-P.gen.test fstat.gen.test fstat-Xabbrev.gen.test fstat-Xraw.gen.test fstat-Xverbose.gen.test fstat64.gen.test fstat64-Xabbrev.gen.test fstat64-Xraw.gen.test fstat64-Xverbose.gen.test fstatat64.gen.test fstatfs.gen.test fstatfs64.gen.test fsync.gen.test fsync-y.gen.test ftruncate.gen.test ftruncate64.gen.test futimesat.gen.test get_mempolicy.gen.test getcpu.gen.test getcwd.gen.test getdents.gen.test getdents64.gen.test getegid.gen.test getegid-creds.gen.test getegid32.gen.test getegid32-creds.gen.test geteuid.gen.test geteuid-creds.gen.test geteuid32.gen.test geteuid32-creds.gen.test getgid.gen.test getgid-creds.gen.test getgid32.gen.test getgid32-creds.gen.test getgroups.gen.test getgroups32.gen.test getpeername.gen.test getpgrp.gen.test getpid.gen.test getppid.gen.test getrandom.gen.test getresgid.gen.test getresgid32.gen.test getresuid.gen.test getresuid32.gen.test getrlimit.gen.test getrusage.gen.test getsid.gen.test getsockname.gen.test gettid.gen.test getuid-creds.gen.test getuid32.gen.test getuid32-creds.gen.test getxxid.gen.test group_req.gen.test inet-cmsg.gen.test init_module.gen.test inotify.gen.test inotify_init.gen.test inotify_init1.gen.test inotify_init1-y.gen.test io_uring_enter.gen.test io_uring_register.gen.test io_uring_setup.gen.test ioctl_block.gen.test ioctl_dm.gen.test ioctl_dm-v.gen.test ioctl_evdev.gen.test ioctl_evdev-Xabbrev.gen.test ioctl_evdev-Xraw.gen.test ioctl_evdev-Xverbose.gen.test ioctl_evdev-v.gen.test ioctl_evdev-v-Xabbrev.gen.test ioctl_evdev-v-Xraw.gen.test ioctl_evdev-v-Xverbose.gen.test ioctl_evdev-success-Xabbrev.gen.test ioctl_evdev-success-Xraw.gen.test ioctl_evdev-success-Xverbose.gen.test ioctl_evdev-success-v.gen.test ioctl_evdev-success-v-Xabbrev.gen.test ioctl_evdev-success-v-Xraw.gen.test ioctl_evdev-success-v-Xverbose.gen.test ioctl_inotify.gen.test ioctl_kvm_run.gen.test ioctl_kvm_run-v.gen.test ioctl_kvm_run_auxstr_vcpu.gen.test ioctl_loop.gen.test ioctl_loop-nv.gen.test ioctl_loop-v.gen.test ioctl_mtd.gen.test ioctl_nbd.gen.test ioctl_nsfs.gen.test ioctl_perf.gen.test ioctl_ptp.gen.test ioctl_random.gen.test ioctl_rtc.gen.test ioctl_rtc-v.gen.test ioctl_scsi.gen.test ioctl_sg_io_v3.gen.test ioctl_sg_io_v4.gen.test ioctl_sock_gifconf.gen.test ioctl_uffdio.gen.test ioctl_v4l2.gen.test ioctl_watchdog.gen.test ioperm.gen.test iopl.gen.test ioprio.gen.test ioprio-Xabbrev.gen.test ioprio-Xraw.gen.test ioprio-Xverbose.gen.test ip_mreq.gen.test ipc.gen.test ipc_msg.gen.test ipc_msg-Xabbrev.gen.test ipc_msg-Xraw.gen.test ipc_msg-Xverbose.gen.test ipc_msgbuf-Xabbrev.gen.test ipc_msgbuf-Xraw.gen.test ipc_msgbuf-Xverbose.gen.test ipc_sem.gen.test ipc_sem-Xabbrev.gen.test ipc_sem-Xraw.gen.test ipc_sem-Xverbose.gen.test ipc_shm.gen.test ipc_shm-Xabbrev.gen.test ipc_shm-Xraw.gen.test ipc_shm-Xverbose.gen.test kcmp.gen.test kcmp-y.gen.test kern_features.gen.test kernel_version.gen.test kernel_version-Xabbrev.gen.test kernel_version-Xraw.gen.test kernel_version-Xverbose.gen.test kexec_file_load.gen.test kexec_load.gen.test keyctl.gen.test keyctl-Xabbrev.gen.test keyctl-Xraw.gen.test keyctl-Xverbose.gen.test kill.gen.test ksysent.gen.test lchown.gen.test lchown32.gen.test link.gen.test linkat.gen.test lookup_dcookie.gen.test lstat.gen.test lstat64.gen.test madvise.gen.test maybe_switch_current_tcp.gen.test mbind.gen.test mbind-Xabbrev.gen.test mbind-Xraw.gen.test mbind-Xverbose.gen.test membarrier.gen.test memfd_create.gen.test memfd_create-Xabbrev.gen.test memfd_create-Xraw.gen.test memfd_create-Xverbose.gen.test migrate_pages.gen.test mincore.gen.test mkdir.gen.test mkdirat.gen.test mknod.gen.test mknodat.gen.test mlock.gen.test mlock2.gen.test mlockall.gen.test mmap-Xabbrev.gen.test mmap-Xraw.gen.test mmap-Xverbose.gen.test mmap64.gen.test mmap64-Xabbrev.gen.test mmap64-Xraw.gen.test mmap64-Xverbose.gen.test mmsg.gen.test mmsg-silent.gen.test mmsg_name.gen.test mmsg_name-v.gen.test modify_ldt.gen.test mount.gen.test mount-Xabbrev.gen.test mount-Xraw.gen.test mount-Xverbose.gen.test move_mount.gen.test move_mount-P.gen.test move_pages.gen.test move_pages-Xabbrev.gen.test move_pages-Xraw.gen.test move_pages-Xverbose.gen.test mq.gen.test mq_sendrecv.gen.test mq_sendrecv-read.gen.test mq_sendrecv-write.gen.test msg_control.gen.test msg_control-v.gen.test msg_name.gen.test munlockall.gen.test nanosleep.gen.test net-icmp_filter.gen.test net-packet_mreq.gen.test net-packet_mreq-Xabbrev.gen.test net-packet_mreq-Xraw.gen.test net-packet_mreq-Xverbose.gen.test net-sockaddr.gen.test net-tpacket_req.gen.test net-tpacket_stats.gen.test net-yy-inet6.gen.test netlink_audit.gen.test netlink_crypto.gen.test netlink_generic.gen.test netlink_kobject_uevent.gen.test netlink_netfilter.gen.test netlink_protocol.gen.test netlink_route.gen.test netlink_selinux.gen.test netlink_xfrm.gen.test newfstatat.gen.test nfnetlink_acct.gen.test nfnetlink_cthelper.gen.test nfnetlink_ctnetlink.gen.test nfnetlink_ctnetlink_exp.gen.test nfnetlink_cttimeout.gen.test nfnetlink_ipset.gen.test nfnetlink_nft_compat.gen.test nfnetlink_nftables.gen.test nfnetlink_osf.gen.test nfnetlink_queue.gen.test nfnetlink_ulog.gen.test nlattr.gen.test nlattr_br_port_msg.gen.test nlattr_crypto_user_alg.gen.test nlattr_dcbmsg.gen.test nlattr_fib_rule_hdr.gen.test nlattr_ifaddrlblmsg.gen.test nlattr_ifaddrmsg.gen.test nlattr_ifinfomsg.gen.test nlattr_ifla_af_spec.gen.test nlattr_ifla_brport.gen.test nlattr_ifla_linkinfo.gen.test nlattr_ifla_port.gen.test nlattr_ifla_xdp.gen.test nlattr_inet_diag_msg.gen.test nlattr_inet_diag_req_compat.gen.test nlattr_inet_diag_req_v2.gen.test nlattr_mdba_mdb_entry.gen.test nlattr_mdba_router_port.gen.test nlattr_ndmsg.gen.test nlattr_ndtmsg.gen.test nlattr_netconfmsg.gen.test nlattr_netlink_diag_msg.gen.test nlattr_nlmsgerr.gen.test nlattr_packet_diag_msg.gen.test nlattr_rtgenmsg.gen.test nlattr_rtmsg.gen.test nlattr_smc_diag_msg.gen.test nlattr_tc_stats.gen.test nlattr_tca_stab.gen.test nlattr_tcamsg.gen.test nlattr_tcmsg.gen.test nlattr_unix_diag_msg.gen.test old_mmap.gen.test old_mmap-P.gen.test old_mmap-Xabbrev.gen.test old_mmap-Xraw.gen.test old_mmap-Xverbose.gen.test old_mmap-v-none.gen.test oldfstat.gen.test oldlstat.gen.test oldselect.gen.test oldselect-P.gen.test oldselect-efault.gen.test oldselect-efault-P.gen.test oldstat.gen.test open.gen.test open_tree.gen.test open_tree-P.gen.test openat.gen.test orphaned_process_group.gen.test osf_utimes.gen.test pause.gen.test perf_event_open.gen.test perf_event_open_nonverbose.gen.test perf_event_open_unabbrev.gen.test personality-Xabbrev.gen.test personality-Xraw.gen.test personality-Xverbose.gen.test pidfd_open.gen.test pidfd_open-P.gen.test pidfd_open-y.gen.test pidfd_send_signal.gen.test pipe2.gen.test pkey_alloc.gen.test pkey_free.gen.test pkey_mprotect.gen.test ppoll.gen.test ppoll-P.gen.test ppoll-v.gen.test pread64-pwrite64.gen.test preadv.gen.test preadv-pwritev.gen.test preadv2-pwritev2.gen.test printpath-umovestr.gen.test printpath-umovestr-peekdata.gen.test printpath-umovestr-undumpable.gen.test printsignal-Xabbrev.gen.test printsignal-Xraw.gen.test printsignal-Xverbose.gen.test printstr.gen.test printstrn-umoven.gen.test printstrn-umoven-peekdata.gen.test printstrn-umoven-undumpable.gen.test prlimit64.gen.test process_vm_readv.gen.test process_vm_writev.gen.test pselect6.gen.test ptrace.gen.test ptrace_syscall_info.gen.test pwritev.gen.test quotactl.gen.test quotactl-Xabbrev.gen.test quotactl-Xraw.gen.test quotactl-Xverbose.gen.test quotactl-v.gen.test quotactl-xfs.gen.test quotactl-xfs-v.gen.test read-write.gen.test readahead.gen.test readdir.gen.test readlink.gen.test readlinkat.gen.test reboot.gen.test recv-MSG_TRUNC.gen.test recvfrom.gen.test recvfrom-MSG_TRUNC.gen.test recvmmsg-timeout.gen.test recvmsg.gen.test regex.gen.test remap_file_pages.gen.test remap_file_pages-Xabbrev.gen.test remap_file_pages-Xraw.gen.test remap_file_pages-Xverbose.gen.test rename.gen.test renameat.gen.test renameat2.gen.test request_key.gen.test riscv_flush_icache.gen.test rmdir.gen.test rt_sigpending.gen.test rt_sigprocmask.gen.test rt_sigqueueinfo.gen.test rt_sigreturn.gen.test rt_sigsuspend.gen.test rt_sigtimedwait.gen.test rt_tgsigqueueinfo.gen.test s390_guarded_storage.gen.test s390_guarded_storage-v.gen.test s390_pci_mmio_read_write.gen.test s390_runtime_instr.gen.test s390_sthyi.gen.test s390_sthyi-v.gen.test sched.gen.test sched_get_priority_mxx.gen.test sched_rr_get_interval.gen.test sched_xetaffinity.gen.test sched_xetattr.gen.test sched_xetparam.gen.test sched_xetscheduler.gen.test sched_yield.gen.test seccomp-filter.gen.test seccomp-filter-v.gen.test seccomp_get_action_avail.gen.test select.gen.test select-P.gen.test semop.gen.test semop-indirect.gen.test semtimedop.gen.test sendfile.gen.test sendfile64.gen.test set_mempolicy.gen.test set_mempolicy-Xabbrev.gen.test set_mempolicy-Xraw.gen.test set_mempolicy-Xverbose.gen.test setdomainname.gen.test setfsgid.gen.test setfsgid32.gen.test setfsuid.gen.test setfsuid32.gen.test setgid.gen.test setgid32.gen.test setgroups.gen.test setgroups32.gen.test sethostname.gen.test setns.gen.test setregid.gen.test setregid32.gen.test setresgid.gen.test setresgid32.gen.test setresuid.gen.test setresuid32.gen.test setreuid.gen.test setreuid32.gen.test setrlimit.gen.test setrlimit-Xabbrev.gen.test setrlimit-Xraw.gen.test setrlimit-Xverbose.gen.test setuid.gen.test setuid32.gen.test shmxt.gen.test shutdown.gen.test sigaction.gen.test siginfo.gen.test signal.gen.test signal_receive.gen.test signalfd4.gen.test sigpending.gen.test sigprocmask.gen.test sigreturn.gen.test sigsuspend.gen.test so_error.gen.test so_linger.gen.test so_peercred.gen.test so_peercred-Xabbrev.gen.test so_peercred-Xraw.gen.test so_peercred-Xverbose.gen.test sock_filter-v.gen.test sock_filter-v-Xabbrev.gen.test sock_filter-v-Xraw.gen.test sock_filter-v-Xverbose.gen.test sockaddr_xlat-Xabbrev.gen.test sockaddr_xlat-Xraw.gen.test sockaddr_xlat-Xverbose.gen.test socketcall.gen.test sockopt-sol_netlink.gen.test sockopt-timestamp.gen.test splice.gen.test stat.gen.test stat64.gen.test statfs.gen.test statfs64.gen.test status-all.gen.test status-failed.gen.test status-none.gen.test status-successful.gen.test status-unfinished.gen.test statx.gen.test swap.gen.test sxetmask.gen.test symlink.gen.test symlinkat.gen.test sync.gen.test sync_file_range.gen.test sync_file_range2.gen.test sysinfo.gen.test syslog.gen.test tee.gen.test time.gen.test timer_create.gen.test timer_xettime.gen.test timerfd_xettime.gen.test times.gen.test times-fail.gen.test trace_creds.gen.test trace_fstat.gen.test trace_fstatfs.gen.test trace_lstat.gen.test trace_personality_32.gen.test trace_personality_64.gen.test trace_personality_regex_32.gen.test trace_personality_regex_64.gen.test trace_personality_regex_x32.gen.test trace_personality_x32.gen.test trace_question.gen.test trace_stat.gen.test trace_stat_like.gen.test trace_statfs.gen.test trace_statfs_like.gen.test truncate.gen.test truncate64.gen.test ugetrlimit.gen.test umask.gen.test umoven-illptr.gen.test umovestr-illptr.gen.test umovestr3.gen.test unlink.gen.test unlinkat.gen.test unshare.gen.test userfaultfd.gen.test ustat.gen.test utime.gen.test utimensat.gen.test utimensat-Xabbrev.gen.test utimensat-Xraw.gen.test utimensat-Xverbose.gen.test utimes.gen.test vfork-f.gen.test vhangup.gen.test vmsplice.gen.test wait4.gen.test wait4-v.gen.test waitid.gen.test waitid-v.gen.test waitpid.gen.test xattr.gen.test xattr-strings.gen.test xet_robust_list.gen.test xetitimer.gen.test xetpgid.gen.test xetpriority.gen.test xettimeofday.gen.test
+GEN_TESTS = _newselect.gen.test _newselect-P.gen.test accept.gen.test accept4.gen.test access.gen.test acct.gen.test add_key.gen.test adjtimex.gen.test aio.gen.test aio_pgetevents.gen.test alarm.gen.test bpf.gen.test bpf-obj_get_info_by_fd.gen.test bpf-obj_get_info_by_fd-prog.gen.test bpf-obj_get_info_by_fd-prog-v.gen.test bpf-obj_get_info_by_fd-v.gen.test bpf-v.gen.test btrfs.gen.test chmod.gen.test chown.gen.test chown32.gen.test chroot.gen.test clock.gen.test clock_adjtime.gen.test clock_nanosleep.gen.test clock_xettime.gen.test clone3.gen.test clone3-Xabbrev.gen.test clone3-Xraw.gen.test clone3-Xverbose.gen.test clone3-success-Xabbrev.gen.test clone3-success-Xraw.gen.test clone3-success-Xverbose.gen.test clone_parent.gen.test clone_parent--quiet-exit.gen.test clone_parent-q.gen.test clone_parent-qq.gen.test clone_ptrace--quiet-attach.gen.test clone_ptrace--quiet-exit.gen.test clone_ptrace-q.gen.test clone_ptrace-qq.gen.test close_range.gen.test close_range-P.gen.test close_range-y.gen.test close_range-yy.gen.test copy_file_range.gen.test creat.gen.test delete_module.gen.test dev--decode-fds-dev.gen.test dev--decode-fds-path.gen.test dev--decode-fds-socket.gen.test dev-yy.gen.test dup.gen.test dup-P.gen.test dup-y.gen.test dup-yy.gen.test dup2.gen.test dup2-P.gen.test dup2-y.gen.test dup2-yy.gen.test dup3.gen.test dup3-P.gen.test dup3-y.gen.test dup3-yy.gen.test epoll_create.gen.test epoll_create1.gen.test epoll_ctl.gen.test epoll_pwait.gen.test epoll_wait.gen.test erestartsys.gen.test execveat.gen.test execveat-v.gen.test faccessat-P.gen.test faccessat-y.gen.test faccessat-yy.gen.test faccessat2-P.gen.test faccessat2-y.gen.test faccessat2-yy.gen.test fadvise64_64.gen.test fallocate.gen.test fanotify_init.gen.test fanotify_mark.gen.test fanotify_mark-Xabbrev.gen.test fanotify_mark-Xraw.gen.test fanotify_mark-Xverbose.gen.test fchdir.gen.test fchmod.gen.test fchmodat.gen.test fchown.gen.test fchown32.gen.test fchownat.gen.test fcntl.gen.test fcntl--pidns-translation.gen.test fcntl64.gen.test fcntl64--pidns-translation.gen.test fdatasync.gen.test file_handle.gen.test file_ioctl.gen.test filter_seccomp.gen.test filter_seccomp-flag.gen.test finit_module.gen.test flock.gen.test fork-f.gen.test fsconfig.gen.test fsconfig-P.gen.test fsmount.gen.test fsopen.gen.test fspick.gen.test fspick-P.gen.test fstat.gen.test fstat-Xabbrev.gen.test fstat-Xraw.gen.test fstat-Xverbose.gen.test fstat64.gen.test fstat64-Xabbrev.gen.test fstat64-Xraw.gen.test fstat64-Xverbose.gen.test fstatat64.gen.test fstatfs.gen.test fstatfs64.gen.test fsync.gen.test fsync-y.gen.test ftruncate.gen.test ftruncate64.gen.test futimesat.gen.test get_mempolicy.gen.test getcpu.gen.test getcwd.gen.test getdents.gen.test getdents-v.gen.test getdents64.gen.test getdents64-v.gen.test getegid.gen.test getegid-creds.gen.test getegid32.gen.test getegid32-creds.gen.test geteuid.gen.test geteuid-creds.gen.test geteuid32.gen.test geteuid32-creds.gen.test getgid.gen.test getgid-creds.gen.test getgid32.gen.test getgid32-creds.gen.test getgroups.gen.test getgroups32.gen.test getpeername.gen.test getpgrp.gen.test getpgrp--pidns-translation.gen.test getpid.gen.test getpid--pidns-translation.gen.test getppid.gen.test getrandom.gen.test getresgid.gen.test getresgid32.gen.test getresuid.gen.test getresuid32.gen.test getrlimit.gen.test getrusage.gen.test getsid.gen.test getsid--pidns-translation.gen.test getsockname.gen.test gettid.gen.test getuid-creds.gen.test getuid32.gen.test getuid32-creds.gen.test getxgid.gen.test getxpid.gen.test getxuid.gen.test group_req.gen.test inet-cmsg.gen.test init_module.gen.test inotify.gen.test inotify_init.gen.test inotify_init1.gen.test inotify_init1-y.gen.test io_uring_enter.gen.test io_uring_register.gen.test io_uring_setup.gen.test ioctl_block.gen.test ioctl_dm.gen.test ioctl_dm-v.gen.test ioctl_evdev.gen.test ioctl_evdev-Xabbrev.gen.test ioctl_evdev-Xraw.gen.test ioctl_evdev-Xverbose.gen.test ioctl_evdev-v.gen.test ioctl_evdev-v-Xabbrev.gen.test ioctl_evdev-v-Xraw.gen.test ioctl_evdev-v-Xverbose.gen.test ioctl_evdev-success-Xabbrev.gen.test ioctl_evdev-success-Xraw.gen.test ioctl_evdev-success-Xverbose.gen.test ioctl_evdev-success-v.gen.test ioctl_evdev-success-v-Xabbrev.gen.test ioctl_evdev-success-v-Xraw.gen.test ioctl_evdev-success-v-Xverbose.gen.test ioctl_hdio.gen.test ioctl_hdio-Xabbrev.gen.test ioctl_hdio-Xraw.gen.test ioctl_hdio-Xverbose.gen.test ioctl_hdio-v.gen.test ioctl_hdio-v-Xabbrev.gen.test ioctl_hdio-v-Xraw.gen.test ioctl_hdio-v-Xverbose.gen.test ioctl_hdio-success.gen.test ioctl_hdio-success-Xabbrev.gen.test ioctl_hdio-success-Xraw.gen.test ioctl_hdio-success-Xverbose.gen.test ioctl_hdio-success-v.gen.test ioctl_hdio-success-v-Xabbrev.gen.test ioctl_hdio-success-v-Xraw.gen.test ioctl_hdio-success-v-Xverbose.gen.test ioctl_inotify.gen.test ioctl_kvm_run.gen.test ioctl_kvm_run-v.gen.test ioctl_kvm_run_auxstr_vcpu.gen.test ioctl_loop.gen.test ioctl_loop-nv.gen.test ioctl_loop-v.gen.test ioctl_mtd.gen.test ioctl_nbd.gen.test ioctl_nsfs.gen.test ioctl_perf.gen.test ioctl_perf-success.gen.test ioctl_ptp.gen.test ioctl_random.gen.test ioctl_rtc.gen.test ioctl_rtc-v.gen.test ioctl_scsi.gen.test ioctl_sg_io_v3.gen.test ioctl_sg_io_v4.gen.test ioctl_sock_gifconf.gen.test ioctl_tee.gen.test ioctl_uffdio.gen.test ioctl_v4l2.gen.test ioctl_v4l2-Xabbrev.gen.test ioctl_v4l2-Xraw.gen.test ioctl_v4l2-Xverbose.gen.test ioctl_v4l2-v.gen.test ioctl_v4l2-v-Xabbrev.gen.test ioctl_v4l2-v-Xraw.gen.test ioctl_v4l2-v-Xverbose.gen.test ioctl_v4l2-success.gen.test ioctl_v4l2-success-Xabbrev.gen.test ioctl_v4l2-success-Xraw.gen.test ioctl_v4l2-success-Xverbose.gen.test ioctl_v4l2-success-v.gen.test ioctl_v4l2-success-v-Xabbrev.gen.test ioctl_v4l2-success-v-Xraw.gen.test ioctl_v4l2-success-v-Xverbose.gen.test ioctl_watchdog.gen.test ioperm.gen.test iopl.gen.test ioprio.gen.test ioprio--pidns-translation.gen.test ioprio-Xabbrev.gen.test ioprio-Xraw.gen.test ioprio-Xverbose.gen.test ip_mreq.gen.test ipc.gen.test ipc_msg.gen.test ipc_msg-Xabbrev.gen.test ipc_msg-Xraw.gen.test ipc_msg-Xverbose.gen.test ipc_msgbuf-Xabbrev.gen.test ipc_msgbuf-Xraw.gen.test ipc_msgbuf-Xverbose.gen.test ipc_sem.gen.test ipc_sem-Xabbrev.gen.test ipc_sem-Xraw.gen.test ipc_sem-Xverbose.gen.test ipc_shm.gen.test ipc_shm-Xabbrev.gen.test ipc_shm-Xraw.gen.test ipc_shm-Xverbose.gen.test kcmp.gen.test kcmp-y.gen.test kcmp-y--pidns-translation.gen.test kern_features.gen.test kernel_version.gen.test kernel_version-Xabbrev.gen.test kernel_version-Xraw.gen.test kernel_version-Xverbose.gen.test kexec_file_load.gen.test kexec_load.gen.test keyctl.gen.test keyctl-Xabbrev.gen.test keyctl-Xraw.gen.test keyctl-Xverbose.gen.test kill.gen.test kill--pidns-translation.gen.test ksysent.gen.test lchown.gen.test lchown32.gen.test link.gen.test linkat.gen.test lookup_dcookie.gen.test lstat.gen.test lstat64.gen.test madvise.gen.test maybe_switch_current_tcp.gen.test maybe_switch_current_tcp--quiet-thread-execve.gen.test mbind.gen.test mbind-Xabbrev.gen.test mbind-Xraw.gen.test mbind-Xverbose.gen.test membarrier.gen.test memfd_create.gen.test memfd_create-Xabbrev.gen.test memfd_create-Xraw.gen.test memfd_create-Xverbose.gen.test migrate_pages.gen.test migrate_pages--pidns-translation.gen.test mincore.gen.test mkdir.gen.test mkdirat.gen.test mknod.gen.test mknodat.gen.test mlock.gen.test mlock2.gen.test mlockall.gen.test mmap-Xabbrev.gen.test mmap-Xraw.gen.test mmap-Xverbose.gen.test mmap64.gen.test mmap64-Xabbrev.gen.test mmap64-Xraw.gen.test mmap64-Xverbose.gen.test mmsg.gen.test mmsg-silent.gen.test mmsg_name.gen.test mmsg_name-v.gen.test modify_ldt.gen.test mount.gen.test mount-Xabbrev.gen.test mount-Xraw.gen.test mount-Xverbose.gen.test move_mount.gen.test move_mount-P.gen.test move_pages.gen.test move_pages-Xabbrev.gen.test move_pages-Xraw.gen.test move_pages-Xverbose.gen.test move_pages--pidns-translation.gen.test mq.gen.test mq_sendrecv.gen.test mq_sendrecv-read.gen.test mq_sendrecv-write.gen.test msg_control.gen.test msg_control-v.gen.test msg_name.gen.test munlockall.gen.test nanosleep.gen.test net--decode-fds-dev-netlink.gen.test net--decode-fds-none-netlink.gen.test net--decode-fds-path-netlink.gen.test net--decode-fds-socket-netlink.gen.test net-icmp_filter.gen.test net-packet_mreq.gen.test net-packet_mreq-Xabbrev.gen.test net-packet_mreq-Xraw.gen.test net-packet_mreq-Xverbose.gen.test net-sockaddr.gen.test net-sockaddr--pidns-translation.gen.test net-tpacket_req.gen.test net-tpacket_stats.gen.test net-yy-inet6.gen.test netlink_audit.gen.test netlink_crypto.gen.test netlink_generic.gen.test netlink_kobject_uevent.gen.test netlink_netfilter.gen.test netlink_protocol.gen.test netlink_route.gen.test netlink_selinux.gen.test netlink_xfrm.gen.test newfstatat.gen.test nfnetlink_acct.gen.test nfnetlink_cthelper.gen.test nfnetlink_ctnetlink.gen.test nfnetlink_ctnetlink_exp.gen.test nfnetlink_cttimeout.gen.test nfnetlink_ipset.gen.test nfnetlink_nft_compat.gen.test nfnetlink_nftables.gen.test nfnetlink_osf.gen.test nfnetlink_queue.gen.test nfnetlink_ulog.gen.test nlattr.gen.test nlattr_br_port_msg.gen.test nlattr_crypto_user_alg.gen.test nlattr_dcbmsg.gen.test nlattr_fib_rule_hdr.gen.test nlattr_ifaddrlblmsg.gen.test nlattr_ifaddrmsg.gen.test nlattr_ifinfomsg.gen.test nlattr_ifla_af_spec.gen.test nlattr_ifla_brport.gen.test nlattr_ifla_linkinfo.gen.test nlattr_ifla_port.gen.test nlattr_ifla_xdp.gen.test nlattr_ifla_xdp-y.gen.test nlattr_inet_diag_msg.gen.test nlattr_inet_diag_req_compat.gen.test nlattr_inet_diag_req_v2.gen.test nlattr_mdba_mdb_entry.gen.test nlattr_mdba_router_port.gen.test nlattr_ndmsg.gen.test nlattr_ndtmsg.gen.test nlattr_netconfmsg.gen.test nlattr_netlink_diag_msg.gen.test nlattr_nlmsgerr.gen.test nlattr_packet_diag_msg.gen.test nlattr_rtgenmsg.gen.test nlattr_rtmsg.gen.test nlattr_smc_diag_msg.gen.test nlattr_tc_stats.gen.test nlattr_tca_stab.gen.test nlattr_tcamsg.gen.test nlattr_tcmsg.gen.test nlattr_unix_diag_msg.gen.test old_mmap.gen.test old_mmap-P.gen.test old_mmap-Xabbrev.gen.test old_mmap-Xraw.gen.test old_mmap-Xverbose.gen.test old_mmap-v-none.gen.test oldfstat.gen.test oldlstat.gen.test oldselect.gen.test oldselect-P.gen.test oldselect-efault.gen.test oldselect-efault-P.gen.test oldstat.gen.test open.gen.test open_tree.gen.test open_tree-P.gen.test openat.gen.test openat2.gen.test openat2-Xabbrev.gen.test openat2-Xraw.gen.test openat2-Xverbose.gen.test openat2-v.gen.test openat2-v-y.gen.test openat2-v-y-Xabbrev.gen.test openat2-v-y-Xraw.gen.test openat2-v-y-Xverbose.gen.test openat2-y.gen.test orphaned_process_group.gen.test osf_utimes.gen.test pause.gen.test perf_event_open.gen.test perf_event_open_nonverbose.gen.test perf_event_open_unabbrev.gen.test personality-Xabbrev.gen.test personality-Xraw.gen.test personality-Xverbose.gen.test pidfd_getfd.gen.test pidfd_getfd-y.gen.test pidfd_getfd-yy.gen.test pidfd_open.gen.test pidfd_open--decode-fd-path.gen.test pidfd_open--decode-fd-pidfd.gen.test pidfd_open--decode-fd-socket.gen.test pidfd_open-P.gen.test pidfd_open-y.gen.test pidfd_open-yy.gen.test pidfd_open--pidns-translation.gen.test pidfd_send_signal.gen.test pidfd_send_signal--pidns-translation.gen.test pipe2.gen.test pkey_alloc.gen.test pkey_free.gen.test pkey_mprotect.gen.test ppoll.gen.test ppoll-P.gen.test ppoll-v.gen.test pread64-pwrite64.gen.test preadv.gen.test preadv-pwritev.gen.test preadv2-pwritev2.gen.test printpath-umovestr.gen.test printpath-umovestr-peekdata.gen.test printpath-umovestr-undumpable.gen.test printsignal-Xabbrev.gen.test printsignal-Xraw.gen.test printsignal-Xverbose.gen.test printstr.gen.test printstrn-umoven.gen.test printstrn-umoven-peekdata.gen.test printstrn-umoven-undumpable.gen.test prlimit64.gen.test prlimit64--pidns-translation.gen.test process_vm_readv.gen.test process_vm_readv--pidns-translation.gen.test process_vm_writev.gen.test process_vm_writev--pidns-translation.gen.test pselect6.gen.test ptrace.gen.test ptrace_syscall_info.gen.test pwritev.gen.test quotactl.gen.test quotactl-Xabbrev.gen.test quotactl-Xraw.gen.test quotactl-Xverbose.gen.test quotactl-v.gen.test quotactl-xfs.gen.test quotactl-xfs-v.gen.test read-write.gen.test readahead.gen.test readdir.gen.test readlink.gen.test readlinkat.gen.test reboot.gen.test recv-MSG_TRUNC.gen.test recvfrom.gen.test recvfrom-MSG_TRUNC.gen.test recvmmsg-timeout.gen.test recvmsg.gen.test regex.gen.test remap_file_pages.gen.test remap_file_pages-Xabbrev.gen.test remap_file_pages-Xraw.gen.test remap_file_pages-Xverbose.gen.test rename.gen.test renameat.gen.test renameat2.gen.test request_key.gen.test riscv_flush_icache.gen.test rmdir.gen.test rt_sigpending.gen.test rt_sigprocmask.gen.test rt_sigqueueinfo.gen.test rt_sigqueueinfo--pidns-translation.gen.test rt_sigreturn.gen.test rt_sigsuspend.gen.test rt_sigtimedwait.gen.test rt_tgsigqueueinfo.gen.test rt_tgsigqueueinfo--pidns-translation.gen.test s390_guarded_storage.gen.test s390_guarded_storage-v.gen.test s390_pci_mmio_read_write.gen.test s390_runtime_instr.gen.test s390_sthyi.gen.test s390_sthyi-v.gen.test sched.gen.test sched_get_priority_mxx.gen.test sched_rr_get_interval.gen.test sched_xetaffinity.gen.test sched_xetaffinity--pidns-translation.gen.test sched_xetattr.gen.test sched_xetattr--pidns-translation.gen.test sched_xetparam.gen.test sched_xetparam--pidns-translation.gen.test sched_xetscheduler.gen.test sched_xetscheduler--pidns-translation.gen.test sched_yield.gen.test seccomp-filter.gen.test seccomp-filter-v.gen.test seccomp_get_action_avail.gen.test select.gen.test select-P.gen.test semop.gen.test semop-indirect.gen.test semtimedop.gen.test sendfile.gen.test sendfile64.gen.test set_mempolicy.gen.test set_mempolicy-Xabbrev.gen.test set_mempolicy-Xraw.gen.test set_mempolicy-Xverbose.gen.test setdomainname.gen.test setfsgid.gen.test setfsgid32.gen.test setfsuid.gen.test setfsuid32.gen.test setgid.gen.test setgid32.gen.test setgroups.gen.test setgroups32.gen.test sethostname.gen.test setns.gen.test setregid.gen.test setregid32.gen.test setresgid.gen.test setresgid32.gen.test setresuid.gen.test setresuid32.gen.test setreuid.gen.test setreuid32.gen.test setrlimit.gen.test setrlimit-Xabbrev.gen.test setrlimit-Xraw.gen.test setrlimit-Xverbose.gen.test setuid.gen.test setuid32.gen.test shmxt.gen.test shutdown.gen.test sigaction.gen.test siginfo.gen.test signal.gen.test signal_receive.gen.test signal_receive--pidns-translation.gen.test signalfd4.gen.test sigpending.gen.test sigprocmask.gen.test sigreturn.gen.test sigsuspend.gen.test so_error.gen.test so_linger.gen.test so_peercred.gen.test so_peercred-Xabbrev.gen.test so_peercred-Xraw.gen.test so_peercred-Xverbose.gen.test so_peercred--pidns-translation.gen.test sock_filter-v.gen.test sock_filter-v-Xabbrev.gen.test sock_filter-v-Xraw.gen.test sock_filter-v-Xverbose.gen.test sockaddr_xlat-Xabbrev.gen.test sockaddr_xlat-Xraw.gen.test sockaddr_xlat-Xverbose.gen.test socketcall.gen.test sockopt-sol_netlink.gen.test sockopt-timestamp.gen.test splice.gen.test stat.gen.test stat64.gen.test statfs.gen.test statfs64.gen.test status-all.gen.test status-failed.gen.test status-failed-long.gen.test status-failed-status.gen.test status-none.gen.test status-successful.gen.test status-successful-long.gen.test status-successful-status.gen.test status-unfinished.gen.test statx.gen.test strace--absolute-timestamps.gen.test strace--absolute-timestamps-format-time.gen.test strace--absolute-timestamps-format-time-precision-s.gen.test strace--absolute-timestamps-format-time-precision-ms.gen.test strace--absolute-timestamps-format-time-precision-us.gen.test strace--absolute-timestamps-format-time-precision-ns.gen.test strace--absolute-timestamps-format-unix-precision-s.gen.test strace--absolute-timestamps-format-unix-precision-ms.gen.test strace--absolute-timestamps-format-unix-precision-us.gen.test strace--absolute-timestamps-format-unix-precision-ns.gen.test strace--follow-forks-output-separately.gen.test strace--relative-timestamps.gen.test strace--relative-timestamps-s.gen.test strace--relative-timestamps-ms.gen.test strace--relative-timestamps-us.gen.test strace--relative-timestamps-ns.gen.test strace--syscall-times.gen.test strace--syscall-times-s.gen.test strace--syscall-times-ms.gen.test strace--syscall-times-us.gen.test strace--syscall-times-ns.gen.test strace--strings-in-hex.gen.test strace--strings-in-hex-all.gen.test strace--strings-in-hex-non-ascii.gen.test strace--timestamps.gen.test strace--timestamps-time.gen.test strace--timestamps-time-s.gen.test strace--timestamps-time-ms.gen.test strace--timestamps-time-us.gen.test strace--timestamps-time-ns.gen.test strace--timestamps-unix-s.gen.test strace--timestamps-unix-ms.gen.test strace--timestamps-unix-us.gen.test strace--timestamps-unix-ns.gen.test strace-n.gen.test strace-x.gen.test strace-xx.gen.test swap.gen.test sxetmask.gen.test symlink.gen.test symlinkat.gen.test sync.gen.test sync_file_range.gen.test sync_file_range2.gen.test sysinfo.gen.test syslog.gen.test tee.gen.test tgkill.gen.test tgkill--pidns-translation.gen.test threads-execve--quiet-thread-execve.gen.test threads-execve-q.gen.test threads-execve-qq.gen.test threads-execve-qqq.gen.test time.gen.test timer_create.gen.test timer_xettime.gen.test timerfd_xettime.gen.test times.gen.test times-fail.gen.test tkill.gen.test tkill--pidns-translation.gen.test trace_clock.gen.test trace_creds.gen.test trace_fstat.gen.test trace_fstatfs.gen.test trace_lstat.gen.test trace_personality_32.gen.test trace_personality_64.gen.test trace_personality_regex_32.gen.test trace_personality_regex_64.gen.test trace_personality_regex_x32.gen.test trace_personality_x32.gen.test trace_question.gen.test trace_stat.gen.test trace_stat_like.gen.test trace_statfs.gen.test trace_statfs_like.gen.test trie_test.gen.test truncate.gen.test truncate64.gen.test ugetrlimit.gen.test umask.gen.test umoven-illptr.gen.test umovestr-illptr.gen.test umovestr3.gen.test umovestr_cached_adjacent.gen.test unlink.gen.test unlinkat.gen.test unshare.gen.test userfaultfd.gen.test ustat.gen.test utime.gen.test utimensat.gen.test utimensat-Xabbrev.gen.test utimensat-Xraw.gen.test utimensat-Xverbose.gen.test utimes.gen.test vfork-f.gen.test vhangup.gen.test vmsplice.gen.test wait4.gen.test wait4-v.gen.test waitid.gen.test waitid-v.gen.test waitpid.gen.test xattr.gen.test xattr-strings.gen.test xet_robust_list.gen.test xet_robust_list--pidns-translation.gen.test xetitimer.gen.test xetpgid.gen.test xetpgid--pidns-translation.gen.test xetpriority.gen.test xetpriority--pidns-translation.gen.test xettimeofday.gen.test
 
 $(srcdir)/_newselect.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
@@ -100,6 +100,42 @@ $(srcdir)/clone3-success-Xraw.gen.test:
 $(srcdir)/clone3-success-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/clone_parent.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_parent--quiet-exit.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_parent-q.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_parent-qq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_ptrace--quiet-attach.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_ptrace--quiet-exit.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_ptrace-q.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_ptrace-qq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/close_range.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/close_range-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/close_range-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/close_range-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/copy_file_range.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -109,18 +145,54 @@ $(srcdir)/creat.gen.test: $(abs_srcdir)/
 $(srcdir)/delete_module.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/dev--decode-fds-dev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dev--decode-fds-path.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dev--decode-fds-socket.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/dev-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/dup.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/dup-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/dup2.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/dup2-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup2-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup2-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/dup3.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/dup3-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup3-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup3-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/epoll_create.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -145,7 +217,22 @@ $(srcdir)/execveat.gen.test: $(abs_srcdi
 $(srcdir)/execveat-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
-$(srcdir)/faccessat.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+$(srcdir)/faccessat-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat2-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat2-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat2-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/fadvise64_64.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
@@ -190,9 +277,15 @@ $(srcdir)/fchownat.gen.test: $(abs_srcdi
 $(srcdir)/fcntl.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/fcntl--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/fcntl64.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/fcntl64--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/fdatasync.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -295,9 +388,15 @@ $(srcdir)/getcwd.gen.test: $(abs_srcdir)
 $(srcdir)/getdents.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getdents-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getdents64.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getdents64-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getegid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -346,9 +445,15 @@ $(srcdir)/getpeername.gen.test: $(abs_sr
 $(srcdir)/getpgrp.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getpgrp--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getpid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getpid--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getppid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -376,6 +481,9 @@ $(srcdir)/getrusage.gen.test: $(abs_srcd
 $(srcdir)/getsid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getsid--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getsockname.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -391,7 +499,13 @@ $(srcdir)/getuid32.gen.test: $(abs_srcdi
 $(srcdir)/getuid32-creds.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
-$(srcdir)/getxxid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+$(srcdir)/getxgid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/getxpid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/getxuid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/group_req.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
@@ -478,6 +592,54 @@ $(srcdir)/ioctl_evdev-success-v-Xraw.gen
 $(srcdir)/ioctl_evdev-success-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioctl_hdio.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-v-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-v-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-v-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-v-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioctl_inotify.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -511,6 +673,9 @@ $(srcdir)/ioctl_nsfs.gen.test: $(abs_src
 $(srcdir)/ioctl_perf.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioctl_perf-success.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioctl_ptp.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -535,12 +700,60 @@ $(srcdir)/ioctl_sg_io_v4.gen.test: $(abs
 $(srcdir)/ioctl_sock_gifconf.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioctl_tee.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioctl_uffdio.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/ioctl_v4l2.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioctl_v4l2-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-v-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-v-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-v-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-v-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioctl_watchdog.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -553,6 +766,9 @@ $(srcdir)/iopl.gen.test: $(abs_srcdir)/g
 $(srcdir)/ioprio.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioprio--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioprio-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -619,6 +835,9 @@ $(srcdir)/kcmp.gen.test: $(abs_srcdir)/g
 $(srcdir)/kcmp-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/kcmp-y--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/kern_features.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -655,6 +874,9 @@ $(srcdir)/keyctl-Xverbose.gen.test: $(ab
 $(srcdir)/kill.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/kill--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ksysent.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -685,6 +907,9 @@ $(srcdir)/madvise.gen.test: $(abs_srcdir
 $(srcdir)/maybe_switch_current_tcp.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/maybe_switch_current_tcp--quiet-thread-execve.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/mbind.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -715,6 +940,9 @@ $(srcdir)/memfd_create-Xverbose.gen.test
 $(srcdir)/migrate_pages.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/migrate_pages--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/mincore.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -805,6 +1033,9 @@ $(srcdir)/move_pages-Xraw.gen.test: $(ab
 $(srcdir)/move_pages-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/move_pages--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/mq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -832,6 +1063,18 @@ $(srcdir)/munlockall.gen.test: $(abs_src
 $(srcdir)/nanosleep.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/net--decode-fds-dev-netlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/net--decode-fds-none-netlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/net--decode-fds-path-netlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/net--decode-fds-socket-netlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/net-icmp_filter.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -850,6 +1093,9 @@ $(srcdir)/net-packet_mreq-Xverbose.gen.t
 $(srcdir)/net-sockaddr.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/net-sockaddr--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/net-tpacket_req.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -961,6 +1207,9 @@ $(srcdir)/nlattr_ifla_port.gen.test: $(a
 $(srcdir)/nlattr_ifla_xdp.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/nlattr_ifla_xdp-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/nlattr_inet_diag_msg.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1069,6 +1318,36 @@ $(srcdir)/open_tree-P.gen.test: $(abs_sr
 $(srcdir)/openat.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/openat2.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v-y-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v-y-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v-y-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/orphaned_process_group.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1096,18 +1375,45 @@ $(srcdir)/personality-Xraw.gen.test: $(a
 $(srcdir)/personality-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/pidfd_getfd.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_getfd-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_getfd-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pidfd_open.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/pidfd_open--decode-fd-path.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_open--decode-fd-pidfd.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_open--decode-fd-socket.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pidfd_open-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/pidfd_open-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/pidfd_open-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_open--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pidfd_send_signal.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/pidfd_send_signal--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pipe2.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1174,12 +1480,21 @@ $(srcdir)/printstrn-umoven-undumpable.ge
 $(srcdir)/prlimit64.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/prlimit64--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/process_vm_readv.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/process_vm_readv--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/process_vm_writev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/process_vm_writev--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pselect6.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1288,6 +1603,9 @@ $(srcdir)/rt_sigprocmask.gen.test: $(abs
 $(srcdir)/rt_sigqueueinfo.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/rt_sigqueueinfo--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/rt_sigreturn.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1300,6 +1618,9 @@ $(srcdir)/rt_sigtimedwait.gen.test: $(ab
 $(srcdir)/rt_tgsigqueueinfo.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/rt_tgsigqueueinfo--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/s390_guarded_storage.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1330,15 +1651,27 @@ $(srcdir)/sched_rr_get_interval.gen.test
 $(srcdir)/sched_xetaffinity.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/sched_xetaffinity--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sched_xetattr.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/sched_xetattr--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sched_xetparam.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/sched_xetparam--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sched_xetscheduler.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/sched_xetscheduler--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sched_yield.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1477,6 +1810,9 @@ $(srcdir)/signal.gen.test: $(abs_srcdir)
 $(srcdir)/signal_receive.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/signal_receive--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/signalfd4.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1510,6 +1846,9 @@ $(srcdir)/so_peercred-Xraw.gen.test: $(a
 $(srcdir)/so_peercred-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/so_peercred--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sock_filter-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1561,18 +1900,141 @@ $(srcdir)/status-all.gen.test: $(abs_src
 $(srcdir)/status-failed.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/status-failed-long.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/status-failed-status.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/status-none.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/status-successful.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/status-successful-long.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/status-successful-status.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/status-unfinished.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/statx.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/strace--absolute-timestamps.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time-precision-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time-precision-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time-precision-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time-precision-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-unix-precision-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-unix-precision-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-unix-precision-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-unix-precision-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--follow-forks-output-separately.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--strings-in-hex.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--strings-in-hex-all.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--strings-in-hex-non-ascii.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-unix-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-unix-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-unix-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-unix-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace-n.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace-x.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace-xx.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/swap.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1603,6 +2065,24 @@ $(srcdir)/syslog.gen.test: $(abs_srcdir)
 $(srcdir)/tee.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/tgkill.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/tgkill--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/threads-execve--quiet-thread-execve.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/threads-execve-q.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/threads-execve-qq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/threads-execve-qqq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/time.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1621,6 +2101,15 @@ $(srcdir)/times.gen.test: $(abs_srcdir)/
 $(srcdir)/times-fail.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/tkill.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/tkill--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/trace_clock.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/trace_creds.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1666,6 +2155,9 @@ $(srcdir)/trace_statfs.gen.test: $(abs_s
 $(srcdir)/trace_statfs_like.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/trie_test.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/truncate.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1687,6 +2179,9 @@ $(srcdir)/umovestr-illptr.gen.test: $(ab
 $(srcdir)/umovestr3.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/umovestr_cached_adjacent.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/unlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -1753,14 +2248,23 @@ $(srcdir)/xattr-strings.gen.test: $(abs_
 $(srcdir)/xet_robust_list.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/xet_robust_list--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/xetitimer.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/xetpgid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/xetpgid--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/xetpriority.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/xetpriority--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/xettimeofday.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
diff -pruN 5.5-3/tests-mx32/gen_tests.in 5.9-0ubuntu2/tests-mx32/gen_tests.in
--- 5.5-3/tests-mx32/gen_tests.in	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/gen_tests.in	2020-09-23 12:56:26.000000000 +0000
@@ -38,13 +38,37 @@ clone3-Xverbose	-a16 -Xverbose -e trace=
 clone3-success-Xabbrev	+clone3-success.test -a16 -Xabbrev
 clone3-success-Xraw	+clone3-success.test -a16 -Xraw
 clone3-success-Xverbose	+clone3-success.test -a16 -Xverbose
+clone_parent +clone_ptrace.test
+clone_parent--quiet-exit +clone_ptrace.test --quiet=exit,personality
+clone_parent-q +clone_ptrace.test -q
+clone_parent-qq +clone_ptrace.test -qq
+clone_ptrace--quiet-attach +clone_ptrace.test --quiet=attach,personality
+clone_ptrace--quiet-exit +clone_ptrace.test --quiet=exit,personality
+clone_ptrace-q +clone_ptrace.test -q
+clone_ptrace-qq +clone_ptrace.test -qq
+close_range	-a21 7>>/dev/full
+close_range-P	-a21 --trace=close_range -P /dev/full 7>>/dev/full
+close_range-y	-a33 --trace=close_range -y 7>>/dev/full
+close_range-yy	-a33 --trace=close_range -yy 7>>/dev/full
 copy_file_range
 creat	-a20
 delete_module	-a23
+dev--decode-fds-dev	-a30 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" -e decode-fds=dev
+dev--decode-fds-path	-a19 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" -e decode-fds=path
+dev--decode-fds-socket	-a19 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" --decode-fds=socket
 dev-yy	-a30 -e trace=openat,fsync -P "/dev/full" -P "/dev/zero" -P "/dev/sda" -yy
-dup	-a8
-dup2	-a13
-dup3	-a24
+dup	-a7 9>>/dev/full
+dup-P	-a7 --trace=dup -P /dev/full 9>>/dev/full
+dup-y	-a8 --trace=dup -y 9>>/dev/full
+dup-yy	-a8 --trace=dup -yy 9>>/dev/full
+dup2	-a11 9>>/dev/full
+dup2-P	-a11 --trace=dup2 -P /dev/full 9>>/dev/full
+dup2-y	-a13 --trace=dup2 -y 9>>/dev/full
+dup2-yy	-a13 --trace=dup2 -yy 9>>/dev/full
+dup3	-a13 7>>/dev/full
+dup3-P	-a13 --trace=dup3 -P /dev/full 7>>/dev/full
+dup3-y	-a15 --trace=dup3 -y 7>>/dev/full
+dup3-yy	-a15 --trace=dup3 -yy 7>>/dev/full
 epoll_create	-a17
 epoll_create1	-a28
 epoll_ctl
@@ -53,7 +77,12 @@ epoll_wait	-a26
 erestartsys	-a34 -e signal=none -e trace=recvfrom
 execveat
 execveat-v	-v -e trace=execveat
-faccessat	-P $NAME.sample
+faccessat-P	-a23 --trace=faccessat -P /dev/full
+faccessat-y	+faccessat.test -a24 -y
+faccessat-yy	+faccessat.test -a24 -yy
+faccessat2-P	-a27 --trace=faccessat2 -P /dev/full
+faccessat2-y	+faccessat2.test -a28 -y
+faccessat2-yy	+faccessat2.test -a28 -yy
 fadvise64_64	+fadvise64.test
 fallocate	-a18
 fanotify_init
@@ -68,7 +97,9 @@ fchown	-a16
 fchown32	-a18
 fchownat
 fcntl	-a8
+fcntl--pidns-translation	test_pidns -a8 -e trace=fcntl
 fcntl64	-a8
+fcntl64--pidns-translation	test_pidns -a8 -e trace=fcntl64
 fdatasync	-a14
 file_handle	-e trace=name_to_handle_at,open_by_handle_at
 file_ioctl	+ioctl.test
@@ -102,8 +133,10 @@ futimesat	-a28
 get_mempolicy	-s3 -a38
 getcpu	-a25
 getcwd	-a18
-getdents	-a22 -v
-getdents64	-a24 -v
+getdents	-a31
+getdents-v	-a22 -v --trace=getdents
+getdents64	-a33
+getdents64-v	-a24 -v --trace=getdents64
 getegid	+getuid.test
 getegid-creds	+getuid.test
 getegid32	+getuid.test
@@ -120,7 +153,9 @@ getgroups	-a17
 getgroups32	-a19
 getpeername	-a27
 getpgrp	-a10
+getpgrp--pidns-translation	test_pidns -e trace=getpgrp -a10
 getpid	-a9
+getpid--pidns-translation	test_pidns -e trace=getpid -a9
 getppid	-a10
 getrandom	-a32 -s3
 getresgid	-a25
@@ -130,12 +165,15 @@ getresuid32	-a27
 getrlimit	-a27
 getrusage	-v
 getsid	-a10
+getsid--pidns-translation	test_pidns -e trace=getsid -a10
 getsockname	-a27
 gettid	-a9
 getuid-creds	+getuid.test
 getuid32	+getuid.test
 getuid32-creds	+getuid.test
-getxxid	-a10 -e trace=getxpid,getxuid,getxgid
+getxgid	-a10
+getxpid	-a10
+getxuid	-a10
 group_req	-e trace=setsockopt
 inet-cmsg	-e trace=recvmsg
 init_module	-a27
@@ -164,6 +202,22 @@ ioctl_evdev-success-v	+ioctl_evdev-succe
 ioctl_evdev-success-v-Xabbrev	+ioctl_evdev-success.test -v -Xabbrev
 ioctl_evdev-success-v-Xraw	+ioctl_evdev-success.test -a27 -v -Xraw
 ioctl_evdev-success-v-Xverbose	+ioctl_evdev-success.test -a43 -v -Xverbose
+ioctl_hdio	+ioctl.test -a27
+ioctl_hdio-Xabbrev	+ioctl.test -a27 -Xabbrev
+ioctl_hdio-Xraw	+ioctl.test -a20 -Xraw
+ioctl_hdio-Xverbose	+ioctl.test -a39 -Xverbose
+ioctl_hdio-v	+ioctl.test -a27 -v
+ioctl_hdio-v-Xabbrev	+ioctl.test -a27 -v -Xabbrev
+ioctl_hdio-v-Xraw	+ioctl.test -a20 -v -Xraw
+ioctl_hdio-v-Xverbose	+ioctl.test -a39 -v -Xverbose
+ioctl_hdio-success	+ioctl-success.sh -a27
+ioctl_hdio-success-Xabbrev	+ioctl-success.sh -a27 -Xabbrev
+ioctl_hdio-success-Xraw	+ioctl-success.sh -a20 -Xraw
+ioctl_hdio-success-Xverbose	+ioctl-success.sh -a39 -Xverbose
+ioctl_hdio-success-v	+ioctl-success.sh -a27 -v
+ioctl_hdio-success-v-Xabbrev	+ioctl-success.sh -a27 -v -Xabbrev
+ioctl_hdio-success-v-Xraw	+ioctl-success.sh -a20 -v -Xraw
+ioctl_hdio-success-v-Xverbose	+ioctl-success.sh -a39 -v -Xverbose
 ioctl_inotify	+ioctl.test
 ioctl_kvm_run	+ioctl.test -a36 -y
 ioctl_kvm_run-v	+ioctl.test -v -a36 -y
@@ -175,6 +229,7 @@ ioctl_mtd	+ioctl.test
 ioctl_nbd	+ioctl.test -y
 ioctl_nsfs	+ioctl.test -esignal=none
 ioctl_perf	+ioctl.test
+ioctl_perf-success +ioctl-success.sh -a35
 ioctl_ptp	+ioctl.test
 ioctl_random	+ioctl.test
 ioctl_rtc	+ioctl.test
@@ -183,12 +238,29 @@ ioctl_scsi	+ioctl.test
 ioctl_sg_io_v3	+ioctl.test
 ioctl_sg_io_v4	+ioctl.test
 ioctl_sock_gifconf	+ioctl.test -a28 -s1
+ioctl_tee	+ioctl.test
 ioctl_uffdio	+ioctl.test
 ioctl_v4l2	+ioctl.test
+ioctl_v4l2-Xabbrev	+ioctl.test -Xabbrev
+ioctl_v4l2-Xraw	+ioctl.test -Xraw
+ioctl_v4l2-Xverbose	+ioctl.test -Xverbose
+ioctl_v4l2-v	+ioctl.test -v
+ioctl_v4l2-v-Xabbrev	+ioctl.test -v -Xabbrev
+ioctl_v4l2-v-Xraw	+ioctl.test -v -Xraw
+ioctl_v4l2-v-Xverbose	+ioctl.test -v -Xverbose
+ioctl_v4l2-success	+ioctl-success.sh -a29
+ioctl_v4l2-success-Xabbrev	+ioctl-success.sh -a29 -Xabbrev
+ioctl_v4l2-success-Xraw	+ioctl-success.sh -a27 -Xraw
+ioctl_v4l2-success-Xverbose	+ioctl-success.sh -a30 -Xverbose
+ioctl_v4l2-success-v	+ioctl-success.sh -a29 -v
+ioctl_v4l2-success-v-Xabbrev	+ioctl-success.sh -a29 -v -Xabbrev
+ioctl_v4l2-success-v-Xraw	+ioctl-success.sh -a27 -v -Xraw
+ioctl_v4l2-success-v-Xverbose	+ioctl-success.sh -a29 -v -Xverbose
 ioctl_watchdog	+ioctl.test
 ioperm	-a27
 iopl	-a8
 ioprio	-a18 -e trace=ioprio_get,ioprio_set
+ioprio--pidns-translation	test_pidns -a18 -e trace=ioprio_get,ioprio_set
 ioprio-Xabbrev	-a18 -e trace=ioprio_get,ioprio_set -Xabbrev
 ioprio-Xraw	-a18 -e trace=ioprio_get,ioprio_set -Xraw
 ioprio-Xverbose	-a18 -e trace=ioprio_get,ioprio_set -Xverbose
@@ -211,6 +283,7 @@ ipc_shm-Xraw	+ipc.sh -Xraw -a19
 ipc_shm-Xverbose	+ipc.sh -Xverbose -a34
 kcmp	-a22
 kcmp-y	-a22 -y -e trace=kcmp
+kcmp-y--pidns-translation	test_pidns -a22 -y -e trace=kcmp
 kern_features -a16
 kernel_version	-a16 -v -e trace=bpf
 kernel_version-Xabbrev	-a16 -Xabbrev -v -e trace=bpf
@@ -223,6 +296,7 @@ keyctl-Xabbrev	-a31 -s10 -e trace=keyctl
 keyctl-Xraw	-a13 -s10 -e trace=keyctl -Xraw
 keyctl-Xverbose	-a41 -s10 -e trace=keyctl -Xverbose
 kill	-a12 -esignal=none
+kill--pidns-translation	test_pidns -a12 -e trace=kill -esignal=none
 ksysent	../$NAME
 lchown	-a30
 lchown32	-a32
@@ -233,6 +307,7 @@ lstat	-a31 --no-abbrev --trace-path=stat
 lstat64	-a32 --no-abbrev --trace-path=stat.sample --trace-path=/dev/full
 madvise	-a33
 maybe_switch_current_tcp	-a30 -f -e trace=execveat
+maybe_switch_current_tcp--quiet-thread-execve	-a30 -s48 -f -e trace=execveat --quiet=personality,thread-execve
 mbind
 mbind-Xabbrev	-Xabbrev -e trace=mbind
 mbind-Xraw	-a33 -Xraw -e trace=mbind
@@ -243,6 +318,7 @@ memfd_create-Xabbrev	-Xabbrev -e trace=m
 memfd_create-Xraw	-a30 -Xraw -e trace=memfd_create
 memfd_create-Xverbose	-Xverbose -e trace=memfd_create
 migrate_pages	-a33
+migrate_pages--pidns-translation	test_pidns -a33 -e trace=migrate_pages
 mincore	-a22
 mkdir	-a20
 mkdirat	-a28
@@ -273,6 +349,7 @@ move_pages	-s3
 move_pages-Xabbrev	-s3 -e trace=move_pages -Xabbrev
 move_pages-Xraw	-s3 -a36 -e trace=move_pages -Xraw
 move_pages-Xverbose	-s3 -e trace=move_pages -Xverbose
+move_pages--pidns-translation	test_pidns -s3 -e trace=move_pages
 mq	-a32 -e trace=mq_getsetattr,mq_open,mq_unlink
 mq_sendrecv	-a14 -e trace=mq_open,mq_notify,mq_timedsend,mq_timedreceive,mq_unlink
 mq_sendrecv-read	-eread=0 -a14 -e trace=mq_open,mq_notify,mq_timedsend,mq_timedreceive,mq_unlink
@@ -282,12 +359,17 @@ msg_control-v	-v -a21 -e trace=sendmsg
 msg_name	-a20 -e trace=recvmsg
 munlockall	-a13
 nanosleep	-a20
+net--decode-fds-dev-netlink	+net-yy-netlink.test --decode-fds=dev
+net--decode-fds-none-netlink	+net-yy-netlink.test --decode-fds=none -a9
+net--decode-fds-path-netlink	+net-yy-netlink.test --decode-fds=path
+net--decode-fds-socket-netlink	+net-yy-netlink.test --decode-fds=socket
 net-icmp_filter	-e trace=getsockopt,setsockopt
 net-packet_mreq -e trace=setsockopt
 net-packet_mreq-Xabbrev	-e trace=setsockopt -Xabbrev
 net-packet_mreq-Xraw	-e trace=setsockopt -Xraw
 net-packet_mreq-Xverbose	-e trace=setsockopt -Xverbose
 net-sockaddr	-a24 -e trace=connect
+net-sockaddr--pidns-translation	test_pidns -a24 -e trace=connect
 net-tpacket_req -e trace=setsockopt
 net-tpacket_stats -e trace=getsockopt
 net-yy-inet6	+net-yy-inet.test
@@ -325,6 +407,7 @@ nlattr_ifla_brport		+netlink_sock_diag.t
 nlattr_ifla_linkinfo		+netlink_sock_diag.test
 nlattr_ifla_port		+netlink_sock_diag.test
 nlattr_ifla_xdp			+netlink_sock_diag.test
+nlattr_ifla_xdp-y		+netlink_sock_diag.test -y; exec 9</dev/full
 nlattr_inet_diag_msg		+netlink_sock_diag.test
 nlattr_inet_diag_req_compat	+netlink_sock_diag.test
 nlattr_inet_diag_req_v2		+netlink_sock_diag.test
@@ -335,7 +418,7 @@ nlattr_ndtmsg			+netlink_sock_diag.test
 nlattr_netconfmsg		+netlink_sock_diag.test
 nlattr_netlink_diag_msg		+netlink_sock_diag.test
 nlattr_nlmsgerr			+netlink_sock_diag.test
-nlattr_packet_diag_msg		+netlink_sock_diag-v.sh
+nlattr_packet_diag_msg		+netlink_sock_diag.test -v
 nlattr_rtgenmsg			+netlink_sock_diag.test
 nlattr_rtmsg			+netlink_sock_diag.test
 nlattr_smc_diag_msg		+netlink_sock_diag.test
@@ -359,8 +442,18 @@ oldselect-efault-P	-a13 -e trace=select
 oldstat	-a32 -v -P stat.sample -P /dev/full
 open	-a30 -P $NAME.sample
 open_tree -a30 -y
-open_tree-P -a30 -y -P /dev/full -e trace=open_tree
+open_tree-P -a30 --decode-fds -P /dev/full -e trace=open_tree
 openat	-a36 -P $NAME.sample
+openat2	-a35
+openat2-Xabbrev	--trace=openat2 -a35 -Xabbrev
+openat2-Xraw	--trace=openat2 -a32 -Xraw
+openat2-Xverbose	--trace=openat2 -a35 -Xverbose
+openat2-v	--trace=openat2 -a35 -v
+openat2-v-y	--trace=openat2 -a36 -v -y </dev/full
+openat2-v-y-Xabbrev	--trace=openat2 -a35 -v -y -Xabbrev </dev/full
+openat2-v-y-Xraw	--trace=openat2 -a32 -v -y -Xraw </dev/full
+openat2-v-y-Xverbose	--trace=openat2 -a44 -v -y -Xverbose </dev/full
+openat2-y	--trace=openat2 -a36 -y </dev/full
 orphaned_process_group	. "${srcdir=.}/PTRACE_SEIZE.sh"; run_strace_match_diff -f -e trace=none -e signal='!chld'
 osf_utimes	-a21
 pause	-a8 -esignal=none
@@ -370,10 +463,19 @@ perf_event_open_unabbrev	-a1 -v -e trace
 personality-Xabbrev	+personality.test -Xabbrev
 personality-Xraw	+personality.test -a15 -Xraw
 personality-Xverbose	+personality.test -Xverbose
+pidfd_getfd	-a18 -Xverbose -e signal=none </dev/full
+pidfd_getfd-y	--trace=pidfd_getfd -a18 -e signal=none -y </dev/full
+pidfd_getfd-yy	--trace=pidfd_getfd -a18 -e signal=none -yy </dev/full
 pidfd_open	-a17
+pidfd_open--decode-fd-path	-a17 -e decode-fd=path -e trace=pidfd_open
+pidfd_open--decode-fd-pidfd	-a17 -e decode-fd=pidfd -e trace=pidfd_open
+pidfd_open--decode-fd-socket	-a17 -e decode-fd=socket -e trace=pidfd_open
 pidfd_open-P	-a17 -P /dev/full -e trace=pidfd_open
 pidfd_open-y	-a17 -y -e trace=pidfd_open
+pidfd_open-yy	-a17 -yy -e trace=pidfd_open
+pidfd_open--pidns-translation	test_pidns -a17 -e trace=pidfd_open
 pidfd_send_signal
+pidfd_send_signal--pidns-translation test_pidns -e trace=pidfd_send_signal
 pipe2	-a15
 pkey_alloc	-a17
 pkey_free	-a13
@@ -396,8 +498,11 @@ printstrn-umoven	-s4096 -e signal=none -
 printstrn-umoven-peekdata	-e signal=none -e trace=add_key
 printstrn-umoven-undumpable	-e signal=none -e trace=add_key
 prlimit64
+prlimit64--pidns-translation     test_pidns -e trace=prlimit64
 process_vm_readv	-s5 -a37
+process_vm_readv--pidns-translation	test_pidns -s5 -a37 -e trace=process_vm_readv
 process_vm_writev	-s5 -a38
+process_vm_writev--pidns-translation	test_pidns -s5 -a38 -e trace=process_vm_writev
 pselect6
 ptrace	-a23 -e signal=none
 ptrace_syscall_info	-a35 -e signal=none -e trace=ptrace
@@ -434,10 +539,12 @@ rmdir	-a22
 rt_sigpending	-a20
 rt_sigprocmask
 rt_sigqueueinfo	-esignal=none
+rt_sigqueueinfo--pidns-translation	test_pidns -esignal=none -e trace=rt_sigqueueinfo
 rt_sigreturn	-esignal='!USR1'
 rt_sigsuspend	-a20 -esignal=none
 rt_sigtimedwait	-a38
 rt_tgsigqueueinfo	-esignal=none
+rt_tgsigqueueinfo--pidns-translation	test_pidns -esignal=none -e trace=rt_tgsigqueueinfo
 s390_guarded_storage	-a32
 s390_guarded_storage-v	-e trace=s390_guarded_storage -a32 -v
 s390_pci_mmio_read_write	-e trace=s390_pci_mmio_read,s390_pci_mmio_write -a30
@@ -448,9 +555,13 @@ sched	test_trace_expr times -e/sched
 sched_get_priority_mxx	-a33 -e trace=sched_get_priority_min,sched_get_priority_max
 sched_rr_get_interval	-a31
 sched_xetaffinity	-a28 -e trace=sched_getaffinity,sched_setaffinity
+sched_xetaffinity--pidns-translation	test_pidns -a28 -e trace=sched_getaffinity,sched_setaffinity
 sched_xetattr	-a29 -e trace=sched_getattr,sched_setattr
+sched_xetattr--pidns-translation	test_pidns -a29 -e trace=sched_getattr,sched_setattr
 sched_xetparam	-a23 -e trace=sched_getparam,sched_setparam
+sched_xetparam--pidns-translation	test_pidns -a23 -e trace=sched_getparam,sched_setparam
 sched_xetscheduler	-a22 -e trace=sched_getscheduler,sched_setscheduler
+sched_xetscheduler--pidns-translation	test_pidns -a22 -e trace=sched_getscheduler,sched_setscheduler
 sched_yield	-a14
 seccomp-filter	-e trace=seccomp
 seccomp-filter-v	-v -e trace=seccomp
@@ -497,6 +608,7 @@ sigaction	-a31
 siginfo	-e trace=none
 signal	-a25 -e signal=none -e trace='/^signal$'
 signal_receive	-a16 -e trace=kill
+signal_receive--pidns-translation	test_pidns -a16 -e trace=kill
 signalfd4
 sigpending	-a15
 sigprocmask	-a34
@@ -508,6 +620,7 @@ so_peercred	-e trace=getsockopt
 so_peercred-Xabbrev	-e trace=getsockopt -Xabbrev
 so_peercred-Xraw	-e trace=getsockopt -Xraw -a39
 so_peercred-Xverbose	-e trace=getsockopt -Xverbose
+so_peercred--pidns-translation	test_pidns -e trace=getsockopt
 sock_filter-v	-v -e trace=getsockopt,setsockopt
 sock_filter-v-Xabbrev	-v -e trace=getsockopt,setsockopt -X abbrev
 sock_filter-v-Xraw	-a 37 -v -e trace=getsockopt,setsockopt -X raw
@@ -525,10 +638,51 @@ statfs	-a17
 statfs64	-a23
 status-all	-a10 -e trace=chdir --status=detached,failed,successful,unavailable,unfinished
 status-failed	-a10 -e trace=chdir -Z
+status-failed-long	-a10 -e trace=chdir --failed-only
+status-failed-status	-a10 -e trace=chdir -e status=failed
 status-none	-e trace=all --status=none
 status-successful	-a10 -e trace=chdir -z
+status-successful-long	-a10 -e trace=chdir --successful-only
+status-successful-status	-a10 -e trace=chdir --status=successful
 status-unfinished	-a10 -e trace=all --status=unfinished
 statx	-a32 --no-abbrev --trace-path=stat.sample --trace-path=/dev/full
+strace--absolute-timestamps +strace-t.test --absolute-timestamps
+strace--absolute-timestamps-format-time +strace-t.test --absolute-timestamps=format:time
+strace--absolute-timestamps-format-time-precision-s +strace-t.test --absolute-timestamps=format:time --absolute-timestamps=precision:s
+strace--absolute-timestamps-format-time-precision-ms +strace-tt.test 3 --absolute-timestamps=format:time --absolute-timestamps=precision:ms
+strace--absolute-timestamps-format-time-precision-us +strace-tt.test 6 --absolute-timestamps=format:time --absolute-timestamps=precision:us
+strace--absolute-timestamps-format-time-precision-ns +strace-tt.test 9 --absolute-timestamps=format:time --absolute-timestamps=precision:ns
+strace--absolute-timestamps-format-unix-precision-s +strace-ttt.test 0 --absolute-timestamps=format:unix --absolute-timestamps=precision:s
+strace--absolute-timestamps-format-unix-precision-ms +strace-ttt.test 3 --absolute-timestamps=precision:ms --absolute-timestamps=format:unix
+strace--absolute-timestamps-format-unix-precision-us +strace-ttt.test 6 --absolute-timestamps=precision:us --absolute-timestamps=format:unix
+strace--absolute-timestamps-format-unix-precision-ns +strace-ttt.test 9 --absolute-timestamps=format:unix --absolute-timestamps=precision:ns
+strace--follow-forks-output-separately +strace-ff.test --follow-forks --output-separately
+strace--relative-timestamps +strace-r.test --relative-timestamps
+strace--relative-timestamps-s +strace-r.test --relative-timestamps=s
+strace--relative-timestamps-ms +strace-r.test --relative-timestamps=ms
+strace--relative-timestamps-us +strace-r.test --relative-timestamps=us
+strace--relative-timestamps-ns +strace-r.test --relative-timestamps=ns
+strace--syscall-times +strace-T.test --syscall-times
+strace--syscall-times-s +strace-T.test --syscall-times=s
+strace--syscall-times-ms +strace-T.test --syscall-times=ms
+strace--syscall-times-us +strace-T.test --syscall-times=us
+strace--syscall-times-ns +strace-T.test --syscall-times=ns
+strace--strings-in-hex	--trace=chdir --strings-in-hex --columns=18
+strace--strings-in-hex-all	--trace=chdir --strings-in-hex=all --columns=18
+strace--strings-in-hex-non-ascii	--trace=chdir --strings-in-hex=non-ascii --columns=12
+strace--timestamps +strace-t.test --timestamps
+strace--timestamps-time +strace-t.test --timestamps=time
+strace--timestamps-time-s +strace-t.test --timestamps=time,s
+strace--timestamps-time-ms +strace-tt.test 3 --timestamps=time,ms
+strace--timestamps-time-us +strace-tt.test 6 --timestamps=time,us
+strace--timestamps-time-ns +strace-tt.test 9 --timestamps=time,ns
+strace--timestamps-unix-s +strace-ttt.test 0 --timestamps=unix,s
+strace--timestamps-unix-ms +strace-ttt.test 3 --timestamps=unix,ms
+strace--timestamps-unix-us +strace-ttt.test 6 --timestamps=unix,us
+strace--timestamps-unix-ns +strace-ttt.test 9 --timestamps=unix,ns
+strace-n	-e trace=listen -n -qq -a 12
+strace-x	-e trace=chdir -x -a 12
+strace-xx	-e trace=chdir -xx -a 18
 swap	-a23 -e trace=swapon,swapoff
 sxetmask	-a11 -e trace=sgetmask,ssetmask
 symlink	-a34
@@ -539,12 +693,21 @@ sync_file_range2
 sysinfo	-a14
 syslog	-a35
 tee
+tgkill	-a15 --signal='!cont'
+tgkill--pidns-translation       test_pidns -a15 --signal='!cont' -e trace=tgkill
+threads-execve--quiet-thread-execve +threads-execve.test -s40 --quiet=personality,thread-execve
+threads-execve-q +threads-execve.test -q
+threads-execve-qq +threads-execve.test -qq
+threads-execve-qqq +threads-execve.test -qqq
 time	-a10
 timer_create
 timer_xettime	-e trace=timer_create,timer_settime,timer_gettime
 timerfd_xettime	-e trace=timerfd_create,timerfd_settime,timerfd_gettime
 times	-esignal=none
 times-fail	-a12 -e trace=times
+tkill	-a12 --signal='!cont'
+tkill--pidns-translation       test_pidns --signal='!cont' -a12 -e trace=tkill
+trace_clock	test_trace_expr 'clock_nanosleep|times' -e%clock
 trace_creds	test_trace_expr '([gs]et[^p]*([gu]id|groups)|caps|prctl|[fl]?chown|print(path-umovestr|strn-umoven)-undumpable|ptrace|quotactl|rt_sigtimedwait|rt_(tg)?sigqueueinfo).*' -e%creds
 trace_fstat	test_trace_expr '' -e%fstat -v -P stat.sample -P /dev/full
 trace_fstatfs	test_trace_expr '' -e%fstatfs
@@ -560,6 +723,7 @@ trace_stat	test_trace_expr '' -e%stat -v
 trace_stat_like	test_trace_expr '' -e%%stat -v -P stat.sample -P /dev/full
 trace_statfs	test_trace_expr '' -e%statfs
 trace_statfs_like	test_trace_expr '' -e%%statfs
+trie_test    run_prog
 truncate
 truncate64
 ugetrlimit	-a28
@@ -567,6 +731,7 @@ umask	-a11
 umoven-illptr	-a36 -e trace=nanosleep
 umovestr-illptr	-a11 -e trace=chdir
 umovestr3	-a14 -e trace=chdir
+umovestr_cached_adjacent	+umovestr_cached.test 3
 unlink	-a24
 unlinkat	-a35
 unshare	-a11
@@ -589,7 +754,10 @@ waitpid	-a28
 xattr	-a22 -e trace=getxattr,fgetxattr,lgetxattr,setxattr,fsetxattr,lsetxattr,listxattr,flistxattr,llistxattr,removexattr,fremovexattr,lremovexattr
 xattr-strings	-a22 -s 4 -e trace=fsetxattr
 xet_robust_list	-a24 -e trace=get_robust_list,set_robust_list
+xet_robust_list--pidns-translation	test_pidns -a24 -e trace=get_robust_list,set_robust_list
 xetitimer	-a29 -e trace=setitimer,getitimer
 xetpgid	-a11 -e trace=getpgid,setpgid
-xetpriority	-a29 -e trace=getpriority,setpriority
+xetpgid--pidns-translation	test_pidns -a11 -e trace=getpgid,setpgid
+xetpriority	-a27 -e trace=getpriority,setpriority
+xetpriority--pidns-translation	test_pidns -a27 -e trace=getpriority,setpriority
 xettimeofday	-a20 -e trace=gettimeofday,settimeofday
diff -pruN 5.5-3/tests-mx32/getdents64.c 5.9-0ubuntu2/tests-mx32/getdents64.c
--- 5.5-3/tests-mx32/getdents64.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getdents64.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,6 +1,8 @@
 /*
+ * Check decoding of getdents64 syscall.
+ *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -11,115 +13,29 @@
 
 #ifdef __NR_getdents64
 
-# include <assert.h>
-# include <dirent.h>
-# include <fcntl.h>
-# include <inttypes.h>
-# include <stddef.h>
-# include <stdio.h>
-# include <sys/stat.h>
-# include <unistd.h>
-
-static const char fname[] =
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nZ";
-static const char qname[] =
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nZ";
-
-typedef struct {
-		uint64_t d_ino;
-		uint64_t d_off;
-		unsigned short d_reclen;
-		unsigned char d_type;
-		char d_name[256];
-} kernel_dirent64;
+# define kernel_dirent_type kernel_dirent64_t
+# define NR_getdents	__NR_getdents64
+# define STR_getdents	"getdents64"
 
-static char buf[8192];
+# include "xgetdents.c"
 
-static const char *
-str_d_type(const unsigned char d_type)
-{
-	switch (d_type) {
-		case DT_DIR:
-			return "DT_DIR";
-		case DT_REG:
-			return "DT_REG";
-		default:
-			return "DT_UNKNOWN";
-	}
-}
+# if VERBOSE
 static void
-print_dirent(const kernel_dirent64 *d)
-{
-	const unsigned int d_name_offset = offsetof(kernel_dirent64, d_name);
-	int d_name_len = d->d_reclen - d_name_offset;
-	assert(d_name_len > 0);
-
-	printf("{d_ino=%" PRIu64 ", d_off=%" PRId64
-	       ", d_reclen=%u, d_type=%s, d_name=",
-	       d->d_ino, d->d_off, d->d_reclen, str_d_type(d->d_type));
-
-	if (d->d_name[0] == '.')
-		printf("\"%.*s\"}", d_name_len, d->d_name);
-	else
-		printf("\"%s\"}", qname);
-}
-
-int
-main(void)
+print_dirent(const kernel_dirent_type *d)
 {
-	static const char dname[] = "getdents64.test.tmp.dir";
-
-	assert(!mkdir(dname, 0700));
-	assert(!chdir(dname));
-	(void) close(0);
-	assert(!creat(fname, 0600));
-	assert(!close(0));
-	assert(!open(".", O_RDONLY | O_DIRECTORY));
-
-	unsigned long count = (unsigned long) 0xfacefeeddeadbeefULL;
-	long rc = syscall(__NR_getdents64, (long) 0xdefacedffffffffULL, NULL,
-			  count);
-	printf("getdents64(-1, NULL, %u) = %ld %s (%m)\n",
-	       (unsigned) count, rc, errno2name());
-
-	count = (unsigned long) 0xfacefeed00000000ULL | sizeof(buf);
-	while ((rc = syscall(__NR_getdents64, 0, buf, count))) {
-		kernel_dirent64 *d;
-		long i;
-
-		if (rc < 0)
-			perror_msg_and_skip("getdents64");
-		printf("getdents64(0, [");
-		for (i = 0; i < rc; i += d->d_reclen) {
-			d = (kernel_dirent64 *) &buf[i];
-			if (i)
-				printf(", ");
-			print_dirent(d);
-		}
-		printf("], %u) = %ld\n", (unsigned) count, rc);
-	}
-	printf("getdents64(0, [], %u) = 0\n", (unsigned) count);
-	puts("+++ exited with 0 +++");
-	assert(!unlink(fname));
-	assert(!chdir(".."));
-	assert(!rmdir(dname));
-
-	return 0;
+	const unsigned int d_name_offset = offsetof(kernel_dirent_type, d_name);
+	int d_name_len = (int) d->d_reclen - d_name_offset;
+	if (d_name_len <= 0)
+		error_msg_and_fail("d_name_len = %d", d_name_len);
+
+	PRINT_FIELD_U("{", *d, d_ino);
+	PRINT_FIELD_U(", ", *d, d_off);
+	PRINT_FIELD_U(", ", *d, d_reclen);
+	printf(", d_type=%s, d_name=", str_d_type(d->d_type));
+	print_quoted_cstring(d->d_name, d_name_len);
+	printf("}");
 }
+# endif
 
 #else
 
diff -pruN 5.5-3/tests-mx32/getdents64.gen.test 5.9-0ubuntu2/tests-mx32/getdents64.gen.test
--- 5.5-3/tests-mx32/getdents64.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getdents64.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -1,4 +1,4 @@
 #!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getdents64 -a24 -v); do not edit.
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getdents64 -a33 ); do not edit.
 . "${srcdir=.}/init.sh"
-run_strace_match_diff -a24 -v
+run_strace_match_diff -a33 
diff -pruN 5.5-3/tests-mx32/getdents64-v.c 5.9-0ubuntu2/tests-mx32/getdents64-v.c
--- 5.5-3/tests-mx32/getdents64-v.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getdents64-v.c	2020-04-11 01:01:47.000000000 +0000
@@ -0,0 +1,3 @@
+/* Check --no-abbrev decoding of getdents64 syscall.  */
+#define VERBOSE 1
+#include "getdents64.c"
diff -pruN 5.5-3/tests-mx32/getdents64-v.gen.test 5.9-0ubuntu2/tests-mx32/getdents64-v.gen.test
--- 5.5-3/tests-mx32/getdents64-v.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getdents64-v.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getdents64-v -a24 -v --trace=getdents64); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a24 -v --trace=getdents64
diff -pruN 5.5-3/tests-mx32/getdents.c 5.9-0ubuntu2/tests-mx32/getdents.c
--- 5.5-3/tests-mx32/getdents.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getdents.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,6 +1,8 @@
 /*
+ * Check decoding of getdents syscall.
+ *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -11,109 +13,30 @@
 
 #ifdef __NR_getdents
 
-# include <assert.h>
-# include <dirent.h>
-# include <fcntl.h>
-# include <stddef.h>
-# include <stdio.h>
-# include <sys/stat.h>
-# include <unistd.h>
-
-static const char fname[] =
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
-	"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nZ";
-static const char qname[] =
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\n"
-	"A\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nA\\nZ";
+# define kernel_dirent_type kernel_dirent_t
+# define NR_getdents	__NR_getdents
+# define STR_getdents	"getdents"
 
-static char buf[8192];
+# include "xgetdents.c"
 
-static const char *
-str_d_type(const unsigned char d_type)
-{
-	switch (d_type) {
-		case DT_DIR:
-			return "DT_DIR";
-		case DT_REG:
-			return "DT_REG";
-		default:
-			return "DT_UNKNOWN";
-	}
-}
+# if VERBOSE
 static void
-print_dirent(const kernel_dirent *d)
+print_dirent(const kernel_dirent_type *d)
 {
-	const unsigned int d_name_offset = offsetof(kernel_dirent, d_name);
-	int d_name_len = d->d_reclen - d_name_offset - 1;
-	assert(d_name_len > 0);
-
-	printf("{d_ino=%llu, d_off=%llu, d_reclen=%u, d_name=",
-	       (unsigned long long) d->d_ino,
-	       (unsigned long long) d->d_off, d->d_reclen);
-
-	if (d->d_name[0] == '.')
-		printf("\"%.*s\"", d_name_len, d->d_name);
-	else
-		printf("\"%s\"", qname);
-
+	const unsigned int d_name_offset = offsetof(kernel_dirent_type, d_name);
+	int d_name_len = (int) d->d_reclen - d_name_offset - 1;
+	if (d_name_len <= 0)
+		error_msg_and_fail("d_name_len = %d", d_name_len);
+
+	PRINT_FIELD_U("{", *d, d_ino);
+	PRINT_FIELD_U(", ", *d, d_off);
+	PRINT_FIELD_U(", ", *d, d_reclen);
+	printf(", d_name=");
+	print_quoted_cstring(d->d_name, d_name_len);
 	printf(", d_type=%s}",
 	       str_d_type(*((const char *) d + d->d_reclen - 1)));
 }
-
-int
-main(void)
-{
-	static const char dname[] = "getdents.test.tmp.dir";
-
-	assert(!mkdir(dname, 0700));
-	assert(!chdir(dname));
-	(void) close(0);
-	assert(!creat(fname, 0600));
-	assert(!close(0));
-	assert(!open(".", O_RDONLY | O_DIRECTORY));
-
-	unsigned long count = (unsigned long) 0xfacefeeddeadbeefULL;
-	long rc = syscall(__NR_getdents, (long) 0xdefacedffffffffULL, NULL,
-			  count);
-	printf("getdents(-1, NULL, %u) = %ld %s (%m)\n",
-	       (unsigned) count, rc, errno2name());
-
-	count = (unsigned long) 0xfacefeed00000000ULL | sizeof(buf);
-	while ((rc = syscall(__NR_getdents, 0, buf, count))) {
-		kernel_dirent *d;
-		long i;
-
-		if (rc < 0)
-			perror_msg_and_skip("getdents");
-		printf("getdents(0, [");
-		for (i = 0; i < rc; i += d->d_reclen) {
-			d = (kernel_dirent *) &buf[i];
-			if (i)
-				printf(", ");
-			print_dirent(d);
-		}
-		printf("], %u) = %ld\n", (unsigned) count, rc);
-	}
-	printf("getdents(0, [], %u) = 0\n", (unsigned) count);
-	puts("+++ exited with 0 +++");
-	assert(!unlink(fname));
-	assert(!chdir(".."));
-	assert(!rmdir(dname));
-
-	return 0;
-}
+# endif
 
 #else
 
diff -pruN 5.5-3/tests-mx32/getdents.gen.test 5.9-0ubuntu2/tests-mx32/getdents.gen.test
--- 5.5-3/tests-mx32/getdents.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getdents.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -1,4 +1,4 @@
 #!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getdents -a22 -v); do not edit.
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getdents -a31 ); do not edit.
 . "${srcdir=.}/init.sh"
-run_strace_match_diff -a22 -v
+run_strace_match_diff -a31 
diff -pruN 5.5-3/tests-mx32/getdents-v.c 5.9-0ubuntu2/tests-mx32/getdents-v.c
--- 5.5-3/tests-mx32/getdents-v.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getdents-v.c	2020-04-11 01:01:47.000000000 +0000
@@ -0,0 +1,3 @@
+/* Check --no-abbrev decoding of getdents syscall.  */
+#define VERBOSE 1
+#include "getdents.c"
diff -pruN 5.5-3/tests-mx32/getdents-v.gen.test 5.9-0ubuntu2/tests-mx32/getdents-v.gen.test
--- 5.5-3/tests-mx32/getdents-v.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getdents-v.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getdents-v -a22 -v --trace=getdents); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a22 -v --trace=getdents
diff -pruN 5.5-3/tests-mx32/getpgrp.c 5.9-0ubuntu2/tests-mx32/getpgrp.c
--- 5.5-3/tests-mx32/getpgrp.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getpgrp.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -7,6 +7,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #ifdef __NR_getpgrp
 
@@ -16,8 +17,13 @@
 int
 main(void)
 {
-	printf("getpgrp() = %ld\n", syscall(__NR_getpgrp));
+	PIDNS_TEST_INIT;
 
+	pidns_print_leader();
+	printf("getpgrp() = %d%s\n", (int) syscall(__NR_getpgrp),
+		pidns_pid2str(PT_PGID));
+
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/getpgrp--pidns-translation.c 5.9-0ubuntu2/tests-mx32/getpgrp--pidns-translation.c
--- 5.5-3/tests-mx32/getpgrp--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getpgrp--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "getpgrp.c"
diff -pruN 5.5-3/tests-mx32/getpgrp--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/getpgrp--pidns-translation.gen.test
--- 5.5-3/tests-mx32/getpgrp--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getpgrp--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getpgrp--pidns-translation test_pidns -e trace=getpgrp -a10); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -e trace=getpgrp -a10
diff -pruN 5.5-3/tests-mx32/getpid.c 5.9-0ubuntu2/tests-mx32/getpid.c
--- 5.5-3/tests-mx32/getpid.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getpid.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -7,6 +7,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #if defined __NR_getpid && (!defined __NR_getxpid || __NR_getxpid != __NR_getpid)
 
@@ -16,7 +17,12 @@
 int
 main(void)
 {
-	printf("getpid() = %ld\n", syscall(__NR_getpid));
+	PIDNS_TEST_INIT;
+
+	pidns_print_leader();
+	printf("getpid() = %d%s\n", (int) syscall(__NR_getpid),
+		pidns_pid2str(PT_TGID));
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/getpid--pidns-translation.c 5.9-0ubuntu2/tests-mx32/getpid--pidns-translation.c
--- 5.5-3/tests-mx32/getpid--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getpid--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "getpid.c"
diff -pruN 5.5-3/tests-mx32/getpid--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/getpid--pidns-translation.gen.test
--- 5.5-3/tests-mx32/getpid--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getpid--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getpid--pidns-translation test_pidns -e trace=getpid -a9); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -e trace=getpid -a9
diff -pruN 5.5-3/tests-mx32/get_process_reaper.c 5.9-0ubuntu2/tests-mx32/get_process_reaper.c
--- 5.5-3/tests-mx32/get_process_reaper.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/get_process_reaper.c	2020-04-03 22:58:26.000000000 +0000
@@ -0,0 +1,108 @@
+/*
+ * Print the process reaper id.
+ *
+ * Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include <stdio.h>
+#include <unistd.h>
+#include <sys/wait.h>
+
+/* PARENT - CHILD - GRANDCHILD */
+
+static int
+grandchild(int read_fd, int write_fd)
+{
+	/* wait for notification from PARENT about CHILD completion */
+	pid_t pid;
+	if (read(read_fd, &pid, sizeof(pid)) != 0)
+		perror_msg_and_fail("read");
+
+	/* write ppid to PARENT */
+	pid = getppid();
+	if (write(write_fd, &pid, sizeof(pid)) != sizeof(pid))
+		perror_msg_and_fail("write");
+
+	_exit(0);
+}
+
+static int
+child(int read_fd, int write_fd)
+{
+	pid_t pid = fork();
+	if (pid < 0)
+		perror_msg_and_fail("fork");
+
+	if (!pid)
+		return grandchild(read_fd, write_fd);
+	else
+		_exit(0);
+}
+
+static int
+parent(pid_t pid, int read_fd, int write_fd)
+{
+	/* wait for CHILD completion */
+	int status;
+	if (waitpid(pid, &status, 0) != pid)
+		perror_msg_and_fail("waitpid");
+	if (status != 0)
+		error_msg_and_fail("status %x", status);
+
+	/* notify GRANDCHILD about CHILD completion */
+	close(write_fd),
+	      write_fd = -1;
+
+	/* read ppid of GRANDCHILD */
+	if (read(read_fd, &pid, sizeof(pid)) != sizeof(pid))
+		perror_msg_and_fail("read");
+
+	printf("%d\n", pid);
+	return 0;
+}
+
+int
+main(void)
+{
+	int parent_grandchild_fds[2];
+#define parent_read_fd		parent_grandchild_fds[0]
+#define grandchild_write_fd	parent_grandchild_fds[1]
+
+	int grandchild_parent_fds[2];
+#define grandchild_read_fd	grandchild_parent_fds[0]
+#define parent_write_fd		grandchild_parent_fds[1]
+
+	if (pipe(parent_grandchild_fds) ||
+	    pipe(grandchild_parent_fds))
+		perror_msg_and_fail("pipe");
+
+	pid_t pid = fork();
+	if (pid < 0)
+		perror_msg_and_fail("fork");
+
+	if (!pid) {
+		/* CHILD */
+		close(parent_read_fd),
+		      parent_read_fd = -1;
+
+		close(parent_write_fd),
+		      parent_write_fd = -1;
+
+		return child(grandchild_read_fd,
+			     grandchild_write_fd);
+	} else {
+		/* PARENT */
+		close(grandchild_read_fd),
+		      grandchild_read_fd = -1;
+
+		close(grandchild_write_fd),
+		      grandchild_write_fd = -1;
+
+		return parent(pid, parent_read_fd,
+				   parent_write_fd);
+	}
+}
diff -pruN 5.5-3/tests-mx32/getrusage.c 5.9-0ubuntu2/tests-mx32/getrusage.c
--- 5.5-3/tests-mx32/getrusage.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getrusage.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2016 Fei Jie <feij.fnst@cn.fujitsu.com>
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -18,30 +18,41 @@
 # include <unistd.h>
 # include <errno.h>
 
+# include "kernel_rusage.h"
 # include "xlat.h"
 # include "xlat/usagewho.h"
 
 int
-invoke_print(int who, const char *who_str, struct rusage *usage)
+invoke_print(int who, const char *who_str, kernel_rusage_t *usage)
 {
 	int rc = syscall(__NR_getrusage, who, usage);
 	int saved_errno = errno;
 	printf("getrusage(%s, {ru_utime={tv_sec=%lld, tv_usec=%llu}"
-	       ", ru_stime={tv_sec=%lld, tv_usec=%llu}, ru_maxrss=%lu"
-	       ", ru_ixrss=%lu, ru_idrss=%lu, ru_isrss=%lu, ru_minflt=%lu"
-	       ", ru_majflt=%lu, ru_nswap=%lu, ru_inblock=%lu"
-	       ", ru_oublock=%lu, ru_msgsnd=%lu, ru_msgrcv=%lu"
-	       ", ru_nsignals=%lu, ru_nvcsw=%lu, ru_nivcsw=%lu}) = %s\n",
+	       ", ru_stime={tv_sec=%lld, tv_usec=%llu}, ru_maxrss=%llu"
+	       ", ru_ixrss=%llu, ru_idrss=%llu, ru_isrss=%llu, ru_minflt=%llu"
+	       ", ru_majflt=%llu, ru_nswap=%llu, ru_inblock=%llu"
+	       ", ru_oublock=%llu, ru_msgsnd=%llu, ru_msgrcv=%llu"
+	       ", ru_nsignals=%llu, ru_nvcsw=%llu, ru_nivcsw=%llu}) = %s\n",
 	       who_str,
 	       (long long) usage->ru_utime.tv_sec,
 	       zero_extend_signed_to_ull(usage->ru_utime.tv_usec),
 	       (long long) usage->ru_stime.tv_sec,
 	       zero_extend_signed_to_ull(usage->ru_stime.tv_usec),
-	       usage->ru_maxrss, usage->ru_ixrss, usage->ru_idrss,
-	       usage->ru_isrss, usage->ru_minflt, usage->ru_majflt,
-	       usage->ru_nswap, usage->ru_inblock, usage->ru_oublock,
-	       usage->ru_msgsnd, usage->ru_msgrcv, usage->ru_nsignals,
-	       usage->ru_nvcsw, usage->ru_nivcsw, sprintrc(rc));
+	       zero_extend_signed_to_ull(usage->ru_maxrss),
+	       zero_extend_signed_to_ull(usage->ru_ixrss),
+	       zero_extend_signed_to_ull(usage->ru_idrss),
+	       zero_extend_signed_to_ull(usage->ru_isrss),
+	       zero_extend_signed_to_ull(usage->ru_minflt),
+	       zero_extend_signed_to_ull(usage->ru_majflt),
+	       zero_extend_signed_to_ull(usage->ru_nswap),
+	       zero_extend_signed_to_ull(usage->ru_inblock),
+	       zero_extend_signed_to_ull(usage->ru_oublock),
+	       zero_extend_signed_to_ull(usage->ru_msgsnd),
+	       zero_extend_signed_to_ull(usage->ru_msgrcv),
+	       zero_extend_signed_to_ull(usage->ru_nsignals),
+	       zero_extend_signed_to_ull(usage->ru_nvcsw),
+	       zero_extend_signed_to_ull(usage->ru_nivcsw),
+	       sprintrc(rc));
 	errno = saved_errno;
 	return rc;
 }
@@ -49,7 +60,7 @@ invoke_print(int who, const char *who_st
 int
 main(void)
 {
-	TAIL_ALLOC_OBJECT_CONST_PTR(struct rusage, usage);
+	TAIL_ALLOC_OBJECT_CONST_PTR(kernel_rusage_t, usage);
 	if (invoke_print(ARG_STR(RUSAGE_SELF), usage)) {
 		perror_msg_and_fail("RUSAGE_SELF");
 	}
diff -pruN 5.5-3/tests-mx32/getsid.c 5.9-0ubuntu2/tests-mx32/getsid.c
--- 5.5-3/tests-mx32/getsid.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getsid.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,20 +1,27 @@
 /*
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include "pidns.h"
+
 #include <stdio.h>
 #include <unistd.h>
 
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	pid_t pid = getpid();
-	printf("getsid(%d) = %d\n", pid, getsid(pid));
+	pidns_print_leader();
+	printf("getsid(%d%s) = %d%s\n", pid, pidns_pid2str(PT_TGID),
+		getsid(pid), pidns_pid2str(PT_SID));
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/getsid--pidns-translation.c 5.9-0ubuntu2/tests-mx32/getsid--pidns-translation.c
--- 5.5-3/tests-mx32/getsid--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getsid--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "getsid.c"
diff -pruN 5.5-3/tests-mx32/getsid--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/getsid--pidns-translation.gen.test
--- 5.5-3/tests-mx32/getsid--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getsid--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getsid--pidns-translation test_pidns -e trace=getsid -a10); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -e trace=getsid -a10
diff -pruN 5.5-3/tests-mx32/gettid.c 5.9-0ubuntu2/tests-mx32/gettid.c
--- 5.5-3/tests-mx32/gettid.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/gettid.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -9,11 +9,17 @@
 #include <stdio.h>
 #include <unistd.h>
 #include "scno.h"
+#include "pidns.h"
 
 int
 main(void)
 {
-	printf("gettid() = %ld\n", syscall(__NR_gettid));
+	PIDNS_TEST_INIT;
+
+	pidns_print_leader();
+	printf("gettid() = %d%s\n", (int) syscall(__NR_gettid),
+		pidns_pid2str(PT_TID));
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/gettid--pidns-translation.c 5.9-0ubuntu2/tests-mx32/gettid--pidns-translation.c
--- 5.5-3/tests-mx32/gettid--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/gettid--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "gettid.c"
diff -pruN 5.5-3/tests-mx32/gettid--pidns-translation.test 5.9-0ubuntu2/tests-mx32/gettid--pidns-translation.test
--- 5.5-3/tests-mx32/gettid--pidns-translation.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/gettid--pidns-translation.test	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,18 @@
+#!/bin/sh
+#
+# Check pidns translation of gettid's return value.
+#
+# Copyright (c) 2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: LGPL-2.1-or-later
+
+. "${srcdir=.}/init.sh"
+
+run_prog > /dev/null
+run_strace -a9 --pidns-translation -f -e trace=gettid $args > "$EXP"
+parent_pid="$(tail -n 2 $LOG | head -n 1 | cut -d' ' -f1)"
+init_pid="$(tail -n 1 $LOG | cut -d' ' -f1)"
+# uniq: filter out extra gettid calls made by musl libc
+grep -E -v "^($parent_pid|$init_pid) |unfinished|resumed" "$LOG" | uniq > "$OUT"
+match_diff "$OUT" "$EXP"
diff -pruN 5.5-3/tests-mx32/getuid.test 5.9-0ubuntu2/tests-mx32/getuid.test
--- 5.5-3/tests-mx32/getuid.test	2020-01-05 21:09:51.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getuid.test	2020-03-31 22:57:10.000000000 +0000
@@ -9,14 +9,25 @@
 
 . "${srcdir=.}/init.sh"
 
+check_prog grep
 check_prog uniq
+
 if [ "${NAME%-creds}" = "$NAME" ]; then
 	syscall="$NAME"
 else
 	NAME="${NAME%-creds}"
 	syscall='%creds'
 fi
+
 run_prog > /dev/null
 run_strace -qq -a9 -e"$syscall" $args > "$EXP"
-uniq < "$LOG" > "$OUT"
+
+case "$STRACE_ARCH:$syscall" in
+	mips:%creds)
+		grep -Fxv 'prctl(PR_GET_FP_MODE) = 0' < "$LOG" | uniq > "$OUT"
+		;;
+	*)	uniq < "$LOG" > "$OUT"
+		;;
+esac
+
 match_diff "$OUT" "$EXP"
diff -pruN 5.5-3/tests-mx32/getxgid.c 5.9-0ubuntu2/tests-mx32/getxgid.c
--- 5.5-3/tests-mx32/getxgid.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getxgid.c	2020-04-03 22:58:26.000000000 +0000
@@ -0,0 +1,31 @@
+/*
+ * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2016-2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+
+#ifdef __NR_getxgid
+
+# include <stdio.h>
+# include <unistd.h>
+
+int
+main(void)
+{
+	long id = syscall(__NR_getxgid);
+	printf("getxgid() = %ld (egid %ld)\n", id, id);
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_getxgid")
+
+#endif
diff -pruN 5.5-3/tests-mx32/getxgid.gen.test 5.9-0ubuntu2/tests-mx32/getxgid.gen.test
--- 5.5-3/tests-mx32/getxgid.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getxgid.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getxgid -a10 ); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a10 
diff -pruN 5.5-3/tests-mx32/getxpid.c 5.9-0ubuntu2/tests-mx32/getxpid.c
--- 5.5-3/tests-mx32/getxpid.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getxpid.c	2020-04-03 22:58:26.000000000 +0000
@@ -0,0 +1,34 @@
+/*
+ * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2016-2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+
+#ifdef __NR_getxpid
+
+# include <stdio.h>
+# include <unistd.h>
+
+int
+main(void)
+{
+	long id = syscall(__NR_getxpid);
+	pid_t ppid = getppid();
+
+	printf("getxpid() = %ld (ppid %ld)\n", id, (long) ppid);
+	printf("getxpid() = %ld (ppid %ld)\n", id, (long) ppid);
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_getxpid")
+
+#endif
diff -pruN 5.5-3/tests-mx32/getxpid.gen.test 5.9-0ubuntu2/tests-mx32/getxpid.gen.test
--- 5.5-3/tests-mx32/getxpid.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getxpid.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getxpid -a10 ); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a10 
diff -pruN 5.5-3/tests-mx32/getxuid.c 5.9-0ubuntu2/tests-mx32/getxuid.c
--- 5.5-3/tests-mx32/getxuid.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getxuid.c	2020-04-03 22:58:26.000000000 +0000
@@ -0,0 +1,31 @@
+/*
+ * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2016-2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+
+#ifdef __NR_getxuid
+
+# include <stdio.h>
+# include <unistd.h>
+
+int
+main(void)
+{
+	long id = syscall(__NR_getxuid);
+	printf("getxuid() = %ld (euid %ld)\n", id, id);
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_getxuid")
+
+#endif
diff -pruN 5.5-3/tests-mx32/getxuid.gen.test 5.9-0ubuntu2/tests-mx32/getxuid.gen.test
--- 5.5-3/tests-mx32/getxuid.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getxuid.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getxuid -a10 ); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a10 
diff -pruN 5.5-3/tests-mx32/getxxid.c 5.9-0ubuntu2/tests-mx32/getxxid.c
--- 5.5-3/tests-mx32/getxxid.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getxxid.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,42 +0,0 @@
-/*
- * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
- * All rights reserved.
- *
- * SPDX-License-Identifier: GPL-2.0-or-later
- */
-
-#include "tests.h"
-#include "scno.h"
-
-#if defined __NR_getxpid && defined __NR_getxuid && defined __NR_getxgid
-
-# include <stdio.h>
-# include <unistd.h>
-
-int
-main(void)
-{
-	long id;
-	pid_t ppid;
-
-	id = syscall(__NR_getxpid);
-	ppid = getppid();
-	printf("getxpid() = %ld (ppid %ld)\n", id, (long) ppid);
-	printf("getxpid() = %ld (ppid %ld)\n", id, (long) ppid);
-
-	id = syscall(__NR_getxuid);
-	printf("getxuid() = %ld (euid %ld)\n", id, id);
-
-	id = syscall(__NR_getxgid);
-	printf("getxgid() = %ld (egid %ld)\n", id, id);
-
-	puts("+++ exited with 0 +++");
-	return 0;
-}
-
-#else
-
-SKIP_MAIN_UNDEFINED("__NR_getxpid && __NR_getxuid && __NR_getxgid")
-
-#endif
diff -pruN 5.5-3/tests-mx32/getxxid.gen.test 5.9-0ubuntu2/tests-mx32/getxxid.gen.test
--- 5.5-3/tests-mx32/getxxid.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/getxxid.gen.test	1970-01-01 00:00:00.000000000 +0000
@@ -1,4 +0,0 @@
-#!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (getxxid -a10 -e trace=getxpid,getxuid,getxgid); do not edit.
-. "${srcdir=.}/init.sh"
-run_strace_match_diff -a10 -e trace=getxpid,getxuid,getxgid
diff -pruN 5.5-3/tests-mx32/init.sh 5.9-0ubuntu2/tests-mx32/init.sh
--- 5.5-3/tests-mx32/init.sh	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/init.sh	2020-08-25 14:29:30.000000000 +0000
@@ -189,7 +189,7 @@ match_diff()
 # dump both files and fail with ERROR_MESSAGE.
 match_grep()
 {
-	local output patterns error pattern cnt failed=
+	local output patterns error pattern cnt failed= rc negated
 	if [ $# -eq 0 ]; then
 		output="$LOG"
 	else
@@ -211,7 +211,15 @@ match_grep()
 
 	cnt=1
 	while read -r pattern; do
-		LC_ALL=C grep -E -x -e "$pattern" < "$output" > /dev/null || {
+		negated=0
+		[ "x${pattern#!}" = "x${pattern}" ] ||
+			negated=1
+
+		rc="$negated"
+		LC_ALL=C grep -E -x -e "${pattern#!}" < "$output" > /dev/null ||
+			rc="$((!negated))"
+
+		[ 0 = "$rc" ] || {
 			test -n "$failed" || {
 				echo 'Failed patterns of expected output:'
 				failed=1
@@ -219,7 +227,8 @@ match_grep()
 			printf '#%d: %s\n' "$cnt" "$pattern"
 		}
 		cnt=$(($cnt + 1))
-	done < "$patterns"
+	done < "$patterns" ||
+		fail_ "Error reading patterns from \"$patterns\""
 	test -z "$failed" || {
 		echo 'Actual output:'
 		cat < "$output"
@@ -231,7 +240,7 @@ match_grep()
 run_strace_match_diff()
 {
 	args="$*"
-	[ -n "$args" -a -z "${args##*-e trace=*}" ] ||
+	[ -n "$args" -a \( -z "${args##*-e trace=*}" -o -z "${args##*--trace=*}" \) ] ||
 		set -- -e trace="$NAME" "$@"
 	run_prog > /dev/null
 	run_strace "$@" $args > "$EXP"
@@ -242,7 +251,7 @@ run_strace_match_diff()
 run_strace_match_grep()
 {
 	args="$*"
-	[ -n "$args" -a -z "${args##*-e trace=*}" ] ||
+	[ -n "$args" -a \( -z "${args##*-e trace=*}" -o -z "${args##*--trace=*}" \) ] ||
 		set -- -e trace="$NAME" "$@"
 	run_prog > /dev/null
 	run_strace "$@" $args > "$EXP"
@@ -281,7 +290,7 @@ require_min_nproc()
 	local min_nproc
 	min_nproc="$1"; shift
 
-	check_prog
+	check_prog nproc
 	local nproc
 	nproc="$(nproc)"
 
@@ -339,6 +348,13 @@ test_pure_prog_set()
 
 		try_run_prog "../$t" || continue
 		run_strace $prog_args "$@" "../$t" > "$expfile"
+
+		case "$STRACE_ARCH:$MIPS_ABI:$NAME" in
+			mips:o32:*creds)
+				sed -i '/^prctl(PR_GET_FP_MODE)  *= 0$/d' "$LOG"
+				;;
+		esac
+
 		match_diff "$LOG" "$expfile"
 	} < /dev/null; done
 }
@@ -371,6 +387,36 @@ test_prog_set()
 	test_pure_prog_set "$@" < "$srcdir/$NAME.in"
 }
 
+test_pidns_run_strace()
+{
+	local parent_pid init_pid
+
+	check_prog tail
+	check_prog cut
+	check_prog grep
+
+	run_prog > /dev/null
+	run_strace --pidns-translation -f $@ $args > "$EXP"
+
+	# filter out logs made by the parent or init process of the pidns test
+	parent_pid="$(tail -n 2 $LOG | head -n 1 | cut -d' ' -f1)"
+	init_pid="$(tail -n 1 $LOG | cut -d' ' -f1)"
+	grep -E -v "^($parent_pid|$init_pid) " "$LOG" > "$OUT"
+	match_diff "$OUT" "$EXP"
+}
+
+test_pidns()
+{
+	check_prog unshare
+	unshare -Urpf true || framework_skip_ "unshare -Urpf true failed"
+
+	test_pidns_run_strace "$@"
+
+	# test PID translation when /proc is mounted from an other namespace
+	STRACE="unshare -Urpf $STRACE"
+	test_pidns_run_strace "$@"
+}
+
 check_prog cat
 check_prog rm
 
@@ -412,7 +458,7 @@ fi
 : "${STRACE_EXE:=$STRACE}"
 export STRACE_EXE
 
-: "${TIMEOUT_DURATION:=600}"
+: "${TIMEOUT_DURATION:=1500}"
 : "${SLEEP_A_BIT:=sleep 1}"
 
 [ -z "${VERBOSE-}" ] ||
diff -pruN 5.5-3/tests-mx32/inject-nf.c 5.9-0ubuntu2/tests-mx32/inject-nf.c
--- 5.5-3/tests-mx32/inject-nf.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/inject-nf.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check decoding of return values injected into a syscall that "never fails".
  *
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -16,28 +16,26 @@
 
 #include "raw_syscall.h"
 
-#ifdef __alpha__
-/* alpha has no getpid */
-# define SC_NR __NR_getpgrp
-# define SC_NAME "getpgrp"
-# define getpid getpgrp
+#ifdef __NR_geteuid32
+# define SC_NR __NR_geteuid32
+# define SC_NAME "geteuid32"
 #else
-# define SC_NR __NR_getpid
-# define SC_NAME "getpid"
+# define SC_NR __NR_geteuid
+# define SC_NAME "geteuid"
 #endif
 
 #ifdef raw_syscall_0
 # define INVOKE_SC(err) raw_syscall_0(SC_NR, &err)
 #else
-/* No raw_syscall_0, let's use getpid() and hope for the best.  */
-# define INVOKE_SC(err) getpid()
+/* No raw_syscall_0, let's use geteuid() and hope for the best. */
+# define INVOKE_SC(err) geteuid()
 #endif
 
 /*
  * This prototype is intentionally different
  * from the prototype provided by <unistd.h>.
  */
-extern kernel_ulong_t getpid(void);
+extern kernel_ulong_t geteuid(void);
 
 int
 main(int ac, char **av)
@@ -45,7 +43,7 @@ main(int ac, char **av)
 	assert(ac == 1 || ac == 2);
 
 	kernel_ulong_t expected =
-		(ac == 1) ? getpid() : strtoull(av[1], NULL, 0);
+		(ac == 1) ? geteuid() : strtoull(av[1], NULL, 0);
 	kernel_ulong_t err = 0;
 	kernel_ulong_t rc = INVOKE_SC(err);
 
diff -pruN 5.5-3/tests-mx32/inject-nf.test 5.9-0ubuntu2/tests-mx32/inject-nf.test
--- 5.5-3/tests-mx32/inject-nf.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/inject-nf.test	2020-08-03 08:00:00.000000000 +0000
@@ -2,21 +2,14 @@
 #
 # Check decoding of return values injected into a syscall that "never fails".
 #
-# Copyright (c) 2018 The strace developers.
+# Copyright (c) 2018-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/scno_tampering.sh"
 
-case "$STRACE_ARCH" in
-alpha)
-	SYSCALL=getpgrp
-	;;
-*)
-	SYSCALL=getpid
-	;;
-esac
+SYSCALL='/^geteuid(32)?$'
 
 run_prog
 prog="$args"
diff -pruN 5.5-3/tests-mx32/ioctl_block.c 5.9-0ubuntu2/tests-mx32/ioctl_block.c
--- 5.5-3/tests-mx32/ioctl_block.c	2019-07-24 17:12:18.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_block.c	2020-08-25 14:29:30.000000000 +0000
@@ -2,14 +2,16 @@
  * This file is part of ioctl_block strace test.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include "pidns.h"
 #include <errno.h>
+#include <unistd.h>
 #include <inttypes.h>
 #include <stdio.h>
 #include <string.h>
@@ -41,12 +43,15 @@ static struct xlat_data block_argless[]
 #define TEST_NULL_ARG(cmd)						\
 	do {								\
 		ioctl(-1, cmd, 0);					\
+		pidns_print_leader();					\
 		printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n", #cmd);	\
 	} while (0)
 
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	TEST_NULL_ARG(BLKBSZGET);
 	TEST_NULL_ARG(BLKBSZSET);
 	TEST_NULL_ARG(BLKFRAGET);
@@ -91,18 +96,22 @@ main(void)
 #endif
 
 	ioctl(-1, BLKRASET, lmagic);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKRASET, %lu) = -1 EBADF (%m)\n", lmagic);
 
 	ioctl(-1, BLKFRASET, lmagic);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKFRASET, %lu) = -1 EBADF (%m)\n", lmagic);
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(int, val_int);
 	*val_int = magic;
 
 	ioctl(-1, BLKROSET, val_int);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKROSET, [%d]) = -1 EBADF (%m)\n", *val_int);
 
 	ioctl(-1, BLKBSZSET, val_int);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKBSZSET, [%d]) = -1 EBADF (%m)\n", *val_int);
 
 	uint64_t *pair_int64 = tail_alloc(sizeof(*pair_int64) * 2);
@@ -111,18 +120,21 @@ main(void)
 
 #ifdef BLKDISCARD
 	ioctl(-1, BLKDISCARD, pair_int64);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKDISCARD, [%" PRIu64 ", %" PRIu64 "])"
 	       " = -1 EBADF (%m)\n", pair_int64[0], pair_int64[1]);
 #endif
 
 #ifdef BLKSECDISCARD
 	ioctl(-1, BLKSECDISCARD, pair_int64);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKSECDISCARD, [%" PRIu64 ", %" PRIu64 "])"
 	       " = -1 EBADF (%m)\n", pair_int64[0], pair_int64[1]);
 #endif
 
 #ifdef BLKZEROOUT
 	ioctl(-1, BLKZEROOUT, pair_int64);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKZEROOUT, [%" PRIu64 ", %" PRIu64 "])"
 	       " = -1 EBADF (%m)\n", pair_int64[0], pair_int64[1]);
 #endif
@@ -134,6 +146,7 @@ main(void)
 	blkpg->data = (void *) (unsigned long) 0xcafef00dfffffeedULL;
 
 	ioctl(-1, BLKPG, blkpg);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKPG, {op=%s, flags=%d, datalen=%d"
 	       ", data=%#lx}) = -1 EBADF (%m)\n",
 	       "BLKPG_RESIZE_PARTITION", blkpg->flags, blkpg->datalen,
@@ -149,6 +162,7 @@ main(void)
 	blkpg->data = bp;
 
 	ioctl(-1, BLKPG, blkpg);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKPG, {op=%s, flags=%d, datalen=%d"
 	       ", data={start=%lld, length=%lld, pno=%d"
 	       ", devname=\"%.*s\"..., volname=\"%.*s\"...}})"
@@ -162,25 +176,31 @@ main(void)
 #if defined BLKTRACESETUP && defined HAVE_STRUCT_BLK_USER_TRACE_SETUP
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct blk_user_trace_setup, buts);
 	fill_memory(buts, sizeof(*buts));
+	buts->pid = getpid();
 
 	ioctl(-1, BLKTRACESETUP, buts);
+	pidns_print_leader();
 	printf("ioctl(-1, BLKTRACESETUP, {act_mask=%hu, buf_size=%u, buf_nr=%u"
-	       ", start_lba=%" PRI__u64 ", end_lba=%" PRI__u64 ", pid=%u})"
+	       ", start_lba=%" PRI__u64 ", end_lba=%" PRI__u64 ", pid=%d%s})"
 	       " = -1 EBADF (%m)\n",
 	       buts->act_mask, buts->buf_size, buts->buf_nr,
-	       buts->start_lba, buts->end_lba, buts->pid);
+	       buts->start_lba, buts->end_lba, buts->pid,
+	       pidns_pid2str(PT_TGID));
 #endif
 
 	unsigned int i;
 	for (i = 0; i < ARRAY_SIZE(block_argless); ++i) {
 		ioctl(-1, (unsigned long) block_argless[i].val, lmagic);
+		pidns_print_leader();
 		printf("ioctl(-1, %s) = -1 EBADF (%m)\n", block_argless[i].str);
 	}
 
 	ioctl(-1, _IOC(_IOC_READ, 0x12, 0xfe, 0xff), lmagic);
+	pidns_print_leader();
 	printf("ioctl(-1, %s, %#lx) = -1 EBADF (%m)\n",
 	       "_IOC(_IOC_READ, 0x12, 0xfe, 0xff)", lmagic);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/ioctl_block--pidns-translation.c 5.9-0ubuntu2/tests-mx32/ioctl_block--pidns-translation.c
--- 5.5-3/tests-mx32/ioctl_block--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_block--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "ioctl_block.c"
diff -pruN 5.5-3/tests-mx32/ioctl_block--pidns-translation.test 5.9-0ubuntu2/tests-mx32/ioctl_block--pidns-translation.test
--- 5.5-3/tests-mx32/ioctl_block--pidns-translation.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_block--pidns-translation.test	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,22 @@
+#!/bin/sh
+#
+# Check pidns translation of ioctl(BLK*) syscall decoding.
+#
+# Copyright (c) 2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: LGPL-2.1-or-later
+
+. "${srcdir=.}/init.sh"
+
+check_prog head
+check_prog tail
+check_prog cut
+check_prog grep
+
+run_prog > /dev/null
+run_strace --pidns-translation -f -a16 -e trace=ioctl $@ $args > "$EXP"
+parent_pid="$(tail -n 2 $LOG | head -n 1 | cut -d' ' -f1)"
+init_pid="$(tail -n 1 $LOG | cut -d' ' -f1)"
+grep -E -v "^($parent_pid|$init_pid) |ioctl\([0123][,<]" "$LOG" > "$OUT"
+match_diff "$OUT" "$EXP"
diff -pruN 5.5-3/tests-mx32/ioctl.c 5.9-0ubuntu2/tests-mx32/ioctl.c
--- 5.5-3/tests-mx32/ioctl.c	2018-12-30 15:35:21.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -14,6 +14,8 @@
 #include <termios.h>
 #include <sys/ioctl.h>
 
+#include <linux/types.h>
+
 #ifdef HAVE_LINUX_MMTIMER_H
 # include <linux/mmtimer.h>
 #endif
diff -pruN 5.5-3/tests-mx32/ioctl_evdev.c 5.9-0ubuntu2/tests-mx32/ioctl_evdev.c
--- 5.5-3/tests-mx32/ioctl_evdev.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_evdev.c	2020-08-03 08:00:00.000000000 +0000
@@ -2,7 +2,7 @@
  * This file is part of ioctl_evdev strace test.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -50,7 +50,7 @@ static void
 print_ffe_common(const struct ff_effect *const ffe, const char *const type_str)
 {
 	printf("ioctl(-1, %s", XLAT_STR(EVIOCSFF));
-	printf(", {type=%s, id=%" PRIu16
+	printf(", {type=%s, id=%" PRId16
 	       ", direction=%" PRIu16 ", ",
 	       sprintxlat(type_str, ffe->type, NULL),
 	       ffe->id, ffe->direction);
@@ -223,7 +223,7 @@ main(void)
 	for (i = 0; i < ARRAY_SIZE(ike->scancode); ++i) {
 		if (i > 0)
 			printf(", ");
-		printf("%" PRIx8, ike->scancode[i]);
+		printf("%#" PRIx8, ike->scancode[i]);
 	}
 	printf("]");
 #  else
diff -pruN 5.5-3/tests-mx32/ioctl_evdev-success.c 5.9-0ubuntu2/tests-mx32/ioctl_evdev-success.c
--- 5.5-3/tests-mx32/ioctl_evdev-success.c	2019-10-22 17:44:08.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_evdev-success.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -99,10 +99,10 @@ print_input_id(long rc, const void *ptr,
 		printf("%p", id);
 		return;
 	}
-	printf("{ID_BUS=%" PRIu16
-	       ", ID_VENDOR=%" PRIu16
-	       ", ID_PRODUCT=%" PRIu16
-	       ", ID_VERSION=%" PRIu16 "}",
+	printf("{bustype=%" PRIu16
+	       ", vendor=%" PRIu16
+	       ", product=%" PRIu16
+	       ", version=%" PRIu16 "}",
 	       id->bustype, id->vendor, id->product, id->version);
 }
 
diff -pruN 5.5-3/tests-mx32/ioctl_hdio.c 5.9-0ubuntu2/tests-mx32/ioctl_hdio.c
--- 5.5-3/tests-mx32/ioctl_hdio.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,227 @@
+/*
+ * Check HDIO_* ioctl decoding.
+ *
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+
+#include <errno.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <linux/hdreg.h>
+#include <sys/ioctl.h>
+
+static const char *errstr;
+
+static long
+do_ioctl(kernel_ulong_t cmd, kernel_ulong_t arg)
+{
+	long rc = ioctl(-1, cmd, arg);
+
+	errstr = sprintrc(rc);
+
+#ifdef INJECT_RETVAL
+	if (rc != INJECT_RETVAL)
+		error_msg_and_fail("Got a return value of %ld != %ld",
+				   rc, (long) INJECT_RETVAL);
+
+	static char inj_errstr[4096];
+
+	snprintf(inj_errstr, sizeof(inj_errstr), "%s (INJECTED)", errstr);
+	errstr = inj_errstr;
+#endif
+
+	return rc;
+}
+
+static inline long
+do_ioctl_ptr(kernel_ulong_t cmd, const void *arg)
+{
+	return do_ioctl(cmd, (uintptr_t) arg);
+}
+
+int
+main(int argc, char *argv[])
+{
+#ifdef INJECT_RETVAL
+	unsigned long num_skip;
+	bool locked = false;
+
+	if (argc < 2)
+		error_msg_and_fail("Usage: %s NUM_SKIP", argv[0]);
+
+	num_skip = strtoul(argv[1], NULL, 0);
+
+	for (size_t i = 0; i < num_skip; i++) {
+		long ret = ioctl(-1, HDIO_GET_UNMASKINTR, 0);
+
+		printf("ioctl(-1, %s, 0) = %s%s\n",
+		       XLAT_STR(HDIO_GET_UNMASKINTR), sprintrc(ret),
+		       ret == INJECT_RETVAL ? " (INJECTED)" : "");
+
+		if (ret != INJECT_RETVAL)
+			continue;
+
+		locked = true;
+		break;
+	}
+
+	if (!locked)
+		error_msg_and_fail("Hasn't locked on ioctl(-1"
+				   ", HDIO_GET_UNMASKINTR, 0) returning %d",
+				   INJECT_RETVAL);
+#endif
+
+	long rc;
+
+	/* Decoding is not supported */
+	static const struct {
+		uint32_t cmd;
+		const char *str;
+	} unsupp_cmds[] = {
+		{ ARG_STR(HDIO_GET_UNMASKINTR) },
+		{ ARG_STR(HDIO_GET_MULTCOUNT) },
+		{ ARG_STR(HDIO_GET_QDMA) },
+		{ ARG_STR(HDIO_SET_XFER) },
+		{ ARG_STR(HDIO_OBSOLETE_IDENTITY) },
+		{ ARG_STR(HDIO_GET_KEEPSETTINGS) },
+		{ ARG_STR(HDIO_GET_32BIT) },
+		{ ARG_STR(HDIO_GET_NOWERR) },
+		{ ARG_STR(HDIO_GET_DMA) },
+		{ ARG_STR(HDIO_GET_NICE) },
+		{ ARG_STR(HDIO_GET_IDENTITY) },
+		{ ARG_STR(HDIO_GET_WCACHE) },
+		{ ARG_STR(HDIO_GET_ACOUSTIC) },
+		{ ARG_STR(HDIO_GET_ADDRESS) },
+		{ ARG_STR(HDIO_GET_BUSSTATE) },
+		{ ARG_STR(HDIO_TRISTATE_HWIF) },
+		{ ARG_STR(HDIO_DRIVE_RESET) },
+		{ ARG_STR(HDIO_DRIVE_TASKFILE) },
+		{ ARG_STR(HDIO_DRIVE_TASK) },
+		{ ARG_STR(HDIO_SET_MULTCOUNT) },
+		{ ARG_STR(HDIO_SET_UNMASKINTR) },
+		{ ARG_STR(HDIO_SET_KEEPSETTINGS) },
+		{ ARG_STR(HDIO_SET_32BIT) },
+		{ ARG_STR(HDIO_SET_NOWERR) },
+		{ ARG_STR(HDIO_SET_DMA) },
+		{ ARG_STR(HDIO_SET_PIO_MODE) },
+		{ ARG_STR(HDIO_SCAN_HWIF) },
+		{ ARG_STR(HDIO_UNREGISTER_HWIF) },
+		{ ARG_STR(HDIO_SET_NICE) },
+		{ ARG_STR(HDIO_SET_WCACHE) },
+		{ ARG_STR(HDIO_SET_ACOUSTIC) },
+		{ ARG_STR(HDIO_SET_BUSSTATE) },
+		{ ARG_STR(HDIO_SET_QDMA) },
+		{ ARG_STR(HDIO_SET_ADDRESS) },
+	};
+
+	for (size_t i = 0; i < ARRAY_SIZE(unsupp_cmds); i++) {
+		do_ioctl(unsupp_cmds[i].cmd, 0);
+		printf("ioctl(-1, " XLAT_FMT ", 0) = %s\n",
+		       XLAT_SEL(unsupp_cmds[i].cmd, unsupp_cmds[i].str),
+		       errstr);
+
+		do_ioctl(unsupp_cmds[i].cmd,
+			 (unsigned long) 0xbadc0deddeadc0deULL);
+		printf("ioctl(-1, " XLAT_FMT ", %#lx) = %s\n",
+		       XLAT_SEL(unsupp_cmds[i].cmd, unsupp_cmds[i].str),
+		       (unsigned long) 0xbadc0deddeadc0deULL, errstr);
+	}
+
+
+	/* HDIO_GETGEO */
+	do_ioctl(HDIO_GETGEO, 0);
+	printf("ioctl(-1, %s, NULL) = %s\n",
+	       XLAT_STR(HDIO_GETGEO), errstr);
+
+	TAIL_ALLOC_OBJECT_CONST_PTR(struct hd_geometry, p_hd_geom);
+
+	p_hd_geom->heads = 0xca;
+	p_hd_geom->sectors = 0xfe;
+	p_hd_geom->cylinders = 0xbabe;
+	p_hd_geom->start = (unsigned long) 0xbadc0deddeadfaceULL;
+
+	do_ioctl_ptr(HDIO_GETGEO, (char *) p_hd_geom + 1);
+	printf("ioctl(-1, %s, %p) = %s\n",
+	       XLAT_STR(HDIO_GETGEO), (char *) p_hd_geom + 1, errstr);
+
+	rc = do_ioctl_ptr(HDIO_GETGEO, p_hd_geom);
+	printf("ioctl(-1, %s, ", XLAT_STR(HDIO_GETGEO));
+	if (rc >= 0) {
+		printf("{heads=202, sectors=254, cylinders=47806, start=%lu}",
+		       (unsigned long) 0xbadc0deddeadfaceULL);
+	} else {
+		printf("%p", p_hd_geom);
+	}
+	printf(") = %s\n", errstr);
+
+	/* HDIO_DRIVE_CMD */
+	do_ioctl(HDIO_DRIVE_CMD, 0);
+	printf("ioctl(-1, %s, NULL) = %s\n",
+	       XLAT_STR(HDIO_DRIVE_CMD), errstr);
+
+	TAIL_ALLOC_OBJECT_CONST_PTR(struct hd_drive_cmd_hdr, p_hd_drive_cmd);
+	struct hd_drive_cmd_hdr *p_hd_drive_cmd2 =
+		tail_alloc(sizeof(*p_hd_drive_cmd2) + 16);
+	struct hd_drive_cmd_hdr *p_hd_drive_cmd3 =
+		tail_alloc(sizeof(*p_hd_drive_cmd3) + DEFAULT_STRLEN + 1);
+
+	fill_memory(p_hd_drive_cmd2, sizeof(*p_hd_drive_cmd2) + 16);
+	fill_memory(p_hd_drive_cmd3,
+		    sizeof(*p_hd_drive_cmd3) + DEFAULT_STRLEN + 1);
+
+	p_hd_drive_cmd->command = 0xca;
+	p_hd_drive_cmd->sector_number = 0xff;
+	p_hd_drive_cmd->feature = 0xee;
+	p_hd_drive_cmd->sector_count = 0;
+
+	do_ioctl_ptr(HDIO_DRIVE_CMD, (char *) p_hd_drive_cmd + 1);
+	printf("ioctl(-1, %s, %p) = %s\n",
+	       XLAT_STR(HDIO_DRIVE_CMD), (char *) p_hd_drive_cmd + 1, errstr);
+
+	for (size_t i = 0; i < 2; i++) {
+		p_hd_drive_cmd->sector_count = i;
+
+		rc = do_ioctl_ptr(HDIO_DRIVE_CMD, p_hd_drive_cmd);
+		printf("ioctl(-1, %s, {command=" XLAT_FMT ", sector_number=255"
+		       ", feature=238, sector_count=%zu",
+		       XLAT_STR(HDIO_DRIVE_CMD),
+		       XLAT_SEL(0xca, "ATA_CMD_WRITE"), i);
+		if (rc >= 0) {
+			printf("} => {/* status */ 0xca, /* error */ 255"
+			       ", /* nsector */ 238");
+			if (i)
+				printf(", %p", p_hd_drive_cmd + 1);
+		}
+		printf("}) = %s\n", errstr);
+	}
+
+	rc = do_ioctl_ptr(HDIO_DRIVE_CMD, p_hd_drive_cmd2);
+	printf("ioctl(-1, %s, {command=0x80" NRAW(" /* ATA_CMD_??? */")
+	       ", sector_number=129, feature=130, sector_count=131",
+	       XLAT_STR(HDIO_DRIVE_CMD));
+	if (rc >= 0) {
+		printf("} => {/* status */ 0x80, /* error */ 129"
+		       ", /* nsector */ 130, %p", p_hd_drive_cmd2 + 1);
+	}
+	printf("}) = %s\n", errstr);
+
+	rc = do_ioctl_ptr(HDIO_DRIVE_CMD, p_hd_drive_cmd3);
+	printf("ioctl(-1, %s, {command=0x80" NRAW(" /* ATA_CMD_??? */")
+	       ", sector_number=129, feature=130, sector_count=131",
+	       XLAT_STR(HDIO_DRIVE_CMD));
+	if (rc >= 0) {
+		printf("} => {/* status */ 0x80, /* error */ 129"
+		       ", /* nsector */ 130, ");
+		print_quoted_hex(p_hd_drive_cmd3 + 1, DEFAULT_STRLEN);
+		printf("...");
+	}
+	printf("}) = %s\n", errstr);
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
diff -pruN 5.5-3/tests-mx32/ioctl_hdio.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_hdio.gen.test
--- 5.5-3/tests-mx32/ioctl_hdio.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio +ioctl.test -a27); do not edit.
+set -- -a27
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-success.c 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success.c
--- 5.5-3/tests-mx32/ioctl_hdio-success.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define INJECT_RETVAL 42
+#include "ioctl_hdio.c"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-success.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success.gen.test
--- 5.5-3/tests-mx32/ioctl_hdio-success.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-success +ioctl-success.sh -a27); do not edit.
+set -- -a27
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-success-v.c 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-v.c
--- 5.5-3/tests-mx32/ioctl_hdio-success-v.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-v.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define VERBOSE 1
+#include "ioctl_hdio-success.c"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-success-v.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-v.gen.test
--- 5.5-3/tests-mx32/ioctl_hdio-success-v.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-v.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-success-v +ioctl-success.sh -a27 -v); do not edit.
+set -- -a27 -v
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-success-v-Xabbrev.c 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-v-Xabbrev.c
--- 5.5-3/tests-mx32/ioctl_hdio-success-v-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-v-Xabbrev.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "ioctl_hdio-success-v.c"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-success-v-Xabbrev.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-v-Xabbrev.gen.test
--- 5.5-3/tests-mx32/ioctl_hdio-success-v-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-v-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-success-v-Xabbrev +ioctl-success.sh -a27 -v -Xabbrev); do not edit.
+set -- -a27 -v -Xabbrev
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-success-v-Xraw.c 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-v-Xraw.c
--- 5.5-3/tests-mx32/ioctl_hdio-success-v-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-v-Xraw.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "ioctl_hdio-success-v.c"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-success-v-Xraw.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-v-Xraw.gen.test
--- 5.5-3/tests-mx32/ioctl_hdio-success-v-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-v-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-success-v-Xraw +ioctl-success.sh -a20 -v -Xraw); do not edit.
+set -- -a20 -v -Xraw
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-success-v-Xverbose.c 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-v-Xverbose.c
--- 5.5-3/tests-mx32/ioctl_hdio-success-v-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-v-Xverbose.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "ioctl_hdio-success-v.c"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-success-v-Xverbose.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-v-Xverbose.gen.test
--- 5.5-3/tests-mx32/ioctl_hdio-success-v-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-v-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-success-v-Xverbose +ioctl-success.sh -a39 -v -Xverbose); do not edit.
+set -- -a39 -v -Xverbose
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-success-Xabbrev.c 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-Xabbrev.c
--- 5.5-3/tests-mx32/ioctl_hdio-success-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-Xabbrev.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "ioctl_hdio-success.c"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-success-Xabbrev.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-Xabbrev.gen.test
--- 5.5-3/tests-mx32/ioctl_hdio-success-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-success-Xabbrev +ioctl-success.sh -a27 -Xabbrev); do not edit.
+set -- -a27 -Xabbrev
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-success-Xraw.c 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-Xraw.c
--- 5.5-3/tests-mx32/ioctl_hdio-success-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-Xraw.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "ioctl_hdio-success.c"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-success-Xraw.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-Xraw.gen.test
--- 5.5-3/tests-mx32/ioctl_hdio-success-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-success-Xraw +ioctl-success.sh -a20 -Xraw); do not edit.
+set -- -a20 -Xraw
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-success-Xverbose.c 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-Xverbose.c
--- 5.5-3/tests-mx32/ioctl_hdio-success-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-Xverbose.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "ioctl_hdio-success.c"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-success-Xverbose.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-Xverbose.gen.test
--- 5.5-3/tests-mx32/ioctl_hdio-success-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-success-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-success-Xverbose +ioctl-success.sh -a39 -Xverbose); do not edit.
+set -- -a39 -Xverbose
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-v.c 5.9-0ubuntu2/tests-mx32/ioctl_hdio-v.c
--- 5.5-3/tests-mx32/ioctl_hdio-v.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-v.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define VERBOSE 1
+#include "ioctl_hdio.c"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-v.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_hdio-v.gen.test
--- 5.5-3/tests-mx32/ioctl_hdio-v.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-v.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-v +ioctl.test -a27 -v); do not edit.
+set -- -a27 -v
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-v-Xabbrev.c 5.9-0ubuntu2/tests-mx32/ioctl_hdio-v-Xabbrev.c
--- 5.5-3/tests-mx32/ioctl_hdio-v-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-v-Xabbrev.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "ioctl_hdio-v.c"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-v-Xabbrev.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_hdio-v-Xabbrev.gen.test
--- 5.5-3/tests-mx32/ioctl_hdio-v-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-v-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-v-Xabbrev +ioctl.test -a27 -v -Xabbrev); do not edit.
+set -- -a27 -v -Xabbrev
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-v-Xraw.c 5.9-0ubuntu2/tests-mx32/ioctl_hdio-v-Xraw.c
--- 5.5-3/tests-mx32/ioctl_hdio-v-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-v-Xraw.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "ioctl_hdio-v.c"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-v-Xraw.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_hdio-v-Xraw.gen.test
--- 5.5-3/tests-mx32/ioctl_hdio-v-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-v-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-v-Xraw +ioctl.test -a20 -v -Xraw); do not edit.
+set -- -a20 -v -Xraw
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-v-Xverbose.c 5.9-0ubuntu2/tests-mx32/ioctl_hdio-v-Xverbose.c
--- 5.5-3/tests-mx32/ioctl_hdio-v-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-v-Xverbose.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "ioctl_hdio-v.c"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-v-Xverbose.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_hdio-v-Xverbose.gen.test
--- 5.5-3/tests-mx32/ioctl_hdio-v-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-v-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-v-Xverbose +ioctl.test -a39 -v -Xverbose); do not edit.
+set -- -a39 -v -Xverbose
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-Xabbrev.c 5.9-0ubuntu2/tests-mx32/ioctl_hdio-Xabbrev.c
--- 5.5-3/tests-mx32/ioctl_hdio-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-Xabbrev.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "ioctl_hdio.c"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-Xabbrev.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_hdio-Xabbrev.gen.test
--- 5.5-3/tests-mx32/ioctl_hdio-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-Xabbrev +ioctl.test -a27 -Xabbrev); do not edit.
+set -- -a27 -Xabbrev
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-Xraw.c 5.9-0ubuntu2/tests-mx32/ioctl_hdio-Xraw.c
--- 5.5-3/tests-mx32/ioctl_hdio-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-Xraw.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "ioctl_hdio.c"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-Xraw.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_hdio-Xraw.gen.test
--- 5.5-3/tests-mx32/ioctl_hdio-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-Xraw +ioctl.test -a20 -Xraw); do not edit.
+set -- -a20 -Xraw
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-Xverbose.c 5.9-0ubuntu2/tests-mx32/ioctl_hdio-Xverbose.c
--- 5.5-3/tests-mx32/ioctl_hdio-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-Xverbose.c	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "ioctl_hdio.c"
diff -pruN 5.5-3/tests-mx32/ioctl_hdio-Xverbose.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_hdio-Xverbose.gen.test
--- 5.5-3/tests-mx32/ioctl_hdio-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_hdio-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_hdio-Xverbose +ioctl.test -a39 -Xverbose); do not edit.
+set -- -a39 -Xverbose
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-mx32/ioctl_loop.c 5.9-0ubuntu2/tests-mx32/ioctl_loop.c
--- 5.5-3/tests-mx32/ioctl_loop.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_loop.c	2020-08-03 08:00:00.000000000 +0000
@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2016 JingPiao Chen <chenjingpiao@gmail.com>
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -22,6 +22,12 @@
 #include <linux/loop.h>
 #include "print_fields.h"
 
+#ifdef HAVE_STRUCT_LOOP_CONFIG
+typedef struct loop_config struct_loop_config;
+#else
+# include "types/loop.h"
+#endif
+
 #define XLAT_MACROS_ONLY
 #include "xlat/loop_cmds.h"
 #undef XLAT_MACROS_ONLY
@@ -155,6 +161,27 @@ print_loop_info64(struct loop_info64 * c
 #endif /* !ABBREV */
 }
 
+static void
+print_loop_config(struct_loop_config *config, bool print_reserved)
+{
+#if ABBREV
+	printf("%p", config);
+#else
+	printf("{fd=%d, block_size=%u, info=",
+	       (int) config->fd, config->block_size);
+	print_loop_info64(&config->info, false, "LO_CRYPT_NONE", NULL,
+			  "LO_FLAGS_READ_ONLY");
+	if (print_reserved) {
+		printf(", __reserved=");
+		for (size_t i = 0; i < ARRAY_SIZE(config->__reserved); ++i)
+			printf("%s%#llx", (i ? ", " : "["),
+			       (unsigned long long) config->__reserved[i]);
+		printf("]");
+	}
+	printf("}");
+#endif /* !ABBREV */
+}
+
 int
 main(void)
 {
@@ -167,6 +194,7 @@ main(void)
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct loop_info, info);
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct loop_info64, info64);
+	TAIL_ALLOC_OBJECT_CONST_PTR(struct_loop_config, config);
 
 	/* Unknown loop commands */
 	sys_ioctl(-1, unknown_loop_cmd, magic);
@@ -178,12 +206,12 @@ main(void)
 	       _IOC_SIZE((unsigned int) unknown_loop_cmd),
 	       (unsigned long) magic);
 
-	sys_ioctl(-1, LOOP_SET_BLOCK_SIZE + 1, magic);
+	sys_ioctl(-1, LOOP_CONFIGURE + 1, magic);
 	printf("ioctl(-1, _IOC(%s, 0x4c, %#x, %#x), %#lx) = "
 	       "-1 EBADF (%m)\n",
 	       _IOC_NONE ? "0" : "_IOC_NONE",
-	       _IOC_NR(LOOP_SET_BLOCK_SIZE + 1),
-	       _IOC_SIZE(LOOP_SET_BLOCK_SIZE + 1),
+	       _IOC_NR(LOOP_CONFIGURE + 1),
+	       _IOC_SIZE(LOOP_CONFIGURE + 1),
 	       (unsigned long) magic);
 
 	sys_ioctl(-1, LOOP_CTL_GET_FREE + 1, magic);
@@ -281,6 +309,32 @@ main(void)
 	ioctl(-1, LOOP_GET_STATUS64, (unsigned long) info64 | kernel_mask);
 	printf("ioctl(-1, LOOP_GET_STATUS64, %p) = -1 EBADF (%m)\n", info64);
 
+	/* LOOP_CONFIGURE */
+	ioctl(-1, LOOP_CONFIGURE, NULL);
+	printf("ioctl(-1, LOOP_CONFIGURE, NULL) = -1 EBADF (%m)\n");
+
+	fill_memory(config, sizeof(*config));
+	config->info.lo_flags = LO_FLAGS_READ_ONLY;
+	config->info.lo_encrypt_type = LO_CRYPT_NONE;
+	memset(config->info.lo_file_name, 'C', sizeof(config->info.lo_file_name));
+	memset(config->info.lo_crypt_name, 'D', sizeof(config->info.lo_crypt_name));
+	memset(config->info.lo_encrypt_key, 'E', sizeof(config->info.lo_encrypt_key));
+
+	ioctl(-1, LOOP_CONFIGURE, (void *) config + ALIGNOF(config));
+	printf("ioctl(-1, LOOP_CONFIGURE, %p) = -1 EBADF (%m)\n",
+	       (void *) config + ALIGNOF(config));
+
+	printf("ioctl(-1, LOOP_CONFIGURE, ");
+	print_loop_config(config, true);
+	ioctl(-1, LOOP_CONFIGURE, config);
+	printf(") = -1 EBADF (%m)\n");
+
+	memset(config->__reserved, 0, sizeof(config->__reserved));
+	printf("ioctl(-1, LOOP_CONFIGURE, ");
+	print_loop_config(config, false);
+	ioctl(-1, LOOP_CONFIGURE, config);
+	printf(") = -1 EBADF (%m)\n");
+
 	/* LOOP_CHANGE_FD */
 	sys_ioctl(-1, LOOP_CHANGE_FD, magic);
 	printf("ioctl(-1, LOOP_CHANGE_FD, %d) = -1 EBADF (%m)\n",
diff -pruN 5.5-3/tests-mx32/ioctl_nsfs.c 5.9-0ubuntu2/tests-mx32/ioctl_nsfs.c
--- 5.5-3/tests-mx32/ioctl_nsfs.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_nsfs.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of NS_* commands of ioctl syscall.
  *
  * Copyright (c) 2017 Nikolay Marchuk <marchuk.nikolay.a@gmail.com>
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
diff -pruN 5.5-3/tests-mx32/ioctl_perf-success.c 5.9-0ubuntu2/tests-mx32/ioctl_perf-success.c
--- 5.5-3/tests-mx32/ioctl_perf-success.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_perf-success.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check decoding of successful PERF_EVENT_IOC_{ID,QUERY_BPF} ioctls.
  *
- * Copyright (c) 2018 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -9,29 +9,31 @@
 
 #include "tests.h"
 
-#ifdef HAVE_LINUX_PERF_EVENT_H
 
-# include <assert.h>
-# include <inttypes.h>
-# include <stdio.h>
-# include <stdlib.h>
-# include <string.h>
-# include <sys/ioctl.h>
+#include <assert.h>
+#include <inttypes.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <sys/ioctl.h>
+
+#ifdef HAVE_LINUX_PERF_EVENT_H
 # include <linux/perf_event.h>
+#endif
 
-# ifndef PERF_EVENT_IOC_ID
-#  define PERF_EVENT_IOC_ID			_IOR('$', 7, void *)
-# endif
+#ifndef PERF_EVENT_IOC_ID
+# define PERF_EVENT_IOC_ID			_IOR('$', 7, void *)
+#endif
 
-# ifndef PERF_EVENT_IOC_QUERY_BPF
-#  define PERF_EVENT_IOC_QUERY_BPF		_IOWR('$', 10, void *)
+#ifndef PERF_EVENT_IOC_QUERY_BPF
+# define PERF_EVENT_IOC_QUERY_BPF		_IOWR('$', 10, void *)
 
 struct perf_event_query_bpf {
         uint32_t ids_len;
         uint32_t prog_cnt;
         uint32_t ids[0];
 };
-# endif
+#endif
 
 int
 main(int argc, char **argv)
@@ -137,9 +139,3 @@ main(int argc, char **argv)
 	puts("+++ exited with 0 +++");
 	return 0;
 }
-
-#else
-
-SKIP_MAIN_UNDEFINED("HAVE_LINUX_PERF_EVENT_H");
-
-#endif
diff -pruN 5.5-3/tests-mx32/ioctl_perf-success.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_perf-success.gen.test
--- 5.5-3/tests-mx32/ioctl_perf-success.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_perf-success.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_perf-success +ioctl-success.sh -a35); do not edit.
+set -- -a35
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-mx32/ioctl_perf-success.test 5.9-0ubuntu2/tests-mx32/ioctl_perf-success.test
--- 5.5-3/tests-mx32/ioctl_perf-success.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_perf-success.test	1970-01-01 00:00:00.000000000 +0000
@@ -1,20 +0,0 @@
-#!/bin/sh -efu
-#
-# Check decoding of successful PERF_EVENT_IOC_{ID,QUERY_BPF} ioctls.
-#
-# Copyright (c) 2018 The strace developers.
-# All rights reserved.
-#
-# SPDX-License-Identifier: GPL-2.0-or-later
-
-. "${srcdir=.}/scno_tampering.sh"
-
-: ${IOCTL_INJECT_START=256}
-: ${IOCTL_INJECT_RETVAL=42}
-
-run_prog
-run_strace -a35 -e trace=ioctl \
-	-e inject=ioctl:retval="${IOCTL_INJECT_RETVAL}":when="${IOCTL_INJECT_START}+" \
-	../ioctl_perf-success "${IOCTL_INJECT_START}" "${IOCTL_INJECT_RETVAL}" > "$EXP"
-grep -v '^ioctl([012][,<]' < "$LOG" > "$OUT"
-match_diff "$OUT" "$EXP"
diff -pruN 5.5-3/tests-mx32/ioctl-success.sh 5.9-0ubuntu2/tests-mx32/ioctl-success.sh
--- 5.5-3/tests-mx32/ioctl-success.sh	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl-success.sh	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,21 @@
+#!/bin/sh -efu
+#
+# Check decoding of ioctls using syscall injection.
+#
+# Expects a binary that accepts IOCTL_INJECT_START as the first argument.
+#
+# Copyright (c) 2018-2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: GPL-2.0-or-later
+
+. "${srcdir=.}/scno_tampering.sh"
+
+: ${IOCTL_INJECT_START=256}
+: ${IOCTL_INJECT_RETVAL=42}
+
+run_strace -a50 "$@" -e trace=ioctl \
+	-e inject=ioctl:retval="${IOCTL_INJECT_RETVAL}":when="${IOCTL_INJECT_START}+" \
+	"../$NAME" "${IOCTL_INJECT_START}" "${IOCTL_INJECT_RETVAL}" > "$EXP"
+grep -v '^ioctl([012][,<]' < "$LOG" > "$OUT"
+match_diff "$OUT" "$EXP"
diff -pruN 5.5-3/tests-mx32/ioctl_tee.c 5.9-0ubuntu2/tests-mx32/ioctl_tee.c
--- 5.5-3/tests-mx32/ioctl_tee.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_tee.c	2020-09-23 16:28:11.000000000 +0000
@@ -0,0 +1,437 @@
+/*
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+
+#ifdef HAVE_LINUX_TEE_H
+
+# include <fcntl.h>
+# include <stdio.h>
+# include <string.h>
+
+# include <linux/tee.h>
+
+# include <sys/ioctl.h>
+# include <sys/stat.h>
+# include <sys/types.h>
+
+# include "xlat.h"
+
+# define NUM_PARAMS 8
+# define RVAL_EBADF " = -1 EBADF (%m)\n"
+
+# define UUID_SIZE 16
+
+# ifndef TEE_IOCTL_PARAM_ATTR_META
+#  define TEE_IOCTL_PARAM_ATTR_META 0x100
+# endif
+
+# ifndef HAVE_STRUCT_TEE_IOCTL_SHM_REGISTER_FD_DATA
+struct tee_ioctl_shm_register_fd_data {
+	__s64 fd;
+	__u64 size;
+	__u32 flags;
+	__u8  _pad1[4];
+	__u32 id;
+	__u8  _pad2[4];
+} ATTRIBUTE_ALIGNED(8);
+# endif
+
+# ifndef HAVE_STRUCT_TEE_IOCTL_SHM_REGISTER_DATA
+struct tee_ioctl_shm_register_data {
+	__u64 addr;
+	__u64 length;
+	__u32 flags;
+	__s32 id;
+};
+# endif
+
+# ifndef TEE_IOC_SHM_REGISTER_FD
+#  define TEE_IOC_SHM_REGISTER_FD _IOWR(TEE_IOC_MAGIC, TEE_IOC_BASE + 8, \
+					struct tee_ioctl_shm_register_fd_data)
+# endif
+
+# ifndef TEE_IOC_SHM_REGISTER
+#  define TEE_IOC_SHM_REGISTER    _IOWR(TEE_IOC_MAGIC, TEE_IOC_BASE + 9, \
+					struct tee_ioctl_shm_register_data)
+# endif
+
+
+typedef struct {
+	uint8_t b[UUID_SIZE];
+} uuid_t;
+
+# define UUID_INIT(a_, b_, c_, d0, d1, d2, d3, d4, d5, d6, d7)		\
+{ .b = {((a_) >> 24) & 0xff, ((a_) >> 16) & 0xff,			\
+        ((a_) >> 8) & 0xff, (a_) & 0xff,				\
+        ((b_) >> 8) & 0xff, (b_) & 0xff,				\
+        ((c_) >> 8) & 0xff, (c_) & 0xff,				\
+        (d0), (d1), (d2), (d3), (d4), (d5), (d6), (d7)} }
+
+# define CHK_NULL(ioctl_)						\
+	do {								\
+		ioctl(-1, ioctl_, NULL);				\
+		printf("ioctl(-1, " #ioctl_ ", NULL)" RVAL_EBADF);	\
+	} while (0)
+
+# define CHK_BUF(ioctl_)						\
+	do {								\
+		ioctl(-1, ioctl_, &buf_data);				\
+		printf("ioctl(-1, " #ioctl_				\
+		       ", {buf_len=%llu, buf_ptr=%#llx})" RVAL_EBADF,	\
+		       (unsigned long long) buf_data.buf_len,		\
+		       (unsigned long long) buf_data.buf_ptr);		\
+	} while (0)
+
+# define DEFINE_BUF_W_PARAMS(type_, shorthand_)				\
+	const size_t shorthand_ ## _size = sizeof(type_) +		\
+		NUM_PARAMS * sizeof(struct tee_ioctl_param);		\
+	union {								\
+		type_ shorthand_;					\
+		uint8_t data[shorthand_ ## _size];			\
+	} shorthand_ ## _buf
+
+static const unsigned long one_beef = (unsigned long) 0xcafef00ddeadbeefULL;
+static const unsigned long two_beef = (unsigned long) 0xbadc0dedbadc0dedULL;
+static const unsigned long red_beef = (unsigned long) 0xdefacedbeef0beefULL;
+static const unsigned long blu_beef = (unsigned long) 0xfacefeedcafef00dULL;
+
+static const uuid_t uuid_beef = UUID_INIT(0xdeadbeef, 0xcafe, 0xc0de,
+					  0xba, 0xdc, 0x0d, 0xed,
+					  0xfa, 0xce, 0xfe, 0xed);
+
+static void
+fill_params(struct tee_ioctl_param *params)
+{
+	for (unsigned i = 0; i < NUM_PARAMS; i++) {
+		params[i].a = two_beef;
+		params[i].b = red_beef;
+		params[i].c = blu_beef;
+	}
+	params[0].attr = TEE_IOCTL_PARAM_ATTR_TYPE_NONE;
+	params[1].attr = TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INPUT;
+	params[2].attr = TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_OUTPUT;
+	params[3].attr = TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INOUT;
+	params[4].attr = TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INPUT;
+	params[5].attr = TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_OUTPUT;
+	params[6].attr = TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INOUT;
+	params[7].attr = TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INPUT |
+			 TEE_IOCTL_PARAM_ATTR_META;
+}
+
+static void
+print_params(struct tee_ioctl_param *params)
+{
+	printf("{attr=TEE_IOCTL_PARAM_ATTR_TYPE_NONE}, "
+	       "{attr=TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INPUT, a=%#llx, b=%#llx, c=%#llx}, "
+	       "{attr=TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_OUTPUT, a=%#llx, b=%#llx, c=%#llx}, "
+	       "{attr=TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INOUT, a=%#llx, b=%#llx, c=%#llx}, "
+	       "{attr=TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INPUT, shm_offs=%#llx, size=%#llx, shm_id=%llu}, "
+	       "{attr=TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_OUTPUT, shm_offs=%#llx, size=%#llx, shm_id=%llu}, "
+	       "{attr=TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INOUT, shm_offs=%#llx, size=%#llx, shm_id=%llu}, "
+	       "{attr=TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INPUT|TEE_IOCTL_PARAM_ATTR_META, a=%#llx, b=%#llx, c=%#llx}",
+	       (unsigned long long) two_beef, (unsigned long long) red_beef,
+	       (unsigned long long) blu_beef, (unsigned long long) two_beef,
+	       (unsigned long long) red_beef, (unsigned long long) blu_beef,
+	       (unsigned long long) two_beef, (unsigned long long) red_beef,
+	       (unsigned long long) blu_beef, (unsigned long long) two_beef,
+	       (unsigned long long) red_beef, (unsigned long long) blu_beef,
+	       (unsigned long long) two_beef, (unsigned long long) red_beef,
+	       (unsigned long long) blu_beef, (unsigned long long) two_beef,
+	       (unsigned long long) red_beef, (unsigned long long) blu_beef,
+	       (unsigned long long) two_beef, (unsigned long long) red_beef,
+	       (unsigned long long) blu_beef
+	       );
+}
+
+int
+main(void)
+{
+	gid_t gid;
+
+	struct tee_ioctl_cancel_arg cancel;
+	struct tee_ioctl_shm_alloc_data shm_alloc;
+	struct tee_ioctl_shm_register_data shm_register;
+	struct tee_ioctl_close_session_arg close_session;
+	struct tee_ioctl_shm_register_fd_data shm_register_fd;
+
+	struct tee_ioctl_buf_data buf_data;
+	struct tee_ioctl_param *params = NULL;
+
+	DEFINE_BUF_W_PARAMS(struct tee_ioctl_invoke_arg, invoke);
+	DEFINE_BUF_W_PARAMS(struct tee_iocl_supp_recv_arg, supp_recv);
+	DEFINE_BUF_W_PARAMS(struct tee_iocl_supp_send_arg, supp_send);
+	DEFINE_BUF_W_PARAMS(struct tee_ioctl_open_session_arg, open_session);
+
+	static const char null_path[] = "/dev/null";
+	int fd = open(null_path, O_RDONLY);
+
+	/* NULL as arg */
+	CHK_NULL(TEE_IOC_CANCEL);
+	CHK_NULL(TEE_IOC_INVOKE);
+	CHK_NULL(TEE_IOC_VERSION);
+	CHK_NULL(TEE_IOC_SHM_ALLOC);
+	CHK_NULL(TEE_IOC_SUPPL_RECV);
+	CHK_NULL(TEE_IOC_SUPPL_SEND);
+	CHK_NULL(TEE_IOC_OPEN_SESSION);
+	CHK_NULL(TEE_IOC_SHM_REGISTER);
+	CHK_NULL(TEE_IOC_CLOSE_SESSION);
+
+	/* Valid parameterless calls */
+	ioctl(-1, TEE_IOC_SHM_REGISTER_FD, NULL);
+	printf("ioctl(-1, _IOC(_IOC_READ|_IOC_WRITE, 0xa4, 0x8, 0x20), NULL)"
+	       RVAL_EBADF);
+	ioctl(-1, _IOC(_IOC_NONE, 0xa4, 0xa, 0), NULL);
+	printf("ioctl(-1, _IOC(_IOC_NONE, 0xa4, 0xa, 0), 0)" RVAL_EBADF);
+
+	cancel.cancel_id = (uint32_t) one_beef;
+	cancel.session = (uint32_t) two_beef;
+	ioctl(-1, TEE_IOC_CANCEL, &cancel);
+	printf("ioctl(-1, TEE_IOC_CANCEL, {cancel_id=%u, session=%#x})" RVAL_EBADF,
+	       (uint32_t) one_beef, (uint32_t) two_beef);
+
+	close_session.session = (uint32_t) red_beef;
+	ioctl(-1, TEE_IOC_CLOSE_SESSION, &close_session);
+	printf("ioctl(-1, TEE_IOC_CLOSE_SESSION, {session=%#x})" RVAL_EBADF,
+	       (uint32_t) red_beef);
+
+	shm_alloc.size = one_beef;
+	shm_alloc.flags = TEE_IOCTL_SHM_MAPPED | TEE_IOCTL_SHM_DMA_BUF | 0x80;
+	ioctl(-1, TEE_IOC_SHM_ALLOC, &shm_alloc);
+	printf("ioctl(-1, TEE_IOC_SHM_ALLOC, {size=%#llx, "
+	       "flags=TEE_IOCTL_SHM_MAPPED|TEE_IOCTL_SHM_DMA_BUF|0x80})" RVAL_EBADF,
+	       (unsigned long long) one_beef);
+
+	shm_register.addr = red_beef;
+	shm_register.length = blu_beef;
+	shm_register.flags = TEE_IOCTL_SHM_MAPPED | 0x80;
+	ioctl(-1, TEE_IOC_SHM_REGISTER, &shm_register);
+	printf("ioctl(-1, TEE_IOC_SHM_REGISTER, {addr=%#llx, length=%#llx, "
+	       "flags=TEE_IOCTL_SHM_MAPPED|0x80})" RVAL_EBADF,
+	       (unsigned long long) red_beef,
+	       (unsigned long long) blu_beef);
+
+	if (fd >= 0) {
+		shm_register_fd.fd = fd;
+		shm_register_fd.flags = TEE_IOCTL_SHM_DMA_BUF;
+		ioctl(-1, TEE_IOC_SHM_REGISTER_FD, &shm_register_fd);
+		printf("ioctl(-1, _IOC(_IOC_READ|_IOC_WRITE, 0xa4, 0x8, 0x20), "
+		       "{fd=%d, flags=TEE_IOCTL_SHM_DMA_BUF})" RVAL_EBADF, fd);
+	}
+
+	/* Beef in buf_data */
+	buf_data.buf_ptr = one_beef;
+	buf_data.buf_len = two_beef;
+	CHK_BUF(TEE_IOC_INVOKE);
+	CHK_BUF(TEE_IOC_OPEN_SESSION);
+	CHK_BUF(TEE_IOC_SUPPL_RECV);
+	CHK_BUF(TEE_IOC_SUPPL_SEND);
+
+	/* Valid calls with parameters */
+	invoke_buf.invoke.func = (uint32_t) one_beef;
+	invoke_buf.invoke.session = (uint32_t) two_beef;
+	invoke_buf.invoke.cancel_id = (uint32_t) red_beef;
+	invoke_buf.invoke.num_params = NUM_PARAMS;
+	params = (struct tee_ioctl_param *)(&invoke_buf.invoke + 1);
+	fill_params(params);
+	buf_data.buf_ptr = (uintptr_t) &invoke_buf;
+	buf_data.buf_len = invoke_size;
+	ioctl(-1, TEE_IOC_INVOKE, &buf_data);
+	printf("ioctl(-1, TEE_IOC_INVOKE, {buf_len=%llu, "
+	       "buf_ptr={func=%u, session=%#x, cancel_id=%u, "
+	       "num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       (uint32_t) one_beef, (uint32_t) two_beef,
+	       (uint32_t) red_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	open_session_buf.open_session.clnt_login = TEE_IOCTL_LOGIN_PUBLIC;
+	gid = (gid_t) blu_beef;
+	memcpy(&open_session_buf.open_session.clnt_uuid, &gid, sizeof(gid_t));
+	memcpy(&open_session_buf.open_session.uuid, &uuid_beef, UUID_SIZE);
+	open_session_buf.open_session.cancel_id = (uint32_t) red_beef;
+	open_session_buf.open_session.num_params = NUM_PARAMS;
+	params = (struct tee_ioctl_param *)(&open_session_buf.open_session + 1);
+	fill_params(params);
+	buf_data.buf_ptr = (uintptr_t) &open_session_buf;
+	buf_data.buf_len = open_session_size;
+	ioctl(-1, TEE_IOC_OPEN_SESSION, &buf_data);
+	printf("ioctl(-1, TEE_IOC_OPEN_SESSION, {buf_len=%llu, "
+	       "buf_ptr={uuid=deadbeef-cafe-c0de-badc-0dedfacefeed, "
+	       "clnt_login=TEE_IOCTL_LOGIN_PUBLIC, "
+	       "cancel_id=%u, "
+	       "num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       (uint32_t) red_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	/* All the login types */
+	open_session_buf.open_session.clnt_login = TEE_IOCTL_LOGIN_USER;
+	ioctl(-1, TEE_IOC_OPEN_SESSION, &buf_data);
+	printf("ioctl(-1, TEE_IOC_OPEN_SESSION, {buf_len=%llu, "
+	       "buf_ptr={uuid=deadbeef-cafe-c0de-badc-0dedfacefeed, "
+	       "clnt_login=TEE_IOCTL_LOGIN_USER, "
+	       "cancel_id=%u, "
+	       "num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       (uint32_t) red_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	open_session_buf.open_session.clnt_login = TEE_IOCTL_LOGIN_GROUP;
+	ioctl(-1, TEE_IOC_OPEN_SESSION, &buf_data);
+	printf("ioctl(-1, TEE_IOC_OPEN_SESSION, {buf_len=%llu, "
+	       "buf_ptr={uuid=deadbeef-cafe-c0de-badc-0dedfacefeed, "
+	       "clnt_login=TEE_IOCTL_LOGIN_GROUP, "
+	       "clnt_uuid=%u, cancel_id=%u, "
+	       "num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       gid, (uint32_t) red_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	open_session_buf.open_session.clnt_login = TEE_IOCTL_LOGIN_APPLICATION;
+	ioctl(-1, TEE_IOC_OPEN_SESSION, &buf_data);
+	printf("ioctl(-1, TEE_IOC_OPEN_SESSION, {buf_len=%llu, "
+	       "buf_ptr={uuid=deadbeef-cafe-c0de-badc-0dedfacefeed, "
+	       "clnt_login=TEE_IOCTL_LOGIN_APPLICATION, "
+	       "cancel_id=%u, "
+	       "num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       (uint32_t) red_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	open_session_buf.open_session.clnt_login = TEE_IOCTL_LOGIN_USER_APPLICATION;
+	ioctl(-1, TEE_IOC_OPEN_SESSION, &buf_data);
+	printf("ioctl(-1, TEE_IOC_OPEN_SESSION, {buf_len=%llu, "
+	       "buf_ptr={uuid=deadbeef-cafe-c0de-badc-0dedfacefeed, "
+	       "clnt_login=TEE_IOCTL_LOGIN_USER_APPLICATION, "
+	       "cancel_id=%u, "
+	       "num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       (uint32_t) red_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	open_session_buf.open_session.clnt_login = TEE_IOCTL_LOGIN_GROUP_APPLICATION;
+	ioctl(-1, TEE_IOC_OPEN_SESSION, &buf_data);
+	printf("ioctl(-1, TEE_IOC_OPEN_SESSION, {buf_len=%llu, "
+	       "buf_ptr={uuid=deadbeef-cafe-c0de-badc-0dedfacefeed, "
+	       "clnt_login=TEE_IOCTL_LOGIN_GROUP_APPLICATION, "
+	       "clnt_uuid=%u, cancel_id=%u, "
+	       "num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       gid, (uint32_t) red_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	open_session_buf.open_session.clnt_login = 0xff;
+	ioctl(-1, TEE_IOC_OPEN_SESSION, &buf_data);
+	printf("ioctl(-1, TEE_IOC_OPEN_SESSION, {buf_len=%llu, "
+	       "buf_ptr={uuid=deadbeef-cafe-c0de-badc-0dedfacefeed, "
+	       "clnt_login=%#x /* TEE_IOCTL_LOGIN_??? */, "
+	       "clnt_uuid=[", (unsigned long long) buf_data.buf_len,
+	       open_session_buf.open_session.clnt_login);
+	for (unsigned i = 0; i < UUID_SIZE; i++) {
+		if (i > 0)
+			printf(", ");
+		printf("%#x", open_session_buf.open_session.clnt_uuid[i]);
+	}
+	printf("], cancel_id=%u, "
+	       "num_params=%u, params=[",
+	       (uint32_t) red_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	supp_recv_buf.supp_recv.func = (uint32_t) blu_beef;
+	supp_recv_buf.supp_recv.num_params = NUM_PARAMS;
+	params = (struct tee_ioctl_param *)(&supp_recv_buf.supp_recv + 1);
+	fill_params(params);
+	buf_data.buf_ptr = (uintptr_t) &supp_recv_buf;
+	buf_data.buf_len = supp_recv_size;
+	ioctl(-1, TEE_IOC_SUPPL_RECV, &buf_data);
+	printf("ioctl(-1, TEE_IOC_SUPPL_RECV, {buf_len=%llu, "
+	       "buf_ptr={func=%u, "
+	       "num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       (uint32_t) blu_beef, NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	supp_send_buf.supp_send.num_params = NUM_PARAMS;
+	params = (struct tee_ioctl_param *)(&supp_send_buf.supp_send + 1);
+	fill_params(params);
+	buf_data.buf_ptr = (uintptr_t) &supp_send_buf;
+	buf_data.buf_len = supp_send_size;
+	ioctl(-1, TEE_IOC_SUPPL_SEND, &buf_data);
+	printf("ioctl(-1, TEE_IOC_SUPPL_SEND, {buf_len=%llu, "
+	       "buf_ptr={num_params=%u, params=[",
+	       (unsigned long long) buf_data.buf_len,
+	       NUM_PARAMS);
+	print_params(params);
+	printf("]}})" RVAL_EBADF);
+
+	/* Valid buf, but unmatching num_params */
+	invoke_buf.invoke.num_params = 0;
+	supp_recv_buf.supp_recv.num_params = 0;
+	supp_send_buf.supp_send.num_params = 0;
+	open_session_buf.open_session.num_params = 0;
+
+	buf_data.buf_ptr = (uintptr_t) &invoke_buf;
+	buf_data.buf_len = invoke_size;
+	CHK_BUF(TEE_IOC_INVOKE);
+	buf_data.buf_ptr = (uintptr_t) &open_session_buf;
+	buf_data.buf_len = open_session_size;
+	CHK_BUF(TEE_IOC_OPEN_SESSION);
+	buf_data.buf_ptr = (uintptr_t) &supp_recv_buf;
+	buf_data.buf_len = supp_recv_size;
+	CHK_BUF(TEE_IOC_SUPPL_RECV);
+	buf_data.buf_ptr = (uintptr_t) &supp_send_buf;
+	buf_data.buf_len = supp_send_size;
+	CHK_BUF(TEE_IOC_SUPPL_SEND);
+
+	invoke_buf.invoke.num_params = NUM_PARAMS;
+	supp_recv_buf.supp_recv.num_params = NUM_PARAMS;
+	supp_send_buf.supp_send.num_params = NUM_PARAMS;
+	open_session_buf.open_session.num_params = NUM_PARAMS;
+
+	/* Invalid buf_len */
+	buf_data.buf_len = 0;
+	CHK_BUF(TEE_IOC_INVOKE);
+	CHK_BUF(TEE_IOC_OPEN_SESSION);
+	CHK_BUF(TEE_IOC_SUPPL_RECV);
+	CHK_BUF(TEE_IOC_SUPPL_SEND);
+
+	buf_data.buf_len = (unsigned long long) -1;
+	CHK_BUF(TEE_IOC_INVOKE);
+	CHK_BUF(TEE_IOC_OPEN_SESSION);
+	CHK_BUF(TEE_IOC_SUPPL_RECV);
+	CHK_BUF(TEE_IOC_SUPPL_SEND);
+
+	/* Valid buf_len, invalid buf_ptr */
+	buf_data.buf_ptr = one_beef;
+	buf_data.buf_len = invoke_size;
+	CHK_BUF(TEE_IOC_INVOKE);
+	buf_data.buf_len = open_session_size;
+	CHK_BUF(TEE_IOC_OPEN_SESSION);
+	buf_data.buf_len = supp_recv_size;
+	CHK_BUF(TEE_IOC_SUPPL_RECV);
+	buf_data.buf_len = supp_send_size;
+	CHK_BUF(TEE_IOC_SUPPL_SEND);
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else /* !HAVE_LINUX_TEE_H */
+
+SKIP_MAIN_UNDEFINED("HAVE_LINUX_TEE_H")
+
+#endif /* HAVE_LINUX_TEE_H */
diff -pruN 5.5-3/tests-mx32/ioctl_tee.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_tee.gen.test
--- 5.5-3/tests-mx32/ioctl_tee.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_tee.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_tee +ioctl.test ); do not edit.
+set -- 
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-mx32/ioctl_uffdio.c 5.9-0ubuntu2/tests-mx32/ioctl_uffdio.c
--- 5.5-3/tests-mx32/ioctl_uffdio.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_uffdio.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
  * Copyright (c)      2016 Red Hat, Inc.
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -135,6 +135,13 @@ main(void)
 	       " mode=UFFDIO_COPY_MODE_DONTWAKE, copy=%#zx}) = %d\n",
 	       fd, area2, area1, pagesize, pagesize, rc);
 
+	copy_struct->mode = 0xdeadbeef;;
+	rc = ioctl(fd, UFFDIO_COPY, copy_struct);
+	printf("ioctl(%d, UFFDIO_COPY, {dst=%p, src=%p, len=%#zx,"
+	       " mode=UFFDIO_COPY_MODE_DONTWAKE|UFFDIO_COPY_MODE_WP|0xdeadbeec"
+	       "}) = %s\n",
+	       fd, area2, area1, pagesize, sprintrc(rc));
+
 	/* ---- ZEROPAGE ---- */
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct uffdio_zeropage, zero_struct);
 	madvise(area2, pagesize, MADV_DONTNEED);
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2.c 5.9-0ubuntu2/tests-mx32/ioctl_v4l2.c
--- 5.5-3/tests-mx32/ioctl_v4l2.c	2019-08-05 22:48:31.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -8,11 +8,23 @@
 
 #include "tests.h"
 #include <errno.h>
+#include <stdint.h>
 #include <stdio.h>
 #include <string.h>
 #include <sys/ioctl.h>
-#include <linux/types.h>
-#include <linux/videodev2.h>
+#include "kernel_v4l2_types.h"
+
+#define XLAT_MACROS_ONLY
+# include "xlat/v4l2_ioctl_cmds.h"
+#undef XLAT_MACROS_ONLY
+
+#ifndef V4L2_CTRL_FLAG_NEXT_CTRL
+# define V4L2_CTRL_FLAG_NEXT_CTRL 0x80000000
+#endif
+
+#ifndef V4L2_CTRL_CLASS_DETECT
+# define V4L2_CTRL_CLASS_DETECT 0x00a30000
+#endif
 
 #define cc0(arg) ((unsigned int) (unsigned char) (arg))
 #define cc1(arg) ((unsigned int) (unsigned char) ((unsigned int) (arg) >> 8))
@@ -70,8 +82,21 @@ init_v4l2_format(struct v4l2_format *con
 		     i < ARRAY_SIZE(f->fmt.pix_mp.plane_fmt);
 		     i++) {
 			cur_pix[i].sizeimage = 0x1e3c531c | i;
-			cur_pix[i].bytesperline = 0xa983d721 | i;
+			if (sizeof(cur_pix[i].bytesperline) ==
+			    sizeof(uint32_t)) {
+				cur_pix[i].bytesperline = 0xa983d721 | i;
+			} else {
+# if WORDS_BIGENDIAN
+				cur_pix[i].bytesperline = 0xa983;
+				cur_pix[i].reserved[0] = 0xd721 | i;
+# else
+				cur_pix[i].bytesperline = 0xd721 | i;
+				cur_pix[i].reserved[0] = 0xa983;
+# endif
+			}
 		}
+		if (buf_type == V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE)
+			f->fmt.pix_mp.num_planes = 1;
 		break;
 	}
 #endif
@@ -85,10 +110,10 @@ init_v4l2_format(struct v4l2_format *con
 		f->fmt.win.w.height = 0xbbd886c8;
 		f->fmt.win.field = V4L2_FIELD_ANY;
 		f->fmt.win.chromakey = 0xdb1f991f;
-		f->fmt.win.clipcount = 2;
+		f->fmt.win.clipcount =
+			buf_type == V4L2_BUF_TYPE_VIDEO_OVERLAY ? 3 : 2;
 		f->fmt.win.clips =
-			tail_alloc(sizeof(*f->fmt.win.clips) *
-			f->fmt.win.clipcount);
+			tail_alloc(sizeof(*f->fmt.win.clips) * 2);
 		f->fmt.win.clips[0].c.left = 0x3313d36e;
 		f->fmt.win.clips[0].c.top = 0xcdffe510;
 		f->fmt.win.clips[0].c.width = 0x2064f3a8;
@@ -101,6 +126,9 @@ init_v4l2_format(struct v4l2_format *con
 		f->fmt.win.bitmap = (void *) -2UL;
 #ifdef HAVE_STRUCT_V4L2_WINDOW_GLOBAL_ALPHA
 		f->fmt.win.global_alpha = 0xce;
+#else
+		((uint8_t *) &f->fmt.win)[offsetofend(struct v4l2_window,
+						      bitmap)] = 0xce;
 #endif
 		break;
 	case V4L2_BUF_TYPE_VBI_CAPTURE:
@@ -138,7 +166,12 @@ init_v4l2_format(struct v4l2_format *con
 	case V4L2_BUF_TYPE_SDR_OUTPUT:
 		f->fmt.sdr.pixelformat = sf_magic;
 # ifdef HAVE_STRUCT_V4L2_SDR_FORMAT_BUFFERSIZE
-		f->fmt.sdr.buffersize = 0x25afabfb;
+		if (sizeof(f->fmt.sdr.buffersize == sizeof(uint32_t)))
+			f->fmt.sdr.buffersize = 0x25afabfb;
+		else
+			((uint32_t *) &f->fmt.sdr)[1] = 0x25afabfb;
+# else
+		((uint32_t *) &f->fmt.sdr)[1] = 0x25afabfb;
 # endif
 		break;
 #endif
@@ -155,8 +188,8 @@ init_v4l2_format(struct v4l2_format *con
 
 static void
 dprint_ioctl_v4l2(struct v4l2_format *const f,
-		  const char *request, const unsigned int buf_type,
-		  const char *buf_type_string)
+		  XLAT_SEL(unsigned reqval, const char *reqstr),
+		  const unsigned int buf_type, const char *buf_type_string)
 {
 	int saved_errno;
 
@@ -164,12 +197,16 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 	case V4L2_BUF_TYPE_VIDEO_CAPTURE:
 	case V4L2_BUF_TYPE_VIDEO_OUTPUT:
 		saved_errno = errno;
-		printf("ioctl(-1, %s, {type=%s"
+		printf("ioctl(-1, " XLAT_FMT ", {type=" XLAT_FMT
 		       ", fmt.pix={width=%u, height=%u, pixelformat=",
-		       request,
-		       buf_type_string,
+		       XLAT_SEL(reqval, reqstr),
+		       XLAT_SEL(buf_type, buf_type_string),
 		       f->fmt.pix.width, f->fmt.pix.height);
 
+#if XLAT_RAW
+		printf("%#x", buf_type == V4L2_BUF_TYPE_VIDEO_CAPTURE
+			      ? magic : pf_magic);
+#else /* !XLAT_RAW */
 		if (buf_type == V4L2_BUF_TYPE_VIDEO_CAPTURE)
 			printf("v4l2_fourcc('\\x%x', '\\x%x', '\\x%x', '\\x%x')",
 			       cc0(magic), cc1(magic), cc2(magic), cc3(magic));
@@ -178,12 +215,15 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 			       "/* V4L2_PIX_FMT_SPCA508 */",
 			       cc0(pf_magic), cc1(pf_magic), cc2(pf_magic),
 			       cc3(pf_magic));
+#endif /* XLAT_RAW */
 
 		errno = saved_errno;
-		printf(", field=V4L2_FIELD_NONE, bytesperline=%u, sizeimage=%u"
-		       ", colorspace=V4L2_COLORSPACE_JPEG}}) = -1 EBADF (%m)\n",
+		printf(", field=" XLAT_FMT ", bytesperline=%u, sizeimage=%u"
+		       ", colorspace=" XLAT_FMT "}}) = -1 EBADF (%m)\n",
+		       XLAT_ARGS(V4L2_FIELD_NONE),
 		       f->fmt.pix.bytesperline,
-		       f->fmt.pix.sizeimage);
+		       f->fmt.pix.sizeimage,
+		       XLAT_ARGS(V4L2_COLORSPACE_JPEG));
 		break;
 #if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE
 	case V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE:
@@ -191,13 +231,17 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 		unsigned int i;
 
 		saved_errno = errno;
-		printf("ioctl(-1, %s"
-		       ", {type=%s"
+		printf("ioctl(-1, " XLAT_FMT
+		       ", {type=" XLAT_FMT
 		       ", fmt.pix_mp={width=%u, height=%u, pixelformat=",
-		       request,
-		       buf_type_string,
+		       XLAT_SEL(reqval, reqstr),
+		       XLAT_SEL(buf_type, buf_type_string),
 		       f->fmt.pix_mp.width, f->fmt.pix_mp.height);
 
+# if XLAT_RAW
+		printf("%#x", buf_type == V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE
+			      ? magic : pf_magic);
+# else /* !XLAT_RAW */
 		if (buf_type == V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE)
 			printf("v4l2_fourcc('\\x%x', '\\x%x', '\\x%x', '\\x%x')",
 			       cc0(magic), cc1(magic), cc2(magic), cc3(magic));
@@ -206,21 +250,35 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 			       "/* V4L2_PIX_FMT_SPCA508 */",
 			       cc0(pf_magic), cc1(pf_magic), cc2(pf_magic),
 			       cc3(pf_magic));
+# endif /* XLAT_RAW */
 
-		printf(", field=V4L2_FIELD_NONE, colorspace="
-		       "V4L2_COLORSPACE_JPEG, plane_fmt=[");
+		printf(", field=" XLAT_FMT ", colorspace=" XLAT_FMT
+		       ", plane_fmt=[",
+		       XLAT_ARGS(V4L2_FIELD_NONE),
+		       XLAT_ARGS(V4L2_COLORSPACE_JPEG));
 		for (i = 0;
-		     i < ARRAY_SIZE(f->fmt.pix_mp.plane_fmt);
+		     i < (buf_type == V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE
+		          ? 1 : ARRAY_SIZE(f->fmt.pix_mp.plane_fmt));
 		     ++i) {
 			if (i)
 				printf(", ");
 			printf("{sizeimage=%u, bytesperline=%u}",
 			f->fmt.pix_mp.plane_fmt[i].sizeimage,
-			f->fmt.pix_mp.plane_fmt[i].bytesperline);
+			sizeof(f->fmt.pix_mp.plane_fmt[i].bytesperline) ==
+			sizeof(uint32_t)
+			? f->fmt.pix_mp.plane_fmt[i].bytesperline :
+# if WORDS_BIGENDIAN
+			(f->fmt.pix_mp.plane_fmt[i].bytesperline << 16) |
+			f->fmt.pix_mp.plane_fmt[i].reserved[0]
+# else
+			f->fmt.pix_mp.plane_fmt[i].bytesperline |
+			(f->fmt.pix_mp.plane_fmt[i].reserved[0] << 16)
+# endif
+			);
 		}
 		errno = saved_errno;
 		printf("], num_planes=%u}}) = -1 EBADF (%m)\n",
-		f->fmt.pix_mp.num_planes);
+		       f->fmt.pix_mp.num_planes);
 		break;
 	}
 #endif
@@ -228,20 +286,17 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 	case V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY:
 #endif
 	case V4L2_BUF_TYPE_VIDEO_OVERLAY:
-		printf("ioctl(-1, %s, {type=%s"
+		saved_errno = errno;
+		printf("ioctl(-1, " XLAT_FMT ", {type=" XLAT_FMT
 		       ", fmt.win={left=%d, top=%d, width=%u, height=%u"
-		       ", field=V4L2_FIELD_ANY, chromakey=%#x, clips="
+		       ", field=" XLAT_FMT ", chromakey=%#x, clips="
 		       "[{left=%d, top=%d, width=%u, height=%u}, "
-		       "{left=%d, top=%d, width=%u, height=%u}]"
-		       ", clipcount=%u, bitmap=%p"
-#ifdef HAVE_STRUCT_V4L2_WINDOW_GLOBAL_ALPHA
-		       ", global_alpha=%#x"
-#endif
-		       "}}) = -1 EBADF (%m)\n",
-		       request,
-		       buf_type_string,
+		       "{left=%d, top=%d, width=%u, height=%u}",
+		       XLAT_SEL(reqval, reqstr),
+		       XLAT_SEL(buf_type, buf_type_string),
 		       f->fmt.win.w.left, f->fmt.win.w.top,
 		       f->fmt.win.w.width, f->fmt.win.w.height,
+		       XLAT_ARGS(V4L2_FIELD_ANY),
 		       f->fmt.win.chromakey,
 		       f->fmt.win.clips[0].c.left,
 		       f->fmt.win.clips[0].c.top,
@@ -250,24 +305,37 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 		       f->fmt.win.clips[1].c.left,
 		       f->fmt.win.clips[1].c.top,
 		       f->fmt.win.clips[1].c.width,
-		       f->fmt.win.clips[1].c.height,
-		       f->fmt.win.clipcount, f->fmt.win.bitmap
+		       f->fmt.win.clips[1].c.height);
+		if (f->fmt.win.clipcount > 2)
+			printf(", ... /* %p */", f->fmt.win.clips + 2);
+		errno = saved_errno;
+		printf("], clipcount=%u, bitmap=%p"
+		       ", global_alpha=%#x"
+		       "}}) = -1 EBADF (%m)\n",
+		       f->fmt.win.clipcount, f->fmt.win.bitmap,
 #ifdef HAVE_STRUCT_V4L2_WINDOW_GLOBAL_ALPHA
-		       , f->fmt.win.global_alpha
+		       f->fmt.win.global_alpha
+#else
+		       ((uint8_t *) &f->fmt.win)[offsetofend(struct v4l2_window,
+							     bitmap)]
 #endif
 		       );
 		break;
 	case V4L2_BUF_TYPE_VBI_CAPTURE:
 	case V4L2_BUF_TYPE_VBI_OUTPUT:
 		saved_errno = errno;
-		printf("ioctl(-1, %s, {type=%s"
+		printf("ioctl(-1, " XLAT_FMT ", {type=" XLAT_FMT
 		       ", fmt.vbi={sampling_rate=%u, offset=%u"
 		       ", samples_per_line=%u, sample_format=",
-		       request,
-		       buf_type_string,
+		       XLAT_SEL(reqval, reqstr),
+		       XLAT_SEL(buf_type, buf_type_string),
 		       f->fmt.vbi.sampling_rate, f->fmt.vbi.offset,
 		       f->fmt.vbi.samples_per_line);
 
+#if XLAT_RAW
+		printf("%#x", buf_type == V4L2_BUF_TYPE_VBI_CAPTURE
+			      ? magic : pf_magic);
+#else /* !XLAT_RAW */
 		if (buf_type == V4L2_BUF_TYPE_VBI_CAPTURE)
 			printf("v4l2_fourcc('\\x%x', '\\x%x', '\\x%x', '\\x%x')",
 			       cc0(magic), cc1(magic), cc2(magic), cc3(magic));
@@ -276,24 +344,27 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 			       "/* V4L2_PIX_FMT_SPCA508 */",
 			       cc0(pf_magic), cc1(pf_magic), cc2(pf_magic),
 			       cc3(pf_magic));
+#endif /* XLAT_RAW */
 
 		errno = saved_errno;
-		printf(", start=[%u, %u], count=[%u, %u]"
-		       ", flags=V4L2_VBI_INTERLACED}})"
+		printf(", start=[%d, %d], count=[%u, %u]"
+		       ", flags=" XLAT_FMT "}})"
 		       " = -1 EBADF (%m)\n",
 		       f->fmt.vbi.start[0], f->fmt.vbi.start[1],
-		       f->fmt.vbi.count[0], f->fmt.vbi.count[1]);
+		       f->fmt.vbi.count[0], f->fmt.vbi.count[1],
+		       XLAT_ARGS(V4L2_VBI_INTERLACED));
 		break;
 #if HAVE_DECL_V4L2_BUF_TYPE_SLICED_VBI_CAPTURE
 	case V4L2_BUF_TYPE_SLICED_VBI_CAPTURE:
 	case V4L2_BUF_TYPE_SLICED_VBI_OUTPUT: {
 		unsigned int i, j;
 
-		printf("ioctl(-1, %s, {type=%s"
-		       ", fmt.sliced={service_set=V4L2_SLICED_VPS"
+		printf("ioctl(-1, " XLAT_FMT ", {type=" XLAT_FMT
+		       ", fmt.sliced={service_set=" XLAT_FMT
 		       ", io_size=%u, service_lines=[",
-		       request,
-		       buf_type_string,
+		       XLAT_SEL(reqval, reqstr),
+		       XLAT_SEL(buf_type, buf_type_string),
+		       XLAT_ARGS(V4L2_SLICED_VPS),
 		       f->fmt.sliced.io_size);
 		for (i = 0;
 		     i < ARRAY_SIZE(f->fmt.sliced.service_lines);
@@ -321,30 +392,38 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 #if HAVE_DECL_V4L2_BUF_TYPE_SDR_CAPTURE
 	case V4L2_BUF_TYPE_SDR_CAPTURE:
 		saved_errno = errno;
-		printf("ioctl(-1, %s, {type=%s"
+		printf("ioctl(-1, " XLAT_FMT ", {type=" XLAT_FMT
 		       ", fmt.sdr={pixelformat=",
-		       request,
-		       buf_type_string);
+		       XLAT_SEL(reqval, reqstr),
+		       XLAT_SEL(buf_type, buf_type_string));
 
+# if XLAT_RAW
+		if (buf_type == V4L2_BUF_TYPE_SDR_CAPTURE)
+			printf("%#x", magic);
+#  if HAVE_DECL_V4L2_BUF_TYPE_SDR_OUTPUT
+		else
+			printf("%#x", sf_magic);
+#  endif
+# else /* !XLAT_RAW */
 		if (buf_type == V4L2_BUF_TYPE_SDR_CAPTURE)
 			printf("v4l2_fourcc('\\x%x', '\\x%x', '\\x%x', '\\x%x')",
 			       cc0(magic), cc1(magic), cc2(magic), cc3(magic));
-# if HAVE_DECL_V4L2_BUF_TYPE_SDR_OUTPUT
+#  if HAVE_DECL_V4L2_BUF_TYPE_SDR_OUTPUT
 		else
 			printf("v4l2_fourcc('%c', '%c', '%c', '%c') "
 			       "/* V4L2_SDR_FMT_RU12LE */",
 			       cc0(sf_magic), cc1(sf_magic), cc2(sf_magic),
 			       cc3(sf_magic));
-# endif
+#  endif
+# endif /* XLAT_RAW */
 
 		errno = saved_errno;
-		printf(
-# ifdef HAVE_STRUCT_V4L2_SDR_FORMAT_BUFFERSIZE
-		       ", buffersize=%u"
-# endif
-		       "}}) = -1 EBADF (%m)\n"
+		printf(", buffersize=%u}}) = -1 EBADF (%m)\n"
 # ifdef HAVE_STRUCT_V4L2_SDR_FORMAT_BUFFERSIZE
-		       , f->fmt.sdr.buffersize
+		       , sizeof(f->fmt.sdr.buffersize == sizeof(uint32_t))
+			? f->fmt.sdr.buffersize : ((uint32_t *) &f->fmt.sdr)[1]
+# else
+		       , ((uint32_t *) &f->fmt.sdr)[1]
 # endif
 		       );
 		break;
@@ -352,7 +431,8 @@ dprint_ioctl_v4l2(struct v4l2_format *co
 	}
 }
 #define print_ioctl_v4l2(v4l2_format, request, buf_type)	\
-	dprint_ioctl_v4l2((v4l2_format), (request), (buf_type), #buf_type)
+	dprint_ioctl_v4l2((v4l2_format), XLAT_SEL(request, #request), \
+			  (buf_type), #buf_type)
 
 int
 main(void)
@@ -364,267 +444,559 @@ main(void)
 
 	unsigned char cc[sizeof(int)] = { 'A', '\'', '\\', '\xfa' };
 
+	/* Unknown */
+	static const struct {
+		uint32_t flags;
+		const char *str;
+	} cmd_flags[] = {
+		{ ARG_STR(_IOC_NONE) },
+		{ ARG_STR(_IOC_READ) },
+		{ ARG_STR(_IOC_WRITE) },
+		{ ARG_STR(_IOC_READ|_IOC_WRITE) },
+	};
+	static const uint8_t unknown_cmds[] = {
+		1, 3, 6 /* VIDIOC_G_MPEGCOMP */, 7 /* VIDIOC_S_MPEGCOMP */,
+		12, 13, 20, 31, 32, 35, 42, 43, 44, 45, 51, 52, 53,
+		81 /* VIDIOC_G_CHIP_IDENT_OLD */,
+		83 /* VIDIOC_ENUM_DV_PRESETS */, 84 /* VIDIOC_S_DV_PRESET */,
+		85 /* VIDIOC_G_DV_PRESET */, 86 /* VIDIOC_QUERY_DV_PRESET */,
+		104 /* 103 is the last existing */, 255
+	};
+
+	for (size_t i = 0; i < ARRAY_SIZE(unknown_cmds); i++) {
+		/* Trying to hit common argument sizes */
+		for (size_t j = 0; j < 256; j += 4) {
+			for (size_t k = 0; k < ARRAY_SIZE(cmd_flags); k++) {
+				uint32_t ioc = _IOC(cmd_flags[k].flags, 'V',
+						    unknown_cmds[i], j);
+				/*
+				 * Conflicts with VT* and VBG* ioctls
+				 * that happen to also use 'V' command type.
+				 */
+				switch (ioc) {
+				/* VT_GETMODE */
+				case _IOC(_IOC_NONE, 'V', 1, 0):
+				/* VT_GETSTATE */
+				case _IOC(_IOC_NONE, 'V', 3, 0):
+				/* VBG_IOCTL_VMMDEV_REQUEST_BIG */
+				case _IOC(_IOC_READ|_IOC_WRITE, 'V', 3, 0):
+				/* VT_ACTIVATE */
+				case _IOC(_IOC_NONE, 'V', 6, 0):
+				/* VT_WAITACTIVE */
+				case _IOC(_IOC_NONE, 'V', 7, 0):
+				/* VT_UNLOCKSWITCH */
+				case _IOC(_IOC_NONE, 'V', 12, 0):
+				/* VBG_IOCTL_CHANGE_FILTER_MASK */
+				case _IOC(_IOC_READ|_IOC_WRITE, 'V', 12, 32):
+				/* VT_GETHIFONTMASK */
+				case _IOC(_IOC_NONE, 'V', 13, 0):
+					continue;
+				/* VBG_IOCTL_ACQUIRE_GUEST_CAPABILITIES */
+				case _IOC(_IOC_READ|_IOC_WRITE, 'V', 13, 36):
+					continue;
+				}
+
+				ioctl(-1, ioc, 0);
+				printf("ioctl(-1, " NABBR("%#x") VERB(" /* ")
+				       NRAW("_IOC(%s, 0x56, %#x, %#zx)")
+				       VERB(" */") ", 0) = -1 EBADF (%m)\n"
+#if XLAT_RAW || XLAT_VERBOSE
+				       , ioc
+#endif
+#if !XLAT_RAW
+				       , cmd_flags[k].str, unknown_cmds[i], j
+#endif
+				       );
+
+				ioctl(-1, ioc,
+				      (unsigned long) 0xbadc0deddeadc0deULL);
+				printf("ioctl(-1, " NABBR("%#x") VERB(" /* ")
+				       NRAW("_IOC(%s, 0x56, %#x, %#zx)")
+				       VERB(" */") ", %#lx) = -1 EBADF (%m)\n",
+#if XLAT_RAW || XLAT_VERBOSE
+				       ioc,
+#endif
+#if !XLAT_RAW
+				       cmd_flags[k].str, unknown_cmds[i], j,
+#endif
+				       (unsigned long) 0xbadc0deddeadc0deULL);
+			}
+		}
+	}
+
+	/* Decoding is not supported */
+	static const struct {
+		uint32_t cmd;
+		const char *str;
+	} unsupp_cmds[] = {
+		{ ARG_STR(VIDIOC_OVERLAY) },
+#ifdef VIDIOC_EXPBUF
+		{ ARG_STR(VIDIOC_EXPBUF) },
+#endif
+		{ ARG_STR(VIDIOC_G_AUDIO) },
+		{ ARG_STR(VIDIOC_S_AUDIO) },
+		{ ARG_STR(VIDIOC_QUERYMENU) },
+#ifdef VIDIOC_G_EDID
+		{ ARG_STR(VIDIOC_G_EDID) },
+#endif
+#ifdef VIDIOC_S_EDID
+		{ ARG_STR(VIDIOC_S_EDID) },
+#endif
+		{ ARG_STR(VIDIOC_G_OUTPUT) },
+		{ ARG_STR(VIDIOC_S_OUTPUT) },
+		{ ARG_STR(VIDIOC_ENUMOUTPUT) },
+		{ ARG_STR(VIDIOC_G_AUDOUT) },
+		{ ARG_STR(VIDIOC_S_AUDOUT) },
+		{ ARG_STR(VIDIOC_G_MODULATOR) },
+		{ ARG_STR(VIDIOC_S_MODULATOR) },
+		{ ARG_STR(VIDIOC_G_FREQUENCY) },
+		{ ARG_STR(VIDIOC_S_FREQUENCY) },
+		{ ARG_STR(VIDIOC_G_JPEGCOMP) },
+		{ ARG_STR(VIDIOC_S_JPEGCOMP) },
+		{ ARG_STR(VIDIOC_QUERYSTD) },
+		{ ARG_STR(VIDIOC_ENUMAUDIO) },
+		{ ARG_STR(VIDIOC_ENUMAUDOUT) },
+		{ ARG_STR(VIDIOC_G_PRIORITY) },
+		{ ARG_STR(VIDIOC_S_PRIORITY) },
+		{ ARG_STR(VIDIOC_G_SLICED_VBI_CAP) },
+		{ ARG_STR(VIDIOC_LOG_STATUS) },
+#ifdef VIDIOC_G_ENC_INDEX
+		{ ARG_STR(VIDIOC_G_ENC_INDEX) },
+#endif
+#ifdef VIDIOC_ENCODER_CMD
+		{ ARG_STR(VIDIOC_ENCODER_CMD) },
+#endif
+#ifdef VIDIOC_TRY_ENCODER_CMD
+		{ ARG_STR(VIDIOC_TRY_ENCODER_CMD) },
+#endif
+#ifdef VIDIOC_DBG_S_REGISTER
+		{ ARG_STR(VIDIOC_DBG_S_REGISTER) },
+#endif
+#ifdef VIDIOC_DBG_G_REGISTER
+		{ ARG_STR(VIDIOC_DBG_G_REGISTER) },
+#endif
+#ifdef VIDIOC_G_CHIP_IDENT_OLD
+		{ ARG_STR(VIDIOC_G_CHIP_IDENT_OLD) },
+#endif
+#ifdef VIDIOC_DBG_G_CHIP_IDENT
+		/* Broken on RHEL 6/7 */
+		/* { ARG_STR(VIDIOC_DBG_G_CHIP_IDENT) }, */
+#endif
+#ifdef VIDIOC_S_HW_FREQ_SEEK
+		{ ARG_STR(VIDIOC_S_HW_FREQ_SEEK) },
+#endif
+#ifdef VIDIOC_ENUM_DV_PRESETS
+		/* Next 4 are broken on RHEL 6 */
+		/* { ARG_STR(VIDIOC_ENUM_DV_PRESETS) }, */
+#endif
+#ifdef VIDIOC_S_DV_PRESET
+		/* { ARG_STR(VIDIOC_S_DV_PRESET) }, */
+#endif
+#ifdef VIDIOC_G_DV_PRESET
+		/* { ARG_STR(VIDIOC_G_DV_PRESET) }, */
+#endif
+#ifdef VIDIOC_QUERY_DV_PRESET
+		/* { ARG_STR(VIDIOC_QUERY_DV_PRESET) }, */
+#endif
+#ifdef VIDIOC_S_DV_TIMINGS
+		{ ARG_STR(VIDIOC_S_DV_TIMINGS) },
+#endif
+#ifdef VIDIOC_G_DV_TIMINGS
+		{ ARG_STR(VIDIOC_G_DV_TIMINGS) },
+#endif
+#ifdef VIDIOC_DQEVENT
+		{ ARG_STR(VIDIOC_DQEVENT) },
+#endif
+#ifdef VIDIOC_SUBSCRIBE_EVENT
+		{ ARG_STR(VIDIOC_SUBSCRIBE_EVENT) },
+#endif
+#ifdef VIDIOC_UNSUBSCRIBE_EVENT
+		{ ARG_STR(VIDIOC_UNSUBSCRIBE_EVENT) },
+#endif
+#ifdef VIDIOC_PREPARE_BUF
+		{ ARG_STR(VIDIOC_PREPARE_BUF) },
+#endif
+#ifdef VIDIOC_G_SELECTION
+		{ ARG_STR(VIDIOC_G_SELECTION) },
+#endif
+#ifdef VIDIOC_S_SELECTION
+		{ ARG_STR(VIDIOC_S_SELECTION) },
+#endif
+#ifdef VIDIOC_DECODER_CMD
+		{ ARG_STR(VIDIOC_DECODER_CMD) },
+#endif
+#ifdef VIDIOC_TRY_DECODER_CMD
+		{ ARG_STR(VIDIOC_TRY_DECODER_CMD) },
+#endif
+#ifdef VIDIOC_ENUM_DV_TIMINGS
+		{ ARG_STR(VIDIOC_ENUM_DV_TIMINGS) },
+#endif
+#ifdef VIDIOC_QUERY_DV_TIMINGS
+		{ ARG_STR(VIDIOC_QUERY_DV_TIMINGS) },
+#endif
+#ifdef VIDIOC_DV_TIMINGS_CAP
+		{ ARG_STR(VIDIOC_DV_TIMINGS_CAP) },
+#endif
+#ifdef VIDIOC_ENUM_FREQ_BANDS
+		{ ARG_STR(VIDIOC_ENUM_FREQ_BANDS) },
+#endif
+#ifdef VIDIOC_DBG_G_CHIP_INFO
+		{ ARG_STR(VIDIOC_DBG_G_CHIP_INFO) },
+#endif
+#ifdef VIDIOC_QUERY_EXT_CTRL
+		{ ARG_STR(VIDIOC_QUERY_EXT_CTRL) },
+#endif
+#ifdef VIDIOC_SUBDEV_ENUM_MBUS_CODE
+		{ ARG_STR(VIDIOC_SUBDEV_ENUM_MBUS_CODE) },
+#endif
+#ifdef VIDIOC_SUBDEV_G_FMT
+		{ ARG_STR(VIDIOC_SUBDEV_G_FMT) },
+#endif
+#ifdef VIDIOC_SUBDEV_S_FMT
+		{ ARG_STR(VIDIOC_SUBDEV_S_FMT) },
+#endif
+#ifdef VIDIOC_SUBDEV_G_FRAME_INTERVAL
+		{ ARG_STR(VIDIOC_SUBDEV_G_FRAME_INTERVAL) },
+#endif
+#ifdef VIDIOC_SUBDEV_S_FRAME_INTERVAL
+		{ ARG_STR(VIDIOC_SUBDEV_S_FRAME_INTERVAL) },
+#endif
+#ifdef VIDIOC_SUBDEV_G_CROP
+		{ ARG_STR(VIDIOC_SUBDEV_G_CROP) },
+#endif
+#ifdef VIDIOC_SUBDEV_S_CROP
+		{ ARG_STR(VIDIOC_SUBDEV_S_CROP) },
+#endif
+#ifdef VIDIOC_SUBDEV_G_SELECTION
+		{ ARG_STR(VIDIOC_SUBDEV_G_SELECTION) },
+#endif
+#ifdef VIDIOC_SUBDEV_S_SELECTION
+		{ ARG_STR(VIDIOC_SUBDEV_S_SELECTION) },
+#endif
+#ifdef VIDIOC_SUBDEV_ENUM_FRAME_SIZE
+		{ ARG_STR(VIDIOC_SUBDEV_ENUM_FRAME_SIZE) },
+#endif
+#ifdef VIDIOC_SUBDEV_ENUM_FRAME_INTERVAL
+		{ ARG_STR(VIDIOC_SUBDEV_ENUM_FRAME_INTERVAL) },
+#endif
+	};
+
+	for (size_t i = 0; i < ARRAY_SIZE(unsupp_cmds); i++) {
+		switch (unsupp_cmds[i].cmd) {
+		/*
+		 * VIDIOC_G_SLICED_VBI_CAP macro has been changed from
+		 * IOR to IOWR in Linux v2.6.19-rc1~643^2~37, skip it.
+		 */
+		case _IOR('V', 69, struct v4l2_sliced_vbi_cap):
+			continue;
+		}
+
+		ioctl(-1, unsupp_cmds[i].cmd, 0);
+		printf("ioctl(-1, " XLAT_FMT ", 0) = -1 EBADF (%m)\n",
+		       XLAT_SEL(unsupp_cmds[i].cmd, unsupp_cmds[i].str));
+
+		ioctl(-1, unsupp_cmds[i].cmd,
+		      (unsigned long) 0xbadc0deddeadc0deULL);
+		printf("ioctl(-1, " XLAT_FMT ", %#lx) = -1 EBADF (%m)\n",
+		       XLAT_SEL(unsupp_cmds[i].cmd, unsupp_cmds[i].str),
+		       (unsigned long) 0xbadc0deddeadc0deULL);
+	}
+
 	/* VIDIOC_QUERYCAP */
 	ioctl(-1, VIDIOC_QUERYCAP, 0);
-	printf("ioctl(-1, VIDIOC_QUERYCAP, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QUERYCAP));
 
 	ioctl(-1, VIDIOC_QUERYCAP, page);
-	printf("ioctl(-1, VIDIOC_QUERYCAP, %p) = -1 EBADF (%m)\n", page);
+	printf("ioctl(-1, %s, %p) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QUERYCAP), page);
 
 	/* VIDIOC_ENUM_FMT */
 	ioctl(-1, VIDIOC_ENUM_FMT, 0);
-	printf("ioctl(-1, VIDIOC_ENUM_FMT, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUM_FMT));
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct v4l2_fmtdesc, p_fmtdesc);
 	p_fmtdesc->index = magic;
 	p_fmtdesc->type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
 	ioctl(-1, VIDIOC_ENUM_FMT, p_fmtdesc);
-	printf("ioctl(-1, VIDIOC_ENUM_FMT, {index=%u"
-	       ", type=V4L2_BUF_TYPE_VIDEO_CAPTURE}) = -1 EBADF (%m)\n",
-	       p_fmtdesc->index);
+	printf("ioctl(-1, %s, {index=%u, type=" XLAT_FMT
+	       "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUM_FMT), p_fmtdesc->index,
+	       XLAT_ARGS(V4L2_BUF_TYPE_VIDEO_CAPTURE));
 
 	/* VIDIOC_G_FMT */
 	ioctl(-1, VIDIOC_G_FMT, 0);
-	printf("ioctl(-1, VIDIOC_G_FMT, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT));
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct v4l2_format, p_format);
 
 	p_format->type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
 	ioctl(-1, VIDIOC_G_FMT, p_format);
-	printf("ioctl(-1, VIDIOC_G_FMT"
-	       ", {type=V4L2_BUF_TYPE_VIDEO_CAPTURE}) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {type=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT),
+	       XLAT_ARGS(V4L2_BUF_TYPE_VIDEO_CAPTURE));
 #if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE
 	p_format->type = V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE;
 	ioctl(-1, VIDIOC_G_FMT, p_format);
-	printf("ioctl(-1, VIDIOC_G_FMT"
-	       ", {type=V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE}) ="
-	       " -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {type=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT),
+	       XLAT_ARGS(V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE));
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY
 	p_format->type = V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY;
 	ioctl(-1, VIDIOC_G_FMT, p_format);
-	printf("ioctl(-1, VIDIOC_G_FMT"
-	       ", {type=V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY}) ="
-	       " -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {type=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT),
+	       XLAT_ARGS(V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY));
 #endif
 	p_format->type = V4L2_BUF_TYPE_VIDEO_OVERLAY;
 	ioctl(-1, VIDIOC_G_FMT, p_format);
-	printf("ioctl(-1, VIDIOC_G_FMT"
-	       ", {type=V4L2_BUF_TYPE_VIDEO_OVERLAY}) ="
-	       " -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {type=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT),
+	       XLAT_ARGS(V4L2_BUF_TYPE_VIDEO_OVERLAY));
 
 	p_format->type = V4L2_BUF_TYPE_VBI_CAPTURE;
 	ioctl(-1, VIDIOC_G_FMT, p_format);
-	printf("ioctl(-1, VIDIOC_G_FMT"
-	       ", {type=V4L2_BUF_TYPE_VBI_CAPTURE}) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {type=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT),
+	       XLAT_ARGS(V4L2_BUF_TYPE_VBI_CAPTURE));
 #if HAVE_DECL_V4L2_BUF_TYPE_SLICED_VBI_CAPTURE
 	p_format->type = V4L2_BUF_TYPE_SLICED_VBI_CAPTURE;
 	ioctl(-1, VIDIOC_G_FMT, p_format);
-	printf("ioctl(-1, VIDIOC_G_FMT"
-	       ", {type=V4L2_BUF_TYPE_SLICED_VBI_CAPTURE}) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {type=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT),
+	       XLAT_ARGS(V4L2_BUF_TYPE_SLICED_VBI_CAPTURE));
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_SDR_CAPTURE
 	p_format->type = V4L2_BUF_TYPE_SDR_CAPTURE;
 	ioctl(-1, VIDIOC_G_FMT, p_format);
-	printf("ioctl(-1, VIDIOC_G_FMT"
-	       ", {type=V4L2_BUF_TYPE_SDR_CAPTURE}) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {type=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT),
+	       XLAT_ARGS(V4L2_BUF_TYPE_SDR_CAPTURE));
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_SDR_OUTPUT
 	p_format->type = V4L2_BUF_TYPE_SDR_OUTPUT;
 	ioctl(-1, VIDIOC_G_FMT, p_format);
-	printf("ioctl(-1, VIDIOC_G_FMT"
-	       ", {type=V4L2_BUF_TYPE_SDR_OUTPUT}) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {type=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FMT),
+	       XLAT_ARGS(V4L2_BUF_TYPE_SDR_OUTPUT));
 #endif
 	/* VIDIOC_S_FMT */
 	ioctl(-1, VIDIOC_S_FMT, 0);
-	printf("ioctl(-1, VIDIOC_S_FMT, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_FMT));
 
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VIDEO_OUTPUT);
 	ioctl(-1, VIDIOC_S_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_S_FMT", V4L2_BUF_TYPE_VIDEO_OUTPUT);
+	print_ioctl_v4l2(p_format, VIDIOC_S_FMT,
+			 V4L2_BUF_TYPE_VIDEO_OUTPUT);
 #if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE);
 	ioctl(-1, VIDIOC_S_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_S_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_S_FMT,
 			 V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE);
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY);
 	ioctl(-1, VIDIOC_S_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_S_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_S_FMT,
 			 V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY);
 #endif
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VIDEO_OVERLAY);
 	ioctl(-1, VIDIOC_S_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_S_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_S_FMT,
 			 V4L2_BUF_TYPE_VIDEO_OVERLAY);
 
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VBI_CAPTURE);
 	ioctl(-1, VIDIOC_S_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_S_FMT", V4L2_BUF_TYPE_VBI_CAPTURE);
+	print_ioctl_v4l2(p_format, VIDIOC_S_FMT, V4L2_BUF_TYPE_VBI_CAPTURE);
 #if HAVE_DECL_V4L2_BUF_TYPE_SLICED_VBI_CAPTURE
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_SLICED_VBI_CAPTURE);
 	ioctl(-1, VIDIOC_S_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_S_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_S_FMT,
 			 V4L2_BUF_TYPE_SLICED_VBI_CAPTURE);
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_SDR_CAPTURE
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_SDR_CAPTURE);
 	ioctl(-1, VIDIOC_S_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_S_FMT", V4L2_BUF_TYPE_SDR_CAPTURE);
+	print_ioctl_v4l2(p_format, VIDIOC_S_FMT, V4L2_BUF_TYPE_SDR_CAPTURE);
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_SDR_OUTPUT
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_SDR_OUTPUT);
 	ioctl(-1, VIDIOC_S_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_S_FMT", V4L2_BUF_TYPE_SDR_OUTPUT);
+	print_ioctl_v4l2(p_format, VIDIOC_S_FMT, V4L2_BUF_TYPE_SDR_OUTPUT);
 #endif
 	/* VIDIOC_TRY_FMT */
 	ioctl(-1, VIDIOC_TRY_FMT, 0);
-	printf("ioctl(-1, VIDIOC_TRY_FMT, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_TRY_FMT));
 
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VIDEO_OUTPUT);
 	ioctl(-1, VIDIOC_TRY_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_TRY_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_TRY_FMT,
 			 V4L2_BUF_TYPE_VIDEO_OUTPUT);
 #if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE);
 	ioctl(-1, VIDIOC_TRY_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_TRY_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_TRY_FMT,
 			 V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE);
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY);
 	ioctl(-1, VIDIOC_TRY_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_TRY_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_TRY_FMT,
 			 V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY);
 #endif
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VIDEO_OVERLAY);
 	ioctl(-1, VIDIOC_TRY_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_TRY_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_TRY_FMT,
 			 V4L2_BUF_TYPE_VIDEO_OVERLAY);
 
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_VBI_CAPTURE);
 	ioctl(-1, VIDIOC_TRY_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_TRY_FMT", V4L2_BUF_TYPE_VBI_CAPTURE);
+	print_ioctl_v4l2(p_format, VIDIOC_TRY_FMT, V4L2_BUF_TYPE_VBI_CAPTURE);
 #if HAVE_DECL_V4L2_BUF_TYPE_SLICED_VBI_CAPTURE
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_SLICED_VBI_CAPTURE);
 	ioctl(-1, VIDIOC_TRY_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_TRY_FMT",
+	print_ioctl_v4l2(p_format, VIDIOC_TRY_FMT,
 			 V4L2_BUF_TYPE_SLICED_VBI_CAPTURE);
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_SDR_CAPTURE
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_SDR_CAPTURE);
 	ioctl(-1, VIDIOC_TRY_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_TRY_FMT", V4L2_BUF_TYPE_SDR_CAPTURE);
+	print_ioctl_v4l2(p_format, VIDIOC_TRY_FMT, V4L2_BUF_TYPE_SDR_CAPTURE);
 #endif
 #if HAVE_DECL_V4L2_BUF_TYPE_SDR_OUTPUT
 	init_v4l2_format(p_format, V4L2_BUF_TYPE_SDR_OUTPUT);
 	ioctl(-1, VIDIOC_TRY_FMT, p_format);
-	print_ioctl_v4l2(p_format, "VIDIOC_TRY_FMT", V4L2_BUF_TYPE_SDR_OUTPUT);
+	print_ioctl_v4l2(p_format, VIDIOC_TRY_FMT, V4L2_BUF_TYPE_SDR_OUTPUT);
 #endif
 	struct v4l2_format *const p_v4l2_format =
 		page_end - sizeof(*p_v4l2_format);
 	ioctl(-1, VIDIOC_TRY_FMT, p_v4l2_format);
-	printf("ioctl(-1, VIDIOC_TRY_FMT, {type=%#x /* V4L2_BUF_TYPE_??? */})"
-	       " = -1 EBADF (%m)\n", p_v4l2_format->type);
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */") "})"
+	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_TRY_FMT), p_v4l2_format->type);
 
 	/* VIDIOC_REQBUFS */
 	ioctl(-1, VIDIOC_REQBUFS, 0);
-	printf("ioctl(-1, VIDIOC_REQBUFS, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_REQBUFS));
 
 	struct v4l2_requestbuffers *const p_v4l2_requestbuffers =
 		page_end - sizeof(*p_v4l2_requestbuffers);
 	ioctl(-1, VIDIOC_REQBUFS, p_v4l2_requestbuffers);
-	printf("ioctl(-1, VIDIOC_REQBUFS, {type=%#x /* V4L2_BUF_TYPE_??? */, "
-	       "memory=%#x /* V4L2_MEMORY_??? */, count=%u})"
+	printf("ioctl(-1, %s, {type=%#x"
+	       NRAW(" /* V4L2_BUF_TYPE_??? */")
+	       ", memory=%#x" NRAW(" /* V4L2_MEMORY_??? */") ", count=%u})"
 	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_REQBUFS),
 	       p_v4l2_requestbuffers->type,
 	       p_v4l2_requestbuffers->memory,
 	       p_v4l2_requestbuffers->count);
 
 	/* VIDIOC_QUERYBUF */
 	ioctl(-1, VIDIOC_QUERYBUF, 0);
-	printf("ioctl(-1, VIDIOC_QUERYBUF, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QUERYBUF));
 
-	struct v4l2_buffer *const p_v4l2_buffer =
+	kernel_v4l2_buffer_t *const p_v4l2_buffer =
 		page_end - sizeof(*p_v4l2_buffer);
 	ioctl(-1, VIDIOC_QUERYBUF, p_v4l2_buffer);
-	printf("ioctl(-1, VIDIOC_QUERYBUF, {type=%#x /* V4L2_BUF_TYPE_??? */"
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */")
 	       ", index=%u}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QUERYBUF),
 	       p_v4l2_buffer->type, p_v4l2_buffer->index);
 
 	/* VIDIOC_QBUF */
 	ioctl(-1, VIDIOC_QBUF, 0);
-	printf("ioctl(-1, VIDIOC_QBUF, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QBUF));
 
 	ioctl(-1, VIDIOC_QBUF, p_v4l2_buffer);
-	printf("ioctl(-1, VIDIOC_QBUF, {type=%#x /* V4L2_BUF_TYPE_??? */"
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */")
 	       ", index=%u}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QBUF),
 	       p_v4l2_buffer->type, p_v4l2_buffer->index);
 
 	/* VIDIOC_DQBUF */
 	ioctl(-1, VIDIOC_DQBUF, 0);
-	printf("ioctl(-1, VIDIOC_DQBUF, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_DQBUF));
 
 	ioctl(-1, VIDIOC_DQBUF, p_v4l2_buffer);
-	printf("ioctl(-1, VIDIOC_DQBUF, {type=%#x"
-	       " /* V4L2_BUF_TYPE_??? */}) = -1 EBADF (%m)\n",
-	       p_v4l2_buffer->type);
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */")
+	       "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_DQBUF), p_v4l2_buffer->type);
 
 	/* VIDIOC_G_FBUF */
 	ioctl(-1, VIDIOC_G_FBUF, 0);
-	printf("ioctl(-1, VIDIOC_G_FBUF, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FBUF));
 
 	ioctl(-1, VIDIOC_G_FBUF, page);
-	printf("ioctl(-1, VIDIOC_G_FBUF, %p) = -1 EBADF (%m)\n", page);
+	printf("ioctl(-1, %s, %p) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_FBUF), page);
 
 	/* VIDIOC_S_FBUF */
 	ioctl(-1, VIDIOC_S_FBUF, 0);
-	printf("ioctl(-1, VIDIOC_S_FBUF, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_FBUF));
 
 	struct v4l2_framebuffer *const p_v4l2_framebuffer =
 		page_end - sizeof(*p_v4l2_framebuffer);
 	ioctl(-1, VIDIOC_S_FBUF, p_v4l2_framebuffer);
-	printf("ioctl(-1, VIDIOC_S_FBUF, {capability=%#x"
+	printf("ioctl(-1, %s, {capability=%#x"
 	       ", flags=%#x, base=%p}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_FBUF),
 	       p_v4l2_framebuffer->capability,
 	       p_v4l2_framebuffer->flags,
 	       p_v4l2_framebuffer->base);
 
 	/* VIDIOC_STREAMON */
 	ioctl(-1, VIDIOC_STREAMON, 0);
-	printf("ioctl(-1, VIDIOC_STREAMON, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_STREAMON));
 
 	int *const p_int = page_end - sizeof(int);
 	ioctl(-1, VIDIOC_STREAMON, p_int);
-	printf("ioctl(-1, VIDIOC_STREAMON, [%#x /* V4L2_BUF_TYPE_??? */])"
-	       " = -1 EBADF (%m)\n", *p_int);
+	printf("ioctl(-1, %s, [%#x" NRAW(" /* V4L2_BUF_TYPE_??? */") "])"
+	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_STREAMON), *p_int);
 
 	/* VIDIOC_STREAMOFF */
 	ioctl(-1, VIDIOC_STREAMOFF, 0);
-	printf("ioctl(-1, VIDIOC_STREAMOFF, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_STREAMOFF));
 
 	ioctl(-1, VIDIOC_STREAMOFF, p_int);
-	printf("ioctl(-1, VIDIOC_STREAMOFF, [%#x /* V4L2_BUF_TYPE_??? */])"
-	       " = -1 EBADF (%m)\n", *p_int);
+	printf("ioctl(-1, %s, [%#x" NRAW(" /* V4L2_BUF_TYPE_??? */") "])"
+	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_STREAMOFF), *p_int);
 
 	/* VIDIOC_G_PARM */
 	ioctl(-1, VIDIOC_G_PARM, 0);
-	printf("ioctl(-1, VIDIOC_G_PARM, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_PARM));
 
 	struct v4l2_streamparm *const p_v4l2_streamparm =
 		page_end - sizeof(*p_v4l2_streamparm);
 	ioctl(-1, VIDIOC_G_PARM, p_v4l2_streamparm);
-	printf("ioctl(-1, VIDIOC_G_PARM, {type=%#x /* V4L2_BUF_TYPE_??? */})"
-	       " = -1 EBADF (%m)\n", p_v4l2_streamparm->type);
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */") "})"
+	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_PARM), p_v4l2_streamparm->type);
 
 	/* VIDIOC_S_PARM */
 	ioctl(-1, VIDIOC_S_PARM, 0);
-	printf("ioctl(-1, VIDIOC_S_PARM, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_PARM));
 
 	ioctl(-1, VIDIOC_S_PARM, p_v4l2_streamparm);
-	printf("ioctl(-1, VIDIOC_S_PARM, {type=%#x /* V4L2_BUF_TYPE_??? */})"
-	       " = -1 EBADF (%m)\n", p_v4l2_streamparm->type);
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */") "})"
+	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_PARM), p_v4l2_streamparm->type);
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct v4l2_streamparm, p_streamparm);
 	p_streamparm->type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
@@ -633,62 +1005,72 @@ main(void)
 	p_streamparm->parm.capture.timeperframe.numerator = 0xdeadbeef;
 	p_streamparm->parm.capture.timeperframe.denominator = 0xbadc0ded;
 	ioctl(-1, VIDIOC_S_PARM, p_streamparm);
-	printf("ioctl(-1, VIDIOC_S_PARM, {type=V4L2_BUF_TYPE_VIDEO_CAPTURE"
-	       ", parm.capture={capability=V4L2_CAP_TIMEPERFRAME"
-	       ", capturemode=V4L2_MODE_HIGHQUALITY, timeperframe=%u/%u"
-	       ", extendedmode=%u, readbuffers=%u}}) = -1 EBADF (%m)\n",
+	printf("ioctl(-1, %s, {type=" XLAT_FMT
+	       ", parm.capture={capability=" XLAT_FMT
+	       ", capturemode=" XLAT_FMT ", timeperframe=%u/%u"
+	       ", extendedmode=%#x, readbuffers=%u}}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_PARM), XLAT_ARGS(V4L2_BUF_TYPE_VIDEO_CAPTURE),
+	       XLAT_ARGS(V4L2_CAP_TIMEPERFRAME), XLAT_ARGS(V4L2_MODE_HIGHQUALITY),
 	       p_streamparm->parm.capture.timeperframe.numerator,
 	       p_streamparm->parm.capture.timeperframe.denominator, -1U, -1U);
 
 	p_streamparm->type = V4L2_BUF_TYPE_VIDEO_OUTPUT;
 	p_streamparm->parm.output.outputmode = 0;
 	ioctl(-1, VIDIOC_S_PARM, p_streamparm);
-	printf("ioctl(-1, VIDIOC_S_PARM, {type=V4L2_BUF_TYPE_VIDEO_OUTPUT"
-	       ", parm.output={capability=V4L2_CAP_TIMEPERFRAME"
+	printf("ioctl(-1, %s, {type=" XLAT_FMT
+	       ", parm.output={capability=" XLAT_FMT
 	       ", outputmode=0, timeperframe=%u/%u"
-	       ", extendedmode=%u, writebuffers=%u}}) = -1 EBADF (%m)\n",
+	       ", extendedmode=%#x, writebuffers=%u}}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_PARM), XLAT_ARGS(V4L2_BUF_TYPE_VIDEO_OUTPUT),
+	       XLAT_ARGS(V4L2_CAP_TIMEPERFRAME),
 	       p_streamparm->parm.output.timeperframe.numerator,
 	       p_streamparm->parm.output.timeperframe.denominator, -1U, -1U);
 
 	/* VIDIOC_G_STD */
 	ioctl(-1, VIDIOC_G_STD, 0);
-	printf("ioctl(-1, VIDIOC_G_STD, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_STD));
 
 	ioctl(-1, VIDIOC_G_STD, page);
-	printf("ioctl(-1, VIDIOC_G_STD, %p) = -1 EBADF (%m)\n", page);
+	printf("ioctl(-1, %s, %p) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_STD), page);
 
 	/* VIDIOC_S_STD */
 	ioctl(-1, VIDIOC_S_STD, 0);
-	printf("ioctl(-1, VIDIOC_S_STD, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_STD));
 
 	long long *const p_longlong = page_end - sizeof(*p_longlong);
 	ioctl(-1, VIDIOC_S_STD, p_longlong);
-	printf("ioctl(-1, VIDIOC_S_STD, [%#llx]) = -1 EBADF (%m)\n",
-	       *p_longlong);
+	printf("ioctl(-1, %s, [%#llx]) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_STD), *p_longlong);
 
 	/* VIDIOC_ENUMSTD */
 	ioctl(-1, VIDIOC_ENUMSTD, 0);
-	printf("ioctl(-1, VIDIOC_ENUMSTD, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUMSTD));
 
 	struct v4l2_standard *const p_v4l2_standard =
 		page_end - sizeof(*p_v4l2_standard);
 	ioctl(-1, VIDIOC_ENUMSTD, p_v4l2_standard);
-	printf("ioctl(-1, VIDIOC_ENUMSTD, {index=%u}) = -1 EBADF (%m)\n",
-	       p_v4l2_standard->index);
+	printf("ioctl(-1, %s, {index=%u}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUMSTD), p_v4l2_standard->index);
 
 	/* VIDIOC_ENUMINPUT */
 	ioctl(-1, VIDIOC_ENUMINPUT, 0);
-	printf("ioctl(-1, VIDIOC_ENUMINPUT, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUMINPUT));
 
 	struct v4l2_input *const p_v4l2_input =
 		page_end - sizeof(*p_v4l2_input);
 	ioctl(-1, VIDIOC_ENUMINPUT, p_v4l2_input);
-	printf("ioctl(-1, VIDIOC_ENUMINPUT, {index=%u}) = -1 EBADF (%m)\n",
-	       p_v4l2_input->index);
+	printf("ioctl(-1, %s, {index=%u}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUMINPUT), p_v4l2_input->index);
 
 	/* VIDIOC_G_CTRL */
 	ioctl(-1, VIDIOC_G_CTRL, 0);
-	printf("ioctl(-1, VIDIOC_G_CTRL, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_CTRL));
 
 	static const struct v4l2_control v4l2_control_vals[] = {
 		{ .id = 0,                    .value = 3141592653U },
@@ -699,55 +1081,59 @@ main(void)
 		{ .id = 0xa40000,             .value = -1 },
 	};
 	static const char *id_strs[] = {
-		"0 /* V4L2_CID_??? */",
-		"0x97abcd /* V4L2_CID_??? */",
-		"V4L2_CTRL_CLASS_USER+0",
-		"V4L2_CID_MPEG_VIDEO_H264_CPB_SIZE",
-		"V4L2_CTRL_CLASS_DETECT+0x1234",
-		"0xa40000 /* V4L2_CID_??? */",
+		"0" NRAW(" /* V4L2_CID_??? */"),
+		"0x97abcd" NRAW(" /* V4L2_CID_??? */"),
+		XLAT_KNOWN(0x980000, "V4L2_CTRL_CLASS_USER+0"),
+		XLAT_KNOWN(0x990a64, "V4L2_CID_MPEG_VIDEO_H264_CPB_SIZE"),
+		XLAT_KNOWN(0xa31234, "V4L2_CTRL_CLASS_DETECT+0x1234"),
+		"0xa40000" NRAW(" /* V4L2_CID_??? */"),
 	};
 
 	struct v4l2_control *const p_v4l2_control =
 		page_end - sizeof(*p_v4l2_control);
 	ioctl(-1, VIDIOC_G_CTRL, p_v4l2_control);
-	printf("ioctl(-1, VIDIOC_G_CTRL, {id=%#x /* V4L2_CID_??? */})"
-	       " = -1 EBADF (%m)\n", p_v4l2_control->id);
+	printf("ioctl(-1, %s, {id=%#x" NRAW(" /* V4L2_CID_??? */")
+	       "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_CTRL), p_v4l2_control->id);
 
 	/* VIDIOC_S_CTRL */
 	ioctl(-1, VIDIOC_S_CTRL, 0);
-	printf("ioctl(-1, VIDIOC_S_CTRL, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_CTRL));
 
 	ioctl(-1, VIDIOC_S_CTRL, p_v4l2_control);
-	printf("ioctl(-1, VIDIOC_S_CTRL, {id=%#x /* V4L2_CID_??? */"
+	printf("ioctl(-1, %s, {id=%#x" NRAW(" /* V4L2_CID_??? */")
 	       ", value=%d}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_CTRL),
 	       p_v4l2_control->id, p_v4l2_control->value);
 
 	for (size_t i = 0; i < ARRAY_SIZE(id_strs); i++) {
 		struct v4l2_control v4l2_c = v4l2_control_vals[i];
 
 		ioctl(-1, VIDIOC_G_CTRL, &v4l2_c);
-		printf("ioctl(-1, VIDIOC_G_CTRL, {id=%s}) = -1 EBADF (%m)\n",
-		       id_strs[i]);
+		printf("ioctl(-1, %s, {id=%s}) = -1 EBADF (%m)\n",
+		       XLAT_STR(VIDIOC_G_CTRL), id_strs[i]);
 
 		ioctl(-1, VIDIOC_S_CTRL, &v4l2_c);
-		printf("ioctl(-1, VIDIOC_S_CTRL, {id=%s, value=%d})"
-		       " = -1 EBADF (%m)\n",
-		       id_strs[i], v4l2_c.value);
+		printf("ioctl(-1, %s, {id=%s, value=%d}) = -1 EBADF (%m)\n",
+		       XLAT_STR(VIDIOC_S_CTRL), id_strs[i], v4l2_c.value);
 	}
 
 	/* VIDIOC_G_TUNER */
 	ioctl(-1, VIDIOC_G_TUNER, 0);
-	printf("ioctl(-1, VIDIOC_G_TUNER, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_TUNER));
 
 	struct v4l2_tuner *const p_v4l2_tuner =
 		page_end - sizeof(*p_v4l2_tuner);
 	ioctl(-1, VIDIOC_G_TUNER, p_v4l2_tuner);
-	printf("ioctl(-1, VIDIOC_G_TUNER, {index=%u})"
-	       " = -1 EBADF (%m)\n", p_v4l2_tuner->index);
+	printf("ioctl(-1, %s, {index=%u}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_TUNER), p_v4l2_tuner->index);
 
 	/* VIDIOC_S_TUNER */
 	ioctl(-1, VIDIOC_S_TUNER, 0);
-	printf("ioctl(-1, VIDIOC_S_TUNER, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_TUNER));
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct v4l2_tuner, p_tuner);
 	p_tuner->index = 0x4fb6df39;
@@ -761,79 +1147,98 @@ main(void)
 	p_tuner->signal = 0x10bf92c8;
 	p_tuner->afc = 0x3bf7e18b;
 	ioctl(-1, VIDIOC_S_TUNER, p_tuner);
-	printf("ioctl(-1, VIDIOC_S_TUNER, {index=%u"
-	       ", name=\"cum tacent clamant\""
-	       ", type=V4L2_TUNER_RADIO, capability=V4L2_TUNER_CAP_LOW"
+	printf("ioctl(-1, %s, {index=%u, name=\"cum tacent clamant\""
+	       ", type=" XLAT_FMT ", capability=" XLAT_FMT
 	       ", rangelow=%u, rangehigh=%u"
-	       ", rxsubchans=V4L2_TUNER_SUB_MONO"
-	       ", audmode=V4L2_TUNER_MODE_MONO, signal=%d, afc=%d"
-	       "}) = -1 EBADF (%m)\n",
-	       p_tuner->index, p_tuner->rangelow,
-	       p_tuner->rangehigh, p_tuner->signal, p_tuner->afc);
+	       ", rxsubchans=" XLAT_FMT ", audmode=" XLAT_FMT
+	       ", signal=%d, afc=%d}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_TUNER), p_tuner->index,
+	       XLAT_ARGS(V4L2_TUNER_RADIO), XLAT_ARGS(V4L2_TUNER_CAP_LOW),
+	       p_tuner->rangelow, p_tuner->rangehigh,
+	       XLAT_ARGS(V4L2_TUNER_SUB_MONO), XLAT_ARGS(V4L2_TUNER_MODE_MONO),
+	       p_tuner->signal, p_tuner->afc);
 
 	/* VIDIOC_QUERYCTRL */
 	ioctl(-1, VIDIOC_QUERYCTRL, 0);
-	printf("ioctl(-1, VIDIOC_QUERYCTRL, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QUERYCTRL));
 
 	struct v4l2_queryctrl *const p_v4l2_queryctrl =
 		page_end - sizeof(*p_v4l2_queryctrl);
 	ioctl(-1, VIDIOC_QUERYCTRL, p_v4l2_queryctrl);
-#ifdef V4L2_CTRL_FLAG_NEXT_CTRL
-	printf("ioctl(-1, VIDIOC_QUERYCTRL, {id=V4L2_CTRL_FLAG_NEXT_CTRL"
-	       "|%#x /* V4L2_CID_??? */}) = -1 EBADF (%m)\n",
-	       p_v4l2_queryctrl->id & ~V4L2_CTRL_FLAG_NEXT_CTRL);
+	printf("ioctl(-1, %s, {id="
+#if XLAT_RAW
+	      "%#x"
+#else
+	       XLAT_FMT "|%#x /* V4L2_CID_??? */"
+#endif
+	       "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QUERYCTRL),
+#if XLAT_RAW
+	       p_v4l2_queryctrl->id
 #else
-	printf("ioctl(-1, VIDIOC_QUERYCTRL, {id=%#x /* V4L2_CID_??? */})"
-	       " = -1 EBADF (%m)\n", p_v4l2_queryctrl->id);
+	       XLAT_ARGS(V4L2_CTRL_FLAG_NEXT_CTRL),
+	       p_v4l2_queryctrl->id & ~V4L2_CTRL_FLAG_NEXT_CTRL
 #endif
+	       );
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct v4l2_queryctrl, p_queryctrl);
 	p_queryctrl->id = V4L2_CID_SATURATION;
 	ioctl(-1, VIDIOC_QUERYCTRL, p_queryctrl);
-	printf("ioctl(-1, VIDIOC_QUERYCTRL, {id=V4L2_CID_SATURATION})"
-	       " = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, {id=" XLAT_FMT "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_QUERYCTRL), XLAT_ARGS(V4L2_CID_SATURATION));
 
 	/* VIDIOC_G_INPUT */
 	ioctl(-1, VIDIOC_G_INPUT, 0);
-	printf("ioctl(-1, VIDIOC_G_INPUT, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_INPUT));
 
 	ioctl(-1, VIDIOC_G_INPUT, page);
-	printf("ioctl(-1, VIDIOC_G_INPUT, %p) = -1 EBADF (%m)\n", page);
+	printf("ioctl(-1, %s, %p) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_INPUT), page);
 
 	/* VIDIOC_S_INPUT */
 	ioctl(-1, VIDIOC_S_INPUT, 0);
-	printf("ioctl(-1, VIDIOC_S_INPUT, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_INPUT));
 
 	ioctl(-1, VIDIOC_S_INPUT, p_int);
-	printf("ioctl(-1, VIDIOC_S_INPUT, [%u]) = -1 EBADF (%m)\n", *p_int);
+	printf("ioctl(-1, %s, [%u]) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_INPUT), *p_int);
 
 	/* VIDIOC_CROPCAP */
 	ioctl(-1, VIDIOC_CROPCAP, 0);
-	printf("ioctl(-1, VIDIOC_CROPCAP, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_CROPCAP));
 
 	struct v4l2_cropcap *const p_v4l2_cropcap =
 		page_end - sizeof(*p_v4l2_cropcap);
 	ioctl(-1, VIDIOC_CROPCAP, p_v4l2_cropcap);
-	printf("ioctl(-1, VIDIOC_CROPCAP, {type=%#x /* V4L2_BUF_TYPE_??? */})"
-	       " = -1 EBADF (%m)\n", p_v4l2_cropcap->type);
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */") "})"
+	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_CROPCAP), p_v4l2_cropcap->type);
 
 	/* VIDIOC_G_CROP */
 	ioctl(-1, VIDIOC_G_CROP, 0);
-	printf("ioctl(-1, VIDIOC_G_CROP, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_CROP));
 
 	struct v4l2_crop *const p_v4l2_crop =
 		page_end - sizeof(*p_v4l2_crop);
 	ioctl(-1, VIDIOC_G_CROP, p_v4l2_crop);
-	printf("ioctl(-1, VIDIOC_G_CROP, {type=%#x /* V4L2_BUF_TYPE_??? */})"
-	       " = -1 EBADF (%m)\n", p_v4l2_crop->type);
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */") "})"
+	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_CROP), p_v4l2_crop->type);
 
 	/* VIDIOC_S_CROP */
 	ioctl(-1, VIDIOC_S_CROP, 0);
-	printf("ioctl(-1, VIDIOC_S_CROP, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_CROP));
 
 	ioctl(-1, VIDIOC_S_CROP, p_v4l2_crop);
-	printf("ioctl(-1, VIDIOC_S_CROP, {type=%#x /* V4L2_BUF_TYPE_??? */"
+	printf("ioctl(-1, %s, {type=%#x" NRAW(" /* V4L2_BUF_TYPE_??? */")
 	       ", c={left=%d, top=%d, width=%u, height=%u}}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_CROP),
 	       p_v4l2_crop->type,
 	       p_v4l2_crop->c.left,
 	       p_v4l2_crop->c.top,
@@ -843,36 +1248,42 @@ main(void)
 #ifdef VIDIOC_S_EXT_CTRLS
 	/* VIDIOC_S_EXT_CTRLS */
 	ioctl(-1, VIDIOC_S_EXT_CTRLS, 0);
-	printf("ioctl(-1, VIDIOC_S_EXT_CTRLS, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_EXT_CTRLS));
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct v4l2_ext_controls, p_ext_controls);
 	p_ext_controls->ctrl_class = V4L2_CTRL_CLASS_USER;
 	p_ext_controls->count = 0;
 	p_ext_controls->controls = (void *) -2UL;
 	ioctl(-1, VIDIOC_S_EXT_CTRLS, p_ext_controls);
-	printf("ioctl(-1, VIDIOC_S_EXT_CTRLS, {ctrl_class=V4L2_CTRL_CLASS_USER"
-	       ", count=%u}) = -1 EBADF (%m)\n", p_ext_controls->count);
+	printf("ioctl(-1, %s, {ctrl_class=" XLAT_FMT ", count=%u})"
+	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_EXT_CTRLS), XLAT_ARGS(V4L2_CTRL_CLASS_USER),
+	       p_ext_controls->count);
 
 	p_ext_controls->ctrl_class = 0x00a30000;
 	p_ext_controls->count = magic;
 	ioctl(-1, VIDIOC_S_EXT_CTRLS, p_ext_controls);
-	printf("ioctl(-1, VIDIOC_S_EXT_CTRLS, {ctrl_class=V4L2_CTRL_CLASS_DETECT"
+	printf("ioctl(-1, %s, {ctrl_class=" XLAT_FMT
 	       ", count=%u, controls=%p}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_EXT_CTRLS), XLAT_ARGS(V4L2_CTRL_CLASS_DETECT),
 	       p_ext_controls->count, p_ext_controls->controls);
 
 	p_ext_controls->ctrl_class = 0x00a40000;
 	p_ext_controls->count = magic;
 	ioctl(-1, VIDIOC_S_EXT_CTRLS, p_ext_controls);
-	printf("ioctl(-1, VIDIOC_S_EXT_CTRLS"
-	       ", {ctrl_class=0xa40000 /* V4L2_CTRL_CLASS_??? */"
+	printf("ioctl(-1, %s"
+	       ", {ctrl_class=0xa40000" NRAW(" /* V4L2_CTRL_CLASS_??? */")
 	       ", count=%u, controls=%p}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_EXT_CTRLS),
 	       p_ext_controls->count, p_ext_controls->controls);
 
 	p_ext_controls->ctrl_class = V4L2_CTRL_CLASS_MPEG;
 	p_ext_controls->count = magic;
 	ioctl(-1, VIDIOC_S_EXT_CTRLS, p_ext_controls);
-	printf("ioctl(-1, VIDIOC_S_EXT_CTRLS, {ctrl_class=V4L2_CTRL_CLASS_MPEG"
+	printf("ioctl(-1, %s, {ctrl_class=" XLAT_FMT
 	       ", count=%u, controls=%p}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_S_EXT_CTRLS), XLAT_ARGS(V4L2_CTRL_CLASS_MPEG),
 	       p_ext_controls->count, p_ext_controls->controls);
 
 # if HAVE_DECL_V4L2_CTRL_TYPE_STRING
@@ -888,107 +1299,132 @@ main(void)
 		tail_alloc(p_ext_controls->controls[1].size);
 
 	ioctl(-1, VIDIOC_S_EXT_CTRLS, p_ext_controls);
-	printf("ioctl(-1, VIDIOC_S_EXT_CTRLS"
-	       ", {ctrl_class=V4L2_CTRL_CLASS_MPEG, count=%u, controls="
-	       "[{id=V4L2_CID_BRIGHTNESS, size=0, value=%d, value64=%lld}"
-	       ", {id=V4L2_CID_CONTRAST, size=2, string=\"\\377\\377\"}"
-	       "] => controls="
-	       "[{id=V4L2_CID_BRIGHTNESS, size=0, value=%d, value64=%lld}"
-	       ", {id=V4L2_CID_CONTRAST, size=2, string=\"\\377\\377\"}"
+	printf("ioctl(-1, %s, {ctrl_class=" XLAT_FMT ", count=%u, controls="
+	       "[{id=" XLAT_FMT ", size=0, value=%d, value64=%lld}"
+	       ", {id=" XLAT_FMT ", size=2, string=\"\\377\\377\"}"
+	       "]} => {controls="
+	       "[{id=" XLAT_FMT ", size=0, value=%d, value64=%lld}"
+	       ", {id=" XLAT_FMT ", size=2, string=\"\\377\\377\"}"
 	       "], error_idx=%u}) = -1 EBADF (%m)\n",
-	       p_ext_controls->count,
+	       XLAT_STR(VIDIOC_S_EXT_CTRLS), XLAT_ARGS(V4L2_CTRL_CLASS_MPEG),
+	       p_ext_controls->count, XLAT_ARGS(V4L2_CID_BRIGHTNESS),
 	       p_ext_controls->controls[0].value,
 	       (long long) p_ext_controls->controls[0].value64,
+	       XLAT_ARGS(V4L2_CID_CONTRAST), XLAT_ARGS(V4L2_CID_BRIGHTNESS),
 	       p_ext_controls->controls[0].value,
 	       (long long) p_ext_controls->controls[0].value64,
-	       p_ext_controls->error_idx);
+	       XLAT_ARGS(V4L2_CID_CONTRAST), p_ext_controls->error_idx);
 
 	++p_ext_controls->count;
 	ioctl(-1, VIDIOC_S_EXT_CTRLS, p_ext_controls);
-	printf("ioctl(-1, VIDIOC_S_EXT_CTRLS"
-	       ", {ctrl_class=V4L2_CTRL_CLASS_MPEG, count=%u, controls="
-	       "[{id=V4L2_CID_BRIGHTNESS, size=0, value=%d, value64=%lld}"
-	       ", {id=V4L2_CID_CONTRAST, size=2, string=\"\\377\\377\"}"
+	printf("ioctl(-1, %s, {ctrl_class=" XLAT_FMT ", count=%u, controls="
+	       "[{id=" XLAT_FMT ", size=0, value=%d, value64=%lld}"
+	       ", {id=" XLAT_FMT ", size=2, string=\"\\377\\377\"}"
 	       ", ... /* %p */]}) = -1 EBADF (%m)\n",
-	       p_ext_controls->count,
+	       XLAT_STR(VIDIOC_S_EXT_CTRLS), XLAT_ARGS(V4L2_CTRL_CLASS_MPEG),
+	       p_ext_controls->count, XLAT_ARGS(V4L2_CID_BRIGHTNESS),
 	       p_ext_controls->controls[0].value,
 	       (long long) p_ext_controls->controls[0].value64,
-	       p_ext_controls->controls + 2);
+	       XLAT_ARGS(V4L2_CID_CONTRAST), p_ext_controls->controls + 2);
 # endif /* HAVE_DECL_V4L2_CTRL_TYPE_STRING */
 
 	/* VIDIOC_TRY_EXT_CTRLS */
 	ioctl(-1, VIDIOC_TRY_EXT_CTRLS, 0);
-	printf("ioctl(-1, VIDIOC_TRY_EXT_CTRLS, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_TRY_EXT_CTRLS));
 
 	p_ext_controls->ctrl_class = V4L2_CTRL_CLASS_USER;
 	p_ext_controls->count = magic;
 	p_ext_controls->controls = (void *) -2UL;
 	ioctl(-1, VIDIOC_TRY_EXT_CTRLS, p_ext_controls);
-	printf("ioctl(-1, VIDIOC_TRY_EXT_CTRLS"
-	       ", {ctrl_class=V4L2_CTRL_CLASS_USER, count=%u, controls=%p})"
+	printf("ioctl(-1, %s, {ctrl_class=" XLAT_FMT ", count=%u, controls=%p})"
 	       " = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_TRY_EXT_CTRLS), XLAT_ARGS(V4L2_CTRL_CLASS_USER),
 	       p_ext_controls->count, p_ext_controls->controls);
 
 	/* VIDIOC_G_EXT_CTRLS */
 	ioctl(-1, VIDIOC_G_EXT_CTRLS, 0);
-	printf("ioctl(-1, VIDIOC_G_EXT_CTRLS, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_EXT_CTRLS));
 
 	ioctl(-1, VIDIOC_G_EXT_CTRLS, p_ext_controls);
-	printf("ioctl(-1, VIDIOC_G_EXT_CTRLS"
-	       ", {ctrl_class=V4L2_CTRL_CLASS_USER, count=%u, controls=%p"
+	printf("ioctl(-1, %s, {ctrl_class=" XLAT_FMT ", count=%u, controls=%p"
 	       ", error_idx=%u}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_G_EXT_CTRLS), XLAT_ARGS(V4L2_CTRL_CLASS_USER),
 	       p_ext_controls->count, p_ext_controls->controls,
 	       p_ext_controls->error_idx);
 #endif /* VIDIOC_S_EXT_CTRLS */
 
-#ifdef VIDIOC_ENUM_FRAMESIZES
+#ifdef HAVE_STRUCT_V4L2_FRMSIZEENUM
 	ioctl(-1, VIDIOC_ENUM_FRAMESIZES, 0);
-	printf("ioctl(-1, VIDIOC_ENUM_FRAMESIZES, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMESIZES));
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct v4l2_frmsizeenum, p_frmsizeenum);
 	p_frmsizeenum->index = magic;
 	p_frmsizeenum->pixel_format = fourcc(cc[0], cc[1], cc[2], cc[3]);
 
 	ioctl(-1, VIDIOC_ENUM_FRAMESIZES, p_frmsizeenum);
-	printf("ioctl(-1, VIDIOC_ENUM_FRAMESIZES, {index=%u"
-	       ", pixel_format=v4l2_fourcc('%c', '\\%c', '\\%c', '\\x%x')})"
-	       " = -1 EBADF (%m)\n", p_frmsizeenum->index,
-	       cc[0], cc[1], cc[2], cc[3]);
-#endif /* VIDIOC_ENUM_FRAMESIZES */
+	printf("ioctl(-1, %s, {index=%u, pixel_format="
+# if XLAT_RAW
+	       "0x%hhx%hhx%hhx%hhx"
+# else /* !XLAT_RAW */
+	       "v4l2_fourcc('%c', '\\%c', '\\%c', '\\x%x')"
+# endif /* XLAT_RAW */
+	       "}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMESIZES), p_frmsizeenum->index,
+# if XLAT_RAW
+	       cc[3], cc[2], cc[1], cc[0]
+# else /* !XLAT_RAW */
+	       cc[0], cc[1], cc[2], cc[3]
+# endif /* XLAT_RAW */
+	       );
+#endif /* HAVE_STRUCT_V4L2_FRMSIZEENUM */
 
-#ifdef VIDIOC_ENUM_FRAMEINTERVALS
+#ifdef HAVE_STRUCT_V4L2_FRMIVALENUM
 	ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, 0);
-	printf("ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMEINTERVALS));
 
 	struct v4l2_frmivalenum *const p_v4l2_frmivalenum =
 		page_end - sizeof(*p_v4l2_frmivalenum);
 	ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, p_v4l2_frmivalenum);
-	printf("ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, {index=%u"
-	       ", pixel_format=v4l2_fourcc('\\x%x', '\\x%x', '\\x%x', '\\x%x')"
+	printf("ioctl(-1, %s, {index=%u, pixel_format="
+# if XLAT_RAW
+	       "%#x"
+# else /* !XLAT_RAW */
+	       "v4l2_fourcc('\\x%x', '\\x%x', '\\x%x', '\\x%x')"
+# endif /* XLAT_RAW */
 	       ", width=%u, height=%u}) = -1 EBADF (%m)\n",
-	       p_v4l2_frmivalenum->index,
+	       XLAT_STR(VIDIOC_ENUM_FRAMEINTERVALS), p_v4l2_frmivalenum->index,
+# if XLAT_RAW
+	       p_v4l2_frmivalenum->pixel_format,
+# else /* !XLAT_RAW */
 	       cc0(p_v4l2_frmivalenum->pixel_format),
 	       cc1(p_v4l2_frmivalenum->pixel_format),
 	       cc2(p_v4l2_frmivalenum->pixel_format),
 	       cc3(p_v4l2_frmivalenum->pixel_format),
+# endif /* XLAT_RAW */
 	       p_v4l2_frmivalenum->width,
 	       p_v4l2_frmivalenum->height);
-#endif /* VIDIOC_ENUM_FRAMEINTERVALS */
+#endif /* HAVE_STRUCT_V4L2_FRMIVALENUM */
 
-#ifdef VIDIOC_CREATE_BUFS
+#ifdef HAVE_STRUCT_V4L2_CREATE_BUFFERS
 	ioctl(-1, VIDIOC_CREATE_BUFS, 0);
-	printf("ioctl(-1, VIDIOC_CREATE_BUFS, NULL) = -1 EBADF (%m)\n");
+	printf("ioctl(-1, %s, NULL) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_CREATE_BUFS));
 
 	struct v4l2_create_buffers *const p_v4l2_create_buffers =
 		page_end - sizeof(*p_v4l2_create_buffers);
 	ioctl(-1, VIDIOC_CREATE_BUFS, p_v4l2_create_buffers);
-	printf("ioctl(-1, VIDIOC_CREATE_BUFS, {count=%u, memory=%#x"
-	       " /* V4L2_MEMORY_??? */, format={type=%#x"
-	       " /* V4L2_BUF_TYPE_??? */}}) = -1 EBADF (%m)\n",
+	printf("ioctl(-1, %s, {count=%u, memory=%#x"
+	       NRAW(" /* V4L2_MEMORY_??? */") ", format={type=%#x"
+	       NRAW(" /* V4L2_BUF_TYPE_??? */") "}}) = -1 EBADF (%m)\n",
+	       XLAT_STR(VIDIOC_CREATE_BUFS),
 	       p_v4l2_create_buffers->count,
 	       p_v4l2_create_buffers->memory,
 	       p_v4l2_create_buffers->format.type);
-#endif /* VIDIOC_CREATE_BUFS */
+#endif /* HAVE_STRUCT_V4L2_CREATE_BUFFERS */
 
 	puts("+++ exited with 0 +++");
 	return 0;
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-success.c 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success.c
--- 5.5-3/tests-mx32/ioctl_v4l2-success.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success.c	2020-09-06 08:00:00.000000000 +0000
@@ -0,0 +1,1473 @@
+/*
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+
+#include <stdint.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <sys/ioctl.h>
+#include "kernel_v4l2_types.h"
+
+#define XLAT_MACROS_ONLY
+# include "xlat/v4l2_ioctl_cmds.h"
+#undef XLAT_MACROS_ONLY
+
+static bool
+fill_fmt(struct v4l2_format *f)
+{
+	static struct v4l2_clip *clips;
+
+	switch (f->type) {
+	case V4L2_BUF_TYPE_VIDEO_CAPTURE:
+	case V4L2_BUF_TYPE_VIDEO_OUTPUT:
+		f->fmt.pix.width        = 0xdeadc0de;
+		f->fmt.pix.height       = 0xfeedbeef;
+		f->fmt.pix.pixelformat  = 0xb5315258; /* forurcc_be("XR15") */
+		f->fmt.pix.field = f->type == V4L2_BUF_TYPE_VIDEO_CAPTURE
+			? V4L2_FIELD_ALTERNATE : 0xdec0ded1;
+		f->fmt.pix.bytesperline = 0xbadc0ded;
+		f->fmt.pix.sizeimage    = 0xface1e55;
+		f->fmt.pix.colorspace   = V4L2_COLORSPACE_REC709;
+		break;
+
+	case V4L2_BUF_TYPE_VIDEO_OVERLAY:
+#if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY
+	case V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY:
+#endif
+		f->fmt.win.w.left    = 0xa0a1a2a3;
+		f->fmt.win.w.top     = 0xb0b1b2b3;
+		f->fmt.win.w.width   = 0xc0c1c2c3;
+		f->fmt.win.w.height  = 0xd0d1d2d3;
+		f->fmt.win.field     = f->type == V4L2_BUF_TYPE_VIDEO_OVERLAY
+			? V4L2_FIELD_ANY : 10;
+		f->fmt.win.chromakey = 0xbeefface;
+
+		if (!clips)
+			clips = tail_alloc(sizeof(*clips) * 3);
+		f->fmt.win.clips = clips;
+
+		f->fmt.win.clips[0].c.left   = 0xa4a5a6a7;
+		f->fmt.win.clips[0].c.top    = 0xb4b5b6b7;
+		f->fmt.win.clips[0].c.width  = 0xc4c5c6c7;
+		f->fmt.win.clips[0].c.height = 0xd4d5d6d7;
+		f->fmt.win.clips[0].next     = clips;
+
+		f->fmt.win.clips[1].c.left   = 0xa8a9aaab;
+		f->fmt.win.clips[1].c.top    = 0xb8b9babb;
+		f->fmt.win.clips[1].c.width  = 0xc8c9cacb;
+		f->fmt.win.clips[1].c.height = 0xd8d9dadb;
+
+		f->fmt.win.clips[2].c.left   = 0xacadaeaf;
+		f->fmt.win.clips[2].c.top    = 0xbcbdbebf;
+		f->fmt.win.clips[2].c.width  = 0xcccdcecf;
+		f->fmt.win.clips[2].c.height = 0xdcdddedf;
+		f->fmt.win.clips[2].next     = clips + 1;
+
+		f->fmt.win.clipcount = f->type == V4L2_BUF_TYPE_VIDEO_OVERLAY
+			? 4 : 0;
+		f->fmt.win.bitmap    = f->type == V4L2_BUF_TYPE_VIDEO_OVERLAY
+			? NULL : clips;
+		break;
+
+	case V4L2_BUF_TYPE_VBI_CAPTURE:
+	case V4L2_BUF_TYPE_VBI_OUTPUT:
+		f->fmt.vbi.sampling_rate    = 0xdecaffed;
+		f->fmt.vbi.offset           = 0xcafefeed;
+		f->fmt.vbi.samples_per_line = 0xbeefaced;
+		f->fmt.vbi.sample_format    = V4L2_PIX_FMT_RGB555X;
+
+		f->fmt.vbi.start[0] = 0xdec0ded0;
+		f->fmt.vbi.start[1] = 0xdec0ded1;
+		f->fmt.vbi.count[0] = 0xacceded2;
+		f->fmt.vbi.count[1] = 0xacceded3;
+
+		f->fmt.vbi.flags = f->type == V4L2_BUF_TYPE_VBI_CAPTURE
+			? 0x3 : 0x1ce50d1c;
+		break;
+
+#if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE
+	case V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE:
+	case V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE:
+		f->fmt.pix_mp.width        = 0xdeaffade;
+		f->fmt.pix_mp.height       = 0xfadeb1a5;
+		f->fmt.pix_mp.pixelformat  = 0x36314454;
+		f->fmt.pix_mp.field        = V4L2_FIELD_NONE;
+		f->fmt.pix_mp.colorspace   = 13;
+
+		for (size_t i = 0; i < VIDEO_MAX_PLANES; i++) {
+			f->fmt.pix_mp.plane_fmt[i].sizeimage = 0xd0decad0 ^ i;
+			if (sizeof(f->fmt.pix_mp.plane_fmt[i].bytesperline) ==
+			    sizeof(uint32_t)) {
+				f->fmt.pix_mp.plane_fmt[i].bytesperline
+					= 0xd0decad1 ^ i;
+			} else {
+# if WORDS_BIGENDIAN
+				f->fmt.pix_mp.plane_fmt[i].bytesperline
+					= 0xd0de;
+				f->fmt.pix_mp.plane_fmt[i].reserved[0]
+					= 0xcad1 ^ i;
+# else
+				f->fmt.pix_mp.plane_fmt[i].bytesperline
+					= 0xcad1 ^ i;
+				f->fmt.pix_mp.plane_fmt[i].reserved[0]
+					= 0xd0de;
+# endif
+			}
+		}
+
+		f->fmt.pix_mp.num_planes   = f->type ==
+			V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE ? 0xd5 : 0;
+		break;
+#endif
+#if HAVE_DECL_V4L2_BUF_TYPE_SLICED_VBI_CAPTURE
+	case V4L2_BUF_TYPE_SLICED_VBI_CAPTURE:
+	case V4L2_BUF_TYPE_SLICED_VBI_OUTPUT:
+		f->fmt.sliced.service_set = 0xfeed;
+		for (size_t i = 0; i < 2; i++) {
+			for (size_t j = 0; j < 24; j++) {
+				f->fmt.sliced.service_lines[i][j] =
+					0xdead ^ (i << 8) ^ j;
+			}
+		}
+		f->fmt.sliced.io_size = 0xdefaceed;
+		break;
+#endif
+#if HAVE_DECL_V4L2_BUF_TYPE_SDR_CAPTURE
+	case V4L2_BUF_TYPE_SDR_CAPTURE:
+# if HAVE_DECL_V4L2_BUF_TYPE_SDR_OUTPUT
+	case V4L2_BUF_TYPE_SDR_OUTPUT:
+# endif
+		f->fmt.sdr.pixelformat = V4L2_SDR_FMT_CU8;
+# ifdef HAVE_STRUCT_V4L2_SDR_FORMAT_BUFFERSIZE
+		if (sizeof(f->fmt.sdr.buffersize == sizeof(uint32_t)))
+			f->fmt.sdr.buffersize = 0xbadc0ded;
+		else
+			((uint32_t *) &f->fmt.sdr)[1] = 0xbadc0ded;
+# else
+		((uint32_t *) &f->fmt.sdr)[1] = 0xbadc0ded;
+# endif
+		break;
+#endif
+	default:
+		return false;
+	}
+
+	return true;
+}
+
+static void
+print_fmt(const char *pfx, struct v4l2_format *f)
+{
+	switch (f->type) {
+	case V4L2_BUF_TYPE_VIDEO_CAPTURE:
+	case V4L2_BUF_TYPE_VIDEO_OUTPUT:
+		printf("%sfmt.pix={width=3735929054, height=4276993775"
+		       ", pixelformat=" RAW("0xb5315258")
+		       NRAW("v4l2_fourcc('X', 'R', '1', '\\xb5')"
+		            " /* V4L2_PIX_FMT_XRGB555X */")
+		       ", field=%s, bytesperline=3134983661"
+		       ", sizeimage=4207812181, colorspace="
+		       XLAT_KNOWN(0x3, "V4L2_COLORSPACE_REC709") "}",
+		       pfx, f->type == V4L2_BUF_TYPE_VIDEO_CAPTURE
+			? XLAT_STR(V4L2_FIELD_ALTERNATE)
+			: XLAT_UNKNOWN(0xdec0ded1, "V4L2_FIELD_???"));
+		break;
+
+	case V4L2_BUF_TYPE_VIDEO_OVERLAY:
+#if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY
+	case V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY:
+#endif
+		printf("%sfmt.win={left=-1600019805, top=-1330531661"
+		       ", width=3233923779, height=3503411923, field=%s"
+		       ", chromakey=0xbeefface, clips=[",
+		       pfx, f->type == V4L2_BUF_TYPE_VIDEO_OVERLAY
+			? XLAT_STR(V4L2_FIELD_ANY)
+			: XLAT_UNKNOWN(0xa, "V4L2_FIELD_???"));
+		if (f->type == V4L2_BUF_TYPE_VIDEO_OVERLAY) {
+			printf("{left=-1532647769, top=-1263159625"
+			       ", width=3301295815, height=3570783959}, "
+			       "{left=-1465275733, top=-1195787589"
+			       ", width=3368667851, height=3638155995}, "
+			       "{left=-1397903697, top=-1128415553"
+			       ", width=3436039887, height=3705528031}, "
+			       "... /* %p */", f->fmt.win.clips + 3);
+		}
+		printf("], clipcount=%d, bitmap=",
+		       f->type == V4L2_BUF_TYPE_VIDEO_OVERLAY ? 4 : 0);
+
+		if (f->type == V4L2_BUF_TYPE_VIDEO_OVERLAY)
+			printf("NULL");
+		else
+			printf("%p", f->fmt.win.bitmap);
+
+#ifdef HAVE_STRUCT_V4L2_WINDOW_GLOBAL_ALPHA
+		printf(", global_alpha=%#hhx}", f->fmt.win.global_alpha);
+#else
+		struct win_ga {
+			struct v4l2_rect w;
+			uint32_t field;
+			uint32_t chromakey;
+			struct v4l2_clip *clips;
+			uint32_t clipcount;
+			void *bitmap;
+			uint8_t global_alpha;
+		};
+		printf(", global_alpha=%#hhx}",
+		       ((struct win_ga *) &f->fmt.win)->global_alpha);
+#endif
+		break;
+
+	case V4L2_BUF_TYPE_VBI_CAPTURE:
+	case V4L2_BUF_TYPE_VBI_OUTPUT:
+		printf("%sfmt.vbi={sampling_rate=3737845741, offset=3405709037"
+		       ", samples_per_line=3203378413, sample_format="
+		       RAW("0x51424752") NRAW("v4l2_fourcc('R', 'G', 'B', 'Q')"
+		       " /* V4L2_PIX_FMT_RGB555X */")
+		       ", start=[-557785392, -557785391]"
+		       ", count=[2899238610, 2899238611], flags=%s}",
+		       pfx, f->type == V4L2_BUF_TYPE_VBI_CAPTURE
+			? XLAT_KNOWN(0x3, "V4L2_VBI_UNSYNC|V4L2_VBI_INTERLACED")
+			: XLAT_UNKNOWN(0x1ce50d1c, "V4L2_VBI_???"));
+		break;
+
+#if HAVE_DECL_V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE
+	case V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE:
+	case V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE:
+		printf("%sfmt.pix_mp={width=3736074974, height=4208898469"
+		       ", pixelformat=" RAW("0x36314454")
+		       NRAW("v4l2_fourcc('T', 'D', '1', '6')")
+		       ", field=%s, colorspace=0xd"
+		       NRAW(" /* V4L2_COLORSPACE_??? */") ", plane_fmt=[",
+		       pfx, XLAT_STR(V4L2_FIELD_NONE));
+		if (f->type == V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE) {
+			printf("{sizeimage=3504261840, bytesperline=3504261841}"
+			", "
+			       "{sizeimage=3504261841, bytesperline=3504261840}"
+			       ", "
+			       "{sizeimage=3504261842, bytesperline=3504261843}"
+			       ", "
+			       "{sizeimage=3504261843, bytesperline=3504261842}"
+			       ", "
+			       "{sizeimage=3504261844, bytesperline=3504261845}"
+			       ", "
+			       "{sizeimage=3504261845, bytesperline=3504261844}"
+			       ", "
+			       "{sizeimage=3504261846, bytesperline=3504261847}"
+			       ", "
+			       "{sizeimage=3504261847, bytesperline=3504261846}"
+			       "], num_planes=213}");
+		} else {
+			printf("], num_planes=0}");
+		}
+		break;
+#endif
+#if HAVE_DECL_V4L2_BUF_TYPE_SLICED_VBI_CAPTURE
+	case V4L2_BUF_TYPE_SLICED_VBI_CAPTURE:
+	case V4L2_BUF_TYPE_SLICED_VBI_OUTPUT:
+		printf("%sfmt.sliced={service_set="
+		       XLAT_UNKNOWN(0xfeed, "V4L2_SLICED_???")
+		       ", io_size=3740978925, service_lines=[[0xdead, 0xdeac"
+		       ", 0xdeaf, 0xdeae, 0xdea9, 0xdea8, 0xdeab, 0xdeaa"
+		       ", 0xdea5, 0xdea4, 0xdea7, 0xdea6, 0xdea1, 0xdea0"
+		       ", 0xdea3, 0xdea2, 0xdebd, 0xdebc, 0xdebf, 0xdebe"
+		       ", 0xdeb9, 0xdeb8, 0xdebb, 0xdeba], [0xdfad, 0xdfac"
+		       ", 0xdfaf, 0xdfae, 0xdfa9, 0xdfa8, 0xdfab, 0xdfaa"
+		       ", 0xdfa5, 0xdfa4, 0xdfa7, 0xdfa6, 0xdfa1, 0xdfa0"
+		       ", 0xdfa3, 0xdfa2, 0xdfbd, 0xdfbc, 0xdfbf, 0xdfbe"
+		       ", 0xdfb9, 0xdfb8, 0xdfbb, 0xdfba]]}",
+		       pfx);
+		break;
+#endif
+#if HAVE_DECL_V4L2_BUF_TYPE_SDR_CAPTURE
+	case V4L2_BUF_TYPE_SDR_CAPTURE:
+# if HAVE_DECL_V4L2_BUF_TYPE_SDR_OUTPUT
+	case V4L2_BUF_TYPE_SDR_OUTPUT:
+# endif
+		printf("%sfmt.sdr={pixelformat=" RAW("0x38305543")
+		       NRAW("v4l2_fourcc('C', 'U', '0', '8')"
+			    " /* V4L2_SDR_FMT_CU8 */")
+		       ", buffersize=3134983661}",
+		       pfx);
+		break;
+#endif
+	}
+}
+
+int
+main(int argc, char **argv)
+{
+	unsigned long num_skip;
+	long inject_retval;
+	bool locked = false;
+
+	if (argc == 1)
+		return 0;
+
+	if (argc < 3)
+		error_msg_and_fail("Usage: %s NUM_SKIP INJECT_RETVAL", argv[0]);
+
+	num_skip = strtoul(argv[1], NULL, 0);
+	inject_retval = strtol(argv[2], NULL, 0);
+
+	if (inject_retval < 0)
+		error_msg_and_fail("Expected non-negative INJECT_RETVAL, "
+				   "but got %ld", inject_retval);
+
+	for (unsigned int i = 0; i < num_skip; i++) {
+		long rc = ioctl(-1, VIDIOC_QUERYCAP, NULL);
+		printf("ioctl(-1, %s, NULL) = %s%s\n",
+		       XLAT_STR(VIDIOC_QUERYCAP), sprintrc(rc),
+		       rc == inject_retval ? " (INJECTED)" : "");
+
+		if (rc != inject_retval)
+			continue;
+
+		locked = true;
+		break;
+	}
+
+	if (!locked)
+		error_msg_and_fail("Hasn't locked on ioctl(-1"
+				   ", VIDIOC_QUERYCAP, NULL) returning %lu",
+				   inject_retval);
+
+
+	/* VIDIOC_QUERYCAP */
+	struct v4l2_capability *caps = tail_alloc(sizeof(*caps));
+
+	fill_memory(caps, sizeof(*caps));
+	caps->capabilities = 0xdeadbeef;
+#ifdef HAVE_STRUCT_V4L2_CAPABILITY_DEVICE_CAPS
+	caps->device_caps = 0xfacefeed;
+#else
+	caps->reserved[0] = 0xfacefeed;
+#endif
+
+	ioctl(-1, VIDIOC_QUERYCAP, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_QUERYCAP), inject_retval);
+
+	ioctl(-1, VIDIOC_QUERYCAP, (char *) caps + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_QUERYCAP), (char *) caps + 1, inject_retval);
+
+	ioctl(-1, VIDIOC_QUERYCAP, caps);
+	printf("ioctl(-1, %s, {driver=", XLAT_STR(VIDIOC_QUERYCAP));
+	print_quoted_cstring((char *) caps->driver, sizeof(caps->driver));
+	printf(", card=");
+	print_quoted_cstring((char *) caps->card, sizeof(caps->card));
+	printf(", bus_info=");
+	print_quoted_cstring((char *) caps->bus_info, sizeof(caps->bus_info));
+	printf(", version="
+#ifdef WORDS_BIGENDIAN
+	       XLAT_KNOWN(0xd0d1d2d3, "KERNEL_VERSION(53457, 210, 211)")
+#else
+	       XLAT_KNOWN(0xd3d2d1d0, "KERNEL_VERSION(54226, 209, 208)")
+#endif
+	       ", capabilities=" XLAT_KNOWN(0xdeadbeef,
+	       "V4L2_CAP_VIDEO_CAPTURE|V4L2_CAP_VIDEO_OUTPUT"
+	       "|V4L2_CAP_VIDEO_OVERLAY|V4L2_CAP_VBI_OUTPUT"
+	       "|V4L2_CAP_SLICED_VBI_CAPTURE|V4L2_CAP_SLICED_VBI_OUTPUT"
+	       "|V4L2_CAP_VIDEO_OUTPUT_OVERLAY|V4L2_CAP_HW_FREQ_SEEK"
+	       "|V4L2_CAP_RDS_OUTPUT|V4L2_CAP_VIDEO_CAPTURE_MPLANE"
+	       "|V4L2_CAP_VIDEO_OUTPUT_MPLANE|V4L2_CAP_VIDEO_M2M"
+	       "|V4L2_CAP_TUNER|V4L2_CAP_RADIO|V4L2_CAP_MODULATOR"
+	       "|V4L2_CAP_EXT_PIX_FORMAT|V4L2_CAP_META_CAPTURE|V4L2_CAP_ASYNCIO"
+	       "|V4L2_CAP_STREAMING|V4L2_CAP_META_OUTPUT|V4L2_CAP_TOUCH"
+	       "|V4L2_CAP_DEVICE_CAPS|0x40000008"));
+	printf(", device_caps=" XLAT_KNOWN(0xfacefeed,
+	       "V4L2_CAP_VIDEO_CAPTURE|V4L2_CAP_VIDEO_OVERLAY"
+	       "|V4L2_CAP_VBI_OUTPUT|V4L2_CAP_SLICED_VBI_CAPTURE"
+	       "|V4L2_CAP_SLICED_VBI_OUTPUT|V4L2_CAP_VIDEO_OUTPUT_OVERLAY"
+	       "|V4L2_CAP_HW_FREQ_SEEK|V4L2_CAP_RDS_OUTPUT"
+	       "|V4L2_CAP_VIDEO_CAPTURE_MPLANE|V4L2_CAP_VIDEO_OUTPUT_MPLANE"
+	       "|V4L2_CAP_VIDEO_M2M_MPLANE|V4L2_CAP_VIDEO_M2M|V4L2_CAP_AUDIO"
+	       "|V4L2_CAP_RADIO|V4L2_CAP_MODULATOR|V4L2_CAP_SDR_OUTPUT"
+	       "|V4L2_CAP_META_CAPTURE|V4L2_CAP_ASYNCIO|V4L2_CAP_META_OUTPUT"
+	       "|V4L2_CAP_TOUCH|V4L2_CAP_DEVICE_CAPS|0x60000008"));
+	printf("}) = %ld (INJECTED)\n", inject_retval);
+
+
+	/* VIDIOC_ENUM_FMT */
+	static const struct strval32 buf_types[] = {
+		{ ARG_XLAT_UNKNOWN(0, "V4L2_BUF_TYPE_???") },
+		{ ARG_XLAT_KNOWN(0x1, "V4L2_BUF_TYPE_VIDEO_CAPTURE") },
+		{ ARG_XLAT_KNOWN(0x2, "V4L2_BUF_TYPE_VIDEO_OUTPUT") },
+		{ ARG_XLAT_KNOWN(0x3, "V4L2_BUF_TYPE_VIDEO_OVERLAY") },
+		{ ARG_XLAT_KNOWN(0x4, "V4L2_BUF_TYPE_VBI_CAPTURE") },
+		{ ARG_XLAT_KNOWN(0x5, "V4L2_BUF_TYPE_VBI_OUTPUT") },
+		{ ARG_XLAT_KNOWN(0x6, "V4L2_BUF_TYPE_SLICED_VBI_CAPTURE") },
+		{ ARG_XLAT_KNOWN(0x7, "V4L2_BUF_TYPE_SLICED_VBI_OUTPUT") },
+		{ ARG_XLAT_KNOWN(0x8, "V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY") },
+		{ ARG_XLAT_KNOWN(0x9, "V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE") },
+		{ ARG_XLAT_KNOWN(0xa, "V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE") },
+		{ ARG_XLAT_KNOWN(0xb, "V4L2_BUF_TYPE_SDR_CAPTURE") },
+		{ ARG_XLAT_KNOWN(0xc, "V4L2_BUF_TYPE_SDR_OUTPUT") },
+		{ ARG_XLAT_KNOWN(0xd, "V4L2_BUF_TYPE_META_CAPTURE") },
+		{ ARG_XLAT_KNOWN(0xe, "V4L2_BUF_TYPE_META_OUTPUT") },
+		{ ARG_XLAT_UNKNOWN(0xf, "V4L2_BUF_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0x80, "V4L2_BUF_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0xbadc0ded, "V4L2_BUF_TYPE_???") },
+	};
+	static const struct strval32 fmtdesc_flags[] = {
+		{ ARG_STR(0) },
+		{ ARG_XLAT_KNOWN(0x1, "V4L2_FMT_FLAG_COMPRESSED") },
+		{ ARG_XLAT_KNOWN(0x3e, "V4L2_FMT_FLAG_EMULATED"
+				       "|V4L2_FMT_FLAG_CONTINUOUS_BYTESTREAM"
+				       "|V4L2_FMT_FLAG_DYN_RESOLUTION"
+				       "|V4L2_FMT_FLAG_ENC_CAP_FRAME_INTERVAL"
+				       "|0x20") },
+		{ ARG_XLAT_UNKNOWN(0xdead0000, "V4L2_FMT_FLAG_???") },
+	};
+	static const struct strval32 fmtdesc_fmts[] = {
+		{ 0x4c47504a, RAW("0x4c47504a")
+			      NRAW("v4l2_fourcc('J', 'P', 'G', 'L')"
+			           " /* V4L2_PIX_FMT_JPGL */") },
+		{ 0xbadc0ded, RAW("0xbadc0ded")
+			      NRAW("v4l2_fourcc('\\xed', '\\x0d', '\\xdc',"
+			           " '\\xba')") },
+	};
+	struct v4l2_fmtdesc *fmtdesc = tail_alloc(sizeof(*fmtdesc));
+
+	fill_memory(fmtdesc, sizeof(*fmtdesc));
+	fmtdesc->index = 0xdeac0de;
+
+	ioctl(-1, VIDIOC_ENUM_FMT, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FMT), inject_retval);
+
+	ioctl(-1, VIDIOC_ENUM_FMT, (char *) fmtdesc + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FMT), (char *) fmtdesc + 1, inject_retval);
+
+	for (size_t i = 0; i < ARRAY_SIZE(buf_types); i++) {
+		for (size_t j = 0; j < ARRAY_SIZE(fmtdesc_flags); j++) {
+			for (size_t k = 0; k < ARRAY_SIZE(fmtdesc_fmts); k++) {
+				fmtdesc->type = buf_types[i].val;
+				fmtdesc->flags = fmtdesc_flags[j].val;
+				fmtdesc->pixelformat = fmtdesc_fmts[k].val;
+
+				ioctl(-1, VIDIOC_ENUM_FMT, fmtdesc);
+				printf("ioctl(-1, %s, {index=233488606, type=%s"
+				       ", flags=%s, description=",
+				       XLAT_STR(VIDIOC_ENUM_FMT),
+				       buf_types[i].str,
+				       fmtdesc_flags[j].str);
+				print_quoted_cstring((char *) fmtdesc->description,
+					sizeof(fmtdesc->description));
+				printf(", pixelformat=%s}) = %ld (INJECTED)\n",
+				       fmtdesc_fmts[k].str, inject_retval);
+
+				fill_memory_ex(fmtdesc->description,
+					       sizeof(fmtdesc->description),
+					       (i * 9 + j) * 7 + k,
+					       (k * 3 + j) * 11 + i + 5);
+			}
+		}
+	}
+
+
+	/* VIDIOC_REQBUFS */
+	static const struct strval32 reqb_mems[] = {
+		{ ARG_XLAT_UNKNOWN(0, "V4L2_MEMORY_???") },
+		{ ARG_XLAT_KNOWN(0x1, "V4L2_MEMORY_MMAP") },
+		{ ARG_XLAT_KNOWN(0x4, "V4L2_MEMORY_DMABUF") },
+		{ ARG_XLAT_UNKNOWN(0x5, "V4L2_MEMORY_???") },
+		{ ARG_XLAT_UNKNOWN(0xbadc0ded, "V4L2_MEMORY_???") },
+	};
+	struct v4l2_requestbuffers *reqb = tail_alloc(sizeof(*reqb));
+
+	fill_memory(reqb, sizeof(*reqb));
+	reqb->count = 0xfeedface;
+
+	ioctl(-1, VIDIOC_REQBUFS, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_REQBUFS), inject_retval);
+
+	ioctl(-1, VIDIOC_REQBUFS, (char *) reqb + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_REQBUFS), (char *) reqb + 1, inject_retval);
+
+	for (size_t i = 0; i < MAX(ARRAY_SIZE(buf_types),
+				   ARRAY_SIZE(reqb_mems)); i++) {
+		reqb->type = buf_types[i % ARRAY_SIZE(buf_types)].val;
+		reqb->memory = reqb_mems[i % ARRAY_SIZE(reqb_mems)].val;
+
+		ioctl(-1, VIDIOC_REQBUFS, reqb);
+		printf("ioctl(-1, %s, {type=%s, memory=%s"
+		       ", count=4277009102 => 4277009102}) = %ld (INJECTED)\n",
+		       XLAT_STR(VIDIOC_REQBUFS),
+		       buf_types[i % ARRAY_SIZE(buf_types)].str,
+		       reqb_mems[i % ARRAY_SIZE(reqb_mems)].str,
+		       inject_retval);
+	}
+
+
+	/* VIDIOC_G_FMT, VIDIOC_S_FMT, VIDIOC_TRY_FMT */
+	static const struct strval32 fmt_cmds[] = {
+		{ ARG_STR(VIDIOC_G_FMT) },
+		{ ARG_STR(VIDIOC_S_FMT) },
+		{ ARG_STR(VIDIOC_TRY_FMT) },
+	};
+
+	struct v4l2_format *fmt = tail_alloc(sizeof(*fmt));
+
+	for (size_t i = 0; i < ARRAY_SIZE(fmt_cmds); i++) {
+		ioctl(-1, fmt_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(fmt_cmds[i].str, fmt_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, fmt_cmds[i].val, (char *) fmt + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(fmt_cmds[i].str, fmt_cmds[i].val, NULL),
+		       (char *) fmt + 1, inject_retval);
+
+		for (size_t j = 0; j < ARRAY_SIZE(buf_types); j++) {
+			fill_memory(fmt, sizeof(*fmt));
+
+			fmt->type = buf_types[j].val;
+			if (!fill_fmt(fmt))
+				continue;
+
+			ioctl(-1, fmt_cmds[i].val, fmt);
+			printf("ioctl(-1, %s, {type=%s",
+			       sprintxlat(fmt_cmds[i].str, fmt_cmds[i].val,
+					  NULL),
+			       buf_types[j].str);
+			print_fmt(", ", fmt);
+			if (fmt_cmds[i].val != VIDIOC_G_FMT &&
+			    buf_types[j].val != V4L2_BUF_TYPE_VIDEO_OVERLAY &&
+			    buf_types[j].val != 8)
+				print_fmt("} => {", fmt);
+			printf("}) = %ld (INJECTED)\n", inject_retval);
+		}
+	}
+
+
+	/* VIDIOC_QUERYBUF, VIDIOC_QBUF, VIDIOC_DQBUF */
+	static const struct strval32 buf_cmds[] = {
+		{ ARG_STR(VIDIOC_QUERYBUF) },
+		{ ARG_STR(VIDIOC_QBUF) },
+		{ ARG_STR(VIDIOC_DQBUF) },
+	};
+
+	kernel_v4l2_buffer_t *buf = tail_alloc(sizeof(*buf));
+
+	for (size_t i = 0; i < ARRAY_SIZE(buf_cmds); i++) {
+		ioctl(-1, buf_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(buf_cmds[i].str, buf_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, buf_cmds[i].val, (char *) buf + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(buf_cmds[i].str, buf_cmds[i].val, NULL),
+		       (char *) buf + 1, inject_retval);
+
+		fill_memory(buf, sizeof(*buf));
+		buf->index     = 0xdeadc0de;
+		buf->type      = V4L2_BUF_TYPE_VIDEO_CAPTURE;
+		buf->bytesused = 0xdecaffee;
+		buf->flags     = 0x1ff; /* TODO: update */
+		buf->field     = V4L2_FIELD_TOP;
+
+		buf->timestamp.tv_sec  = 0x1e55c0de;
+		buf->timestamp.tv_usec = 999999;
+
+		buf->timecode.type = V4L2_TC_TYPE_24FPS;
+		buf->timecode.flags = 0xbeefdeaf;
+
+		buf->memory    = V4L2_MEMORY_MMAP;
+		buf->m.offset  = 0xfacefeed;
+		buf->length    = 0xcafebed5;
+		buf->reserved  = 0xdeefaced;
+
+		ioctl(-1, buf_cmds[i].val, buf);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_KNOWN(0x1, "V4L2_BUF_TYPE_VIDEO_CAPTURE")
+		       ", index=3735929054, memory="
+		       XLAT_KNOWN(0x1, "V4L2_MEMORY_MMAP")
+		       ", m.offset=0xfacefeed, length=3405692629"
+		       ", bytesused=3737845742, flags=" RAW("0x1ff")
+#if !XLAT_RAW
+		       XLAT_KNOWN(0x1ff, "V4L2_BUF_FLAG_MAPPED"
+		       "|V4L2_BUF_FLAG_QUEUED|V4L2_BUF_FLAG_DONE"
+		       "|V4L2_BUF_FLAG_KEYFRAME|V4L2_BUF_FLAG_PFRAME"
+		       "|V4L2_BUF_FLAG_BFRAME|V4L2_BUF_FLAG_ERROR"
+		       "|V4L2_BUF_FLAG_IN_REQUEST|V4L2_BUF_FLAG_TIMECODE") "|"
+		       XLAT_KNOWN(0, "V4L2_BUF_FLAG_TIMESTAMP_UNKNOWN") "|"
+		       XLAT_KNOWN(0, "V4L2_BUF_FLAG_TSTAMP_SRC_EOF")
+#endif
+		       "%s, ...}) = %ld (INJECTED)\n",
+		       sprintxlat(buf_cmds[i].str, buf_cmds[i].val, NULL),
+		       buf_cmds[i].val == VIDIOC_DQBUF
+			? ", timestamp={tv_sec=508936414, tv_usec=999999}" : "",
+		       inject_retval);
+
+		buf->type      = V4L2_BUF_TYPE_VBI_CAPTURE;
+		buf->flags     = 0x268040;
+		buf->field     = 0xb;
+		buf->memory    = V4L2_MEMORY_USERPTR;
+		buf->m.userptr = (long) 0xdefaced0dec0ded1LL;
+
+		ioctl(-1, buf_cmds[i].val, buf);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_KNOWN(0x4, "V4L2_BUF_TYPE_VBI_CAPTURE")
+		       ", index=3735929054, memory="
+		       XLAT_KNOWN(0x2, "V4L2_MEMORY_USERPTR")
+		       ", m.userptr=%p, length=3405692629"
+		       ", bytesused=3737845742, flags=" RAW("0x268040")
+#if !XLAT_RAW
+		       XLAT_KNOWN(0x200040, "V4L2_BUF_FLAG_ERROR|0x200000") "|"
+		       XLAT_UNKNOWN(0x8000, "V4L2_BUF_FLAG_TIMESTAMP_???") "|"
+		       XLAT_UNKNOWN(0x60000, "V4L2_BUF_FLAG_TSTAMP_SRC_???")
+#endif
+		       "%s, ...}) = %ld (INJECTED)\n",
+		       sprintxlat(buf_cmds[i].str, buf_cmds[i].val, NULL),
+		       (void *) (intptr_t) 0xdefaced0dec0ded1LL,
+		       buf_cmds[i].val == VIDIOC_DQBUF
+			? ", timestamp={tv_sec=508936414, tv_usec=999999}" : "",
+		       inject_retval);
+
+		buf->type      = 0x9;
+		buf->flags     = 0;
+
+		ioctl(-1, buf_cmds[i].val, buf);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_KNOWN(0x9, "V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE")
+		       ", index=3735929054, memory="
+		       XLAT_KNOWN(0x2, "V4L2_MEMORY_USERPTR")
+		       ", m.userptr=%p, length=3405692629"
+		       ", bytesused=3737845742, flags=" RAW("0")
+#if !XLAT_RAW
+		       XLAT_KNOWN(0, "V4L2_BUF_FLAG_TIMESTAMP_UNKNOWN") "|"
+		       XLAT_KNOWN(0, "V4L2_BUF_FLAG_TSTAMP_SRC_EOF")
+#endif
+		       "%s, ...}) = %ld (INJECTED)\n",
+		       sprintxlat(buf_cmds[i].str, buf_cmds[i].val, NULL),
+		       (void *) (intptr_t) 0xdefaced0dec0ded1LL,
+		       buf_cmds[i].val == VIDIOC_DQBUF
+			? ", timestamp={tv_sec=508936414, tv_usec=999999}" : "",
+		       inject_retval);
+
+		buf->type      = 0xa;
+		buf->memory    = V4L2_MEMORY_OVERLAY;
+		buf->flags     = 0x2000;
+
+		ioctl(-1, buf_cmds[i].val, buf);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_KNOWN(0xa, "V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE")
+		       ", index=3735929054, memory="
+		       XLAT_KNOWN(0x3, "V4L2_MEMORY_OVERLAY")
+		       ", length=3405692629, bytesused=3737845742"
+		       ", flags=" RAW("0x2000")
+#if !XLAT_RAW
+		       XLAT_KNOWN(0x2000, "V4L2_BUF_FLAG_TIMESTAMP_MONOTONIC")
+		       "|" XLAT_KNOWN(0, "V4L2_BUF_FLAG_TSTAMP_SRC_EOF")
+#endif
+		       "%s, ...}) = %ld (INJECTED)\n",
+		       sprintxlat(buf_cmds[i].str, buf_cmds[i].val, NULL),
+		       buf_cmds[i].val == VIDIOC_DQBUF
+			? ", timestamp={tv_sec=508936414, tv_usec=999999}" : "",
+		       inject_retval);
+	}
+
+
+	/* VIDIOC_G_FBUF, VIDIOC_S_FBUF */
+	static const struct strval32 fbuf_cmds[] = {
+		{ ARG_STR(VIDIOC_G_FBUF) },
+		{ ARG_STR(VIDIOC_S_FBUF) },
+	};
+
+	struct v4l2_framebuffer *fbuf = tail_alloc(sizeof(*fbuf));
+
+	for (size_t i = 0; i < ARRAY_SIZE(fbuf_cmds); i++) {
+		ioctl(-1, fbuf_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(fbuf_cmds[i].str, fbuf_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, fbuf_cmds[i].val, (char *) fbuf + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(fbuf_cmds[i].str, fbuf_cmds[i].val, NULL),
+		       (char *) fbuf + 1, inject_retval);
+
+		fill_memory32(fbuf, sizeof(*fbuf));
+		fbuf->base = NULL;
+
+		ioctl(-1, fbuf_cmds[i].val, fbuf);
+		printf("ioctl(-1, %s, {capability=0x80a0c0e0, flags=0x80a0c0e1"
+		       ", base=NULL}) = %ld (INJECTED)\n",
+		       sprintxlat(fbuf_cmds[i].str, fbuf_cmds[i].val, NULL),
+		       inject_retval);
+	}
+
+
+	/* VIDIOC_G_PARM, VIDIOC_S_PARM */
+	static const struct strval32 sparm_cmds[] = {
+		{ ARG_STR(VIDIOC_G_PARM) },
+		{ ARG_STR(VIDIOC_S_PARM) },
+	};
+
+	struct v4l2_streamparm *sparm = tail_alloc(sizeof(*sparm));
+
+	for (size_t i = 0; i < ARRAY_SIZE(sparm_cmds); i++) {
+		ioctl(-1, sparm_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(sparm_cmds[i].str, sparm_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, sparm_cmds[i].val, (char *) sparm + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(sparm_cmds[i].str, sparm_cmds[i].val, NULL),
+		       (char *) sparm + 1, inject_retval);
+
+		fill_memory32(sparm, sizeof(*sparm));
+
+		ioctl(-1, sparm_cmds[i].val, sparm);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_UNKNOWN(0x80a0c0e0, "V4L2_BUF_TYPE_???")
+		       "}) = %ld (INJECTED)\n",
+		       sprintxlat(sparm_cmds[i].str, sparm_cmds[i].val, NULL),
+		       inject_retval);
+
+		sparm->type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
+
+		static const char *parm_str1 = "parm.capture={capability="
+			XLAT_UNKNOWN(0x80a0c0e1, "V4L2_CAP_???")
+			", capturemode="
+			XLAT_UNKNOWN(0x80a0c0e2, "V4L2_MODE_???")
+			", timeperframe=2158018787/2158018788"
+			", extendedmode=0x80a0c0e5, readbuffers=2158018790}";
+
+		ioctl(-1, sparm_cmds[i].val, sparm);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_KNOWN(0x1, "V4L2_BUF_TYPE_VIDEO_CAPTURE")
+		       ", %s}%s%s%s) = %ld (INJECTED)\n",
+		       sprintxlat(sparm_cmds[i].str, sparm_cmds[i].val, NULL),
+		       parm_str1,
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? " => {" : "",
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? parm_str1 : "",
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? "}" : "",
+		       inject_retval);
+
+		sparm->parm.capture.capability = 0x1000;
+		sparm->parm.capture.capturemode = 0x1;
+
+		static const char *parm_str2 = "parm.capture={capability="
+			XLAT_KNOWN(0x1000, "V4L2_CAP_TIMEPERFRAME")
+			", capturemode="
+			XLAT_KNOWN(0x1, "V4L2_MODE_HIGHQUALITY")
+			", timeperframe=2158018787/2158018788"
+			", extendedmode=0x80a0c0e5, readbuffers=2158018790}";
+
+		ioctl(-1, sparm_cmds[i].val, sparm);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_KNOWN(0x1, "V4L2_BUF_TYPE_VIDEO_CAPTURE")
+		       ", %s}%s%s%s) = %ld (INJECTED)\n",
+		       sprintxlat(sparm_cmds[i].str, sparm_cmds[i].val, NULL),
+		       parm_str2,
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? " => {" : "",
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? parm_str2 : "",
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? "}" : "",
+		       inject_retval);
+
+		sparm->type = 0x9;
+		sparm->parm.capture.capability = 0xdeadbeef;
+		sparm->parm.capture.capturemode = 0xadec0ded;
+
+		ioctl(-1, sparm_cmds[i].val, sparm);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_KNOWN(0x9, "V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE")
+		       "}) = %ld (INJECTED)\n",
+		       sprintxlat(sparm_cmds[i].str, sparm_cmds[i].val, NULL),
+		       inject_retval);
+
+		fill_memory32(sparm, sizeof(*sparm));
+		sparm->type = V4L2_BUF_TYPE_VIDEO_OUTPUT;
+
+		static const char *parm_str3 = "parm.output={capability="
+			XLAT_UNKNOWN(0x80a0c0e1, "V4L2_CAP_???")
+			", outputmode="
+			XLAT_UNKNOWN(0x80a0c0e2, "V4L2_MODE_???")
+			", timeperframe=2158018787/2158018788"
+			", extendedmode=0x80a0c0e5, writebuffers=2158018790}";
+
+		ioctl(-1, sparm_cmds[i].val, sparm);
+		printf("ioctl(-1, %s, {type="
+		       XLAT_KNOWN(0x2, "V4L2_BUF_TYPE_VIDEO_OUTPUT")
+		       ", %s}%s%s%s) = %ld (INJECTED)\n",
+		       sprintxlat(sparm_cmds[i].str, sparm_cmds[i].val, NULL),
+		       parm_str3,
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? " => {" : "",
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? parm_str3 : "",
+		       sparm_cmds[i].val == VIDIOC_S_PARM ? "}" : "",
+		       inject_retval);
+
+	}
+
+
+	/* VIDIOC_G_STD, VIDIOC_S_STD */
+	static const struct strval32 stdid_cmds[] = {
+		{ ARG_STR(VIDIOC_G_STD) },
+		{ ARG_STR(VIDIOC_S_STD) },
+	};
+	static const struct strval64 stdids[] = {
+		{ ARG_STR(0) },
+		{ ARG_STR(0x1) },
+		{ ARG_STR(0xb000) },
+		{ ARG_STR(0x3ffffff) },
+		{ ARG_STR(0xffffffff) },
+		{ ARG_ULL_STR(0xbadc0deddeadface) },
+	};
+
+	v4l2_std_id *stdid = tail_alloc(sizeof(*stdid));
+
+	for (size_t i = 0; i < ARRAY_SIZE(stdid_cmds); i++) {
+		ioctl(-1, stdid_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(stdid_cmds[i].str, stdid_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, stdid_cmds[i].val, (char *) stdid + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(stdid_cmds[i].str, stdid_cmds[i].val, NULL),
+		       (char *) stdid + 1, inject_retval);
+
+		for (size_t j = 0; j < ARRAY_SIZE(stdids); j++) {
+			*stdid = stdids[j].val;
+
+			ioctl(-1, stdid_cmds[i].val, stdid);
+			printf("ioctl(-1, %s, [%s]) = %ld (INJECTED)\n",
+			       sprintxlat(stdid_cmds[i].str, stdid_cmds[i].val, NULL),
+			       stdids[j].str, inject_retval);
+
+		}
+	}
+
+
+	/* VIDIOC_ENUMSTD */
+	struct v4l2_standard *std = tail_alloc(sizeof(*std));
+
+	ioctl(-1, VIDIOC_ENUMSTD, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUMSTD), inject_retval);
+
+	ioctl(-1, VIDIOC_ENUMSTD, (char *) std + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUMSTD), (char *) std + 1, inject_retval);
+
+	for (size_t i = 0; i < ARRAY_SIZE(stdids); i++) {
+		fill_memory32(&std->frameperiod, sizeof(*std) -
+			      offsetof(struct v4l2_standard, frameperiod));
+		fill_memory_ex(std->name, sizeof(std->name), i * 47 + 1, 255);
+		std->index = 0xdeadface;
+		std->id = stdids[i].val;
+
+		ioctl(-1, VIDIOC_ENUMSTD, std);
+		printf("ioctl(-1, %s, {index=3735943886, name=",
+		       XLAT_STR(VIDIOC_ENUMSTD));
+		print_quoted_cstring((char *) std->name, sizeof(std->name));
+		printf(", frameperiod=2158018784/2158018785"
+		       ", framelines=2158018786}) = %ld (INJECTED)\n",
+		       inject_retval);
+	}
+
+
+	/* VIDIOC_ENUMINPUT */
+	static const struct strval32 input_types[] = {
+		{ ARG_XLAT_UNKNOWN(0, "V4L2_INPUT_TYPE_???") },
+		{ V4L2_INPUT_TYPE_TUNER,
+		  XLAT_KNOWN(0x1, "V4L2_INPUT_TYPE_TUNER") },
+		{ V4L2_INPUT_TYPE_CAMERA,
+		  XLAT_KNOWN(0x2, "V4L2_INPUT_TYPE_CAMERA") },
+		{ ARG_XLAT_UNKNOWN(0x4, "V4L2_INPUT_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0xdeadc0de, "V4L2_INPUT_TYPE_???") },
+	};
+
+	struct v4l2_input *input = tail_alloc(sizeof(*input));
+
+	ioctl(-1, VIDIOC_ENUMINPUT, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUMINPUT), inject_retval);
+
+	ioctl(-1, VIDIOC_ENUMINPUT, (char *) input + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUMINPUT), (char *) input + 1, inject_retval);
+
+	for (size_t i = 0; i < ARRAY_SIZE(stdids); i++) {
+		for (size_t j = 0; j < ARRAY_SIZE(input_types); j++) {
+			fill_memory32(input, sizeof(*input));
+			fill_memory_ex(input->name, sizeof(input->name),
+				       i * 47 + 13, 255);
+			input->type = input_types[j].val;
+			input->std = stdids[i].val;
+
+			ioctl(-1, VIDIOC_ENUMINPUT, input);
+			printf("ioctl(-1, %s, {index=2158018784, name=",
+			       XLAT_STR(VIDIOC_ENUMINPUT));
+			print_quoted_cstring((char *) input->name,
+					     sizeof(input->name));
+			printf(", type=%s}) = %ld (INJECTED)\n",
+			       input_types[j].str, inject_retval);
+		}
+	}
+
+
+	/* VIDIOC_G_CTRL, VIDIOC_S_CTRL */
+	static const struct strval32 ctrl_cmds[] = {
+		{ ARG_STR(VIDIOC_G_CTRL) },
+		{ ARG_STR(VIDIOC_S_CTRL) },
+	};
+
+	struct v4l2_control *ctrl = tail_alloc(sizeof(*ctrl));
+
+	for (size_t i = 0; i < ARRAY_SIZE(ctrl_cmds); i++) {
+		ioctl(-1, ctrl_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(ctrl_cmds[i].str, ctrl_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, ctrl_cmds[i].val, (char *) ctrl + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(ctrl_cmds[i].str, ctrl_cmds[i].val, NULL),
+		       (char *) ctrl + 1, inject_retval);
+
+		/* NB: cid printing is mostly tested in ioctl_v4l2.c */
+		fill_memory32(ctrl, sizeof(*ctrl));
+		ioctl(-1, ctrl_cmds[i].val, ctrl);
+		printf("ioctl(-1, %s, {id=0x80a0c0e0"
+		       NRAW(" /* V4L2_CID_??? */")
+		       ", value=-2136948511%s}) = %ld (INJECTED)\n",
+		       sprintxlat(ctrl_cmds[i].str, ctrl_cmds[i].val, NULL),
+		       ctrl_cmds[i].val == VIDIOC_S_CTRL
+			? " => -2136948511" : "",
+		       inject_retval);
+	}
+
+
+	/* VIDIOC_G_TUNER, VIDIOC_S_TUNER */
+	static const struct strval32 tuner_cmds[] = {
+		{ ARG_STR(VIDIOC_G_TUNER) },
+		{ ARG_STR(VIDIOC_S_TUNER) },
+	};
+	static const struct strval32 tuner_types[] = {
+		{ ARG_XLAT_UNKNOWN(0, "V4L2_TUNER_???") },
+		{ ARG_XLAT_KNOWN(0x1, "V4L2_TUNER_RADIO") },
+		{ ARG_XLAT_KNOWN(0x5, "V4L2_TUNER_RF") },
+		{ ARG_XLAT_UNKNOWN(0x6, "V4L2_TUNER_???") },
+		{ ARG_XLAT_UNKNOWN(0xdeadc0de, "V4L2_TUNER_???") },
+	};
+	static const struct strval32 tuner_caps[] = {
+		{ ARG_STR(0) },
+		{ ARG_XLAT_KNOWN(0x1fff, "V4L2_TUNER_CAP_LOW"
+				 "|V4L2_TUNER_CAP_NORM"
+				 "|V4L2_TUNER_CAP_HWSEEK_BOUNDED"
+				 "|V4L2_TUNER_CAP_HWSEEK_WRAP"
+				 "|V4L2_TUNER_CAP_STEREO|V4L2_TUNER_CAP_LANG2"
+				 "|V4L2_TUNER_CAP_LANG1|V4L2_TUNER_CAP_RDS"
+				 "|V4L2_TUNER_CAP_RDS_BLOCK_IO"
+				 "|V4L2_TUNER_CAP_RDS_CONTROLS"
+				 "|V4L2_TUNER_CAP_FREQ_BANDS"
+				 "|V4L2_TUNER_CAP_HWSEEK_PROG_LIM"
+				 "|V4L2_TUNER_CAP_1HZ") },
+		{ ARG_XLAT_KNOWN(0xdeadc0de, "V4L2_TUNER_CAP_NORM"
+				 "|V4L2_TUNER_CAP_HWSEEK_BOUNDED"
+				 "|V4L2_TUNER_CAP_HWSEEK_WRAP"
+				 "|V4L2_TUNER_CAP_STEREO|V4L2_TUNER_CAP_LANG1"
+				 "|V4L2_TUNER_CAP_RDS|0xdeadc000") },
+		{ ARG_XLAT_UNKNOWN(0xffffe000, "V4L2_TUNER_CAP_???") },
+	};
+	static const struct strval32 tuner_rxsc[] = {
+		{ ARG_STR(0) },
+		{ ARG_XLAT_KNOWN(0x1f, "V4L2_TUNER_SUB_MONO"
+				 "|V4L2_TUNER_SUB_STEREO|V4L2_TUNER_SUB_LANG2"
+				 "|V4L2_TUNER_SUB_LANG1|V4L2_TUNER_SUB_RDS") },
+		{ ARG_XLAT_KNOWN(0xbeefface, "V4L2_TUNER_SUB_STEREO"
+				 "|V4L2_TUNER_SUB_LANG2|V4L2_TUNER_SUB_LANG1"
+				 "|0xbeeffac0") },
+		{ ARG_XLAT_UNKNOWN(0xffffffe0, "V4L2_TUNER_SUB_???") },
+
+	};
+	static const struct strval32 tuner_amodes[] = {
+		{ ARG_XLAT_KNOWN(0, "V4L2_TUNER_MODE_MONO") },
+		{ ARG_XLAT_KNOWN(0x2, "V4L2_TUNER_MODE_LANG2") },
+		{ ARG_XLAT_KNOWN(0x4, "V4L2_TUNER_MODE_LANG1_LANG2") },
+		{ ARG_XLAT_UNKNOWN(0x5, "V4L2_TUNER_MODE_???") },
+		{ ARG_XLAT_UNKNOWN(0xcaffeeed, "V4L2_TUNER_MODE_???") },
+	};
+	static const size_t tuner_iters = MAX(MAX(MAX(ARRAY_SIZE(tuner_types),
+						      ARRAY_SIZE(tuner_caps)),
+						  ARRAY_SIZE(tuner_rxsc)),
+					      ARRAY_SIZE(tuner_amodes));
+
+	struct v4l2_tuner *tuner = tail_alloc(sizeof(*tuner));
+
+	for (size_t i = 0; i < ARRAY_SIZE(tuner_cmds); i++) {
+		ioctl(-1, tuner_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(tuner_cmds[i].str, tuner_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, tuner_cmds[i].val, (char *) tuner + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(tuner_cmds[i].str, tuner_cmds[i].val, NULL),
+		       (char *) tuner + 1, inject_retval);
+
+		for (size_t j = 0; j < tuner_iters; j++) {
+			fill_memory32(tuner, sizeof(*tuner));
+			fill_memory_ex(tuner->name, sizeof(tuner->name),
+				       j * 47 + 7, 255);
+			tuner->type =
+				tuner_types[j % ARRAY_SIZE(tuner_types)].val;
+			tuner->capability =
+				tuner_caps[j % ARRAY_SIZE(tuner_caps)].val;
+			tuner->rxsubchans =
+				tuner_rxsc[j % ARRAY_SIZE(tuner_rxsc)].val;
+			tuner->audmode =
+				tuner_amodes[j % ARRAY_SIZE(tuner_amodes)].val;
+
+			ioctl(-1, tuner_cmds[i].val, tuner);
+			printf("ioctl(-1, %s, {index=2158018784",
+			       sprintxlat(tuner_cmds[i].str,
+					  tuner_cmds[i].val, NULL));
+			for (size_t k = 0;
+			     k < (tuner_cmds[i].val == VIDIOC_S_TUNER ? 2 : 1);
+			     k++) {
+				printf("%sname=", k ? "} => {" : ", ");
+				print_quoted_cstring((char *) tuner->name,
+						     sizeof(tuner->name));
+				printf(", type=%s, capability=%s"
+				       ", rangelow=2158018795"
+				       ", rangehigh=2158018796, rxsubchans=%s"
+				       ", audmode=%s, signal=-2136948497"
+				       ", afc=-2136948496",
+				       tuner_types[j %
+						   ARRAY_SIZE(tuner_types)].str,
+				       tuner_caps[j %
+						  ARRAY_SIZE(tuner_caps)].str,
+				       tuner_rxsc[j %
+						  ARRAY_SIZE(tuner_rxsc)].str,
+				       tuner_amodes[j %
+						 ARRAY_SIZE(tuner_amodes)].str);
+			}
+			printf("}) = %ld (INJECTED)\n", inject_retval);
+		}
+	}
+
+
+	/* VIDIOC_QUERYCTRL */
+	static const struct strval32 cids[] = {
+		{ ARG_XLAT_UNKNOWN(0, "V4L2_CID_???") },
+		{ ARG_XLAT_UNKNOWN(0x97abcd, "V4L2_CID_???") },
+		{ ARG_XLAT_KNOWN(0x980000, "V4L2_CTRL_CLASS_USER+0") },
+		{ ARG_XLAT_KNOWN(0x990a64,
+				 "V4L2_CID_MPEG_VIDEO_H264_CPB_SIZE") },
+		{ ARG_XLAT_KNOWN(0xa31234, "V4L2_CTRL_CLASS_DETECT+0x1234") },
+		{ ARG_XLAT_UNKNOWN(0xa40000, "V4L2_CID_???") },
+		{ 0xdeadc0de,
+#if XLAT_RAW
+		  "0xdeadc0de"
+#else
+		  XLAT_KNOWN(0xc0000000, "V4L2_CTRL_FLAG_NEXT_CTRL"
+					 "|V4L2_CTRL_FLAG_NEXT_COMPOUND")
+		  "|0x1eadc0de /* V4L2_CID_??? */"
+#endif
+			      },
+	};
+	static const struct strval32 ctrl_types[] = {
+		{ ARG_XLAT_UNKNOWN(0, "V4L2_CTRL_TYPE_???") },
+		{ ARG_XLAT_KNOWN(0x1, "V4L2_CTRL_TYPE_INTEGER") },
+		{ ARG_XLAT_KNOWN(0x2, "V4L2_CTRL_TYPE_BOOLEAN") },
+		{ ARG_XLAT_KNOWN(0x3, "V4L2_CTRL_TYPE_MENU") },
+		{ ARG_XLAT_KNOWN(0x4, "V4L2_CTRL_TYPE_BUTTON") },
+		{ ARG_XLAT_KNOWN(0x5, "V4L2_CTRL_TYPE_INTEGER64") },
+		{ ARG_XLAT_KNOWN(0x6, "V4L2_CTRL_TYPE_CTRL_CLASS") },
+		{ ARG_XLAT_KNOWN(0x7, "V4L2_CTRL_TYPE_STRING") },
+		{ ARG_XLAT_KNOWN(0x8, "V4L2_CTRL_TYPE_BITMASK") },
+		{ ARG_XLAT_KNOWN(0x9, "V4L2_CTRL_TYPE_INTEGER_MENU") },
+		{ ARG_XLAT_UNKNOWN(0xa, "V4L2_CTRL_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0xff, "V4L2_CTRL_TYPE_???") },
+		{ ARG_XLAT_KNOWN(0x100, "V4L2_CTRL_TYPE_U8") },
+		{ ARG_XLAT_KNOWN(0x101, "V4L2_CTRL_TYPE_U16") },
+		{ ARG_XLAT_KNOWN(0x102, "V4L2_CTRL_TYPE_U32") },
+		{ ARG_XLAT_UNKNOWN(0x103, "V4L2_CTRL_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0x104, "V4L2_CTRL_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0x105, "V4L2_CTRL_TYPE_???") },
+		{ ARG_XLAT_KNOWN(0x106, "V4L2_CTRL_TYPE_AREA") },
+		{ ARG_XLAT_UNKNOWN(0x107, "V4L2_CTRL_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0xdeadc0de, "V4L2_CTRL_TYPE_???") },
+	};
+	static const struct strval32 ctrl_flags[] = {
+		{ ARG_STR(0) },
+		{ ARG_XLAT_KNOWN(0x7ff, "V4L2_CTRL_FLAG_DISABLED"
+					"|V4L2_CTRL_FLAG_GRABBED"
+					"|V4L2_CTRL_FLAG_READ_ONLY"
+					"|V4L2_CTRL_FLAG_UPDATE"
+					"|V4L2_CTRL_FLAG_INACTIVE"
+					"|V4L2_CTRL_FLAG_SLIDER"
+					"|V4L2_CTRL_FLAG_WRITE_ONLY"
+					"|V4L2_CTRL_FLAG_VOLATILE"
+					"|V4L2_CTRL_FLAG_HAS_PAYLOAD"
+					"|V4L2_CTRL_FLAG_EXECUTE_ON_WRITE"
+					"|V4L2_CTRL_FLAG_MODIFY_LAYOUT") },
+		{ ARG_XLAT_KNOWN(0xbeefface, "V4L2_CTRL_FLAG_GRABBED"
+					     "|V4L2_CTRL_FLAG_READ_ONLY"
+					     "|V4L2_CTRL_FLAG_UPDATE"
+					     "|V4L2_CTRL_FLAG_WRITE_ONLY"
+					     "|V4L2_CTRL_FLAG_VOLATILE"
+					     "|V4L2_CTRL_FLAG_EXECUTE_ON_WRITE"
+					     "|0xbeeff800") },
+		{ ARG_XLAT_UNKNOWN(0xfffff800, "V4L2_CTRL_FLAG_???") },
+	};
+	static const size_t qctrl_iters = MAX(MAX(ARRAY_SIZE(cids),
+						  ARRAY_SIZE(ctrl_types)),
+					       ARRAY_SIZE(ctrl_flags));
+
+	struct v4l2_queryctrl *qctrl = tail_alloc(sizeof(*qctrl));
+
+	ioctl(-1, VIDIOC_QUERYCTRL, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_QUERYCTRL), inject_retval);
+
+	ioctl(-1, VIDIOC_QUERYCTRL, (char *) qctrl + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_QUERYCTRL), (char *) qctrl + 1, inject_retval);
+
+	for (size_t i = 0; i < qctrl_iters; i++) {
+		fill_memory32(qctrl, sizeof(*qctrl));
+		fill_memory_ex(qctrl->name, sizeof(qctrl->name),
+			       i * 47 + 5, 255);
+		qctrl->id    = cids[i % ARRAY_SIZE(cids)].val;
+		qctrl->type  = ctrl_types[i % ARRAY_SIZE(ctrl_types)].val;
+		qctrl->flags = ctrl_flags[i % ARRAY_SIZE(ctrl_flags)].val;
+
+		if (i % 2)
+			memset(qctrl->reserved, 0, sizeof(qctrl->reserved));
+
+		ioctl(-1, VIDIOC_QUERYCTRL, qctrl);
+		printf("ioctl(-1, %s, {id=%s, type=%s, name=",
+		       XLAT_STR(VIDIOC_QUERYCTRL),
+		       cids[i % ARRAY_SIZE(cids)].str,
+		       ctrl_types[i % ARRAY_SIZE(ctrl_types)].str);
+		print_quoted_cstring((char *) qctrl->name, sizeof(qctrl->name));
+#if VERBOSE
+		printf(", minimum=-2136948502, maximum=-2136948501"
+		       ", step=-2136948500, default_value=-2136948499"
+		       ", flags=%s%s",
+		       ctrl_flags[i % ARRAY_SIZE(ctrl_flags)].str,
+		       i % 2 ? "" : ", reserved=[0x80a0c0ef, 0x80a0c0f0]");
+#else
+		printf(", ...");
+#endif
+		printf("}) = %ld (INJECTED)\n", inject_retval);
+	}
+
+
+	/* VIDIOC_G_INPUT, VIDIOC_S_INPUT */
+	static const struct strval32 input_cmds[] = {
+		{ ARG_STR(VIDIOC_G_INPUT) },
+		{ ARG_STR(VIDIOC_S_INPUT) },
+	};
+	static const struct strval32 inputids[] = {
+		{ ARG_STR(0) },
+		{ ARG_STR(1) },
+		{ ARG_STR(1578221295) },
+		{ ARG_STR(31415926) },
+		{ ARG_STR(4294967295) },
+	};
+
+	int *inputid = tail_alloc(sizeof(*inputid));
+
+	for (size_t i = 0; i < ARRAY_SIZE(input_cmds); i++) {
+		ioctl(-1, input_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(input_cmds[i].str, input_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, input_cmds[i].val, (char *) inputid + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(input_cmds[i].str, input_cmds[i].val, NULL),
+		       (char *) inputid + 1, inject_retval);
+
+		for (size_t j = 0; j < ARRAY_SIZE(inputids); j++) {
+			*inputid = inputids[j].val;
+
+			ioctl(-1, input_cmds[i].val, inputid);
+			printf("ioctl(-1, %s, [%s]) = %ld (INJECTED)\n",
+			       sprintxlat(input_cmds[i].str, input_cmds[i].val,
+					  NULL),
+			       inputids[j].str, inject_retval);
+
+		}
+	}
+
+
+	/* VIDIOC_CROPCAP */
+	struct v4l2_cropcap *ccap = tail_alloc(sizeof(*ccap));
+
+	fill_memory32(ccap, sizeof(*ccap));
+
+	ioctl(-1, VIDIOC_CROPCAP, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_CROPCAP), inject_retval);
+
+	ioctl(-1, VIDIOC_CROPCAP, (char *) ccap + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_CROPCAP), (char *) ccap + 1, inject_retval);
+
+	for (size_t i = 0; i < ARRAY_SIZE(buf_types); i++) {
+		ccap->type = buf_types[i].val;
+
+		ioctl(-1, VIDIOC_CROPCAP, ccap);
+		printf("ioctl(-1, %s, {type=%s"
+		       ", bounds={left=-2136948511, top=-2136948510"
+		       ", width=2158018787, height=2158018788}"
+		       ", defrect={left=-2136948507, top=-2136948506"
+		       ", width=2158018791, height=2158018792}"
+		       ", pixelaspect=2158018793/2158018794})"
+		       " = %ld (INJECTED)\n",
+		       XLAT_STR(VIDIOC_CROPCAP),
+		       buf_types[i].str, inject_retval);
+	}
+
+
+	/* VIDIOC_G_CROP, VIDIOC_S_CROP */
+	static const struct strval32 crop_cmds[] = {
+		{ ARG_STR(VIDIOC_G_CROP) },
+		{ ARG_STR(VIDIOC_S_CROP) },
+	};
+	struct v4l2_crop *crop = tail_alloc(sizeof(*crop));
+
+	for (size_t i = 0; i < ARRAY_SIZE(crop_cmds); i++) {
+		fill_memory32(crop, sizeof(*crop));
+
+		ioctl(-1, crop_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(crop_cmds[i].str, crop_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, crop_cmds[i].val, (char *) crop + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(crop_cmds[i].str, crop_cmds[i].val, NULL),
+		       (char *) crop + 1, inject_retval);
+
+		for (size_t j = 0; j < ARRAY_SIZE(buf_types); j++) {
+			crop->type = buf_types[j].val;
+
+			ioctl(-1, crop_cmds[i].val, crop);
+			printf("ioctl(-1, %s, {type=%s, c={left=-2136948511"
+			       ", top=-2136948510, width=2158018787"
+			       ", height=2158018788}}) = %ld (INJECTED)\n",
+			       sprintxlat(crop_cmds[i].str, crop_cmds[i].val,
+					  NULL),
+			       buf_types[j].str, inject_retval);
+		}
+	}
+
+
+#ifdef VIDIOC_S_EXT_CTRLS
+	/* VIDIOC_S_EXT_CTRLS, VIDIOC_TRY_EXT_CTRLS, VIDIOC_G_EXT_CTRLS */
+	static const struct strval32 ectrl_cmds[] = {
+		{ ARG_STR(VIDIOC_S_EXT_CTRLS) },
+		{ ARG_STR(VIDIOC_TRY_EXT_CTRLS) },
+		{ ARG_STR(VIDIOC_G_EXT_CTRLS) },
+	};
+	/* static const struct strval32 ectrl_which = {
+	}; */
+
+	struct v4l2_ext_controls *ectrls = tail_alloc(sizeof(*ectrls));
+	/* struct v4l2_ext_control *ectrl = tail_alloc(sizeof(*ectrl) * 2); */
+
+	for (size_t i = 0; i < ARRAY_SIZE(ectrl_cmds); i++) {
+		fill_memory32(ectrls, sizeof(*ectrls));
+
+		ioctl(-1, ectrl_cmds[i].val, 0);
+		printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+		       sprintxlat(ectrl_cmds[i].str, ectrl_cmds[i].val, NULL),
+		       inject_retval);
+
+		ioctl(-1, ectrl_cmds[i].val, (char *) ectrls + 1);
+		printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+		       sprintxlat(ectrl_cmds[i].str, ectrl_cmds[i].val, NULL),
+		       (char *) ectrls + 1, inject_retval);
+	}
+
+#endif /* VIDIOC_S_EXT_CTRLS */
+
+
+#ifdef HAVE_STRUCT_V4L2_FRMSIZEENUM
+	/* VIDIOC_ENUM_FRAMESIZES */
+	static const struct strval32 frmsz_simple_types[] = {
+		{ ARG_XLAT_UNKNOWN(0, "V4L2_FRMSIZE_TYPE_???") },
+		{ ARG_XLAT_KNOWN(0x2, "V4L2_FRMSIZE_TYPE_CONTINUOUS") },
+		{ ARG_XLAT_UNKNOWN(0x4, "V4L2_FRMSIZE_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0xdeadf157, "V4L2_FRMSIZE_TYPE_???") },
+	};
+
+	struct v4l2_frmsizeenum *fse = tail_alloc(sizeof(*fse));
+
+	ioctl(-1, VIDIOC_ENUM_FRAMESIZES, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMESIZES), inject_retval);
+
+	ioctl(-1, VIDIOC_ENUM_FRAMESIZES, (char *) fse + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMESIZES), (char *) fse + 1,
+	       inject_retval);
+
+	fill_memory32(fse, sizeof(*fse));
+	fse->type = V4L2_FRMSIZE_TYPE_DISCRETE;
+
+	ioctl(-1, VIDIOC_ENUM_FRAMESIZES, fse);
+	printf("ioctl(-1, %s, {index=2158018784, pixel_format="
+	       RAW("0x80a0c0e1")
+	       NRAW("v4l2_fourcc('\\xe1', '\\xc0', '\\xa0', '\\x80')")
+	       ", type=" XLAT_KNOWN(0x1, "V4L2_FRMSIZE_TYPE_DISCRETE")
+	       ", discrete={width=2158018787, height=2158018788}"
+	       "}) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMESIZES), inject_retval);
+
+	fse->pixel_format = 0x5c22270d;
+	fse->type = V4L2_FRMSIZE_TYPE_STEPWISE;
+
+	ioctl(-1, VIDIOC_ENUM_FRAMESIZES, fse);
+	printf("ioctl(-1, %s, {index=2158018784, pixel_format="
+	       RAW("0x5c22270d")
+	       NRAW("v4l2_fourcc('\\x0d', '\\\'', '\"', '\\\\')")
+	       ", type=" XLAT_KNOWN(0x3, "V4L2_FRMSIZE_TYPE_STEPWISE")
+	       ", stepwise={min_width=2158018787, max_width=2158018788"
+	       ", step_width=2158018789, min_height=2158018790"
+	       ", max_height=2158018791, step_height=2158018792}"
+	       "}) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMESIZES), inject_retval);
+
+	for (size_t i = 0; i < ARRAY_SIZE(frmsz_simple_types); i++) {
+		fill_memory32(fse, sizeof(*fse));
+		fse->type = frmsz_simple_types[i].val;
+
+		ioctl(-1, VIDIOC_ENUM_FRAMESIZES, fse);
+		printf("ioctl(-1, %s, {index=2158018784, pixel_format="
+		       RAW("0x80a0c0e1")
+		       NRAW("v4l2_fourcc('\\xe1', '\\xc0', '\\xa0', '\\x80')")
+		       ", type=%s}) = %ld (INJECTED)\n",
+		       XLAT_STR(VIDIOC_ENUM_FRAMESIZES),
+		       frmsz_simple_types[i].str, inject_retval);
+
+	}
+#endif /* HAVE_STRUCT_V4L2_FRMSIZEENUM */
+
+
+#ifdef HAVE_STRUCT_V4L2_FRMIVALENUM
+	/* VIDIOC_ENUM_FRAMEINTERVALS */
+	static const struct strval32 frmival_simple_types[] = {
+		{ ARG_XLAT_UNKNOWN(0, "V4L2_FRMIVAL_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0x4, "V4L2_FRMIVAL_TYPE_???") },
+		{ ARG_XLAT_UNKNOWN(0xdeadf157, "V4L2_FRMIVAL_TYPE_???") },
+	};
+	static const struct strval32 frmival_step_types[] = {
+		{ ARG_XLAT_KNOWN(0x2, "V4L2_FRMIVAL_TYPE_CONTINUOUS") },
+		{ ARG_XLAT_KNOWN(0x3, "V4L2_FRMIVAL_TYPE_STEPWISE") },
+	};
+
+	struct v4l2_frmivalenum *fie = tail_alloc(sizeof(*fie));
+
+	ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMEINTERVALS), inject_retval);
+
+	ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, (char *) fie + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMEINTERVALS), (char *) fie + 1,
+	       inject_retval);
+
+	fill_memory32(fie, sizeof(*fie));
+	fie->type = V4L2_FRMIVAL_TYPE_DISCRETE;
+
+	ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, fie);
+	printf("ioctl(-1, %s, {index=2158018784, pixel_format="
+	       RAW("0x80a0c0e1")
+	       NRAW("v4l2_fourcc('\\xe1', '\\xc0', '\\xa0', '\\x80')")
+	       ", width=2158018786, height=2158018787"
+	       ", type=" XLAT_KNOWN(0x1, "V4L2_FRMIVAL_TYPE_DISCRETE")
+	       ", discrete=2158018789/2158018790}) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_ENUM_FRAMEINTERVALS), inject_retval);
+
+	fie->pixel_format = 0x5c22270d;
+
+	for (size_t i = 0; i < ARRAY_SIZE(frmival_step_types); i++) {
+		fie->type = frmival_step_types[i].val;
+
+		ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, fie);
+		printf("ioctl(-1, %s, {index=2158018784, pixel_format="
+		       RAW("0x5c22270d")
+		       NRAW("v4l2_fourcc('\\x0d', '\\\'', '\"', '\\\\')")
+		       ", width=2158018786, height=2158018787, type=%s"
+		       ", stepwise={min=2158018789/2158018790"
+		       ", max=2158018791/2158018792"
+		       ", step=2158018793/2158018794}}) = %ld (INJECTED)\n",
+		       XLAT_STR(VIDIOC_ENUM_FRAMEINTERVALS),
+		       frmival_step_types[i].str, inject_retval);
+	}
+
+	for (size_t i = 0; i < ARRAY_SIZE(frmival_simple_types); i++) {
+		fill_memory32(fie, sizeof(*fie));
+		fie->type = frmival_simple_types[i].val;
+
+		ioctl(-1, VIDIOC_ENUM_FRAMEINTERVALS, fie);
+		printf("ioctl(-1, %s, {index=2158018784, pixel_format="
+		       RAW("0x80a0c0e1")
+		       NRAW("v4l2_fourcc('\\xe1', '\\xc0', '\\xa0', '\\x80')")
+	               ", width=2158018786, height=2158018787, type=%s})"
+		       " = %ld (INJECTED)\n",
+		       XLAT_STR(VIDIOC_ENUM_FRAMEINTERVALS),
+		       frmival_simple_types[i].str, inject_retval);
+
+	}
+#endif /* HAVE_STRUCT_V4L2_FRMIVALENUM */
+
+
+#ifdef HAVE_STRUCT_V4L2_CREATE_BUFFERS
+	/* VIDIOC_CREATE_BUFS */
+	struct v4l2_create_buffers *cbuf = tail_alloc(sizeof(*cbuf));
+
+	fill_memory32(cbuf, sizeof(*cbuf));
+
+	ioctl(-1, VIDIOC_CREATE_BUFS, 0);
+	printf("ioctl(-1, %s, NULL) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_CREATE_BUFS), inject_retval);
+
+	ioctl(-1, VIDIOC_CREATE_BUFS, (char *) cbuf + 1);
+	printf("ioctl(-1, %s, %p) = %ld (INJECTED)\n",
+	       XLAT_STR(VIDIOC_CREATE_BUFS), (char *) cbuf + 1, inject_retval);
+
+	for (size_t i = 0; i < MAX(ARRAY_SIZE(buf_types),
+				   ARRAY_SIZE(reqb_mems)); i++) {
+		cbuf->memory = reqb_mems[i % ARRAY_SIZE(reqb_mems)].val;
+		cbuf->format.type = buf_types[i % ARRAY_SIZE(buf_types)].val;
+		if (!fill_fmt(&cbuf->format))
+			continue;
+
+		ioctl(-1, VIDIOC_CREATE_BUFS, cbuf);
+		printf("ioctl(-1, %s, {count=2158018785, memory=%s"
+		       ", format={type=%s",
+		       XLAT_STR(VIDIOC_CREATE_BUFS),
+		       reqb_mems[i % ARRAY_SIZE(reqb_mems)].str,
+		       buf_types[i % ARRAY_SIZE(buf_types)].str);
+		print_fmt(", ", &cbuf->format);
+		printf("}}) = %ld ({index=2158018784, count=2158018785})"
+		       " (INJECTED)\n", inject_retval);
+	}
+#endif /* HAVE_STRUCT_V4L2_CREATE_BUFFERS */
+
+	puts("+++ exited with 0 +++");
+
+	return 0;
+}
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-success.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success.gen.test
--- 5.5-3/tests-mx32/ioctl_v4l2-success.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-success +ioctl-success.sh -a29); do not edit.
+set -- -a29
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-success-v.c 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-v.c
--- 5.5-3/tests-mx32/ioctl_v4l2-success-v.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-v.c	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,2 @@
+#define VERBOSE 1
+#include "ioctl_v4l2-success.c"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-success-v.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-v.gen.test
--- 5.5-3/tests-mx32/ioctl_v4l2-success-v.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-v.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-success-v +ioctl-success.sh -a29 -v); do not edit.
+set -- -a29 -v
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-success-v-Xabbrev.c 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-v-Xabbrev.c
--- 5.5-3/tests-mx32/ioctl_v4l2-success-v-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-v-Xabbrev.c	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "ioctl_v4l2-success-v.c"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-success-v-Xabbrev.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-v-Xabbrev.gen.test
--- 5.5-3/tests-mx32/ioctl_v4l2-success-v-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-v-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-success-v-Xabbrev +ioctl-success.sh -a29 -v -Xabbrev); do not edit.
+set -- -a29 -v -Xabbrev
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-success-v-Xraw.c 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-v-Xraw.c
--- 5.5-3/tests-mx32/ioctl_v4l2-success-v-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-v-Xraw.c	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "ioctl_v4l2-success-v.c"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-success-v-Xraw.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-v-Xraw.gen.test
--- 5.5-3/tests-mx32/ioctl_v4l2-success-v-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-v-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-success-v-Xraw +ioctl-success.sh -a27 -v -Xraw); do not edit.
+set -- -a27 -v -Xraw
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-success-v-Xverbose.c 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-v-Xverbose.c
--- 5.5-3/tests-mx32/ioctl_v4l2-success-v-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-v-Xverbose.c	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "ioctl_v4l2-success-v.c"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-success-v-Xverbose.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-v-Xverbose.gen.test
--- 5.5-3/tests-mx32/ioctl_v4l2-success-v-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-v-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-success-v-Xverbose +ioctl-success.sh -a29 -v -Xverbose); do not edit.
+set -- -a29 -v -Xverbose
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-success-Xabbrev.c 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-Xabbrev.c
--- 5.5-3/tests-mx32/ioctl_v4l2-success-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-Xabbrev.c	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "ioctl_v4l2-success.c"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-success-Xabbrev.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-Xabbrev.gen.test
--- 5.5-3/tests-mx32/ioctl_v4l2-success-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-success-Xabbrev +ioctl-success.sh -a29 -Xabbrev); do not edit.
+set -- -a29 -Xabbrev
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-success-Xraw.c 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-Xraw.c
--- 5.5-3/tests-mx32/ioctl_v4l2-success-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-Xraw.c	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "ioctl_v4l2-success.c"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-success-Xraw.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-Xraw.gen.test
--- 5.5-3/tests-mx32/ioctl_v4l2-success-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-success-Xraw +ioctl-success.sh -a27 -Xraw); do not edit.
+set -- -a27 -Xraw
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-success-Xverbose.c 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-Xverbose.c
--- 5.5-3/tests-mx32/ioctl_v4l2-success-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-Xverbose.c	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "ioctl_v4l2-success.c"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-success-Xverbose.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-Xverbose.gen.test
--- 5.5-3/tests-mx32/ioctl_v4l2-success-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-success-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-success-Xverbose +ioctl-success.sh -a30 -Xverbose); do not edit.
+set -- -a30 -Xverbose
+. "${srcdir=.}/ioctl-success.sh"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-v.c 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-v.c
--- 5.5-3/tests-mx32/ioctl_v4l2-v.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-v.c	2020-03-28 16:57:34.000000000 +0000
@@ -0,0 +1,3 @@
+/* This file is part of ioctl_v4l2-v strace test. */
+#define VERBOSE 1
+#include "ioctl_v4l2.c"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-v.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-v.gen.test
--- 5.5-3/tests-mx32/ioctl_v4l2-v.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-v.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-v +ioctl.test -v); do not edit.
+set -- -v
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-v-Xabbrev.c 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-v-Xabbrev.c
--- 5.5-3/tests-mx32/ioctl_v4l2-v-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-v-Xabbrev.c	2020-03-28 16:57:34.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "ioctl_v4l2-v.c"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-v-Xabbrev.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-v-Xabbrev.gen.test
--- 5.5-3/tests-mx32/ioctl_v4l2-v-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-v-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-v-Xabbrev +ioctl.test -v -Xabbrev); do not edit.
+set -- -v -Xabbrev
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-v-Xraw.c 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-v-Xraw.c
--- 5.5-3/tests-mx32/ioctl_v4l2-v-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-v-Xraw.c	2020-03-28 16:57:34.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "ioctl_v4l2-v.c"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-v-Xraw.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-v-Xraw.gen.test
--- 5.5-3/tests-mx32/ioctl_v4l2-v-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-v-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-v-Xraw +ioctl.test -v -Xraw); do not edit.
+set -- -v -Xraw
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-v-Xverbose.c 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-v-Xverbose.c
--- 5.5-3/tests-mx32/ioctl_v4l2-v-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-v-Xverbose.c	2020-03-28 16:57:34.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "ioctl_v4l2-v.c"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-v-Xverbose.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-v-Xverbose.gen.test
--- 5.5-3/tests-mx32/ioctl_v4l2-v-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-v-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-v-Xverbose +ioctl.test -v -Xverbose); do not edit.
+set -- -v -Xverbose
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-Xabbrev.c 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-Xabbrev.c
--- 5.5-3/tests-mx32/ioctl_v4l2-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-Xabbrev.c	2020-03-28 16:57:34.000000000 +0000
@@ -0,0 +1 @@
+#include "ioctl_v4l2.c"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-Xabbrev.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-Xabbrev.gen.test
--- 5.5-3/tests-mx32/ioctl_v4l2-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-Xabbrev +ioctl.test -Xabbrev); do not edit.
+set -- -Xabbrev
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-Xraw.c 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-Xraw.c
--- 5.5-3/tests-mx32/ioctl_v4l2-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-Xraw.c	2020-03-28 16:57:34.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "ioctl_v4l2.c"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-Xraw.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-Xraw.gen.test
--- 5.5-3/tests-mx32/ioctl_v4l2-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-Xraw +ioctl.test -Xraw); do not edit.
+set -- -Xraw
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-Xverbose.c 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-Xverbose.c
--- 5.5-3/tests-mx32/ioctl_v4l2-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-Xverbose.c	2020-03-28 16:57:34.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "ioctl_v4l2.c"
diff -pruN 5.5-3/tests-mx32/ioctl_v4l2-Xverbose.gen.test 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-Xverbose.gen.test
--- 5.5-3/tests-mx32/ioctl_v4l2-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioctl_v4l2-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioctl_v4l2-Xverbose +ioctl.test -Xverbose); do not edit.
+set -- -Xverbose
+. "${srcdir=.}/ioctl.test"
diff -pruN 5.5-3/tests-mx32/ioprio.c 5.9-0ubuntu2/tests-mx32/ioprio.c
--- 5.5-3/tests-mx32/ioprio.c	2019-09-24 15:31:28.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioprio.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,15 +2,15 @@
  * Check decoding of ioprio_get and ioprio_set syscalls.
  *
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-
 #include "scno.h"
+#include "pidns.h"
 
 #if defined(__NR_ioprio_get) && defined(__NR_ioprio_set)
 
@@ -30,12 +30,18 @@ enum {
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	static const kernel_ulong_t bogus_which =
 		(kernel_ulong_t) 0xdeadfacefa57beefULL;
 	static const kernel_ulong_t bogus_who =
 		(kernel_ulong_t) 0xbadc0dedda7a1057ULL;
 	static const kernel_ulong_t bogus_ioprio =
 		(kernel_ulong_t) 0xdec0ded1facefeedULL;
+
+	const int pid = getpid();
+	const int pgid = getpgid(0);
+
 # if !XLAT_RAW
 	static const char * const bogus_ioprio_str =
 		"IOPRIO_PRIO_VALUE(0x7d677 /* IOPRIO_CLASS_??? */, 7917)";
@@ -46,6 +52,7 @@ main(void)
 
 	rc = syscall(__NR_ioprio_get, bogus_which, bogus_who);
 	errstr = sprintrc(rc);
+	pidns_print_leader();
 # if XLAT_RAW
 	printf("ioprio_get(%#x, %d) = %s\n",
 	       (int) bogus_which, (int) bogus_who, errstr);
@@ -54,42 +61,52 @@ main(void)
 	       (int) bogus_which, (int) bogus_who, errstr);
 # endif
 
-	rc = syscall(__NR_ioprio_get, 1, 0);
+	rc = syscall(__NR_ioprio_get, 1, pid);
 	errstr = sprintrc(rc);
+	pidns_print_leader();
+	printf("ioprio_get(");
 # if XLAT_RAW
-	printf("ioprio_get(0x1, 0) = %s\n", errstr);
+	printf("0x1, ");
+# elif XLAT_VERBOSE
+	printf("0x1 /* IOPRIO_WHO_PROCESS */, ");
 # else /* XLAT_ABBREV */
-#  if XLAT_VERBOSE
-	printf("ioprio_get(0x1 /* IOPRIO_WHO_PROCESS */, 0) = %s", errstr);
-#  else
-	printf("ioprio_get(IOPRIO_WHO_PROCESS, 0) = %s", errstr);
-#  endif
+	printf("IOPRIO_WHO_PROCESS, ");
+# endif
+	printf("%d%s) = %s", pid, pidns_pid2str(PT_TGID), errstr);
+# if !XLAT_RAW
 	if (rc >= 0) {
 		printf(" (IOPRIO_PRIO_VALUE(");
 		printxval(ioprio_class, (unsigned int) rc >> 13,
 			  "IOPRIO_CLASS_???");
 		printf(", %u))", (unsigned int) rc & 0x1fff);
 	}
-	puts("");
 # endif
+	puts("");
 
-	rc = syscall(__NR_ioprio_set, 2, 0, 8191);
+	rc = syscall(__NR_ioprio_set, 2, pgid, 8191);
 	errstr = sprintrc(rc);
+	pidns_print_leader();
+	printf("ioprio_set(");
 # if XLAT_RAW
-	printf("ioprio_set(%#x, 0, 8191) = %s\n", 2, errstr);
+	printf("%#x", 2);
 # elif XLAT_VERBOSE
-	printf("ioprio_set(%#x /* IOPRIO_WHO_PGRP */, 0, 8191"
-	       " /* IOPRIO_PRIO_VALUE(0 /* IOPRIO_CLASS_NONE */, 8191) */)"
-	       " = %s\n",
-	       2, errstr);
+	printf("%#x /* IOPRIO_WHO_PGRP */", 2);
 # else /* XLAT_ABBREV */
-	printf("ioprio_set(IOPRIO_WHO_PGRP, 0"
-	       ", IOPRIO_PRIO_VALUE(IOPRIO_CLASS_NONE, 8191)) = %s\n",
-	       errstr);
+	printf("IOPRIO_WHO_PGRP");
+# endif
+	printf(", %d%s", pgid, pidns_pid2str(PT_PGID));
+# if XLAT_RAW
+	printf(", 8191)");
+# elif XLAT_VERBOSE
+	printf(", 8191 /* IOPRIO_PRIO_VALUE(0 /* IOPRIO_CLASS_NONE */, 8191) */)");
+# else /* XLAT_ABBREV */
+	printf(", IOPRIO_PRIO_VALUE(IOPRIO_CLASS_NONE, 8191))");
 # endif
+	printf(" = %s\n", errstr);
 
 	rc = syscall(__NR_ioprio_set, bogus_which, bogus_who, bogus_ioprio);
 	errstr = sprintrc(rc);
+	pidns_print_leader();
 # if XLAT_RAW
 	printf("ioprio_set(%#x, %d, %d) = %s\n",
 	       (int) bogus_which, (int) bogus_who, (int) bogus_ioprio,
@@ -104,6 +121,7 @@ main(void)
 	       errstr);
 # endif
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 
 	return 0;
diff -pruN 5.5-3/tests-mx32/ioprio--pidns-translation.c 5.9-0ubuntu2/tests-mx32/ioprio--pidns-translation.c
--- 5.5-3/tests-mx32/ioprio--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioprio--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "ioprio.c"
diff -pruN 5.5-3/tests-mx32/ioprio--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/ioprio--pidns-translation.gen.test
--- 5.5-3/tests-mx32/ioprio--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ioprio--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (ioprio--pidns-translation test_pidns -a18 -e trace=ioprio_get,ioprio_set); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a18 -e trace=ioprio_get,ioprio_set
diff -pruN 5.5-3/tests-mx32/io_uring_register.c 5.9-0ubuntu2/tests-mx32/io_uring_register.c
--- 5.5-3/tests-mx32/io_uring_register.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/io_uring_register.c	2020-06-28 08:00:00.000000000 +0000
@@ -25,16 +25,21 @@
 # endif
 
 /* From tests/bpf.c */
-#if defined MPERS_IS_m32 || SIZEOF_KERNEL_LONG_T > 4
-# define BIG_ADDR_MAYBE(addr_)
-#elif defined __arm__ || defined __i386__ || defined __mips__ \
+# if defined MPERS_IS_m32 || SIZEOF_KERNEL_LONG_T > 4
+#  define BIG_ADDR_MAYBE(addr_)
+# elif defined __arm__ || defined __i386__ || defined __mips__ \
    || defined __powerpc__ || defined __riscv__ || defined __s390__ \
    || defined __sparc__ || defined __tile__
-# define BIG_ADDR_MAYBE(addr_) addr_ " or "
-#else
-# define BIG_ADDR_MAYBE(addr_)
-#endif
+#  define BIG_ADDR_MAYBE(addr_) addr_ " or "
+# else
+#  define BIG_ADDR_MAYBE(addr_)
+# endif
 
+# if WORDS_BIGENDIAN
+#  define BE_LE(be_, le_) be_
+# else
+#  define BE_LE(be_, le_) le_
+# endif
 
 static const char *errstr;
 
@@ -81,12 +86,12 @@ main(void)
 
 	int fd_full = open(path_full, O_RDONLY);
 	if (fd_full < 0)
-		perror_msg_and_fail("open: %s", path_null);
+		perror_msg_and_fail("open: %s", path_full);
 
 	int fds[] = { fd_full, fd_null };
 	const int *arg_fds = tail_memdup(fds, sizeof(fds));
 
-	static const unsigned int invalid_ops[] = { 0xbadc0dedU, 7 };
+	static const unsigned int invalid_ops[] = { 0xbadc0dedU, 11 };
 
 	for (size_t i = 0; i < ARRAY_SIZE(invalid_ops); i++) {
 		sys_io_uring_register(fd_null, invalid_ops[i], path_null,
@@ -104,6 +109,8 @@ main(void)
 		{ 1, "IORING_UNREGISTER_BUFFERS" },
 		{ 3, "IORING_UNREGISTER_FILES" },
 		{ 5, "IORING_UNREGISTER_EVENTFD" },
+		{ 9, "IORING_REGISTER_PERSONALITY" },
+		{ 10, "IORING_UNREGISTER_PERSONALITY" },
 	};
 
 	for (size_t i = 0; i < ARRAY_SIZE(no_arg_ops); i++) {
@@ -129,6 +136,7 @@ main(void)
 	} fd_arr_ops[] = {
 		{ 2, "IORING_REGISTER_FILES" },
 		{ 4, "IORING_REGISTER_EVENTFD" },
+		{ 7, "IORING_REGISTER_EVENTFD_ASYNC" },
 	};
 
 	for (size_t i = 0; i < ARRAY_SIZE(fd_arr_ops); i++) {
@@ -141,7 +149,7 @@ main(void)
 		       (unsigned int) ARRAY_SIZE(fds), errstr);
 	}
 
-#ifdef HAVE_STRUCT_IO_URING_FILES_UPDATE
+# ifdef HAVE_STRUCT_IO_URING_FILES_UPDATE
 	struct io_uring_files_update bogus_iufu;
 	struct io_uring_files_update iufu;
 
@@ -154,7 +162,8 @@ main(void)
 	sys_io_uring_register(fd_null, 6, &bogus_iufu, 0);
 	printf("io_uring_register(%u<%s>, IORING_REGISTER_FILES_UPDATE"
 	       ", {offset=%" PRIu32 ", resv=%#" PRIx32 ", fds="
-	       BIG_ADDR_MAYBE("0x8f8e8d8c8b8a8988") "[]}, 0) = %s\n",
+	       BIG_ADDR_MAYBE(BE_LE("0x88898a8b8c8d8e8f", "0x8f8e8d8c8b8a8988"))
+	       "[]}, 0) = %s\n",
 	       fd_null, path_null,
 	       ((uint32_t *) &bogus_iufu)[0], ((uint32_t *) &bogus_iufu)[1],
 	       errstr);
@@ -167,7 +176,111 @@ main(void)
 	       ", {offset=3735929054, fds=[%u<%s>, %u<%s>]}, %u) = %s\n",
 	       fd_null, path_null, fd_full, path_full, fd_null, path_null,
 	       (unsigned int) ARRAY_SIZE(fds), errstr);
-#endif
+# endif
+
+# ifdef HAVE_STRUCT_IO_URING_PROBE
+	struct io_uring_probe *probe = tail_alloc(sizeof(*probe) +
+		       (DEFAULT_STRLEN + 1) * sizeof(struct io_uring_probe_op));
+
+	sys_io_uring_register(fd_null, IORING_REGISTER_PROBE, NULL, 0xfacefeed);
+	printf("io_uring_register(%u<%s>, IORING_REGISTER_PROBE"
+	       ", NULL, 4207869677) = %s\n",
+	       fd_null, path_null, errstr);
+
+	sys_io_uring_register(fd_null, IORING_REGISTER_PROBE, probe,
+			      0xfacefeed);
+	printf("io_uring_register(%u<%s>, IORING_REGISTER_PROBE"
+	       ", %p, 4207869677) = %s\n",
+	       fd_null, path_null, probe, errstr);
+
+	sys_io_uring_register(fd_null, IORING_REGISTER_PROBE,
+			      (char *) probe + 1, DEFAULT_STRLEN + 1);
+	printf("io_uring_register(%u<%s>, IORING_REGISTER_PROBE"
+	       ", %p, %d) = %s\n",
+	       fd_null, path_null, (char *) probe + 1, DEFAULT_STRLEN + 1,
+	       errstr);
+
+	sys_io_uring_register(fd_null, IORING_REGISTER_PROBE, probe, 0);
+	printf("io_uring_register(%u<%s>, IORING_REGISTER_PROBE"
+	       ", {last_op=%u /* IORING_OP_??? */, ops_len=%hhu, resv=%#hx"
+	       ", resv2=[%#x, %#x, %#x], ops=[]}, 0) = %s\n",
+	       fd_null, path_null, probe->last_op, probe->ops_len, probe->resv,
+	       probe->resv2[0], probe->resv2[1], probe->resv2[2], errstr);
+
+	probe->last_op = IORING_OP_READV;
+	probe->resv = 0;
+	sys_io_uring_register(fd_null, IORING_REGISTER_PROBE, probe, 0);
+	printf("io_uring_register(%u<%s>, IORING_REGISTER_PROBE"
+	       ", {last_op=IORING_OP_READV, ops_len=%hhu"
+	       ", resv2=[%#x, %#x, %#x], ops=[]}, 0) = %s\n",
+	       fd_null, path_null, probe->ops_len,
+	       probe->resv2[0], probe->resv2[1], probe->resv2[2], errstr);
+
+	probe->last_op = IORING_OP_EPOLL_CTL;
+	probe->resv2[0] = 0;
+	probe->resv2[2] = 0;
+
+	probe->ops[0].op = IORING_OP_NOP;
+	probe->ops[0].resv = 0xde;
+	probe->ops[0].flags = 0;
+	probe->ops[0].resv2 = 0xbeefface;
+
+	probe->ops[1].op = 33;
+	probe->ops[1].resv = 0;
+	probe->ops[1].flags = IO_URING_OP_SUPPORTED;
+	probe->ops[1].resv2 = 0xdeadc0de;
+
+	probe->ops[2].op = 34;
+	probe->ops[2].resv = 0xaf;
+	probe->ops[2].flags = 0xbeef;
+	probe->ops[2].resv2 = 0;
+
+	probe->ops[3].op = 0xfe;
+	probe->ops[3].resv = 0;
+	probe->ops[3].flags = 0xc0de;
+	probe->ops[3].resv2 = 0;
+
+	sys_io_uring_register(fd_null, IORING_REGISTER_PROBE, probe, 4);
+	printf("io_uring_register(%u<%s>, IORING_REGISTER_PROBE"
+	       ", {last_op=IORING_OP_EPOLL_CTL, ops_len=%hhu"
+	       ", resv2=[0, %#x, 0], ops=["
+	       "{op=IORING_OP_NOP, resv=0xde, flags=0, resv2=0xbeefface}, "
+	       "{op=IORING_OP_TEE, flags=IO_URING_OP_SUPPORTED"
+	       ", resv2=0xdeadc0de}, "
+	       "{op=34 /* IORING_OP_??? */, resv=0xaf"
+	       ", flags=IO_URING_OP_SUPPORTED|0xbeee}, "
+	       "{op=254 /* IORING_OP_??? */"
+	       ", flags=0xc0de /* IO_URING_OP_??? */}]}, 4) = %s\n",
+	       fd_null, path_null, probe->ops_len, probe->resv2[1], errstr);
+
+	probe->last_op = 34;
+	probe->resv2[1] = 0;
+	fill_memory_ex(probe->ops, sizeof(probe->ops[0]) * (DEFAULT_STRLEN + 1),
+		    0x40, 0x80);
+	sys_io_uring_register(fd_null, IORING_REGISTER_PROBE, probe,
+			      DEFAULT_STRLEN + 1);
+	printf("io_uring_register(%u<%s>, IORING_REGISTER_PROBE"
+	       ", {last_op=34 /* IORING_OP_??? */, ops_len=%hhu, ops=[",
+	       fd_null, path_null, probe->ops_len);
+	for (size_t i = 0; i < DEFAULT_STRLEN; i++) {
+		printf("%s{op=%u /* IORING_OP_??? */, resv=%#hhx"
+		       ", flags=%s%#hx%s, resv2=%#x}",
+		       i ? ", " : "",
+		       probe->ops[i].op, probe->ops[i].resv,
+		       probe->ops[i].flags & 1 ? "IO_URING_OP_SUPPORTED|" : "",
+		       (typeof(probe->ops[i].flags)) (probe->ops[i].flags & ~1),
+		       probe->ops[i].flags & 1 ? "" : " /* IO_URING_OP_??? */",
+		       probe->ops[i].resv2);
+	}
+	printf(", ...]}, %d) = %s\n", DEFAULT_STRLEN + 1, errstr);
+
+	probe->last_op = 0;
+	probe->ops_len = 0;
+	memset(probe->ops, 0, sizeof(probe->ops[0]) * (DEFAULT_STRLEN + 1));
+	sys_io_uring_register(fd_null, IORING_REGISTER_PROBE, probe, 8);
+	printf("io_uring_register(%u<%s>, IORING_REGISTER_PROBE, %p, 8) = %s\n",
+	       fd_null, path_null, probe, errstr);
+# endif
 
 	puts("+++ exited with 0 +++");
 	return 0;
diff -pruN 5.5-3/tests-mx32/io_uring_setup.c 5.9-0ubuntu2/tests-mx32/io_uring_setup.c
--- 5.5-3/tests-mx32/io_uring_setup.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/io_uring_setup.c	2020-09-23 16:29:35.000000000 +0000
@@ -27,6 +27,7 @@
 # include "xlat.h"
 
 # include "xlat/uring_setup_features.h"
+# include "xlat/uring_cqring_flags.h"
 
 # ifdef HAVE_STRUCT_IO_URING_PARAMS_FEATURES
 #  ifdef HAVE_STRUCT_IO_URING_PARAMS_WQ_FD
@@ -144,20 +145,40 @@ main(void)
 						params->sq_off.resv2);
 
 			printf("}, cq_off={head=%u, tail=%u, ring_mask=%u"
-			       ", ring_entries=%u, overflow=%u, cqes=%u",
+			       ", ring_entries=%u, overflow=%u, cqes=%u, flags=",
 			       params->cq_off.head,
 			       params->cq_off.tail,
 			       params->cq_off.ring_mask,
 			       params->cq_off.ring_entries,
 			       params->cq_off.overflow,
 			       params->cq_off.cqes);
-			if (params->cq_off.resv[0] || params->cq_off.resv[1]) {
-				printf(", resv=[%#llx, %#llx]",
+# ifdef HAVE_STRUCT_IO_CQRING_OFFSETS_FLAGS
+			printflags(uring_cqring_flags,
+			       params->cq_off.flags,
+			       "IORING_CQ_???");
+			if (params->cq_off.resv1)
+				printf(", resv1=%#x", params->cq_off.resv1);
+			if (params->cq_off.resv2)
+				printf(", resv2=%#llx",
 				       (unsigned long long)
-						params->cq_off.resv[0],
+						params->cq_off.resv2);
+# else
+			union {
+				struct {
+					uint32_t flags;
+					uint32_t resv1;
+				} s;
+				uint64_t v;
+			} u = { .v = params->cq_off.resv[0] };
+			printflags(uring_cqring_flags, u.s.flags,
+				   "IORING_CQ_???");
+			if (u.s.resv1)
+				printf(", resv1=%#x", u.s.resv1);
+			if (params->cq_off.resv[1])
+				printf(", resv2=%#llx",
 				       (unsigned long long)
 						params->cq_off.resv[1]);
-			}
+# endif
 
 			printf("}}) = %ld<anon_inode:[io_uring]>\n", rc);
 		}
diff -pruN 5.5-3/tests-mx32/ipc_msg.c 5.9-0ubuntu2/tests-mx32/ipc_msg.c
--- 5.5-3/tests-mx32/ipc_msg.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ipc_msg.c	2020-09-19 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2015 Elvira Khabirova <lineprinter0@gmail.com>
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -20,18 +20,24 @@
 # define MSG_STAT_ANY 13
 #endif
 
+#undef TEST_MSGCTL_BOGUS_ADDR
+
+/*
+ * Starting with commit glibc-2.32~83, on every 32-bit architecture
+ * where 32-bit time_t support is enabled, glibc tries to retrieve
+ * the data provided in the third argument of msgctl call.
+ */
+#if GLIBC_PREREQ_GE(2, 32) && defined __TIMESIZE && __TIMESIZE != 64
+# define TEST_MSGCTL_BOGUS_ADDR 0
+#endif
 /*
  * Before glibc-2.22-122-gbe48165, ppc64 code tried to retrieve data
  * provided in third argument of msgctl call (in case of IPC_SET cmd)
  * which led to segmentation fault.
  */
-#undef TEST_MSGCTL_BOGUS_ADDR
-#if defined __GLIBC__ && (defined POWERPC64 || defined POWERPC64LE)
-# if !(defined __GLIBC_MINOR__) \
-   || ((__GLIBC__ << 16) + __GLIBC_MINOR__ < (2 << 16) + 23)
-#  define TEST_MSGCTL_BOGUS_ADDR 0
-# endif
-#endif /* __GLIBC__ && (POWERPC64 || POWERPC64LE) */
+#if GLIBC_PREREQ_LT(2, 23) && (defined POWERPC64 || defined POWERPC64LE)
+# define TEST_MSGCTL_BOGUS_ADDR 0
+#endif
 
 #ifndef TEST_MSGCTL_BOGUS_ADDR
 # define TEST_MSGCTL_BOGUS_ADDR 1
@@ -43,6 +49,7 @@
 # define str_ipc_rmid "0"
 # define str_ipc_set "0x1"
 # define str_ipc_stat "0x2"
+# define str_ipc_info "0x3"
 # define str_msg_stat "0xb"
 # define str_msg_info "0xc"
 # define str_msg_stat_any "0xd"
@@ -55,6 +62,7 @@
 # define str_ipc_rmid "0 /\\* IPC_RMID \\*/"
 # define str_ipc_set "0x1 /\\* IPC_SET \\*/"
 # define str_ipc_stat "0x2 /\\* IPC_STAT \\*/"
+# define str_ipc_info "0x3 /\\* IPC_INFO \\*/"
 # define str_msg_stat "0xb /\\* MSG_STAT \\*/"
 # define str_msg_info "0xc /\\* MSG_INFO \\*/"
 # define str_msg_stat_any "0xd /\\* MSG_STAT_ANY \\*/"
@@ -66,6 +74,7 @@
 # define str_ipc_rmid "IPC_RMID"
 # define str_ipc_set "IPC_SET"
 # define str_ipc_stat "IPC_STAT"
+# define str_ipc_info "IPC_INFO"
 # define str_msg_stat "MSG_STAT"
 # define str_msg_info "MSG_INFO"
 # define str_msg_stat_any "MSG_STAT_ANY"
@@ -84,6 +93,68 @@ cleanup(void)
 	id = -1;
 }
 
+static void
+print_msginfo(const char *const str_ipc_cmd,
+	      const struct msginfo *const info,
+	      const int rc)
+{
+	if (rc < 0) {
+		printf("msgctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
+		       id, str_ipc_64, str_ipc_cmd, info, sprintrc_grep(rc));
+		return;
+	}
+
+	printf("msgctl\\(%d, (%s\\|)?%s, \\{msgpool=%d, msgmap=%d, msgmax=%d"
+	       ", msgmnb=%d, msgmni=%d, msgssz=%d, msgtql=%d, msgseg=%u\\}\\)"
+	       " = %d\n",
+	       id,
+	       str_ipc_64,
+	       str_ipc_cmd,
+	       info->msgpool,
+	       info->msgmap,
+	       info->msgmax,
+	       info->msgmnb,
+	       info->msgmni,
+	       info->msgssz,
+	       info->msgtql,
+	       (unsigned) info->msgseg,
+	       rc);
+}
+
+static void
+print_msqid_ds(const char *const str_ipc_cmd,
+	       const struct msqid_ds *const ds,
+	       const int rc)
+{
+	if (rc < 0) {
+		printf("msgctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
+		       id, str_ipc_64, str_ipc_cmd, ds, sprintrc_grep(rc));
+		return;
+	}
+
+	printf("msgctl\\(%d, (%s\\|)?%s, \\{msg_perm=\\{uid=%u"
+	       ", gid=%u, mode=%#o, key=%u, cuid=%u, cgid=%u\\}"
+	       ", msg_stime=%u, msg_rtime=%u, msg_ctime=%u, msg_qnum=%u"
+	       ", msg_qbytes=%u, msg_lspid=%d, msg_lrpid=%d\\}\\) = %d\n",
+	       id,
+	       str_ipc_64,
+	       str_ipc_cmd,
+	       (unsigned) ds->msg_perm.uid,
+	       (unsigned) ds->msg_perm.gid,
+	       (unsigned) ds->msg_perm.mode,
+	       (unsigned) ds->msg_perm.__key,
+	       (unsigned) ds->msg_perm.cuid,
+	       (unsigned) ds->msg_perm.cgid,
+	       (unsigned) ds->msg_stime,
+	       (unsigned) ds->msg_rtime,
+	       (unsigned) ds->msg_ctime,
+	       (unsigned) ds->msg_qnum,
+	       (unsigned) ds->msg_qbytes,
+	       (int) ds->msg_lspid,
+	       (int) ds->msg_lrpid,
+	       rc);
+}
+
 int
 main(void)
 {
@@ -98,7 +169,10 @@ main(void)
 	static const int bogus_flags = 0xface1e55 & ~IPC_CREAT;
 
 	int rc;
-	struct msqid_ds ds;
+	union {
+		struct msqid_ds ds;
+		struct msginfo info;
+	} buf;
 
 	rc = msgget(bogus_key, bogus_flags);
 	printf("msgget\\(%#llx, %s\\|%#04o\\) = %s\n",
@@ -123,39 +197,32 @@ main(void)
 	       sprintrc_grep(rc));
 #endif
 
-	if (msgctl(id, IPC_STAT, &ds))
+	rc = msgctl(id, IPC_STAT, &buf.ds);
+	if (rc < 0)
 		perror_msg_and_skip("msgctl IPC_STAT");
-	printf("msgctl\\(%d, (%s\\|)?%s, \\{msg_perm=\\{uid=%u"
-	       ", gid=%u, mode=%#o, key=%u, cuid=%u, cgid=%u\\}, msg_stime=%u"
-	       ", msg_rtime=%u, msg_ctime=%u, msg_qnum=%u, msg_qbytes=%u"
-	       ", msg_lspid=%u, msg_lrpid=%u\\}\\) = 0\n",
-	       id, str_ipc_64, str_ipc_stat,
-	       (unsigned) ds.msg_perm.uid, (unsigned) ds.msg_perm.gid,
-	       (unsigned) ds.msg_perm.mode, (unsigned) ds.msg_perm.__key,
-	       (unsigned) ds.msg_perm.cuid, (unsigned) ds.msg_perm.cgid,
-	       (unsigned) ds.msg_stime, (unsigned) ds.msg_rtime,
-	       (unsigned) ds.msg_ctime, (unsigned) ds.msg_qnum,
-	       (unsigned) ds.msg_qbytes, (unsigned) ds.msg_lspid,
-	       (unsigned) ds.msg_lrpid);
+	print_msqid_ds(str_ipc_stat, &buf.ds, rc);
 
-	if (msgctl(id, IPC_SET, &ds))
+	if (msgctl(id, IPC_SET, &buf.ds))
 		perror_msg_and_skip("msgctl IPC_SET");
 	printf("msgctl\\(%d, (%s\\|)?%s, \\{msg_perm=\\{uid=%u"
-	       ", gid=%u, mode=%#o\\}, ...\\}\\) = 0\n",
-	       id, str_ipc_64, str_ipc_set, (unsigned) ds.msg_perm.uid,
-	       (unsigned) ds.msg_perm.gid, (unsigned) ds.msg_perm.mode);
-
-	rc = msgctl(0, MSG_INFO, &ds);
-	printf("msgctl\\(0, (%s\\|)?%s, %p\\) = %s\n",
-	       str_ipc_64, str_msg_info, &ds, sprintrc_grep(rc));
+	       ", gid=%u, mode=%#o\\}, msg_qbytes=%u\\}\\) = 0\n",
+	       id, str_ipc_64, str_ipc_set,
+	       (unsigned) buf.ds.msg_perm.uid,
+	       (unsigned) buf.ds.msg_perm.gid,
+	       (unsigned) buf.ds.msg_perm.mode,
+	       (unsigned) buf.ds.msg_qbytes);
+
+	rc = msgctl(id, IPC_INFO, &buf.ds);
+	print_msginfo(str_ipc_info, &buf.info, rc);
 
-	rc = msgctl(id, MSG_STAT, &ds);
-	printf("msgctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
-	       id, str_ipc_64, str_msg_stat, &ds, sprintrc_grep(rc));
+	rc = msgctl(id, MSG_INFO, &buf.ds);
+	print_msginfo(str_msg_info, &buf.info, rc);
 
-	rc = msgctl(id, MSG_STAT_ANY, &ds);
-	printf("msgctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
-	       id, str_ipc_64, str_msg_stat_any, &ds, sprintrc_grep(rc));
+	rc = msgctl(id, MSG_STAT, &buf.ds);
+	print_msqid_ds(str_msg_stat, &buf.ds, rc);
+
+	rc = msgctl(id, MSG_STAT_ANY, &buf.ds);
+	print_msqid_ds(str_msg_stat_any, &buf.ds, rc);
 
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/ipc_sem.c 5.9-0ubuntu2/tests-mx32/ipc_sem.c
--- 5.5-3/tests-mx32/ipc_sem.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ipc_sem.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2015 Andreas Schwab <schwab@suse.de>
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -11,6 +11,7 @@
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <sys/sem.h>
 
 #include "xlat.h"
@@ -24,7 +25,9 @@
 # define str_ipc_flags "0xface1e00"
 # define str_ipc_private "0"
 # define str_ipc_rmid "0"
+# define str_ipc_set "0x1"
 # define str_ipc_stat "0x2"
+# define str_ipc_info "0x3"
 # define str_sem_stat "0x12"
 # define str_sem_info "0x13"
 # define str_sem_stat_any "0x14"
@@ -35,7 +38,9 @@
 	"0xface1e00 /\\* IPC_CREAT\\|IPC_EXCL\\|IPC_NOWAIT\\|0xface1000 \\*/"
 # define str_ipc_private "0 /\\* IPC_PRIVATE \\*/"
 # define str_ipc_rmid "0 /\\* IPC_RMID \\*/"
+# define str_ipc_set "0x1 /\\* IPC_SET \\*/"
 # define str_ipc_stat "0x2 /\\* IPC_STAT \\*/"
+# define str_ipc_info "0x3 /\\* IPC_INFO \\*/"
 # define str_sem_stat "0x12 /\\* SEM_STAT \\*/"
 # define str_sem_info "0x13 /\\* SEM_INFO \\*/"
 # define str_sem_stat_any "0x14 /\\* SEM_STAT_ANY \\*/"
@@ -45,7 +50,9 @@
 # define str_ipc_flags "IPC_CREAT\\|IPC_EXCL\\|IPC_NOWAIT\\|0xface1000"
 # define str_ipc_private "IPC_PRIVATE"
 # define str_ipc_rmid "IPC_RMID"
+# define str_ipc_set "IPC_SET"
 # define str_ipc_stat "IPC_STAT"
+# define str_ipc_info "IPC_INFO"
 # define str_sem_stat "SEM_STAT"
 # define str_sem_info "SEM_INFO"
 # define str_sem_stat_any "SEM_STAT_ANY"
@@ -72,6 +79,66 @@ cleanup(void)
 	id = -1;
 }
 
+static void
+print_semid_ds(const char *const str_ipc_cmd,
+              const struct semid_ds *const ds,
+              const int rc)
+{
+	if (rc < 0) {
+		printf("semctl\\(%d, 0, (%s\\|)?%s, (%p|\\[%p\\])\\) = %s\n",
+		       id, str_ipc_64, str_ipc_cmd, &ds, &ds,
+		       sprintrc_grep(rc));
+		return;
+	}
+	printf("semctl\\(%d, 0, (%s\\|)?%s, \\{sem_perm=\\{uid=%u, gid=%u"
+		", mode=%#o, key=%u, cuid=%u, cgid=%u\\}, sem_otime=%llu"
+		", sem_ctime=%llu, sem_nsems=%llu\\}\\) = %d\n",
+		id,
+		str_ipc_64,
+		str_ipc_cmd,
+		(unsigned) ds->sem_perm.uid,
+		(unsigned) ds->sem_perm.gid,
+		(unsigned) ds->sem_perm.mode,
+		(unsigned) ds->sem_perm.__key,
+		(unsigned) ds->sem_perm.cuid,
+		(unsigned) ds->sem_perm.cgid,
+		(unsigned long long) ds->sem_otime,
+		(unsigned long long) ds->sem_ctime,
+		(unsigned long long) ds->sem_nsems,
+		rc);
+}
+
+static void
+print_sem_info(const char *const str_ipc_cmd,
+               const struct seminfo *const info,
+               const int rc)
+{
+	if (rc < 0) {
+		printf("semctl\\(%d, 0, (%s\\|)?%s, (%p|\\[%p\\])\\) = %s\n",
+		       id, str_ipc_64, str_ipc_cmd, &info, &info,
+		       sprintrc_grep(rc));
+		return;
+	}
+
+	printf("semctl\\(%d, 0, (%s\\|)?%s, \\{semmap=%d, semmni=%d"
+	       ", semmns=%d, semmnu=%d, semmsl=%d, semopm=%d, semume=%d"
+	       ", semusz=%d, semvmx=%d, semaem=%d\\}\\) = %d\n",
+	       id,
+	       str_ipc_64,
+	       str_ipc_cmd,
+	       info->semmap,
+	       info->semmni,
+	       info->semmns,
+	       info->semmnu,
+	       info->semmsl,
+	       info->semopm,
+	       info->semume,
+	       info->semusz,
+	       info->semvmx,
+	       info->semaem,
+	       rc);
+}
+
 int
 main(void)
 {
@@ -91,6 +158,8 @@ main(void)
 	struct semid_ds ds;
 	struct seminfo info;
 
+	memset(&ds, 0, sizeof(ds));
+
 	rc = semget(bogus_key, bogus_size, bogus_flags);
 	printf("semget\\(%#llx, %d, %s\\|%#04o\\) = %s\n",
 	       zero_extend_signed_to_ull(bogus_key), bogus_size,
@@ -108,25 +177,41 @@ main(void)
 	       bogus_semid, bogus_semnum, str_ipc_64, str_bogus_cmd,
 	       bogus_arg, bogus_arg, sprintrc_grep(rc));
 
+	un.__buf = &info;
+	rc = semctl(id, 0, IPC_INFO, un);
+        print_sem_info(str_ipc_info, &info, rc);
+
+	rc = semctl(id, 0, SEM_INFO, un);
+        print_sem_info(str_sem_info, &info, rc);
+
 	un.buf = &ds;
-	if (semctl(id, 0, IPC_STAT, un))
+	rc = semctl(id, 0, IPC_STAT, un);
+	if (rc < 0)
 		perror_msg_and_skip("semctl IPC_STAT");
-	printf("semctl\\(%d, 0, (%s\\|)?%s, \\[?%p\\]?\\) = 0\n",
-	       id, str_ipc_64, str_ipc_stat, &ds);
+	print_semid_ds(str_ipc_stat, &ds, rc);
 
-	un.__buf = &info;
-	rc = semctl(0, 0, SEM_INFO, un);
-	printf("semctl\\(0, 0, (%s\\|)?%s, \\[?%p\\]?\\) = %s\n",
-	       str_ipc_64, str_sem_info, &info, sprintrc_grep(rc));
+	if (semctl(id, 0, IPC_SET, un))
+		perror_msg_and_skip("semctl IPC_SET");
+	printf("semctl\\(%d, 0, (%s\\|)?%s, \\{sem_perm=\\{uid=%u, gid=%u"
+	       ", mode=%#o\\}\\}\\) = 0\n",
+	       id, str_ipc_64, str_ipc_set,
+	       (unsigned) ds.sem_perm.uid,
+	       (unsigned) ds.sem_perm.gid,
+	       (unsigned) ds.sem_perm.mode);
 
-	un.buf = &ds;
 	rc = semctl(id, 0, SEM_STAT, un);
-	printf("semctl\\(%d, 0, (%s\\|)?%s, \\[?%p\\]?\\) = %s\n",
-	       id, str_ipc_64, str_sem_stat, &ds, sprintrc_grep(rc));
+	print_semid_ds(str_sem_stat, &ds, rc);
 
+/*
+ * glibc fails to pass the buffer for SEM_STAT_ANY command,
+ * so the kernel receives garbage instead of un.buf address:
+ * https://sourceware.org/bugzilla/show_bug.cgi?id=26637
+ * musl doesn't pass the buffer either.
+ */
+#if 0
 	rc = semctl(id, 0, SEM_STAT_ANY, un);
-	printf("semctl\\(%d, 0, (%s\\|)?%s, (%p|\\[(%p|NULL)\\]|NULL)\\) = %s\n",
-	       id, str_ipc_64, str_sem_stat_any, &ds, &ds, sprintrc_grep(rc));
+	print_semid_ds(str_sem_stat_any, &ds, rc);
+#endif
 
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/ipc_shm.c 5.9-0ubuntu2/tests-mx32/ipc_shm.c
--- 5.5-3/tests-mx32/ipc_shm.c	2019-11-28 19:30:05.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ipc_shm.c	2020-09-19 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2015 Elvira Khabirova <lineprinter0@gmail.com>
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -39,6 +39,7 @@
 # define str_ipc_rmid "0"
 # define str_ipc_set "0x1"
 # define str_ipc_stat "0x2"
+# define str_ipc_info "0x3"
 # define str_shm_stat "0xd"
 # define str_shm_info "0xe"
 # define str_shm_stat_any "0xf"
@@ -53,6 +54,7 @@
 # define str_ipc_rmid "0 /\\* IPC_RMID \\*/"
 # define str_ipc_set "0x1 /\\* IPC_SET \\*/"
 # define str_ipc_stat "0x2 /\\* IPC_STAT \\*/"
+# define str_ipc_info "0x3 /\\* IPC_INFO \\*/"
 # define str_shm_stat "0xd /\\* SHM_STAT \\*/"
 # define str_shm_info "0xe /\\* SHM_INFO \\*/"
 # define str_shm_stat_any "0xf /\\* SHM_STAT_ANY \\*/"
@@ -66,6 +68,7 @@
 # define str_ipc_rmid "IPC_RMID"
 # define str_ipc_set "IPC_SET"
 # define str_ipc_stat "IPC_STAT"
+# define str_ipc_info "IPC_INFO"
 # define str_shm_stat "SHM_STAT"
 # define str_shm_info "SHM_INFO"
 # define str_shm_stat_any "SHM_STAT_ANY"
@@ -73,6 +76,21 @@
 # define str_bogus_cmd "0xdefaced2 /\\* SHM_\\?\\?\\? \\*/"
 #endif
 
+#undef TEST_SHMCTL_BOGUS_ADDR
+
+/*
+ * Starting with commit glibc-2.32~80, on every 32-bit architecture
+ * where 32-bit time_t support is enabled, glibc tries to retrieve
+ * the data provided in the third argument of shmctl call.
+ */
+#if GLIBC_PREREQ_GE(2, 32) && defined __TIMESIZE && __TIMESIZE != 64
+# define TEST_SHMCTL_BOGUS_ADDR 0
+#endif
+
+#ifndef TEST_SHMCTL_BOGUS_ADDR
+# define TEST_SHMCTL_BOGUS_ADDR 1
+#endif
+
 static int id = -1;
 
 static void
@@ -84,6 +102,89 @@ cleanup(void)
 	id = -1;
 }
 
+static void
+print_shmid_ds(const char *const str_ipc_cmd,
+	       const struct shmid_ds *const ds,
+	       const int rc)
+{
+	if (rc < 0) {
+		printf("shmctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
+		       id, str_ipc_64, str_ipc_cmd, ds, sprintrc_grep(rc));
+		return;
+	}
+	printf("shmctl\\(%d, (%s\\|)?%s, \\{shm_perm=\\{uid=%u, gid=%u"
+		", mode=%#o, key=%u, cuid=%u, cgid=%u\\}, shm_segsz=%u"
+		", shm_cpid=%d, shm_lpid=%d, shm_nattch=%u, shm_atime=%u"
+		", shm_dtime=%u, shm_ctime=%u\\}\\) = %d\n",
+		id,
+		str_ipc_64,
+		str_ipc_cmd,
+		(unsigned) ds->shm_perm.uid,
+		(unsigned) ds->shm_perm.gid,
+		(unsigned) ds->shm_perm.mode,
+		(unsigned) ds->shm_perm.__key,
+		(unsigned) ds->shm_perm.cuid,
+		(unsigned) ds->shm_perm.cgid,
+		(unsigned) ds->shm_segsz,
+		(int) ds->shm_cpid,
+		(int) ds->shm_lpid,
+		(unsigned) ds->shm_nattch,
+		(unsigned) ds->shm_atime,
+		(unsigned) ds->shm_dtime,
+		(unsigned) ds->shm_ctime,
+		rc);
+}
+
+static void
+print_ipc_info(const char *const str_ipc_cmd,
+               const struct shminfo *const info,
+               const int rc)
+{
+	if (rc < 0) {
+		printf("shmctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
+		       id, str_ipc_64, str_ipc_cmd, info, sprintrc_grep(rc));
+		return;
+	}
+
+	printf("shmctl\\(%d, (%s\\|)?%s, \\{shmmax=%llu, shmmin=%llu"
+	       ", shmmni=%llu, shmseg=%llu, shmall=%llu\\}\\) = %d\n",
+	       id,
+	       str_ipc_64,
+	       str_ipc_cmd,
+	       (unsigned long long) info->shmmax,
+	       (unsigned long long) info->shmmin,
+	       (unsigned long long) info->shmmni,
+	       (unsigned long long) info->shmseg,
+	       (unsigned long long) info->shmall,
+	       rc);
+}
+
+static void
+print_shm_info(const char *const str_ipc_cmd,
+              const struct shm_info *const info,
+              const int rc)
+{
+	if (rc < 0) {
+		printf("shmctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
+		       id, str_ipc_64, str_ipc_cmd, info, sprintrc_grep(rc));
+		return;
+	}
+
+	printf("shmctl\\(%d, (%s\\|)?%s, \\{used_ids=%d, shm_tot=%llu"
+	       ", shm_rss=%llu, shm_swp=%llu, swap_attempts=%llu"
+	       ", swap_successes=%llu\\}\\) = %d\n",
+	       id,
+	       str_ipc_64,
+	       str_ipc_cmd,
+	       info->used_ids,
+	       (unsigned long long) info->shm_tot,
+	       (unsigned long long) info->shm_rss,
+	       (unsigned long long) info->shm_swp,
+	       (unsigned long long) info->swap_attempts,
+	       (unsigned long long) info->swap_successes,
+	       rc);
+}
+
 int
 main(void)
 {
@@ -92,7 +193,9 @@ main(void)
 	static const key_t bogus_key = (key_t) 0xeca86420fdb97531ULL;
 	static const int bogus_id = 0xdefaced1;
 	static const int bogus_cmd = 0xdefaced2;
+#if TEST_SHMCTL_BOGUS_ADDR
 	static void * const bogus_addr = (void *) -1L;
+#endif
 	static const size_t bogus_size =
 	/*
 	 * musl sets size to SIZE_MAX if size argument is greater than
@@ -109,7 +212,11 @@ main(void)
 	static const unsigned int huge_flags = 21 << SHM_HUGE_SHIFT;
 	int bogus_flags;
 	int rc;
-	struct shmid_ds ds;
+	union {
+		struct shmid_ds ds;
+		struct shminfo ipc_info;
+		struct shm_info shm_info;
+	} buf;
 
 	rc = shmget(bogus_key, bogus_size, 0);
 	printf("shmget\\(%#llx, %zu, 000\\) = %s\n",
@@ -160,45 +267,38 @@ main(void)
 	printf("shmctl\\(%d, (%s\\|)?%s, NULL\\) = %s\n",
 	       bogus_id, str_ipc_64, str_bogus_cmd, sprintrc_grep(rc));
 
+#if TEST_SHMCTL_BOGUS_ADDR
 	rc = shmctl(bogus_id, IPC_STAT, bogus_addr);
 	printf("shmctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
 	       bogus_id, str_ipc_64, str_ipc_stat, bogus_addr,
 	       sprintrc_grep(rc));
+#endif
 
-	if (shmctl(id, IPC_STAT, &ds))
+	rc = shmctl(id, IPC_STAT, &buf.ds);
+	if (rc < 0)
 		perror_msg_and_skip("shmctl IPC_STAT");
-	printf("shmctl\\(%d, (%s\\|)?%s, \\{shm_perm=\\{uid=%u, gid=%u, "
-		"mode=%#o, key=%u, cuid=%u, cgid=%u\\}, shm_segsz=%u, shm_cpid=%u, "
-		"shm_lpid=%u, shm_nattch=%u, shm_atime=%u, shm_dtime=%u, "
-		"shm_ctime=%u\\}\\) = 0\n",
-		id, str_ipc_64, str_ipc_stat,
-		(unsigned) ds.shm_perm.uid, (unsigned) ds.shm_perm.gid,
-		(unsigned) ds.shm_perm.mode, (unsigned) ds.shm_perm.__key,
-		(unsigned) ds.shm_perm.cuid, (unsigned) ds.shm_perm.cgid,
-		(unsigned) ds.shm_segsz, (unsigned) ds.shm_cpid,
-		(unsigned) ds.shm_lpid, (unsigned) ds.shm_nattch,
-		(unsigned) ds.shm_atime, (unsigned) ds.shm_dtime,
-		(unsigned) ds. shm_ctime);
+	print_shmid_ds(str_ipc_stat, &buf.ds, rc);
 
-	if (shmctl(id, IPC_SET, &ds))
+	if (shmctl(id, IPC_SET, &buf.ds))
 		perror_msg_and_skip("shmctl IPC_SET");
 	printf("shmctl\\(%d, (%s\\|)?%s, \\{shm_perm=\\{uid=%u, gid=%u"
-	       ", mode=%#o\\}, ...\\}\\) = 0\n",
+	       ", mode=%#o\\}\\}\\) = 0\n",
 	       id, str_ipc_64, str_ipc_set,
-	       (unsigned) ds.shm_perm.uid, (unsigned) ds.shm_perm.gid,
-	       (unsigned) ds.shm_perm.mode);
+	       (unsigned) buf.ds.shm_perm.uid,
+	       (unsigned) buf.ds.shm_perm.gid,
+	       (unsigned) buf.ds.shm_perm.mode);
 
-	rc = shmctl(0, SHM_INFO, &ds);
-	printf("shmctl\\(0, (%s\\|)?%s, %p\\) = %s\n",
-	       str_ipc_64, str_shm_info, &ds, sprintrc_grep(rc));
+	rc = shmctl(id, IPC_INFO, &buf.ds);
+	print_ipc_info(str_ipc_info, &buf.ipc_info, rc);
 
-	rc = shmctl(id, SHM_STAT, &ds);
-	printf("shmctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
-	       id, str_ipc_64, str_shm_stat, &ds, sprintrc_grep(rc));
+	rc = shmctl(id, SHM_INFO, &buf.ds);
+	print_shm_info(str_shm_info, &buf.shm_info, rc);
 
-	rc = shmctl(id, SHM_STAT_ANY, &ds);
-	printf("shmctl\\(%d, (%s\\|)?%s, %p\\) = %s\n",
-	       id, str_ipc_64, str_shm_stat_any, &ds, sprintrc_grep(rc));
+	rc = shmctl(id, SHM_STAT, &buf.ds);
+	print_shmid_ds(str_shm_stat, &buf.ds, rc);
+
+	rc = shmctl(id, SHM_STAT_ANY, &buf.ds);
+	print_shmid_ds(str_shm_stat_any, &buf.ds, rc);
 
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/kcmp.c 5.9-0ubuntu2/tests-mx32/kcmp.c
--- 5.5-3/tests-mx32/kcmp.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/kcmp.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,15 +2,15 @@
  * Check decoding of kcmp syscall.
  *
  * Copyright (c) 2016-2017 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-
 #include "scno.h"
+#include "pidns.h"
 
 #ifdef __NR_kcmp
 
@@ -64,7 +64,26 @@ static const char zero_path[] = "/dev/ze
 static void
 printpidfd(const char *prefix, pid_t pid, unsigned fd)
 {
-	printf("%s%d", prefix, fd);
+	const char *path = NULL;
+
+# if VERBOSE_FD
+	if (pid == getpid()) {
+		switch (fd)
+		{
+		case NULL_FD:
+			path = null_path;
+			break;
+		case ZERO_FD:
+			path = zero_path;
+			break;
+		}
+	}
+# endif
+
+	if (path)
+		printf("%s%d<%s>", prefix, fd, path);
+	else
+		printf("%s%d", prefix, fd);
 }
 
 /*
@@ -82,7 +101,11 @@ do_kcmp(kernel_ulong_t pid1, kernel_ulon
 	rc = syscall(__NR_kcmp, pid1, pid2, type, idx1, idx2);
 	errstr = sprintrc(rc);
 
-	printf("kcmp(%d, %d, ", (int) pid1, (int) pid2);
+	const char *pid_str = pidns_pid2str(PT_TGID);
+	pidns_print_leader();
+	printf("kcmp(%d%s, %d%s, ",
+		(int) pid1, (int) pid1 == getpid() ? pid_str : "",
+		(int) pid2, (int) pid2 == getpid() ? pid_str : "");
 
 	if (type_str)
 		printf("%s", type_str);
@@ -127,6 +150,8 @@ do_kcmp(kernel_ulong_t pid1, kernel_ulon
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	static const kernel_ulong_t bogus_pid1 =
 		(kernel_ulong_t) 0xdeadca75face1057ULL;
 	static const kernel_ulong_t bogus_pid2 =
@@ -179,7 +204,7 @@ main(void)
 	/* KCMP_FILE is the only type which has additional args */
 	do_kcmp(3141592653U, 2718281828U, ARG_STR(KCMP_FILE), bogus_idx1,
 		bogus_idx2);
-	do_kcmp(-1, -1, ARG_STR(KCMP_FILE), NULL_FD, ZERO_FD);
+	do_kcmp(getpid(), getpid(), ARG_STR(KCMP_FILE), NULL_FD, ZERO_FD);
 
 	/* Types without additional args */
 	do_kcmp(-1, -1, ARG_STR(KCMP_VM), bogus_idx1, bogus_idx2);
@@ -198,10 +223,11 @@ main(void)
 	for (i = 0; i < ARRAY_SIZE(slot_data); i++) {
 		memcpy(slot, slot_data + i, sizeof(*slot));
 
-		do_kcmp(getpid(), getppid(), ARG_STR(KCMP_EPOLL_TFD), NULL_FD,
+		do_kcmp(getpid(), -1, ARG_STR(KCMP_EPOLL_TFD), NULL_FD,
 			(uintptr_t) slot, 1);
 	}
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 
 	return 0;
diff -pruN 5.5-3/tests-mx32/kcmp-y--pidns-translation.c 5.9-0ubuntu2/tests-mx32/kcmp-y--pidns-translation.c
--- 5.5-3/tests-mx32/kcmp-y--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/kcmp-y--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "kcmp-y.c"
diff -pruN 5.5-3/tests-mx32/kcmp-y--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/kcmp-y--pidns-translation.gen.test
--- 5.5-3/tests-mx32/kcmp-y--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/kcmp-y--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (kcmp-y--pidns-translation test_pidns -a22 -y -e trace=kcmp); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a22 -y -e trace=kcmp
diff -pruN 5.5-3/tests-mx32/kernel_version.c 5.9-0ubuntu2/tests-mx32/kernel_version.c
--- 5.5-3/tests-mx32/kernel_version.c	2019-12-10 09:44:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/kernel_version.c	2020-09-06 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check kernel version decoding.
  *
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -34,9 +34,9 @@ static void
 print_bpf_attr(void)
 {
 #if XLAT_RAW
-	printf("{prog_type=0x1b"
+	printf("{prog_type=0x1f"
 #else
-	printf("{prog_type=0x1b /* BPF_PROG_TYPE_??? */"
+	printf("{prog_type=0x1f /* BPF_PROG_TYPE_??? */"
 #endif
 		", insn_cnt=3134983661"
 		", insns=NULL"
@@ -79,7 +79,7 @@ main(void)
 {
 	long ret;
 	struct BPF_PROG_LOAD_struct prog = {
-		.prog_type = 27,
+		.prog_type = 31,
 		.insn_cnt = 0xbadc0ded,
 		.insns = 0,
 		.license = 0,
diff -pruN 5.5-3/tests-mx32/kill.c 5.9-0ubuntu2/tests-mx32/kill.c
--- 5.5-3/tests-mx32/kill.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/kill.c	2020-09-23 16:29:35.000000000 +0000
@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
  * Copyright (c) 2016 Fei Jie <feij.fnst@cn.fujitsu.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -11,6 +11,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #ifdef __NR_kill
 
@@ -26,6 +27,8 @@ handler(int sig)
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	const struct sigaction act = { .sa_handler = handler };
 	if (sigaction(SIGALRM, &act, NULL))
 		perror_msg_and_fail("sigaction");
@@ -37,18 +40,23 @@ main(void)
 		perror_msg_and_fail("sigprocmask");
 
 	const int pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
 	long rc = syscall(__NR_kill, pid, (long) 0xdefaced00000000ULL | SIGALRM);
-	printf("kill(%d, SIGALRM) = %ld\n", pid, rc);
+	pidns_print_leader();
+	printf("kill(%d%s, SIGALRM) = %ld\n", pid, pid_str, rc);
 
 	const long big_pid = (long) 0xfacefeedbadc0dedULL;
 	const long big_sig = (long) 0xdeadbeefcafef00dULL;
 	rc = syscall(__NR_kill, big_pid, big_sig);
+	pidns_print_leader();
 	printf("kill(%d, %d) = %ld %s (%m)\n",
 	       (int) big_pid, (int) big_sig, rc, errno2name());
 
 	rc = syscall(__NR_kill, (long) 0xdefaced00000000ULL | pid, 0);
-	printf("kill(%d, 0) = %ld\n", pid, rc);
+	pidns_print_leader();
+	printf("kill(%d%s, 0) = %ld\n", pid, pid_str, rc);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/kill--pidns-translation.c 5.9-0ubuntu2/tests-mx32/kill--pidns-translation.c
--- 5.5-3/tests-mx32/kill--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/kill--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "kill.c"
diff -pruN 5.5-3/tests-mx32/kill--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/kill--pidns-translation.gen.test
--- 5.5-3/tests-mx32/kill--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/kill--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (kill--pidns-translation test_pidns -a12 -e trace=kill -esignal=none); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a12 -e trace=kill -esignal=none
diff -pruN 5.5-3/tests-mx32/looping_threads.test 5.9-0ubuntu2/tests-mx32/looping_threads.test
--- 5.5-3/tests-mx32/looping_threads.test	2019-11-28 19:30:05.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/looping_threads.test	2020-09-03 18:42:36.000000000 +0000
@@ -2,7 +2,7 @@
 #
 # Check tracing of looping threads.
 #
-# Copyright (c) 2009-2019 The strace developers.
+# Copyright (c) 2009-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -20,16 +20,16 @@ inc="$(nproc)"
 [ "$inc" -ge 1 ] || inc=1
 
 timeout_2="$(($TIMEOUT_DURATION/2))"
-timeout_8="$(($TIMEOUT_DURATION/8))"
+timeout_16="$(($TIMEOUT_DURATION/16))"
 nproc=1
 
-run_prog "../$NAME" "$timeout_8" "$nproc"
+run_prog "../$NAME" "$timeout_16" "$nproc"
 
 while :; do
-	run_strace -f -qq -enone -esignal=none "../$NAME" "$timeout_2" "$nproc"
+	run_strace --follow-forks -qq -enone -esignal=none "../$NAME" "$timeout_2" "$nproc"
 
 	s1="$(date +%s)"
-	[ "$(($s1-$s0))" -lt "$timeout_8" ] ||
+	[ "$(($s1-$s0))" -lt "$timeout_16" ] ||
 		break
 
 	nproc="$(($nproc+$inc))"
diff -pruN 5.5-3/tests-mx32/Makefile.am 5.9-0ubuntu2/tests-mx32/Makefile.am
--- 5.5-3/tests-mx32/Makefile.am	2020-02-06 16:23:28.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/Makefile.am	2020-09-24 09:18:51.000000000 +0000
@@ -30,6 +30,7 @@ AM_LDFLAGS = $(ARCH_MFLAGS)
 
 libtests_a_SOURCES = \
 	create_nl_socket.c \
+	create_tmpfile.c \
 	errno2name.c \
 	error_msg.c \
 	fill_memory.c \
@@ -43,6 +44,8 @@ libtests_a_SOURCES = \
 	libsocketcall.c \
 	lock_file.c \
 	overflowuid.c \
+	pidns.c \
+	pidns.h \
 	pipe_maxfd.c \
 	print_quoted_string.c \
 	print_time.c \
@@ -63,6 +66,7 @@ libtests_a_SOURCES = \
 	test_ucopy.h \
 	tests.h \
 	tprintf.c \
+	xmalloc_for_tests.c \
 	# end of libtests_a_SOURCES
 libtests_a_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 check_LIBRARIES = libtests.a
@@ -84,12 +88,20 @@ check_PROGRAMS = $(PURE_EXECUTABLES) \
 	bpf-obj_get_info_by_fd-prog-v \
 	bpf-obj_get_info_by_fd-v \
 	bpf-success \
+	bpf-success-long-y \
 	bpf-success-v \
 	caps-abbrev \
 	check_sigblock \
 	check_sigign \
 	clone_parent \
+	clone_parent--quiet-exit \
+	clone_parent-q \
+	clone_parent-qq \
 	clone_ptrace \
+	clone_ptrace--quiet-attach \
+	clone_ptrace--quiet-exit \
+	clone_ptrace-q \
+	clone_ptrace-qq \
 	clone3-success \
 	clone3-success-Xabbrev \
 	clone3-success-Xraw \
@@ -98,16 +110,25 @@ check_PROGRAMS = $(PURE_EXECUTABLES) \
 	delay \
 	execve-v \
 	execveat-v \
+	fcntl--pidns-translation \
+	fcntl64--pidns-translation \
 	filter_seccomp-flag \
 	filter_seccomp-perf \
 	filter-unavailable \
 	fork-f \
+	fork--pidns-translation \
 	fsync-y \
+	get_process_reaper \
+	getpgrp--pidns-translation	\
 	getpid	\
+	getpid--pidns-translation	\
 	getppid	\
+	getsid--pidns-translation \
 	gettid \
+	gettid--pidns-translation \
 	inject-nf \
 	int_0x80 \
+	ioctl_block--pidns-translation \
 	ioctl_dm-v \
 	ioctl_evdev-success \
 	ioctl_evdev-success-Xabbrev \
@@ -117,22 +138,46 @@ check_PROGRAMS = $(PURE_EXECUTABLES) \
 	ioctl_evdev-success-v-Xabbrev \
 	ioctl_evdev-success-v-Xraw \
 	ioctl_evdev-success-v-Xverbose \
+	ioctl_hdio-success \
+	ioctl_hdio-success-Xabbrev \
+	ioctl_hdio-success-Xraw \
+	ioctl_hdio-success-Xverbose \
+	ioctl_hdio-success-v \
+	ioctl_hdio-success-v-Xabbrev \
+	ioctl_hdio-success-v-Xraw \
+	ioctl_hdio-success-v-Xverbose \
 	ioctl_loop-nv \
 	ioctl_loop-v \
 	ioctl_nsfs \
 	ioctl_perf-success \
 	ioctl_rtc-v \
+	ioctl_v4l2-success \
+	ioctl_v4l2-success-Xabbrev \
+	ioctl_v4l2-success-Xraw \
+	ioctl_v4l2-success-Xverbose \
+	ioctl_v4l2-success-v \
+	ioctl_v4l2-success-v-Xabbrev \
+	ioctl_v4l2-success-v-Xraw \
+	ioctl_v4l2-success-v-Xverbose \
+	ioprio--pidns-translation \
 	is_linux_mips_n64 \
+	kcmp-y--pidns-translation \
 	kill_child \
+	kill--pidns-translation \
 	ksysent \
 	list_sigaction_signum \
 	localtime \
 	looping_threads \
+	migrate_pages--pidns-translation \
 	mmsg-silent \
 	mmsg_name-v \
+	move_pages--pidns-translation \
 	msg_control-v \
 	net-accept-connect \
+	net-sockaddr--pidns-translation \
 	net-tpacket_stats-success \
+	nlattr_ifla_xdp-y \
+	netlink_audit--pidns-translation \
 	netlink_inet_diag \
 	netlink_netlink_diag \
 	netlink_unix_diag \
@@ -144,11 +189,20 @@ check_PROGRAMS = $(PURE_EXECUTABLES) \
 	pc \
 	perf_event_open_nonverbose \
 	perf_event_open_unabbrev \
+	pidfd_open--pidns-translation \
+	pidfd_send_signal--pidns-translation \
+	pidns-cache \
+	poll-P \
+	ppoll-P \
 	ppoll-v \
+	prlimit64--pidns-translation \
 	prctl-seccomp-filter-v \
 	prctl-seccomp-strict \
 	prctl-spec-inject \
 	print_maxfd \
+	print_ppid_tracerpid \
+	process_vm_readv--pidns-translation \
+	process_vm_writev--pidns-translation \
 	qual_fault \
 	qual_inject-error-signal \
 	qual_inject-retval \
@@ -162,7 +216,13 @@ check_PROGRAMS = $(PURE_EXECUTABLES) \
 	quotactl-xfs-v \
 	redirect-fds \
 	restart_syscall \
+	rt_sigqueueinfo--pidns-translation \
+	rt_tgsigqueueinfo--pidns-translation \
 	run_expect_termsig \
+	sched_xetaffinity--pidns-translation \
+	sched_xetattr--pidns-translation \
+	sched_xetparam--pidns-translation \
+	sched_xetscheduler--pidns-translation \
 	scm_rights \
 	seccomp-filter-v \
 	seccomp-strict \
@@ -170,22 +230,35 @@ check_PROGRAMS = $(PURE_EXECUTABLES) \
 	set_ptracer_any \
 	set_sigblock \
 	set_sigign \
+	setpgrp-exec \
 	signal_receive \
+	signal_receive--pidns-translation \
 	sleep \
 	stack-fcall \
 	stack-fcall-attach \
 	stack-fcall-mangled \
 	status-none-threads \
 	status-unfinished-threads \
+	so_peercred--pidns-translation \
 	syslog-success \
+	tgkill--pidns-translation \
 	threads-execve \
+	threads-execve--quiet-thread-execve \
+	threads-execve-q \
+	threads-execve-qq \
+	threads-execve-qqq \
+	tkill--pidns-translation \
 	tracer_ppid_pgid_sid \
+	trie_test \
 	unblock_reset_raise \
 	unix-pair-send-recv \
 	unix-pair-sendto-recvfrom \
 	vfork-f \
 	wait4-v \
 	waitid-v \
+	xetpgid--pidns-translation \
+	xetpriority--pidns-translation \
+	xet_robust_list--pidns-translation \
 	zeroargc \
 	# end of check_PROGRAMS
 
@@ -200,6 +273,7 @@ localtime_LDADD = $(clock_LIBS) $(LDADD)
 looping_threads_LDADD = -lpthread $(LDADD)
 lstat64_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 maybe_switch_current_tcp_LDADD = -lpthread $(LDADD)
+maybe_switch_current_tcp__quiet_thread_execve_LDADD = -lpthread $(LDADD)
 mmap64_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 mmap64_Xabbrev_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 mmap64_Xraw_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
@@ -216,6 +290,10 @@ statfs_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE
 status_none_threads_LDADD = -lpthread $(LDADD)
 status_unfinished_threads_LDADD = -lpthread $(LDADD)
 threads_execve_LDADD = -lpthread $(clock_LIBS) $(LDADD)
+threads_execve__quiet_thread_execve_LDADD = -lpthread $(clock_LIBS) $(LDADD)
+threads_execve_q_LDADD = -lpthread $(clock_LIBS) $(LDADD)
+threads_execve_qq_LDADD = -lpthread $(clock_LIBS) $(LDADD)
+threads_execve_qqq_LDADD = -lpthread $(clock_LIBS) $(LDADD)
 times_LDADD = $(clock_LIBS) $(LDADD)
 truncate64_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 uio_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
@@ -230,6 +308,11 @@ stack_fcall_mangled_SOURCES = stack-fcal
 	stack-fcall-mangled-0.c stack-fcall-mangled-1.c \
 	stack-fcall-mangled-2.c stack-fcall-mangled-3.c
 
+trie_test_SOURCES = trie_test.c trie_for_tests.c
+trie_test_CPPFLAGS = $(AM_CPPFLAGS) $(CODE_COVERAGE_CPPFLAGS)
+trie_test_CFLAGS = $(AM_CFLAGS) $(CODE_COVERAGE_CFLAGS)
+trie_test_LDADD = $(LDADD) $(CODE_COVERAGE_LIBS)
+
 include gen_tests.am
 
 if ENABLE_STACKTRACE
@@ -242,6 +325,7 @@ STACKTRACE_TESTS =
 endif
 
 DECODER_TESTS = \
+	bpf-success-long-y.test \
 	bpf-success-v.test \
 	bpf-success.test \
 	brk.test \
@@ -260,13 +344,15 @@ DECODER_TESTS = \
 	execve-v.test \
 	execve.test \
 	fadvise64.test \
+	faccessat.test \
+	faccessat2.test \
 	futex.test \
 	getuid.test \
 	int_0x80.test \
 	inotify_init-y.test \
 	ioctl.test \
+	ioctl_block--pidns-translation.test \
 	ioctl_evdev-success.test \
-	ioctl_perf-success.test \
 	ipc_msgbuf.test \
 	kern_features-fault.test \
 	llseek.test \
@@ -324,7 +410,6 @@ MISC_TESTS = \
 	attach-f-p.test \
 	attach-p-cmd.test \
 	bexecve.test \
-	clone_parent.test \
 	clone_ptrace.test \
 	count-f.test \
 	count.test \
@@ -338,15 +423,19 @@ MISC_TESTS = \
 	filtering_fd-syntax.test \
 	filtering_syscall-syntax.test \
 	first_exec_failure.test \
+	fork--pidns-translation.test \
 	get_regs.test \
+	gettid--pidns-translation.test \
 	inject-nf.test \
 	interactive_block.test \
 	kill_child.test \
 	localtime.test \
 	looping_threads.test \
+	netlink_audit--pidns-translation.test \
 	opipe.test \
 	options-syntax.test \
 	pc.test \
+	pidns-cache.test \
 	printpath-umovestr-legacy.test \
 	printstrn-umoven-legacy.test \
 	qual_fault-syntax.test \
@@ -374,6 +463,8 @@ MISC_TESTS = \
 	strace-DD.test \
 	strace-DDD.test \
 	strace-E.test \
+	strace-E-override.test \
+	strace-E-unset.test \
 	strace-S.test \
 	strace-T.test \
 	strace-V.test \
@@ -422,6 +513,7 @@ EXTRA_DIST = \
 	filter_seccomp.in \
 	filter_seccomp.sh \
 	filter-unavailable.expected \
+	fork--pidns-translation.awk \
 	fstatat.c \
 	fstatx.c \
 	gen_pure_executables.sh \
@@ -430,6 +522,7 @@ EXTRA_DIST = \
 	getresugid.c \
 	init.sh \
 	init_delete_module.h \
+	ioctl-success.sh \
 	ioctl_kvm_run_common.c \
 	ipc.sh \
 	kernel_old_timespec.h \
@@ -438,7 +531,6 @@ EXTRA_DIST = \
 	lstatx.c \
 	match.awk \
 	net.expected \
-	netlink_sock_diag-v.sh \
 	nlattr_ifla.h \
 	pipe.expected \
 	print_user_desc.c \
@@ -467,11 +559,22 @@ EXTRA_DIST = \
 	sockname.c \
 	stack-fcall.h \
 	status-detached.expected \
+	strace--follow-forks-output-separately.expected \
+	strace--relative-timestamps.expected \
+	strace--relative-timestamps-s.expected \
+	strace--relative-timestamps-ms.expected \
+	strace--relative-timestamps-us.expected \
+	strace--relative-timestamps-ns.expected \
+	strace--syscall-times.expected \
+	strace--syscall-times-s.expected \
+	strace--syscall-times-ms.expected \
+	strace--syscall-times-us.expected \
+	strace--syscall-times-ns.expected \
 	strace-C.expected \
 	strace-D.expected \
-	strace-DD.expected \
 	strace-DDD.expected \
 	strace-E.expected \
+	strace-E-unset.expected \
 	strace-T.expected \
 	strace-ff.expected \
 	strace-k-demangle.expected \
@@ -484,6 +587,7 @@ EXTRA_DIST = \
 	strace.supp \
 	sun_path.expected \
 	syntax.sh \
+	trace_clock.in \
 	trace_creds.in \
 	trace_fstat.in \
 	trace_fstatfs.in \
@@ -505,6 +609,7 @@ EXTRA_DIST = \
 	unix-pair-send-recv.expected \
 	unix-pair-sendto-recvfrom.expected \
 	xchownx.c \
+	xgetdents.c \
 	xgetrlimit.c \
 	xselect.c \
 	xstatfs.c \
diff -pruN 5.5-3/tests-mx32/Makefile.in 5.9-0ubuntu2/tests-mx32/Makefile.in
--- 5.5-3/tests-mx32/Makefile.in	2020-02-06 16:23:36.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/Makefile.in	2020-09-24 09:19:02.000000000 +0000
@@ -1,7 +1,7 @@
-# Makefile.in generated by automake 1.16.1 from Makefile.am.
+# Makefile.in generated by automake 1.16.2 from Makefile.am.
 # @configure_input@
 
-# Copyright (C) 1994-2018 Free Software Foundation, Inc.
+# Copyright (C) 1994-2020 Free Software Foundation, Inc.
 
 # This Makefile.in is free software; the Free Software Foundation
 # gives unlimited permission to copy and/or distribute it,
@@ -110,69 +110,161 @@ check_PROGRAMS = $(am__EXEEXT_1) _newsel
 	bpf-obj_get_info_by_fd-prog$(EXEEXT) \
 	bpf-obj_get_info_by_fd-prog-v$(EXEEXT) \
 	bpf-obj_get_info_by_fd-v$(EXEEXT) bpf-success$(EXEEXT) \
-	bpf-success-v$(EXEEXT) caps-abbrev$(EXEEXT) \
-	check_sigblock$(EXEEXT) check_sigign$(EXEEXT) \
-	clone_parent$(EXEEXT) clone_ptrace$(EXEEXT) \
-	clone3-success$(EXEEXT) clone3-success-Xabbrev$(EXEEXT) \
-	clone3-success-Xraw$(EXEEXT) clone3-success-Xverbose$(EXEEXT) \
-	count-f$(EXEEXT) delay$(EXEEXT) execve-v$(EXEEXT) \
-	execveat-v$(EXEEXT) filter_seccomp-flag$(EXEEXT) \
-	filter_seccomp-perf$(EXEEXT) filter-unavailable$(EXEEXT) \
-	fork-f$(EXEEXT) fsync-y$(EXEEXT) getpid$(EXEEXT) \
-	getppid$(EXEEXT) gettid$(EXEEXT) inject-nf$(EXEEXT) \
-	int_0x80$(EXEEXT) ioctl_dm-v$(EXEEXT) \
-	ioctl_evdev-success$(EXEEXT) \
+	bpf-success-long-y$(EXEEXT) bpf-success-v$(EXEEXT) \
+	caps-abbrev$(EXEEXT) check_sigblock$(EXEEXT) \
+	check_sigign$(EXEEXT) clone_parent$(EXEEXT) \
+	clone_parent--quiet-exit$(EXEEXT) clone_parent-q$(EXEEXT) \
+	clone_parent-qq$(EXEEXT) clone_ptrace$(EXEEXT) \
+	clone_ptrace--quiet-attach$(EXEEXT) \
+	clone_ptrace--quiet-exit$(EXEEXT) clone_ptrace-q$(EXEEXT) \
+	clone_ptrace-qq$(EXEEXT) clone3-success$(EXEEXT) \
+	clone3-success-Xabbrev$(EXEEXT) clone3-success-Xraw$(EXEEXT) \
+	clone3-success-Xverbose$(EXEEXT) count-f$(EXEEXT) \
+	delay$(EXEEXT) execve-v$(EXEEXT) execveat-v$(EXEEXT) \
+	fcntl--pidns-translation$(EXEEXT) \
+	fcntl64--pidns-translation$(EXEEXT) \
+	filter_seccomp-flag$(EXEEXT) filter_seccomp-perf$(EXEEXT) \
+	filter-unavailable$(EXEEXT) fork-f$(EXEEXT) \
+	fork--pidns-translation$(EXEEXT) fsync-y$(EXEEXT) \
+	get_process_reaper$(EXEEXT) \
+	getpgrp--pidns-translation$(EXEEXT) getpid$(EXEEXT) \
+	getpid--pidns-translation$(EXEEXT) getppid$(EXEEXT) \
+	getsid--pidns-translation$(EXEEXT) gettid$(EXEEXT) \
+	gettid--pidns-translation$(EXEEXT) inject-nf$(EXEEXT) \
+	int_0x80$(EXEEXT) ioctl_block--pidns-translation$(EXEEXT) \
+	ioctl_dm-v$(EXEEXT) ioctl_evdev-success$(EXEEXT) \
 	ioctl_evdev-success-Xabbrev$(EXEEXT) \
 	ioctl_evdev-success-Xraw$(EXEEXT) \
 	ioctl_evdev-success-Xverbose$(EXEEXT) \
 	ioctl_evdev-success-v$(EXEEXT) \
 	ioctl_evdev-success-v-Xabbrev$(EXEEXT) \
 	ioctl_evdev-success-v-Xraw$(EXEEXT) \
-	ioctl_evdev-success-v-Xverbose$(EXEEXT) ioctl_loop-nv$(EXEEXT) \
+	ioctl_evdev-success-v-Xverbose$(EXEEXT) \
+	ioctl_hdio-success$(EXEEXT) \
+	ioctl_hdio-success-Xabbrev$(EXEEXT) \
+	ioctl_hdio-success-Xraw$(EXEEXT) \
+	ioctl_hdio-success-Xverbose$(EXEEXT) \
+	ioctl_hdio-success-v$(EXEEXT) \
+	ioctl_hdio-success-v-Xabbrev$(EXEEXT) \
+	ioctl_hdio-success-v-Xraw$(EXEEXT) \
+	ioctl_hdio-success-v-Xverbose$(EXEEXT) ioctl_loop-nv$(EXEEXT) \
 	ioctl_loop-v$(EXEEXT) ioctl_nsfs$(EXEEXT) \
 	ioctl_perf-success$(EXEEXT) ioctl_rtc-v$(EXEEXT) \
-	is_linux_mips_n64$(EXEEXT) kill_child$(EXEEXT) \
-	ksysent$(EXEEXT) list_sigaction_signum$(EXEEXT) \
-	localtime$(EXEEXT) looping_threads$(EXEEXT) \
-	mmsg-silent$(EXEEXT) mmsg_name-v$(EXEEXT) \
+	ioctl_v4l2-success$(EXEEXT) \
+	ioctl_v4l2-success-Xabbrev$(EXEEXT) \
+	ioctl_v4l2-success-Xraw$(EXEEXT) \
+	ioctl_v4l2-success-Xverbose$(EXEEXT) \
+	ioctl_v4l2-success-v$(EXEEXT) \
+	ioctl_v4l2-success-v-Xabbrev$(EXEEXT) \
+	ioctl_v4l2-success-v-Xraw$(EXEEXT) \
+	ioctl_v4l2-success-v-Xverbose$(EXEEXT) \
+	ioprio--pidns-translation$(EXEEXT) is_linux_mips_n64$(EXEEXT) \
+	kcmp-y--pidns-translation$(EXEEXT) kill_child$(EXEEXT) \
+	kill--pidns-translation$(EXEEXT) ksysent$(EXEEXT) \
+	list_sigaction_signum$(EXEEXT) localtime$(EXEEXT) \
+	looping_threads$(EXEEXT) \
+	migrate_pages--pidns-translation$(EXEEXT) mmsg-silent$(EXEEXT) \
+	mmsg_name-v$(EXEEXT) move_pages--pidns-translation$(EXEEXT) \
 	msg_control-v$(EXEEXT) net-accept-connect$(EXEEXT) \
-	net-tpacket_stats-success$(EXEEXT) netlink_inet_diag$(EXEEXT) \
-	netlink_netlink_diag$(EXEEXT) netlink_unix_diag$(EXEEXT) \
-	nsyscalls$(EXEEXT) nsyscalls-d$(EXEEXT) oldselect-P$(EXEEXT) \
+	net-sockaddr--pidns-translation$(EXEEXT) \
+	net-tpacket_stats-success$(EXEEXT) nlattr_ifla_xdp-y$(EXEEXT) \
+	netlink_audit--pidns-translation$(EXEEXT) \
+	netlink_inet_diag$(EXEEXT) netlink_netlink_diag$(EXEEXT) \
+	netlink_unix_diag$(EXEEXT) nsyscalls$(EXEEXT) \
+	nsyscalls-d$(EXEEXT) oldselect-P$(EXEEXT) \
 	oldselect-efault-P$(EXEEXT) orphaned_process_group$(EXEEXT) \
 	pc$(EXEEXT) perf_event_open_nonverbose$(EXEEXT) \
-	perf_event_open_unabbrev$(EXEEXT) ppoll-v$(EXEEXT) \
+	perf_event_open_unabbrev$(EXEEXT) \
+	pidfd_open--pidns-translation$(EXEEXT) \
+	pidfd_send_signal--pidns-translation$(EXEEXT) \
+	pidns-cache$(EXEEXT) poll-P$(EXEEXT) ppoll-P$(EXEEXT) \
+	ppoll-v$(EXEEXT) prlimit64--pidns-translation$(EXEEXT) \
 	prctl-seccomp-filter-v$(EXEEXT) prctl-seccomp-strict$(EXEEXT) \
 	prctl-spec-inject$(EXEEXT) print_maxfd$(EXEEXT) \
+	print_ppid_tracerpid$(EXEEXT) \
+	process_vm_readv--pidns-translation$(EXEEXT) \
+	process_vm_writev--pidns-translation$(EXEEXT) \
 	qual_fault$(EXEEXT) qual_inject-error-signal$(EXEEXT) \
 	qual_inject-retval$(EXEEXT) qual_inject-signal$(EXEEXT) \
 	qual_signal$(EXEEXT) quotactl-success$(EXEEXT) \
 	quotactl-success-v$(EXEEXT) quotactl-v$(EXEEXT) \
 	quotactl-xfs-success$(EXEEXT) quotactl-xfs-success-v$(EXEEXT) \
 	quotactl-xfs-v$(EXEEXT) redirect-fds$(EXEEXT) \
-	restart_syscall$(EXEEXT) run_expect_termsig$(EXEEXT) \
+	restart_syscall$(EXEEXT) \
+	rt_sigqueueinfo--pidns-translation$(EXEEXT) \
+	rt_tgsigqueueinfo--pidns-translation$(EXEEXT) \
+	run_expect_termsig$(EXEEXT) \
+	sched_xetaffinity--pidns-translation$(EXEEXT) \
+	sched_xetattr--pidns-translation$(EXEEXT) \
+	sched_xetparam--pidns-translation$(EXEEXT) \
+	sched_xetscheduler--pidns-translation$(EXEEXT) \
 	scm_rights$(EXEEXT) seccomp-filter-v$(EXEEXT) \
 	seccomp-strict$(EXEEXT) select-P$(EXEEXT) \
 	set_ptracer_any$(EXEEXT) set_sigblock$(EXEEXT) \
-	set_sigign$(EXEEXT) signal_receive$(EXEEXT) sleep$(EXEEXT) \
+	set_sigign$(EXEEXT) setpgrp-exec$(EXEEXT) \
+	signal_receive$(EXEEXT) \
+	signal_receive--pidns-translation$(EXEEXT) sleep$(EXEEXT) \
 	stack-fcall$(EXEEXT) stack-fcall-attach$(EXEEXT) \
 	stack-fcall-mangled$(EXEEXT) status-none-threads$(EXEEXT) \
-	status-unfinished-threads$(EXEEXT) syslog-success$(EXEEXT) \
-	threads-execve$(EXEEXT) tracer_ppid_pgid_sid$(EXEEXT) \
+	status-unfinished-threads$(EXEEXT) \
+	so_peercred--pidns-translation$(EXEEXT) \
+	syslog-success$(EXEEXT) tgkill--pidns-translation$(EXEEXT) \
+	threads-execve$(EXEEXT) \
+	threads-execve--quiet-thread-execve$(EXEEXT) \
+	threads-execve-q$(EXEEXT) threads-execve-qq$(EXEEXT) \
+	threads-execve-qqq$(EXEEXT) tkill--pidns-translation$(EXEEXT) \
+	tracer_ppid_pgid_sid$(EXEEXT) trie_test$(EXEEXT) \
 	unblock_reset_raise$(EXEEXT) unix-pair-send-recv$(EXEEXT) \
 	unix-pair-sendto-recvfrom$(EXEEXT) vfork-f$(EXEEXT) \
-	wait4-v$(EXEEXT) waitid-v$(EXEEXT) zeroargc$(EXEEXT)
+	wait4-v$(EXEEXT) waitid-v$(EXEEXT) \
+	xetpgid--pidns-translation$(EXEEXT) \
+	xetpriority--pidns-translation$(EXEEXT) \
+	xet_robust_list--pidns-translation$(EXEEXT) zeroargc$(EXEEXT)
 @ENABLE_STACKTRACE_TRUE@@USE_DEMANGLE_TRUE@am__append_1 = strace-k-demangle.test
 TESTS = $(GEN_TESTS) $(DECODER_TESTS) $(MISC_TESTS) $(am__EXEEXT_2)
 subdir = tests-mx32
 ACLOCAL_M4 = $(top_srcdir)/aclocal.m4
-am__aclocal_m4_deps = $(top_srcdir)/types/check-cryptouser.m4 \
+am__aclocal_m4_deps = $(top_srcdir)/xlat/btrfs_compress_types.m4 \
+	$(top_srcdir)/xlat/close_range_flags.m4 \
+	$(top_srcdir)/xlat/loop_flags_options.m4 \
+	$(top_srcdir)/xlat/rtnl_ifla_xdp_attached_mode.m4 \
+	$(top_srcdir)/xlat/rtnl_ifla_xdp_attrs.m4 \
+	$(top_srcdir)/xlat/rtnl_link_attrs.m4 \
+	$(top_srcdir)/xlat/rtnl_tc_action_attrs.m4 \
+	$(top_srcdir)/xlat/rtnl_tca_stab_attrs.m4 \
+	$(top_srcdir)/xlat/rtnl_tca_stats_attrs.m4 \
+	$(top_srcdir)/xlat/st_check_enums.m4 \
+	$(top_srcdir)/xlat/sysctl_kern.m4 \
+	$(top_srcdir)/xlat/sysctl_net.m4 \
+	$(top_srcdir)/xlat/sysctl_net_core.m4 \
+	$(top_srcdir)/xlat/sysctl_net_ipv4.m4 \
+	$(top_srcdir)/xlat/sysctl_net_ipv4_conf.m4 \
+	$(top_srcdir)/xlat/sysctl_net_ipv4_route.m4 \
+	$(top_srcdir)/xlat/sysctl_net_ipv6.m4 \
+	$(top_srcdir)/xlat/sysctl_net_ipv6_route.m4 \
+	$(top_srcdir)/xlat/sysctl_net_unix.m4 \
+	$(top_srcdir)/xlat/sysctl_root.m4 \
+	$(top_srcdir)/xlat/sysctl_vm.m4 \
+	$(top_srcdir)/xlat/v4l2_buf_types.m4 \
+	$(top_srcdir)/xlat/v4l2_colorspaces.m4 \
+	$(top_srcdir)/xlat/v4l2_control_types.m4 \
+	$(top_srcdir)/xlat/v4l2_fields.m4 \
+	$(top_srcdir)/xlat/v4l2_framesize_types.m4 \
+	$(top_srcdir)/xlat/v4l2_memories.m4 \
+	$(top_srcdir)/xlat/v4l2_tuner_types.m4 \
+	$(top_srcdir)/xlat/waitid_types.m4 \
+	$(top_srcdir)/types/check-btrfs.m4 \
+	$(top_srcdir)/types/check-cryptouser.m4 \
 	$(top_srcdir)/types/check-evdev.m4 \
 	$(top_srcdir)/types/check-io_uring.m4 \
+	$(top_srcdir)/types/check-loop.m4 \
+	$(top_srcdir)/types/check-openat2.m4 \
 	$(top_srcdir)/types/check-rtnl_link.m4 \
 	$(top_srcdir)/types/check-rtnl_mdb.m4 \
 	$(top_srcdir)/types/check-rtnl_neightbl.m4 \
 	$(top_srcdir)/types/check-rtnl_route.m4 \
+	$(top_srcdir)/types/check-tee.m4 \
+	$(top_srcdir)/types/check-v4l2.m4 \
 	$(top_srcdir)/types/st_check_types.m4 \
 	$(top_srcdir)/m4/ax_code_coverage.m4 \
 	$(top_srcdir)/m4/ax_prog_cc_for_build.m4 \
@@ -201,12 +293,21 @@ am__EXEEXT_1 = _newselect$(EXEEXT) accep
 	clock_nanosleep$(EXEEXT) clock_xettime$(EXEEXT) \
 	clone-flags$(EXEEXT) clone3$(EXEEXT) clone3-Xabbrev$(EXEEXT) \
 	clone3-Xraw$(EXEEXT) clone3-Xverbose$(EXEEXT) \
+	close_range$(EXEEXT) close_range-P$(EXEEXT) \
+	close_range-y$(EXEEXT) close_range-yy$(EXEEXT) \
 	copy_file_range$(EXEEXT) creat$(EXEEXT) delete_module$(EXEEXT) \
-	dev-yy$(EXEEXT) dup$(EXEEXT) dup2$(EXEEXT) dup3$(EXEEXT) \
+	dev--decode-fds-dev$(EXEEXT) dev--decode-fds-path$(EXEEXT) \
+	dev--decode-fds-socket$(EXEEXT) dev-yy$(EXEEXT) dup$(EXEEXT) \
+	dup-P$(EXEEXT) dup-y$(EXEEXT) dup-yy$(EXEEXT) dup2$(EXEEXT) \
+	dup2-P$(EXEEXT) dup2-y$(EXEEXT) dup2-yy$(EXEEXT) dup3$(EXEEXT) \
+	dup3-P$(EXEEXT) dup3-y$(EXEEXT) dup3-yy$(EXEEXT) \
 	epoll_create$(EXEEXT) epoll_create1$(EXEEXT) \
 	epoll_ctl$(EXEEXT) epoll_pwait$(EXEEXT) epoll_wait$(EXEEXT) \
 	erestartsys$(EXEEXT) eventfd$(EXEEXT) execve$(EXEEXT) \
-	execveat$(EXEEXT) faccessat$(EXEEXT) fadvise64$(EXEEXT) \
+	execveat$(EXEEXT) faccessat$(EXEEXT) faccessat-P$(EXEEXT) \
+	faccessat-y$(EXEEXT) faccessat-yy$(EXEEXT) faccessat2$(EXEEXT) \
+	faccessat2-P$(EXEEXT) faccessat2-y$(EXEEXT) \
+	faccessat2-yy$(EXEEXT) fadvise64$(EXEEXT) \
 	fadvise64_64$(EXEEXT) fallocate$(EXEEXT) \
 	fanotify_init$(EXEEXT) fanotify_mark$(EXEEXT) \
 	fanotify_mark-Xabbrev$(EXEEXT) fanotify_mark-Xraw$(EXEEXT) \
@@ -224,17 +325,18 @@ am__EXEEXT_1 = _newselect$(EXEEXT) accep
 	fstatfs64$(EXEEXT) fsync$(EXEEXT) ftruncate$(EXEEXT) \
 	ftruncate64$(EXEEXT) futex$(EXEEXT) futimesat$(EXEEXT) \
 	get_mempolicy$(EXEEXT) getcpu$(EXEEXT) getcwd$(EXEEXT) \
-	getdents$(EXEEXT) getdents64$(EXEEXT) getegid$(EXEEXT) \
-	getegid32$(EXEEXT) geteuid$(EXEEXT) geteuid32$(EXEEXT) \
-	getgid$(EXEEXT) getgid32$(EXEEXT) getgroups$(EXEEXT) \
-	getgroups32$(EXEEXT) getpeername$(EXEEXT) getpgrp$(EXEEXT) \
-	getpid$(EXEEXT) getppid$(EXEEXT) getrandom$(EXEEXT) \
-	getresgid$(EXEEXT) getresgid32$(EXEEXT) getresuid$(EXEEXT) \
-	getresuid32$(EXEEXT) getrlimit$(EXEEXT) getrusage$(EXEEXT) \
-	getsid$(EXEEXT) getsockname$(EXEEXT) getuid$(EXEEXT) \
-	getuid32$(EXEEXT) getxxid$(EXEEXT) group_req$(EXEEXT) \
-	inet-cmsg$(EXEEXT) init_module$(EXEEXT) inotify$(EXEEXT) \
-	inotify_init$(EXEEXT) inotify_init-y$(EXEEXT) \
+	getdents$(EXEEXT) getdents-v$(EXEEXT) getdents64$(EXEEXT) \
+	getdents64-v$(EXEEXT) getegid$(EXEEXT) getegid32$(EXEEXT) \
+	geteuid$(EXEEXT) geteuid32$(EXEEXT) getgid$(EXEEXT) \
+	getgid32$(EXEEXT) getgroups$(EXEEXT) getgroups32$(EXEEXT) \
+	getpeername$(EXEEXT) getpgrp$(EXEEXT) getpid$(EXEEXT) \
+	getppid$(EXEEXT) getrandom$(EXEEXT) getresgid$(EXEEXT) \
+	getresgid32$(EXEEXT) getresuid$(EXEEXT) getresuid32$(EXEEXT) \
+	getrlimit$(EXEEXT) getrusage$(EXEEXT) getsid$(EXEEXT) \
+	getsockname$(EXEEXT) getuid$(EXEEXT) getuid32$(EXEEXT) \
+	getxgid$(EXEEXT) getxpid$(EXEEXT) getxuid$(EXEEXT) \
+	group_req$(EXEEXT) inet-cmsg$(EXEEXT) init_module$(EXEEXT) \
+	inotify$(EXEEXT) inotify_init$(EXEEXT) inotify_init-y$(EXEEXT) \
 	inotify_init1$(EXEEXT) inotify_init1-y$(EXEEXT) \
 	io_uring_enter$(EXEEXT) io_uring_register$(EXEEXT) \
 	io_uring_setup$(EXEEXT) ioctl$(EXEEXT) ioctl_block$(EXEEXT) \
@@ -242,16 +344,24 @@ am__EXEEXT_1 = _newselect$(EXEEXT) accep
 	ioctl_evdev-Xabbrev$(EXEEXT) ioctl_evdev-Xraw$(EXEEXT) \
 	ioctl_evdev-Xverbose$(EXEEXT) ioctl_evdev-v$(EXEEXT) \
 	ioctl_evdev-v-Xabbrev$(EXEEXT) ioctl_evdev-v-Xraw$(EXEEXT) \
-	ioctl_evdev-v-Xverbose$(EXEEXT) ioctl_inotify$(EXEEXT) \
+	ioctl_evdev-v-Xverbose$(EXEEXT) ioctl_hdio$(EXEEXT) \
+	ioctl_hdio-Xabbrev$(EXEEXT) ioctl_hdio-Xraw$(EXEEXT) \
+	ioctl_hdio-Xverbose$(EXEEXT) ioctl_hdio-v$(EXEEXT) \
+	ioctl_hdio-v-Xabbrev$(EXEEXT) ioctl_hdio-v-Xraw$(EXEEXT) \
+	ioctl_hdio-v-Xverbose$(EXEEXT) ioctl_inotify$(EXEEXT) \
 	ioctl_kvm_run$(EXEEXT) ioctl_kvm_run-v$(EXEEXT) \
 	ioctl_kvm_run_auxstr_vcpu$(EXEEXT) ioctl_loop$(EXEEXT) \
 	ioctl_mtd$(EXEEXT) ioctl_nbd$(EXEEXT) ioctl_perf$(EXEEXT) \
 	ioctl_ptp$(EXEEXT) ioctl_random$(EXEEXT) ioctl_rtc$(EXEEXT) \
 	ioctl_scsi$(EXEEXT) ioctl_sg_io_v3$(EXEEXT) \
 	ioctl_sg_io_v4$(EXEEXT) ioctl_sock_gifconf$(EXEEXT) \
-	ioctl_uffdio$(EXEEXT) ioctl_v4l2$(EXEEXT) \
-	ioctl_watchdog$(EXEEXT) ioperm$(EXEEXT) iopl$(EXEEXT) \
-	ioprio$(EXEEXT) ioprio-Xabbrev$(EXEEXT) ioprio-Xraw$(EXEEXT) \
+	ioctl_tee$(EXEEXT) ioctl_uffdio$(EXEEXT) ioctl_v4l2$(EXEEXT) \
+	ioctl_v4l2-Xabbrev$(EXEEXT) ioctl_v4l2-Xraw$(EXEEXT) \
+	ioctl_v4l2-Xverbose$(EXEEXT) ioctl_v4l2-v$(EXEEXT) \
+	ioctl_v4l2-v-Xabbrev$(EXEEXT) ioctl_v4l2-v-Xraw$(EXEEXT) \
+	ioctl_v4l2-v-Xverbose$(EXEEXT) ioctl_watchdog$(EXEEXT) \
+	ioperm$(EXEEXT) iopl$(EXEEXT) ioprio$(EXEEXT) \
+	ioprio-Xabbrev$(EXEEXT) ioprio-Xraw$(EXEEXT) \
 	ioprio-Xverbose$(EXEEXT) ip_mreq$(EXEEXT) ipc$(EXEEXT) \
 	ipc_msg$(EXEEXT) ipc_msg-Xabbrev$(EXEEXT) \
 	ipc_msg-Xraw$(EXEEXT) ipc_msg-Xverbose$(EXEEXT) \
@@ -270,6 +380,7 @@ am__EXEEXT_1 = _newselect$(EXEEXT) accep
 	linkat$(EXEEXT) llseek$(EXEEXT) lookup_dcookie$(EXEEXT) \
 	lseek$(EXEEXT) lstat$(EXEEXT) lstat64$(EXEEXT) \
 	madvise$(EXEEXT) maybe_switch_current_tcp$(EXEEXT) \
+	maybe_switch_current_tcp--quiet-thread-execve$(EXEEXT) \
 	mbind$(EXEEXT) mbind-Xabbrev$(EXEEXT) mbind-Xraw$(EXEEXT) \
 	mbind-Xverbose$(EXEEXT) membarrier$(EXEEXT) \
 	memfd_create$(EXEEXT) memfd_create-Xabbrev$(EXEEXT) \
@@ -288,9 +399,12 @@ am__EXEEXT_1 = _newselect$(EXEEXT) accep
 	move_pages-Xverbose$(EXEEXT) mq$(EXEEXT) mq_sendrecv$(EXEEXT) \
 	mq_sendrecv-read$(EXEEXT) mq_sendrecv-write$(EXEEXT) \
 	msg_control$(EXEEXT) msg_name$(EXEEXT) munlockall$(EXEEXT) \
-	nanosleep$(EXEEXT) net-icmp_filter$(EXEEXT) \
-	net-packet_mreq$(EXEEXT) net-packet_mreq-Xabbrev$(EXEEXT) \
-	net-packet_mreq-Xraw$(EXEEXT) \
+	nanosleep$(EXEEXT) net--decode-fds-dev-netlink$(EXEEXT) \
+	net--decode-fds-none-netlink$(EXEEXT) \
+	net--decode-fds-path-netlink$(EXEEXT) \
+	net--decode-fds-socket-netlink$(EXEEXT) \
+	net-icmp_filter$(EXEEXT) net-packet_mreq$(EXEEXT) \
+	net-packet_mreq-Xabbrev$(EXEEXT) net-packet_mreq-Xraw$(EXEEXT) \
 	net-packet_mreq-Xverbose$(EXEEXT) net-sockaddr$(EXEEXT) \
 	net-tpacket_req$(EXEEXT) net-tpacket_stats$(EXEEXT) \
 	net-y-unix$(EXEEXT) net-yy-inet$(EXEEXT) net-yy-inet6$(EXEEXT) \
@@ -329,19 +443,27 @@ am__EXEEXT_1 = _newselect$(EXEEXT) accep
 	old_mmap-v-none$(EXEEXT) oldfstat$(EXEEXT) oldlstat$(EXEEXT) \
 	oldselect$(EXEEXT) oldselect-efault$(EXEEXT) oldstat$(EXEEXT) \
 	open$(EXEEXT) open_tree$(EXEEXT) open_tree-P$(EXEEXT) \
-	openat$(EXEEXT) osf_utimes$(EXEEXT) pause$(EXEEXT) \
-	perf_event_open$(EXEEXT) personality$(EXEEXT) \
-	personality-Xabbrev$(EXEEXT) personality-Xraw$(EXEEXT) \
-	personality-Xverbose$(EXEEXT) pidfd_open$(EXEEXT) \
-	pidfd_open-P$(EXEEXT) pidfd_open-y$(EXEEXT) \
+	openat$(EXEEXT) openat2$(EXEEXT) openat2-Xabbrev$(EXEEXT) \
+	openat2-Xraw$(EXEEXT) openat2-Xverbose$(EXEEXT) \
+	openat2-v$(EXEEXT) openat2-v-y$(EXEEXT) \
+	openat2-v-y-Xabbrev$(EXEEXT) openat2-v-y-Xraw$(EXEEXT) \
+	openat2-v-y-Xverbose$(EXEEXT) openat2-y$(EXEEXT) \
+	osf_utimes$(EXEEXT) pause$(EXEEXT) perf_event_open$(EXEEXT) \
+	personality$(EXEEXT) personality-Xabbrev$(EXEEXT) \
+	personality-Xraw$(EXEEXT) personality-Xverbose$(EXEEXT) \
+	pidfd_getfd$(EXEEXT) pidfd_getfd-y$(EXEEXT) \
+	pidfd_getfd-yy$(EXEEXT) pidfd_open$(EXEEXT) \
+	pidfd_open--decode-fd-path$(EXEEXT) \
+	pidfd_open--decode-fd-pidfd$(EXEEXT) \
+	pidfd_open--decode-fd-socket$(EXEEXT) pidfd_open-P$(EXEEXT) \
+	pidfd_open-y$(EXEEXT) pidfd_open-yy$(EXEEXT) \
 	pidfd_send_signal$(EXEEXT) pipe$(EXEEXT) pipe2$(EXEEXT) \
 	pkey_alloc$(EXEEXT) pkey_free$(EXEEXT) pkey_mprotect$(EXEEXT) \
-	poll$(EXEEXT) poll-P$(EXEEXT) ppoll$(EXEEXT) ppoll-P$(EXEEXT) \
-	prctl-arg2-intptr$(EXEEXT) prctl-dumpable$(EXEEXT) \
-	prctl-name$(EXEEXT) prctl-no-args$(EXEEXT) \
-	prctl-pdeathsig$(EXEEXT) prctl-securebits$(EXEEXT) \
-	prctl-tid_address$(EXEEXT) prctl-tsc$(EXEEXT) \
-	pread64-pwrite64$(EXEEXT) preadv$(EXEEXT) \
+	poll$(EXEEXT) ppoll$(EXEEXT) prctl-arg2-intptr$(EXEEXT) \
+	prctl-dumpable$(EXEEXT) prctl-name$(EXEEXT) \
+	prctl-no-args$(EXEEXT) prctl-pdeathsig$(EXEEXT) \
+	prctl-securebits$(EXEEXT) prctl-tid_address$(EXEEXT) \
+	prctl-tsc$(EXEEXT) pread64-pwrite64$(EXEEXT) preadv$(EXEEXT) \
 	preadv-pwritev$(EXEEXT) preadv2-pwritev2$(EXEEXT) \
 	printpath-umovestr$(EXEEXT) \
 	printpath-umovestr-peekdata$(EXEEXT) \
@@ -402,29 +524,35 @@ am__EXEEXT_1 = _newselect$(EXEEXT) accep
 	sockopt-sol_netlink$(EXEEXT) sockopt-timestamp$(EXEEXT) \
 	splice$(EXEEXT) stat$(EXEEXT) stat64$(EXEEXT) statfs$(EXEEXT) \
 	statfs64$(EXEEXT) status-all$(EXEEXT) status-failed$(EXEEXT) \
+	status-failed-long$(EXEEXT) status-failed-status$(EXEEXT) \
 	status-none$(EXEEXT) status-none-f$(EXEEXT) \
-	status-successful$(EXEEXT) status-unfinished$(EXEEXT) \
-	statx$(EXEEXT) swap$(EXEEXT) sxetmask$(EXEEXT) \
-	symlink$(EXEEXT) symlinkat$(EXEEXT) sync$(EXEEXT) \
-	sync_file_range$(EXEEXT) sync_file_range2$(EXEEXT) \
-	sysinfo$(EXEEXT) syslog$(EXEEXT) tee$(EXEEXT) time$(EXEEXT) \
+	status-successful$(EXEEXT) status-successful-long$(EXEEXT) \
+	status-successful-status$(EXEEXT) status-unfinished$(EXEEXT) \
+	statx$(EXEEXT) strace--strings-in-hex$(EXEEXT) \
+	strace--strings-in-hex-all$(EXEEXT) \
+	strace--strings-in-hex-non-ascii$(EXEEXT) strace-n$(EXEEXT) \
+	strace-x$(EXEEXT) strace-xx$(EXEEXT) swap$(EXEEXT) \
+	sxetmask$(EXEEXT) symlink$(EXEEXT) symlinkat$(EXEEXT) \
+	sync$(EXEEXT) sync_file_range$(EXEEXT) \
+	sync_file_range2$(EXEEXT) sysinfo$(EXEEXT) syslog$(EXEEXT) \
+	tee$(EXEEXT) tgkill$(EXEEXT) time$(EXEEXT) \
 	timer_create$(EXEEXT) timer_xettime$(EXEEXT) \
 	timerfd_xettime$(EXEEXT) times$(EXEEXT) times-fail$(EXEEXT) \
-	truncate$(EXEEXT) truncate64$(EXEEXT) ugetrlimit$(EXEEXT) \
-	uio$(EXEEXT) umask$(EXEEXT) umount$(EXEEXT) umount2$(EXEEXT) \
-	umoven-illptr$(EXEEXT) umovestr$(EXEEXT) \
-	umovestr-illptr$(EXEEXT) umovestr2$(EXEEXT) umovestr3$(EXEEXT) \
-	umovestr_cached$(EXEEXT) uname$(EXEEXT) unlink$(EXEEXT) \
-	unlinkat$(EXEEXT) unshare$(EXEEXT) userfaultfd$(EXEEXT) \
-	ustat$(EXEEXT) utime$(EXEEXT) utimensat$(EXEEXT) \
-	utimensat-Xabbrev$(EXEEXT) utimensat-Xraw$(EXEEXT) \
-	utimensat-Xverbose$(EXEEXT) utimes$(EXEEXT) vhangup$(EXEEXT) \
-	vmsplice$(EXEEXT) wait4$(EXEEXT) waitid$(EXEEXT) \
-	waitpid$(EXEEXT) xattr$(EXEEXT) xattr-strings$(EXEEXT) \
-	xet_robust_list$(EXEEXT) xet_thread_area_x86$(EXEEXT) \
-	xetitimer$(EXEEXT) xetpgid$(EXEEXT) xetpriority$(EXEEXT) \
-	xettimeofday$(EXEEXT)
-AR = ar
+	tkill$(EXEEXT) truncate$(EXEEXT) truncate64$(EXEEXT) \
+	ugetrlimit$(EXEEXT) uio$(EXEEXT) umask$(EXEEXT) \
+	umount$(EXEEXT) umount2$(EXEEXT) umoven-illptr$(EXEEXT) \
+	umovestr$(EXEEXT) umovestr-illptr$(EXEEXT) umovestr2$(EXEEXT) \
+	umovestr3$(EXEEXT) umovestr_cached$(EXEEXT) \
+	umovestr_cached_adjacent$(EXEEXT) uname$(EXEEXT) \
+	unlink$(EXEEXT) unlinkat$(EXEEXT) unshare$(EXEEXT) \
+	userfaultfd$(EXEEXT) ustat$(EXEEXT) utime$(EXEEXT) \
+	utimensat$(EXEEXT) utimensat-Xabbrev$(EXEEXT) \
+	utimensat-Xraw$(EXEEXT) utimensat-Xverbose$(EXEEXT) \
+	utimes$(EXEEXT) vhangup$(EXEEXT) vmsplice$(EXEEXT) \
+	wait4$(EXEEXT) waitid$(EXEEXT) waitpid$(EXEEXT) xattr$(EXEEXT) \
+	xattr-strings$(EXEEXT) xet_robust_list$(EXEEXT) \
+	xet_thread_area_x86$(EXEEXT) xetitimer$(EXEEXT) \
+	xetpgid$(EXEEXT) xetpriority$(EXEEXT) xettimeofday$(EXEEXT)
 ARFLAGS = cru
 AM_V_AR = $(am__v_AR_@AM_V@)
 am__v_AR_ = $(am__v_AR_@AM_DEFAULT_V@)
@@ -433,6 +561,7 @@ am__v_AR_1 =
 libtests_a_AR = $(AR) $(ARFLAGS)
 libtests_a_LIBADD =
 am_libtests_a_OBJECTS = libtests_a-create_nl_socket.$(OBJEXT) \
+	libtests_a-create_tmpfile.$(OBJEXT) \
 	libtests_a-errno2name.$(OBJEXT) libtests_a-error_msg.$(OBJEXT) \
 	libtests_a-fill_memory.$(OBJEXT) \
 	libtests_a-get_page_size.$(OBJEXT) \
@@ -444,7 +573,7 @@ am_libtests_a_OBJECTS = libtests_a-creat
 	libtests_a-libmmsg.$(OBJEXT) \
 	libtests_a-libsocketcall.$(OBJEXT) \
 	libtests_a-lock_file.$(OBJEXT) \
-	libtests_a-overflowuid.$(OBJEXT) \
+	libtests_a-overflowuid.$(OBJEXT) libtests_a-pidns.$(OBJEXT) \
 	libtests_a-pipe_maxfd.$(OBJEXT) \
 	libtests_a-print_quoted_string.$(OBJEXT) \
 	libtests_a-print_time.$(OBJEXT) \
@@ -458,7 +587,8 @@ am_libtests_a_OBJECTS = libtests_a-creat
 	libtests_a-tail_alloc.$(OBJEXT) \
 	libtests_a-test_printpath.$(OBJEXT) \
 	libtests_a-test_printstrn.$(OBJEXT) \
-	libtests_a-test_ucopy.$(OBJEXT) libtests_a-tprintf.$(OBJEXT)
+	libtests_a-test_ucopy.$(OBJEXT) libtests_a-tprintf.$(OBJEXT) \
+	libtests_a-xmalloc_for_tests.$(OBJEXT)
 libtests_a_OBJECTS = $(am_libtests_a_OBJECTS)
 _newselect_SOURCES = _newselect.c
 _newselect_OBJECTS = _newselect.$(OBJEXT)
@@ -558,6 +688,10 @@ bpf_success_SOURCES = bpf-success.c
 bpf_success_OBJECTS = bpf-success.$(OBJEXT)
 bpf_success_LDADD = $(LDADD)
 bpf_success_DEPENDENCIES = libtests.a
+bpf_success_long_y_SOURCES = bpf-success-long-y.c
+bpf_success_long_y_OBJECTS = bpf-success-long-y.$(OBJEXT)
+bpf_success_long_y_LDADD = $(LDADD)
+bpf_success_long_y_DEPENDENCIES = libtests.a
 bpf_success_v_SOURCES = bpf-success-v.c
 bpf_success_v_OBJECTS = bpf-success-v.$(OBJEXT)
 bpf_success_v_LDADD = $(LDADD)
@@ -658,10 +792,55 @@ clone_parent_SOURCES = clone_parent.c
 clone_parent_OBJECTS = clone_parent.$(OBJEXT)
 clone_parent_LDADD = $(LDADD)
 clone_parent_DEPENDENCIES = libtests.a
+clone_parent__quiet_exit_SOURCES = clone_parent--quiet-exit.c
+clone_parent__quiet_exit_OBJECTS = clone_parent--quiet-exit.$(OBJEXT)
+clone_parent__quiet_exit_LDADD = $(LDADD)
+clone_parent__quiet_exit_DEPENDENCIES = libtests.a
+clone_parent_q_SOURCES = clone_parent-q.c
+clone_parent_q_OBJECTS = clone_parent-q.$(OBJEXT)
+clone_parent_q_LDADD = $(LDADD)
+clone_parent_q_DEPENDENCIES = libtests.a
+clone_parent_qq_SOURCES = clone_parent-qq.c
+clone_parent_qq_OBJECTS = clone_parent-qq.$(OBJEXT)
+clone_parent_qq_LDADD = $(LDADD)
+clone_parent_qq_DEPENDENCIES = libtests.a
 clone_ptrace_SOURCES = clone_ptrace.c
 clone_ptrace_OBJECTS = clone_ptrace.$(OBJEXT)
 clone_ptrace_LDADD = $(LDADD)
 clone_ptrace_DEPENDENCIES = libtests.a
+clone_ptrace__quiet_attach_SOURCES = clone_ptrace--quiet-attach.c
+clone_ptrace__quiet_attach_OBJECTS =  \
+	clone_ptrace--quiet-attach.$(OBJEXT)
+clone_ptrace__quiet_attach_LDADD = $(LDADD)
+clone_ptrace__quiet_attach_DEPENDENCIES = libtests.a
+clone_ptrace__quiet_exit_SOURCES = clone_ptrace--quiet-exit.c
+clone_ptrace__quiet_exit_OBJECTS = clone_ptrace--quiet-exit.$(OBJEXT)
+clone_ptrace__quiet_exit_LDADD = $(LDADD)
+clone_ptrace__quiet_exit_DEPENDENCIES = libtests.a
+clone_ptrace_q_SOURCES = clone_ptrace-q.c
+clone_ptrace_q_OBJECTS = clone_ptrace-q.$(OBJEXT)
+clone_ptrace_q_LDADD = $(LDADD)
+clone_ptrace_q_DEPENDENCIES = libtests.a
+clone_ptrace_qq_SOURCES = clone_ptrace-qq.c
+clone_ptrace_qq_OBJECTS = clone_ptrace-qq.$(OBJEXT)
+clone_ptrace_qq_LDADD = $(LDADD)
+clone_ptrace_qq_DEPENDENCIES = libtests.a
+close_range_SOURCES = close_range.c
+close_range_OBJECTS = close_range.$(OBJEXT)
+close_range_LDADD = $(LDADD)
+close_range_DEPENDENCIES = libtests.a
+close_range_P_SOURCES = close_range-P.c
+close_range_P_OBJECTS = close_range-P.$(OBJEXT)
+close_range_P_LDADD = $(LDADD)
+close_range_P_DEPENDENCIES = libtests.a
+close_range_y_SOURCES = close_range-y.c
+close_range_y_OBJECTS = close_range-y.$(OBJEXT)
+close_range_y_LDADD = $(LDADD)
+close_range_y_DEPENDENCIES = libtests.a
+close_range_yy_SOURCES = close_range-yy.c
+close_range_yy_OBJECTS = close_range-yy.$(OBJEXT)
+close_range_yy_LDADD = $(LDADD)
+close_range_yy_DEPENDENCIES = libtests.a
 copy_file_range_SOURCES = copy_file_range.c
 copy_file_range_OBJECTS = copy_file_range.$(OBJEXT)
 copy_file_range_LDADD = $(LDADD)
@@ -681,6 +860,18 @@ delete_module_SOURCES = delete_module.c
 delete_module_OBJECTS = delete_module.$(OBJEXT)
 delete_module_LDADD = $(LDADD)
 delete_module_DEPENDENCIES = libtests.a
+dev__decode_fds_dev_SOURCES = dev--decode-fds-dev.c
+dev__decode_fds_dev_OBJECTS = dev--decode-fds-dev.$(OBJEXT)
+dev__decode_fds_dev_LDADD = $(LDADD)
+dev__decode_fds_dev_DEPENDENCIES = libtests.a
+dev__decode_fds_path_SOURCES = dev--decode-fds-path.c
+dev__decode_fds_path_OBJECTS = dev--decode-fds-path.$(OBJEXT)
+dev__decode_fds_path_LDADD = $(LDADD)
+dev__decode_fds_path_DEPENDENCIES = libtests.a
+dev__decode_fds_socket_SOURCES = dev--decode-fds-socket.c
+dev__decode_fds_socket_OBJECTS = dev--decode-fds-socket.$(OBJEXT)
+dev__decode_fds_socket_LDADD = $(LDADD)
+dev__decode_fds_socket_DEPENDENCIES = libtests.a
 dev_yy_SOURCES = dev-yy.c
 dev_yy_OBJECTS = dev-yy.$(OBJEXT)
 dev_yy_LDADD = $(LDADD)
@@ -689,14 +880,50 @@ dup_SOURCES = dup.c
 dup_OBJECTS = dup.$(OBJEXT)
 dup_LDADD = $(LDADD)
 dup_DEPENDENCIES = libtests.a
+dup_P_SOURCES = dup-P.c
+dup_P_OBJECTS = dup-P.$(OBJEXT)
+dup_P_LDADD = $(LDADD)
+dup_P_DEPENDENCIES = libtests.a
+dup_y_SOURCES = dup-y.c
+dup_y_OBJECTS = dup-y.$(OBJEXT)
+dup_y_LDADD = $(LDADD)
+dup_y_DEPENDENCIES = libtests.a
+dup_yy_SOURCES = dup-yy.c
+dup_yy_OBJECTS = dup-yy.$(OBJEXT)
+dup_yy_LDADD = $(LDADD)
+dup_yy_DEPENDENCIES = libtests.a
 dup2_SOURCES = dup2.c
 dup2_OBJECTS = dup2.$(OBJEXT)
 dup2_LDADD = $(LDADD)
 dup2_DEPENDENCIES = libtests.a
+dup2_P_SOURCES = dup2-P.c
+dup2_P_OBJECTS = dup2-P.$(OBJEXT)
+dup2_P_LDADD = $(LDADD)
+dup2_P_DEPENDENCIES = libtests.a
+dup2_y_SOURCES = dup2-y.c
+dup2_y_OBJECTS = dup2-y.$(OBJEXT)
+dup2_y_LDADD = $(LDADD)
+dup2_y_DEPENDENCIES = libtests.a
+dup2_yy_SOURCES = dup2-yy.c
+dup2_yy_OBJECTS = dup2-yy.$(OBJEXT)
+dup2_yy_LDADD = $(LDADD)
+dup2_yy_DEPENDENCIES = libtests.a
 dup3_SOURCES = dup3.c
 dup3_OBJECTS = dup3.$(OBJEXT)
 dup3_LDADD = $(LDADD)
 dup3_DEPENDENCIES = libtests.a
+dup3_P_SOURCES = dup3-P.c
+dup3_P_OBJECTS = dup3-P.$(OBJEXT)
+dup3_P_LDADD = $(LDADD)
+dup3_P_DEPENDENCIES = libtests.a
+dup3_y_SOURCES = dup3-y.c
+dup3_y_OBJECTS = dup3-y.$(OBJEXT)
+dup3_y_LDADD = $(LDADD)
+dup3_y_DEPENDENCIES = libtests.a
+dup3_yy_SOURCES = dup3-yy.c
+dup3_yy_OBJECTS = dup3-yy.$(OBJEXT)
+dup3_yy_LDADD = $(LDADD)
+dup3_yy_DEPENDENCIES = libtests.a
 epoll_create_SOURCES = epoll_create.c
 epoll_create_OBJECTS = epoll_create.$(OBJEXT)
 epoll_create_LDADD = $(LDADD)
@@ -745,6 +972,34 @@ faccessat_SOURCES = faccessat.c
 faccessat_OBJECTS = faccessat.$(OBJEXT)
 faccessat_LDADD = $(LDADD)
 faccessat_DEPENDENCIES = libtests.a
+faccessat_P_SOURCES = faccessat-P.c
+faccessat_P_OBJECTS = faccessat-P.$(OBJEXT)
+faccessat_P_LDADD = $(LDADD)
+faccessat_P_DEPENDENCIES = libtests.a
+faccessat_y_SOURCES = faccessat-y.c
+faccessat_y_OBJECTS = faccessat-y.$(OBJEXT)
+faccessat_y_LDADD = $(LDADD)
+faccessat_y_DEPENDENCIES = libtests.a
+faccessat_yy_SOURCES = faccessat-yy.c
+faccessat_yy_OBJECTS = faccessat-yy.$(OBJEXT)
+faccessat_yy_LDADD = $(LDADD)
+faccessat_yy_DEPENDENCIES = libtests.a
+faccessat2_SOURCES = faccessat2.c
+faccessat2_OBJECTS = faccessat2.$(OBJEXT)
+faccessat2_LDADD = $(LDADD)
+faccessat2_DEPENDENCIES = libtests.a
+faccessat2_P_SOURCES = faccessat2-P.c
+faccessat2_P_OBJECTS = faccessat2-P.$(OBJEXT)
+faccessat2_P_LDADD = $(LDADD)
+faccessat2_P_DEPENDENCIES = libtests.a
+faccessat2_y_SOURCES = faccessat2-y.c
+faccessat2_y_OBJECTS = faccessat2-y.$(OBJEXT)
+faccessat2_y_LDADD = $(LDADD)
+faccessat2_y_DEPENDENCIES = libtests.a
+faccessat2_yy_SOURCES = faccessat2-yy.c
+faccessat2_yy_OBJECTS = faccessat2-yy.$(OBJEXT)
+faccessat2_yy_LDADD = $(LDADD)
+faccessat2_yy_DEPENDENCIES = libtests.a
 fadvise64_SOURCES = fadvise64.c
 fadvise64_OBJECTS = fadvise64.$(OBJEXT)
 fadvise64_LDADD = $(LDADD)
@@ -805,10 +1060,19 @@ fcntl_SOURCES = fcntl.c
 fcntl_OBJECTS = fcntl.$(OBJEXT)
 fcntl_LDADD = $(LDADD)
 fcntl_DEPENDENCIES = libtests.a
+fcntl__pidns_translation_SOURCES = fcntl--pidns-translation.c
+fcntl__pidns_translation_OBJECTS = fcntl--pidns-translation.$(OBJEXT)
+fcntl__pidns_translation_LDADD = $(LDADD)
+fcntl__pidns_translation_DEPENDENCIES = libtests.a
 fcntl64_SOURCES = fcntl64.c
 fcntl64_OBJECTS = fcntl64.$(OBJEXT)
 fcntl64_LDADD = $(LDADD)
 fcntl64_DEPENDENCIES = libtests.a
+fcntl64__pidns_translation_SOURCES = fcntl64--pidns-translation.c
+fcntl64__pidns_translation_OBJECTS =  \
+	fcntl64--pidns-translation.$(OBJEXT)
+fcntl64__pidns_translation_LDADD = $(LDADD)
+fcntl64__pidns_translation_DEPENDENCIES = libtests.a
 fdatasync_SOURCES = fdatasync.c
 fdatasync_OBJECTS = fdatasync.$(OBJEXT)
 fdatasync_LDADD = $(LDADD)
@@ -844,6 +1108,10 @@ flock_SOURCES = flock.c
 flock_OBJECTS = flock.$(OBJEXT)
 flock_LDADD = $(LDADD)
 flock_DEPENDENCIES = libtests.a
+fork__pidns_translation_SOURCES = fork--pidns-translation.c
+fork__pidns_translation_OBJECTS = fork--pidns-translation.$(OBJEXT)
+fork__pidns_translation_LDADD = $(LDADD)
+fork__pidns_translation_DEPENDENCIES = libtests.a
 fork_f_SOURCES = fork-f.c
 fork_f_OBJECTS = fork-f.$(OBJEXT)
 fork_f_LDADD = $(LDADD)
@@ -944,6 +1212,10 @@ get_mempolicy_SOURCES = get_mempolicy.c
 get_mempolicy_OBJECTS = get_mempolicy.$(OBJEXT)
 get_mempolicy_LDADD = $(LDADD)
 get_mempolicy_DEPENDENCIES = libtests.a
+get_process_reaper_SOURCES = get_process_reaper.c
+get_process_reaper_OBJECTS = get_process_reaper.$(OBJEXT)
+get_process_reaper_LDADD = $(LDADD)
+get_process_reaper_DEPENDENCIES = libtests.a
 getcpu_SOURCES = getcpu.c
 getcpu_OBJECTS = getcpu.$(OBJEXT)
 getcpu_LDADD = $(LDADD)
@@ -956,10 +1228,18 @@ getdents_SOURCES = getdents.c
 getdents_OBJECTS = getdents.$(OBJEXT)
 getdents_LDADD = $(LDADD)
 getdents_DEPENDENCIES = libtests.a
+getdents_v_SOURCES = getdents-v.c
+getdents_v_OBJECTS = getdents-v.$(OBJEXT)
+getdents_v_LDADD = $(LDADD)
+getdents_v_DEPENDENCIES = libtests.a
 getdents64_SOURCES = getdents64.c
 getdents64_OBJECTS = getdents64.$(OBJEXT)
 getdents64_LDADD = $(LDADD)
 getdents64_DEPENDENCIES = libtests.a
+getdents64_v_SOURCES = getdents64-v.c
+getdents64_v_OBJECTS = getdents64-v.$(OBJEXT)
+getdents64_v_LDADD = $(LDADD)
+getdents64_v_DEPENDENCIES = libtests.a
 getegid_SOURCES = getegid.c
 getegid_OBJECTS = getegid.$(OBJEXT)
 getegid_LDADD = $(LDADD)
@@ -1000,10 +1280,20 @@ getpgrp_SOURCES = getpgrp.c
 getpgrp_OBJECTS = getpgrp.$(OBJEXT)
 getpgrp_LDADD = $(LDADD)
 getpgrp_DEPENDENCIES = libtests.a
+getpgrp__pidns_translation_SOURCES = getpgrp--pidns-translation.c
+getpgrp__pidns_translation_OBJECTS =  \
+	getpgrp--pidns-translation.$(OBJEXT)
+getpgrp__pidns_translation_LDADD = $(LDADD)
+getpgrp__pidns_translation_DEPENDENCIES = libtests.a
 getpid_SOURCES = getpid.c
 getpid_OBJECTS = getpid.$(OBJEXT)
 getpid_LDADD = $(LDADD)
 getpid_DEPENDENCIES = libtests.a
+getpid__pidns_translation_SOURCES = getpid--pidns-translation.c
+getpid__pidns_translation_OBJECTS =  \
+	getpid--pidns-translation.$(OBJEXT)
+getpid__pidns_translation_LDADD = $(LDADD)
+getpid__pidns_translation_DEPENDENCIES = libtests.a
 getppid_SOURCES = getppid.c
 getppid_OBJECTS = getppid.$(OBJEXT)
 getppid_LDADD = $(LDADD)
@@ -1040,6 +1330,11 @@ getsid_SOURCES = getsid.c
 getsid_OBJECTS = getsid.$(OBJEXT)
 getsid_LDADD = $(LDADD)
 getsid_DEPENDENCIES = libtests.a
+getsid__pidns_translation_SOURCES = getsid--pidns-translation.c
+getsid__pidns_translation_OBJECTS =  \
+	getsid--pidns-translation.$(OBJEXT)
+getsid__pidns_translation_LDADD = $(LDADD)
+getsid__pidns_translation_DEPENDENCIES = libtests.a
 getsockname_SOURCES = getsockname.c
 getsockname_OBJECTS = getsockname.$(OBJEXT)
 getsockname_LDADD = $(LDADD)
@@ -1048,6 +1343,11 @@ gettid_SOURCES = gettid.c
 gettid_OBJECTS = gettid.$(OBJEXT)
 gettid_LDADD = $(LDADD)
 gettid_DEPENDENCIES = libtests.a
+gettid__pidns_translation_SOURCES = gettid--pidns-translation.c
+gettid__pidns_translation_OBJECTS =  \
+	gettid--pidns-translation.$(OBJEXT)
+gettid__pidns_translation_LDADD = $(LDADD)
+gettid__pidns_translation_DEPENDENCIES = libtests.a
 getuid_SOURCES = getuid.c
 getuid_OBJECTS = getuid.$(OBJEXT)
 getuid_LDADD = $(LDADD)
@@ -1056,10 +1356,18 @@ getuid32_SOURCES = getuid32.c
 getuid32_OBJECTS = getuid32.$(OBJEXT)
 getuid32_LDADD = $(LDADD)
 getuid32_DEPENDENCIES = libtests.a
-getxxid_SOURCES = getxxid.c
-getxxid_OBJECTS = getxxid.$(OBJEXT)
-getxxid_LDADD = $(LDADD)
-getxxid_DEPENDENCIES = libtests.a
+getxgid_SOURCES = getxgid.c
+getxgid_OBJECTS = getxgid.$(OBJEXT)
+getxgid_LDADD = $(LDADD)
+getxgid_DEPENDENCIES = libtests.a
+getxpid_SOURCES = getxpid.c
+getxpid_OBJECTS = getxpid.$(OBJEXT)
+getxpid_LDADD = $(LDADD)
+getxpid_DEPENDENCIES = libtests.a
+getxuid_SOURCES = getxuid.c
+getxuid_OBJECTS = getxuid.$(OBJEXT)
+getxuid_LDADD = $(LDADD)
+getxuid_DEPENDENCIES = libtests.a
 group_req_SOURCES = group_req.c
 group_req_OBJECTS = group_req.$(OBJEXT)
 group_req_LDADD = $(LDADD)
@@ -1120,6 +1428,12 @@ ioctl_block_SOURCES = ioctl_block.c
 ioctl_block_OBJECTS = ioctl_block.$(OBJEXT)
 ioctl_block_LDADD = $(LDADD)
 ioctl_block_DEPENDENCIES = libtests.a
+ioctl_block__pidns_translation_SOURCES =  \
+	ioctl_block--pidns-translation.c
+ioctl_block__pidns_translation_OBJECTS =  \
+	ioctl_block--pidns-translation.$(OBJEXT)
+ioctl_block__pidns_translation_LDADD = $(LDADD)
+ioctl_block__pidns_translation_DEPENDENCIES = libtests.a
 ioctl_dm_SOURCES = ioctl_dm.c
 ioctl_dm_OBJECTS = ioctl_dm.$(OBJEXT)
 ioctl_dm_LDADD = $(LDADD)
@@ -1199,6 +1513,76 @@ ioctl_evdev_v_Xverbose_SOURCES = ioctl_e
 ioctl_evdev_v_Xverbose_OBJECTS = ioctl_evdev-v-Xverbose.$(OBJEXT)
 ioctl_evdev_v_Xverbose_LDADD = $(LDADD)
 ioctl_evdev_v_Xverbose_DEPENDENCIES = libtests.a
+ioctl_hdio_SOURCES = ioctl_hdio.c
+ioctl_hdio_OBJECTS = ioctl_hdio.$(OBJEXT)
+ioctl_hdio_LDADD = $(LDADD)
+ioctl_hdio_DEPENDENCIES = libtests.a
+ioctl_hdio_Xabbrev_SOURCES = ioctl_hdio-Xabbrev.c
+ioctl_hdio_Xabbrev_OBJECTS = ioctl_hdio-Xabbrev.$(OBJEXT)
+ioctl_hdio_Xabbrev_LDADD = $(LDADD)
+ioctl_hdio_Xabbrev_DEPENDENCIES = libtests.a
+ioctl_hdio_Xraw_SOURCES = ioctl_hdio-Xraw.c
+ioctl_hdio_Xraw_OBJECTS = ioctl_hdio-Xraw.$(OBJEXT)
+ioctl_hdio_Xraw_LDADD = $(LDADD)
+ioctl_hdio_Xraw_DEPENDENCIES = libtests.a
+ioctl_hdio_Xverbose_SOURCES = ioctl_hdio-Xverbose.c
+ioctl_hdio_Xverbose_OBJECTS = ioctl_hdio-Xverbose.$(OBJEXT)
+ioctl_hdio_Xverbose_LDADD = $(LDADD)
+ioctl_hdio_Xverbose_DEPENDENCIES = libtests.a
+ioctl_hdio_success_SOURCES = ioctl_hdio-success.c
+ioctl_hdio_success_OBJECTS = ioctl_hdio-success.$(OBJEXT)
+ioctl_hdio_success_LDADD = $(LDADD)
+ioctl_hdio_success_DEPENDENCIES = libtests.a
+ioctl_hdio_success_Xabbrev_SOURCES = ioctl_hdio-success-Xabbrev.c
+ioctl_hdio_success_Xabbrev_OBJECTS =  \
+	ioctl_hdio-success-Xabbrev.$(OBJEXT)
+ioctl_hdio_success_Xabbrev_LDADD = $(LDADD)
+ioctl_hdio_success_Xabbrev_DEPENDENCIES = libtests.a
+ioctl_hdio_success_Xraw_SOURCES = ioctl_hdio-success-Xraw.c
+ioctl_hdio_success_Xraw_OBJECTS = ioctl_hdio-success-Xraw.$(OBJEXT)
+ioctl_hdio_success_Xraw_LDADD = $(LDADD)
+ioctl_hdio_success_Xraw_DEPENDENCIES = libtests.a
+ioctl_hdio_success_Xverbose_SOURCES = ioctl_hdio-success-Xverbose.c
+ioctl_hdio_success_Xverbose_OBJECTS =  \
+	ioctl_hdio-success-Xverbose.$(OBJEXT)
+ioctl_hdio_success_Xverbose_LDADD = $(LDADD)
+ioctl_hdio_success_Xverbose_DEPENDENCIES = libtests.a
+ioctl_hdio_success_v_SOURCES = ioctl_hdio-success-v.c
+ioctl_hdio_success_v_OBJECTS = ioctl_hdio-success-v.$(OBJEXT)
+ioctl_hdio_success_v_LDADD = $(LDADD)
+ioctl_hdio_success_v_DEPENDENCIES = libtests.a
+ioctl_hdio_success_v_Xabbrev_SOURCES = ioctl_hdio-success-v-Xabbrev.c
+ioctl_hdio_success_v_Xabbrev_OBJECTS =  \
+	ioctl_hdio-success-v-Xabbrev.$(OBJEXT)
+ioctl_hdio_success_v_Xabbrev_LDADD = $(LDADD)
+ioctl_hdio_success_v_Xabbrev_DEPENDENCIES = libtests.a
+ioctl_hdio_success_v_Xraw_SOURCES = ioctl_hdio-success-v-Xraw.c
+ioctl_hdio_success_v_Xraw_OBJECTS =  \
+	ioctl_hdio-success-v-Xraw.$(OBJEXT)
+ioctl_hdio_success_v_Xraw_LDADD = $(LDADD)
+ioctl_hdio_success_v_Xraw_DEPENDENCIES = libtests.a
+ioctl_hdio_success_v_Xverbose_SOURCES =  \
+	ioctl_hdio-success-v-Xverbose.c
+ioctl_hdio_success_v_Xverbose_OBJECTS =  \
+	ioctl_hdio-success-v-Xverbose.$(OBJEXT)
+ioctl_hdio_success_v_Xverbose_LDADD = $(LDADD)
+ioctl_hdio_success_v_Xverbose_DEPENDENCIES = libtests.a
+ioctl_hdio_v_SOURCES = ioctl_hdio-v.c
+ioctl_hdio_v_OBJECTS = ioctl_hdio-v.$(OBJEXT)
+ioctl_hdio_v_LDADD = $(LDADD)
+ioctl_hdio_v_DEPENDENCIES = libtests.a
+ioctl_hdio_v_Xabbrev_SOURCES = ioctl_hdio-v-Xabbrev.c
+ioctl_hdio_v_Xabbrev_OBJECTS = ioctl_hdio-v-Xabbrev.$(OBJEXT)
+ioctl_hdio_v_Xabbrev_LDADD = $(LDADD)
+ioctl_hdio_v_Xabbrev_DEPENDENCIES = libtests.a
+ioctl_hdio_v_Xraw_SOURCES = ioctl_hdio-v-Xraw.c
+ioctl_hdio_v_Xraw_OBJECTS = ioctl_hdio-v-Xraw.$(OBJEXT)
+ioctl_hdio_v_Xraw_LDADD = $(LDADD)
+ioctl_hdio_v_Xraw_DEPENDENCIES = libtests.a
+ioctl_hdio_v_Xverbose_SOURCES = ioctl_hdio-v-Xverbose.c
+ioctl_hdio_v_Xverbose_OBJECTS = ioctl_hdio-v-Xverbose.$(OBJEXT)
+ioctl_hdio_v_Xverbose_LDADD = $(LDADD)
+ioctl_hdio_v_Xverbose_DEPENDENCIES = libtests.a
 ioctl_inotify_SOURCES = ioctl_inotify.c
 ioctl_inotify_OBJECTS = ioctl_inotify.$(OBJEXT)
 ioctl_inotify_LDADD = $(LDADD)
@@ -1280,6 +1664,10 @@ ioctl_sock_gifconf_SOURCES = ioctl_sock_
 ioctl_sock_gifconf_OBJECTS = ioctl_sock_gifconf.$(OBJEXT)
 ioctl_sock_gifconf_LDADD = $(LDADD)
 ioctl_sock_gifconf_DEPENDENCIES = libtests.a
+ioctl_tee_SOURCES = ioctl_tee.c
+ioctl_tee_OBJECTS = ioctl_tee.$(OBJEXT)
+ioctl_tee_LDADD = $(LDADD)
+ioctl_tee_DEPENDENCIES = libtests.a
 ioctl_uffdio_SOURCES = ioctl_uffdio.c
 ioctl_uffdio_OBJECTS = ioctl_uffdio.$(OBJEXT)
 ioctl_uffdio_LDADD = $(LDADD)
@@ -1288,6 +1676,72 @@ ioctl_v4l2_SOURCES = ioctl_v4l2.c
 ioctl_v4l2_OBJECTS = ioctl_v4l2.$(OBJEXT)
 ioctl_v4l2_LDADD = $(LDADD)
 ioctl_v4l2_DEPENDENCIES = libtests.a
+ioctl_v4l2_Xabbrev_SOURCES = ioctl_v4l2-Xabbrev.c
+ioctl_v4l2_Xabbrev_OBJECTS = ioctl_v4l2-Xabbrev.$(OBJEXT)
+ioctl_v4l2_Xabbrev_LDADD = $(LDADD)
+ioctl_v4l2_Xabbrev_DEPENDENCIES = libtests.a
+ioctl_v4l2_Xraw_SOURCES = ioctl_v4l2-Xraw.c
+ioctl_v4l2_Xraw_OBJECTS = ioctl_v4l2-Xraw.$(OBJEXT)
+ioctl_v4l2_Xraw_LDADD = $(LDADD)
+ioctl_v4l2_Xraw_DEPENDENCIES = libtests.a
+ioctl_v4l2_Xverbose_SOURCES = ioctl_v4l2-Xverbose.c
+ioctl_v4l2_Xverbose_OBJECTS = ioctl_v4l2-Xverbose.$(OBJEXT)
+ioctl_v4l2_Xverbose_LDADD = $(LDADD)
+ioctl_v4l2_Xverbose_DEPENDENCIES = libtests.a
+ioctl_v4l2_success_SOURCES = ioctl_v4l2-success.c
+ioctl_v4l2_success_OBJECTS = ioctl_v4l2-success.$(OBJEXT)
+ioctl_v4l2_success_LDADD = $(LDADD)
+ioctl_v4l2_success_DEPENDENCIES = libtests.a
+ioctl_v4l2_success_Xabbrev_SOURCES = ioctl_v4l2-success-Xabbrev.c
+ioctl_v4l2_success_Xabbrev_OBJECTS =  \
+	ioctl_v4l2-success-Xabbrev.$(OBJEXT)
+ioctl_v4l2_success_Xabbrev_LDADD = $(LDADD)
+ioctl_v4l2_success_Xabbrev_DEPENDENCIES = libtests.a
+ioctl_v4l2_success_Xraw_SOURCES = ioctl_v4l2-success-Xraw.c
+ioctl_v4l2_success_Xraw_OBJECTS = ioctl_v4l2-success-Xraw.$(OBJEXT)
+ioctl_v4l2_success_Xraw_LDADD = $(LDADD)
+ioctl_v4l2_success_Xraw_DEPENDENCIES = libtests.a
+ioctl_v4l2_success_Xverbose_SOURCES = ioctl_v4l2-success-Xverbose.c
+ioctl_v4l2_success_Xverbose_OBJECTS =  \
+	ioctl_v4l2-success-Xverbose.$(OBJEXT)
+ioctl_v4l2_success_Xverbose_LDADD = $(LDADD)
+ioctl_v4l2_success_Xverbose_DEPENDENCIES = libtests.a
+ioctl_v4l2_success_v_SOURCES = ioctl_v4l2-success-v.c
+ioctl_v4l2_success_v_OBJECTS = ioctl_v4l2-success-v.$(OBJEXT)
+ioctl_v4l2_success_v_LDADD = $(LDADD)
+ioctl_v4l2_success_v_DEPENDENCIES = libtests.a
+ioctl_v4l2_success_v_Xabbrev_SOURCES = ioctl_v4l2-success-v-Xabbrev.c
+ioctl_v4l2_success_v_Xabbrev_OBJECTS =  \
+	ioctl_v4l2-success-v-Xabbrev.$(OBJEXT)
+ioctl_v4l2_success_v_Xabbrev_LDADD = $(LDADD)
+ioctl_v4l2_success_v_Xabbrev_DEPENDENCIES = libtests.a
+ioctl_v4l2_success_v_Xraw_SOURCES = ioctl_v4l2-success-v-Xraw.c
+ioctl_v4l2_success_v_Xraw_OBJECTS =  \
+	ioctl_v4l2-success-v-Xraw.$(OBJEXT)
+ioctl_v4l2_success_v_Xraw_LDADD = $(LDADD)
+ioctl_v4l2_success_v_Xraw_DEPENDENCIES = libtests.a
+ioctl_v4l2_success_v_Xverbose_SOURCES =  \
+	ioctl_v4l2-success-v-Xverbose.c
+ioctl_v4l2_success_v_Xverbose_OBJECTS =  \
+	ioctl_v4l2-success-v-Xverbose.$(OBJEXT)
+ioctl_v4l2_success_v_Xverbose_LDADD = $(LDADD)
+ioctl_v4l2_success_v_Xverbose_DEPENDENCIES = libtests.a
+ioctl_v4l2_v_SOURCES = ioctl_v4l2-v.c
+ioctl_v4l2_v_OBJECTS = ioctl_v4l2-v.$(OBJEXT)
+ioctl_v4l2_v_LDADD = $(LDADD)
+ioctl_v4l2_v_DEPENDENCIES = libtests.a
+ioctl_v4l2_v_Xabbrev_SOURCES = ioctl_v4l2-v-Xabbrev.c
+ioctl_v4l2_v_Xabbrev_OBJECTS = ioctl_v4l2-v-Xabbrev.$(OBJEXT)
+ioctl_v4l2_v_Xabbrev_LDADD = $(LDADD)
+ioctl_v4l2_v_Xabbrev_DEPENDENCIES = libtests.a
+ioctl_v4l2_v_Xraw_SOURCES = ioctl_v4l2-v-Xraw.c
+ioctl_v4l2_v_Xraw_OBJECTS = ioctl_v4l2-v-Xraw.$(OBJEXT)
+ioctl_v4l2_v_Xraw_LDADD = $(LDADD)
+ioctl_v4l2_v_Xraw_DEPENDENCIES = libtests.a
+ioctl_v4l2_v_Xverbose_SOURCES = ioctl_v4l2-v-Xverbose.c
+ioctl_v4l2_v_Xverbose_OBJECTS = ioctl_v4l2-v-Xverbose.$(OBJEXT)
+ioctl_v4l2_v_Xverbose_LDADD = $(LDADD)
+ioctl_v4l2_v_Xverbose_DEPENDENCIES = libtests.a
 ioctl_watchdog_SOURCES = ioctl_watchdog.c
 ioctl_watchdog_OBJECTS = ioctl_watchdog.$(OBJEXT)
 ioctl_watchdog_LDADD = $(LDADD)
@@ -1304,6 +1758,11 @@ ioprio_SOURCES = ioprio.c
 ioprio_OBJECTS = ioprio.$(OBJEXT)
 ioprio_LDADD = $(LDADD)
 ioprio_DEPENDENCIES = libtests.a
+ioprio__pidns_translation_SOURCES = ioprio--pidns-translation.c
+ioprio__pidns_translation_OBJECTS =  \
+	ioprio--pidns-translation.$(OBJEXT)
+ioprio__pidns_translation_LDADD = $(LDADD)
+ioprio__pidns_translation_DEPENDENCIES = libtests.a
 ioprio_Xabbrev_SOURCES = ioprio-Xabbrev.c
 ioprio_Xabbrev_OBJECTS = ioprio-Xabbrev.$(OBJEXT)
 ioprio_Xabbrev_LDADD = $(LDADD)
@@ -1400,6 +1859,11 @@ kcmp_y_SOURCES = kcmp-y.c
 kcmp_y_OBJECTS = kcmp-y.$(OBJEXT)
 kcmp_y_LDADD = $(LDADD)
 kcmp_y_DEPENDENCIES = libtests.a
+kcmp_y__pidns_translation_SOURCES = kcmp-y--pidns-translation.c
+kcmp_y__pidns_translation_OBJECTS =  \
+	kcmp-y--pidns-translation.$(OBJEXT)
+kcmp_y__pidns_translation_LDADD = $(LDADD)
+kcmp_y__pidns_translation_DEPENDENCIES = libtests.a
 kern_features_SOURCES = kern_features.c
 kern_features_OBJECTS = kern_features.$(OBJEXT)
 kern_features_LDADD = $(LDADD)
@@ -1448,6 +1912,10 @@ kill_SOURCES = kill.c
 kill_OBJECTS = kill.$(OBJEXT)
 kill_LDADD = $(LDADD)
 kill_DEPENDENCIES = libtests.a
+kill__pidns_translation_SOURCES = kill--pidns-translation.c
+kill__pidns_translation_OBJECTS = kill--pidns-translation.$(OBJEXT)
+kill__pidns_translation_LDADD = $(LDADD)
+kill__pidns_translation_DEPENDENCIES = libtests.a
 kill_child_SOURCES = kill_child.c
 kill_child_OBJECTS = kill_child.$(OBJEXT)
 kill_child_LDADD = $(LDADD)
@@ -1509,6 +1977,11 @@ madvise_DEPENDENCIES = libtests.a
 maybe_switch_current_tcp_SOURCES = maybe_switch_current_tcp.c
 maybe_switch_current_tcp_OBJECTS = maybe_switch_current_tcp.$(OBJEXT)
 maybe_switch_current_tcp_DEPENDENCIES = $(LDADD)
+maybe_switch_current_tcp__quiet_thread_execve_SOURCES =  \
+	maybe_switch_current_tcp--quiet-thread-execve.c
+maybe_switch_current_tcp__quiet_thread_execve_OBJECTS =  \
+	maybe_switch_current_tcp--quiet-thread-execve.$(OBJEXT)
+maybe_switch_current_tcp__quiet_thread_execve_DEPENDENCIES = $(LDADD)
 mbind_SOURCES = mbind.c
 mbind_OBJECTS = mbind.$(OBJEXT)
 mbind_LDADD = $(LDADD)
@@ -1549,6 +2022,12 @@ migrate_pages_SOURCES = migrate_pages.c
 migrate_pages_OBJECTS = migrate_pages.$(OBJEXT)
 migrate_pages_LDADD = $(LDADD)
 migrate_pages_DEPENDENCIES = libtests.a
+migrate_pages__pidns_translation_SOURCES =  \
+	migrate_pages--pidns-translation.c
+migrate_pages__pidns_translation_OBJECTS =  \
+	migrate_pages--pidns-translation.$(OBJEXT)
+migrate_pages__pidns_translation_LDADD = $(LDADD)
+migrate_pages__pidns_translation_DEPENDENCIES = libtests.a
 mincore_SOURCES = mincore.c
 mincore_OBJECTS = mincore.$(OBJEXT)
 mincore_LDADD = $(LDADD)
@@ -1661,6 +2140,12 @@ move_pages_SOURCES = move_pages.c
 move_pages_OBJECTS = move_pages.$(OBJEXT)
 move_pages_LDADD = $(LDADD)
 move_pages_DEPENDENCIES = libtests.a
+move_pages__pidns_translation_SOURCES =  \
+	move_pages--pidns-translation.c
+move_pages__pidns_translation_OBJECTS =  \
+	move_pages--pidns-translation.$(OBJEXT)
+move_pages__pidns_translation_LDADD = $(LDADD)
+move_pages__pidns_translation_DEPENDENCIES = libtests.a
 move_pages_Xabbrev_SOURCES = move_pages-Xabbrev.c
 move_pages_Xabbrev_OBJECTS = move_pages-Xabbrev.$(OBJEXT)
 move_pages_Xabbrev_LDADD = $(LDADD)
@@ -1708,6 +2193,27 @@ nanosleep_SOURCES = nanosleep.c
 nanosleep_OBJECTS = nanosleep.$(OBJEXT)
 nanosleep_LDADD = $(LDADD)
 nanosleep_DEPENDENCIES = libtests.a
+net__decode_fds_dev_netlink_SOURCES = net--decode-fds-dev-netlink.c
+net__decode_fds_dev_netlink_OBJECTS =  \
+	net--decode-fds-dev-netlink.$(OBJEXT)
+net__decode_fds_dev_netlink_LDADD = $(LDADD)
+net__decode_fds_dev_netlink_DEPENDENCIES = libtests.a
+net__decode_fds_none_netlink_SOURCES = net--decode-fds-none-netlink.c
+net__decode_fds_none_netlink_OBJECTS =  \
+	net--decode-fds-none-netlink.$(OBJEXT)
+net__decode_fds_none_netlink_LDADD = $(LDADD)
+net__decode_fds_none_netlink_DEPENDENCIES = libtests.a
+net__decode_fds_path_netlink_SOURCES = net--decode-fds-path-netlink.c
+net__decode_fds_path_netlink_OBJECTS =  \
+	net--decode-fds-path-netlink.$(OBJEXT)
+net__decode_fds_path_netlink_LDADD = $(LDADD)
+net__decode_fds_path_netlink_DEPENDENCIES = libtests.a
+net__decode_fds_socket_netlink_SOURCES =  \
+	net--decode-fds-socket-netlink.c
+net__decode_fds_socket_netlink_OBJECTS =  \
+	net--decode-fds-socket-netlink.$(OBJEXT)
+net__decode_fds_socket_netlink_LDADD = $(LDADD)
+net__decode_fds_socket_netlink_DEPENDENCIES = libtests.a
 net_accept_connect_SOURCES = net-accept-connect.c
 net_accept_connect_OBJECTS = net-accept-connect.$(OBJEXT)
 net_accept_connect_LDADD = $(LDADD)
@@ -1736,6 +2242,12 @@ net_sockaddr_SOURCES = net-sockaddr.c
 net_sockaddr_OBJECTS = net-sockaddr.$(OBJEXT)
 net_sockaddr_LDADD = $(LDADD)
 net_sockaddr_DEPENDENCIES = libtests.a
+net_sockaddr__pidns_translation_SOURCES =  \
+	net-sockaddr--pidns-translation.c
+net_sockaddr__pidns_translation_OBJECTS =  \
+	net-sockaddr--pidns-translation.$(OBJEXT)
+net_sockaddr__pidns_translation_LDADD = $(LDADD)
+net_sockaddr__pidns_translation_DEPENDENCIES = libtests.a
 net_tpacket_req_SOURCES = net-tpacket_req.c
 net_tpacket_req_OBJECTS = net-tpacket_req.$(OBJEXT)
 net_tpacket_req_LDADD = $(LDADD)
@@ -1773,6 +2285,12 @@ netlink_audit_SOURCES = netlink_audit.c
 netlink_audit_OBJECTS = netlink_audit.$(OBJEXT)
 netlink_audit_LDADD = $(LDADD)
 netlink_audit_DEPENDENCIES = libtests.a
+netlink_audit__pidns_translation_SOURCES =  \
+	netlink_audit--pidns-translation.c
+netlink_audit__pidns_translation_OBJECTS =  \
+	netlink_audit--pidns-translation.$(OBJEXT)
+netlink_audit__pidns_translation_LDADD = $(LDADD)
+netlink_audit__pidns_translation_DEPENDENCIES = libtests.a
 netlink_crypto_SOURCES = netlink_crypto.c
 netlink_crypto_OBJECTS = netlink_crypto.$(OBJEXT)
 netlink_crypto_LDADD = $(LDADD)
@@ -1921,6 +2439,10 @@ nlattr_ifla_xdp_SOURCES = nlattr_ifla_xd
 nlattr_ifla_xdp_OBJECTS = nlattr_ifla_xdp.$(OBJEXT)
 nlattr_ifla_xdp_LDADD = $(LDADD)
 nlattr_ifla_xdp_DEPENDENCIES = libtests.a
+nlattr_ifla_xdp_y_SOURCES = nlattr_ifla_xdp-y.c
+nlattr_ifla_xdp_y_OBJECTS = nlattr_ifla_xdp-y.$(OBJEXT)
+nlattr_ifla_xdp_y_LDADD = $(LDADD)
+nlattr_ifla_xdp_y_DEPENDENCIES = libtests.a
 nlattr_inet_diag_msg_SOURCES = nlattr_inet_diag_msg.c
 nlattr_inet_diag_msg_OBJECTS = nlattr_inet_diag_msg.$(OBJEXT)
 nlattr_inet_diag_msg_LDADD = $(LDADD)
@@ -2074,6 +2596,46 @@ openat_SOURCES = openat.c
 openat_OBJECTS = openat.$(OBJEXT)
 openat_LDADD = $(LDADD)
 openat_DEPENDENCIES = libtests.a
+openat2_SOURCES = openat2.c
+openat2_OBJECTS = openat2.$(OBJEXT)
+openat2_LDADD = $(LDADD)
+openat2_DEPENDENCIES = libtests.a
+openat2_Xabbrev_SOURCES = openat2-Xabbrev.c
+openat2_Xabbrev_OBJECTS = openat2-Xabbrev.$(OBJEXT)
+openat2_Xabbrev_LDADD = $(LDADD)
+openat2_Xabbrev_DEPENDENCIES = libtests.a
+openat2_Xraw_SOURCES = openat2-Xraw.c
+openat2_Xraw_OBJECTS = openat2-Xraw.$(OBJEXT)
+openat2_Xraw_LDADD = $(LDADD)
+openat2_Xraw_DEPENDENCIES = libtests.a
+openat2_Xverbose_SOURCES = openat2-Xverbose.c
+openat2_Xverbose_OBJECTS = openat2-Xverbose.$(OBJEXT)
+openat2_Xverbose_LDADD = $(LDADD)
+openat2_Xverbose_DEPENDENCIES = libtests.a
+openat2_v_SOURCES = openat2-v.c
+openat2_v_OBJECTS = openat2-v.$(OBJEXT)
+openat2_v_LDADD = $(LDADD)
+openat2_v_DEPENDENCIES = libtests.a
+openat2_v_y_SOURCES = openat2-v-y.c
+openat2_v_y_OBJECTS = openat2-v-y.$(OBJEXT)
+openat2_v_y_LDADD = $(LDADD)
+openat2_v_y_DEPENDENCIES = libtests.a
+openat2_v_y_Xabbrev_SOURCES = openat2-v-y-Xabbrev.c
+openat2_v_y_Xabbrev_OBJECTS = openat2-v-y-Xabbrev.$(OBJEXT)
+openat2_v_y_Xabbrev_LDADD = $(LDADD)
+openat2_v_y_Xabbrev_DEPENDENCIES = libtests.a
+openat2_v_y_Xraw_SOURCES = openat2-v-y-Xraw.c
+openat2_v_y_Xraw_OBJECTS = openat2-v-y-Xraw.$(OBJEXT)
+openat2_v_y_Xraw_LDADD = $(LDADD)
+openat2_v_y_Xraw_DEPENDENCIES = libtests.a
+openat2_v_y_Xverbose_SOURCES = openat2-v-y-Xverbose.c
+openat2_v_y_Xverbose_OBJECTS = openat2-v-y-Xverbose.$(OBJEXT)
+openat2_v_y_Xverbose_LDADD = $(LDADD)
+openat2_v_y_Xverbose_DEPENDENCIES = libtests.a
+openat2_y_SOURCES = openat2-y.c
+openat2_y_OBJECTS = openat2-y.$(OBJEXT)
+openat2_y_LDADD = $(LDADD)
+openat2_y_DEPENDENCIES = libtests.a
 orphaned_process_group_SOURCES = orphaned_process_group.c
 orphaned_process_group_OBJECTS = orphaned_process_group.$(OBJEXT)
 orphaned_process_group_LDADD = $(LDADD)
@@ -2118,10 +2680,43 @@ personality_Xverbose_SOURCES = personali
 personality_Xverbose_OBJECTS = personality-Xverbose.$(OBJEXT)
 personality_Xverbose_LDADD = $(LDADD)
 personality_Xverbose_DEPENDENCIES = libtests.a
+pidfd_getfd_SOURCES = pidfd_getfd.c
+pidfd_getfd_OBJECTS = pidfd_getfd.$(OBJEXT)
+pidfd_getfd_LDADD = $(LDADD)
+pidfd_getfd_DEPENDENCIES = libtests.a
+pidfd_getfd_y_SOURCES = pidfd_getfd-y.c
+pidfd_getfd_y_OBJECTS = pidfd_getfd-y.$(OBJEXT)
+pidfd_getfd_y_LDADD = $(LDADD)
+pidfd_getfd_y_DEPENDENCIES = libtests.a
+pidfd_getfd_yy_SOURCES = pidfd_getfd-yy.c
+pidfd_getfd_yy_OBJECTS = pidfd_getfd-yy.$(OBJEXT)
+pidfd_getfd_yy_LDADD = $(LDADD)
+pidfd_getfd_yy_DEPENDENCIES = libtests.a
 pidfd_open_SOURCES = pidfd_open.c
 pidfd_open_OBJECTS = pidfd_open.$(OBJEXT)
 pidfd_open_LDADD = $(LDADD)
 pidfd_open_DEPENDENCIES = libtests.a
+pidfd_open__decode_fd_path_SOURCES = pidfd_open--decode-fd-path.c
+pidfd_open__decode_fd_path_OBJECTS =  \
+	pidfd_open--decode-fd-path.$(OBJEXT)
+pidfd_open__decode_fd_path_LDADD = $(LDADD)
+pidfd_open__decode_fd_path_DEPENDENCIES = libtests.a
+pidfd_open__decode_fd_pidfd_SOURCES = pidfd_open--decode-fd-pidfd.c
+pidfd_open__decode_fd_pidfd_OBJECTS =  \
+	pidfd_open--decode-fd-pidfd.$(OBJEXT)
+pidfd_open__decode_fd_pidfd_LDADD = $(LDADD)
+pidfd_open__decode_fd_pidfd_DEPENDENCIES = libtests.a
+pidfd_open__decode_fd_socket_SOURCES = pidfd_open--decode-fd-socket.c
+pidfd_open__decode_fd_socket_OBJECTS =  \
+	pidfd_open--decode-fd-socket.$(OBJEXT)
+pidfd_open__decode_fd_socket_LDADD = $(LDADD)
+pidfd_open__decode_fd_socket_DEPENDENCIES = libtests.a
+pidfd_open__pidns_translation_SOURCES =  \
+	pidfd_open--pidns-translation.c
+pidfd_open__pidns_translation_OBJECTS =  \
+	pidfd_open--pidns-translation.$(OBJEXT)
+pidfd_open__pidns_translation_LDADD = $(LDADD)
+pidfd_open__pidns_translation_DEPENDENCIES = libtests.a
 pidfd_open_P_SOURCES = pidfd_open-P.c
 pidfd_open_P_OBJECTS = pidfd_open-P.$(OBJEXT)
 pidfd_open_P_LDADD = $(LDADD)
@@ -2130,10 +2725,24 @@ pidfd_open_y_SOURCES = pidfd_open-y.c
 pidfd_open_y_OBJECTS = pidfd_open-y.$(OBJEXT)
 pidfd_open_y_LDADD = $(LDADD)
 pidfd_open_y_DEPENDENCIES = libtests.a
+pidfd_open_yy_SOURCES = pidfd_open-yy.c
+pidfd_open_yy_OBJECTS = pidfd_open-yy.$(OBJEXT)
+pidfd_open_yy_LDADD = $(LDADD)
+pidfd_open_yy_DEPENDENCIES = libtests.a
 pidfd_send_signal_SOURCES = pidfd_send_signal.c
 pidfd_send_signal_OBJECTS = pidfd_send_signal.$(OBJEXT)
 pidfd_send_signal_LDADD = $(LDADD)
 pidfd_send_signal_DEPENDENCIES = libtests.a
+pidfd_send_signal__pidns_translation_SOURCES =  \
+	pidfd_send_signal--pidns-translation.c
+pidfd_send_signal__pidns_translation_OBJECTS =  \
+	pidfd_send_signal--pidns-translation.$(OBJEXT)
+pidfd_send_signal__pidns_translation_LDADD = $(LDADD)
+pidfd_send_signal__pidns_translation_DEPENDENCIES = libtests.a
+pidns_cache_SOURCES = pidns-cache.c
+pidns_cache_OBJECTS = pidns-cache.$(OBJEXT)
+pidns_cache_LDADD = $(LDADD)
+pidns_cache_DEPENDENCIES = libtests.a
 pipe_SOURCES = pipe.c
 pipe_OBJECTS = pipe.$(OBJEXT)
 pipe_LDADD = $(LDADD)
@@ -2239,6 +2848,10 @@ print_maxfd_SOURCES = print_maxfd.c
 print_maxfd_OBJECTS = print_maxfd.$(OBJEXT)
 print_maxfd_LDADD = $(LDADD)
 print_maxfd_DEPENDENCIES = libtests.a
+print_ppid_tracerpid_SOURCES = print_ppid_tracerpid.c
+print_ppid_tracerpid_OBJECTS = print_ppid_tracerpid.$(OBJEXT)
+print_ppid_tracerpid_LDADD = $(LDADD)
+print_ppid_tracerpid_DEPENDENCIES = libtests.a
 printpath_umovestr_SOURCES = printpath-umovestr.c
 printpath_umovestr_OBJECTS = printpath-umovestr.$(OBJEXT)
 printpath_umovestr_LDADD = $(LDADD)
@@ -2288,14 +2901,31 @@ prlimit64_SOURCES = prlimit64.c
 prlimit64_OBJECTS = prlimit64.$(OBJEXT)
 prlimit64_LDADD = $(LDADD)
 prlimit64_DEPENDENCIES = libtests.a
+prlimit64__pidns_translation_SOURCES = prlimit64--pidns-translation.c
+prlimit64__pidns_translation_OBJECTS =  \
+	prlimit64--pidns-translation.$(OBJEXT)
+prlimit64__pidns_translation_LDADD = $(LDADD)
+prlimit64__pidns_translation_DEPENDENCIES = libtests.a
 process_vm_readv_SOURCES = process_vm_readv.c
 process_vm_readv_OBJECTS = process_vm_readv.$(OBJEXT)
 process_vm_readv_LDADD = $(LDADD)
 process_vm_readv_DEPENDENCIES = libtests.a
+process_vm_readv__pidns_translation_SOURCES =  \
+	process_vm_readv--pidns-translation.c
+process_vm_readv__pidns_translation_OBJECTS =  \
+	process_vm_readv--pidns-translation.$(OBJEXT)
+process_vm_readv__pidns_translation_LDADD = $(LDADD)
+process_vm_readv__pidns_translation_DEPENDENCIES = libtests.a
 process_vm_writev_SOURCES = process_vm_writev.c
 process_vm_writev_OBJECTS = process_vm_writev.$(OBJEXT)
 process_vm_writev_LDADD = $(LDADD)
 process_vm_writev_DEPENDENCIES = libtests.a
+process_vm_writev__pidns_translation_SOURCES =  \
+	process_vm_writev--pidns-translation.c
+process_vm_writev__pidns_translation_OBJECTS =  \
+	process_vm_writev--pidns-translation.$(OBJEXT)
+process_vm_writev__pidns_translation_LDADD = $(LDADD)
+process_vm_writev__pidns_translation_DEPENDENCIES = libtests.a
 pselect6_SOURCES = pselect6.c
 pselect6_OBJECTS = pselect6.$(OBJEXT)
 pselect6_LDADD = $(LDADD)
@@ -2489,6 +3119,12 @@ rt_sigqueueinfo_SOURCES = rt_sigqueueinf
 rt_sigqueueinfo_OBJECTS = rt_sigqueueinfo.$(OBJEXT)
 rt_sigqueueinfo_LDADD = $(LDADD)
 rt_sigqueueinfo_DEPENDENCIES = libtests.a
+rt_sigqueueinfo__pidns_translation_SOURCES =  \
+	rt_sigqueueinfo--pidns-translation.c
+rt_sigqueueinfo__pidns_translation_OBJECTS =  \
+	rt_sigqueueinfo--pidns-translation.$(OBJEXT)
+rt_sigqueueinfo__pidns_translation_LDADD = $(LDADD)
+rt_sigqueueinfo__pidns_translation_DEPENDENCIES = libtests.a
 rt_sigreturn_SOURCES = rt_sigreturn.c
 rt_sigreturn_OBJECTS = rt_sigreturn.$(OBJEXT)
 rt_sigreturn_LDADD = $(LDADD)
@@ -2505,6 +3141,12 @@ rt_tgsigqueueinfo_SOURCES = rt_tgsigqueu
 rt_tgsigqueueinfo_OBJECTS = rt_tgsigqueueinfo.$(OBJEXT)
 rt_tgsigqueueinfo_LDADD = $(LDADD)
 rt_tgsigqueueinfo_DEPENDENCIES = libtests.a
+rt_tgsigqueueinfo__pidns_translation_SOURCES =  \
+	rt_tgsigqueueinfo--pidns-translation.c
+rt_tgsigqueueinfo__pidns_translation_OBJECTS =  \
+	rt_tgsigqueueinfo--pidns-translation.$(OBJEXT)
+rt_tgsigqueueinfo__pidns_translation_LDADD = $(LDADD)
+rt_tgsigqueueinfo__pidns_translation_DEPENDENCIES = libtests.a
 run_expect_termsig_SOURCES = run_expect_termsig.c
 run_expect_termsig_OBJECTS = run_expect_termsig.$(OBJEXT)
 run_expect_termsig_LDADD = $(LDADD)
@@ -2545,18 +3187,42 @@ sched_xetaffinity_SOURCES = sched_xetaff
 sched_xetaffinity_OBJECTS = sched_xetaffinity.$(OBJEXT)
 sched_xetaffinity_LDADD = $(LDADD)
 sched_xetaffinity_DEPENDENCIES = libtests.a
+sched_xetaffinity__pidns_translation_SOURCES =  \
+	sched_xetaffinity--pidns-translation.c
+sched_xetaffinity__pidns_translation_OBJECTS =  \
+	sched_xetaffinity--pidns-translation.$(OBJEXT)
+sched_xetaffinity__pidns_translation_LDADD = $(LDADD)
+sched_xetaffinity__pidns_translation_DEPENDENCIES = libtests.a
 sched_xetattr_SOURCES = sched_xetattr.c
 sched_xetattr_OBJECTS = sched_xetattr.$(OBJEXT)
 sched_xetattr_LDADD = $(LDADD)
 sched_xetattr_DEPENDENCIES = libtests.a
+sched_xetattr__pidns_translation_SOURCES =  \
+	sched_xetattr--pidns-translation.c
+sched_xetattr__pidns_translation_OBJECTS =  \
+	sched_xetattr--pidns-translation.$(OBJEXT)
+sched_xetattr__pidns_translation_LDADD = $(LDADD)
+sched_xetattr__pidns_translation_DEPENDENCIES = libtests.a
 sched_xetparam_SOURCES = sched_xetparam.c
 sched_xetparam_OBJECTS = sched_xetparam.$(OBJEXT)
 sched_xetparam_LDADD = $(LDADD)
 sched_xetparam_DEPENDENCIES = libtests.a
+sched_xetparam__pidns_translation_SOURCES =  \
+	sched_xetparam--pidns-translation.c
+sched_xetparam__pidns_translation_OBJECTS =  \
+	sched_xetparam--pidns-translation.$(OBJEXT)
+sched_xetparam__pidns_translation_LDADD = $(LDADD)
+sched_xetparam__pidns_translation_DEPENDENCIES = libtests.a
 sched_xetscheduler_SOURCES = sched_xetscheduler.c
 sched_xetscheduler_OBJECTS = sched_xetscheduler.$(OBJEXT)
 sched_xetscheduler_LDADD = $(LDADD)
 sched_xetscheduler_DEPENDENCIES = libtests.a
+sched_xetscheduler__pidns_translation_SOURCES =  \
+	sched_xetscheduler--pidns-translation.c
+sched_xetscheduler__pidns_translation_OBJECTS =  \
+	sched_xetscheduler--pidns-translation.$(OBJEXT)
+sched_xetscheduler__pidns_translation_LDADD = $(LDADD)
+sched_xetscheduler__pidns_translation_DEPENDENCIES = libtests.a
 sched_yield_SOURCES = sched_yield.c
 sched_yield_OBJECTS = sched_yield.$(OBJEXT)
 sched_yield_LDADD = $(LDADD)
@@ -2681,6 +3347,10 @@ setns_SOURCES = setns.c
 setns_OBJECTS = setns.$(OBJEXT)
 setns_LDADD = $(LDADD)
 setns_DEPENDENCIES = libtests.a
+setpgrp_exec_SOURCES = setpgrp-exec.c
+setpgrp_exec_OBJECTS = setpgrp-exec.$(OBJEXT)
+setpgrp_exec_LDADD = $(LDADD)
+setpgrp_exec_DEPENDENCIES = libtests.a
 setregid_SOURCES = setregid.c
 setregid_OBJECTS = setregid.$(OBJEXT)
 setregid_LDADD = $(LDADD)
@@ -2765,6 +3435,12 @@ signal_receive_SOURCES = signal_receive.
 signal_receive_OBJECTS = signal_receive.$(OBJEXT)
 signal_receive_LDADD = $(LDADD)
 signal_receive_DEPENDENCIES = libtests.a
+signal_receive__pidns_translation_SOURCES =  \
+	signal_receive--pidns-translation.c
+signal_receive__pidns_translation_OBJECTS =  \
+	signal_receive--pidns-translation.$(OBJEXT)
+signal_receive__pidns_translation_LDADD = $(LDADD)
+signal_receive__pidns_translation_DEPENDENCIES = libtests.a
 signalfd4_SOURCES = signalfd4.c
 signalfd4_OBJECTS = signalfd4.$(OBJEXT)
 signalfd4_LDADD = $(LDADD)
@@ -2801,6 +3477,12 @@ so_peercred_SOURCES = so_peercred.c
 so_peercred_OBJECTS = so_peercred.$(OBJEXT)
 so_peercred_LDADD = $(LDADD)
 so_peercred_DEPENDENCIES = libtests.a
+so_peercred__pidns_translation_SOURCES =  \
+	so_peercred--pidns-translation.c
+so_peercred__pidns_translation_OBJECTS =  \
+	so_peercred--pidns-translation.$(OBJEXT)
+so_peercred__pidns_translation_LDADD = $(LDADD)
+so_peercred__pidns_translation_DEPENDENCIES = libtests.a
 so_peercred_Xabbrev_SOURCES = so_peercred-Xabbrev.c
 so_peercred_Xabbrev_OBJECTS = so_peercred-Xabbrev.$(OBJEXT)
 so_peercred_Xabbrev_LDADD = $(LDADD)
@@ -2901,6 +3583,14 @@ status_failed_SOURCES = status-failed.c
 status_failed_OBJECTS = status-failed.$(OBJEXT)
 status_failed_LDADD = $(LDADD)
 status_failed_DEPENDENCIES = libtests.a
+status_failed_long_SOURCES = status-failed-long.c
+status_failed_long_OBJECTS = status-failed-long.$(OBJEXT)
+status_failed_long_LDADD = $(LDADD)
+status_failed_long_DEPENDENCIES = libtests.a
+status_failed_status_SOURCES = status-failed-status.c
+status_failed_status_OBJECTS = status-failed-status.$(OBJEXT)
+status_failed_status_LDADD = $(LDADD)
+status_failed_status_DEPENDENCIES = libtests.a
 status_none_SOURCES = status-none.c
 status_none_OBJECTS = status-none.$(OBJEXT)
 status_none_LDADD = $(LDADD)
@@ -2916,6 +3606,14 @@ status_successful_SOURCES = status-succe
 status_successful_OBJECTS = status-successful.$(OBJEXT)
 status_successful_LDADD = $(LDADD)
 status_successful_DEPENDENCIES = libtests.a
+status_successful_long_SOURCES = status-successful-long.c
+status_successful_long_OBJECTS = status-successful-long.$(OBJEXT)
+status_successful_long_LDADD = $(LDADD)
+status_successful_long_DEPENDENCIES = libtests.a
+status_successful_status_SOURCES = status-successful-status.c
+status_successful_status_OBJECTS = status-successful-status.$(OBJEXT)
+status_successful_status_LDADD = $(LDADD)
+status_successful_status_DEPENDENCIES = libtests.a
 status_unfinished_SOURCES = status-unfinished.c
 status_unfinished_OBJECTS = status-unfinished.$(OBJEXT)
 status_unfinished_LDADD = $(LDADD)
@@ -2928,6 +3626,33 @@ statx_SOURCES = statx.c
 statx_OBJECTS = statx.$(OBJEXT)
 statx_LDADD = $(LDADD)
 statx_DEPENDENCIES = libtests.a
+strace__strings_in_hex_SOURCES = strace--strings-in-hex.c
+strace__strings_in_hex_OBJECTS = strace--strings-in-hex.$(OBJEXT)
+strace__strings_in_hex_LDADD = $(LDADD)
+strace__strings_in_hex_DEPENDENCIES = libtests.a
+strace__strings_in_hex_all_SOURCES = strace--strings-in-hex-all.c
+strace__strings_in_hex_all_OBJECTS =  \
+	strace--strings-in-hex-all.$(OBJEXT)
+strace__strings_in_hex_all_LDADD = $(LDADD)
+strace__strings_in_hex_all_DEPENDENCIES = libtests.a
+strace__strings_in_hex_non_ascii_SOURCES =  \
+	strace--strings-in-hex-non-ascii.c
+strace__strings_in_hex_non_ascii_OBJECTS =  \
+	strace--strings-in-hex-non-ascii.$(OBJEXT)
+strace__strings_in_hex_non_ascii_LDADD = $(LDADD)
+strace__strings_in_hex_non_ascii_DEPENDENCIES = libtests.a
+strace_n_SOURCES = strace-n.c
+strace_n_OBJECTS = strace-n.$(OBJEXT)
+strace_n_LDADD = $(LDADD)
+strace_n_DEPENDENCIES = libtests.a
+strace_x_SOURCES = strace-x.c
+strace_x_OBJECTS = strace-x.$(OBJEXT)
+strace_x_LDADD = $(LDADD)
+strace_x_DEPENDENCIES = libtests.a
+strace_xx_SOURCES = strace-xx.c
+strace_xx_OBJECTS = strace-xx.$(OBJEXT)
+strace_xx_LDADD = $(LDADD)
+strace_xx_DEPENDENCIES = libtests.a
 swap_SOURCES = swap.c
 swap_OBJECTS = swap.$(OBJEXT)
 swap_LDADD = $(LDADD)
@@ -2972,9 +3697,33 @@ tee_SOURCES = tee.c
 tee_OBJECTS = tee.$(OBJEXT)
 tee_LDADD = $(LDADD)
 tee_DEPENDENCIES = libtests.a
+tgkill_SOURCES = tgkill.c
+tgkill_OBJECTS = tgkill.$(OBJEXT)
+tgkill_LDADD = $(LDADD)
+tgkill_DEPENDENCIES = libtests.a
+tgkill__pidns_translation_SOURCES = tgkill--pidns-translation.c
+tgkill__pidns_translation_OBJECTS =  \
+	tgkill--pidns-translation.$(OBJEXT)
+tgkill__pidns_translation_LDADD = $(LDADD)
+tgkill__pidns_translation_DEPENDENCIES = libtests.a
 threads_execve_SOURCES = threads-execve.c
 threads_execve_OBJECTS = threads-execve.$(OBJEXT)
 threads_execve_DEPENDENCIES = $(am__DEPENDENCIES_1) $(LDADD)
+threads_execve__quiet_thread_execve_SOURCES =  \
+	threads-execve--quiet-thread-execve.c
+threads_execve__quiet_thread_execve_OBJECTS =  \
+	threads-execve--quiet-thread-execve.$(OBJEXT)
+threads_execve__quiet_thread_execve_DEPENDENCIES =  \
+	$(am__DEPENDENCIES_1) $(LDADD)
+threads_execve_q_SOURCES = threads-execve-q.c
+threads_execve_q_OBJECTS = threads-execve-q.$(OBJEXT)
+threads_execve_q_DEPENDENCIES = $(am__DEPENDENCIES_1) $(LDADD)
+threads_execve_qq_SOURCES = threads-execve-qq.c
+threads_execve_qq_OBJECTS = threads-execve-qq.$(OBJEXT)
+threads_execve_qq_DEPENDENCIES = $(am__DEPENDENCIES_1) $(LDADD)
+threads_execve_qqq_SOURCES = threads-execve-qqq.c
+threads_execve_qqq_OBJECTS = threads-execve-qqq.$(OBJEXT)
+threads_execve_qqq_DEPENDENCIES = $(am__DEPENDENCIES_1) $(LDADD)
 time_SOURCES = time.c
 time_OBJECTS = time.$(OBJEXT)
 time_LDADD = $(LDADD)
@@ -2998,10 +3747,24 @@ times_fail_SOURCES = times-fail.c
 times_fail_OBJECTS = times-fail.$(OBJEXT)
 times_fail_LDADD = $(LDADD)
 times_fail_DEPENDENCIES = libtests.a
+tkill_SOURCES = tkill.c
+tkill_OBJECTS = tkill.$(OBJEXT)
+tkill_LDADD = $(LDADD)
+tkill_DEPENDENCIES = libtests.a
+tkill__pidns_translation_SOURCES = tkill--pidns-translation.c
+tkill__pidns_translation_OBJECTS = tkill--pidns-translation.$(OBJEXT)
+tkill__pidns_translation_LDADD = $(LDADD)
+tkill__pidns_translation_DEPENDENCIES = libtests.a
 tracer_ppid_pgid_sid_SOURCES = tracer_ppid_pgid_sid.c
 tracer_ppid_pgid_sid_OBJECTS = tracer_ppid_pgid_sid.$(OBJEXT)
 tracer_ppid_pgid_sid_LDADD = $(LDADD)
 tracer_ppid_pgid_sid_DEPENDENCIES = libtests.a
+am_trie_test_OBJECTS = trie_test-trie_test.$(OBJEXT) \
+	trie_test-trie_for_tests.$(OBJEXT)
+trie_test_OBJECTS = $(am_trie_test_OBJECTS)
+trie_test_DEPENDENCIES = $(LDADD) $(am__DEPENDENCIES_1)
+trie_test_LINK = $(CCLD) $(trie_test_CFLAGS) $(CFLAGS) $(AM_LDFLAGS) \
+	$(LDFLAGS) -o $@
 truncate_SOURCES = truncate.c
 truncate_OBJECTS = truncate.$(OBJEXT)
 truncate_LDADD = $(LDADD)
@@ -3054,6 +3817,10 @@ umovestr_cached_SOURCES = umovestr_cache
 umovestr_cached_OBJECTS = umovestr_cached.$(OBJEXT)
 umovestr_cached_LDADD = $(LDADD)
 umovestr_cached_DEPENDENCIES = libtests.a
+umovestr_cached_adjacent_SOURCES = umovestr_cached_adjacent.c
+umovestr_cached_adjacent_OBJECTS = umovestr_cached_adjacent.$(OBJEXT)
+umovestr_cached_adjacent_LDADD = $(LDADD)
+umovestr_cached_adjacent_DEPENDENCIES = libtests.a
 uname_SOURCES = uname.c
 uname_OBJECTS = uname.$(OBJEXT)
 uname_LDADD = $(LDADD)
@@ -3159,6 +3926,12 @@ xet_robust_list_SOURCES = xet_robust_lis
 xet_robust_list_OBJECTS = xet_robust_list.$(OBJEXT)
 xet_robust_list_LDADD = $(LDADD)
 xet_robust_list_DEPENDENCIES = libtests.a
+xet_robust_list__pidns_translation_SOURCES =  \
+	xet_robust_list--pidns-translation.c
+xet_robust_list__pidns_translation_OBJECTS =  \
+	xet_robust_list--pidns-translation.$(OBJEXT)
+xet_robust_list__pidns_translation_LDADD = $(LDADD)
+xet_robust_list__pidns_translation_DEPENDENCIES = libtests.a
 xet_thread_area_x86_SOURCES = xet_thread_area_x86.c
 xet_thread_area_x86_OBJECTS = xet_thread_area_x86.$(OBJEXT)
 xet_thread_area_x86_LDADD = $(LDADD)
@@ -3171,10 +3944,21 @@ xetpgid_SOURCES = xetpgid.c
 xetpgid_OBJECTS = xetpgid.$(OBJEXT)
 xetpgid_LDADD = $(LDADD)
 xetpgid_DEPENDENCIES = libtests.a
+xetpgid__pidns_translation_SOURCES = xetpgid--pidns-translation.c
+xetpgid__pidns_translation_OBJECTS =  \
+	xetpgid--pidns-translation.$(OBJEXT)
+xetpgid__pidns_translation_LDADD = $(LDADD)
+xetpgid__pidns_translation_DEPENDENCIES = libtests.a
 xetpriority_SOURCES = xetpriority.c
 xetpriority_OBJECTS = xetpriority.$(OBJEXT)
 xetpriority_LDADD = $(LDADD)
 xetpriority_DEPENDENCIES = libtests.a
+xetpriority__pidns_translation_SOURCES =  \
+	xetpriority--pidns-translation.c
+xetpriority__pidns_translation_OBJECTS =  \
+	xetpriority--pidns-translation.$(OBJEXT)
+xetpriority__pidns_translation_LDADD = $(LDADD)
+xetpriority__pidns_translation_DEPENDENCIES = libtests.a
 xettimeofday_SOURCES = xettimeofday.c
 xettimeofday_OBJECTS = xettimeofday.$(OBJEXT)
 xettimeofday_LDADD = $(LDADD)
@@ -3213,31 +3997,50 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/bpf-obj_get_info_by_fd-prog.Po \
 	./$(DEPDIR)/bpf-obj_get_info_by_fd-v.Po \
 	./$(DEPDIR)/bpf-obj_get_info_by_fd.Po \
-	./$(DEPDIR)/bpf-success-v.Po ./$(DEPDIR)/bpf-success.Po \
-	./$(DEPDIR)/bpf-v.Po ./$(DEPDIR)/bpf.Po ./$(DEPDIR)/brk.Po \
-	./$(DEPDIR)/btrfs.Po ./$(DEPDIR)/caps-abbrev.Po \
-	./$(DEPDIR)/caps.Po ./$(DEPDIR)/check_sigblock.Po \
-	./$(DEPDIR)/check_sigign.Po ./$(DEPDIR)/chmod.Po \
-	./$(DEPDIR)/chown.Po ./$(DEPDIR)/chown32.Po \
-	./$(DEPDIR)/chroot.Po ./$(DEPDIR)/clock_adjtime.Po \
-	./$(DEPDIR)/clock_nanosleep.Po ./$(DEPDIR)/clock_xettime.Po \
-	./$(DEPDIR)/clone-flags.Po ./$(DEPDIR)/clone3-Xabbrev.Po \
-	./$(DEPDIR)/clone3-Xraw.Po ./$(DEPDIR)/clone3-Xverbose.Po \
+	./$(DEPDIR)/bpf-success-long-y.Po ./$(DEPDIR)/bpf-success-v.Po \
+	./$(DEPDIR)/bpf-success.Po ./$(DEPDIR)/bpf-v.Po \
+	./$(DEPDIR)/bpf.Po ./$(DEPDIR)/brk.Po ./$(DEPDIR)/btrfs.Po \
+	./$(DEPDIR)/caps-abbrev.Po ./$(DEPDIR)/caps.Po \
+	./$(DEPDIR)/check_sigblock.Po ./$(DEPDIR)/check_sigign.Po \
+	./$(DEPDIR)/chmod.Po ./$(DEPDIR)/chown.Po \
+	./$(DEPDIR)/chown32.Po ./$(DEPDIR)/chroot.Po \
+	./$(DEPDIR)/clock_adjtime.Po ./$(DEPDIR)/clock_nanosleep.Po \
+	./$(DEPDIR)/clock_xettime.Po ./$(DEPDIR)/clone-flags.Po \
+	./$(DEPDIR)/clone3-Xabbrev.Po ./$(DEPDIR)/clone3-Xraw.Po \
+	./$(DEPDIR)/clone3-Xverbose.Po \
 	./$(DEPDIR)/clone3-success-Xabbrev.Po \
 	./$(DEPDIR)/clone3-success-Xraw.Po \
 	./$(DEPDIR)/clone3-success-Xverbose.Po \
 	./$(DEPDIR)/clone3-success.Po ./$(DEPDIR)/clone3.Po \
-	./$(DEPDIR)/clone_parent.Po ./$(DEPDIR)/clone_ptrace.Po \
-	./$(DEPDIR)/copy_file_range.Po ./$(DEPDIR)/count-f.Po \
-	./$(DEPDIR)/creat.Po ./$(DEPDIR)/delay.Po \
-	./$(DEPDIR)/delete_module.Po ./$(DEPDIR)/dev-yy.Po \
-	./$(DEPDIR)/dup.Po ./$(DEPDIR)/dup2.Po ./$(DEPDIR)/dup3.Po \
-	./$(DEPDIR)/epoll_create.Po ./$(DEPDIR)/epoll_create1.Po \
-	./$(DEPDIR)/epoll_ctl.Po ./$(DEPDIR)/epoll_pwait.Po \
-	./$(DEPDIR)/epoll_wait.Po ./$(DEPDIR)/erestartsys.Po \
-	./$(DEPDIR)/eventfd.Po ./$(DEPDIR)/execve-v.Po \
-	./$(DEPDIR)/execve.Po ./$(DEPDIR)/execveat-v.Po \
-	./$(DEPDIR)/execveat.Po ./$(DEPDIR)/faccessat.Po \
+	./$(DEPDIR)/clone_parent--quiet-exit.Po \
+	./$(DEPDIR)/clone_parent-q.Po ./$(DEPDIR)/clone_parent-qq.Po \
+	./$(DEPDIR)/clone_parent.Po \
+	./$(DEPDIR)/clone_ptrace--quiet-attach.Po \
+	./$(DEPDIR)/clone_ptrace--quiet-exit.Po \
+	./$(DEPDIR)/clone_ptrace-q.Po ./$(DEPDIR)/clone_ptrace-qq.Po \
+	./$(DEPDIR)/clone_ptrace.Po ./$(DEPDIR)/close_range-P.Po \
+	./$(DEPDIR)/close_range-y.Po ./$(DEPDIR)/close_range-yy.Po \
+	./$(DEPDIR)/close_range.Po ./$(DEPDIR)/copy_file_range.Po \
+	./$(DEPDIR)/count-f.Po ./$(DEPDIR)/creat.Po \
+	./$(DEPDIR)/delay.Po ./$(DEPDIR)/delete_module.Po \
+	./$(DEPDIR)/dev--decode-fds-dev.Po \
+	./$(DEPDIR)/dev--decode-fds-path.Po \
+	./$(DEPDIR)/dev--decode-fds-socket.Po ./$(DEPDIR)/dev-yy.Po \
+	./$(DEPDIR)/dup-P.Po ./$(DEPDIR)/dup-y.Po \
+	./$(DEPDIR)/dup-yy.Po ./$(DEPDIR)/dup.Po ./$(DEPDIR)/dup2-P.Po \
+	./$(DEPDIR)/dup2-y.Po ./$(DEPDIR)/dup2-yy.Po \
+	./$(DEPDIR)/dup2.Po ./$(DEPDIR)/dup3-P.Po \
+	./$(DEPDIR)/dup3-y.Po ./$(DEPDIR)/dup3-yy.Po \
+	./$(DEPDIR)/dup3.Po ./$(DEPDIR)/epoll_create.Po \
+	./$(DEPDIR)/epoll_create1.Po ./$(DEPDIR)/epoll_ctl.Po \
+	./$(DEPDIR)/epoll_pwait.Po ./$(DEPDIR)/epoll_wait.Po \
+	./$(DEPDIR)/erestartsys.Po ./$(DEPDIR)/eventfd.Po \
+	./$(DEPDIR)/execve-v.Po ./$(DEPDIR)/execve.Po \
+	./$(DEPDIR)/execveat-v.Po ./$(DEPDIR)/execveat.Po \
+	./$(DEPDIR)/faccessat-P.Po ./$(DEPDIR)/faccessat-y.Po \
+	./$(DEPDIR)/faccessat-yy.Po ./$(DEPDIR)/faccessat.Po \
+	./$(DEPDIR)/faccessat2-P.Po ./$(DEPDIR)/faccessat2-y.Po \
+	./$(DEPDIR)/faccessat2-yy.Po ./$(DEPDIR)/faccessat2.Po \
 	./$(DEPDIR)/fadvise64.Po ./$(DEPDIR)/fadvise64_64.Po \
 	./$(DEPDIR)/fallocate.Po ./$(DEPDIR)/fanotify_init.Po \
 	./$(DEPDIR)/fanotify_mark-Xabbrev.Po \
@@ -3246,49 +4049,59 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/fanotify_mark.Po ./$(DEPDIR)/fchdir.Po \
 	./$(DEPDIR)/fchmod.Po ./$(DEPDIR)/fchmodat.Po \
 	./$(DEPDIR)/fchown.Po ./$(DEPDIR)/fchown32.Po \
-	./$(DEPDIR)/fchownat.Po ./$(DEPDIR)/fcntl.Po \
+	./$(DEPDIR)/fchownat.Po \
+	./$(DEPDIR)/fcntl--pidns-translation.Po ./$(DEPDIR)/fcntl.Po \
+	./$(DEPDIR)/fcntl64--pidns-translation.Po \
 	./$(DEPDIR)/fcntl64.Po ./$(DEPDIR)/fdatasync.Po \
 	./$(DEPDIR)/fflush.Po ./$(DEPDIR)/file_handle.Po \
 	./$(DEPDIR)/file_ioctl.Po ./$(DEPDIR)/filter-unavailable.Po \
 	./$(DEPDIR)/filter_seccomp-flag.Po \
 	./$(DEPDIR)/filter_seccomp-perf.Po ./$(DEPDIR)/finit_module.Po \
-	./$(DEPDIR)/flock.Po ./$(DEPDIR)/fork-f.Po \
-	./$(DEPDIR)/fsconfig-P.Po ./$(DEPDIR)/fsconfig.Po \
-	./$(DEPDIR)/fsmount.Po ./$(DEPDIR)/fsopen.Po \
-	./$(DEPDIR)/fspick-P.Po ./$(DEPDIR)/fspick.Po \
-	./$(DEPDIR)/fstat-Xabbrev.Po ./$(DEPDIR)/fstat-Xraw.Po \
-	./$(DEPDIR)/fstat-Xverbose.Po ./$(DEPDIR)/fstat.Po \
-	./$(DEPDIR)/fstat64-Xabbrev.Po ./$(DEPDIR)/fstat64-Xraw.Po \
-	./$(DEPDIR)/fstat64-Xverbose.Po ./$(DEPDIR)/fstat64-fstat64.Po \
+	./$(DEPDIR)/flock.Po ./$(DEPDIR)/fork--pidns-translation.Po \
+	./$(DEPDIR)/fork-f.Po ./$(DEPDIR)/fsconfig-P.Po \
+	./$(DEPDIR)/fsconfig.Po ./$(DEPDIR)/fsmount.Po \
+	./$(DEPDIR)/fsopen.Po ./$(DEPDIR)/fspick-P.Po \
+	./$(DEPDIR)/fspick.Po ./$(DEPDIR)/fstat-Xabbrev.Po \
+	./$(DEPDIR)/fstat-Xraw.Po ./$(DEPDIR)/fstat-Xverbose.Po \
+	./$(DEPDIR)/fstat.Po ./$(DEPDIR)/fstat64-Xabbrev.Po \
+	./$(DEPDIR)/fstat64-Xraw.Po ./$(DEPDIR)/fstat64-Xverbose.Po \
+	./$(DEPDIR)/fstat64-fstat64.Po \
 	./$(DEPDIR)/fstatat64-fstatat64.Po ./$(DEPDIR)/fstatfs.Po \
 	./$(DEPDIR)/fstatfs64.Po ./$(DEPDIR)/fsync-y.Po \
 	./$(DEPDIR)/fsync.Po ./$(DEPDIR)/ftruncate.Po \
 	./$(DEPDIR)/ftruncate64-ftruncate64.Po ./$(DEPDIR)/futex.Po \
 	./$(DEPDIR)/futimesat.Po ./$(DEPDIR)/get_mempolicy.Po \
-	./$(DEPDIR)/getcpu.Po ./$(DEPDIR)/getcwd.Po \
-	./$(DEPDIR)/getdents.Po ./$(DEPDIR)/getdents64.Po \
-	./$(DEPDIR)/getegid.Po ./$(DEPDIR)/getegid32.Po \
-	./$(DEPDIR)/geteuid.Po ./$(DEPDIR)/geteuid32.Po \
-	./$(DEPDIR)/getgid.Po ./$(DEPDIR)/getgid32.Po \
-	./$(DEPDIR)/getgroups.Po ./$(DEPDIR)/getgroups32.Po \
-	./$(DEPDIR)/getpeername.Po ./$(DEPDIR)/getpgrp.Po \
-	./$(DEPDIR)/getpid.Po ./$(DEPDIR)/getppid.Po \
-	./$(DEPDIR)/getrandom.Po ./$(DEPDIR)/getresgid.Po \
-	./$(DEPDIR)/getresgid32.Po ./$(DEPDIR)/getresuid.Po \
-	./$(DEPDIR)/getresuid32.Po ./$(DEPDIR)/getrlimit.Po \
-	./$(DEPDIR)/getrusage.Po ./$(DEPDIR)/getsid.Po \
-	./$(DEPDIR)/getsockname.Po ./$(DEPDIR)/gettid.Po \
+	./$(DEPDIR)/get_process_reaper.Po ./$(DEPDIR)/getcpu.Po \
+	./$(DEPDIR)/getcwd.Po ./$(DEPDIR)/getdents-v.Po \
+	./$(DEPDIR)/getdents.Po ./$(DEPDIR)/getdents64-v.Po \
+	./$(DEPDIR)/getdents64.Po ./$(DEPDIR)/getegid.Po \
+	./$(DEPDIR)/getegid32.Po ./$(DEPDIR)/geteuid.Po \
+	./$(DEPDIR)/geteuid32.Po ./$(DEPDIR)/getgid.Po \
+	./$(DEPDIR)/getgid32.Po ./$(DEPDIR)/getgroups.Po \
+	./$(DEPDIR)/getgroups32.Po ./$(DEPDIR)/getpeername.Po \
+	./$(DEPDIR)/getpgrp--pidns-translation.Po \
+	./$(DEPDIR)/getpgrp.Po \
+	./$(DEPDIR)/getpid--pidns-translation.Po ./$(DEPDIR)/getpid.Po \
+	./$(DEPDIR)/getppid.Po ./$(DEPDIR)/getrandom.Po \
+	./$(DEPDIR)/getresgid.Po ./$(DEPDIR)/getresgid32.Po \
+	./$(DEPDIR)/getresuid.Po ./$(DEPDIR)/getresuid32.Po \
+	./$(DEPDIR)/getrlimit.Po ./$(DEPDIR)/getrusage.Po \
+	./$(DEPDIR)/getsid--pidns-translation.Po ./$(DEPDIR)/getsid.Po \
+	./$(DEPDIR)/getsockname.Po \
+	./$(DEPDIR)/gettid--pidns-translation.Po ./$(DEPDIR)/gettid.Po \
 	./$(DEPDIR)/getuid.Po ./$(DEPDIR)/getuid32.Po \
-	./$(DEPDIR)/getxxid.Po ./$(DEPDIR)/group_req.Po \
+	./$(DEPDIR)/getxgid.Po ./$(DEPDIR)/getxpid.Po \
+	./$(DEPDIR)/getxuid.Po ./$(DEPDIR)/group_req.Po \
 	./$(DEPDIR)/inet-cmsg.Po ./$(DEPDIR)/init_module.Po \
 	./$(DEPDIR)/inject-nf.Po ./$(DEPDIR)/inotify.Po \
 	./$(DEPDIR)/inotify_init-y.Po ./$(DEPDIR)/inotify_init.Po \
 	./$(DEPDIR)/inotify_init1-y.Po ./$(DEPDIR)/inotify_init1.Po \
 	./$(DEPDIR)/int_0x80.Po ./$(DEPDIR)/io_uring_enter.Po \
 	./$(DEPDIR)/io_uring_register.Po ./$(DEPDIR)/io_uring_setup.Po \
-	./$(DEPDIR)/ioctl.Po ./$(DEPDIR)/ioctl_block.Po \
-	./$(DEPDIR)/ioctl_dm-v.Po ./$(DEPDIR)/ioctl_dm.Po \
-	./$(DEPDIR)/ioctl_evdev-Xabbrev.Po \
+	./$(DEPDIR)/ioctl.Po \
+	./$(DEPDIR)/ioctl_block--pidns-translation.Po \
+	./$(DEPDIR)/ioctl_block.Po ./$(DEPDIR)/ioctl_dm-v.Po \
+	./$(DEPDIR)/ioctl_dm.Po ./$(DEPDIR)/ioctl_evdev-Xabbrev.Po \
 	./$(DEPDIR)/ioctl_evdev-Xraw.Po \
 	./$(DEPDIR)/ioctl_evdev-Xverbose.Po \
 	./$(DEPDIR)/ioctl_evdev-success-Xabbrev.Po \
@@ -3303,6 +4116,21 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/ioctl_evdev-v-Xraw.Po \
 	./$(DEPDIR)/ioctl_evdev-v-Xverbose.Po \
 	./$(DEPDIR)/ioctl_evdev-v.Po ./$(DEPDIR)/ioctl_evdev.Po \
+	./$(DEPDIR)/ioctl_hdio-Xabbrev.Po \
+	./$(DEPDIR)/ioctl_hdio-Xraw.Po \
+	./$(DEPDIR)/ioctl_hdio-Xverbose.Po \
+	./$(DEPDIR)/ioctl_hdio-success-Xabbrev.Po \
+	./$(DEPDIR)/ioctl_hdio-success-Xraw.Po \
+	./$(DEPDIR)/ioctl_hdio-success-Xverbose.Po \
+	./$(DEPDIR)/ioctl_hdio-success-v-Xabbrev.Po \
+	./$(DEPDIR)/ioctl_hdio-success-v-Xraw.Po \
+	./$(DEPDIR)/ioctl_hdio-success-v-Xverbose.Po \
+	./$(DEPDIR)/ioctl_hdio-success-v.Po \
+	./$(DEPDIR)/ioctl_hdio-success.Po \
+	./$(DEPDIR)/ioctl_hdio-v-Xabbrev.Po \
+	./$(DEPDIR)/ioctl_hdio-v-Xraw.Po \
+	./$(DEPDIR)/ioctl_hdio-v-Xverbose.Po \
+	./$(DEPDIR)/ioctl_hdio-v.Po ./$(DEPDIR)/ioctl_hdio.Po \
 	./$(DEPDIR)/ioctl_inotify.Po ./$(DEPDIR)/ioctl_kvm_run-v.Po \
 	./$(DEPDIR)/ioctl_kvm_run.Po \
 	./$(DEPDIR)/ioctl_kvm_run_auxstr_vcpu.Po \
@@ -3314,9 +4142,24 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/ioctl_rtc-v.Po ./$(DEPDIR)/ioctl_rtc.Po \
 	./$(DEPDIR)/ioctl_scsi.Po ./$(DEPDIR)/ioctl_sg_io_v3.Po \
 	./$(DEPDIR)/ioctl_sg_io_v4.Po \
-	./$(DEPDIR)/ioctl_sock_gifconf.Po ./$(DEPDIR)/ioctl_uffdio.Po \
-	./$(DEPDIR)/ioctl_v4l2.Po ./$(DEPDIR)/ioctl_watchdog.Po \
-	./$(DEPDIR)/ioperm.Po ./$(DEPDIR)/iopl.Po \
+	./$(DEPDIR)/ioctl_sock_gifconf.Po ./$(DEPDIR)/ioctl_tee.Po \
+	./$(DEPDIR)/ioctl_uffdio.Po ./$(DEPDIR)/ioctl_v4l2-Xabbrev.Po \
+	./$(DEPDIR)/ioctl_v4l2-Xraw.Po \
+	./$(DEPDIR)/ioctl_v4l2-Xverbose.Po \
+	./$(DEPDIR)/ioctl_v4l2-success-Xabbrev.Po \
+	./$(DEPDIR)/ioctl_v4l2-success-Xraw.Po \
+	./$(DEPDIR)/ioctl_v4l2-success-Xverbose.Po \
+	./$(DEPDIR)/ioctl_v4l2-success-v-Xabbrev.Po \
+	./$(DEPDIR)/ioctl_v4l2-success-v-Xraw.Po \
+	./$(DEPDIR)/ioctl_v4l2-success-v-Xverbose.Po \
+	./$(DEPDIR)/ioctl_v4l2-success-v.Po \
+	./$(DEPDIR)/ioctl_v4l2-success.Po \
+	./$(DEPDIR)/ioctl_v4l2-v-Xabbrev.Po \
+	./$(DEPDIR)/ioctl_v4l2-v-Xraw.Po \
+	./$(DEPDIR)/ioctl_v4l2-v-Xverbose.Po \
+	./$(DEPDIR)/ioctl_v4l2-v.Po ./$(DEPDIR)/ioctl_v4l2.Po \
+	./$(DEPDIR)/ioctl_watchdog.Po ./$(DEPDIR)/ioperm.Po \
+	./$(DEPDIR)/iopl.Po ./$(DEPDIR)/ioprio--pidns-translation.Po \
 	./$(DEPDIR)/ioprio-Xabbrev.Po ./$(DEPDIR)/ioprio-Xraw.Po \
 	./$(DEPDIR)/ioprio-Xverbose.Po ./$(DEPDIR)/ioprio.Po \
 	./$(DEPDIR)/ip_mreq.Po ./$(DEPDIR)/ipc.Po \
@@ -3329,7 +4172,8 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/ipc_sem-Xverbose.Po ./$(DEPDIR)/ipc_sem.Po \
 	./$(DEPDIR)/ipc_shm-Xabbrev.Po ./$(DEPDIR)/ipc_shm-Xraw.Po \
 	./$(DEPDIR)/ipc_shm-Xverbose.Po ./$(DEPDIR)/ipc_shm.Po \
-	./$(DEPDIR)/is_linux_mips_n64.Po ./$(DEPDIR)/kcmp-y.Po \
+	./$(DEPDIR)/is_linux_mips_n64.Po \
+	./$(DEPDIR)/kcmp-y--pidns-translation.Po ./$(DEPDIR)/kcmp-y.Po \
 	./$(DEPDIR)/kcmp.Po ./$(DEPDIR)/kern_features.Po \
 	./$(DEPDIR)/kernel_version-Xabbrev.Po \
 	./$(DEPDIR)/kernel_version-Xraw.Po \
@@ -3337,10 +4181,12 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/kernel_version.Po ./$(DEPDIR)/kexec_file_load.Po \
 	./$(DEPDIR)/kexec_load.Po ./$(DEPDIR)/keyctl-Xabbrev.Po \
 	./$(DEPDIR)/keyctl-Xraw.Po ./$(DEPDIR)/keyctl-Xverbose.Po \
-	./$(DEPDIR)/keyctl.Po ./$(DEPDIR)/kill.Po \
-	./$(DEPDIR)/kill_child.Po ./$(DEPDIR)/ksysent.Po \
-	./$(DEPDIR)/lchown.Po ./$(DEPDIR)/lchown32.Po \
+	./$(DEPDIR)/keyctl.Po ./$(DEPDIR)/kill--pidns-translation.Po \
+	./$(DEPDIR)/kill.Po ./$(DEPDIR)/kill_child.Po \
+	./$(DEPDIR)/ksysent.Po ./$(DEPDIR)/lchown.Po \
+	./$(DEPDIR)/lchown32.Po \
 	./$(DEPDIR)/libtests_a-create_nl_socket.Po \
+	./$(DEPDIR)/libtests_a-create_tmpfile.Po \
 	./$(DEPDIR)/libtests_a-errno2name.Po \
 	./$(DEPDIR)/libtests_a-error_msg.Po \
 	./$(DEPDIR)/libtests_a-fill_memory.Po \
@@ -3354,6 +4200,7 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/libtests_a-libsocketcall.Po \
 	./$(DEPDIR)/libtests_a-lock_file.Po \
 	./$(DEPDIR)/libtests_a-overflowuid.Po \
+	./$(DEPDIR)/libtests_a-pidns.Po \
 	./$(DEPDIR)/libtests_a-pipe_maxfd.Po \
 	./$(DEPDIR)/libtests_a-print_quoted_string.Po \
 	./$(DEPDIR)/libtests_a-print_time.Po \
@@ -3369,26 +4216,30 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/libtests_a-test_printpath.Po \
 	./$(DEPDIR)/libtests_a-test_printstrn.Po \
 	./$(DEPDIR)/libtests_a-test_ucopy.Po \
-	./$(DEPDIR)/libtests_a-tprintf.Po ./$(DEPDIR)/link.Po \
-	./$(DEPDIR)/linkat.Po ./$(DEPDIR)/list_sigaction_signum.Po \
-	./$(DEPDIR)/llseek.Po ./$(DEPDIR)/localtime.Po \
-	./$(DEPDIR)/lookup_dcookie.Po ./$(DEPDIR)/looping_threads.Po \
-	./$(DEPDIR)/lseek.Po ./$(DEPDIR)/lstat.Po \
-	./$(DEPDIR)/lstat64-lstat64.Po ./$(DEPDIR)/madvise.Po \
+	./$(DEPDIR)/libtests_a-tprintf.Po \
+	./$(DEPDIR)/libtests_a-xmalloc_for_tests.Po \
+	./$(DEPDIR)/link.Po ./$(DEPDIR)/linkat.Po \
+	./$(DEPDIR)/list_sigaction_signum.Po ./$(DEPDIR)/llseek.Po \
+	./$(DEPDIR)/localtime.Po ./$(DEPDIR)/lookup_dcookie.Po \
+	./$(DEPDIR)/looping_threads.Po ./$(DEPDIR)/lseek.Po \
+	./$(DEPDIR)/lstat.Po ./$(DEPDIR)/lstat64-lstat64.Po \
+	./$(DEPDIR)/madvise.Po \
+	./$(DEPDIR)/maybe_switch_current_tcp--quiet-thread-execve.Po \
 	./$(DEPDIR)/maybe_switch_current_tcp.Po \
 	./$(DEPDIR)/mbind-Xabbrev.Po ./$(DEPDIR)/mbind-Xraw.Po \
 	./$(DEPDIR)/mbind-Xverbose.Po ./$(DEPDIR)/mbind.Po \
 	./$(DEPDIR)/membarrier.Po ./$(DEPDIR)/memfd_create-Xabbrev.Po \
 	./$(DEPDIR)/memfd_create-Xraw.Po \
 	./$(DEPDIR)/memfd_create-Xverbose.Po \
-	./$(DEPDIR)/memfd_create.Po ./$(DEPDIR)/migrate_pages.Po \
-	./$(DEPDIR)/mincore.Po ./$(DEPDIR)/mkdir.Po \
-	./$(DEPDIR)/mkdirat.Po ./$(DEPDIR)/mknod.Po \
-	./$(DEPDIR)/mknodat.Po ./$(DEPDIR)/mlock.Po \
-	./$(DEPDIR)/mlock2.Po ./$(DEPDIR)/mlockall.Po \
-	./$(DEPDIR)/mmap-Xabbrev.Po ./$(DEPDIR)/mmap-Xraw.Po \
-	./$(DEPDIR)/mmap-Xverbose.Po ./$(DEPDIR)/mmap.Po \
-	./$(DEPDIR)/mmap64-mmap64.Po \
+	./$(DEPDIR)/memfd_create.Po \
+	./$(DEPDIR)/migrate_pages--pidns-translation.Po \
+	./$(DEPDIR)/migrate_pages.Po ./$(DEPDIR)/mincore.Po \
+	./$(DEPDIR)/mkdir.Po ./$(DEPDIR)/mkdirat.Po \
+	./$(DEPDIR)/mknod.Po ./$(DEPDIR)/mknodat.Po \
+	./$(DEPDIR)/mlock.Po ./$(DEPDIR)/mlock2.Po \
+	./$(DEPDIR)/mlockall.Po ./$(DEPDIR)/mmap-Xabbrev.Po \
+	./$(DEPDIR)/mmap-Xraw.Po ./$(DEPDIR)/mmap-Xverbose.Po \
+	./$(DEPDIR)/mmap.Po ./$(DEPDIR)/mmap64-mmap64.Po \
 	./$(DEPDIR)/mmap64_Xabbrev-mmap64-Xabbrev.Po \
 	./$(DEPDIR)/mmap64_Xraw-mmap64-Xraw.Po \
 	./$(DEPDIR)/mmap64_Xverbose-mmap64-Xverbose.Po \
@@ -3397,24 +4248,33 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/modify_ldt.Po ./$(DEPDIR)/mount-Xabbrev.Po \
 	./$(DEPDIR)/mount-Xraw.Po ./$(DEPDIR)/mount-Xverbose.Po \
 	./$(DEPDIR)/mount.Po ./$(DEPDIR)/move_mount-P.Po \
-	./$(DEPDIR)/move_mount.Po ./$(DEPDIR)/move_pages-Xabbrev.Po \
+	./$(DEPDIR)/move_mount.Po \
+	./$(DEPDIR)/move_pages--pidns-translation.Po \
+	./$(DEPDIR)/move_pages-Xabbrev.Po \
 	./$(DEPDIR)/move_pages-Xraw.Po \
 	./$(DEPDIR)/move_pages-Xverbose.Po ./$(DEPDIR)/move_pages.Po \
 	./$(DEPDIR)/mq.Po ./$(DEPDIR)/mq_sendrecv-read.Po \
 	./$(DEPDIR)/mq_sendrecv-write.Po ./$(DEPDIR)/mq_sendrecv.Po \
 	./$(DEPDIR)/msg_control-v.Po ./$(DEPDIR)/msg_control.Po \
 	./$(DEPDIR)/msg_name.Po ./$(DEPDIR)/munlockall.Po \
-	./$(DEPDIR)/nanosleep.Po ./$(DEPDIR)/net-accept-connect.Po \
+	./$(DEPDIR)/nanosleep.Po \
+	./$(DEPDIR)/net--decode-fds-dev-netlink.Po \
+	./$(DEPDIR)/net--decode-fds-none-netlink.Po \
+	./$(DEPDIR)/net--decode-fds-path-netlink.Po \
+	./$(DEPDIR)/net--decode-fds-socket-netlink.Po \
+	./$(DEPDIR)/net-accept-connect.Po \
 	./$(DEPDIR)/net-icmp_filter.Po \
 	./$(DEPDIR)/net-packet_mreq-Xabbrev.Po \
 	./$(DEPDIR)/net-packet_mreq-Xraw.Po \
 	./$(DEPDIR)/net-packet_mreq-Xverbose.Po \
-	./$(DEPDIR)/net-packet_mreq.Po ./$(DEPDIR)/net-sockaddr.Po \
-	./$(DEPDIR)/net-tpacket_req.Po \
+	./$(DEPDIR)/net-packet_mreq.Po \
+	./$(DEPDIR)/net-sockaddr--pidns-translation.Po \
+	./$(DEPDIR)/net-sockaddr.Po ./$(DEPDIR)/net-tpacket_req.Po \
 	./$(DEPDIR)/net-tpacket_stats-success.Po \
 	./$(DEPDIR)/net-tpacket_stats.Po ./$(DEPDIR)/net-y-unix.Po \
 	./$(DEPDIR)/net-yy-inet.Po ./$(DEPDIR)/net-yy-inet6.Po \
 	./$(DEPDIR)/net-yy-netlink.Po ./$(DEPDIR)/net-yy-unix.Po \
+	./$(DEPDIR)/netlink_audit--pidns-translation.Po \
 	./$(DEPDIR)/netlink_audit.Po ./$(DEPDIR)/netlink_crypto.Po \
 	./$(DEPDIR)/netlink_generic.Po \
 	./$(DEPDIR)/netlink_inet_diag.Po \
@@ -3445,7 +4305,9 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/nlattr_ifla_af_spec.Po \
 	./$(DEPDIR)/nlattr_ifla_brport.Po \
 	./$(DEPDIR)/nlattr_ifla_linkinfo.Po \
-	./$(DEPDIR)/nlattr_ifla_port.Po ./$(DEPDIR)/nlattr_ifla_xdp.Po \
+	./$(DEPDIR)/nlattr_ifla_port.Po \
+	./$(DEPDIR)/nlattr_ifla_xdp-y.Po \
+	./$(DEPDIR)/nlattr_ifla_xdp.Po \
 	./$(DEPDIR)/nlattr_inet_diag_msg.Po \
 	./$(DEPDIR)/nlattr_inet_diag_req_compat.Po \
 	./$(DEPDIR)/nlattr_inet_diag_req_v2.Po \
@@ -3470,7 +4332,13 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/oldselect-efault.Po ./$(DEPDIR)/oldselect.Po \
 	./$(DEPDIR)/oldstat.Po ./$(DEPDIR)/open.Po \
 	./$(DEPDIR)/open_tree-P.Po ./$(DEPDIR)/open_tree.Po \
-	./$(DEPDIR)/openat.Po ./$(DEPDIR)/orphaned_process_group.Po \
+	./$(DEPDIR)/openat.Po ./$(DEPDIR)/openat2-Xabbrev.Po \
+	./$(DEPDIR)/openat2-Xraw.Po ./$(DEPDIR)/openat2-Xverbose.Po \
+	./$(DEPDIR)/openat2-v-y-Xabbrev.Po \
+	./$(DEPDIR)/openat2-v-y-Xraw.Po \
+	./$(DEPDIR)/openat2-v-y-Xverbose.Po ./$(DEPDIR)/openat2-v-y.Po \
+	./$(DEPDIR)/openat2-v.Po ./$(DEPDIR)/openat2-y.Po \
+	./$(DEPDIR)/openat2.Po ./$(DEPDIR)/orphaned_process_group.Po \
 	./$(DEPDIR)/osf_utimes.Po ./$(DEPDIR)/pause.Po \
 	./$(DEPDIR)/pc.Po ./$(DEPDIR)/perf_event_open.Po \
 	./$(DEPDIR)/perf_event_open_nonverbose.Po \
@@ -3478,8 +4346,16 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/personality-Xabbrev.Po \
 	./$(DEPDIR)/personality-Xraw.Po \
 	./$(DEPDIR)/personality-Xverbose.Po ./$(DEPDIR)/personality.Po \
+	./$(DEPDIR)/pidfd_getfd-y.Po ./$(DEPDIR)/pidfd_getfd-yy.Po \
+	./$(DEPDIR)/pidfd_getfd.Po \
+	./$(DEPDIR)/pidfd_open--decode-fd-path.Po \
+	./$(DEPDIR)/pidfd_open--decode-fd-pidfd.Po \
+	./$(DEPDIR)/pidfd_open--decode-fd-socket.Po \
+	./$(DEPDIR)/pidfd_open--pidns-translation.Po \
 	./$(DEPDIR)/pidfd_open-P.Po ./$(DEPDIR)/pidfd_open-y.Po \
-	./$(DEPDIR)/pidfd_open.Po ./$(DEPDIR)/pidfd_send_signal.Po \
+	./$(DEPDIR)/pidfd_open-yy.Po ./$(DEPDIR)/pidfd_open.Po \
+	./$(DEPDIR)/pidfd_send_signal--pidns-translation.Po \
+	./$(DEPDIR)/pidfd_send_signal.Po ./$(DEPDIR)/pidns-cache.Po \
 	./$(DEPDIR)/pipe.Po ./$(DEPDIR)/pipe2.Po \
 	./$(DEPDIR)/pkey_alloc.Po ./$(DEPDIR)/pkey_free.Po \
 	./$(DEPDIR)/pkey_mprotect.Po ./$(DEPDIR)/poll-P.Po \
@@ -3496,7 +4372,7 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/pread64_pwrite64-pread64-pwrite64.Po \
 	./$(DEPDIR)/preadv-preadv.Po ./$(DEPDIR)/preadv2-pwritev2.Po \
 	./$(DEPDIR)/preadv_pwritev-preadv-pwritev.Po \
-	./$(DEPDIR)/print_maxfd.Po \
+	./$(DEPDIR)/print_maxfd.Po ./$(DEPDIR)/print_ppid_tracerpid.Po \
 	./$(DEPDIR)/printpath-umovestr-peekdata.Po \
 	./$(DEPDIR)/printpath-umovestr-undumpable.Po \
 	./$(DEPDIR)/printpath-umovestr.Po \
@@ -3505,8 +4381,12 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/printsignal-Xverbose.Po ./$(DEPDIR)/printstr.Po \
 	./$(DEPDIR)/printstrn-umoven-peekdata.Po \
 	./$(DEPDIR)/printstrn-umoven-undumpable.Po \
-	./$(DEPDIR)/printstrn-umoven.Po ./$(DEPDIR)/prlimit64.Po \
+	./$(DEPDIR)/printstrn-umoven.Po \
+	./$(DEPDIR)/prlimit64--pidns-translation.Po \
+	./$(DEPDIR)/prlimit64.Po \
+	./$(DEPDIR)/process_vm_readv--pidns-translation.Po \
 	./$(DEPDIR)/process_vm_readv.Po \
+	./$(DEPDIR)/process_vm_writev--pidns-translation.Po \
 	./$(DEPDIR)/process_vm_writev.Po ./$(DEPDIR)/pselect6.Po \
 	./$(DEPDIR)/ptrace.Po ./$(DEPDIR)/ptrace_syscall_info.Po \
 	./$(DEPDIR)/pwritev-pwritev.Po ./$(DEPDIR)/qual_fault.Po \
@@ -3536,9 +4416,11 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/request_key.Po ./$(DEPDIR)/restart_syscall.Po \
 	./$(DEPDIR)/riscv_flush_icache.Po ./$(DEPDIR)/rmdir.Po \
 	./$(DEPDIR)/rt_sigaction.Po ./$(DEPDIR)/rt_sigpending.Po \
-	./$(DEPDIR)/rt_sigprocmask.Po ./$(DEPDIR)/rt_sigqueueinfo.Po \
-	./$(DEPDIR)/rt_sigreturn.Po ./$(DEPDIR)/rt_sigsuspend.Po \
-	./$(DEPDIR)/rt_sigtimedwait.Po \
+	./$(DEPDIR)/rt_sigprocmask.Po \
+	./$(DEPDIR)/rt_sigqueueinfo--pidns-translation.Po \
+	./$(DEPDIR)/rt_sigqueueinfo.Po ./$(DEPDIR)/rt_sigreturn.Po \
+	./$(DEPDIR)/rt_sigsuspend.Po ./$(DEPDIR)/rt_sigtimedwait.Po \
+	./$(DEPDIR)/rt_tgsigqueueinfo--pidns-translation.Po \
 	./$(DEPDIR)/rt_tgsigqueueinfo.Po \
 	./$(DEPDIR)/run_expect_termsig.Po \
 	./$(DEPDIR)/s390_guarded_storage-v.Po \
@@ -3548,8 +4430,13 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/s390_sthyi.Po \
 	./$(DEPDIR)/sched_get_priority_mxx.Po \
 	./$(DEPDIR)/sched_rr_get_interval.Po \
-	./$(DEPDIR)/sched_xetaffinity.Po ./$(DEPDIR)/sched_xetattr.Po \
+	./$(DEPDIR)/sched_xetaffinity--pidns-translation.Po \
+	./$(DEPDIR)/sched_xetaffinity.Po \
+	./$(DEPDIR)/sched_xetattr--pidns-translation.Po \
+	./$(DEPDIR)/sched_xetattr.Po \
+	./$(DEPDIR)/sched_xetparam--pidns-translation.Po \
 	./$(DEPDIR)/sched_xetparam.Po \
+	./$(DEPDIR)/sched_xetscheduler--pidns-translation.Po \
 	./$(DEPDIR)/sched_xetscheduler.Po ./$(DEPDIR)/sched_yield.Po \
 	./$(DEPDIR)/scm_rights.Po ./$(DEPDIR)/seccomp-filter-v.Po \
 	./$(DEPDIR)/seccomp-filter.Po ./$(DEPDIR)/seccomp-strict.Po \
@@ -3567,22 +4454,25 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/setfsuid32.Po ./$(DEPDIR)/setgid.Po \
 	./$(DEPDIR)/setgid32.Po ./$(DEPDIR)/setgroups.Po \
 	./$(DEPDIR)/setgroups32.Po ./$(DEPDIR)/sethostname.Po \
-	./$(DEPDIR)/setns.Po ./$(DEPDIR)/setregid.Po \
-	./$(DEPDIR)/setregid32.Po ./$(DEPDIR)/setresgid.Po \
-	./$(DEPDIR)/setresgid32.Po ./$(DEPDIR)/setresuid.Po \
-	./$(DEPDIR)/setresuid32.Po ./$(DEPDIR)/setreuid.Po \
-	./$(DEPDIR)/setreuid32.Po ./$(DEPDIR)/setrlimit-Xabbrev.Po \
-	./$(DEPDIR)/setrlimit-Xraw.Po \
+	./$(DEPDIR)/setns.Po ./$(DEPDIR)/setpgrp-exec.Po \
+	./$(DEPDIR)/setregid.Po ./$(DEPDIR)/setregid32.Po \
+	./$(DEPDIR)/setresgid.Po ./$(DEPDIR)/setresgid32.Po \
+	./$(DEPDIR)/setresuid.Po ./$(DEPDIR)/setresuid32.Po \
+	./$(DEPDIR)/setreuid.Po ./$(DEPDIR)/setreuid32.Po \
+	./$(DEPDIR)/setrlimit-Xabbrev.Po ./$(DEPDIR)/setrlimit-Xraw.Po \
 	./$(DEPDIR)/setrlimit-Xverbose.Po ./$(DEPDIR)/setrlimit.Po \
 	./$(DEPDIR)/setuid.Po ./$(DEPDIR)/setuid32.Po \
 	./$(DEPDIR)/shmxt.Po ./$(DEPDIR)/shutdown.Po \
 	./$(DEPDIR)/sigaction.Po ./$(DEPDIR)/sigaltstack.Po \
 	./$(DEPDIR)/siginfo.Po ./$(DEPDIR)/signal.Po \
+	./$(DEPDIR)/signal_receive--pidns-translation.Po \
 	./$(DEPDIR)/signal_receive.Po ./$(DEPDIR)/signalfd4.Po \
 	./$(DEPDIR)/sigpending.Po ./$(DEPDIR)/sigprocmask.Po \
 	./$(DEPDIR)/sigreturn.Po ./$(DEPDIR)/sigsuspend.Po \
 	./$(DEPDIR)/sleep.Po ./$(DEPDIR)/so_error.Po \
-	./$(DEPDIR)/so_linger.Po ./$(DEPDIR)/so_peercred-Xabbrev.Po \
+	./$(DEPDIR)/so_linger.Po \
+	./$(DEPDIR)/so_peercred--pidns-translation.Po \
+	./$(DEPDIR)/so_peercred-Xabbrev.Po \
 	./$(DEPDIR)/so_peercred-Xraw.Po \
 	./$(DEPDIR)/so_peercred-Xverbose.Po ./$(DEPDIR)/so_peercred.Po \
 	./$(DEPDIR)/sock_filter-v-Xabbrev.Po \
@@ -3604,29 +4494,45 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/stack-fcall-mangled.Po ./$(DEPDIR)/stack-fcall.Po \
 	./$(DEPDIR)/stat.Po ./$(DEPDIR)/stat64-stat64.Po \
 	./$(DEPDIR)/statfs-statfs.Po ./$(DEPDIR)/statfs64.Po \
-	./$(DEPDIR)/status-all.Po ./$(DEPDIR)/status-failed.Po \
-	./$(DEPDIR)/status-none-f.Po \
+	./$(DEPDIR)/status-all.Po ./$(DEPDIR)/status-failed-long.Po \
+	./$(DEPDIR)/status-failed-status.Po \
+	./$(DEPDIR)/status-failed.Po ./$(DEPDIR)/status-none-f.Po \
 	./$(DEPDIR)/status-none-threads.Po ./$(DEPDIR)/status-none.Po \
+	./$(DEPDIR)/status-successful-long.Po \
+	./$(DEPDIR)/status-successful-status.Po \
 	./$(DEPDIR)/status-successful.Po \
 	./$(DEPDIR)/status-unfinished-threads.Po \
 	./$(DEPDIR)/status-unfinished.Po ./$(DEPDIR)/statx.Po \
+	./$(DEPDIR)/strace--strings-in-hex-all.Po \
+	./$(DEPDIR)/strace--strings-in-hex-non-ascii.Po \
+	./$(DEPDIR)/strace--strings-in-hex.Po ./$(DEPDIR)/strace-n.Po \
+	./$(DEPDIR)/strace-x.Po ./$(DEPDIR)/strace-xx.Po \
 	./$(DEPDIR)/swap.Po ./$(DEPDIR)/sxetmask.Po \
 	./$(DEPDIR)/symlink.Po ./$(DEPDIR)/symlinkat.Po \
 	./$(DEPDIR)/sync.Po ./$(DEPDIR)/sync_file_range.Po \
 	./$(DEPDIR)/sync_file_range2.Po ./$(DEPDIR)/sysinfo.Po \
 	./$(DEPDIR)/syslog-success.Po ./$(DEPDIR)/syslog.Po \
-	./$(DEPDIR)/tee.Po ./$(DEPDIR)/threads-execve.Po \
-	./$(DEPDIR)/time.Po ./$(DEPDIR)/timer_create.Po \
-	./$(DEPDIR)/timer_xettime.Po ./$(DEPDIR)/timerfd_xettime.Po \
-	./$(DEPDIR)/times-fail.Po ./$(DEPDIR)/times.Po \
-	./$(DEPDIR)/tracer_ppid_pgid_sid.Po ./$(DEPDIR)/truncate.Po \
+	./$(DEPDIR)/tee.Po ./$(DEPDIR)/tgkill--pidns-translation.Po \
+	./$(DEPDIR)/tgkill.Po \
+	./$(DEPDIR)/threads-execve--quiet-thread-execve.Po \
+	./$(DEPDIR)/threads-execve-q.Po \
+	./$(DEPDIR)/threads-execve-qq.Po \
+	./$(DEPDIR)/threads-execve-qqq.Po \
+	./$(DEPDIR)/threads-execve.Po ./$(DEPDIR)/time.Po \
+	./$(DEPDIR)/timer_create.Po ./$(DEPDIR)/timer_xettime.Po \
+	./$(DEPDIR)/timerfd_xettime.Po ./$(DEPDIR)/times-fail.Po \
+	./$(DEPDIR)/times.Po ./$(DEPDIR)/tkill--pidns-translation.Po \
+	./$(DEPDIR)/tkill.Po ./$(DEPDIR)/tracer_ppid_pgid_sid.Po \
+	./$(DEPDIR)/trie_test-trie_for_tests.Po \
+	./$(DEPDIR)/trie_test-trie_test.Po ./$(DEPDIR)/truncate.Po \
 	./$(DEPDIR)/truncate64-truncate64.Po ./$(DEPDIR)/ugetrlimit.Po \
 	./$(DEPDIR)/uio-uio.Po ./$(DEPDIR)/umask.Po \
 	./$(DEPDIR)/umount.Po ./$(DEPDIR)/umount2.Po \
 	./$(DEPDIR)/umoven-illptr.Po ./$(DEPDIR)/umovestr-illptr.Po \
 	./$(DEPDIR)/umovestr.Po ./$(DEPDIR)/umovestr2.Po \
 	./$(DEPDIR)/umovestr3.Po ./$(DEPDIR)/umovestr_cached.Po \
-	./$(DEPDIR)/uname.Po ./$(DEPDIR)/unblock_reset_raise.Po \
+	./$(DEPDIR)/umovestr_cached_adjacent.Po ./$(DEPDIR)/uname.Po \
+	./$(DEPDIR)/unblock_reset_raise.Po \
 	./$(DEPDIR)/unix-pair-send-recv.Po \
 	./$(DEPDIR)/unix-pair-sendto-recvfrom.Po ./$(DEPDIR)/unlink.Po \
 	./$(DEPDIR)/unlinkat.Po ./$(DEPDIR)/unshare.Po \
@@ -3639,10 +4545,15 @@ am__depfiles_remade = ./$(DEPDIR)/_newse
 	./$(DEPDIR)/wait4-v.Po ./$(DEPDIR)/wait4.Po \
 	./$(DEPDIR)/waitid-v.Po ./$(DEPDIR)/waitid.Po \
 	./$(DEPDIR)/waitpid.Po ./$(DEPDIR)/xattr-strings.Po \
-	./$(DEPDIR)/xattr.Po ./$(DEPDIR)/xet_robust_list.Po \
+	./$(DEPDIR)/xattr.Po \
+	./$(DEPDIR)/xet_robust_list--pidns-translation.Po \
+	./$(DEPDIR)/xet_robust_list.Po \
 	./$(DEPDIR)/xet_thread_area_x86.Po ./$(DEPDIR)/xetitimer.Po \
-	./$(DEPDIR)/xetpgid.Po ./$(DEPDIR)/xetpriority.Po \
-	./$(DEPDIR)/xettimeofday.Po ./$(DEPDIR)/zeroargc.Po
+	./$(DEPDIR)/xetpgid--pidns-translation.Po \
+	./$(DEPDIR)/xetpgid.Po \
+	./$(DEPDIR)/xetpriority--pidns-translation.Po \
+	./$(DEPDIR)/xetpriority.Po ./$(DEPDIR)/xettimeofday.Po \
+	./$(DEPDIR)/zeroargc.Po
 am__mv = mv -f
 AM_V_lt = $(am__v_lt_@AM_V@)
 am__v_lt_ = $(am__v_lt_@AM_DEFAULT_V@)
@@ -3667,85 +4578,121 @@ SOURCES = $(libtests_a_SOURCES) _newsele
 	block_reset_raise_run.c block_reset_run.c bpf.c \
 	bpf-obj_get_info_by_fd.c bpf-obj_get_info_by_fd-prog.c \
 	bpf-obj_get_info_by_fd-prog-v.c bpf-obj_get_info_by_fd-v.c \
-	bpf-success.c bpf-success-v.c bpf-v.c brk.c btrfs.c caps.c \
-	caps-abbrev.c check_sigblock.c check_sigign.c chmod.c chown.c \
-	chown32.c chroot.c clock_adjtime.c clock_nanosleep.c \
-	clock_xettime.c clone-flags.c clone3.c clone3-Xabbrev.c \
-	clone3-Xraw.c clone3-Xverbose.c clone3-success.c \
-	clone3-success-Xabbrev.c clone3-success-Xraw.c \
-	clone3-success-Xverbose.c clone_parent.c clone_ptrace.c \
+	bpf-success.c bpf-success-long-y.c bpf-success-v.c bpf-v.c \
+	brk.c btrfs.c caps.c caps-abbrev.c check_sigblock.c \
+	check_sigign.c chmod.c chown.c chown32.c chroot.c \
+	clock_adjtime.c clock_nanosleep.c clock_xettime.c \
+	clone-flags.c clone3.c clone3-Xabbrev.c clone3-Xraw.c \
+	clone3-Xverbose.c clone3-success.c clone3-success-Xabbrev.c \
+	clone3-success-Xraw.c clone3-success-Xverbose.c clone_parent.c \
+	clone_parent--quiet-exit.c clone_parent-q.c clone_parent-qq.c \
+	clone_ptrace.c clone_ptrace--quiet-attach.c \
+	clone_ptrace--quiet-exit.c clone_ptrace-q.c clone_ptrace-qq.c \
+	close_range.c close_range-P.c close_range-y.c close_range-yy.c \
 	copy_file_range.c count-f.c creat.c delay.c delete_module.c \
-	dev-yy.c dup.c dup2.c dup3.c epoll_create.c epoll_create1.c \
-	epoll_ctl.c epoll_pwait.c epoll_wait.c erestartsys.c eventfd.c \
-	execve.c execve-v.c execveat.c execveat-v.c faccessat.c \
-	fadvise64.c fadvise64_64.c fallocate.c fanotify_init.c \
-	fanotify_mark.c fanotify_mark-Xabbrev.c fanotify_mark-Xraw.c \
+	dev--decode-fds-dev.c dev--decode-fds-path.c \
+	dev--decode-fds-socket.c dev-yy.c dup.c dup-P.c dup-y.c \
+	dup-yy.c dup2.c dup2-P.c dup2-y.c dup2-yy.c dup3.c dup3-P.c \
+	dup3-y.c dup3-yy.c epoll_create.c epoll_create1.c epoll_ctl.c \
+	epoll_pwait.c epoll_wait.c erestartsys.c eventfd.c execve.c \
+	execve-v.c execveat.c execveat-v.c faccessat.c faccessat-P.c \
+	faccessat-y.c faccessat-yy.c faccessat2.c faccessat2-P.c \
+	faccessat2-y.c faccessat2-yy.c fadvise64.c fadvise64_64.c \
+	fallocate.c fanotify_init.c fanotify_mark.c \
+	fanotify_mark-Xabbrev.c fanotify_mark-Xraw.c \
 	fanotify_mark-Xverbose.c fchdir.c fchmod.c fchmodat.c fchown.c \
-	fchown32.c fchownat.c fcntl.c fcntl64.c fdatasync.c fflush.c \
+	fchown32.c fchownat.c fcntl.c fcntl--pidns-translation.c \
+	fcntl64.c fcntl64--pidns-translation.c fdatasync.c fflush.c \
 	file_handle.c file_ioctl.c filter-unavailable.c \
 	filter_seccomp-flag.c filter_seccomp-perf.c finit_module.c \
-	flock.c fork-f.c fsconfig.c fsconfig-P.c fsmount.c fsopen.c \
-	fspick.c fspick-P.c fstat.c fstat-Xabbrev.c fstat-Xraw.c \
-	fstat-Xverbose.c fstat64.c fstat64-Xabbrev.c fstat64-Xraw.c \
-	fstat64-Xverbose.c fstatat64.c fstatfs.c fstatfs64.c fsync.c \
-	fsync-y.c ftruncate.c ftruncate64.c futex.c futimesat.c \
-	get_mempolicy.c getcpu.c getcwd.c getdents.c getdents64.c \
-	getegid.c getegid32.c geteuid.c geteuid32.c getgid.c \
-	getgid32.c getgroups.c getgroups32.c getpeername.c getpgrp.c \
-	getpid.c getppid.c getrandom.c getresgid.c getresgid32.c \
-	getresuid.c getresuid32.c getrlimit.c getrusage.c getsid.c \
-	getsockname.c gettid.c getuid.c getuid32.c getxxid.c \
-	group_req.c inet-cmsg.c init_module.c inject-nf.c inotify.c \
-	inotify_init.c inotify_init-y.c inotify_init1.c \
-	inotify_init1-y.c int_0x80.c io_uring_enter.c \
-	io_uring_register.c io_uring_setup.c ioctl.c ioctl_block.c \
-	ioctl_dm.c ioctl_dm-v.c ioctl_evdev.c ioctl_evdev-Xabbrev.c \
+	flock.c fork--pidns-translation.c fork-f.c fsconfig.c \
+	fsconfig-P.c fsmount.c fsopen.c fspick.c fspick-P.c fstat.c \
+	fstat-Xabbrev.c fstat-Xraw.c fstat-Xverbose.c fstat64.c \
+	fstat64-Xabbrev.c fstat64-Xraw.c fstat64-Xverbose.c \
+	fstatat64.c fstatfs.c fstatfs64.c fsync.c fsync-y.c \
+	ftruncate.c ftruncate64.c futex.c futimesat.c get_mempolicy.c \
+	get_process_reaper.c getcpu.c getcwd.c getdents.c getdents-v.c \
+	getdents64.c getdents64-v.c getegid.c getegid32.c geteuid.c \
+	geteuid32.c getgid.c getgid32.c getgroups.c getgroups32.c \
+	getpeername.c getpgrp.c getpgrp--pidns-translation.c getpid.c \
+	getpid--pidns-translation.c getppid.c getrandom.c getresgid.c \
+	getresgid32.c getresuid.c getresuid32.c getrlimit.c \
+	getrusage.c getsid.c getsid--pidns-translation.c getsockname.c \
+	gettid.c gettid--pidns-translation.c getuid.c getuid32.c \
+	getxgid.c getxpid.c getxuid.c group_req.c inet-cmsg.c \
+	init_module.c inject-nf.c inotify.c inotify_init.c \
+	inotify_init-y.c inotify_init1.c inotify_init1-y.c int_0x80.c \
+	io_uring_enter.c io_uring_register.c io_uring_setup.c ioctl.c \
+	ioctl_block.c ioctl_block--pidns-translation.c ioctl_dm.c \
+	ioctl_dm-v.c ioctl_evdev.c ioctl_evdev-Xabbrev.c \
 	ioctl_evdev-Xraw.c ioctl_evdev-Xverbose.c \
 	ioctl_evdev-success.c ioctl_evdev-success-Xabbrev.c \
 	ioctl_evdev-success-Xraw.c ioctl_evdev-success-Xverbose.c \
 	ioctl_evdev-success-v.c ioctl_evdev-success-v-Xabbrev.c \
 	ioctl_evdev-success-v-Xraw.c ioctl_evdev-success-v-Xverbose.c \
 	ioctl_evdev-v.c ioctl_evdev-v-Xabbrev.c ioctl_evdev-v-Xraw.c \
-	ioctl_evdev-v-Xverbose.c ioctl_inotify.c ioctl_kvm_run.c \
+	ioctl_evdev-v-Xverbose.c ioctl_hdio.c ioctl_hdio-Xabbrev.c \
+	ioctl_hdio-Xraw.c ioctl_hdio-Xverbose.c ioctl_hdio-success.c \
+	ioctl_hdio-success-Xabbrev.c ioctl_hdio-success-Xraw.c \
+	ioctl_hdio-success-Xverbose.c ioctl_hdio-success-v.c \
+	ioctl_hdio-success-v-Xabbrev.c ioctl_hdio-success-v-Xraw.c \
+	ioctl_hdio-success-v-Xverbose.c ioctl_hdio-v.c \
+	ioctl_hdio-v-Xabbrev.c ioctl_hdio-v-Xraw.c \
+	ioctl_hdio-v-Xverbose.c ioctl_inotify.c ioctl_kvm_run.c \
 	ioctl_kvm_run-v.c ioctl_kvm_run_auxstr_vcpu.c ioctl_loop.c \
 	ioctl_loop-nv.c ioctl_loop-v.c ioctl_mtd.c ioctl_nbd.c \
 	ioctl_nsfs.c ioctl_perf.c ioctl_perf-success.c ioctl_ptp.c \
 	ioctl_random.c ioctl_rtc.c ioctl_rtc-v.c ioctl_scsi.c \
 	ioctl_sg_io_v3.c ioctl_sg_io_v4.c ioctl_sock_gifconf.c \
-	ioctl_uffdio.c ioctl_v4l2.c ioctl_watchdog.c ioperm.c iopl.c \
-	ioprio.c ioprio-Xabbrev.c ioprio-Xraw.c ioprio-Xverbose.c \
-	ip_mreq.c ipc.c ipc_msg.c ipc_msg-Xabbrev.c ipc_msg-Xraw.c \
-	ipc_msg-Xverbose.c ipc_msgbuf.c ipc_msgbuf-Xabbrev.c \
-	ipc_msgbuf-Xraw.c ipc_msgbuf-Xverbose.c ipc_sem.c \
-	ipc_sem-Xabbrev.c ipc_sem-Xraw.c ipc_sem-Xverbose.c ipc_shm.c \
-	ipc_shm-Xabbrev.c ipc_shm-Xraw.c ipc_shm-Xverbose.c \
-	is_linux_mips_n64.c kcmp.c kcmp-y.c kern_features.c \
+	ioctl_tee.c ioctl_uffdio.c ioctl_v4l2.c ioctl_v4l2-Xabbrev.c \
+	ioctl_v4l2-Xraw.c ioctl_v4l2-Xverbose.c ioctl_v4l2-success.c \
+	ioctl_v4l2-success-Xabbrev.c ioctl_v4l2-success-Xraw.c \
+	ioctl_v4l2-success-Xverbose.c ioctl_v4l2-success-v.c \
+	ioctl_v4l2-success-v-Xabbrev.c ioctl_v4l2-success-v-Xraw.c \
+	ioctl_v4l2-success-v-Xverbose.c ioctl_v4l2-v.c \
+	ioctl_v4l2-v-Xabbrev.c ioctl_v4l2-v-Xraw.c \
+	ioctl_v4l2-v-Xverbose.c ioctl_watchdog.c ioperm.c iopl.c \
+	ioprio.c ioprio--pidns-translation.c ioprio-Xabbrev.c \
+	ioprio-Xraw.c ioprio-Xverbose.c ip_mreq.c ipc.c ipc_msg.c \
+	ipc_msg-Xabbrev.c ipc_msg-Xraw.c ipc_msg-Xverbose.c \
+	ipc_msgbuf.c ipc_msgbuf-Xabbrev.c ipc_msgbuf-Xraw.c \
+	ipc_msgbuf-Xverbose.c ipc_sem.c ipc_sem-Xabbrev.c \
+	ipc_sem-Xraw.c ipc_sem-Xverbose.c ipc_shm.c ipc_shm-Xabbrev.c \
+	ipc_shm-Xraw.c ipc_shm-Xverbose.c is_linux_mips_n64.c kcmp.c \
+	kcmp-y.c kcmp-y--pidns-translation.c kern_features.c \
 	kernel_version.c kernel_version-Xabbrev.c \
 	kernel_version-Xraw.c kernel_version-Xverbose.c \
 	kexec_file_load.c kexec_load.c keyctl.c keyctl-Xabbrev.c \
-	keyctl-Xraw.c keyctl-Xverbose.c kill.c kill_child.c ksysent.c \
-	lchown.c lchown32.c link.c linkat.c list_sigaction_signum.c \
-	llseek.c localtime.c lookup_dcookie.c looping_threads.c \
-	lseek.c lstat.c lstat64.c madvise.c maybe_switch_current_tcp.c \
-	mbind.c mbind-Xabbrev.c mbind-Xraw.c mbind-Xverbose.c \
-	membarrier.c memfd_create.c memfd_create-Xabbrev.c \
-	memfd_create-Xraw.c memfd_create-Xverbose.c migrate_pages.c \
-	mincore.c mkdir.c mkdirat.c mknod.c mknodat.c mlock.c mlock2.c \
-	mlockall.c mmap.c mmap-Xabbrev.c mmap-Xraw.c mmap-Xverbose.c \
-	mmap64.c mmap64-Xabbrev.c mmap64-Xraw.c mmap64-Xverbose.c \
-	mmsg.c mmsg-silent.c mmsg_name.c mmsg_name-v.c modify_ldt.c \
-	mount.c mount-Xabbrev.c mount-Xraw.c mount-Xverbose.c \
-	move_mount.c move_mount-P.c move_pages.c move_pages-Xabbrev.c \
-	move_pages-Xraw.c move_pages-Xverbose.c mq.c mq_sendrecv.c \
-	mq_sendrecv-read.c mq_sendrecv-write.c msg_control.c \
-	msg_control-v.c msg_name.c munlockall.c nanosleep.c \
-	net-accept-connect.c net-icmp_filter.c net-packet_mreq.c \
-	net-packet_mreq-Xabbrev.c net-packet_mreq-Xraw.c \
-	net-packet_mreq-Xverbose.c net-sockaddr.c net-tpacket_req.c \
-	net-tpacket_stats.c net-tpacket_stats-success.c net-y-unix.c \
-	net-yy-inet.c net-yy-inet6.c net-yy-netlink.c net-yy-unix.c \
-	netlink_audit.c netlink_crypto.c netlink_generic.c \
-	netlink_inet_diag.c netlink_kobject_uevent.c \
+	keyctl-Xraw.c keyctl-Xverbose.c kill.c \
+	kill--pidns-translation.c kill_child.c ksysent.c lchown.c \
+	lchown32.c link.c linkat.c list_sigaction_signum.c llseek.c \
+	localtime.c lookup_dcookie.c looping_threads.c lseek.c lstat.c \
+	lstat64.c madvise.c maybe_switch_current_tcp.c \
+	maybe_switch_current_tcp--quiet-thread-execve.c mbind.c \
+	mbind-Xabbrev.c mbind-Xraw.c mbind-Xverbose.c membarrier.c \
+	memfd_create.c memfd_create-Xabbrev.c memfd_create-Xraw.c \
+	memfd_create-Xverbose.c migrate_pages.c \
+	migrate_pages--pidns-translation.c mincore.c mkdir.c mkdirat.c \
+	mknod.c mknodat.c mlock.c mlock2.c mlockall.c mmap.c \
+	mmap-Xabbrev.c mmap-Xraw.c mmap-Xverbose.c mmap64.c \
+	mmap64-Xabbrev.c mmap64-Xraw.c mmap64-Xverbose.c mmsg.c \
+	mmsg-silent.c mmsg_name.c mmsg_name-v.c modify_ldt.c mount.c \
+	mount-Xabbrev.c mount-Xraw.c mount-Xverbose.c move_mount.c \
+	move_mount-P.c move_pages.c move_pages--pidns-translation.c \
+	move_pages-Xabbrev.c move_pages-Xraw.c move_pages-Xverbose.c \
+	mq.c mq_sendrecv.c mq_sendrecv-read.c mq_sendrecv-write.c \
+	msg_control.c msg_control-v.c msg_name.c munlockall.c \
+	nanosleep.c net--decode-fds-dev-netlink.c \
+	net--decode-fds-none-netlink.c net--decode-fds-path-netlink.c \
+	net--decode-fds-socket-netlink.c net-accept-connect.c \
+	net-icmp_filter.c net-packet_mreq.c net-packet_mreq-Xabbrev.c \
+	net-packet_mreq-Xraw.c net-packet_mreq-Xverbose.c \
+	net-sockaddr.c net-sockaddr--pidns-translation.c \
+	net-tpacket_req.c net-tpacket_stats.c \
+	net-tpacket_stats-success.c net-y-unix.c net-yy-inet.c \
+	net-yy-inet6.c net-yy-netlink.c net-yy-unix.c netlink_audit.c \
+	netlink_audit--pidns-translation.c netlink_crypto.c \
+	netlink_generic.c netlink_inet_diag.c netlink_kobject_uevent.c \
 	netlink_netfilter.c netlink_netlink_diag.c netlink_protocol.c \
 	netlink_route.c netlink_selinux.c netlink_sock_diag.c \
 	netlink_unix_diag.c netlink_xfrm.c newfstatat.c \
@@ -3757,56 +4704,71 @@ SOURCES = $(libtests_a_SOURCES) _newsele
 	nlattr_fib_rule_hdr.c nlattr_ifaddrlblmsg.c nlattr_ifaddrmsg.c \
 	nlattr_ifinfomsg.c nlattr_ifla_af_spec.c nlattr_ifla_brport.c \
 	nlattr_ifla_linkinfo.c nlattr_ifla_port.c nlattr_ifla_xdp.c \
-	nlattr_inet_diag_msg.c nlattr_inet_diag_req_compat.c \
-	nlattr_inet_diag_req_v2.c nlattr_mdba_mdb_entry.c \
-	nlattr_mdba_router_port.c nlattr_ndmsg.c nlattr_ndtmsg.c \
-	nlattr_netconfmsg.c nlattr_netlink_diag_msg.c \
-	nlattr_nlmsgerr.c nlattr_packet_diag_msg.c nlattr_rtgenmsg.c \
-	nlattr_rtmsg.c nlattr_smc_diag_msg.c nlattr_tc_stats.c \
-	nlattr_tca_stab.c nlattr_tcamsg.c nlattr_tcmsg.c \
-	nlattr_unix_diag_msg.c nsyscalls.c nsyscalls-d.c old_mmap.c \
-	old_mmap-P.c old_mmap-Xabbrev.c old_mmap-Xraw.c \
-	old_mmap-Xverbose.c old_mmap-v-none.c oldfstat.c oldlstat.c \
-	oldselect.c oldselect-P.c oldselect-efault.c \
-	oldselect-efault-P.c oldstat.c open.c open_tree.c \
-	open_tree-P.c openat.c orphaned_process_group.c osf_utimes.c \
-	pause.c pc.c perf_event_open.c perf_event_open_nonverbose.c \
+	nlattr_ifla_xdp-y.c nlattr_inet_diag_msg.c \
+	nlattr_inet_diag_req_compat.c nlattr_inet_diag_req_v2.c \
+	nlattr_mdba_mdb_entry.c nlattr_mdba_router_port.c \
+	nlattr_ndmsg.c nlattr_ndtmsg.c nlattr_netconfmsg.c \
+	nlattr_netlink_diag_msg.c nlattr_nlmsgerr.c \
+	nlattr_packet_diag_msg.c nlattr_rtgenmsg.c nlattr_rtmsg.c \
+	nlattr_smc_diag_msg.c nlattr_tc_stats.c nlattr_tca_stab.c \
+	nlattr_tcamsg.c nlattr_tcmsg.c nlattr_unix_diag_msg.c \
+	nsyscalls.c nsyscalls-d.c old_mmap.c old_mmap-P.c \
+	old_mmap-Xabbrev.c old_mmap-Xraw.c old_mmap-Xverbose.c \
+	old_mmap-v-none.c oldfstat.c oldlstat.c oldselect.c \
+	oldselect-P.c oldselect-efault.c oldselect-efault-P.c \
+	oldstat.c open.c open_tree.c open_tree-P.c openat.c openat2.c \
+	openat2-Xabbrev.c openat2-Xraw.c openat2-Xverbose.c \
+	openat2-v.c openat2-v-y.c openat2-v-y-Xabbrev.c \
+	openat2-v-y-Xraw.c openat2-v-y-Xverbose.c openat2-y.c \
+	orphaned_process_group.c osf_utimes.c pause.c pc.c \
+	perf_event_open.c perf_event_open_nonverbose.c \
 	perf_event_open_unabbrev.c personality.c personality-Xabbrev.c \
-	personality-Xraw.c personality-Xverbose.c pidfd_open.c \
-	pidfd_open-P.c pidfd_open-y.c pidfd_send_signal.c pipe.c \
-	pipe2.c pkey_alloc.c pkey_free.c pkey_mprotect.c poll.c \
-	poll-P.c ppoll.c ppoll-P.c ppoll-v.c prctl-arg2-intptr.c \
-	prctl-dumpable.c prctl-name.c prctl-no-args.c \
-	prctl-pdeathsig.c prctl-seccomp-filter-v.c \
+	personality-Xraw.c personality-Xverbose.c pidfd_getfd.c \
+	pidfd_getfd-y.c pidfd_getfd-yy.c pidfd_open.c \
+	pidfd_open--decode-fd-path.c pidfd_open--decode-fd-pidfd.c \
+	pidfd_open--decode-fd-socket.c pidfd_open--pidns-translation.c \
+	pidfd_open-P.c pidfd_open-y.c pidfd_open-yy.c \
+	pidfd_send_signal.c pidfd_send_signal--pidns-translation.c \
+	pidns-cache.c pipe.c pipe2.c pkey_alloc.c pkey_free.c \
+	pkey_mprotect.c poll.c poll-P.c ppoll.c ppoll-P.c ppoll-v.c \
+	prctl-arg2-intptr.c prctl-dumpable.c prctl-name.c \
+	prctl-no-args.c prctl-pdeathsig.c prctl-seccomp-filter-v.c \
 	prctl-seccomp-strict.c prctl-securebits.c prctl-spec-inject.c \
 	prctl-tid_address.c prctl-tsc.c pread64-pwrite64.c preadv.c \
 	preadv-pwritev.c preadv2-pwritev2.c print_maxfd.c \
-	printpath-umovestr.c printpath-umovestr-peekdata.c \
-	printpath-umovestr-undumpable.c printsignal-Xabbrev.c \
-	printsignal-Xraw.c printsignal-Xverbose.c printstr.c \
-	printstrn-umoven.c printstrn-umoven-peekdata.c \
-	printstrn-umoven-undumpable.c prlimit64.c process_vm_readv.c \
-	process_vm_writev.c pselect6.c ptrace.c ptrace_syscall_info.c \
-	pwritev.c qual_fault.c qual_inject-error-signal.c \
-	qual_inject-retval.c qual_inject-signal.c qual_signal.c \
-	quotactl.c quotactl-Xabbrev.c quotactl-Xraw.c \
-	quotactl-Xverbose.c quotactl-success.c quotactl-success-v.c \
-	quotactl-v.c quotactl-xfs.c quotactl-xfs-success.c \
-	quotactl-xfs-success-v.c quotactl-xfs-v.c read-write.c \
-	readahead.c readdir.c readlink.c readlinkat.c readv.c reboot.c \
-	recv-MSG_TRUNC.c recvfrom.c recvfrom-MSG_TRUNC.c \
-	recvmmsg-timeout.c recvmsg.c redirect-fds.c remap_file_pages.c \
-	remap_file_pages-Xabbrev.c remap_file_pages-Xraw.c \
-	remap_file_pages-Xverbose.c rename.c renameat.c renameat2.c \
-	request_key.c restart_syscall.c riscv_flush_icache.c rmdir.c \
-	rt_sigaction.c rt_sigpending.c rt_sigprocmask.c \
-	rt_sigqueueinfo.c rt_sigreturn.c rt_sigsuspend.c \
-	rt_sigtimedwait.c rt_tgsigqueueinfo.c run_expect_termsig.c \
+	print_ppid_tracerpid.c printpath-umovestr.c \
+	printpath-umovestr-peekdata.c printpath-umovestr-undumpable.c \
+	printsignal-Xabbrev.c printsignal-Xraw.c \
+	printsignal-Xverbose.c printstr.c printstrn-umoven.c \
+	printstrn-umoven-peekdata.c printstrn-umoven-undumpable.c \
+	prlimit64.c prlimit64--pidns-translation.c process_vm_readv.c \
+	process_vm_readv--pidns-translation.c process_vm_writev.c \
+	process_vm_writev--pidns-translation.c pselect6.c ptrace.c \
+	ptrace_syscall_info.c pwritev.c qual_fault.c \
+	qual_inject-error-signal.c qual_inject-retval.c \
+	qual_inject-signal.c qual_signal.c quotactl.c \
+	quotactl-Xabbrev.c quotactl-Xraw.c quotactl-Xverbose.c \
+	quotactl-success.c quotactl-success-v.c quotactl-v.c \
+	quotactl-xfs.c quotactl-xfs-success.c quotactl-xfs-success-v.c \
+	quotactl-xfs-v.c read-write.c readahead.c readdir.c readlink.c \
+	readlinkat.c readv.c reboot.c recv-MSG_TRUNC.c recvfrom.c \
+	recvfrom-MSG_TRUNC.c recvmmsg-timeout.c recvmsg.c \
+	redirect-fds.c remap_file_pages.c remap_file_pages-Xabbrev.c \
+	remap_file_pages-Xraw.c remap_file_pages-Xverbose.c rename.c \
+	renameat.c renameat2.c request_key.c restart_syscall.c \
+	riscv_flush_icache.c rmdir.c rt_sigaction.c rt_sigpending.c \
+	rt_sigprocmask.c rt_sigqueueinfo.c \
+	rt_sigqueueinfo--pidns-translation.c rt_sigreturn.c \
+	rt_sigsuspend.c rt_sigtimedwait.c rt_tgsigqueueinfo.c \
+	rt_tgsigqueueinfo--pidns-translation.c run_expect_termsig.c \
 	s390_guarded_storage.c s390_guarded_storage-v.c \
 	s390_pci_mmio_read_write.c s390_runtime_instr.c s390_sthyi.c \
 	s390_sthyi-v.c sched_get_priority_mxx.c \
-	sched_rr_get_interval.c sched_xetaffinity.c sched_xetattr.c \
-	sched_xetparam.c sched_xetscheduler.c sched_yield.c \
+	sched_rr_get_interval.c sched_xetaffinity.c \
+	sched_xetaffinity--pidns-translation.c sched_xetattr.c \
+	sched_xetattr--pidns-translation.c sched_xetparam.c \
+	sched_xetparam--pidns-translation.c sched_xetscheduler.c \
+	sched_xetscheduler--pidns-translation.c sched_yield.c \
 	scm_rights.c seccomp-filter.c seccomp-filter-v.c \
 	seccomp-strict.c seccomp_get_action_avail.c select.c \
 	select-P.c semop.c semop-indirect.c semtimedop.c sendfile.c \
@@ -3815,38 +4777,50 @@ SOURCES = $(libtests_a_SOURCES) _newsele
 	set_ptracer_any.c set_sigblock.c set_sigign.c setdomainname.c \
 	setfsgid.c setfsgid32.c setfsuid.c setfsuid32.c setgid.c \
 	setgid32.c setgroups.c setgroups32.c sethostname.c setns.c \
-	setregid.c setregid32.c setresgid.c setresgid32.c setresuid.c \
-	setresuid32.c setreuid.c setreuid32.c setrlimit.c \
-	setrlimit-Xabbrev.c setrlimit-Xraw.c setrlimit-Xverbose.c \
-	setuid.c setuid32.c shmxt.c shutdown.c sigaction.c \
-	sigaltstack.c siginfo.c signal.c signal_receive.c signalfd4.c \
-	sigpending.c sigprocmask.c sigreturn.c sigsuspend.c sleep.c \
-	so_error.c so_linger.c so_peercred.c so_peercred-Xabbrev.c \
-	so_peercred-Xraw.c so_peercred-Xverbose.c sock_filter-v.c \
-	sock_filter-v-Xabbrev.c sock_filter-v-Xraw.c \
-	sock_filter-v-Xverbose.c sockaddr_xlat-Xabbrev.c \
-	sockaddr_xlat-Xraw.c sockaddr_xlat-Xverbose.c socketcall.c \
-	sockopt-sol_netlink.c sockopt-timestamp.c splice.c \
-	$(stack_fcall_SOURCES) $(stack_fcall_attach_SOURCES) \
-	$(stack_fcall_mangled_SOURCES) stat.c stat64.c statfs.c \
-	statfs64.c status-all.c status-failed.c status-none.c \
-	status-none-f.c status-none-threads.c status-successful.c \
-	status-unfinished.c status-unfinished-threads.c statx.c swap.c \
-	sxetmask.c symlink.c symlinkat.c sync.c sync_file_range.c \
-	sync_file_range2.c sysinfo.c syslog.c syslog-success.c tee.c \
-	threads-execve.c time.c timer_create.c timer_xettime.c \
-	timerfd_xettime.c times.c times-fail.c tracer_ppid_pgid_sid.c \
-	truncate.c truncate64.c ugetrlimit.c uio.c umask.c umount.c \
-	umount2.c umoven-illptr.c umovestr.c umovestr-illptr.c \
-	umovestr2.c umovestr3.c umovestr_cached.c uname.c \
-	unblock_reset_raise.c unix-pair-send-recv.c \
+	setpgrp-exec.c setregid.c setregid32.c setresgid.c \
+	setresgid32.c setresuid.c setresuid32.c setreuid.c \
+	setreuid32.c setrlimit.c setrlimit-Xabbrev.c setrlimit-Xraw.c \
+	setrlimit-Xverbose.c setuid.c setuid32.c shmxt.c shutdown.c \
+	sigaction.c sigaltstack.c siginfo.c signal.c signal_receive.c \
+	signal_receive--pidns-translation.c signalfd4.c sigpending.c \
+	sigprocmask.c sigreturn.c sigsuspend.c sleep.c so_error.c \
+	so_linger.c so_peercred.c so_peercred--pidns-translation.c \
+	so_peercred-Xabbrev.c so_peercred-Xraw.c \
+	so_peercred-Xverbose.c sock_filter-v.c sock_filter-v-Xabbrev.c \
+	sock_filter-v-Xraw.c sock_filter-v-Xverbose.c \
+	sockaddr_xlat-Xabbrev.c sockaddr_xlat-Xraw.c \
+	sockaddr_xlat-Xverbose.c socketcall.c sockopt-sol_netlink.c \
+	sockopt-timestamp.c splice.c $(stack_fcall_SOURCES) \
+	$(stack_fcall_attach_SOURCES) $(stack_fcall_mangled_SOURCES) \
+	stat.c stat64.c statfs.c statfs64.c status-all.c \
+	status-failed.c status-failed-long.c status-failed-status.c \
+	status-none.c status-none-f.c status-none-threads.c \
+	status-successful.c status-successful-long.c \
+	status-successful-status.c status-unfinished.c \
+	status-unfinished-threads.c statx.c strace--strings-in-hex.c \
+	strace--strings-in-hex-all.c \
+	strace--strings-in-hex-non-ascii.c strace-n.c strace-x.c \
+	strace-xx.c swap.c sxetmask.c symlink.c symlinkat.c sync.c \
+	sync_file_range.c sync_file_range2.c sysinfo.c syslog.c \
+	syslog-success.c tee.c tgkill.c tgkill--pidns-translation.c \
+	threads-execve.c threads-execve--quiet-thread-execve.c \
+	threads-execve-q.c threads-execve-qq.c threads-execve-qqq.c \
+	time.c timer_create.c timer_xettime.c timerfd_xettime.c \
+	times.c times-fail.c tkill.c tkill--pidns-translation.c \
+	tracer_ppid_pgid_sid.c $(trie_test_SOURCES) truncate.c \
+	truncate64.c ugetrlimit.c uio.c umask.c umount.c umount2.c \
+	umoven-illptr.c umovestr.c umovestr-illptr.c umovestr2.c \
+	umovestr3.c umovestr_cached.c umovestr_cached_adjacent.c \
+	uname.c unblock_reset_raise.c unix-pair-send-recv.c \
 	unix-pair-sendto-recvfrom.c unlink.c unlinkat.c unshare.c \
 	userfaultfd.c ustat.c utime.c utimensat.c utimensat-Xabbrev.c \
 	utimensat-Xraw.c utimensat-Xverbose.c utimes.c vfork-f.c \
 	vhangup.c vmsplice.c wait4.c wait4-v.c waitid.c waitid-v.c \
 	waitpid.c xattr.c xattr-strings.c xet_robust_list.c \
-	xet_thread_area_x86.c xetitimer.c xetpgid.c xetpriority.c \
-	xettimeofday.c zeroargc.c
+	xet_robust_list--pidns-translation.c xet_thread_area_x86.c \
+	xetitimer.c xetpgid.c xetpgid--pidns-translation.c \
+	xetpriority.c xetpriority--pidns-translation.c xettimeofday.c \
+	zeroargc.c
 DIST_SOURCES = $(libtests_a_SOURCES) _newselect.c _newselect-P.c \
 	accept.c accept4.c access.c acct.c add_key.c adjtimex.c aio.c \
 	aio_pgetevents.c alarm.c answer.c attach-f-p.c \
@@ -3854,85 +4828,121 @@ DIST_SOURCES = $(libtests_a_SOURCES) _ne
 	block_reset_raise_run.c block_reset_run.c bpf.c \
 	bpf-obj_get_info_by_fd.c bpf-obj_get_info_by_fd-prog.c \
 	bpf-obj_get_info_by_fd-prog-v.c bpf-obj_get_info_by_fd-v.c \
-	bpf-success.c bpf-success-v.c bpf-v.c brk.c btrfs.c caps.c \
-	caps-abbrev.c check_sigblock.c check_sigign.c chmod.c chown.c \
-	chown32.c chroot.c clock_adjtime.c clock_nanosleep.c \
-	clock_xettime.c clone-flags.c clone3.c clone3-Xabbrev.c \
-	clone3-Xraw.c clone3-Xverbose.c clone3-success.c \
-	clone3-success-Xabbrev.c clone3-success-Xraw.c \
-	clone3-success-Xverbose.c clone_parent.c clone_ptrace.c \
+	bpf-success.c bpf-success-long-y.c bpf-success-v.c bpf-v.c \
+	brk.c btrfs.c caps.c caps-abbrev.c check_sigblock.c \
+	check_sigign.c chmod.c chown.c chown32.c chroot.c \
+	clock_adjtime.c clock_nanosleep.c clock_xettime.c \
+	clone-flags.c clone3.c clone3-Xabbrev.c clone3-Xraw.c \
+	clone3-Xverbose.c clone3-success.c clone3-success-Xabbrev.c \
+	clone3-success-Xraw.c clone3-success-Xverbose.c clone_parent.c \
+	clone_parent--quiet-exit.c clone_parent-q.c clone_parent-qq.c \
+	clone_ptrace.c clone_ptrace--quiet-attach.c \
+	clone_ptrace--quiet-exit.c clone_ptrace-q.c clone_ptrace-qq.c \
+	close_range.c close_range-P.c close_range-y.c close_range-yy.c \
 	copy_file_range.c count-f.c creat.c delay.c delete_module.c \
-	dev-yy.c dup.c dup2.c dup3.c epoll_create.c epoll_create1.c \
-	epoll_ctl.c epoll_pwait.c epoll_wait.c erestartsys.c eventfd.c \
-	execve.c execve-v.c execveat.c execveat-v.c faccessat.c \
-	fadvise64.c fadvise64_64.c fallocate.c fanotify_init.c \
-	fanotify_mark.c fanotify_mark-Xabbrev.c fanotify_mark-Xraw.c \
+	dev--decode-fds-dev.c dev--decode-fds-path.c \
+	dev--decode-fds-socket.c dev-yy.c dup.c dup-P.c dup-y.c \
+	dup-yy.c dup2.c dup2-P.c dup2-y.c dup2-yy.c dup3.c dup3-P.c \
+	dup3-y.c dup3-yy.c epoll_create.c epoll_create1.c epoll_ctl.c \
+	epoll_pwait.c epoll_wait.c erestartsys.c eventfd.c execve.c \
+	execve-v.c execveat.c execveat-v.c faccessat.c faccessat-P.c \
+	faccessat-y.c faccessat-yy.c faccessat2.c faccessat2-P.c \
+	faccessat2-y.c faccessat2-yy.c fadvise64.c fadvise64_64.c \
+	fallocate.c fanotify_init.c fanotify_mark.c \
+	fanotify_mark-Xabbrev.c fanotify_mark-Xraw.c \
 	fanotify_mark-Xverbose.c fchdir.c fchmod.c fchmodat.c fchown.c \
-	fchown32.c fchownat.c fcntl.c fcntl64.c fdatasync.c fflush.c \
+	fchown32.c fchownat.c fcntl.c fcntl--pidns-translation.c \
+	fcntl64.c fcntl64--pidns-translation.c fdatasync.c fflush.c \
 	file_handle.c file_ioctl.c filter-unavailable.c \
 	filter_seccomp-flag.c filter_seccomp-perf.c finit_module.c \
-	flock.c fork-f.c fsconfig.c fsconfig-P.c fsmount.c fsopen.c \
-	fspick.c fspick-P.c fstat.c fstat-Xabbrev.c fstat-Xraw.c \
-	fstat-Xverbose.c fstat64.c fstat64-Xabbrev.c fstat64-Xraw.c \
-	fstat64-Xverbose.c fstatat64.c fstatfs.c fstatfs64.c fsync.c \
-	fsync-y.c ftruncate.c ftruncate64.c futex.c futimesat.c \
-	get_mempolicy.c getcpu.c getcwd.c getdents.c getdents64.c \
-	getegid.c getegid32.c geteuid.c geteuid32.c getgid.c \
-	getgid32.c getgroups.c getgroups32.c getpeername.c getpgrp.c \
-	getpid.c getppid.c getrandom.c getresgid.c getresgid32.c \
-	getresuid.c getresuid32.c getrlimit.c getrusage.c getsid.c \
-	getsockname.c gettid.c getuid.c getuid32.c getxxid.c \
-	group_req.c inet-cmsg.c init_module.c inject-nf.c inotify.c \
-	inotify_init.c inotify_init-y.c inotify_init1.c \
-	inotify_init1-y.c int_0x80.c io_uring_enter.c \
-	io_uring_register.c io_uring_setup.c ioctl.c ioctl_block.c \
-	ioctl_dm.c ioctl_dm-v.c ioctl_evdev.c ioctl_evdev-Xabbrev.c \
+	flock.c fork--pidns-translation.c fork-f.c fsconfig.c \
+	fsconfig-P.c fsmount.c fsopen.c fspick.c fspick-P.c fstat.c \
+	fstat-Xabbrev.c fstat-Xraw.c fstat-Xverbose.c fstat64.c \
+	fstat64-Xabbrev.c fstat64-Xraw.c fstat64-Xverbose.c \
+	fstatat64.c fstatfs.c fstatfs64.c fsync.c fsync-y.c \
+	ftruncate.c ftruncate64.c futex.c futimesat.c get_mempolicy.c \
+	get_process_reaper.c getcpu.c getcwd.c getdents.c getdents-v.c \
+	getdents64.c getdents64-v.c getegid.c getegid32.c geteuid.c \
+	geteuid32.c getgid.c getgid32.c getgroups.c getgroups32.c \
+	getpeername.c getpgrp.c getpgrp--pidns-translation.c getpid.c \
+	getpid--pidns-translation.c getppid.c getrandom.c getresgid.c \
+	getresgid32.c getresuid.c getresuid32.c getrlimit.c \
+	getrusage.c getsid.c getsid--pidns-translation.c getsockname.c \
+	gettid.c gettid--pidns-translation.c getuid.c getuid32.c \
+	getxgid.c getxpid.c getxuid.c group_req.c inet-cmsg.c \
+	init_module.c inject-nf.c inotify.c inotify_init.c \
+	inotify_init-y.c inotify_init1.c inotify_init1-y.c int_0x80.c \
+	io_uring_enter.c io_uring_register.c io_uring_setup.c ioctl.c \
+	ioctl_block.c ioctl_block--pidns-translation.c ioctl_dm.c \
+	ioctl_dm-v.c ioctl_evdev.c ioctl_evdev-Xabbrev.c \
 	ioctl_evdev-Xraw.c ioctl_evdev-Xverbose.c \
 	ioctl_evdev-success.c ioctl_evdev-success-Xabbrev.c \
 	ioctl_evdev-success-Xraw.c ioctl_evdev-success-Xverbose.c \
 	ioctl_evdev-success-v.c ioctl_evdev-success-v-Xabbrev.c \
 	ioctl_evdev-success-v-Xraw.c ioctl_evdev-success-v-Xverbose.c \
 	ioctl_evdev-v.c ioctl_evdev-v-Xabbrev.c ioctl_evdev-v-Xraw.c \
-	ioctl_evdev-v-Xverbose.c ioctl_inotify.c ioctl_kvm_run.c \
+	ioctl_evdev-v-Xverbose.c ioctl_hdio.c ioctl_hdio-Xabbrev.c \
+	ioctl_hdio-Xraw.c ioctl_hdio-Xverbose.c ioctl_hdio-success.c \
+	ioctl_hdio-success-Xabbrev.c ioctl_hdio-success-Xraw.c \
+	ioctl_hdio-success-Xverbose.c ioctl_hdio-success-v.c \
+	ioctl_hdio-success-v-Xabbrev.c ioctl_hdio-success-v-Xraw.c \
+	ioctl_hdio-success-v-Xverbose.c ioctl_hdio-v.c \
+	ioctl_hdio-v-Xabbrev.c ioctl_hdio-v-Xraw.c \
+	ioctl_hdio-v-Xverbose.c ioctl_inotify.c ioctl_kvm_run.c \
 	ioctl_kvm_run-v.c ioctl_kvm_run_auxstr_vcpu.c ioctl_loop.c \
 	ioctl_loop-nv.c ioctl_loop-v.c ioctl_mtd.c ioctl_nbd.c \
 	ioctl_nsfs.c ioctl_perf.c ioctl_perf-success.c ioctl_ptp.c \
 	ioctl_random.c ioctl_rtc.c ioctl_rtc-v.c ioctl_scsi.c \
 	ioctl_sg_io_v3.c ioctl_sg_io_v4.c ioctl_sock_gifconf.c \
-	ioctl_uffdio.c ioctl_v4l2.c ioctl_watchdog.c ioperm.c iopl.c \
-	ioprio.c ioprio-Xabbrev.c ioprio-Xraw.c ioprio-Xverbose.c \
-	ip_mreq.c ipc.c ipc_msg.c ipc_msg-Xabbrev.c ipc_msg-Xraw.c \
-	ipc_msg-Xverbose.c ipc_msgbuf.c ipc_msgbuf-Xabbrev.c \
-	ipc_msgbuf-Xraw.c ipc_msgbuf-Xverbose.c ipc_sem.c \
-	ipc_sem-Xabbrev.c ipc_sem-Xraw.c ipc_sem-Xverbose.c ipc_shm.c \
-	ipc_shm-Xabbrev.c ipc_shm-Xraw.c ipc_shm-Xverbose.c \
-	is_linux_mips_n64.c kcmp.c kcmp-y.c kern_features.c \
+	ioctl_tee.c ioctl_uffdio.c ioctl_v4l2.c ioctl_v4l2-Xabbrev.c \
+	ioctl_v4l2-Xraw.c ioctl_v4l2-Xverbose.c ioctl_v4l2-success.c \
+	ioctl_v4l2-success-Xabbrev.c ioctl_v4l2-success-Xraw.c \
+	ioctl_v4l2-success-Xverbose.c ioctl_v4l2-success-v.c \
+	ioctl_v4l2-success-v-Xabbrev.c ioctl_v4l2-success-v-Xraw.c \
+	ioctl_v4l2-success-v-Xverbose.c ioctl_v4l2-v.c \
+	ioctl_v4l2-v-Xabbrev.c ioctl_v4l2-v-Xraw.c \
+	ioctl_v4l2-v-Xverbose.c ioctl_watchdog.c ioperm.c iopl.c \
+	ioprio.c ioprio--pidns-translation.c ioprio-Xabbrev.c \
+	ioprio-Xraw.c ioprio-Xverbose.c ip_mreq.c ipc.c ipc_msg.c \
+	ipc_msg-Xabbrev.c ipc_msg-Xraw.c ipc_msg-Xverbose.c \
+	ipc_msgbuf.c ipc_msgbuf-Xabbrev.c ipc_msgbuf-Xraw.c \
+	ipc_msgbuf-Xverbose.c ipc_sem.c ipc_sem-Xabbrev.c \
+	ipc_sem-Xraw.c ipc_sem-Xverbose.c ipc_shm.c ipc_shm-Xabbrev.c \
+	ipc_shm-Xraw.c ipc_shm-Xverbose.c is_linux_mips_n64.c kcmp.c \
+	kcmp-y.c kcmp-y--pidns-translation.c kern_features.c \
 	kernel_version.c kernel_version-Xabbrev.c \
 	kernel_version-Xraw.c kernel_version-Xverbose.c \
 	kexec_file_load.c kexec_load.c keyctl.c keyctl-Xabbrev.c \
-	keyctl-Xraw.c keyctl-Xverbose.c kill.c kill_child.c ksysent.c \
-	lchown.c lchown32.c link.c linkat.c list_sigaction_signum.c \
-	llseek.c localtime.c lookup_dcookie.c looping_threads.c \
-	lseek.c lstat.c lstat64.c madvise.c maybe_switch_current_tcp.c \
-	mbind.c mbind-Xabbrev.c mbind-Xraw.c mbind-Xverbose.c \
-	membarrier.c memfd_create.c memfd_create-Xabbrev.c \
-	memfd_create-Xraw.c memfd_create-Xverbose.c migrate_pages.c \
-	mincore.c mkdir.c mkdirat.c mknod.c mknodat.c mlock.c mlock2.c \
-	mlockall.c mmap.c mmap-Xabbrev.c mmap-Xraw.c mmap-Xverbose.c \
-	mmap64.c mmap64-Xabbrev.c mmap64-Xraw.c mmap64-Xverbose.c \
-	mmsg.c mmsg-silent.c mmsg_name.c mmsg_name-v.c modify_ldt.c \
-	mount.c mount-Xabbrev.c mount-Xraw.c mount-Xverbose.c \
-	move_mount.c move_mount-P.c move_pages.c move_pages-Xabbrev.c \
-	move_pages-Xraw.c move_pages-Xverbose.c mq.c mq_sendrecv.c \
-	mq_sendrecv-read.c mq_sendrecv-write.c msg_control.c \
-	msg_control-v.c msg_name.c munlockall.c nanosleep.c \
-	net-accept-connect.c net-icmp_filter.c net-packet_mreq.c \
-	net-packet_mreq-Xabbrev.c net-packet_mreq-Xraw.c \
-	net-packet_mreq-Xverbose.c net-sockaddr.c net-tpacket_req.c \
-	net-tpacket_stats.c net-tpacket_stats-success.c net-y-unix.c \
-	net-yy-inet.c net-yy-inet6.c net-yy-netlink.c net-yy-unix.c \
-	netlink_audit.c netlink_crypto.c netlink_generic.c \
-	netlink_inet_diag.c netlink_kobject_uevent.c \
+	keyctl-Xraw.c keyctl-Xverbose.c kill.c \
+	kill--pidns-translation.c kill_child.c ksysent.c lchown.c \
+	lchown32.c link.c linkat.c list_sigaction_signum.c llseek.c \
+	localtime.c lookup_dcookie.c looping_threads.c lseek.c lstat.c \
+	lstat64.c madvise.c maybe_switch_current_tcp.c \
+	maybe_switch_current_tcp--quiet-thread-execve.c mbind.c \
+	mbind-Xabbrev.c mbind-Xraw.c mbind-Xverbose.c membarrier.c \
+	memfd_create.c memfd_create-Xabbrev.c memfd_create-Xraw.c \
+	memfd_create-Xverbose.c migrate_pages.c \
+	migrate_pages--pidns-translation.c mincore.c mkdir.c mkdirat.c \
+	mknod.c mknodat.c mlock.c mlock2.c mlockall.c mmap.c \
+	mmap-Xabbrev.c mmap-Xraw.c mmap-Xverbose.c mmap64.c \
+	mmap64-Xabbrev.c mmap64-Xraw.c mmap64-Xverbose.c mmsg.c \
+	mmsg-silent.c mmsg_name.c mmsg_name-v.c modify_ldt.c mount.c \
+	mount-Xabbrev.c mount-Xraw.c mount-Xverbose.c move_mount.c \
+	move_mount-P.c move_pages.c move_pages--pidns-translation.c \
+	move_pages-Xabbrev.c move_pages-Xraw.c move_pages-Xverbose.c \
+	mq.c mq_sendrecv.c mq_sendrecv-read.c mq_sendrecv-write.c \
+	msg_control.c msg_control-v.c msg_name.c munlockall.c \
+	nanosleep.c net--decode-fds-dev-netlink.c \
+	net--decode-fds-none-netlink.c net--decode-fds-path-netlink.c \
+	net--decode-fds-socket-netlink.c net-accept-connect.c \
+	net-icmp_filter.c net-packet_mreq.c net-packet_mreq-Xabbrev.c \
+	net-packet_mreq-Xraw.c net-packet_mreq-Xverbose.c \
+	net-sockaddr.c net-sockaddr--pidns-translation.c \
+	net-tpacket_req.c net-tpacket_stats.c \
+	net-tpacket_stats-success.c net-y-unix.c net-yy-inet.c \
+	net-yy-inet6.c net-yy-netlink.c net-yy-unix.c netlink_audit.c \
+	netlink_audit--pidns-translation.c netlink_crypto.c \
+	netlink_generic.c netlink_inet_diag.c netlink_kobject_uevent.c \
 	netlink_netfilter.c netlink_netlink_diag.c netlink_protocol.c \
 	netlink_route.c netlink_selinux.c netlink_sock_diag.c \
 	netlink_unix_diag.c netlink_xfrm.c newfstatat.c \
@@ -3944,56 +4954,71 @@ DIST_SOURCES = $(libtests_a_SOURCES) _ne
 	nlattr_fib_rule_hdr.c nlattr_ifaddrlblmsg.c nlattr_ifaddrmsg.c \
 	nlattr_ifinfomsg.c nlattr_ifla_af_spec.c nlattr_ifla_brport.c \
 	nlattr_ifla_linkinfo.c nlattr_ifla_port.c nlattr_ifla_xdp.c \
-	nlattr_inet_diag_msg.c nlattr_inet_diag_req_compat.c \
-	nlattr_inet_diag_req_v2.c nlattr_mdba_mdb_entry.c \
-	nlattr_mdba_router_port.c nlattr_ndmsg.c nlattr_ndtmsg.c \
-	nlattr_netconfmsg.c nlattr_netlink_diag_msg.c \
-	nlattr_nlmsgerr.c nlattr_packet_diag_msg.c nlattr_rtgenmsg.c \
-	nlattr_rtmsg.c nlattr_smc_diag_msg.c nlattr_tc_stats.c \
-	nlattr_tca_stab.c nlattr_tcamsg.c nlattr_tcmsg.c \
-	nlattr_unix_diag_msg.c nsyscalls.c nsyscalls-d.c old_mmap.c \
-	old_mmap-P.c old_mmap-Xabbrev.c old_mmap-Xraw.c \
-	old_mmap-Xverbose.c old_mmap-v-none.c oldfstat.c oldlstat.c \
-	oldselect.c oldselect-P.c oldselect-efault.c \
-	oldselect-efault-P.c oldstat.c open.c open_tree.c \
-	open_tree-P.c openat.c orphaned_process_group.c osf_utimes.c \
-	pause.c pc.c perf_event_open.c perf_event_open_nonverbose.c \
+	nlattr_ifla_xdp-y.c nlattr_inet_diag_msg.c \
+	nlattr_inet_diag_req_compat.c nlattr_inet_diag_req_v2.c \
+	nlattr_mdba_mdb_entry.c nlattr_mdba_router_port.c \
+	nlattr_ndmsg.c nlattr_ndtmsg.c nlattr_netconfmsg.c \
+	nlattr_netlink_diag_msg.c nlattr_nlmsgerr.c \
+	nlattr_packet_diag_msg.c nlattr_rtgenmsg.c nlattr_rtmsg.c \
+	nlattr_smc_diag_msg.c nlattr_tc_stats.c nlattr_tca_stab.c \
+	nlattr_tcamsg.c nlattr_tcmsg.c nlattr_unix_diag_msg.c \
+	nsyscalls.c nsyscalls-d.c old_mmap.c old_mmap-P.c \
+	old_mmap-Xabbrev.c old_mmap-Xraw.c old_mmap-Xverbose.c \
+	old_mmap-v-none.c oldfstat.c oldlstat.c oldselect.c \
+	oldselect-P.c oldselect-efault.c oldselect-efault-P.c \
+	oldstat.c open.c open_tree.c open_tree-P.c openat.c openat2.c \
+	openat2-Xabbrev.c openat2-Xraw.c openat2-Xverbose.c \
+	openat2-v.c openat2-v-y.c openat2-v-y-Xabbrev.c \
+	openat2-v-y-Xraw.c openat2-v-y-Xverbose.c openat2-y.c \
+	orphaned_process_group.c osf_utimes.c pause.c pc.c \
+	perf_event_open.c perf_event_open_nonverbose.c \
 	perf_event_open_unabbrev.c personality.c personality-Xabbrev.c \
-	personality-Xraw.c personality-Xverbose.c pidfd_open.c \
-	pidfd_open-P.c pidfd_open-y.c pidfd_send_signal.c pipe.c \
-	pipe2.c pkey_alloc.c pkey_free.c pkey_mprotect.c poll.c \
-	poll-P.c ppoll.c ppoll-P.c ppoll-v.c prctl-arg2-intptr.c \
-	prctl-dumpable.c prctl-name.c prctl-no-args.c \
-	prctl-pdeathsig.c prctl-seccomp-filter-v.c \
+	personality-Xraw.c personality-Xverbose.c pidfd_getfd.c \
+	pidfd_getfd-y.c pidfd_getfd-yy.c pidfd_open.c \
+	pidfd_open--decode-fd-path.c pidfd_open--decode-fd-pidfd.c \
+	pidfd_open--decode-fd-socket.c pidfd_open--pidns-translation.c \
+	pidfd_open-P.c pidfd_open-y.c pidfd_open-yy.c \
+	pidfd_send_signal.c pidfd_send_signal--pidns-translation.c \
+	pidns-cache.c pipe.c pipe2.c pkey_alloc.c pkey_free.c \
+	pkey_mprotect.c poll.c poll-P.c ppoll.c ppoll-P.c ppoll-v.c \
+	prctl-arg2-intptr.c prctl-dumpable.c prctl-name.c \
+	prctl-no-args.c prctl-pdeathsig.c prctl-seccomp-filter-v.c \
 	prctl-seccomp-strict.c prctl-securebits.c prctl-spec-inject.c \
 	prctl-tid_address.c prctl-tsc.c pread64-pwrite64.c preadv.c \
 	preadv-pwritev.c preadv2-pwritev2.c print_maxfd.c \
-	printpath-umovestr.c printpath-umovestr-peekdata.c \
-	printpath-umovestr-undumpable.c printsignal-Xabbrev.c \
-	printsignal-Xraw.c printsignal-Xverbose.c printstr.c \
-	printstrn-umoven.c printstrn-umoven-peekdata.c \
-	printstrn-umoven-undumpable.c prlimit64.c process_vm_readv.c \
-	process_vm_writev.c pselect6.c ptrace.c ptrace_syscall_info.c \
-	pwritev.c qual_fault.c qual_inject-error-signal.c \
-	qual_inject-retval.c qual_inject-signal.c qual_signal.c \
-	quotactl.c quotactl-Xabbrev.c quotactl-Xraw.c \
-	quotactl-Xverbose.c quotactl-success.c quotactl-success-v.c \
-	quotactl-v.c quotactl-xfs.c quotactl-xfs-success.c \
-	quotactl-xfs-success-v.c quotactl-xfs-v.c read-write.c \
-	readahead.c readdir.c readlink.c readlinkat.c readv.c reboot.c \
-	recv-MSG_TRUNC.c recvfrom.c recvfrom-MSG_TRUNC.c \
-	recvmmsg-timeout.c recvmsg.c redirect-fds.c remap_file_pages.c \
-	remap_file_pages-Xabbrev.c remap_file_pages-Xraw.c \
-	remap_file_pages-Xverbose.c rename.c renameat.c renameat2.c \
-	request_key.c restart_syscall.c riscv_flush_icache.c rmdir.c \
-	rt_sigaction.c rt_sigpending.c rt_sigprocmask.c \
-	rt_sigqueueinfo.c rt_sigreturn.c rt_sigsuspend.c \
-	rt_sigtimedwait.c rt_tgsigqueueinfo.c run_expect_termsig.c \
+	print_ppid_tracerpid.c printpath-umovestr.c \
+	printpath-umovestr-peekdata.c printpath-umovestr-undumpable.c \
+	printsignal-Xabbrev.c printsignal-Xraw.c \
+	printsignal-Xverbose.c printstr.c printstrn-umoven.c \
+	printstrn-umoven-peekdata.c printstrn-umoven-undumpable.c \
+	prlimit64.c prlimit64--pidns-translation.c process_vm_readv.c \
+	process_vm_readv--pidns-translation.c process_vm_writev.c \
+	process_vm_writev--pidns-translation.c pselect6.c ptrace.c \
+	ptrace_syscall_info.c pwritev.c qual_fault.c \
+	qual_inject-error-signal.c qual_inject-retval.c \
+	qual_inject-signal.c qual_signal.c quotactl.c \
+	quotactl-Xabbrev.c quotactl-Xraw.c quotactl-Xverbose.c \
+	quotactl-success.c quotactl-success-v.c quotactl-v.c \
+	quotactl-xfs.c quotactl-xfs-success.c quotactl-xfs-success-v.c \
+	quotactl-xfs-v.c read-write.c readahead.c readdir.c readlink.c \
+	readlinkat.c readv.c reboot.c recv-MSG_TRUNC.c recvfrom.c \
+	recvfrom-MSG_TRUNC.c recvmmsg-timeout.c recvmsg.c \
+	redirect-fds.c remap_file_pages.c remap_file_pages-Xabbrev.c \
+	remap_file_pages-Xraw.c remap_file_pages-Xverbose.c rename.c \
+	renameat.c renameat2.c request_key.c restart_syscall.c \
+	riscv_flush_icache.c rmdir.c rt_sigaction.c rt_sigpending.c \
+	rt_sigprocmask.c rt_sigqueueinfo.c \
+	rt_sigqueueinfo--pidns-translation.c rt_sigreturn.c \
+	rt_sigsuspend.c rt_sigtimedwait.c rt_tgsigqueueinfo.c \
+	rt_tgsigqueueinfo--pidns-translation.c run_expect_termsig.c \
 	s390_guarded_storage.c s390_guarded_storage-v.c \
 	s390_pci_mmio_read_write.c s390_runtime_instr.c s390_sthyi.c \
 	s390_sthyi-v.c sched_get_priority_mxx.c \
-	sched_rr_get_interval.c sched_xetaffinity.c sched_xetattr.c \
-	sched_xetparam.c sched_xetscheduler.c sched_yield.c \
+	sched_rr_get_interval.c sched_xetaffinity.c \
+	sched_xetaffinity--pidns-translation.c sched_xetattr.c \
+	sched_xetattr--pidns-translation.c sched_xetparam.c \
+	sched_xetparam--pidns-translation.c sched_xetscheduler.c \
+	sched_xetscheduler--pidns-translation.c sched_yield.c \
 	scm_rights.c seccomp-filter.c seccomp-filter-v.c \
 	seccomp-strict.c seccomp_get_action_avail.c select.c \
 	select-P.c semop.c semop-indirect.c semtimedop.c sendfile.c \
@@ -4002,38 +5027,50 @@ DIST_SOURCES = $(libtests_a_SOURCES) _ne
 	set_ptracer_any.c set_sigblock.c set_sigign.c setdomainname.c \
 	setfsgid.c setfsgid32.c setfsuid.c setfsuid32.c setgid.c \
 	setgid32.c setgroups.c setgroups32.c sethostname.c setns.c \
-	setregid.c setregid32.c setresgid.c setresgid32.c setresuid.c \
-	setresuid32.c setreuid.c setreuid32.c setrlimit.c \
-	setrlimit-Xabbrev.c setrlimit-Xraw.c setrlimit-Xverbose.c \
-	setuid.c setuid32.c shmxt.c shutdown.c sigaction.c \
-	sigaltstack.c siginfo.c signal.c signal_receive.c signalfd4.c \
-	sigpending.c sigprocmask.c sigreturn.c sigsuspend.c sleep.c \
-	so_error.c so_linger.c so_peercred.c so_peercred-Xabbrev.c \
-	so_peercred-Xraw.c so_peercred-Xverbose.c sock_filter-v.c \
-	sock_filter-v-Xabbrev.c sock_filter-v-Xraw.c \
-	sock_filter-v-Xverbose.c sockaddr_xlat-Xabbrev.c \
-	sockaddr_xlat-Xraw.c sockaddr_xlat-Xverbose.c socketcall.c \
-	sockopt-sol_netlink.c sockopt-timestamp.c splice.c \
-	$(stack_fcall_SOURCES) $(stack_fcall_attach_SOURCES) \
-	$(stack_fcall_mangled_SOURCES) stat.c stat64.c statfs.c \
-	statfs64.c status-all.c status-failed.c status-none.c \
-	status-none-f.c status-none-threads.c status-successful.c \
-	status-unfinished.c status-unfinished-threads.c statx.c swap.c \
-	sxetmask.c symlink.c symlinkat.c sync.c sync_file_range.c \
-	sync_file_range2.c sysinfo.c syslog.c syslog-success.c tee.c \
-	threads-execve.c time.c timer_create.c timer_xettime.c \
-	timerfd_xettime.c times.c times-fail.c tracer_ppid_pgid_sid.c \
-	truncate.c truncate64.c ugetrlimit.c uio.c umask.c umount.c \
-	umount2.c umoven-illptr.c umovestr.c umovestr-illptr.c \
-	umovestr2.c umovestr3.c umovestr_cached.c uname.c \
-	unblock_reset_raise.c unix-pair-send-recv.c \
+	setpgrp-exec.c setregid.c setregid32.c setresgid.c \
+	setresgid32.c setresuid.c setresuid32.c setreuid.c \
+	setreuid32.c setrlimit.c setrlimit-Xabbrev.c setrlimit-Xraw.c \
+	setrlimit-Xverbose.c setuid.c setuid32.c shmxt.c shutdown.c \
+	sigaction.c sigaltstack.c siginfo.c signal.c signal_receive.c \
+	signal_receive--pidns-translation.c signalfd4.c sigpending.c \
+	sigprocmask.c sigreturn.c sigsuspend.c sleep.c so_error.c \
+	so_linger.c so_peercred.c so_peercred--pidns-translation.c \
+	so_peercred-Xabbrev.c so_peercred-Xraw.c \
+	so_peercred-Xverbose.c sock_filter-v.c sock_filter-v-Xabbrev.c \
+	sock_filter-v-Xraw.c sock_filter-v-Xverbose.c \
+	sockaddr_xlat-Xabbrev.c sockaddr_xlat-Xraw.c \
+	sockaddr_xlat-Xverbose.c socketcall.c sockopt-sol_netlink.c \
+	sockopt-timestamp.c splice.c $(stack_fcall_SOURCES) \
+	$(stack_fcall_attach_SOURCES) $(stack_fcall_mangled_SOURCES) \
+	stat.c stat64.c statfs.c statfs64.c status-all.c \
+	status-failed.c status-failed-long.c status-failed-status.c \
+	status-none.c status-none-f.c status-none-threads.c \
+	status-successful.c status-successful-long.c \
+	status-successful-status.c status-unfinished.c \
+	status-unfinished-threads.c statx.c strace--strings-in-hex.c \
+	strace--strings-in-hex-all.c \
+	strace--strings-in-hex-non-ascii.c strace-n.c strace-x.c \
+	strace-xx.c swap.c sxetmask.c symlink.c symlinkat.c sync.c \
+	sync_file_range.c sync_file_range2.c sysinfo.c syslog.c \
+	syslog-success.c tee.c tgkill.c tgkill--pidns-translation.c \
+	threads-execve.c threads-execve--quiet-thread-execve.c \
+	threads-execve-q.c threads-execve-qq.c threads-execve-qqq.c \
+	time.c timer_create.c timer_xettime.c timerfd_xettime.c \
+	times.c times-fail.c tkill.c tkill--pidns-translation.c \
+	tracer_ppid_pgid_sid.c $(trie_test_SOURCES) truncate.c \
+	truncate64.c ugetrlimit.c uio.c umask.c umount.c umount2.c \
+	umoven-illptr.c umovestr.c umovestr-illptr.c umovestr2.c \
+	umovestr3.c umovestr_cached.c umovestr_cached_adjacent.c \
+	uname.c unblock_reset_raise.c unix-pair-send-recv.c \
 	unix-pair-sendto-recvfrom.c unlink.c unlinkat.c unshare.c \
 	userfaultfd.c ustat.c utime.c utimensat.c utimensat-Xabbrev.c \
 	utimensat-Xraw.c utimensat-Xverbose.c utimes.c vfork-f.c \
 	vhangup.c vmsplice.c wait4.c wait4-v.c waitid.c waitid-v.c \
 	waitpid.c xattr.c xattr-strings.c xet_robust_list.c \
-	xet_thread_area_x86.c xetitimer.c xetpgid.c xetpriority.c \
-	xettimeofday.c zeroargc.c
+	xet_robust_list--pidns-translation.c xet_thread_area_x86.c \
+	xetitimer.c xetpgid.c xetpgid--pidns-translation.c \
+	xetpriority.c xetpriority--pidns-translation.c xettimeofday.c \
+	zeroargc.c
 am__can_run_installinfo = \
   case $$AM_UPDATE_INFO_DIR in \
     n|no|NO) false;; \
@@ -4244,6 +5281,7 @@ am__set_TESTS_bases = \
   bases='$(TEST_LOGS)'; \
   bases=`for i in $$bases; do echo $$i; done | sed 's/\.log$$//'`; \
   bases=`echo $$bases`
+AM_TESTSUITE_SUMMARY_HEADER = ' for $(PACKAGE_STRING)'
 RECHECK_LOGS = $(TEST_LOGS)
 AM_RECURSIVE_TARGETS = check recheck
 @ENABLE_STACKTRACE_TRUE@am__EXEEXT_2 = strace-k.test strace-k-p.test \
@@ -4273,6 +5311,7 @@ DISTFILES = $(DIST_COMMON) $(DIST_SOURCE
 ACLOCAL = @ACLOCAL@
 AMTAR = @AMTAR@
 AM_DEFAULT_VERBOSITY = @AM_DEFAULT_VERBOSITY@
+AR = @AR@
 AUTOCONF = @AUTOCONF@
 AUTOHEADER = @AUTOHEADER@
 AUTOMAKE = @AUTOMAKE@
@@ -4344,7 +5383,6 @@ PACKAGE_TARNAME = @PACKAGE_TARNAME@
 PACKAGE_URL = @PACKAGE_URL@
 PACKAGE_VERSION = @PACKAGE_VERSION@
 PATH_SEPARATOR = @PATH_SEPARATOR@
-PERL = @PERL@
 RANLIB = @RANLIB@
 READELF = @READELF@
 RPM_CHANGELOGTIME = @RPM_CHANGELOGTIME@
@@ -4363,6 +5401,7 @@ abs_builddir = @abs_builddir@
 abs_srcdir = @abs_srcdir@
 abs_top_builddir = @abs_top_builddir@
 abs_top_srcdir = @abs_top_srcdir@
+ac_ct_AR = @ac_ct_AR@
 ac_ct_CC = @ac_ct_CC@
 ac_ct_CC_FOR_BUILD = @ac_ct_CC_FOR_BUILD@
 am__include = @am__include@
@@ -4453,6 +5492,7 @@ AM_CPPFLAGS = $(ARCH_MFLAGS) \
 AM_LDFLAGS = $(ARCH_MFLAGS)
 libtests_a_SOURCES = \
 	create_nl_socket.c \
+	create_tmpfile.c \
 	errno2name.c \
 	error_msg.c \
 	fill_memory.c \
@@ -4466,6 +5506,8 @@ libtests_a_SOURCES = \
 	libsocketcall.c \
 	lock_file.c \
 	overflowuid.c \
+	pidns.c \
+	pidns.h \
 	pipe_maxfd.c \
 	print_quoted_string.c \
 	print_time.c \
@@ -4486,6 +5528,7 @@ libtests_a_SOURCES = \
 	test_ucopy.h \
 	tests.h \
 	tprintf.c \
+	xmalloc_for_tests.c \
 	# end of libtests_a_SOURCES
 
 libtests_a_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
@@ -4521,13 +5564,29 @@ PURE_EXECUTABLES = \
   clone3-Xabbrev \
   clone3-Xraw \
   clone3-Xverbose \
+  close_range \
+  close_range-P \
+  close_range-y \
+  close_range-yy \
   copy_file_range \
   creat \
   delete_module \
+  dev--decode-fds-dev \
+  dev--decode-fds-path \
+  dev--decode-fds-socket \
   dev-yy \
   dup \
+  dup-P \
+  dup-y \
+  dup-yy \
   dup2 \
+  dup2-P \
+  dup2-y \
+  dup2-yy \
   dup3 \
+  dup3-P \
+  dup3-y \
+  dup3-yy \
   epoll_create \
   epoll_create1 \
   epoll_ctl \
@@ -4538,6 +5597,13 @@ PURE_EXECUTABLES = \
   execve \
   execveat \
   faccessat \
+  faccessat-P \
+  faccessat-y \
+  faccessat-yy \
+  faccessat2 \
+  faccessat2-P \
+  faccessat2-y \
+  faccessat2-yy \
   fadvise64 \
   fadvise64_64 \
   fallocate \
@@ -4586,7 +5652,9 @@ PURE_EXECUTABLES = \
   getcpu \
   getcwd \
   getdents \
+  getdents-v \
   getdents64 \
+  getdents64-v \
   getegid \
   getegid32 \
   geteuid \
@@ -4610,7 +5678,9 @@ PURE_EXECUTABLES = \
   getsockname \
   getuid \
   getuid32 \
-  getxxid \
+  getxgid \
+  getxpid \
+  getxuid \
   group_req \
   inet-cmsg \
   init_module \
@@ -4633,6 +5703,14 @@ PURE_EXECUTABLES = \
   ioctl_evdev-v-Xabbrev \
   ioctl_evdev-v-Xraw \
   ioctl_evdev-v-Xverbose \
+  ioctl_hdio \
+  ioctl_hdio-Xabbrev \
+  ioctl_hdio-Xraw \
+  ioctl_hdio-Xverbose \
+  ioctl_hdio-v \
+  ioctl_hdio-v-Xabbrev \
+  ioctl_hdio-v-Xraw \
+  ioctl_hdio-v-Xverbose \
   ioctl_inotify \
   ioctl_kvm_run \
   ioctl_kvm_run-v \
@@ -4648,8 +5726,16 @@ PURE_EXECUTABLES = \
   ioctl_sg_io_v3 \
   ioctl_sg_io_v4 \
   ioctl_sock_gifconf \
+  ioctl_tee \
   ioctl_uffdio \
   ioctl_v4l2 \
+  ioctl_v4l2-Xabbrev \
+  ioctl_v4l2-Xraw \
+  ioctl_v4l2-Xverbose \
+  ioctl_v4l2-v \
+  ioctl_v4l2-v-Xabbrev \
+  ioctl_v4l2-v-Xraw \
+  ioctl_v4l2-v-Xverbose \
   ioctl_watchdog \
   ioperm \
   iopl \
@@ -4700,6 +5786,7 @@ PURE_EXECUTABLES = \
   lstat64 \
   madvise \
   maybe_switch_current_tcp \
+  maybe_switch_current_tcp--quiet-thread-execve \
   mbind \
   mbind-Xabbrev \
   mbind-Xraw \
@@ -4747,6 +5834,10 @@ PURE_EXECUTABLES = \
   msg_name \
   munlockall \
   nanosleep \
+  net--decode-fds-dev-netlink \
+  net--decode-fds-none-netlink \
+  net--decode-fds-path-netlink \
+  net--decode-fds-socket-netlink \
   net-icmp_filter \
   net-packet_mreq \
   net-packet_mreq-Xabbrev \
@@ -4829,6 +5920,16 @@ PURE_EXECUTABLES = \
   open_tree \
   open_tree-P \
   openat \
+  openat2 \
+  openat2-Xabbrev \
+  openat2-Xraw \
+  openat2-Xverbose \
+  openat2-v \
+  openat2-v-y \
+  openat2-v-y-Xabbrev \
+  openat2-v-y-Xraw \
+  openat2-v-y-Xverbose \
+  openat2-y \
   osf_utimes \
   pause \
   perf_event_open \
@@ -4836,9 +5937,16 @@ PURE_EXECUTABLES = \
   personality-Xabbrev \
   personality-Xraw \
   personality-Xverbose \
+  pidfd_getfd \
+  pidfd_getfd-y \
+  pidfd_getfd-yy \
   pidfd_open \
+  pidfd_open--decode-fd-path \
+  pidfd_open--decode-fd-pidfd \
+  pidfd_open--decode-fd-socket \
   pidfd_open-P \
   pidfd_open-y \
+  pidfd_open-yy \
   pidfd_send_signal \
   pipe \
   pipe2 \
@@ -4846,9 +5954,7 @@ PURE_EXECUTABLES = \
   pkey_free \
   pkey_mprotect \
   poll \
-  poll-P \
   ppoll \
-  ppoll-P \
   prctl-arg2-intptr \
   prctl-dumpable \
   prctl-name \
@@ -4997,11 +6103,21 @@ PURE_EXECUTABLES = \
   statfs64 \
   status-all \
   status-failed \
+  status-failed-long \
+  status-failed-status \
   status-none \
   status-none-f \
   status-successful \
+  status-successful-long \
+  status-successful-status \
   status-unfinished \
   statx \
+  strace--strings-in-hex \
+  strace--strings-in-hex-all \
+  strace--strings-in-hex-non-ascii \
+  strace-n \
+  strace-x \
+  strace-xx \
   swap \
   sxetmask \
   symlink \
@@ -5012,12 +6128,14 @@ PURE_EXECUTABLES = \
   sysinfo \
   syslog \
   tee \
+  tgkill \
   time \
   timer_create \
   timer_xettime \
   timerfd_xettime \
   times \
   times-fail \
+  tkill \
   truncate \
   truncate64 \
   ugetrlimit \
@@ -5031,6 +6149,7 @@ PURE_EXECUTABLES = \
   umovestr2 \
   umovestr3 \
   umovestr_cached \
+  umovestr_cached_adjacent \
   uname \
   unlink \
   unlinkat \
@@ -5069,6 +6188,7 @@ localtime_LDADD = $(clock_LIBS) $(LDADD)
 looping_threads_LDADD = -lpthread $(LDADD)
 lstat64_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 maybe_switch_current_tcp_LDADD = -lpthread $(LDADD)
+maybe_switch_current_tcp__quiet_thread_execve_LDADD = -lpthread $(LDADD)
 mmap64_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 mmap64_Xabbrev_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 mmap64_Xraw_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
@@ -5085,6 +6205,10 @@ statfs_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE
 status_none_threads_LDADD = -lpthread $(LDADD)
 status_unfinished_threads_LDADD = -lpthread $(LDADD)
 threads_execve_LDADD = -lpthread $(clock_LIBS) $(LDADD)
+threads_execve__quiet_thread_execve_LDADD = -lpthread $(clock_LIBS) $(LDADD)
+threads_execve_q_LDADD = -lpthread $(clock_LIBS) $(LDADD)
+threads_execve_qq_LDADD = -lpthread $(clock_LIBS) $(LDADD)
+threads_execve_qqq_LDADD = -lpthread $(clock_LIBS) $(LDADD)
 times_LDADD = $(clock_LIBS) $(LDADD)
 truncate64_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
 uio_CPPFLAGS = $(AM_CPPFLAGS) -D_FILE_OFFSET_BITS=64
@@ -5098,6 +6222,10 @@ stack_fcall_mangled_SOURCES = stack-fcal
 	stack-fcall-mangled-0.c stack-fcall-mangled-1.c \
 	stack-fcall-mangled-2.c stack-fcall-mangled-3.c
 
+trie_test_SOURCES = trie_test.c trie_for_tests.c
+trie_test_CPPFLAGS = $(AM_CPPFLAGS) $(CODE_COVERAGE_CPPFLAGS)
+trie_test_CFLAGS = $(AM_CFLAGS) $(CODE_COVERAGE_CFLAGS)
+trie_test_LDADD = $(LDADD) $(CODE_COVERAGE_LIBS)
 
 # Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in; do not edit.
 GEN_TESTS = _newselect.gen.test _newselect-P.gen.test accept.gen.test \
@@ -5114,69 +6242,111 @@ GEN_TESTS = _newselect.gen.test _newsele
 	clone3.gen.test clone3-Xabbrev.gen.test clone3-Xraw.gen.test \
 	clone3-Xverbose.gen.test clone3-success-Xabbrev.gen.test \
 	clone3-success-Xraw.gen.test clone3-success-Xverbose.gen.test \
-	copy_file_range.gen.test creat.gen.test delete_module.gen.test \
-	dev-yy.gen.test dup.gen.test dup2.gen.test dup3.gen.test \
+	clone_parent.gen.test clone_parent--quiet-exit.gen.test \
+	clone_parent-q.gen.test clone_parent-qq.gen.test \
+	clone_ptrace--quiet-attach.gen.test \
+	clone_ptrace--quiet-exit.gen.test clone_ptrace-q.gen.test \
+	clone_ptrace-qq.gen.test close_range.gen.test \
+	close_range-P.gen.test close_range-y.gen.test \
+	close_range-yy.gen.test copy_file_range.gen.test \
+	creat.gen.test delete_module.gen.test \
+	dev--decode-fds-dev.gen.test dev--decode-fds-path.gen.test \
+	dev--decode-fds-socket.gen.test dev-yy.gen.test dup.gen.test \
+	dup-P.gen.test dup-y.gen.test dup-yy.gen.test dup2.gen.test \
+	dup2-P.gen.test dup2-y.gen.test dup2-yy.gen.test dup3.gen.test \
+	dup3-P.gen.test dup3-y.gen.test dup3-yy.gen.test \
 	epoll_create.gen.test epoll_create1.gen.test \
 	epoll_ctl.gen.test epoll_pwait.gen.test epoll_wait.gen.test \
 	erestartsys.gen.test execveat.gen.test execveat-v.gen.test \
-	faccessat.gen.test fadvise64_64.gen.test fallocate.gen.test \
+	faccessat-P.gen.test faccessat-y.gen.test \
+	faccessat-yy.gen.test faccessat2-P.gen.test \
+	faccessat2-y.gen.test faccessat2-yy.gen.test \
+	fadvise64_64.gen.test fallocate.gen.test \
 	fanotify_init.gen.test fanotify_mark.gen.test \
 	fanotify_mark-Xabbrev.gen.test fanotify_mark-Xraw.gen.test \
 	fanotify_mark-Xverbose.gen.test fchdir.gen.test \
 	fchmod.gen.test fchmodat.gen.test fchown.gen.test \
 	fchown32.gen.test fchownat.gen.test fcntl.gen.test \
-	fcntl64.gen.test fdatasync.gen.test file_handle.gen.test \
-	file_ioctl.gen.test filter_seccomp.gen.test \
-	filter_seccomp-flag.gen.test finit_module.gen.test \
-	flock.gen.test fork-f.gen.test fsconfig.gen.test \
-	fsconfig-P.gen.test fsmount.gen.test fsopen.gen.test \
-	fspick.gen.test fspick-P.gen.test fstat.gen.test \
-	fstat-Xabbrev.gen.test fstat-Xraw.gen.test \
+	fcntl--pidns-translation.gen.test fcntl64.gen.test \
+	fcntl64--pidns-translation.gen.test fdatasync.gen.test \
+	file_handle.gen.test file_ioctl.gen.test \
+	filter_seccomp.gen.test filter_seccomp-flag.gen.test \
+	finit_module.gen.test flock.gen.test fork-f.gen.test \
+	fsconfig.gen.test fsconfig-P.gen.test fsmount.gen.test \
+	fsopen.gen.test fspick.gen.test fspick-P.gen.test \
+	fstat.gen.test fstat-Xabbrev.gen.test fstat-Xraw.gen.test \
 	fstat-Xverbose.gen.test fstat64.gen.test \
 	fstat64-Xabbrev.gen.test fstat64-Xraw.gen.test \
 	fstat64-Xverbose.gen.test fstatat64.gen.test fstatfs.gen.test \
 	fstatfs64.gen.test fsync.gen.test fsync-y.gen.test \
 	ftruncate.gen.test ftruncate64.gen.test futimesat.gen.test \
 	get_mempolicy.gen.test getcpu.gen.test getcwd.gen.test \
-	getdents.gen.test getdents64.gen.test getegid.gen.test \
-	getegid-creds.gen.test getegid32.gen.test \
-	getegid32-creds.gen.test geteuid.gen.test \
+	getdents.gen.test getdents-v.gen.test getdents64.gen.test \
+	getdents64-v.gen.test getegid.gen.test getegid-creds.gen.test \
+	getegid32.gen.test getegid32-creds.gen.test geteuid.gen.test \
 	geteuid-creds.gen.test geteuid32.gen.test \
 	geteuid32-creds.gen.test getgid.gen.test getgid-creds.gen.test \
 	getgid32.gen.test getgid32-creds.gen.test getgroups.gen.test \
 	getgroups32.gen.test getpeername.gen.test getpgrp.gen.test \
-	getpid.gen.test getppid.gen.test getrandom.gen.test \
-	getresgid.gen.test getresgid32.gen.test getresuid.gen.test \
-	getresuid32.gen.test getrlimit.gen.test getrusage.gen.test \
-	getsid.gen.test getsockname.gen.test gettid.gen.test \
-	getuid-creds.gen.test getuid32.gen.test \
-	getuid32-creds.gen.test getxxid.gen.test group_req.gen.test \
-	inet-cmsg.gen.test init_module.gen.test inotify.gen.test \
-	inotify_init.gen.test inotify_init1.gen.test \
-	inotify_init1-y.gen.test io_uring_enter.gen.test \
-	io_uring_register.gen.test io_uring_setup.gen.test \
-	ioctl_block.gen.test ioctl_dm.gen.test ioctl_dm-v.gen.test \
-	ioctl_evdev.gen.test ioctl_evdev-Xabbrev.gen.test \
-	ioctl_evdev-Xraw.gen.test ioctl_evdev-Xverbose.gen.test \
-	ioctl_evdev-v.gen.test ioctl_evdev-v-Xabbrev.gen.test \
-	ioctl_evdev-v-Xraw.gen.test ioctl_evdev-v-Xverbose.gen.test \
+	getpgrp--pidns-translation.gen.test getpid.gen.test \
+	getpid--pidns-translation.gen.test getppid.gen.test \
+	getrandom.gen.test getresgid.gen.test getresgid32.gen.test \
+	getresuid.gen.test getresuid32.gen.test getrlimit.gen.test \
+	getrusage.gen.test getsid.gen.test \
+	getsid--pidns-translation.gen.test getsockname.gen.test \
+	gettid.gen.test getuid-creds.gen.test getuid32.gen.test \
+	getuid32-creds.gen.test getxgid.gen.test getxpid.gen.test \
+	getxuid.gen.test group_req.gen.test inet-cmsg.gen.test \
+	init_module.gen.test inotify.gen.test inotify_init.gen.test \
+	inotify_init1.gen.test inotify_init1-y.gen.test \
+	io_uring_enter.gen.test io_uring_register.gen.test \
+	io_uring_setup.gen.test ioctl_block.gen.test ioctl_dm.gen.test \
+	ioctl_dm-v.gen.test ioctl_evdev.gen.test \
+	ioctl_evdev-Xabbrev.gen.test ioctl_evdev-Xraw.gen.test \
+	ioctl_evdev-Xverbose.gen.test ioctl_evdev-v.gen.test \
+	ioctl_evdev-v-Xabbrev.gen.test ioctl_evdev-v-Xraw.gen.test \
+	ioctl_evdev-v-Xverbose.gen.test \
 	ioctl_evdev-success-Xabbrev.gen.test \
 	ioctl_evdev-success-Xraw.gen.test \
 	ioctl_evdev-success-Xverbose.gen.test \
 	ioctl_evdev-success-v.gen.test \
 	ioctl_evdev-success-v-Xabbrev.gen.test \
 	ioctl_evdev-success-v-Xraw.gen.test \
-	ioctl_evdev-success-v-Xverbose.gen.test ioctl_inotify.gen.test \
+	ioctl_evdev-success-v-Xverbose.gen.test ioctl_hdio.gen.test \
+	ioctl_hdio-Xabbrev.gen.test ioctl_hdio-Xraw.gen.test \
+	ioctl_hdio-Xverbose.gen.test ioctl_hdio-v.gen.test \
+	ioctl_hdio-v-Xabbrev.gen.test ioctl_hdio-v-Xraw.gen.test \
+	ioctl_hdio-v-Xverbose.gen.test ioctl_hdio-success.gen.test \
+	ioctl_hdio-success-Xabbrev.gen.test \
+	ioctl_hdio-success-Xraw.gen.test \
+	ioctl_hdio-success-Xverbose.gen.test \
+	ioctl_hdio-success-v.gen.test \
+	ioctl_hdio-success-v-Xabbrev.gen.test \
+	ioctl_hdio-success-v-Xraw.gen.test \
+	ioctl_hdio-success-v-Xverbose.gen.test ioctl_inotify.gen.test \
 	ioctl_kvm_run.gen.test ioctl_kvm_run-v.gen.test \
 	ioctl_kvm_run_auxstr_vcpu.gen.test ioctl_loop.gen.test \
 	ioctl_loop-nv.gen.test ioctl_loop-v.gen.test \
 	ioctl_mtd.gen.test ioctl_nbd.gen.test ioctl_nsfs.gen.test \
-	ioctl_perf.gen.test ioctl_ptp.gen.test ioctl_random.gen.test \
-	ioctl_rtc.gen.test ioctl_rtc-v.gen.test ioctl_scsi.gen.test \
+	ioctl_perf.gen.test ioctl_perf-success.gen.test \
+	ioctl_ptp.gen.test ioctl_random.gen.test ioctl_rtc.gen.test \
+	ioctl_rtc-v.gen.test ioctl_scsi.gen.test \
 	ioctl_sg_io_v3.gen.test ioctl_sg_io_v4.gen.test \
-	ioctl_sock_gifconf.gen.test ioctl_uffdio.gen.test \
-	ioctl_v4l2.gen.test ioctl_watchdog.gen.test ioperm.gen.test \
-	iopl.gen.test ioprio.gen.test ioprio-Xabbrev.gen.test \
+	ioctl_sock_gifconf.gen.test ioctl_tee.gen.test \
+	ioctl_uffdio.gen.test ioctl_v4l2.gen.test \
+	ioctl_v4l2-Xabbrev.gen.test ioctl_v4l2-Xraw.gen.test \
+	ioctl_v4l2-Xverbose.gen.test ioctl_v4l2-v.gen.test \
+	ioctl_v4l2-v-Xabbrev.gen.test ioctl_v4l2-v-Xraw.gen.test \
+	ioctl_v4l2-v-Xverbose.gen.test ioctl_v4l2-success.gen.test \
+	ioctl_v4l2-success-Xabbrev.gen.test \
+	ioctl_v4l2-success-Xraw.gen.test \
+	ioctl_v4l2-success-Xverbose.gen.test \
+	ioctl_v4l2-success-v.gen.test \
+	ioctl_v4l2-success-v-Xabbrev.gen.test \
+	ioctl_v4l2-success-v-Xraw.gen.test \
+	ioctl_v4l2-success-v-Xverbose.gen.test ioctl_watchdog.gen.test \
+	ioperm.gen.test iopl.gen.test ioprio.gen.test \
+	ioprio--pidns-translation.gen.test ioprio-Xabbrev.gen.test \
 	ioprio-Xraw.gen.test ioprio-Xverbose.gen.test ip_mreq.gen.test \
 	ipc.gen.test ipc_msg.gen.test ipc_msg-Xabbrev.gen.test \
 	ipc_msg-Xraw.gen.test ipc_msg-Xverbose.gen.test \
@@ -5186,23 +6356,27 @@ GEN_TESTS = _newselect.gen.test _newsele
 	ipc_sem-Xverbose.gen.test ipc_shm.gen.test \
 	ipc_shm-Xabbrev.gen.test ipc_shm-Xraw.gen.test \
 	ipc_shm-Xverbose.gen.test kcmp.gen.test kcmp-y.gen.test \
-	kern_features.gen.test kernel_version.gen.test \
-	kernel_version-Xabbrev.gen.test kernel_version-Xraw.gen.test \
-	kernel_version-Xverbose.gen.test kexec_file_load.gen.test \
-	kexec_load.gen.test keyctl.gen.test keyctl-Xabbrev.gen.test \
-	keyctl-Xraw.gen.test keyctl-Xverbose.gen.test kill.gen.test \
-	ksysent.gen.test lchown.gen.test lchown32.gen.test \
-	link.gen.test linkat.gen.test lookup_dcookie.gen.test \
-	lstat.gen.test lstat64.gen.test madvise.gen.test \
-	maybe_switch_current_tcp.gen.test mbind.gen.test \
-	mbind-Xabbrev.gen.test mbind-Xraw.gen.test \
+	kcmp-y--pidns-translation.gen.test kern_features.gen.test \
+	kernel_version.gen.test kernel_version-Xabbrev.gen.test \
+	kernel_version-Xraw.gen.test kernel_version-Xverbose.gen.test \
+	kexec_file_load.gen.test kexec_load.gen.test keyctl.gen.test \
+	keyctl-Xabbrev.gen.test keyctl-Xraw.gen.test \
+	keyctl-Xverbose.gen.test kill.gen.test \
+	kill--pidns-translation.gen.test ksysent.gen.test \
+	lchown.gen.test lchown32.gen.test link.gen.test \
+	linkat.gen.test lookup_dcookie.gen.test lstat.gen.test \
+	lstat64.gen.test madvise.gen.test \
+	maybe_switch_current_tcp.gen.test \
+	maybe_switch_current_tcp--quiet-thread-execve.gen.test \
+	mbind.gen.test mbind-Xabbrev.gen.test mbind-Xraw.gen.test \
 	mbind-Xverbose.gen.test membarrier.gen.test \
 	memfd_create.gen.test memfd_create-Xabbrev.gen.test \
 	memfd_create-Xraw.gen.test memfd_create-Xverbose.gen.test \
-	migrate_pages.gen.test mincore.gen.test mkdir.gen.test \
-	mkdirat.gen.test mknod.gen.test mknodat.gen.test \
-	mlock.gen.test mlock2.gen.test mlockall.gen.test \
-	mmap-Xabbrev.gen.test mmap-Xraw.gen.test \
+	migrate_pages.gen.test \
+	migrate_pages--pidns-translation.gen.test mincore.gen.test \
+	mkdir.gen.test mkdirat.gen.test mknod.gen.test \
+	mknodat.gen.test mlock.gen.test mlock2.gen.test \
+	mlockall.gen.test mmap-Xabbrev.gen.test mmap-Xraw.gen.test \
 	mmap-Xverbose.gen.test mmap64.gen.test mmap64-Xabbrev.gen.test \
 	mmap64-Xraw.gen.test mmap64-Xverbose.gen.test mmsg.gen.test \
 	mmsg-silent.gen.test mmsg_name.gen.test mmsg_name-v.gen.test \
@@ -5210,13 +6384,19 @@ GEN_TESTS = _newselect.gen.test _newsele
 	mount-Xraw.gen.test mount-Xverbose.gen.test \
 	move_mount.gen.test move_mount-P.gen.test move_pages.gen.test \
 	move_pages-Xabbrev.gen.test move_pages-Xraw.gen.test \
-	move_pages-Xverbose.gen.test mq.gen.test mq_sendrecv.gen.test \
-	mq_sendrecv-read.gen.test mq_sendrecv-write.gen.test \
-	msg_control.gen.test msg_control-v.gen.test msg_name.gen.test \
-	munlockall.gen.test nanosleep.gen.test \
+	move_pages-Xverbose.gen.test \
+	move_pages--pidns-translation.gen.test mq.gen.test \
+	mq_sendrecv.gen.test mq_sendrecv-read.gen.test \
+	mq_sendrecv-write.gen.test msg_control.gen.test \
+	msg_control-v.gen.test msg_name.gen.test munlockall.gen.test \
+	nanosleep.gen.test net--decode-fds-dev-netlink.gen.test \
+	net--decode-fds-none-netlink.gen.test \
+	net--decode-fds-path-netlink.gen.test \
+	net--decode-fds-socket-netlink.gen.test \
 	net-icmp_filter.gen.test net-packet_mreq.gen.test \
 	net-packet_mreq-Xabbrev.gen.test net-packet_mreq-Xraw.gen.test \
 	net-packet_mreq-Xverbose.gen.test net-sockaddr.gen.test \
+	net-sockaddr--pidns-translation.gen.test \
 	net-tpacket_req.gen.test net-tpacket_stats.gen.test \
 	net-yy-inet6.gen.test netlink_audit.gen.test \
 	netlink_crypto.gen.test netlink_generic.gen.test \
@@ -5235,7 +6415,8 @@ GEN_TESTS = _newselect.gen.test _newsele
 	nlattr_ifaddrmsg.gen.test nlattr_ifinfomsg.gen.test \
 	nlattr_ifla_af_spec.gen.test nlattr_ifla_brport.gen.test \
 	nlattr_ifla_linkinfo.gen.test nlattr_ifla_port.gen.test \
-	nlattr_ifla_xdp.gen.test nlattr_inet_diag_msg.gen.test \
+	nlattr_ifla_xdp.gen.test nlattr_ifla_xdp-y.gen.test \
+	nlattr_inet_diag_msg.gen.test \
 	nlattr_inet_diag_req_compat.gen.test \
 	nlattr_inet_diag_req_v2.gen.test \
 	nlattr_mdba_mdb_entry.gen.test \
@@ -5253,17 +6434,28 @@ GEN_TESTS = _newselect.gen.test _newsele
 	oldselect.gen.test oldselect-P.gen.test \
 	oldselect-efault.gen.test oldselect-efault-P.gen.test \
 	oldstat.gen.test open.gen.test open_tree.gen.test \
-	open_tree-P.gen.test openat.gen.test \
-	orphaned_process_group.gen.test osf_utimes.gen.test \
-	pause.gen.test perf_event_open.gen.test \
+	open_tree-P.gen.test openat.gen.test openat2.gen.test \
+	openat2-Xabbrev.gen.test openat2-Xraw.gen.test \
+	openat2-Xverbose.gen.test openat2-v.gen.test \
+	openat2-v-y.gen.test openat2-v-y-Xabbrev.gen.test \
+	openat2-v-y-Xraw.gen.test openat2-v-y-Xverbose.gen.test \
+	openat2-y.gen.test orphaned_process_group.gen.test \
+	osf_utimes.gen.test pause.gen.test perf_event_open.gen.test \
 	perf_event_open_nonverbose.gen.test \
 	perf_event_open_unabbrev.gen.test personality-Xabbrev.gen.test \
 	personality-Xraw.gen.test personality-Xverbose.gen.test \
-	pidfd_open.gen.test pidfd_open-P.gen.test \
-	pidfd_open-y.gen.test pidfd_send_signal.gen.test \
-	pipe2.gen.test pkey_alloc.gen.test pkey_free.gen.test \
-	pkey_mprotect.gen.test ppoll.gen.test ppoll-P.gen.test \
-	ppoll-v.gen.test pread64-pwrite64.gen.test preadv.gen.test \
+	pidfd_getfd.gen.test pidfd_getfd-y.gen.test \
+	pidfd_getfd-yy.gen.test pidfd_open.gen.test \
+	pidfd_open--decode-fd-path.gen.test \
+	pidfd_open--decode-fd-pidfd.gen.test \
+	pidfd_open--decode-fd-socket.gen.test pidfd_open-P.gen.test \
+	pidfd_open-y.gen.test pidfd_open-yy.gen.test \
+	pidfd_open--pidns-translation.gen.test \
+	pidfd_send_signal.gen.test \
+	pidfd_send_signal--pidns-translation.gen.test pipe2.gen.test \
+	pkey_alloc.gen.test pkey_free.gen.test pkey_mprotect.gen.test \
+	ppoll.gen.test ppoll-P.gen.test ppoll-v.gen.test \
+	pread64-pwrite64.gen.test preadv.gen.test \
 	preadv-pwritev.gen.test preadv2-pwritev2.gen.test \
 	printpath-umovestr.gen.test \
 	printpath-umovestr-peekdata.gen.test \
@@ -5272,7 +6464,11 @@ GEN_TESTS = _newselect.gen.test _newsele
 	printsignal-Xverbose.gen.test printstr.gen.test \
 	printstrn-umoven.gen.test printstrn-umoven-peekdata.gen.test \
 	printstrn-umoven-undumpable.gen.test prlimit64.gen.test \
-	process_vm_readv.gen.test process_vm_writev.gen.test \
+	prlimit64--pidns-translation.gen.test \
+	process_vm_readv.gen.test \
+	process_vm_readv--pidns-translation.gen.test \
+	process_vm_writev.gen.test \
+	process_vm_writev--pidns-translation.gen.test \
 	pselect6.gen.test ptrace.gen.test ptrace_syscall_info.gen.test \
 	pwritev.gen.test quotactl.gen.test quotactl-Xabbrev.gen.test \
 	quotactl-Xraw.gen.test quotactl-Xverbose.gen.test \
@@ -5288,15 +6484,23 @@ GEN_TESTS = _newselect.gen.test _newsele
 	renameat.gen.test renameat2.gen.test request_key.gen.test \
 	riscv_flush_icache.gen.test rmdir.gen.test \
 	rt_sigpending.gen.test rt_sigprocmask.gen.test \
-	rt_sigqueueinfo.gen.test rt_sigreturn.gen.test \
-	rt_sigsuspend.gen.test rt_sigtimedwait.gen.test \
-	rt_tgsigqueueinfo.gen.test s390_guarded_storage.gen.test \
-	s390_guarded_storage-v.gen.test \
+	rt_sigqueueinfo.gen.test \
+	rt_sigqueueinfo--pidns-translation.gen.test \
+	rt_sigreturn.gen.test rt_sigsuspend.gen.test \
+	rt_sigtimedwait.gen.test rt_tgsigqueueinfo.gen.test \
+	rt_tgsigqueueinfo--pidns-translation.gen.test \
+	s390_guarded_storage.gen.test s390_guarded_storage-v.gen.test \
 	s390_pci_mmio_read_write.gen.test s390_runtime_instr.gen.test \
 	s390_sthyi.gen.test s390_sthyi-v.gen.test sched.gen.test \
 	sched_get_priority_mxx.gen.test sched_rr_get_interval.gen.test \
-	sched_xetaffinity.gen.test sched_xetattr.gen.test \
-	sched_xetparam.gen.test sched_xetscheduler.gen.test \
+	sched_xetaffinity.gen.test \
+	sched_xetaffinity--pidns-translation.gen.test \
+	sched_xetattr.gen.test \
+	sched_xetattr--pidns-translation.gen.test \
+	sched_xetparam.gen.test \
+	sched_xetparam--pidns-translation.gen.test \
+	sched_xetscheduler.gen.test \
+	sched_xetscheduler--pidns-translation.gen.test \
 	sched_yield.gen.test seccomp-filter.gen.test \
 	seccomp-filter-v.gen.test seccomp_get_action_avail.gen.test \
 	select.gen.test select-P.gen.test semop.gen.test \
@@ -5314,26 +6518,70 @@ GEN_TESTS = _newselect.gen.test _newsele
 	setrlimit-Xraw.gen.test setrlimit-Xverbose.gen.test \
 	setuid.gen.test setuid32.gen.test shmxt.gen.test \
 	shutdown.gen.test sigaction.gen.test siginfo.gen.test \
-	signal.gen.test signal_receive.gen.test signalfd4.gen.test \
+	signal.gen.test signal_receive.gen.test \
+	signal_receive--pidns-translation.gen.test signalfd4.gen.test \
 	sigpending.gen.test sigprocmask.gen.test sigreturn.gen.test \
 	sigsuspend.gen.test so_error.gen.test so_linger.gen.test \
 	so_peercred.gen.test so_peercred-Xabbrev.gen.test \
 	so_peercred-Xraw.gen.test so_peercred-Xverbose.gen.test \
-	sock_filter-v.gen.test sock_filter-v-Xabbrev.gen.test \
-	sock_filter-v-Xraw.gen.test sock_filter-v-Xverbose.gen.test \
-	sockaddr_xlat-Xabbrev.gen.test sockaddr_xlat-Xraw.gen.test \
-	sockaddr_xlat-Xverbose.gen.test socketcall.gen.test \
-	sockopt-sol_netlink.gen.test sockopt-timestamp.gen.test \
-	splice.gen.test stat.gen.test stat64.gen.test statfs.gen.test \
-	statfs64.gen.test status-all.gen.test status-failed.gen.test \
+	so_peercred--pidns-translation.gen.test sock_filter-v.gen.test \
+	sock_filter-v-Xabbrev.gen.test sock_filter-v-Xraw.gen.test \
+	sock_filter-v-Xverbose.gen.test sockaddr_xlat-Xabbrev.gen.test \
+	sockaddr_xlat-Xraw.gen.test sockaddr_xlat-Xverbose.gen.test \
+	socketcall.gen.test sockopt-sol_netlink.gen.test \
+	sockopt-timestamp.gen.test splice.gen.test stat.gen.test \
+	stat64.gen.test statfs.gen.test statfs64.gen.test \
+	status-all.gen.test status-failed.gen.test \
+	status-failed-long.gen.test status-failed-status.gen.test \
 	status-none.gen.test status-successful.gen.test \
-	status-unfinished.gen.test statx.gen.test swap.gen.test \
+	status-successful-long.gen.test \
+	status-successful-status.gen.test status-unfinished.gen.test \
+	statx.gen.test strace--absolute-timestamps.gen.test \
+	strace--absolute-timestamps-format-time.gen.test \
+	strace--absolute-timestamps-format-time-precision-s.gen.test \
+	strace--absolute-timestamps-format-time-precision-ms.gen.test \
+	strace--absolute-timestamps-format-time-precision-us.gen.test \
+	strace--absolute-timestamps-format-time-precision-ns.gen.test \
+	strace--absolute-timestamps-format-unix-precision-s.gen.test \
+	strace--absolute-timestamps-format-unix-precision-ms.gen.test \
+	strace--absolute-timestamps-format-unix-precision-us.gen.test \
+	strace--absolute-timestamps-format-unix-precision-ns.gen.test \
+	strace--follow-forks-output-separately.gen.test \
+	strace--relative-timestamps.gen.test \
+	strace--relative-timestamps-s.gen.test \
+	strace--relative-timestamps-ms.gen.test \
+	strace--relative-timestamps-us.gen.test \
+	strace--relative-timestamps-ns.gen.test \
+	strace--syscall-times.gen.test \
+	strace--syscall-times-s.gen.test \
+	strace--syscall-times-ms.gen.test \
+	strace--syscall-times-us.gen.test \
+	strace--syscall-times-ns.gen.test \
+	strace--strings-in-hex.gen.test \
+	strace--strings-in-hex-all.gen.test \
+	strace--strings-in-hex-non-ascii.gen.test \
+	strace--timestamps.gen.test strace--timestamps-time.gen.test \
+	strace--timestamps-time-s.gen.test \
+	strace--timestamps-time-ms.gen.test \
+	strace--timestamps-time-us.gen.test \
+	strace--timestamps-time-ns.gen.test \
+	strace--timestamps-unix-s.gen.test \
+	strace--timestamps-unix-ms.gen.test \
+	strace--timestamps-unix-us.gen.test \
+	strace--timestamps-unix-ns.gen.test strace-n.gen.test \
+	strace-x.gen.test strace-xx.gen.test swap.gen.test \
 	sxetmask.gen.test symlink.gen.test symlinkat.gen.test \
 	sync.gen.test sync_file_range.gen.test \
 	sync_file_range2.gen.test sysinfo.gen.test syslog.gen.test \
-	tee.gen.test time.gen.test timer_create.gen.test \
-	timer_xettime.gen.test timerfd_xettime.gen.test times.gen.test \
-	times-fail.gen.test trace_creds.gen.test trace_fstat.gen.test \
+	tee.gen.test tgkill.gen.test \
+	tgkill--pidns-translation.gen.test \
+	threads-execve--quiet-thread-execve.gen.test \
+	threads-execve-q.gen.test threads-execve-qq.gen.test \
+	threads-execve-qqq.gen.test time.gen.test \
+	timer_create.gen.test timer_xettime.gen.test \
+	timerfd_xettime.gen.test times.gen.test times-fail.gen.test \
+	tkill.gen.test tkill--pidns-translation.gen.test \
+	trace_clock.gen.test trace_creds.gen.test trace_fstat.gen.test \
 	trace_fstatfs.gen.test trace_lstat.gen.test \
 	trace_personality_32.gen.test trace_personality_64.gen.test \
 	trace_personality_regex_32.gen.test \
@@ -5342,22 +6590,27 @@ GEN_TESTS = _newselect.gen.test _newsele
 	trace_personality_x32.gen.test trace_question.gen.test \
 	trace_stat.gen.test trace_stat_like.gen.test \
 	trace_statfs.gen.test trace_statfs_like.gen.test \
-	truncate.gen.test truncate64.gen.test ugetrlimit.gen.test \
-	umask.gen.test umoven-illptr.gen.test umovestr-illptr.gen.test \
-	umovestr3.gen.test unlink.gen.test unlinkat.gen.test \
-	unshare.gen.test userfaultfd.gen.test ustat.gen.test \
-	utime.gen.test utimensat.gen.test utimensat-Xabbrev.gen.test \
-	utimensat-Xraw.gen.test utimensat-Xverbose.gen.test \
-	utimes.gen.test vfork-f.gen.test vhangup.gen.test \
-	vmsplice.gen.test wait4.gen.test wait4-v.gen.test \
-	waitid.gen.test waitid-v.gen.test waitpid.gen.test \
-	xattr.gen.test xattr-strings.gen.test xet_robust_list.gen.test \
-	xetitimer.gen.test xetpgid.gen.test xetpriority.gen.test \
+	trie_test.gen.test truncate.gen.test truncate64.gen.test \
+	ugetrlimit.gen.test umask.gen.test umoven-illptr.gen.test \
+	umovestr-illptr.gen.test umovestr3.gen.test \
+	umovestr_cached_adjacent.gen.test unlink.gen.test \
+	unlinkat.gen.test unshare.gen.test userfaultfd.gen.test \
+	ustat.gen.test utime.gen.test utimensat.gen.test \
+	utimensat-Xabbrev.gen.test utimensat-Xraw.gen.test \
+	utimensat-Xverbose.gen.test utimes.gen.test vfork-f.gen.test \
+	vhangup.gen.test vmsplice.gen.test wait4.gen.test \
+	wait4-v.gen.test waitid.gen.test waitid-v.gen.test \
+	waitpid.gen.test xattr.gen.test xattr-strings.gen.test \
+	xet_robust_list.gen.test \
+	xet_robust_list--pidns-translation.gen.test xetitimer.gen.test \
+	xetpgid.gen.test xetpgid--pidns-translation.gen.test \
+	xetpriority.gen.test xetpriority--pidns-translation.gen.test \
 	xettimeofday.gen.test
 @ENABLE_STACKTRACE_FALSE@STACKTRACE_TESTS = 
 @ENABLE_STACKTRACE_TRUE@STACKTRACE_TESTS = strace-k.test \
 @ENABLE_STACKTRACE_TRUE@	strace-k-p.test $(am__append_1)
 DECODER_TESTS = \
+	bpf-success-long-y.test \
 	bpf-success-v.test \
 	bpf-success.test \
 	brk.test \
@@ -5376,13 +6629,15 @@ DECODER_TESTS = \
 	execve-v.test \
 	execve.test \
 	fadvise64.test \
+	faccessat.test \
+	faccessat2.test \
 	futex.test \
 	getuid.test \
 	int_0x80.test \
 	inotify_init-y.test \
 	ioctl.test \
+	ioctl_block--pidns-translation.test \
 	ioctl_evdev-success.test \
-	ioctl_perf-success.test \
 	ipc_msgbuf.test \
 	kern_features-fault.test \
 	llseek.test \
@@ -5440,7 +6695,6 @@ MISC_TESTS = \
 	attach-f-p.test \
 	attach-p-cmd.test \
 	bexecve.test \
-	clone_parent.test \
 	clone_ptrace.test \
 	count-f.test \
 	count.test \
@@ -5454,15 +6708,19 @@ MISC_TESTS = \
 	filtering_fd-syntax.test \
 	filtering_syscall-syntax.test \
 	first_exec_failure.test \
+	fork--pidns-translation.test \
 	get_regs.test \
+	gettid--pidns-translation.test \
 	inject-nf.test \
 	interactive_block.test \
 	kill_child.test \
 	localtime.test \
 	looping_threads.test \
+	netlink_audit--pidns-translation.test \
 	opipe.test \
 	options-syntax.test \
 	pc.test \
+	pidns-cache.test \
 	printpath-umovestr-legacy.test \
 	printstrn-umoven-legacy.test \
 	qual_fault-syntax.test \
@@ -5490,6 +6748,8 @@ MISC_TESTS = \
 	strace-DD.test \
 	strace-DDD.test \
 	strace-E.test \
+	strace-E-override.test \
+	strace-E-unset.test \
 	strace-S.test \
 	strace-T.test \
 	strace-V.test \
@@ -5533,6 +6793,7 @@ EXTRA_DIST = \
 	filter_seccomp.in \
 	filter_seccomp.sh \
 	filter-unavailable.expected \
+	fork--pidns-translation.awk \
 	fstatat.c \
 	fstatx.c \
 	gen_pure_executables.sh \
@@ -5541,6 +6802,7 @@ EXTRA_DIST = \
 	getresugid.c \
 	init.sh \
 	init_delete_module.h \
+	ioctl-success.sh \
 	ioctl_kvm_run_common.c \
 	ipc.sh \
 	kernel_old_timespec.h \
@@ -5549,7 +6811,6 @@ EXTRA_DIST = \
 	lstatx.c \
 	match.awk \
 	net.expected \
-	netlink_sock_diag-v.sh \
 	nlattr_ifla.h \
 	pipe.expected \
 	print_user_desc.c \
@@ -5578,11 +6839,22 @@ EXTRA_DIST = \
 	sockname.c \
 	stack-fcall.h \
 	status-detached.expected \
+	strace--follow-forks-output-separately.expected \
+	strace--relative-timestamps.expected \
+	strace--relative-timestamps-s.expected \
+	strace--relative-timestamps-ms.expected \
+	strace--relative-timestamps-us.expected \
+	strace--relative-timestamps-ns.expected \
+	strace--syscall-times.expected \
+	strace--syscall-times-s.expected \
+	strace--syscall-times-ms.expected \
+	strace--syscall-times-us.expected \
+	strace--syscall-times-ns.expected \
 	strace-C.expected \
 	strace-D.expected \
-	strace-DD.expected \
 	strace-DDD.expected \
 	strace-E.expected \
+	strace-E-unset.expected \
 	strace-T.expected \
 	strace-ff.expected \
 	strace-k-demangle.expected \
@@ -5595,6 +6867,7 @@ EXTRA_DIST = \
 	strace.supp \
 	sun_path.expected \
 	syntax.sh \
+	trace_clock.in \
 	trace_creds.in \
 	trace_fstat.in \
 	trace_fstatfs.in \
@@ -5616,6 +6889,7 @@ EXTRA_DIST = \
 	unix-pair-send-recv.expected \
 	unix-pair-sendto-recvfrom.expected \
 	xchownx.c \
+	xgetdents.c \
 	xgetrlimit.c \
 	xselect.c \
 	xstatfs.c \
@@ -5777,6 +7051,10 @@ bpf-success$(EXEEXT): $(bpf_success_OBJE
 	@rm -f bpf-success$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(bpf_success_OBJECTS) $(bpf_success_LDADD) $(LIBS)
 
+bpf-success-long-y$(EXEEXT): $(bpf_success_long_y_OBJECTS) $(bpf_success_long_y_DEPENDENCIES) $(EXTRA_bpf_success_long_y_DEPENDENCIES) 
+	@rm -f bpf-success-long-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(bpf_success_long_y_OBJECTS) $(bpf_success_long_y_LDADD) $(LIBS)
+
 bpf-success-v$(EXEEXT): $(bpf_success_v_OBJECTS) $(bpf_success_v_DEPENDENCIES) $(EXTRA_bpf_success_v_DEPENDENCIES) 
 	@rm -f bpf-success-v$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(bpf_success_v_OBJECTS) $(bpf_success_v_LDADD) $(LIBS)
@@ -5877,10 +7155,54 @@ clone_parent$(EXEEXT): $(clone_parent_OB
 	@rm -f clone_parent$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(clone_parent_OBJECTS) $(clone_parent_LDADD) $(LIBS)
 
+clone_parent--quiet-exit$(EXEEXT): $(clone_parent__quiet_exit_OBJECTS) $(clone_parent__quiet_exit_DEPENDENCIES) $(EXTRA_clone_parent__quiet_exit_DEPENDENCIES) 
+	@rm -f clone_parent--quiet-exit$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(clone_parent__quiet_exit_OBJECTS) $(clone_parent__quiet_exit_LDADD) $(LIBS)
+
+clone_parent-q$(EXEEXT): $(clone_parent_q_OBJECTS) $(clone_parent_q_DEPENDENCIES) $(EXTRA_clone_parent_q_DEPENDENCIES) 
+	@rm -f clone_parent-q$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(clone_parent_q_OBJECTS) $(clone_parent_q_LDADD) $(LIBS)
+
+clone_parent-qq$(EXEEXT): $(clone_parent_qq_OBJECTS) $(clone_parent_qq_DEPENDENCIES) $(EXTRA_clone_parent_qq_DEPENDENCIES) 
+	@rm -f clone_parent-qq$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(clone_parent_qq_OBJECTS) $(clone_parent_qq_LDADD) $(LIBS)
+
 clone_ptrace$(EXEEXT): $(clone_ptrace_OBJECTS) $(clone_ptrace_DEPENDENCIES) $(EXTRA_clone_ptrace_DEPENDENCIES) 
 	@rm -f clone_ptrace$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(clone_ptrace_OBJECTS) $(clone_ptrace_LDADD) $(LIBS)
 
+clone_ptrace--quiet-attach$(EXEEXT): $(clone_ptrace__quiet_attach_OBJECTS) $(clone_ptrace__quiet_attach_DEPENDENCIES) $(EXTRA_clone_ptrace__quiet_attach_DEPENDENCIES) 
+	@rm -f clone_ptrace--quiet-attach$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(clone_ptrace__quiet_attach_OBJECTS) $(clone_ptrace__quiet_attach_LDADD) $(LIBS)
+
+clone_ptrace--quiet-exit$(EXEEXT): $(clone_ptrace__quiet_exit_OBJECTS) $(clone_ptrace__quiet_exit_DEPENDENCIES) $(EXTRA_clone_ptrace__quiet_exit_DEPENDENCIES) 
+	@rm -f clone_ptrace--quiet-exit$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(clone_ptrace__quiet_exit_OBJECTS) $(clone_ptrace__quiet_exit_LDADD) $(LIBS)
+
+clone_ptrace-q$(EXEEXT): $(clone_ptrace_q_OBJECTS) $(clone_ptrace_q_DEPENDENCIES) $(EXTRA_clone_ptrace_q_DEPENDENCIES) 
+	@rm -f clone_ptrace-q$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(clone_ptrace_q_OBJECTS) $(clone_ptrace_q_LDADD) $(LIBS)
+
+clone_ptrace-qq$(EXEEXT): $(clone_ptrace_qq_OBJECTS) $(clone_ptrace_qq_DEPENDENCIES) $(EXTRA_clone_ptrace_qq_DEPENDENCIES) 
+	@rm -f clone_ptrace-qq$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(clone_ptrace_qq_OBJECTS) $(clone_ptrace_qq_LDADD) $(LIBS)
+
+close_range$(EXEEXT): $(close_range_OBJECTS) $(close_range_DEPENDENCIES) $(EXTRA_close_range_DEPENDENCIES) 
+	@rm -f close_range$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(close_range_OBJECTS) $(close_range_LDADD) $(LIBS)
+
+close_range-P$(EXEEXT): $(close_range_P_OBJECTS) $(close_range_P_DEPENDENCIES) $(EXTRA_close_range_P_DEPENDENCIES) 
+	@rm -f close_range-P$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(close_range_P_OBJECTS) $(close_range_P_LDADD) $(LIBS)
+
+close_range-y$(EXEEXT): $(close_range_y_OBJECTS) $(close_range_y_DEPENDENCIES) $(EXTRA_close_range_y_DEPENDENCIES) 
+	@rm -f close_range-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(close_range_y_OBJECTS) $(close_range_y_LDADD) $(LIBS)
+
+close_range-yy$(EXEEXT): $(close_range_yy_OBJECTS) $(close_range_yy_DEPENDENCIES) $(EXTRA_close_range_yy_DEPENDENCIES) 
+	@rm -f close_range-yy$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(close_range_yy_OBJECTS) $(close_range_yy_LDADD) $(LIBS)
+
 copy_file_range$(EXEEXT): $(copy_file_range_OBJECTS) $(copy_file_range_DEPENDENCIES) $(EXTRA_copy_file_range_DEPENDENCIES) 
 	@rm -f copy_file_range$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(copy_file_range_OBJECTS) $(copy_file_range_LDADD) $(LIBS)
@@ -5901,6 +7223,18 @@ delete_module$(EXEEXT): $(delete_module_
 	@rm -f delete_module$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(delete_module_OBJECTS) $(delete_module_LDADD) $(LIBS)
 
+dev--decode-fds-dev$(EXEEXT): $(dev__decode_fds_dev_OBJECTS) $(dev__decode_fds_dev_DEPENDENCIES) $(EXTRA_dev__decode_fds_dev_DEPENDENCIES) 
+	@rm -f dev--decode-fds-dev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dev__decode_fds_dev_OBJECTS) $(dev__decode_fds_dev_LDADD) $(LIBS)
+
+dev--decode-fds-path$(EXEEXT): $(dev__decode_fds_path_OBJECTS) $(dev__decode_fds_path_DEPENDENCIES) $(EXTRA_dev__decode_fds_path_DEPENDENCIES) 
+	@rm -f dev--decode-fds-path$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dev__decode_fds_path_OBJECTS) $(dev__decode_fds_path_LDADD) $(LIBS)
+
+dev--decode-fds-socket$(EXEEXT): $(dev__decode_fds_socket_OBJECTS) $(dev__decode_fds_socket_DEPENDENCIES) $(EXTRA_dev__decode_fds_socket_DEPENDENCIES) 
+	@rm -f dev--decode-fds-socket$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dev__decode_fds_socket_OBJECTS) $(dev__decode_fds_socket_LDADD) $(LIBS)
+
 dev-yy$(EXEEXT): $(dev_yy_OBJECTS) $(dev_yy_DEPENDENCIES) $(EXTRA_dev_yy_DEPENDENCIES) 
 	@rm -f dev-yy$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(dev_yy_OBJECTS) $(dev_yy_LDADD) $(LIBS)
@@ -5909,14 +7243,50 @@ dup$(EXEEXT): $(dup_OBJECTS) $(dup_DEPEN
 	@rm -f dup$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(dup_OBJECTS) $(dup_LDADD) $(LIBS)
 
+dup-P$(EXEEXT): $(dup_P_OBJECTS) $(dup_P_DEPENDENCIES) $(EXTRA_dup_P_DEPENDENCIES) 
+	@rm -f dup-P$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup_P_OBJECTS) $(dup_P_LDADD) $(LIBS)
+
+dup-y$(EXEEXT): $(dup_y_OBJECTS) $(dup_y_DEPENDENCIES) $(EXTRA_dup_y_DEPENDENCIES) 
+	@rm -f dup-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup_y_OBJECTS) $(dup_y_LDADD) $(LIBS)
+
+dup-yy$(EXEEXT): $(dup_yy_OBJECTS) $(dup_yy_DEPENDENCIES) $(EXTRA_dup_yy_DEPENDENCIES) 
+	@rm -f dup-yy$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup_yy_OBJECTS) $(dup_yy_LDADD) $(LIBS)
+
 dup2$(EXEEXT): $(dup2_OBJECTS) $(dup2_DEPENDENCIES) $(EXTRA_dup2_DEPENDENCIES) 
 	@rm -f dup2$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(dup2_OBJECTS) $(dup2_LDADD) $(LIBS)
 
+dup2-P$(EXEEXT): $(dup2_P_OBJECTS) $(dup2_P_DEPENDENCIES) $(EXTRA_dup2_P_DEPENDENCIES) 
+	@rm -f dup2-P$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup2_P_OBJECTS) $(dup2_P_LDADD) $(LIBS)
+
+dup2-y$(EXEEXT): $(dup2_y_OBJECTS) $(dup2_y_DEPENDENCIES) $(EXTRA_dup2_y_DEPENDENCIES) 
+	@rm -f dup2-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup2_y_OBJECTS) $(dup2_y_LDADD) $(LIBS)
+
+dup2-yy$(EXEEXT): $(dup2_yy_OBJECTS) $(dup2_yy_DEPENDENCIES) $(EXTRA_dup2_yy_DEPENDENCIES) 
+	@rm -f dup2-yy$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup2_yy_OBJECTS) $(dup2_yy_LDADD) $(LIBS)
+
 dup3$(EXEEXT): $(dup3_OBJECTS) $(dup3_DEPENDENCIES) $(EXTRA_dup3_DEPENDENCIES) 
 	@rm -f dup3$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(dup3_OBJECTS) $(dup3_LDADD) $(LIBS)
 
+dup3-P$(EXEEXT): $(dup3_P_OBJECTS) $(dup3_P_DEPENDENCIES) $(EXTRA_dup3_P_DEPENDENCIES) 
+	@rm -f dup3-P$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup3_P_OBJECTS) $(dup3_P_LDADD) $(LIBS)
+
+dup3-y$(EXEEXT): $(dup3_y_OBJECTS) $(dup3_y_DEPENDENCIES) $(EXTRA_dup3_y_DEPENDENCIES) 
+	@rm -f dup3-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup3_y_OBJECTS) $(dup3_y_LDADD) $(LIBS)
+
+dup3-yy$(EXEEXT): $(dup3_yy_OBJECTS) $(dup3_yy_DEPENDENCIES) $(EXTRA_dup3_yy_DEPENDENCIES) 
+	@rm -f dup3-yy$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(dup3_yy_OBJECTS) $(dup3_yy_LDADD) $(LIBS)
+
 epoll_create$(EXEEXT): $(epoll_create_OBJECTS) $(epoll_create_DEPENDENCIES) $(EXTRA_epoll_create_DEPENDENCIES) 
 	@rm -f epoll_create$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(epoll_create_OBJECTS) $(epoll_create_LDADD) $(LIBS)
@@ -5965,6 +7335,34 @@ faccessat$(EXEEXT): $(faccessat_OBJECTS)
 	@rm -f faccessat$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(faccessat_OBJECTS) $(faccessat_LDADD) $(LIBS)
 
+faccessat-P$(EXEEXT): $(faccessat_P_OBJECTS) $(faccessat_P_DEPENDENCIES) $(EXTRA_faccessat_P_DEPENDENCIES) 
+	@rm -f faccessat-P$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(faccessat_P_OBJECTS) $(faccessat_P_LDADD) $(LIBS)
+
+faccessat-y$(EXEEXT): $(faccessat_y_OBJECTS) $(faccessat_y_DEPENDENCIES) $(EXTRA_faccessat_y_DEPENDENCIES) 
+	@rm -f faccessat-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(faccessat_y_OBJECTS) $(faccessat_y_LDADD) $(LIBS)
+
+faccessat-yy$(EXEEXT): $(faccessat_yy_OBJECTS) $(faccessat_yy_DEPENDENCIES) $(EXTRA_faccessat_yy_DEPENDENCIES) 
+	@rm -f faccessat-yy$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(faccessat_yy_OBJECTS) $(faccessat_yy_LDADD) $(LIBS)
+
+faccessat2$(EXEEXT): $(faccessat2_OBJECTS) $(faccessat2_DEPENDENCIES) $(EXTRA_faccessat2_DEPENDENCIES) 
+	@rm -f faccessat2$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(faccessat2_OBJECTS) $(faccessat2_LDADD) $(LIBS)
+
+faccessat2-P$(EXEEXT): $(faccessat2_P_OBJECTS) $(faccessat2_P_DEPENDENCIES) $(EXTRA_faccessat2_P_DEPENDENCIES) 
+	@rm -f faccessat2-P$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(faccessat2_P_OBJECTS) $(faccessat2_P_LDADD) $(LIBS)
+
+faccessat2-y$(EXEEXT): $(faccessat2_y_OBJECTS) $(faccessat2_y_DEPENDENCIES) $(EXTRA_faccessat2_y_DEPENDENCIES) 
+	@rm -f faccessat2-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(faccessat2_y_OBJECTS) $(faccessat2_y_LDADD) $(LIBS)
+
+faccessat2-yy$(EXEEXT): $(faccessat2_yy_OBJECTS) $(faccessat2_yy_DEPENDENCIES) $(EXTRA_faccessat2_yy_DEPENDENCIES) 
+	@rm -f faccessat2-yy$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(faccessat2_yy_OBJECTS) $(faccessat2_yy_LDADD) $(LIBS)
+
 fadvise64$(EXEEXT): $(fadvise64_OBJECTS) $(fadvise64_DEPENDENCIES) $(EXTRA_fadvise64_DEPENDENCIES) 
 	@rm -f fadvise64$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(fadvise64_OBJECTS) $(fadvise64_LDADD) $(LIBS)
@@ -6025,10 +7423,18 @@ fcntl$(EXEEXT): $(fcntl_OBJECTS) $(fcntl
 	@rm -f fcntl$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(fcntl_OBJECTS) $(fcntl_LDADD) $(LIBS)
 
+fcntl--pidns-translation$(EXEEXT): $(fcntl__pidns_translation_OBJECTS) $(fcntl__pidns_translation_DEPENDENCIES) $(EXTRA_fcntl__pidns_translation_DEPENDENCIES) 
+	@rm -f fcntl--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(fcntl__pidns_translation_OBJECTS) $(fcntl__pidns_translation_LDADD) $(LIBS)
+
 fcntl64$(EXEEXT): $(fcntl64_OBJECTS) $(fcntl64_DEPENDENCIES) $(EXTRA_fcntl64_DEPENDENCIES) 
 	@rm -f fcntl64$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(fcntl64_OBJECTS) $(fcntl64_LDADD) $(LIBS)
 
+fcntl64--pidns-translation$(EXEEXT): $(fcntl64__pidns_translation_OBJECTS) $(fcntl64__pidns_translation_DEPENDENCIES) $(EXTRA_fcntl64__pidns_translation_DEPENDENCIES) 
+	@rm -f fcntl64--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(fcntl64__pidns_translation_OBJECTS) $(fcntl64__pidns_translation_LDADD) $(LIBS)
+
 fdatasync$(EXEEXT): $(fdatasync_OBJECTS) $(fdatasync_DEPENDENCIES) $(EXTRA_fdatasync_DEPENDENCIES) 
 	@rm -f fdatasync$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(fdatasync_OBJECTS) $(fdatasync_LDADD) $(LIBS)
@@ -6065,6 +7471,10 @@ flock$(EXEEXT): $(flock_OBJECTS) $(flock
 	@rm -f flock$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(flock_OBJECTS) $(flock_LDADD) $(LIBS)
 
+fork--pidns-translation$(EXEEXT): $(fork__pidns_translation_OBJECTS) $(fork__pidns_translation_DEPENDENCIES) $(EXTRA_fork__pidns_translation_DEPENDENCIES) 
+	@rm -f fork--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(fork__pidns_translation_OBJECTS) $(fork__pidns_translation_LDADD) $(LIBS)
+
 fork-f$(EXEEXT): $(fork_f_OBJECTS) $(fork_f_DEPENDENCIES) $(EXTRA_fork_f_DEPENDENCIES) 
 	@rm -f fork-f$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(fork_f_OBJECTS) $(fork_f_LDADD) $(LIBS)
@@ -6165,6 +7575,10 @@ get_mempolicy$(EXEEXT): $(get_mempolicy_
 	@rm -f get_mempolicy$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(get_mempolicy_OBJECTS) $(get_mempolicy_LDADD) $(LIBS)
 
+get_process_reaper$(EXEEXT): $(get_process_reaper_OBJECTS) $(get_process_reaper_DEPENDENCIES) $(EXTRA_get_process_reaper_DEPENDENCIES) 
+	@rm -f get_process_reaper$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(get_process_reaper_OBJECTS) $(get_process_reaper_LDADD) $(LIBS)
+
 getcpu$(EXEEXT): $(getcpu_OBJECTS) $(getcpu_DEPENDENCIES) $(EXTRA_getcpu_DEPENDENCIES) 
 	@rm -f getcpu$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getcpu_OBJECTS) $(getcpu_LDADD) $(LIBS)
@@ -6177,10 +7591,18 @@ getdents$(EXEEXT): $(getdents_OBJECTS) $
 	@rm -f getdents$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getdents_OBJECTS) $(getdents_LDADD) $(LIBS)
 
+getdents-v$(EXEEXT): $(getdents_v_OBJECTS) $(getdents_v_DEPENDENCIES) $(EXTRA_getdents_v_DEPENDENCIES) 
+	@rm -f getdents-v$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(getdents_v_OBJECTS) $(getdents_v_LDADD) $(LIBS)
+
 getdents64$(EXEEXT): $(getdents64_OBJECTS) $(getdents64_DEPENDENCIES) $(EXTRA_getdents64_DEPENDENCIES) 
 	@rm -f getdents64$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getdents64_OBJECTS) $(getdents64_LDADD) $(LIBS)
 
+getdents64-v$(EXEEXT): $(getdents64_v_OBJECTS) $(getdents64_v_DEPENDENCIES) $(EXTRA_getdents64_v_DEPENDENCIES) 
+	@rm -f getdents64-v$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(getdents64_v_OBJECTS) $(getdents64_v_LDADD) $(LIBS)
+
 getegid$(EXEEXT): $(getegid_OBJECTS) $(getegid_DEPENDENCIES) $(EXTRA_getegid_DEPENDENCIES) 
 	@rm -f getegid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getegid_OBJECTS) $(getegid_LDADD) $(LIBS)
@@ -6221,10 +7643,18 @@ getpgrp$(EXEEXT): $(getpgrp_OBJECTS) $(g
 	@rm -f getpgrp$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getpgrp_OBJECTS) $(getpgrp_LDADD) $(LIBS)
 
+getpgrp--pidns-translation$(EXEEXT): $(getpgrp__pidns_translation_OBJECTS) $(getpgrp__pidns_translation_DEPENDENCIES) $(EXTRA_getpgrp__pidns_translation_DEPENDENCIES) 
+	@rm -f getpgrp--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(getpgrp__pidns_translation_OBJECTS) $(getpgrp__pidns_translation_LDADD) $(LIBS)
+
 getpid$(EXEEXT): $(getpid_OBJECTS) $(getpid_DEPENDENCIES) $(EXTRA_getpid_DEPENDENCIES) 
 	@rm -f getpid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getpid_OBJECTS) $(getpid_LDADD) $(LIBS)
 
+getpid--pidns-translation$(EXEEXT): $(getpid__pidns_translation_OBJECTS) $(getpid__pidns_translation_DEPENDENCIES) $(EXTRA_getpid__pidns_translation_DEPENDENCIES) 
+	@rm -f getpid--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(getpid__pidns_translation_OBJECTS) $(getpid__pidns_translation_LDADD) $(LIBS)
+
 getppid$(EXEEXT): $(getppid_OBJECTS) $(getppid_DEPENDENCIES) $(EXTRA_getppid_DEPENDENCIES) 
 	@rm -f getppid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getppid_OBJECTS) $(getppid_LDADD) $(LIBS)
@@ -6261,6 +7691,10 @@ getsid$(EXEEXT): $(getsid_OBJECTS) $(get
 	@rm -f getsid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getsid_OBJECTS) $(getsid_LDADD) $(LIBS)
 
+getsid--pidns-translation$(EXEEXT): $(getsid__pidns_translation_OBJECTS) $(getsid__pidns_translation_DEPENDENCIES) $(EXTRA_getsid__pidns_translation_DEPENDENCIES) 
+	@rm -f getsid--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(getsid__pidns_translation_OBJECTS) $(getsid__pidns_translation_LDADD) $(LIBS)
+
 getsockname$(EXEEXT): $(getsockname_OBJECTS) $(getsockname_DEPENDENCIES) $(EXTRA_getsockname_DEPENDENCIES) 
 	@rm -f getsockname$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getsockname_OBJECTS) $(getsockname_LDADD) $(LIBS)
@@ -6269,6 +7703,10 @@ gettid$(EXEEXT): $(gettid_OBJECTS) $(get
 	@rm -f gettid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(gettid_OBJECTS) $(gettid_LDADD) $(LIBS)
 
+gettid--pidns-translation$(EXEEXT): $(gettid__pidns_translation_OBJECTS) $(gettid__pidns_translation_DEPENDENCIES) $(EXTRA_gettid__pidns_translation_DEPENDENCIES) 
+	@rm -f gettid--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(gettid__pidns_translation_OBJECTS) $(gettid__pidns_translation_LDADD) $(LIBS)
+
 getuid$(EXEEXT): $(getuid_OBJECTS) $(getuid_DEPENDENCIES) $(EXTRA_getuid_DEPENDENCIES) 
 	@rm -f getuid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getuid_OBJECTS) $(getuid_LDADD) $(LIBS)
@@ -6277,9 +7715,17 @@ getuid32$(EXEEXT): $(getuid32_OBJECTS) $
 	@rm -f getuid32$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(getuid32_OBJECTS) $(getuid32_LDADD) $(LIBS)
 
-getxxid$(EXEEXT): $(getxxid_OBJECTS) $(getxxid_DEPENDENCIES) $(EXTRA_getxxid_DEPENDENCIES) 
-	@rm -f getxxid$(EXEEXT)
-	$(AM_V_CCLD)$(LINK) $(getxxid_OBJECTS) $(getxxid_LDADD) $(LIBS)
+getxgid$(EXEEXT): $(getxgid_OBJECTS) $(getxgid_DEPENDENCIES) $(EXTRA_getxgid_DEPENDENCIES) 
+	@rm -f getxgid$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(getxgid_OBJECTS) $(getxgid_LDADD) $(LIBS)
+
+getxpid$(EXEEXT): $(getxpid_OBJECTS) $(getxpid_DEPENDENCIES) $(EXTRA_getxpid_DEPENDENCIES) 
+	@rm -f getxpid$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(getxpid_OBJECTS) $(getxpid_LDADD) $(LIBS)
+
+getxuid$(EXEEXT): $(getxuid_OBJECTS) $(getxuid_DEPENDENCIES) $(EXTRA_getxuid_DEPENDENCIES) 
+	@rm -f getxuid$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(getxuid_OBJECTS) $(getxuid_LDADD) $(LIBS)
 
 group_req$(EXEEXT): $(group_req_OBJECTS) $(group_req_DEPENDENCIES) $(EXTRA_group_req_DEPENDENCIES) 
 	@rm -f group_req$(EXEEXT)
@@ -6341,6 +7787,10 @@ ioctl_block$(EXEEXT): $(ioctl_block_OBJE
 	@rm -f ioctl_block$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioctl_block_OBJECTS) $(ioctl_block_LDADD) $(LIBS)
 
+ioctl_block--pidns-translation$(EXEEXT): $(ioctl_block__pidns_translation_OBJECTS) $(ioctl_block__pidns_translation_DEPENDENCIES) $(EXTRA_ioctl_block__pidns_translation_DEPENDENCIES) 
+	@rm -f ioctl_block--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_block__pidns_translation_OBJECTS) $(ioctl_block__pidns_translation_LDADD) $(LIBS)
+
 ioctl_dm$(EXEEXT): $(ioctl_dm_OBJECTS) $(ioctl_dm_DEPENDENCIES) $(EXTRA_ioctl_dm_DEPENDENCIES) 
 	@rm -f ioctl_dm$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioctl_dm_OBJECTS) $(ioctl_dm_LDADD) $(LIBS)
@@ -6413,6 +7863,70 @@ ioctl_evdev-v-Xverbose$(EXEEXT): $(ioctl
 	@rm -f ioctl_evdev-v-Xverbose$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioctl_evdev_v_Xverbose_OBJECTS) $(ioctl_evdev_v_Xverbose_LDADD) $(LIBS)
 
+ioctl_hdio$(EXEEXT): $(ioctl_hdio_OBJECTS) $(ioctl_hdio_DEPENDENCIES) $(EXTRA_ioctl_hdio_DEPENDENCIES) 
+	@rm -f ioctl_hdio$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_OBJECTS) $(ioctl_hdio_LDADD) $(LIBS)
+
+ioctl_hdio-Xabbrev$(EXEEXT): $(ioctl_hdio_Xabbrev_OBJECTS) $(ioctl_hdio_Xabbrev_DEPENDENCIES) $(EXTRA_ioctl_hdio_Xabbrev_DEPENDENCIES) 
+	@rm -f ioctl_hdio-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_Xabbrev_OBJECTS) $(ioctl_hdio_Xabbrev_LDADD) $(LIBS)
+
+ioctl_hdio-Xraw$(EXEEXT): $(ioctl_hdio_Xraw_OBJECTS) $(ioctl_hdio_Xraw_DEPENDENCIES) $(EXTRA_ioctl_hdio_Xraw_DEPENDENCIES) 
+	@rm -f ioctl_hdio-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_Xraw_OBJECTS) $(ioctl_hdio_Xraw_LDADD) $(LIBS)
+
+ioctl_hdio-Xverbose$(EXEEXT): $(ioctl_hdio_Xverbose_OBJECTS) $(ioctl_hdio_Xverbose_DEPENDENCIES) $(EXTRA_ioctl_hdio_Xverbose_DEPENDENCIES) 
+	@rm -f ioctl_hdio-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_Xverbose_OBJECTS) $(ioctl_hdio_Xverbose_LDADD) $(LIBS)
+
+ioctl_hdio-success$(EXEEXT): $(ioctl_hdio_success_OBJECTS) $(ioctl_hdio_success_DEPENDENCIES) $(EXTRA_ioctl_hdio_success_DEPENDENCIES) 
+	@rm -f ioctl_hdio-success$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_success_OBJECTS) $(ioctl_hdio_success_LDADD) $(LIBS)
+
+ioctl_hdio-success-Xabbrev$(EXEEXT): $(ioctl_hdio_success_Xabbrev_OBJECTS) $(ioctl_hdio_success_Xabbrev_DEPENDENCIES) $(EXTRA_ioctl_hdio_success_Xabbrev_DEPENDENCIES) 
+	@rm -f ioctl_hdio-success-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_success_Xabbrev_OBJECTS) $(ioctl_hdio_success_Xabbrev_LDADD) $(LIBS)
+
+ioctl_hdio-success-Xraw$(EXEEXT): $(ioctl_hdio_success_Xraw_OBJECTS) $(ioctl_hdio_success_Xraw_DEPENDENCIES) $(EXTRA_ioctl_hdio_success_Xraw_DEPENDENCIES) 
+	@rm -f ioctl_hdio-success-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_success_Xraw_OBJECTS) $(ioctl_hdio_success_Xraw_LDADD) $(LIBS)
+
+ioctl_hdio-success-Xverbose$(EXEEXT): $(ioctl_hdio_success_Xverbose_OBJECTS) $(ioctl_hdio_success_Xverbose_DEPENDENCIES) $(EXTRA_ioctl_hdio_success_Xverbose_DEPENDENCIES) 
+	@rm -f ioctl_hdio-success-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_success_Xverbose_OBJECTS) $(ioctl_hdio_success_Xverbose_LDADD) $(LIBS)
+
+ioctl_hdio-success-v$(EXEEXT): $(ioctl_hdio_success_v_OBJECTS) $(ioctl_hdio_success_v_DEPENDENCIES) $(EXTRA_ioctl_hdio_success_v_DEPENDENCIES) 
+	@rm -f ioctl_hdio-success-v$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_success_v_OBJECTS) $(ioctl_hdio_success_v_LDADD) $(LIBS)
+
+ioctl_hdio-success-v-Xabbrev$(EXEEXT): $(ioctl_hdio_success_v_Xabbrev_OBJECTS) $(ioctl_hdio_success_v_Xabbrev_DEPENDENCIES) $(EXTRA_ioctl_hdio_success_v_Xabbrev_DEPENDENCIES) 
+	@rm -f ioctl_hdio-success-v-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_success_v_Xabbrev_OBJECTS) $(ioctl_hdio_success_v_Xabbrev_LDADD) $(LIBS)
+
+ioctl_hdio-success-v-Xraw$(EXEEXT): $(ioctl_hdio_success_v_Xraw_OBJECTS) $(ioctl_hdio_success_v_Xraw_DEPENDENCIES) $(EXTRA_ioctl_hdio_success_v_Xraw_DEPENDENCIES) 
+	@rm -f ioctl_hdio-success-v-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_success_v_Xraw_OBJECTS) $(ioctl_hdio_success_v_Xraw_LDADD) $(LIBS)
+
+ioctl_hdio-success-v-Xverbose$(EXEEXT): $(ioctl_hdio_success_v_Xverbose_OBJECTS) $(ioctl_hdio_success_v_Xverbose_DEPENDENCIES) $(EXTRA_ioctl_hdio_success_v_Xverbose_DEPENDENCIES) 
+	@rm -f ioctl_hdio-success-v-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_success_v_Xverbose_OBJECTS) $(ioctl_hdio_success_v_Xverbose_LDADD) $(LIBS)
+
+ioctl_hdio-v$(EXEEXT): $(ioctl_hdio_v_OBJECTS) $(ioctl_hdio_v_DEPENDENCIES) $(EXTRA_ioctl_hdio_v_DEPENDENCIES) 
+	@rm -f ioctl_hdio-v$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_v_OBJECTS) $(ioctl_hdio_v_LDADD) $(LIBS)
+
+ioctl_hdio-v-Xabbrev$(EXEEXT): $(ioctl_hdio_v_Xabbrev_OBJECTS) $(ioctl_hdio_v_Xabbrev_DEPENDENCIES) $(EXTRA_ioctl_hdio_v_Xabbrev_DEPENDENCIES) 
+	@rm -f ioctl_hdio-v-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_v_Xabbrev_OBJECTS) $(ioctl_hdio_v_Xabbrev_LDADD) $(LIBS)
+
+ioctl_hdio-v-Xraw$(EXEEXT): $(ioctl_hdio_v_Xraw_OBJECTS) $(ioctl_hdio_v_Xraw_DEPENDENCIES) $(EXTRA_ioctl_hdio_v_Xraw_DEPENDENCIES) 
+	@rm -f ioctl_hdio-v-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_v_Xraw_OBJECTS) $(ioctl_hdio_v_Xraw_LDADD) $(LIBS)
+
+ioctl_hdio-v-Xverbose$(EXEEXT): $(ioctl_hdio_v_Xverbose_OBJECTS) $(ioctl_hdio_v_Xverbose_DEPENDENCIES) $(EXTRA_ioctl_hdio_v_Xverbose_DEPENDENCIES) 
+	@rm -f ioctl_hdio-v-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_hdio_v_Xverbose_OBJECTS) $(ioctl_hdio_v_Xverbose_LDADD) $(LIBS)
+
 ioctl_inotify$(EXEEXT): $(ioctl_inotify_OBJECTS) $(ioctl_inotify_DEPENDENCIES) $(EXTRA_ioctl_inotify_DEPENDENCIES) 
 	@rm -f ioctl_inotify$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioctl_inotify_OBJECTS) $(ioctl_inotify_LDADD) $(LIBS)
@@ -6493,6 +8007,10 @@ ioctl_sock_gifconf$(EXEEXT): $(ioctl_soc
 	@rm -f ioctl_sock_gifconf$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioctl_sock_gifconf_OBJECTS) $(ioctl_sock_gifconf_LDADD) $(LIBS)
 
+ioctl_tee$(EXEEXT): $(ioctl_tee_OBJECTS) $(ioctl_tee_DEPENDENCIES) $(EXTRA_ioctl_tee_DEPENDENCIES) 
+	@rm -f ioctl_tee$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_tee_OBJECTS) $(ioctl_tee_LDADD) $(LIBS)
+
 ioctl_uffdio$(EXEEXT): $(ioctl_uffdio_OBJECTS) $(ioctl_uffdio_DEPENDENCIES) $(EXTRA_ioctl_uffdio_DEPENDENCIES) 
 	@rm -f ioctl_uffdio$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioctl_uffdio_OBJECTS) $(ioctl_uffdio_LDADD) $(LIBS)
@@ -6501,6 +8019,66 @@ ioctl_v4l2$(EXEEXT): $(ioctl_v4l2_OBJECT
 	@rm -f ioctl_v4l2$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_OBJECTS) $(ioctl_v4l2_LDADD) $(LIBS)
 
+ioctl_v4l2-Xabbrev$(EXEEXT): $(ioctl_v4l2_Xabbrev_OBJECTS) $(ioctl_v4l2_Xabbrev_DEPENDENCIES) $(EXTRA_ioctl_v4l2_Xabbrev_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_Xabbrev_OBJECTS) $(ioctl_v4l2_Xabbrev_LDADD) $(LIBS)
+
+ioctl_v4l2-Xraw$(EXEEXT): $(ioctl_v4l2_Xraw_OBJECTS) $(ioctl_v4l2_Xraw_DEPENDENCIES) $(EXTRA_ioctl_v4l2_Xraw_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_Xraw_OBJECTS) $(ioctl_v4l2_Xraw_LDADD) $(LIBS)
+
+ioctl_v4l2-Xverbose$(EXEEXT): $(ioctl_v4l2_Xverbose_OBJECTS) $(ioctl_v4l2_Xverbose_DEPENDENCIES) $(EXTRA_ioctl_v4l2_Xverbose_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_Xverbose_OBJECTS) $(ioctl_v4l2_Xverbose_LDADD) $(LIBS)
+
+ioctl_v4l2-success$(EXEEXT): $(ioctl_v4l2_success_OBJECTS) $(ioctl_v4l2_success_DEPENDENCIES) $(EXTRA_ioctl_v4l2_success_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-success$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_success_OBJECTS) $(ioctl_v4l2_success_LDADD) $(LIBS)
+
+ioctl_v4l2-success-Xabbrev$(EXEEXT): $(ioctl_v4l2_success_Xabbrev_OBJECTS) $(ioctl_v4l2_success_Xabbrev_DEPENDENCIES) $(EXTRA_ioctl_v4l2_success_Xabbrev_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-success-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_success_Xabbrev_OBJECTS) $(ioctl_v4l2_success_Xabbrev_LDADD) $(LIBS)
+
+ioctl_v4l2-success-Xraw$(EXEEXT): $(ioctl_v4l2_success_Xraw_OBJECTS) $(ioctl_v4l2_success_Xraw_DEPENDENCIES) $(EXTRA_ioctl_v4l2_success_Xraw_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-success-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_success_Xraw_OBJECTS) $(ioctl_v4l2_success_Xraw_LDADD) $(LIBS)
+
+ioctl_v4l2-success-Xverbose$(EXEEXT): $(ioctl_v4l2_success_Xverbose_OBJECTS) $(ioctl_v4l2_success_Xverbose_DEPENDENCIES) $(EXTRA_ioctl_v4l2_success_Xverbose_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-success-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_success_Xverbose_OBJECTS) $(ioctl_v4l2_success_Xverbose_LDADD) $(LIBS)
+
+ioctl_v4l2-success-v$(EXEEXT): $(ioctl_v4l2_success_v_OBJECTS) $(ioctl_v4l2_success_v_DEPENDENCIES) $(EXTRA_ioctl_v4l2_success_v_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-success-v$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_success_v_OBJECTS) $(ioctl_v4l2_success_v_LDADD) $(LIBS)
+
+ioctl_v4l2-success-v-Xabbrev$(EXEEXT): $(ioctl_v4l2_success_v_Xabbrev_OBJECTS) $(ioctl_v4l2_success_v_Xabbrev_DEPENDENCIES) $(EXTRA_ioctl_v4l2_success_v_Xabbrev_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-success-v-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_success_v_Xabbrev_OBJECTS) $(ioctl_v4l2_success_v_Xabbrev_LDADD) $(LIBS)
+
+ioctl_v4l2-success-v-Xraw$(EXEEXT): $(ioctl_v4l2_success_v_Xraw_OBJECTS) $(ioctl_v4l2_success_v_Xraw_DEPENDENCIES) $(EXTRA_ioctl_v4l2_success_v_Xraw_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-success-v-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_success_v_Xraw_OBJECTS) $(ioctl_v4l2_success_v_Xraw_LDADD) $(LIBS)
+
+ioctl_v4l2-success-v-Xverbose$(EXEEXT): $(ioctl_v4l2_success_v_Xverbose_OBJECTS) $(ioctl_v4l2_success_v_Xverbose_DEPENDENCIES) $(EXTRA_ioctl_v4l2_success_v_Xverbose_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-success-v-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_success_v_Xverbose_OBJECTS) $(ioctl_v4l2_success_v_Xverbose_LDADD) $(LIBS)
+
+ioctl_v4l2-v$(EXEEXT): $(ioctl_v4l2_v_OBJECTS) $(ioctl_v4l2_v_DEPENDENCIES) $(EXTRA_ioctl_v4l2_v_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-v$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_v_OBJECTS) $(ioctl_v4l2_v_LDADD) $(LIBS)
+
+ioctl_v4l2-v-Xabbrev$(EXEEXT): $(ioctl_v4l2_v_Xabbrev_OBJECTS) $(ioctl_v4l2_v_Xabbrev_DEPENDENCIES) $(EXTRA_ioctl_v4l2_v_Xabbrev_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-v-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_v_Xabbrev_OBJECTS) $(ioctl_v4l2_v_Xabbrev_LDADD) $(LIBS)
+
+ioctl_v4l2-v-Xraw$(EXEEXT): $(ioctl_v4l2_v_Xraw_OBJECTS) $(ioctl_v4l2_v_Xraw_DEPENDENCIES) $(EXTRA_ioctl_v4l2_v_Xraw_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-v-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_v_Xraw_OBJECTS) $(ioctl_v4l2_v_Xraw_LDADD) $(LIBS)
+
+ioctl_v4l2-v-Xverbose$(EXEEXT): $(ioctl_v4l2_v_Xverbose_OBJECTS) $(ioctl_v4l2_v_Xverbose_DEPENDENCIES) $(EXTRA_ioctl_v4l2_v_Xverbose_DEPENDENCIES) 
+	@rm -f ioctl_v4l2-v-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioctl_v4l2_v_Xverbose_OBJECTS) $(ioctl_v4l2_v_Xverbose_LDADD) $(LIBS)
+
 ioctl_watchdog$(EXEEXT): $(ioctl_watchdog_OBJECTS) $(ioctl_watchdog_DEPENDENCIES) $(EXTRA_ioctl_watchdog_DEPENDENCIES) 
 	@rm -f ioctl_watchdog$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioctl_watchdog_OBJECTS) $(ioctl_watchdog_LDADD) $(LIBS)
@@ -6517,6 +8095,10 @@ ioprio$(EXEEXT): $(ioprio_OBJECTS) $(iop
 	@rm -f ioprio$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioprio_OBJECTS) $(ioprio_LDADD) $(LIBS)
 
+ioprio--pidns-translation$(EXEEXT): $(ioprio__pidns_translation_OBJECTS) $(ioprio__pidns_translation_DEPENDENCIES) $(EXTRA_ioprio__pidns_translation_DEPENDENCIES) 
+	@rm -f ioprio--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(ioprio__pidns_translation_OBJECTS) $(ioprio__pidns_translation_LDADD) $(LIBS)
+
 ioprio-Xabbrev$(EXEEXT): $(ioprio_Xabbrev_OBJECTS) $(ioprio_Xabbrev_DEPENDENCIES) $(EXTRA_ioprio_Xabbrev_DEPENDENCIES) 
 	@rm -f ioprio-Xabbrev$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(ioprio_Xabbrev_OBJECTS) $(ioprio_Xabbrev_LDADD) $(LIBS)
@@ -6613,6 +8195,10 @@ kcmp-y$(EXEEXT): $(kcmp_y_OBJECTS) $(kcm
 	@rm -f kcmp-y$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(kcmp_y_OBJECTS) $(kcmp_y_LDADD) $(LIBS)
 
+kcmp-y--pidns-translation$(EXEEXT): $(kcmp_y__pidns_translation_OBJECTS) $(kcmp_y__pidns_translation_DEPENDENCIES) $(EXTRA_kcmp_y__pidns_translation_DEPENDENCIES) 
+	@rm -f kcmp-y--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(kcmp_y__pidns_translation_OBJECTS) $(kcmp_y__pidns_translation_LDADD) $(LIBS)
+
 kern_features$(EXEEXT): $(kern_features_OBJECTS) $(kern_features_DEPENDENCIES) $(EXTRA_kern_features_DEPENDENCIES) 
 	@rm -f kern_features$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(kern_features_OBJECTS) $(kern_features_LDADD) $(LIBS)
@@ -6661,6 +8247,10 @@ kill$(EXEEXT): $(kill_OBJECTS) $(kill_DE
 	@rm -f kill$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(kill_OBJECTS) $(kill_LDADD) $(LIBS)
 
+kill--pidns-translation$(EXEEXT): $(kill__pidns_translation_OBJECTS) $(kill__pidns_translation_DEPENDENCIES) $(EXTRA_kill__pidns_translation_DEPENDENCIES) 
+	@rm -f kill--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(kill__pidns_translation_OBJECTS) $(kill__pidns_translation_LDADD) $(LIBS)
+
 kill_child$(EXEEXT): $(kill_child_OBJECTS) $(kill_child_DEPENDENCIES) $(EXTRA_kill_child_DEPENDENCIES) 
 	@rm -f kill_child$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(kill_child_OBJECTS) $(kill_child_LDADD) $(LIBS)
@@ -6725,6 +8315,10 @@ maybe_switch_current_tcp$(EXEEXT): $(may
 	@rm -f maybe_switch_current_tcp$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(maybe_switch_current_tcp_OBJECTS) $(maybe_switch_current_tcp_LDADD) $(LIBS)
 
+maybe_switch_current_tcp--quiet-thread-execve$(EXEEXT): $(maybe_switch_current_tcp__quiet_thread_execve_OBJECTS) $(maybe_switch_current_tcp__quiet_thread_execve_DEPENDENCIES) $(EXTRA_maybe_switch_current_tcp__quiet_thread_execve_DEPENDENCIES) 
+	@rm -f maybe_switch_current_tcp--quiet-thread-execve$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(maybe_switch_current_tcp__quiet_thread_execve_OBJECTS) $(maybe_switch_current_tcp__quiet_thread_execve_LDADD) $(LIBS)
+
 mbind$(EXEEXT): $(mbind_OBJECTS) $(mbind_DEPENDENCIES) $(EXTRA_mbind_DEPENDENCIES) 
 	@rm -f mbind$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(mbind_OBJECTS) $(mbind_LDADD) $(LIBS)
@@ -6765,6 +8359,10 @@ migrate_pages$(EXEEXT): $(migrate_pages_
 	@rm -f migrate_pages$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(migrate_pages_OBJECTS) $(migrate_pages_LDADD) $(LIBS)
 
+migrate_pages--pidns-translation$(EXEEXT): $(migrate_pages__pidns_translation_OBJECTS) $(migrate_pages__pidns_translation_DEPENDENCIES) $(EXTRA_migrate_pages__pidns_translation_DEPENDENCIES) 
+	@rm -f migrate_pages--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(migrate_pages__pidns_translation_OBJECTS) $(migrate_pages__pidns_translation_LDADD) $(LIBS)
+
 mincore$(EXEEXT): $(mincore_OBJECTS) $(mincore_DEPENDENCIES) $(EXTRA_mincore_DEPENDENCIES) 
 	@rm -f mincore$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(mincore_OBJECTS) $(mincore_LDADD) $(LIBS)
@@ -6877,6 +8475,10 @@ move_pages$(EXEEXT): $(move_pages_OBJECT
 	@rm -f move_pages$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(move_pages_OBJECTS) $(move_pages_LDADD) $(LIBS)
 
+move_pages--pidns-translation$(EXEEXT): $(move_pages__pidns_translation_OBJECTS) $(move_pages__pidns_translation_DEPENDENCIES) $(EXTRA_move_pages__pidns_translation_DEPENDENCIES) 
+	@rm -f move_pages--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(move_pages__pidns_translation_OBJECTS) $(move_pages__pidns_translation_LDADD) $(LIBS)
+
 move_pages-Xabbrev$(EXEEXT): $(move_pages_Xabbrev_OBJECTS) $(move_pages_Xabbrev_DEPENDENCIES) $(EXTRA_move_pages_Xabbrev_DEPENDENCIES) 
 	@rm -f move_pages-Xabbrev$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(move_pages_Xabbrev_OBJECTS) $(move_pages_Xabbrev_LDADD) $(LIBS)
@@ -6925,6 +8527,22 @@ nanosleep$(EXEEXT): $(nanosleep_OBJECTS)
 	@rm -f nanosleep$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(nanosleep_OBJECTS) $(nanosleep_LDADD) $(LIBS)
 
+net--decode-fds-dev-netlink$(EXEEXT): $(net__decode_fds_dev_netlink_OBJECTS) $(net__decode_fds_dev_netlink_DEPENDENCIES) $(EXTRA_net__decode_fds_dev_netlink_DEPENDENCIES) 
+	@rm -f net--decode-fds-dev-netlink$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(net__decode_fds_dev_netlink_OBJECTS) $(net__decode_fds_dev_netlink_LDADD) $(LIBS)
+
+net--decode-fds-none-netlink$(EXEEXT): $(net__decode_fds_none_netlink_OBJECTS) $(net__decode_fds_none_netlink_DEPENDENCIES) $(EXTRA_net__decode_fds_none_netlink_DEPENDENCIES) 
+	@rm -f net--decode-fds-none-netlink$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(net__decode_fds_none_netlink_OBJECTS) $(net__decode_fds_none_netlink_LDADD) $(LIBS)
+
+net--decode-fds-path-netlink$(EXEEXT): $(net__decode_fds_path_netlink_OBJECTS) $(net__decode_fds_path_netlink_DEPENDENCIES) $(EXTRA_net__decode_fds_path_netlink_DEPENDENCIES) 
+	@rm -f net--decode-fds-path-netlink$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(net__decode_fds_path_netlink_OBJECTS) $(net__decode_fds_path_netlink_LDADD) $(LIBS)
+
+net--decode-fds-socket-netlink$(EXEEXT): $(net__decode_fds_socket_netlink_OBJECTS) $(net__decode_fds_socket_netlink_DEPENDENCIES) $(EXTRA_net__decode_fds_socket_netlink_DEPENDENCIES) 
+	@rm -f net--decode-fds-socket-netlink$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(net__decode_fds_socket_netlink_OBJECTS) $(net__decode_fds_socket_netlink_LDADD) $(LIBS)
+
 net-accept-connect$(EXEEXT): $(net_accept_connect_OBJECTS) $(net_accept_connect_DEPENDENCIES) $(EXTRA_net_accept_connect_DEPENDENCIES) 
 	@rm -f net-accept-connect$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(net_accept_connect_OBJECTS) $(net_accept_connect_LDADD) $(LIBS)
@@ -6953,6 +8571,10 @@ net-sockaddr$(EXEEXT): $(net_sockaddr_OB
 	@rm -f net-sockaddr$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(net_sockaddr_OBJECTS) $(net_sockaddr_LDADD) $(LIBS)
 
+net-sockaddr--pidns-translation$(EXEEXT): $(net_sockaddr__pidns_translation_OBJECTS) $(net_sockaddr__pidns_translation_DEPENDENCIES) $(EXTRA_net_sockaddr__pidns_translation_DEPENDENCIES) 
+	@rm -f net-sockaddr--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(net_sockaddr__pidns_translation_OBJECTS) $(net_sockaddr__pidns_translation_LDADD) $(LIBS)
+
 net-tpacket_req$(EXEEXT): $(net_tpacket_req_OBJECTS) $(net_tpacket_req_DEPENDENCIES) $(EXTRA_net_tpacket_req_DEPENDENCIES) 
 	@rm -f net-tpacket_req$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(net_tpacket_req_OBJECTS) $(net_tpacket_req_LDADD) $(LIBS)
@@ -6989,6 +8611,10 @@ netlink_audit$(EXEEXT): $(netlink_audit_
 	@rm -f netlink_audit$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(netlink_audit_OBJECTS) $(netlink_audit_LDADD) $(LIBS)
 
+netlink_audit--pidns-translation$(EXEEXT): $(netlink_audit__pidns_translation_OBJECTS) $(netlink_audit__pidns_translation_DEPENDENCIES) $(EXTRA_netlink_audit__pidns_translation_DEPENDENCIES) 
+	@rm -f netlink_audit--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(netlink_audit__pidns_translation_OBJECTS) $(netlink_audit__pidns_translation_LDADD) $(LIBS)
+
 netlink_crypto$(EXEEXT): $(netlink_crypto_OBJECTS) $(netlink_crypto_DEPENDENCIES) $(EXTRA_netlink_crypto_DEPENDENCIES) 
 	@rm -f netlink_crypto$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(netlink_crypto_OBJECTS) $(netlink_crypto_LDADD) $(LIBS)
@@ -7137,6 +8763,10 @@ nlattr_ifla_xdp$(EXEEXT): $(nlattr_ifla_
 	@rm -f nlattr_ifla_xdp$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(nlattr_ifla_xdp_OBJECTS) $(nlattr_ifla_xdp_LDADD) $(LIBS)
 
+nlattr_ifla_xdp-y$(EXEEXT): $(nlattr_ifla_xdp_y_OBJECTS) $(nlattr_ifla_xdp_y_DEPENDENCIES) $(EXTRA_nlattr_ifla_xdp_y_DEPENDENCIES) 
+	@rm -f nlattr_ifla_xdp-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(nlattr_ifla_xdp_y_OBJECTS) $(nlattr_ifla_xdp_y_LDADD) $(LIBS)
+
 nlattr_inet_diag_msg$(EXEEXT): $(nlattr_inet_diag_msg_OBJECTS) $(nlattr_inet_diag_msg_DEPENDENCIES) $(EXTRA_nlattr_inet_diag_msg_DEPENDENCIES) 
 	@rm -f nlattr_inet_diag_msg$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(nlattr_inet_diag_msg_OBJECTS) $(nlattr_inet_diag_msg_LDADD) $(LIBS)
@@ -7289,6 +8919,46 @@ openat$(EXEEXT): $(openat_OBJECTS) $(ope
 	@rm -f openat$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(openat_OBJECTS) $(openat_LDADD) $(LIBS)
 
+openat2$(EXEEXT): $(openat2_OBJECTS) $(openat2_DEPENDENCIES) $(EXTRA_openat2_DEPENDENCIES) 
+	@rm -f openat2$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_OBJECTS) $(openat2_LDADD) $(LIBS)
+
+openat2-Xabbrev$(EXEEXT): $(openat2_Xabbrev_OBJECTS) $(openat2_Xabbrev_DEPENDENCIES) $(EXTRA_openat2_Xabbrev_DEPENDENCIES) 
+	@rm -f openat2-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_Xabbrev_OBJECTS) $(openat2_Xabbrev_LDADD) $(LIBS)
+
+openat2-Xraw$(EXEEXT): $(openat2_Xraw_OBJECTS) $(openat2_Xraw_DEPENDENCIES) $(EXTRA_openat2_Xraw_DEPENDENCIES) 
+	@rm -f openat2-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_Xraw_OBJECTS) $(openat2_Xraw_LDADD) $(LIBS)
+
+openat2-Xverbose$(EXEEXT): $(openat2_Xverbose_OBJECTS) $(openat2_Xverbose_DEPENDENCIES) $(EXTRA_openat2_Xverbose_DEPENDENCIES) 
+	@rm -f openat2-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_Xverbose_OBJECTS) $(openat2_Xverbose_LDADD) $(LIBS)
+
+openat2-v$(EXEEXT): $(openat2_v_OBJECTS) $(openat2_v_DEPENDENCIES) $(EXTRA_openat2_v_DEPENDENCIES) 
+	@rm -f openat2-v$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_v_OBJECTS) $(openat2_v_LDADD) $(LIBS)
+
+openat2-v-y$(EXEEXT): $(openat2_v_y_OBJECTS) $(openat2_v_y_DEPENDENCIES) $(EXTRA_openat2_v_y_DEPENDENCIES) 
+	@rm -f openat2-v-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_v_y_OBJECTS) $(openat2_v_y_LDADD) $(LIBS)
+
+openat2-v-y-Xabbrev$(EXEEXT): $(openat2_v_y_Xabbrev_OBJECTS) $(openat2_v_y_Xabbrev_DEPENDENCIES) $(EXTRA_openat2_v_y_Xabbrev_DEPENDENCIES) 
+	@rm -f openat2-v-y-Xabbrev$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_v_y_Xabbrev_OBJECTS) $(openat2_v_y_Xabbrev_LDADD) $(LIBS)
+
+openat2-v-y-Xraw$(EXEEXT): $(openat2_v_y_Xraw_OBJECTS) $(openat2_v_y_Xraw_DEPENDENCIES) $(EXTRA_openat2_v_y_Xraw_DEPENDENCIES) 
+	@rm -f openat2-v-y-Xraw$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_v_y_Xraw_OBJECTS) $(openat2_v_y_Xraw_LDADD) $(LIBS)
+
+openat2-v-y-Xverbose$(EXEEXT): $(openat2_v_y_Xverbose_OBJECTS) $(openat2_v_y_Xverbose_DEPENDENCIES) $(EXTRA_openat2_v_y_Xverbose_DEPENDENCIES) 
+	@rm -f openat2-v-y-Xverbose$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_v_y_Xverbose_OBJECTS) $(openat2_v_y_Xverbose_LDADD) $(LIBS)
+
+openat2-y$(EXEEXT): $(openat2_y_OBJECTS) $(openat2_y_DEPENDENCIES) $(EXTRA_openat2_y_DEPENDENCIES) 
+	@rm -f openat2-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(openat2_y_OBJECTS) $(openat2_y_LDADD) $(LIBS)
+
 orphaned_process_group$(EXEEXT): $(orphaned_process_group_OBJECTS) $(orphaned_process_group_DEPENDENCIES) $(EXTRA_orphaned_process_group_DEPENDENCIES) 
 	@rm -f orphaned_process_group$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(orphaned_process_group_OBJECTS) $(orphaned_process_group_LDADD) $(LIBS)
@@ -7333,10 +9003,38 @@ personality-Xverbose$(EXEEXT): $(persona
 	@rm -f personality-Xverbose$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(personality_Xverbose_OBJECTS) $(personality_Xverbose_LDADD) $(LIBS)
 
+pidfd_getfd$(EXEEXT): $(pidfd_getfd_OBJECTS) $(pidfd_getfd_DEPENDENCIES) $(EXTRA_pidfd_getfd_DEPENDENCIES) 
+	@rm -f pidfd_getfd$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_getfd_OBJECTS) $(pidfd_getfd_LDADD) $(LIBS)
+
+pidfd_getfd-y$(EXEEXT): $(pidfd_getfd_y_OBJECTS) $(pidfd_getfd_y_DEPENDENCIES) $(EXTRA_pidfd_getfd_y_DEPENDENCIES) 
+	@rm -f pidfd_getfd-y$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_getfd_y_OBJECTS) $(pidfd_getfd_y_LDADD) $(LIBS)
+
+pidfd_getfd-yy$(EXEEXT): $(pidfd_getfd_yy_OBJECTS) $(pidfd_getfd_yy_DEPENDENCIES) $(EXTRA_pidfd_getfd_yy_DEPENDENCIES) 
+	@rm -f pidfd_getfd-yy$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_getfd_yy_OBJECTS) $(pidfd_getfd_yy_LDADD) $(LIBS)
+
 pidfd_open$(EXEEXT): $(pidfd_open_OBJECTS) $(pidfd_open_DEPENDENCIES) $(EXTRA_pidfd_open_DEPENDENCIES) 
 	@rm -f pidfd_open$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(pidfd_open_OBJECTS) $(pidfd_open_LDADD) $(LIBS)
 
+pidfd_open--decode-fd-path$(EXEEXT): $(pidfd_open__decode_fd_path_OBJECTS) $(pidfd_open__decode_fd_path_DEPENDENCIES) $(EXTRA_pidfd_open__decode_fd_path_DEPENDENCIES) 
+	@rm -f pidfd_open--decode-fd-path$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_open__decode_fd_path_OBJECTS) $(pidfd_open__decode_fd_path_LDADD) $(LIBS)
+
+pidfd_open--decode-fd-pidfd$(EXEEXT): $(pidfd_open__decode_fd_pidfd_OBJECTS) $(pidfd_open__decode_fd_pidfd_DEPENDENCIES) $(EXTRA_pidfd_open__decode_fd_pidfd_DEPENDENCIES) 
+	@rm -f pidfd_open--decode-fd-pidfd$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_open__decode_fd_pidfd_OBJECTS) $(pidfd_open__decode_fd_pidfd_LDADD) $(LIBS)
+
+pidfd_open--decode-fd-socket$(EXEEXT): $(pidfd_open__decode_fd_socket_OBJECTS) $(pidfd_open__decode_fd_socket_DEPENDENCIES) $(EXTRA_pidfd_open__decode_fd_socket_DEPENDENCIES) 
+	@rm -f pidfd_open--decode-fd-socket$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_open__decode_fd_socket_OBJECTS) $(pidfd_open__decode_fd_socket_LDADD) $(LIBS)
+
+pidfd_open--pidns-translation$(EXEEXT): $(pidfd_open__pidns_translation_OBJECTS) $(pidfd_open__pidns_translation_DEPENDENCIES) $(EXTRA_pidfd_open__pidns_translation_DEPENDENCIES) 
+	@rm -f pidfd_open--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_open__pidns_translation_OBJECTS) $(pidfd_open__pidns_translation_LDADD) $(LIBS)
+
 pidfd_open-P$(EXEEXT): $(pidfd_open_P_OBJECTS) $(pidfd_open_P_DEPENDENCIES) $(EXTRA_pidfd_open_P_DEPENDENCIES) 
 	@rm -f pidfd_open-P$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(pidfd_open_P_OBJECTS) $(pidfd_open_P_LDADD) $(LIBS)
@@ -7345,10 +9043,22 @@ pidfd_open-y$(EXEEXT): $(pidfd_open_y_OB
 	@rm -f pidfd_open-y$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(pidfd_open_y_OBJECTS) $(pidfd_open_y_LDADD) $(LIBS)
 
+pidfd_open-yy$(EXEEXT): $(pidfd_open_yy_OBJECTS) $(pidfd_open_yy_DEPENDENCIES) $(EXTRA_pidfd_open_yy_DEPENDENCIES) 
+	@rm -f pidfd_open-yy$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_open_yy_OBJECTS) $(pidfd_open_yy_LDADD) $(LIBS)
+
 pidfd_send_signal$(EXEEXT): $(pidfd_send_signal_OBJECTS) $(pidfd_send_signal_DEPENDENCIES) $(EXTRA_pidfd_send_signal_DEPENDENCIES) 
 	@rm -f pidfd_send_signal$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(pidfd_send_signal_OBJECTS) $(pidfd_send_signal_LDADD) $(LIBS)
 
+pidfd_send_signal--pidns-translation$(EXEEXT): $(pidfd_send_signal__pidns_translation_OBJECTS) $(pidfd_send_signal__pidns_translation_DEPENDENCIES) $(EXTRA_pidfd_send_signal__pidns_translation_DEPENDENCIES) 
+	@rm -f pidfd_send_signal--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidfd_send_signal__pidns_translation_OBJECTS) $(pidfd_send_signal__pidns_translation_LDADD) $(LIBS)
+
+pidns-cache$(EXEEXT): $(pidns_cache_OBJECTS) $(pidns_cache_DEPENDENCIES) $(EXTRA_pidns_cache_DEPENDENCIES) 
+	@rm -f pidns-cache$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(pidns_cache_OBJECTS) $(pidns_cache_LDADD) $(LIBS)
+
 pipe$(EXEEXT): $(pipe_OBJECTS) $(pipe_DEPENDENCIES) $(EXTRA_pipe_DEPENDENCIES) 
 	@rm -f pipe$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(pipe_OBJECTS) $(pipe_LDADD) $(LIBS)
@@ -7453,6 +9163,10 @@ print_maxfd$(EXEEXT): $(print_maxfd_OBJE
 	@rm -f print_maxfd$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(print_maxfd_OBJECTS) $(print_maxfd_LDADD) $(LIBS)
 
+print_ppid_tracerpid$(EXEEXT): $(print_ppid_tracerpid_OBJECTS) $(print_ppid_tracerpid_DEPENDENCIES) $(EXTRA_print_ppid_tracerpid_DEPENDENCIES) 
+	@rm -f print_ppid_tracerpid$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(print_ppid_tracerpid_OBJECTS) $(print_ppid_tracerpid_LDADD) $(LIBS)
+
 printpath-umovestr$(EXEEXT): $(printpath_umovestr_OBJECTS) $(printpath_umovestr_DEPENDENCIES) $(EXTRA_printpath_umovestr_DEPENDENCIES) 
 	@rm -f printpath-umovestr$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(printpath_umovestr_OBJECTS) $(printpath_umovestr_LDADD) $(LIBS)
@@ -7497,14 +9211,26 @@ prlimit64$(EXEEXT): $(prlimit64_OBJECTS)
 	@rm -f prlimit64$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(prlimit64_OBJECTS) $(prlimit64_LDADD) $(LIBS)
 
+prlimit64--pidns-translation$(EXEEXT): $(prlimit64__pidns_translation_OBJECTS) $(prlimit64__pidns_translation_DEPENDENCIES) $(EXTRA_prlimit64__pidns_translation_DEPENDENCIES) 
+	@rm -f prlimit64--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(prlimit64__pidns_translation_OBJECTS) $(prlimit64__pidns_translation_LDADD) $(LIBS)
+
 process_vm_readv$(EXEEXT): $(process_vm_readv_OBJECTS) $(process_vm_readv_DEPENDENCIES) $(EXTRA_process_vm_readv_DEPENDENCIES) 
 	@rm -f process_vm_readv$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(process_vm_readv_OBJECTS) $(process_vm_readv_LDADD) $(LIBS)
 
+process_vm_readv--pidns-translation$(EXEEXT): $(process_vm_readv__pidns_translation_OBJECTS) $(process_vm_readv__pidns_translation_DEPENDENCIES) $(EXTRA_process_vm_readv__pidns_translation_DEPENDENCIES) 
+	@rm -f process_vm_readv--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(process_vm_readv__pidns_translation_OBJECTS) $(process_vm_readv__pidns_translation_LDADD) $(LIBS)
+
 process_vm_writev$(EXEEXT): $(process_vm_writev_OBJECTS) $(process_vm_writev_DEPENDENCIES) $(EXTRA_process_vm_writev_DEPENDENCIES) 
 	@rm -f process_vm_writev$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(process_vm_writev_OBJECTS) $(process_vm_writev_LDADD) $(LIBS)
 
+process_vm_writev--pidns-translation$(EXEEXT): $(process_vm_writev__pidns_translation_OBJECTS) $(process_vm_writev__pidns_translation_DEPENDENCIES) $(EXTRA_process_vm_writev__pidns_translation_DEPENDENCIES) 
+	@rm -f process_vm_writev--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(process_vm_writev__pidns_translation_OBJECTS) $(process_vm_writev__pidns_translation_LDADD) $(LIBS)
+
 pselect6$(EXEEXT): $(pselect6_OBJECTS) $(pselect6_DEPENDENCIES) $(EXTRA_pselect6_DEPENDENCIES) 
 	@rm -f pselect6$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(pselect6_OBJECTS) $(pselect6_LDADD) $(LIBS)
@@ -7697,6 +9423,10 @@ rt_sigqueueinfo$(EXEEXT): $(rt_sigqueuei
 	@rm -f rt_sigqueueinfo$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(rt_sigqueueinfo_OBJECTS) $(rt_sigqueueinfo_LDADD) $(LIBS)
 
+rt_sigqueueinfo--pidns-translation$(EXEEXT): $(rt_sigqueueinfo__pidns_translation_OBJECTS) $(rt_sigqueueinfo__pidns_translation_DEPENDENCIES) $(EXTRA_rt_sigqueueinfo__pidns_translation_DEPENDENCIES) 
+	@rm -f rt_sigqueueinfo--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(rt_sigqueueinfo__pidns_translation_OBJECTS) $(rt_sigqueueinfo__pidns_translation_LDADD) $(LIBS)
+
 rt_sigreturn$(EXEEXT): $(rt_sigreturn_OBJECTS) $(rt_sigreturn_DEPENDENCIES) $(EXTRA_rt_sigreturn_DEPENDENCIES) 
 	@rm -f rt_sigreturn$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(rt_sigreturn_OBJECTS) $(rt_sigreturn_LDADD) $(LIBS)
@@ -7713,6 +9443,10 @@ rt_tgsigqueueinfo$(EXEEXT): $(rt_tgsigqu
 	@rm -f rt_tgsigqueueinfo$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(rt_tgsigqueueinfo_OBJECTS) $(rt_tgsigqueueinfo_LDADD) $(LIBS)
 
+rt_tgsigqueueinfo--pidns-translation$(EXEEXT): $(rt_tgsigqueueinfo__pidns_translation_OBJECTS) $(rt_tgsigqueueinfo__pidns_translation_DEPENDENCIES) $(EXTRA_rt_tgsigqueueinfo__pidns_translation_DEPENDENCIES) 
+	@rm -f rt_tgsigqueueinfo--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(rt_tgsigqueueinfo__pidns_translation_OBJECTS) $(rt_tgsigqueueinfo__pidns_translation_LDADD) $(LIBS)
+
 run_expect_termsig$(EXEEXT): $(run_expect_termsig_OBJECTS) $(run_expect_termsig_DEPENDENCIES) $(EXTRA_run_expect_termsig_DEPENDENCIES) 
 	@rm -f run_expect_termsig$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(run_expect_termsig_OBJECTS) $(run_expect_termsig_LDADD) $(LIBS)
@@ -7753,18 +9487,34 @@ sched_xetaffinity$(EXEEXT): $(sched_xeta
 	@rm -f sched_xetaffinity$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(sched_xetaffinity_OBJECTS) $(sched_xetaffinity_LDADD) $(LIBS)
 
+sched_xetaffinity--pidns-translation$(EXEEXT): $(sched_xetaffinity__pidns_translation_OBJECTS) $(sched_xetaffinity__pidns_translation_DEPENDENCIES) $(EXTRA_sched_xetaffinity__pidns_translation_DEPENDENCIES) 
+	@rm -f sched_xetaffinity--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(sched_xetaffinity__pidns_translation_OBJECTS) $(sched_xetaffinity__pidns_translation_LDADD) $(LIBS)
+
 sched_xetattr$(EXEEXT): $(sched_xetattr_OBJECTS) $(sched_xetattr_DEPENDENCIES) $(EXTRA_sched_xetattr_DEPENDENCIES) 
 	@rm -f sched_xetattr$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(sched_xetattr_OBJECTS) $(sched_xetattr_LDADD) $(LIBS)
 
+sched_xetattr--pidns-translation$(EXEEXT): $(sched_xetattr__pidns_translation_OBJECTS) $(sched_xetattr__pidns_translation_DEPENDENCIES) $(EXTRA_sched_xetattr__pidns_translation_DEPENDENCIES) 
+	@rm -f sched_xetattr--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(sched_xetattr__pidns_translation_OBJECTS) $(sched_xetattr__pidns_translation_LDADD) $(LIBS)
+
 sched_xetparam$(EXEEXT): $(sched_xetparam_OBJECTS) $(sched_xetparam_DEPENDENCIES) $(EXTRA_sched_xetparam_DEPENDENCIES) 
 	@rm -f sched_xetparam$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(sched_xetparam_OBJECTS) $(sched_xetparam_LDADD) $(LIBS)
 
+sched_xetparam--pidns-translation$(EXEEXT): $(sched_xetparam__pidns_translation_OBJECTS) $(sched_xetparam__pidns_translation_DEPENDENCIES) $(EXTRA_sched_xetparam__pidns_translation_DEPENDENCIES) 
+	@rm -f sched_xetparam--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(sched_xetparam__pidns_translation_OBJECTS) $(sched_xetparam__pidns_translation_LDADD) $(LIBS)
+
 sched_xetscheduler$(EXEEXT): $(sched_xetscheduler_OBJECTS) $(sched_xetscheduler_DEPENDENCIES) $(EXTRA_sched_xetscheduler_DEPENDENCIES) 
 	@rm -f sched_xetscheduler$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(sched_xetscheduler_OBJECTS) $(sched_xetscheduler_LDADD) $(LIBS)
 
+sched_xetscheduler--pidns-translation$(EXEEXT): $(sched_xetscheduler__pidns_translation_OBJECTS) $(sched_xetscheduler__pidns_translation_DEPENDENCIES) $(EXTRA_sched_xetscheduler__pidns_translation_DEPENDENCIES) 
+	@rm -f sched_xetscheduler--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(sched_xetscheduler__pidns_translation_OBJECTS) $(sched_xetscheduler__pidns_translation_LDADD) $(LIBS)
+
 sched_yield$(EXEEXT): $(sched_yield_OBJECTS) $(sched_yield_DEPENDENCIES) $(EXTRA_sched_yield_DEPENDENCIES) 
 	@rm -f sched_yield$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(sched_yield_OBJECTS) $(sched_yield_LDADD) $(LIBS)
@@ -7889,6 +9639,10 @@ setns$(EXEEXT): $(setns_OBJECTS) $(setns
 	@rm -f setns$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(setns_OBJECTS) $(setns_LDADD) $(LIBS)
 
+setpgrp-exec$(EXEEXT): $(setpgrp_exec_OBJECTS) $(setpgrp_exec_DEPENDENCIES) $(EXTRA_setpgrp_exec_DEPENDENCIES) 
+	@rm -f setpgrp-exec$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(setpgrp_exec_OBJECTS) $(setpgrp_exec_LDADD) $(LIBS)
+
 setregid$(EXEEXT): $(setregid_OBJECTS) $(setregid_DEPENDENCIES) $(EXTRA_setregid_DEPENDENCIES) 
 	@rm -f setregid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(setregid_OBJECTS) $(setregid_LDADD) $(LIBS)
@@ -7973,6 +9727,10 @@ signal_receive$(EXEEXT): $(signal_receiv
 	@rm -f signal_receive$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(signal_receive_OBJECTS) $(signal_receive_LDADD) $(LIBS)
 
+signal_receive--pidns-translation$(EXEEXT): $(signal_receive__pidns_translation_OBJECTS) $(signal_receive__pidns_translation_DEPENDENCIES) $(EXTRA_signal_receive__pidns_translation_DEPENDENCIES) 
+	@rm -f signal_receive--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(signal_receive__pidns_translation_OBJECTS) $(signal_receive__pidns_translation_LDADD) $(LIBS)
+
 signalfd4$(EXEEXT): $(signalfd4_OBJECTS) $(signalfd4_DEPENDENCIES) $(EXTRA_signalfd4_DEPENDENCIES) 
 	@rm -f signalfd4$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(signalfd4_OBJECTS) $(signalfd4_LDADD) $(LIBS)
@@ -8009,6 +9767,10 @@ so_peercred$(EXEEXT): $(so_peercred_OBJE
 	@rm -f so_peercred$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(so_peercred_OBJECTS) $(so_peercred_LDADD) $(LIBS)
 
+so_peercred--pidns-translation$(EXEEXT): $(so_peercred__pidns_translation_OBJECTS) $(so_peercred__pidns_translation_DEPENDENCIES) $(EXTRA_so_peercred__pidns_translation_DEPENDENCIES) 
+	@rm -f so_peercred--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(so_peercred__pidns_translation_OBJECTS) $(so_peercred__pidns_translation_LDADD) $(LIBS)
+
 so_peercred-Xabbrev$(EXEEXT): $(so_peercred_Xabbrev_OBJECTS) $(so_peercred_Xabbrev_DEPENDENCIES) $(EXTRA_so_peercred_Xabbrev_DEPENDENCIES) 
 	@rm -f so_peercred-Xabbrev$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(so_peercred_Xabbrev_OBJECTS) $(so_peercred_Xabbrev_LDADD) $(LIBS)
@@ -8101,6 +9863,14 @@ status-failed$(EXEEXT): $(status_failed_
 	@rm -f status-failed$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(status_failed_OBJECTS) $(status_failed_LDADD) $(LIBS)
 
+status-failed-long$(EXEEXT): $(status_failed_long_OBJECTS) $(status_failed_long_DEPENDENCIES) $(EXTRA_status_failed_long_DEPENDENCIES) 
+	@rm -f status-failed-long$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(status_failed_long_OBJECTS) $(status_failed_long_LDADD) $(LIBS)
+
+status-failed-status$(EXEEXT): $(status_failed_status_OBJECTS) $(status_failed_status_DEPENDENCIES) $(EXTRA_status_failed_status_DEPENDENCIES) 
+	@rm -f status-failed-status$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(status_failed_status_OBJECTS) $(status_failed_status_LDADD) $(LIBS)
+
 status-none$(EXEEXT): $(status_none_OBJECTS) $(status_none_DEPENDENCIES) $(EXTRA_status_none_DEPENDENCIES) 
 	@rm -f status-none$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(status_none_OBJECTS) $(status_none_LDADD) $(LIBS)
@@ -8117,6 +9887,14 @@ status-successful$(EXEEXT): $(status_suc
 	@rm -f status-successful$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(status_successful_OBJECTS) $(status_successful_LDADD) $(LIBS)
 
+status-successful-long$(EXEEXT): $(status_successful_long_OBJECTS) $(status_successful_long_DEPENDENCIES) $(EXTRA_status_successful_long_DEPENDENCIES) 
+	@rm -f status-successful-long$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(status_successful_long_OBJECTS) $(status_successful_long_LDADD) $(LIBS)
+
+status-successful-status$(EXEEXT): $(status_successful_status_OBJECTS) $(status_successful_status_DEPENDENCIES) $(EXTRA_status_successful_status_DEPENDENCIES) 
+	@rm -f status-successful-status$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(status_successful_status_OBJECTS) $(status_successful_status_LDADD) $(LIBS)
+
 status-unfinished$(EXEEXT): $(status_unfinished_OBJECTS) $(status_unfinished_DEPENDENCIES) $(EXTRA_status_unfinished_DEPENDENCIES) 
 	@rm -f status-unfinished$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(status_unfinished_OBJECTS) $(status_unfinished_LDADD) $(LIBS)
@@ -8129,6 +9907,30 @@ statx$(EXEEXT): $(statx_OBJECTS) $(statx
 	@rm -f statx$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(statx_OBJECTS) $(statx_LDADD) $(LIBS)
 
+strace--strings-in-hex$(EXEEXT): $(strace__strings_in_hex_OBJECTS) $(strace__strings_in_hex_DEPENDENCIES) $(EXTRA_strace__strings_in_hex_DEPENDENCIES) 
+	@rm -f strace--strings-in-hex$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(strace__strings_in_hex_OBJECTS) $(strace__strings_in_hex_LDADD) $(LIBS)
+
+strace--strings-in-hex-all$(EXEEXT): $(strace__strings_in_hex_all_OBJECTS) $(strace__strings_in_hex_all_DEPENDENCIES) $(EXTRA_strace__strings_in_hex_all_DEPENDENCIES) 
+	@rm -f strace--strings-in-hex-all$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(strace__strings_in_hex_all_OBJECTS) $(strace__strings_in_hex_all_LDADD) $(LIBS)
+
+strace--strings-in-hex-non-ascii$(EXEEXT): $(strace__strings_in_hex_non_ascii_OBJECTS) $(strace__strings_in_hex_non_ascii_DEPENDENCIES) $(EXTRA_strace__strings_in_hex_non_ascii_DEPENDENCIES) 
+	@rm -f strace--strings-in-hex-non-ascii$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(strace__strings_in_hex_non_ascii_OBJECTS) $(strace__strings_in_hex_non_ascii_LDADD) $(LIBS)
+
+strace-n$(EXEEXT): $(strace_n_OBJECTS) $(strace_n_DEPENDENCIES) $(EXTRA_strace_n_DEPENDENCIES) 
+	@rm -f strace-n$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(strace_n_OBJECTS) $(strace_n_LDADD) $(LIBS)
+
+strace-x$(EXEEXT): $(strace_x_OBJECTS) $(strace_x_DEPENDENCIES) $(EXTRA_strace_x_DEPENDENCIES) 
+	@rm -f strace-x$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(strace_x_OBJECTS) $(strace_x_LDADD) $(LIBS)
+
+strace-xx$(EXEEXT): $(strace_xx_OBJECTS) $(strace_xx_DEPENDENCIES) $(EXTRA_strace_xx_DEPENDENCIES) 
+	@rm -f strace-xx$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(strace_xx_OBJECTS) $(strace_xx_LDADD) $(LIBS)
+
 swap$(EXEEXT): $(swap_OBJECTS) $(swap_DEPENDENCIES) $(EXTRA_swap_DEPENDENCIES) 
 	@rm -f swap$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(swap_OBJECTS) $(swap_LDADD) $(LIBS)
@@ -8173,10 +9975,34 @@ tee$(EXEEXT): $(tee_OBJECTS) $(tee_DEPEN
 	@rm -f tee$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(tee_OBJECTS) $(tee_LDADD) $(LIBS)
 
+tgkill$(EXEEXT): $(tgkill_OBJECTS) $(tgkill_DEPENDENCIES) $(EXTRA_tgkill_DEPENDENCIES) 
+	@rm -f tgkill$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(tgkill_OBJECTS) $(tgkill_LDADD) $(LIBS)
+
+tgkill--pidns-translation$(EXEEXT): $(tgkill__pidns_translation_OBJECTS) $(tgkill__pidns_translation_DEPENDENCIES) $(EXTRA_tgkill__pidns_translation_DEPENDENCIES) 
+	@rm -f tgkill--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(tgkill__pidns_translation_OBJECTS) $(tgkill__pidns_translation_LDADD) $(LIBS)
+
 threads-execve$(EXEEXT): $(threads_execve_OBJECTS) $(threads_execve_DEPENDENCIES) $(EXTRA_threads_execve_DEPENDENCIES) 
 	@rm -f threads-execve$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(threads_execve_OBJECTS) $(threads_execve_LDADD) $(LIBS)
 
+threads-execve--quiet-thread-execve$(EXEEXT): $(threads_execve__quiet_thread_execve_OBJECTS) $(threads_execve__quiet_thread_execve_DEPENDENCIES) $(EXTRA_threads_execve__quiet_thread_execve_DEPENDENCIES) 
+	@rm -f threads-execve--quiet-thread-execve$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(threads_execve__quiet_thread_execve_OBJECTS) $(threads_execve__quiet_thread_execve_LDADD) $(LIBS)
+
+threads-execve-q$(EXEEXT): $(threads_execve_q_OBJECTS) $(threads_execve_q_DEPENDENCIES) $(EXTRA_threads_execve_q_DEPENDENCIES) 
+	@rm -f threads-execve-q$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(threads_execve_q_OBJECTS) $(threads_execve_q_LDADD) $(LIBS)
+
+threads-execve-qq$(EXEEXT): $(threads_execve_qq_OBJECTS) $(threads_execve_qq_DEPENDENCIES) $(EXTRA_threads_execve_qq_DEPENDENCIES) 
+	@rm -f threads-execve-qq$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(threads_execve_qq_OBJECTS) $(threads_execve_qq_LDADD) $(LIBS)
+
+threads-execve-qqq$(EXEEXT): $(threads_execve_qqq_OBJECTS) $(threads_execve_qqq_DEPENDENCIES) $(EXTRA_threads_execve_qqq_DEPENDENCIES) 
+	@rm -f threads-execve-qqq$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(threads_execve_qqq_OBJECTS) $(threads_execve_qqq_LDADD) $(LIBS)
+
 time$(EXEEXT): $(time_OBJECTS) $(time_DEPENDENCIES) $(EXTRA_time_DEPENDENCIES) 
 	@rm -f time$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(time_OBJECTS) $(time_LDADD) $(LIBS)
@@ -8201,10 +10027,22 @@ times-fail$(EXEEXT): $(times_fail_OBJECT
 	@rm -f times-fail$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(times_fail_OBJECTS) $(times_fail_LDADD) $(LIBS)
 
+tkill$(EXEEXT): $(tkill_OBJECTS) $(tkill_DEPENDENCIES) $(EXTRA_tkill_DEPENDENCIES) 
+	@rm -f tkill$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(tkill_OBJECTS) $(tkill_LDADD) $(LIBS)
+
+tkill--pidns-translation$(EXEEXT): $(tkill__pidns_translation_OBJECTS) $(tkill__pidns_translation_DEPENDENCIES) $(EXTRA_tkill__pidns_translation_DEPENDENCIES) 
+	@rm -f tkill--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(tkill__pidns_translation_OBJECTS) $(tkill__pidns_translation_LDADD) $(LIBS)
+
 tracer_ppid_pgid_sid$(EXEEXT): $(tracer_ppid_pgid_sid_OBJECTS) $(tracer_ppid_pgid_sid_DEPENDENCIES) $(EXTRA_tracer_ppid_pgid_sid_DEPENDENCIES) 
 	@rm -f tracer_ppid_pgid_sid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(tracer_ppid_pgid_sid_OBJECTS) $(tracer_ppid_pgid_sid_LDADD) $(LIBS)
 
+trie_test$(EXEEXT): $(trie_test_OBJECTS) $(trie_test_DEPENDENCIES) $(EXTRA_trie_test_DEPENDENCIES) 
+	@rm -f trie_test$(EXEEXT)
+	$(AM_V_CCLD)$(trie_test_LINK) $(trie_test_OBJECTS) $(trie_test_LDADD) $(LIBS)
+
 truncate$(EXEEXT): $(truncate_OBJECTS) $(truncate_DEPENDENCIES) $(EXTRA_truncate_DEPENDENCIES) 
 	@rm -f truncate$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(truncate_OBJECTS) $(truncate_LDADD) $(LIBS)
@@ -8257,6 +10095,10 @@ umovestr_cached$(EXEEXT): $(umovestr_cac
 	@rm -f umovestr_cached$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(umovestr_cached_OBJECTS) $(umovestr_cached_LDADD) $(LIBS)
 
+umovestr_cached_adjacent$(EXEEXT): $(umovestr_cached_adjacent_OBJECTS) $(umovestr_cached_adjacent_DEPENDENCIES) $(EXTRA_umovestr_cached_adjacent_DEPENDENCIES) 
+	@rm -f umovestr_cached_adjacent$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(umovestr_cached_adjacent_OBJECTS) $(umovestr_cached_adjacent_LDADD) $(LIBS)
+
 uname$(EXEEXT): $(uname_OBJECTS) $(uname_DEPENDENCIES) $(EXTRA_uname_DEPENDENCIES) 
 	@rm -f uname$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(uname_OBJECTS) $(uname_LDADD) $(LIBS)
@@ -8361,6 +10203,10 @@ xet_robust_list$(EXEEXT): $(xet_robust_l
 	@rm -f xet_robust_list$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(xet_robust_list_OBJECTS) $(xet_robust_list_LDADD) $(LIBS)
 
+xet_robust_list--pidns-translation$(EXEEXT): $(xet_robust_list__pidns_translation_OBJECTS) $(xet_robust_list__pidns_translation_DEPENDENCIES) $(EXTRA_xet_robust_list__pidns_translation_DEPENDENCIES) 
+	@rm -f xet_robust_list--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(xet_robust_list__pidns_translation_OBJECTS) $(xet_robust_list__pidns_translation_LDADD) $(LIBS)
+
 xet_thread_area_x86$(EXEEXT): $(xet_thread_area_x86_OBJECTS) $(xet_thread_area_x86_DEPENDENCIES) $(EXTRA_xet_thread_area_x86_DEPENDENCIES) 
 	@rm -f xet_thread_area_x86$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(xet_thread_area_x86_OBJECTS) $(xet_thread_area_x86_LDADD) $(LIBS)
@@ -8373,10 +10219,18 @@ xetpgid$(EXEEXT): $(xetpgid_OBJECTS) $(x
 	@rm -f xetpgid$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(xetpgid_OBJECTS) $(xetpgid_LDADD) $(LIBS)
 
+xetpgid--pidns-translation$(EXEEXT): $(xetpgid__pidns_translation_OBJECTS) $(xetpgid__pidns_translation_DEPENDENCIES) $(EXTRA_xetpgid__pidns_translation_DEPENDENCIES) 
+	@rm -f xetpgid--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(xetpgid__pidns_translation_OBJECTS) $(xetpgid__pidns_translation_LDADD) $(LIBS)
+
 xetpriority$(EXEEXT): $(xetpriority_OBJECTS) $(xetpriority_DEPENDENCIES) $(EXTRA_xetpriority_DEPENDENCIES) 
 	@rm -f xetpriority$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(xetpriority_OBJECTS) $(xetpriority_LDADD) $(LIBS)
 
+xetpriority--pidns-translation$(EXEEXT): $(xetpriority__pidns_translation_OBJECTS) $(xetpriority__pidns_translation_DEPENDENCIES) $(EXTRA_xetpriority__pidns_translation_DEPENDENCIES) 
+	@rm -f xetpriority--pidns-translation$(EXEEXT)
+	$(AM_V_CCLD)$(LINK) $(xetpriority__pidns_translation_OBJECTS) $(xetpriority__pidns_translation_LDADD) $(LIBS)
+
 xettimeofday$(EXEEXT): $(xettimeofday_OBJECTS) $(xettimeofday_DEPENDENCIES) $(EXTRA_xettimeofday_DEPENDENCIES) 
 	@rm -f xettimeofday$(EXEEXT)
 	$(AM_V_CCLD)$(LINK) $(xettimeofday_OBJECTS) $(xettimeofday_LDADD) $(LIBS)
@@ -8413,6 +10267,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/bpf-obj_get_info_by_fd-prog.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/bpf-obj_get_info_by_fd-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/bpf-obj_get_info_by_fd.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/bpf-success-long-y.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/bpf-success-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/bpf-success.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/bpf-v.Po@am__quote@ # am--include-marker
@@ -8439,16 +10294,39 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone3-success-Xverbose.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone3-success.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone3.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_parent--quiet-exit.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_parent-q.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_parent-qq.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_parent.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_ptrace--quiet-attach.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_ptrace--quiet-exit.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_ptrace-q.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_ptrace-qq.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/clone_ptrace.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/close_range-P.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/close_range-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/close_range-yy.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/close_range.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/copy_file_range.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/count-f.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/creat.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/delay.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/delete_module.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dev--decode-fds-dev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dev--decode-fds-path.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dev--decode-fds-socket.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dev-yy.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup-P.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup-yy.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup2-P.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup2-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup2-yy.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup2.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup3-P.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup3-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup3-yy.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/dup3.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/epoll_create.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/epoll_create1.Po@am__quote@ # am--include-marker
@@ -8461,7 +10339,14 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/execve.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/execveat-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/execveat.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/faccessat-P.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/faccessat-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/faccessat-yy.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/faccessat.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/faccessat2-P.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/faccessat2-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/faccessat2-yy.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/faccessat2.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fadvise64.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fadvise64_64.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fallocate.Po@am__quote@ # am--include-marker
@@ -8476,7 +10361,9 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fchown.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fchown32.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fchownat.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fcntl--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fcntl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fcntl64--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fcntl64.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fdatasync.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fflush.Po@am__quote@ # am--include-marker
@@ -8487,6 +10374,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/filter_seccomp-perf.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/finit_module.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/flock.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fork--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fork-f.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fsconfig-P.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/fsconfig.Po@am__quote@ # am--include-marker
@@ -8512,9 +10400,12 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/futex.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/futimesat.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/get_mempolicy.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/get_process_reaper.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getcpu.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getcwd.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getdents-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getdents.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getdents64-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getdents64.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getegid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getegid32.Po@am__quote@ # am--include-marker
@@ -8525,7 +10416,9 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getgroups.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getgroups32.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getpeername.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getpgrp--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getpgrp.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getpid--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getpid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getppid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getrandom.Po@am__quote@ # am--include-marker
@@ -8535,12 +10428,16 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getresuid32.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getrlimit.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getrusage.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getsid--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getsid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getsockname.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/gettid--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/gettid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getuid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getuid32.Po@am__quote@ # am--include-marker
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getxxid.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getxgid.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getxpid.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/getxuid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/group_req.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/inet-cmsg.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/init_module.Po@am__quote@ # am--include-marker
@@ -8555,6 +10452,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/io_uring_register.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/io_uring_setup.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_block--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_block.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_dm-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_dm.Po@am__quote@ # am--include-marker
@@ -8574,6 +10472,22 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_evdev-v-Xverbose.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_evdev-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_evdev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-success-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-success-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-success-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-success-v-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-success-v-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-success-v-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-success-v.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-success.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-v-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-v-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-v-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio-v.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_hdio.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_inotify.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_kvm_run-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_kvm_run.Po@am__quote@ # am--include-marker
@@ -8594,11 +10508,28 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_sg_io_v3.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_sg_io_v4.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_sock_gifconf.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_tee.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_uffdio.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-success-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-success-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-success-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-success-v-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-success-v-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-success-v-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-success-v.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-success.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-v-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-v-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-v-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2-v.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_v4l2.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioctl_watchdog.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioperm.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/iopl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioprio--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioprio-Xabbrev.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioprio-Xraw.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ioprio-Xverbose.Po@am__quote@ # am--include-marker
@@ -8622,6 +10553,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipc_shm-Xverbose.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ipc_shm.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/is_linux_mips_n64.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/kcmp-y--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/kcmp-y.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/kcmp.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/kern_features.Po@am__quote@ # am--include-marker
@@ -8635,12 +10567,14 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/keyctl-Xraw.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/keyctl-Xverbose.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/keyctl.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/kill--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/kill.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/kill_child.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ksysent.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/lchown.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/lchown32.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-create_nl_socket.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-create_tmpfile.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-errno2name.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-error_msg.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-fill_memory.Po@am__quote@ # am--include-marker
@@ -8654,6 +10588,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-libsocketcall.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-lock_file.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-overflowuid.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-pidns.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-pipe_maxfd.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-print_quoted_string.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-print_time.Po@am__quote@ # am--include-marker
@@ -8670,6 +10605,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-test_printstrn.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-test_ucopy.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-tprintf.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libtests_a-xmalloc_for_tests.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/link.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/linkat.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/list_sigaction_signum.Po@am__quote@ # am--include-marker
@@ -8681,6 +10617,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/lstat.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/lstat64-lstat64.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/madvise.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/maybe_switch_current_tcp--quiet-thread-execve.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/maybe_switch_current_tcp.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/mbind-Xabbrev.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/mbind-Xraw.Po@am__quote@ # am--include-marker
@@ -8691,6 +10628,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/memfd_create-Xraw.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/memfd_create-Xverbose.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/memfd_create.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/migrate_pages--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/migrate_pages.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/mincore.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/mkdir.Po@am__quote@ # am--include-marker
@@ -8719,6 +10657,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/mount.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/move_mount-P.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/move_mount.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/move_pages--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/move_pages-Xabbrev.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/move_pages-Xraw.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/move_pages-Xverbose.Po@am__quote@ # am--include-marker
@@ -8732,12 +10671,17 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/msg_name.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/munlockall.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/nanosleep.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net--decode-fds-dev-netlink.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net--decode-fds-none-netlink.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net--decode-fds-path-netlink.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net--decode-fds-socket-netlink.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-accept-connect.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-icmp_filter.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-packet_mreq-Xabbrev.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-packet_mreq-Xraw.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-packet_mreq-Xverbose.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-packet_mreq.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-sockaddr--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-sockaddr.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-tpacket_req.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-tpacket_stats-success.Po@am__quote@ # am--include-marker
@@ -8747,6 +10691,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-yy-inet6.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-yy-netlink.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/net-yy-unix.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/netlink_audit--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/netlink_audit.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/netlink_crypto.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/netlink_generic.Po@am__quote@ # am--include-marker
@@ -8784,6 +10729,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/nlattr_ifla_brport.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/nlattr_ifla_linkinfo.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/nlattr_ifla_port.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/nlattr_ifla_xdp-y.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/nlattr_ifla_xdp.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/nlattr_inet_diag_msg.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/nlattr_inet_diag_req_compat.Po@am__quote@ # am--include-marker
@@ -8823,6 +10769,16 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/open_tree-P.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/open_tree.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-v-y-Xabbrev.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-v-y-Xraw.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-v-y-Xverbose.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-v-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-v.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/openat2.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/orphaned_process_group.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/osf_utimes.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pause.Po@am__quote@ # am--include-marker
@@ -8834,10 +10790,20 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/personality-Xraw.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/personality-Xverbose.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/personality.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_getfd-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_getfd-yy.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_getfd.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_open--decode-fd-path.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_open--decode-fd-pidfd.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_open--decode-fd-socket.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_open--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_open-P.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_open-y.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_open-yy.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_open.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_send_signal--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidfd_send_signal.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pidns-cache.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pipe.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pipe2.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pkey_alloc.Po@am__quote@ # am--include-marker
@@ -8864,6 +10830,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/preadv2-pwritev2.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/preadv_pwritev-preadv-pwritev.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/print_maxfd.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/print_ppid_tracerpid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/printpath-umovestr-peekdata.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/printpath-umovestr-undumpable.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/printpath-umovestr.Po@am__quote@ # am--include-marker
@@ -8874,8 +10841,11 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/printstrn-umoven-peekdata.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/printstrn-umoven-undumpable.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/printstrn-umoven.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/prlimit64--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/prlimit64.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/process_vm_readv--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/process_vm_readv.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/process_vm_writev--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/process_vm_writev.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/pselect6.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ptrace.Po@am__quote@ # am--include-marker
@@ -8924,10 +10894,12 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_sigaction.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_sigpending.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_sigprocmask.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_sigqueueinfo--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_sigqueueinfo.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_sigreturn.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_sigsuspend.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_sigtimedwait.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_tgsigqueueinfo--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/rt_tgsigqueueinfo.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/run_expect_termsig.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/s390_guarded_storage-v.Po@am__quote@ # am--include-marker
@@ -8938,9 +10910,13 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/s390_sthyi.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_get_priority_mxx.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_rr_get_interval.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_xetaffinity--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_xetaffinity.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_xetattr--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_xetattr.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_xetparam--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_xetparam.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_xetscheduler--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_xetscheduler.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sched_yield.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/scm_rights.Po@am__quote@ # am--include-marker
@@ -8973,6 +10949,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/setgroups32.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sethostname.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/setns.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/setpgrp-exec.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/setregid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/setregid32.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/setresgid.Po@am__quote@ # am--include-marker
@@ -8993,6 +10970,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sigaltstack.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/siginfo.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/signal.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/signal_receive--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/signal_receive.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/signalfd4.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sigpending.Po@am__quote@ # am--include-marker
@@ -9002,6 +10980,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sleep.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/so_error.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/so_linger.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/so_peercred--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/so_peercred-Xabbrev.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/so_peercred-Xraw.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/so_peercred-Xverbose.Po@am__quote@ # am--include-marker
@@ -9033,14 +11012,24 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/statfs-statfs.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/statfs64.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-all.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-failed-long.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-failed-status.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-failed.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-none-f.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-none-threads.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-none.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-successful-long.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-successful-status.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-successful.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-unfinished-threads.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/status-unfinished.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/statx.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace--strings-in-hex-all.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace--strings-in-hex-non-ascii.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace--strings-in-hex.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-n.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-x.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strace-xx.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/swap.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/sxetmask.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/symlink.Po@am__quote@ # am--include-marker
@@ -9052,6 +11041,12 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/syslog-success.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/syslog.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/tee.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/tgkill--pidns-translation.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/tgkill.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/threads-execve--quiet-thread-execve.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/threads-execve-q.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/threads-execve-qq.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/threads-execve-qqq.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/threads-execve.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/time.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/timer_create.Po@am__quote@ # am--include-marker
@@ -9059,7 +11054,11 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/timerfd_xettime.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/times-fail.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/times.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/tkill--pidns-translation.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/tkill.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/tracer_ppid_pgid_sid.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/trie_test-trie_for_tests.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/trie_test-trie_test.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/truncate.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/truncate64-truncate64.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/ugetrlimit.Po@am__quote@ # am--include-marker
@@ -9073,6 +11072,7 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/umovestr2.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/umovestr3.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/umovestr_cached.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/umovestr_cached_adjacent.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/uname.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/unblock_reset_raise.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/unix-pair-send-recv.Po@am__quote@ # am--include-marker
@@ -9098,10 +11098,13 @@ distclean-compile:
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/waitpid.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xattr-strings.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xattr.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xet_robust_list--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xet_robust_list.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xet_thread_area_x86.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xetitimer.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xetpgid--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xetpgid.Po@am__quote@ # am--include-marker
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xetpriority--pidns-translation.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xetpriority.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xettimeofday.Po@am__quote@ # am--include-marker
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/zeroargc.Po@am__quote@ # am--include-marker
@@ -9142,6 +11145,20 @@ libtests_a-create_nl_socket.obj: create_
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
 @am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-create_nl_socket.obj `if test -f 'create_nl_socket.c'; then $(CYGPATH_W) 'create_nl_socket.c'; else $(CYGPATH_W) '$(srcdir)/create_nl_socket.c'; fi`
 
+libtests_a-create_tmpfile.o: create_tmpfile.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT libtests_a-create_tmpfile.o -MD -MP -MF $(DEPDIR)/libtests_a-create_tmpfile.Tpo -c -o libtests_a-create_tmpfile.o `test -f 'create_tmpfile.c' || echo '$(srcdir)/'`create_tmpfile.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libtests_a-create_tmpfile.Tpo $(DEPDIR)/libtests_a-create_tmpfile.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='create_tmpfile.c' object='libtests_a-create_tmpfile.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-create_tmpfile.o `test -f 'create_tmpfile.c' || echo '$(srcdir)/'`create_tmpfile.c
+
+libtests_a-create_tmpfile.obj: create_tmpfile.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT libtests_a-create_tmpfile.obj -MD -MP -MF $(DEPDIR)/libtests_a-create_tmpfile.Tpo -c -o libtests_a-create_tmpfile.obj `if test -f 'create_tmpfile.c'; then $(CYGPATH_W) 'create_tmpfile.c'; else $(CYGPATH_W) '$(srcdir)/create_tmpfile.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libtests_a-create_tmpfile.Tpo $(DEPDIR)/libtests_a-create_tmpfile.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='create_tmpfile.c' object='libtests_a-create_tmpfile.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-create_tmpfile.obj `if test -f 'create_tmpfile.c'; then $(CYGPATH_W) 'create_tmpfile.c'; else $(CYGPATH_W) '$(srcdir)/create_tmpfile.c'; fi`
+
 libtests_a-errno2name.o: errno2name.c
 @am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT libtests_a-errno2name.o -MD -MP -MF $(DEPDIR)/libtests_a-errno2name.Tpo -c -o libtests_a-errno2name.o `test -f 'errno2name.c' || echo '$(srcdir)/'`errno2name.c
 @am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libtests_a-errno2name.Tpo $(DEPDIR)/libtests_a-errno2name.Po
@@ -9324,6 +11341,20 @@ libtests_a-overflowuid.obj: overflowuid.
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
 @am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-overflowuid.obj `if test -f 'overflowuid.c'; then $(CYGPATH_W) 'overflowuid.c'; else $(CYGPATH_W) '$(srcdir)/overflowuid.c'; fi`
 
+libtests_a-pidns.o: pidns.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT libtests_a-pidns.o -MD -MP -MF $(DEPDIR)/libtests_a-pidns.Tpo -c -o libtests_a-pidns.o `test -f 'pidns.c' || echo '$(srcdir)/'`pidns.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libtests_a-pidns.Tpo $(DEPDIR)/libtests_a-pidns.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='pidns.c' object='libtests_a-pidns.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-pidns.o `test -f 'pidns.c' || echo '$(srcdir)/'`pidns.c
+
+libtests_a-pidns.obj: pidns.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT libtests_a-pidns.obj -MD -MP -MF $(DEPDIR)/libtests_a-pidns.Tpo -c -o libtests_a-pidns.obj `if test -f 'pidns.c'; then $(CYGPATH_W) 'pidns.c'; else $(CYGPATH_W) '$(srcdir)/pidns.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libtests_a-pidns.Tpo $(DEPDIR)/libtests_a-pidns.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='pidns.c' object='libtests_a-pidns.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-pidns.obj `if test -f 'pidns.c'; then $(CYGPATH_W) 'pidns.c'; else $(CYGPATH_W) '$(srcdir)/pidns.c'; fi`
+
 libtests_a-pipe_maxfd.o: pipe_maxfd.c
 @am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT libtests_a-pipe_maxfd.o -MD -MP -MF $(DEPDIR)/libtests_a-pipe_maxfd.Tpo -c -o libtests_a-pipe_maxfd.o `test -f 'pipe_maxfd.c' || echo '$(srcdir)/'`pipe_maxfd.c
 @am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libtests_a-pipe_maxfd.Tpo $(DEPDIR)/libtests_a-pipe_maxfd.Po
@@ -9548,6 +11579,20 @@ libtests_a-tprintf.obj: tprintf.c
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
 @am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-tprintf.obj `if test -f 'tprintf.c'; then $(CYGPATH_W) 'tprintf.c'; else $(CYGPATH_W) '$(srcdir)/tprintf.c'; fi`
 
+libtests_a-xmalloc_for_tests.o: xmalloc_for_tests.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT libtests_a-xmalloc_for_tests.o -MD -MP -MF $(DEPDIR)/libtests_a-xmalloc_for_tests.Tpo -c -o libtests_a-xmalloc_for_tests.o `test -f 'xmalloc_for_tests.c' || echo '$(srcdir)/'`xmalloc_for_tests.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libtests_a-xmalloc_for_tests.Tpo $(DEPDIR)/libtests_a-xmalloc_for_tests.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='xmalloc_for_tests.c' object='libtests_a-xmalloc_for_tests.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-xmalloc_for_tests.o `test -f 'xmalloc_for_tests.c' || echo '$(srcdir)/'`xmalloc_for_tests.c
+
+libtests_a-xmalloc_for_tests.obj: xmalloc_for_tests.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT libtests_a-xmalloc_for_tests.obj -MD -MP -MF $(DEPDIR)/libtests_a-xmalloc_for_tests.Tpo -c -o libtests_a-xmalloc_for_tests.obj `if test -f 'xmalloc_for_tests.c'; then $(CYGPATH_W) 'xmalloc_for_tests.c'; else $(CYGPATH_W) '$(srcdir)/xmalloc_for_tests.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/libtests_a-xmalloc_for_tests.Tpo $(DEPDIR)/libtests_a-xmalloc_for_tests.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='xmalloc_for_tests.c' object='libtests_a-xmalloc_for_tests.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(libtests_a_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o libtests_a-xmalloc_for_tests.obj `if test -f 'xmalloc_for_tests.c'; then $(CYGPATH_W) 'xmalloc_for_tests.c'; else $(CYGPATH_W) '$(srcdir)/xmalloc_for_tests.c'; fi`
+
 fstat64-fstat64.o: fstat64.c
 @am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(fstat64_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT fstat64-fstat64.o -MD -MP -MF $(DEPDIR)/fstat64-fstat64.Tpo -c -o fstat64-fstat64.o `test -f 'fstat64.c' || echo '$(srcdir)/'`fstat64.c
 @am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/fstat64-fstat64.Tpo $(DEPDIR)/fstat64-fstat64.Po
@@ -9758,6 +11803,34 @@ statfs-statfs.obj: statfs.c
 @AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
 @am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(statfs_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -c -o statfs-statfs.obj `if test -f 'statfs.c'; then $(CYGPATH_W) 'statfs.c'; else $(CYGPATH_W) '$(srcdir)/statfs.c'; fi`
 
+trie_test-trie_test.o: trie_test.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(trie_test_CPPFLAGS) $(CPPFLAGS) $(trie_test_CFLAGS) $(CFLAGS) -MT trie_test-trie_test.o -MD -MP -MF $(DEPDIR)/trie_test-trie_test.Tpo -c -o trie_test-trie_test.o `test -f 'trie_test.c' || echo '$(srcdir)/'`trie_test.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/trie_test-trie_test.Tpo $(DEPDIR)/trie_test-trie_test.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='trie_test.c' object='trie_test-trie_test.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(trie_test_CPPFLAGS) $(CPPFLAGS) $(trie_test_CFLAGS) $(CFLAGS) -c -o trie_test-trie_test.o `test -f 'trie_test.c' || echo '$(srcdir)/'`trie_test.c
+
+trie_test-trie_test.obj: trie_test.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(trie_test_CPPFLAGS) $(CPPFLAGS) $(trie_test_CFLAGS) $(CFLAGS) -MT trie_test-trie_test.obj -MD -MP -MF $(DEPDIR)/trie_test-trie_test.Tpo -c -o trie_test-trie_test.obj `if test -f 'trie_test.c'; then $(CYGPATH_W) 'trie_test.c'; else $(CYGPATH_W) '$(srcdir)/trie_test.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/trie_test-trie_test.Tpo $(DEPDIR)/trie_test-trie_test.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='trie_test.c' object='trie_test-trie_test.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(trie_test_CPPFLAGS) $(CPPFLAGS) $(trie_test_CFLAGS) $(CFLAGS) -c -o trie_test-trie_test.obj `if test -f 'trie_test.c'; then $(CYGPATH_W) 'trie_test.c'; else $(CYGPATH_W) '$(srcdir)/trie_test.c'; fi`
+
+trie_test-trie_for_tests.o: trie_for_tests.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(trie_test_CPPFLAGS) $(CPPFLAGS) $(trie_test_CFLAGS) $(CFLAGS) -MT trie_test-trie_for_tests.o -MD -MP -MF $(DEPDIR)/trie_test-trie_for_tests.Tpo -c -o trie_test-trie_for_tests.o `test -f 'trie_for_tests.c' || echo '$(srcdir)/'`trie_for_tests.c
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/trie_test-trie_for_tests.Tpo $(DEPDIR)/trie_test-trie_for_tests.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='trie_for_tests.c' object='trie_test-trie_for_tests.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(trie_test_CPPFLAGS) $(CPPFLAGS) $(trie_test_CFLAGS) $(CFLAGS) -c -o trie_test-trie_for_tests.o `test -f 'trie_for_tests.c' || echo '$(srcdir)/'`trie_for_tests.c
+
+trie_test-trie_for_tests.obj: trie_for_tests.c
+@am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(trie_test_CPPFLAGS) $(CPPFLAGS) $(trie_test_CFLAGS) $(CFLAGS) -MT trie_test-trie_for_tests.obj -MD -MP -MF $(DEPDIR)/trie_test-trie_for_tests.Tpo -c -o trie_test-trie_for_tests.obj `if test -f 'trie_for_tests.c'; then $(CYGPATH_W) 'trie_for_tests.c'; else $(CYGPATH_W) '$(srcdir)/trie_for_tests.c'; fi`
+@am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/trie_test-trie_for_tests.Tpo $(DEPDIR)/trie_test-trie_for_tests.Po
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	$(AM_V_CC)source='trie_for_tests.c' object='trie_test-trie_for_tests.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCC_FALSE@	DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCC_FALSE@	$(AM_V_CC@am__nodep@)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(trie_test_CPPFLAGS) $(CPPFLAGS) $(trie_test_CFLAGS) $(CFLAGS) -c -o trie_test-trie_for_tests.obj `if test -f 'trie_for_tests.c'; then $(CYGPATH_W) 'trie_for_tests.c'; else $(CYGPATH_W) '$(srcdir)/trie_for_tests.c'; fi`
+
 truncate64-truncate64.o: truncate64.c
 @am__fastdepCC_TRUE@	$(AM_V_CC)$(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(truncate64_CPPFLAGS) $(CPPFLAGS) $(AM_CFLAGS) $(CFLAGS) -MT truncate64-truncate64.o -MD -MP -MF $(DEPDIR)/truncate64-truncate64.Tpo -c -o truncate64-truncate64.o `test -f 'truncate64.c' || echo '$(srcdir)/'`truncate64.c
 @am__fastdepCC_TRUE@	$(AM_V_at)$(am__mv) $(DEPDIR)/truncate64-truncate64.Tpo $(DEPDIR)/truncate64-truncate64.Po
@@ -9950,7 +12023,7 @@ $(TEST_SUITE_LOG): $(TEST_LOGS)
 	  test x"$$VERBOSE" = x || cat $(TEST_SUITE_LOG);		\
 	fi;								\
 	echo "$${col}$$br$${std}"; 					\
-	echo "$${col}Testsuite summary for $(PACKAGE_STRING)$${std}";	\
+	echo "$${col}Testsuite summary"$(AM_TESTSUITE_SUMMARY_HEADER)"$${std}";	\
 	echo "$${col}$$br$${std}"; 					\
 	create_testsuite_report --maybe-color;				\
 	echo "$$col$$br$$std";						\
@@ -10123,6 +12196,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/bpf-obj_get_info_by_fd-prog.Po
 	-rm -f ./$(DEPDIR)/bpf-obj_get_info_by_fd-v.Po
 	-rm -f ./$(DEPDIR)/bpf-obj_get_info_by_fd.Po
+	-rm -f ./$(DEPDIR)/bpf-success-long-y.Po
 	-rm -f ./$(DEPDIR)/bpf-success-v.Po
 	-rm -f ./$(DEPDIR)/bpf-success.Po
 	-rm -f ./$(DEPDIR)/bpf-v.Po
@@ -10149,16 +12223,39 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/clone3-success-Xverbose.Po
 	-rm -f ./$(DEPDIR)/clone3-success.Po
 	-rm -f ./$(DEPDIR)/clone3.Po
+	-rm -f ./$(DEPDIR)/clone_parent--quiet-exit.Po
+	-rm -f ./$(DEPDIR)/clone_parent-q.Po
+	-rm -f ./$(DEPDIR)/clone_parent-qq.Po
 	-rm -f ./$(DEPDIR)/clone_parent.Po
+	-rm -f ./$(DEPDIR)/clone_ptrace--quiet-attach.Po
+	-rm -f ./$(DEPDIR)/clone_ptrace--quiet-exit.Po
+	-rm -f ./$(DEPDIR)/clone_ptrace-q.Po
+	-rm -f ./$(DEPDIR)/clone_ptrace-qq.Po
 	-rm -f ./$(DEPDIR)/clone_ptrace.Po
+	-rm -f ./$(DEPDIR)/close_range-P.Po
+	-rm -f ./$(DEPDIR)/close_range-y.Po
+	-rm -f ./$(DEPDIR)/close_range-yy.Po
+	-rm -f ./$(DEPDIR)/close_range.Po
 	-rm -f ./$(DEPDIR)/copy_file_range.Po
 	-rm -f ./$(DEPDIR)/count-f.Po
 	-rm -f ./$(DEPDIR)/creat.Po
 	-rm -f ./$(DEPDIR)/delay.Po
 	-rm -f ./$(DEPDIR)/delete_module.Po
+	-rm -f ./$(DEPDIR)/dev--decode-fds-dev.Po
+	-rm -f ./$(DEPDIR)/dev--decode-fds-path.Po
+	-rm -f ./$(DEPDIR)/dev--decode-fds-socket.Po
 	-rm -f ./$(DEPDIR)/dev-yy.Po
+	-rm -f ./$(DEPDIR)/dup-P.Po
+	-rm -f ./$(DEPDIR)/dup-y.Po
+	-rm -f ./$(DEPDIR)/dup-yy.Po
 	-rm -f ./$(DEPDIR)/dup.Po
+	-rm -f ./$(DEPDIR)/dup2-P.Po
+	-rm -f ./$(DEPDIR)/dup2-y.Po
+	-rm -f ./$(DEPDIR)/dup2-yy.Po
 	-rm -f ./$(DEPDIR)/dup2.Po
+	-rm -f ./$(DEPDIR)/dup3-P.Po
+	-rm -f ./$(DEPDIR)/dup3-y.Po
+	-rm -f ./$(DEPDIR)/dup3-yy.Po
 	-rm -f ./$(DEPDIR)/dup3.Po
 	-rm -f ./$(DEPDIR)/epoll_create.Po
 	-rm -f ./$(DEPDIR)/epoll_create1.Po
@@ -10171,7 +12268,14 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/execve.Po
 	-rm -f ./$(DEPDIR)/execveat-v.Po
 	-rm -f ./$(DEPDIR)/execveat.Po
+	-rm -f ./$(DEPDIR)/faccessat-P.Po
+	-rm -f ./$(DEPDIR)/faccessat-y.Po
+	-rm -f ./$(DEPDIR)/faccessat-yy.Po
 	-rm -f ./$(DEPDIR)/faccessat.Po
+	-rm -f ./$(DEPDIR)/faccessat2-P.Po
+	-rm -f ./$(DEPDIR)/faccessat2-y.Po
+	-rm -f ./$(DEPDIR)/faccessat2-yy.Po
+	-rm -f ./$(DEPDIR)/faccessat2.Po
 	-rm -f ./$(DEPDIR)/fadvise64.Po
 	-rm -f ./$(DEPDIR)/fadvise64_64.Po
 	-rm -f ./$(DEPDIR)/fallocate.Po
@@ -10186,7 +12290,9 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/fchown.Po
 	-rm -f ./$(DEPDIR)/fchown32.Po
 	-rm -f ./$(DEPDIR)/fchownat.Po
+	-rm -f ./$(DEPDIR)/fcntl--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/fcntl.Po
+	-rm -f ./$(DEPDIR)/fcntl64--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/fcntl64.Po
 	-rm -f ./$(DEPDIR)/fdatasync.Po
 	-rm -f ./$(DEPDIR)/fflush.Po
@@ -10197,6 +12303,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/filter_seccomp-perf.Po
 	-rm -f ./$(DEPDIR)/finit_module.Po
 	-rm -f ./$(DEPDIR)/flock.Po
+	-rm -f ./$(DEPDIR)/fork--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/fork-f.Po
 	-rm -f ./$(DEPDIR)/fsconfig-P.Po
 	-rm -f ./$(DEPDIR)/fsconfig.Po
@@ -10222,9 +12329,12 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/futex.Po
 	-rm -f ./$(DEPDIR)/futimesat.Po
 	-rm -f ./$(DEPDIR)/get_mempolicy.Po
+	-rm -f ./$(DEPDIR)/get_process_reaper.Po
 	-rm -f ./$(DEPDIR)/getcpu.Po
 	-rm -f ./$(DEPDIR)/getcwd.Po
+	-rm -f ./$(DEPDIR)/getdents-v.Po
 	-rm -f ./$(DEPDIR)/getdents.Po
+	-rm -f ./$(DEPDIR)/getdents64-v.Po
 	-rm -f ./$(DEPDIR)/getdents64.Po
 	-rm -f ./$(DEPDIR)/getegid.Po
 	-rm -f ./$(DEPDIR)/getegid32.Po
@@ -10235,7 +12345,9 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/getgroups.Po
 	-rm -f ./$(DEPDIR)/getgroups32.Po
 	-rm -f ./$(DEPDIR)/getpeername.Po
+	-rm -f ./$(DEPDIR)/getpgrp--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/getpgrp.Po
+	-rm -f ./$(DEPDIR)/getpid--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/getpid.Po
 	-rm -f ./$(DEPDIR)/getppid.Po
 	-rm -f ./$(DEPDIR)/getrandom.Po
@@ -10245,12 +12357,16 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/getresuid32.Po
 	-rm -f ./$(DEPDIR)/getrlimit.Po
 	-rm -f ./$(DEPDIR)/getrusage.Po
+	-rm -f ./$(DEPDIR)/getsid--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/getsid.Po
 	-rm -f ./$(DEPDIR)/getsockname.Po
+	-rm -f ./$(DEPDIR)/gettid--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/gettid.Po
 	-rm -f ./$(DEPDIR)/getuid.Po
 	-rm -f ./$(DEPDIR)/getuid32.Po
-	-rm -f ./$(DEPDIR)/getxxid.Po
+	-rm -f ./$(DEPDIR)/getxgid.Po
+	-rm -f ./$(DEPDIR)/getxpid.Po
+	-rm -f ./$(DEPDIR)/getxuid.Po
 	-rm -f ./$(DEPDIR)/group_req.Po
 	-rm -f ./$(DEPDIR)/inet-cmsg.Po
 	-rm -f ./$(DEPDIR)/init_module.Po
@@ -10265,6 +12381,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/io_uring_register.Po
 	-rm -f ./$(DEPDIR)/io_uring_setup.Po
 	-rm -f ./$(DEPDIR)/ioctl.Po
+	-rm -f ./$(DEPDIR)/ioctl_block--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/ioctl_block.Po
 	-rm -f ./$(DEPDIR)/ioctl_dm-v.Po
 	-rm -f ./$(DEPDIR)/ioctl_dm.Po
@@ -10284,6 +12401,22 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/ioctl_evdev-v-Xverbose.Po
 	-rm -f ./$(DEPDIR)/ioctl_evdev-v.Po
 	-rm -f ./$(DEPDIR)/ioctl_evdev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-v-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-v-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-v-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-v.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-v-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-v-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-v-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-v.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio.Po
 	-rm -f ./$(DEPDIR)/ioctl_inotify.Po
 	-rm -f ./$(DEPDIR)/ioctl_kvm_run-v.Po
 	-rm -f ./$(DEPDIR)/ioctl_kvm_run.Po
@@ -10304,11 +12437,28 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/ioctl_sg_io_v3.Po
 	-rm -f ./$(DEPDIR)/ioctl_sg_io_v4.Po
 	-rm -f ./$(DEPDIR)/ioctl_sock_gifconf.Po
+	-rm -f ./$(DEPDIR)/ioctl_tee.Po
 	-rm -f ./$(DEPDIR)/ioctl_uffdio.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-v-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-v-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-v-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-v.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-v-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-v-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-v-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-v.Po
 	-rm -f ./$(DEPDIR)/ioctl_v4l2.Po
 	-rm -f ./$(DEPDIR)/ioctl_watchdog.Po
 	-rm -f ./$(DEPDIR)/ioperm.Po
 	-rm -f ./$(DEPDIR)/iopl.Po
+	-rm -f ./$(DEPDIR)/ioprio--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/ioprio-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/ioprio-Xraw.Po
 	-rm -f ./$(DEPDIR)/ioprio-Xverbose.Po
@@ -10332,6 +12482,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/ipc_shm-Xverbose.Po
 	-rm -f ./$(DEPDIR)/ipc_shm.Po
 	-rm -f ./$(DEPDIR)/is_linux_mips_n64.Po
+	-rm -f ./$(DEPDIR)/kcmp-y--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/kcmp-y.Po
 	-rm -f ./$(DEPDIR)/kcmp.Po
 	-rm -f ./$(DEPDIR)/kern_features.Po
@@ -10345,12 +12496,14 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/keyctl-Xraw.Po
 	-rm -f ./$(DEPDIR)/keyctl-Xverbose.Po
 	-rm -f ./$(DEPDIR)/keyctl.Po
+	-rm -f ./$(DEPDIR)/kill--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/kill.Po
 	-rm -f ./$(DEPDIR)/kill_child.Po
 	-rm -f ./$(DEPDIR)/ksysent.Po
 	-rm -f ./$(DEPDIR)/lchown.Po
 	-rm -f ./$(DEPDIR)/lchown32.Po
 	-rm -f ./$(DEPDIR)/libtests_a-create_nl_socket.Po
+	-rm -f ./$(DEPDIR)/libtests_a-create_tmpfile.Po
 	-rm -f ./$(DEPDIR)/libtests_a-errno2name.Po
 	-rm -f ./$(DEPDIR)/libtests_a-error_msg.Po
 	-rm -f ./$(DEPDIR)/libtests_a-fill_memory.Po
@@ -10364,6 +12517,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/libtests_a-libsocketcall.Po
 	-rm -f ./$(DEPDIR)/libtests_a-lock_file.Po
 	-rm -f ./$(DEPDIR)/libtests_a-overflowuid.Po
+	-rm -f ./$(DEPDIR)/libtests_a-pidns.Po
 	-rm -f ./$(DEPDIR)/libtests_a-pipe_maxfd.Po
 	-rm -f ./$(DEPDIR)/libtests_a-print_quoted_string.Po
 	-rm -f ./$(DEPDIR)/libtests_a-print_time.Po
@@ -10380,6 +12534,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/libtests_a-test_printstrn.Po
 	-rm -f ./$(DEPDIR)/libtests_a-test_ucopy.Po
 	-rm -f ./$(DEPDIR)/libtests_a-tprintf.Po
+	-rm -f ./$(DEPDIR)/libtests_a-xmalloc_for_tests.Po
 	-rm -f ./$(DEPDIR)/link.Po
 	-rm -f ./$(DEPDIR)/linkat.Po
 	-rm -f ./$(DEPDIR)/list_sigaction_signum.Po
@@ -10391,6 +12546,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/lstat.Po
 	-rm -f ./$(DEPDIR)/lstat64-lstat64.Po
 	-rm -f ./$(DEPDIR)/madvise.Po
+	-rm -f ./$(DEPDIR)/maybe_switch_current_tcp--quiet-thread-execve.Po
 	-rm -f ./$(DEPDIR)/maybe_switch_current_tcp.Po
 	-rm -f ./$(DEPDIR)/mbind-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/mbind-Xraw.Po
@@ -10401,6 +12557,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/memfd_create-Xraw.Po
 	-rm -f ./$(DEPDIR)/memfd_create-Xverbose.Po
 	-rm -f ./$(DEPDIR)/memfd_create.Po
+	-rm -f ./$(DEPDIR)/migrate_pages--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/migrate_pages.Po
 	-rm -f ./$(DEPDIR)/mincore.Po
 	-rm -f ./$(DEPDIR)/mkdir.Po
@@ -10429,6 +12586,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/mount.Po
 	-rm -f ./$(DEPDIR)/move_mount-P.Po
 	-rm -f ./$(DEPDIR)/move_mount.Po
+	-rm -f ./$(DEPDIR)/move_pages--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/move_pages-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/move_pages-Xraw.Po
 	-rm -f ./$(DEPDIR)/move_pages-Xverbose.Po
@@ -10442,12 +12600,17 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/msg_name.Po
 	-rm -f ./$(DEPDIR)/munlockall.Po
 	-rm -f ./$(DEPDIR)/nanosleep.Po
+	-rm -f ./$(DEPDIR)/net--decode-fds-dev-netlink.Po
+	-rm -f ./$(DEPDIR)/net--decode-fds-none-netlink.Po
+	-rm -f ./$(DEPDIR)/net--decode-fds-path-netlink.Po
+	-rm -f ./$(DEPDIR)/net--decode-fds-socket-netlink.Po
 	-rm -f ./$(DEPDIR)/net-accept-connect.Po
 	-rm -f ./$(DEPDIR)/net-icmp_filter.Po
 	-rm -f ./$(DEPDIR)/net-packet_mreq-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/net-packet_mreq-Xraw.Po
 	-rm -f ./$(DEPDIR)/net-packet_mreq-Xverbose.Po
 	-rm -f ./$(DEPDIR)/net-packet_mreq.Po
+	-rm -f ./$(DEPDIR)/net-sockaddr--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/net-sockaddr.Po
 	-rm -f ./$(DEPDIR)/net-tpacket_req.Po
 	-rm -f ./$(DEPDIR)/net-tpacket_stats-success.Po
@@ -10457,6 +12620,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/net-yy-inet6.Po
 	-rm -f ./$(DEPDIR)/net-yy-netlink.Po
 	-rm -f ./$(DEPDIR)/net-yy-unix.Po
+	-rm -f ./$(DEPDIR)/netlink_audit--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/netlink_audit.Po
 	-rm -f ./$(DEPDIR)/netlink_crypto.Po
 	-rm -f ./$(DEPDIR)/netlink_generic.Po
@@ -10494,6 +12658,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/nlattr_ifla_brport.Po
 	-rm -f ./$(DEPDIR)/nlattr_ifla_linkinfo.Po
 	-rm -f ./$(DEPDIR)/nlattr_ifla_port.Po
+	-rm -f ./$(DEPDIR)/nlattr_ifla_xdp-y.Po
 	-rm -f ./$(DEPDIR)/nlattr_ifla_xdp.Po
 	-rm -f ./$(DEPDIR)/nlattr_inet_diag_msg.Po
 	-rm -f ./$(DEPDIR)/nlattr_inet_diag_req_compat.Po
@@ -10533,6 +12698,16 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/open_tree-P.Po
 	-rm -f ./$(DEPDIR)/open_tree.Po
 	-rm -f ./$(DEPDIR)/openat.Po
+	-rm -f ./$(DEPDIR)/openat2-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/openat2-Xraw.Po
+	-rm -f ./$(DEPDIR)/openat2-Xverbose.Po
+	-rm -f ./$(DEPDIR)/openat2-v-y-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/openat2-v-y-Xraw.Po
+	-rm -f ./$(DEPDIR)/openat2-v-y-Xverbose.Po
+	-rm -f ./$(DEPDIR)/openat2-v-y.Po
+	-rm -f ./$(DEPDIR)/openat2-v.Po
+	-rm -f ./$(DEPDIR)/openat2-y.Po
+	-rm -f ./$(DEPDIR)/openat2.Po
 	-rm -f ./$(DEPDIR)/orphaned_process_group.Po
 	-rm -f ./$(DEPDIR)/osf_utimes.Po
 	-rm -f ./$(DEPDIR)/pause.Po
@@ -10544,10 +12719,20 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/personality-Xraw.Po
 	-rm -f ./$(DEPDIR)/personality-Xverbose.Po
 	-rm -f ./$(DEPDIR)/personality.Po
+	-rm -f ./$(DEPDIR)/pidfd_getfd-y.Po
+	-rm -f ./$(DEPDIR)/pidfd_getfd-yy.Po
+	-rm -f ./$(DEPDIR)/pidfd_getfd.Po
+	-rm -f ./$(DEPDIR)/pidfd_open--decode-fd-path.Po
+	-rm -f ./$(DEPDIR)/pidfd_open--decode-fd-pidfd.Po
+	-rm -f ./$(DEPDIR)/pidfd_open--decode-fd-socket.Po
+	-rm -f ./$(DEPDIR)/pidfd_open--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/pidfd_open-P.Po
 	-rm -f ./$(DEPDIR)/pidfd_open-y.Po
+	-rm -f ./$(DEPDIR)/pidfd_open-yy.Po
 	-rm -f ./$(DEPDIR)/pidfd_open.Po
+	-rm -f ./$(DEPDIR)/pidfd_send_signal--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/pidfd_send_signal.Po
+	-rm -f ./$(DEPDIR)/pidns-cache.Po
 	-rm -f ./$(DEPDIR)/pipe.Po
 	-rm -f ./$(DEPDIR)/pipe2.Po
 	-rm -f ./$(DEPDIR)/pkey_alloc.Po
@@ -10574,6 +12759,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/preadv2-pwritev2.Po
 	-rm -f ./$(DEPDIR)/preadv_pwritev-preadv-pwritev.Po
 	-rm -f ./$(DEPDIR)/print_maxfd.Po
+	-rm -f ./$(DEPDIR)/print_ppid_tracerpid.Po
 	-rm -f ./$(DEPDIR)/printpath-umovestr-peekdata.Po
 	-rm -f ./$(DEPDIR)/printpath-umovestr-undumpable.Po
 	-rm -f ./$(DEPDIR)/printpath-umovestr.Po
@@ -10584,8 +12770,11 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/printstrn-umoven-peekdata.Po
 	-rm -f ./$(DEPDIR)/printstrn-umoven-undumpable.Po
 	-rm -f ./$(DEPDIR)/printstrn-umoven.Po
+	-rm -f ./$(DEPDIR)/prlimit64--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/prlimit64.Po
+	-rm -f ./$(DEPDIR)/process_vm_readv--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/process_vm_readv.Po
+	-rm -f ./$(DEPDIR)/process_vm_writev--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/process_vm_writev.Po
 	-rm -f ./$(DEPDIR)/pselect6.Po
 	-rm -f ./$(DEPDIR)/ptrace.Po
@@ -10634,10 +12823,12 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/rt_sigaction.Po
 	-rm -f ./$(DEPDIR)/rt_sigpending.Po
 	-rm -f ./$(DEPDIR)/rt_sigprocmask.Po
+	-rm -f ./$(DEPDIR)/rt_sigqueueinfo--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/rt_sigqueueinfo.Po
 	-rm -f ./$(DEPDIR)/rt_sigreturn.Po
 	-rm -f ./$(DEPDIR)/rt_sigsuspend.Po
 	-rm -f ./$(DEPDIR)/rt_sigtimedwait.Po
+	-rm -f ./$(DEPDIR)/rt_tgsigqueueinfo--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/rt_tgsigqueueinfo.Po
 	-rm -f ./$(DEPDIR)/run_expect_termsig.Po
 	-rm -f ./$(DEPDIR)/s390_guarded_storage-v.Po
@@ -10648,9 +12839,13 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/s390_sthyi.Po
 	-rm -f ./$(DEPDIR)/sched_get_priority_mxx.Po
 	-rm -f ./$(DEPDIR)/sched_rr_get_interval.Po
+	-rm -f ./$(DEPDIR)/sched_xetaffinity--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/sched_xetaffinity.Po
+	-rm -f ./$(DEPDIR)/sched_xetattr--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/sched_xetattr.Po
+	-rm -f ./$(DEPDIR)/sched_xetparam--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/sched_xetparam.Po
+	-rm -f ./$(DEPDIR)/sched_xetscheduler--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/sched_xetscheduler.Po
 	-rm -f ./$(DEPDIR)/sched_yield.Po
 	-rm -f ./$(DEPDIR)/scm_rights.Po
@@ -10683,6 +12878,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/setgroups32.Po
 	-rm -f ./$(DEPDIR)/sethostname.Po
 	-rm -f ./$(DEPDIR)/setns.Po
+	-rm -f ./$(DEPDIR)/setpgrp-exec.Po
 	-rm -f ./$(DEPDIR)/setregid.Po
 	-rm -f ./$(DEPDIR)/setregid32.Po
 	-rm -f ./$(DEPDIR)/setresgid.Po
@@ -10703,6 +12899,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/sigaltstack.Po
 	-rm -f ./$(DEPDIR)/siginfo.Po
 	-rm -f ./$(DEPDIR)/signal.Po
+	-rm -f ./$(DEPDIR)/signal_receive--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/signal_receive.Po
 	-rm -f ./$(DEPDIR)/signalfd4.Po
 	-rm -f ./$(DEPDIR)/sigpending.Po
@@ -10712,6 +12909,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/sleep.Po
 	-rm -f ./$(DEPDIR)/so_error.Po
 	-rm -f ./$(DEPDIR)/so_linger.Po
+	-rm -f ./$(DEPDIR)/so_peercred--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/so_peercred-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/so_peercred-Xraw.Po
 	-rm -f ./$(DEPDIR)/so_peercred-Xverbose.Po
@@ -10743,14 +12941,24 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/statfs-statfs.Po
 	-rm -f ./$(DEPDIR)/statfs64.Po
 	-rm -f ./$(DEPDIR)/status-all.Po
+	-rm -f ./$(DEPDIR)/status-failed-long.Po
+	-rm -f ./$(DEPDIR)/status-failed-status.Po
 	-rm -f ./$(DEPDIR)/status-failed.Po
 	-rm -f ./$(DEPDIR)/status-none-f.Po
 	-rm -f ./$(DEPDIR)/status-none-threads.Po
 	-rm -f ./$(DEPDIR)/status-none.Po
+	-rm -f ./$(DEPDIR)/status-successful-long.Po
+	-rm -f ./$(DEPDIR)/status-successful-status.Po
 	-rm -f ./$(DEPDIR)/status-successful.Po
 	-rm -f ./$(DEPDIR)/status-unfinished-threads.Po
 	-rm -f ./$(DEPDIR)/status-unfinished.Po
 	-rm -f ./$(DEPDIR)/statx.Po
+	-rm -f ./$(DEPDIR)/strace--strings-in-hex-all.Po
+	-rm -f ./$(DEPDIR)/strace--strings-in-hex-non-ascii.Po
+	-rm -f ./$(DEPDIR)/strace--strings-in-hex.Po
+	-rm -f ./$(DEPDIR)/strace-n.Po
+	-rm -f ./$(DEPDIR)/strace-x.Po
+	-rm -f ./$(DEPDIR)/strace-xx.Po
 	-rm -f ./$(DEPDIR)/swap.Po
 	-rm -f ./$(DEPDIR)/sxetmask.Po
 	-rm -f ./$(DEPDIR)/symlink.Po
@@ -10762,6 +12970,12 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/syslog-success.Po
 	-rm -f ./$(DEPDIR)/syslog.Po
 	-rm -f ./$(DEPDIR)/tee.Po
+	-rm -f ./$(DEPDIR)/tgkill--pidns-translation.Po
+	-rm -f ./$(DEPDIR)/tgkill.Po
+	-rm -f ./$(DEPDIR)/threads-execve--quiet-thread-execve.Po
+	-rm -f ./$(DEPDIR)/threads-execve-q.Po
+	-rm -f ./$(DEPDIR)/threads-execve-qq.Po
+	-rm -f ./$(DEPDIR)/threads-execve-qqq.Po
 	-rm -f ./$(DEPDIR)/threads-execve.Po
 	-rm -f ./$(DEPDIR)/time.Po
 	-rm -f ./$(DEPDIR)/timer_create.Po
@@ -10769,7 +12983,11 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/timerfd_xettime.Po
 	-rm -f ./$(DEPDIR)/times-fail.Po
 	-rm -f ./$(DEPDIR)/times.Po
+	-rm -f ./$(DEPDIR)/tkill--pidns-translation.Po
+	-rm -f ./$(DEPDIR)/tkill.Po
 	-rm -f ./$(DEPDIR)/tracer_ppid_pgid_sid.Po
+	-rm -f ./$(DEPDIR)/trie_test-trie_for_tests.Po
+	-rm -f ./$(DEPDIR)/trie_test-trie_test.Po
 	-rm -f ./$(DEPDIR)/truncate.Po
 	-rm -f ./$(DEPDIR)/truncate64-truncate64.Po
 	-rm -f ./$(DEPDIR)/ugetrlimit.Po
@@ -10783,6 +13001,7 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/umovestr2.Po
 	-rm -f ./$(DEPDIR)/umovestr3.Po
 	-rm -f ./$(DEPDIR)/umovestr_cached.Po
+	-rm -f ./$(DEPDIR)/umovestr_cached_adjacent.Po
 	-rm -f ./$(DEPDIR)/uname.Po
 	-rm -f ./$(DEPDIR)/unblock_reset_raise.Po
 	-rm -f ./$(DEPDIR)/unix-pair-send-recv.Po
@@ -10808,10 +13027,13 @@ distclean: distclean-am
 	-rm -f ./$(DEPDIR)/waitpid.Po
 	-rm -f ./$(DEPDIR)/xattr-strings.Po
 	-rm -f ./$(DEPDIR)/xattr.Po
+	-rm -f ./$(DEPDIR)/xet_robust_list--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/xet_robust_list.Po
 	-rm -f ./$(DEPDIR)/xet_thread_area_x86.Po
 	-rm -f ./$(DEPDIR)/xetitimer.Po
+	-rm -f ./$(DEPDIR)/xetpgid--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/xetpgid.Po
+	-rm -f ./$(DEPDIR)/xetpriority--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/xetpriority.Po
 	-rm -f ./$(DEPDIR)/xettimeofday.Po
 	-rm -f ./$(DEPDIR)/zeroargc.Po
@@ -10882,6 +13104,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/bpf-obj_get_info_by_fd-prog.Po
 	-rm -f ./$(DEPDIR)/bpf-obj_get_info_by_fd-v.Po
 	-rm -f ./$(DEPDIR)/bpf-obj_get_info_by_fd.Po
+	-rm -f ./$(DEPDIR)/bpf-success-long-y.Po
 	-rm -f ./$(DEPDIR)/bpf-success-v.Po
 	-rm -f ./$(DEPDIR)/bpf-success.Po
 	-rm -f ./$(DEPDIR)/bpf-v.Po
@@ -10908,16 +13131,39 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/clone3-success-Xverbose.Po
 	-rm -f ./$(DEPDIR)/clone3-success.Po
 	-rm -f ./$(DEPDIR)/clone3.Po
+	-rm -f ./$(DEPDIR)/clone_parent--quiet-exit.Po
+	-rm -f ./$(DEPDIR)/clone_parent-q.Po
+	-rm -f ./$(DEPDIR)/clone_parent-qq.Po
 	-rm -f ./$(DEPDIR)/clone_parent.Po
+	-rm -f ./$(DEPDIR)/clone_ptrace--quiet-attach.Po
+	-rm -f ./$(DEPDIR)/clone_ptrace--quiet-exit.Po
+	-rm -f ./$(DEPDIR)/clone_ptrace-q.Po
+	-rm -f ./$(DEPDIR)/clone_ptrace-qq.Po
 	-rm -f ./$(DEPDIR)/clone_ptrace.Po
+	-rm -f ./$(DEPDIR)/close_range-P.Po
+	-rm -f ./$(DEPDIR)/close_range-y.Po
+	-rm -f ./$(DEPDIR)/close_range-yy.Po
+	-rm -f ./$(DEPDIR)/close_range.Po
 	-rm -f ./$(DEPDIR)/copy_file_range.Po
 	-rm -f ./$(DEPDIR)/count-f.Po
 	-rm -f ./$(DEPDIR)/creat.Po
 	-rm -f ./$(DEPDIR)/delay.Po
 	-rm -f ./$(DEPDIR)/delete_module.Po
+	-rm -f ./$(DEPDIR)/dev--decode-fds-dev.Po
+	-rm -f ./$(DEPDIR)/dev--decode-fds-path.Po
+	-rm -f ./$(DEPDIR)/dev--decode-fds-socket.Po
 	-rm -f ./$(DEPDIR)/dev-yy.Po
+	-rm -f ./$(DEPDIR)/dup-P.Po
+	-rm -f ./$(DEPDIR)/dup-y.Po
+	-rm -f ./$(DEPDIR)/dup-yy.Po
 	-rm -f ./$(DEPDIR)/dup.Po
+	-rm -f ./$(DEPDIR)/dup2-P.Po
+	-rm -f ./$(DEPDIR)/dup2-y.Po
+	-rm -f ./$(DEPDIR)/dup2-yy.Po
 	-rm -f ./$(DEPDIR)/dup2.Po
+	-rm -f ./$(DEPDIR)/dup3-P.Po
+	-rm -f ./$(DEPDIR)/dup3-y.Po
+	-rm -f ./$(DEPDIR)/dup3-yy.Po
 	-rm -f ./$(DEPDIR)/dup3.Po
 	-rm -f ./$(DEPDIR)/epoll_create.Po
 	-rm -f ./$(DEPDIR)/epoll_create1.Po
@@ -10930,7 +13176,14 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/execve.Po
 	-rm -f ./$(DEPDIR)/execveat-v.Po
 	-rm -f ./$(DEPDIR)/execveat.Po
+	-rm -f ./$(DEPDIR)/faccessat-P.Po
+	-rm -f ./$(DEPDIR)/faccessat-y.Po
+	-rm -f ./$(DEPDIR)/faccessat-yy.Po
 	-rm -f ./$(DEPDIR)/faccessat.Po
+	-rm -f ./$(DEPDIR)/faccessat2-P.Po
+	-rm -f ./$(DEPDIR)/faccessat2-y.Po
+	-rm -f ./$(DEPDIR)/faccessat2-yy.Po
+	-rm -f ./$(DEPDIR)/faccessat2.Po
 	-rm -f ./$(DEPDIR)/fadvise64.Po
 	-rm -f ./$(DEPDIR)/fadvise64_64.Po
 	-rm -f ./$(DEPDIR)/fallocate.Po
@@ -10945,7 +13198,9 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/fchown.Po
 	-rm -f ./$(DEPDIR)/fchown32.Po
 	-rm -f ./$(DEPDIR)/fchownat.Po
+	-rm -f ./$(DEPDIR)/fcntl--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/fcntl.Po
+	-rm -f ./$(DEPDIR)/fcntl64--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/fcntl64.Po
 	-rm -f ./$(DEPDIR)/fdatasync.Po
 	-rm -f ./$(DEPDIR)/fflush.Po
@@ -10956,6 +13211,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/filter_seccomp-perf.Po
 	-rm -f ./$(DEPDIR)/finit_module.Po
 	-rm -f ./$(DEPDIR)/flock.Po
+	-rm -f ./$(DEPDIR)/fork--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/fork-f.Po
 	-rm -f ./$(DEPDIR)/fsconfig-P.Po
 	-rm -f ./$(DEPDIR)/fsconfig.Po
@@ -10981,9 +13237,12 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/futex.Po
 	-rm -f ./$(DEPDIR)/futimesat.Po
 	-rm -f ./$(DEPDIR)/get_mempolicy.Po
+	-rm -f ./$(DEPDIR)/get_process_reaper.Po
 	-rm -f ./$(DEPDIR)/getcpu.Po
 	-rm -f ./$(DEPDIR)/getcwd.Po
+	-rm -f ./$(DEPDIR)/getdents-v.Po
 	-rm -f ./$(DEPDIR)/getdents.Po
+	-rm -f ./$(DEPDIR)/getdents64-v.Po
 	-rm -f ./$(DEPDIR)/getdents64.Po
 	-rm -f ./$(DEPDIR)/getegid.Po
 	-rm -f ./$(DEPDIR)/getegid32.Po
@@ -10994,7 +13253,9 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/getgroups.Po
 	-rm -f ./$(DEPDIR)/getgroups32.Po
 	-rm -f ./$(DEPDIR)/getpeername.Po
+	-rm -f ./$(DEPDIR)/getpgrp--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/getpgrp.Po
+	-rm -f ./$(DEPDIR)/getpid--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/getpid.Po
 	-rm -f ./$(DEPDIR)/getppid.Po
 	-rm -f ./$(DEPDIR)/getrandom.Po
@@ -11004,12 +13265,16 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/getresuid32.Po
 	-rm -f ./$(DEPDIR)/getrlimit.Po
 	-rm -f ./$(DEPDIR)/getrusage.Po
+	-rm -f ./$(DEPDIR)/getsid--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/getsid.Po
 	-rm -f ./$(DEPDIR)/getsockname.Po
+	-rm -f ./$(DEPDIR)/gettid--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/gettid.Po
 	-rm -f ./$(DEPDIR)/getuid.Po
 	-rm -f ./$(DEPDIR)/getuid32.Po
-	-rm -f ./$(DEPDIR)/getxxid.Po
+	-rm -f ./$(DEPDIR)/getxgid.Po
+	-rm -f ./$(DEPDIR)/getxpid.Po
+	-rm -f ./$(DEPDIR)/getxuid.Po
 	-rm -f ./$(DEPDIR)/group_req.Po
 	-rm -f ./$(DEPDIR)/inet-cmsg.Po
 	-rm -f ./$(DEPDIR)/init_module.Po
@@ -11024,6 +13289,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/io_uring_register.Po
 	-rm -f ./$(DEPDIR)/io_uring_setup.Po
 	-rm -f ./$(DEPDIR)/ioctl.Po
+	-rm -f ./$(DEPDIR)/ioctl_block--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/ioctl_block.Po
 	-rm -f ./$(DEPDIR)/ioctl_dm-v.Po
 	-rm -f ./$(DEPDIR)/ioctl_dm.Po
@@ -11043,6 +13309,22 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/ioctl_evdev-v-Xverbose.Po
 	-rm -f ./$(DEPDIR)/ioctl_evdev-v.Po
 	-rm -f ./$(DEPDIR)/ioctl_evdev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-v-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-v-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-v-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success-v.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-success.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-v-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-v-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-v-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio-v.Po
+	-rm -f ./$(DEPDIR)/ioctl_hdio.Po
 	-rm -f ./$(DEPDIR)/ioctl_inotify.Po
 	-rm -f ./$(DEPDIR)/ioctl_kvm_run-v.Po
 	-rm -f ./$(DEPDIR)/ioctl_kvm_run.Po
@@ -11063,11 +13345,28 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/ioctl_sg_io_v3.Po
 	-rm -f ./$(DEPDIR)/ioctl_sg_io_v4.Po
 	-rm -f ./$(DEPDIR)/ioctl_sock_gifconf.Po
+	-rm -f ./$(DEPDIR)/ioctl_tee.Po
 	-rm -f ./$(DEPDIR)/ioctl_uffdio.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-v-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-v-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-v-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success-v.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-success.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-v-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-v-Xraw.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-v-Xverbose.Po
+	-rm -f ./$(DEPDIR)/ioctl_v4l2-v.Po
 	-rm -f ./$(DEPDIR)/ioctl_v4l2.Po
 	-rm -f ./$(DEPDIR)/ioctl_watchdog.Po
 	-rm -f ./$(DEPDIR)/ioperm.Po
 	-rm -f ./$(DEPDIR)/iopl.Po
+	-rm -f ./$(DEPDIR)/ioprio--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/ioprio-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/ioprio-Xraw.Po
 	-rm -f ./$(DEPDIR)/ioprio-Xverbose.Po
@@ -11091,6 +13390,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/ipc_shm-Xverbose.Po
 	-rm -f ./$(DEPDIR)/ipc_shm.Po
 	-rm -f ./$(DEPDIR)/is_linux_mips_n64.Po
+	-rm -f ./$(DEPDIR)/kcmp-y--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/kcmp-y.Po
 	-rm -f ./$(DEPDIR)/kcmp.Po
 	-rm -f ./$(DEPDIR)/kern_features.Po
@@ -11104,12 +13404,14 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/keyctl-Xraw.Po
 	-rm -f ./$(DEPDIR)/keyctl-Xverbose.Po
 	-rm -f ./$(DEPDIR)/keyctl.Po
+	-rm -f ./$(DEPDIR)/kill--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/kill.Po
 	-rm -f ./$(DEPDIR)/kill_child.Po
 	-rm -f ./$(DEPDIR)/ksysent.Po
 	-rm -f ./$(DEPDIR)/lchown.Po
 	-rm -f ./$(DEPDIR)/lchown32.Po
 	-rm -f ./$(DEPDIR)/libtests_a-create_nl_socket.Po
+	-rm -f ./$(DEPDIR)/libtests_a-create_tmpfile.Po
 	-rm -f ./$(DEPDIR)/libtests_a-errno2name.Po
 	-rm -f ./$(DEPDIR)/libtests_a-error_msg.Po
 	-rm -f ./$(DEPDIR)/libtests_a-fill_memory.Po
@@ -11123,6 +13425,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/libtests_a-libsocketcall.Po
 	-rm -f ./$(DEPDIR)/libtests_a-lock_file.Po
 	-rm -f ./$(DEPDIR)/libtests_a-overflowuid.Po
+	-rm -f ./$(DEPDIR)/libtests_a-pidns.Po
 	-rm -f ./$(DEPDIR)/libtests_a-pipe_maxfd.Po
 	-rm -f ./$(DEPDIR)/libtests_a-print_quoted_string.Po
 	-rm -f ./$(DEPDIR)/libtests_a-print_time.Po
@@ -11139,6 +13442,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/libtests_a-test_printstrn.Po
 	-rm -f ./$(DEPDIR)/libtests_a-test_ucopy.Po
 	-rm -f ./$(DEPDIR)/libtests_a-tprintf.Po
+	-rm -f ./$(DEPDIR)/libtests_a-xmalloc_for_tests.Po
 	-rm -f ./$(DEPDIR)/link.Po
 	-rm -f ./$(DEPDIR)/linkat.Po
 	-rm -f ./$(DEPDIR)/list_sigaction_signum.Po
@@ -11150,6 +13454,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/lstat.Po
 	-rm -f ./$(DEPDIR)/lstat64-lstat64.Po
 	-rm -f ./$(DEPDIR)/madvise.Po
+	-rm -f ./$(DEPDIR)/maybe_switch_current_tcp--quiet-thread-execve.Po
 	-rm -f ./$(DEPDIR)/maybe_switch_current_tcp.Po
 	-rm -f ./$(DEPDIR)/mbind-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/mbind-Xraw.Po
@@ -11160,6 +13465,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/memfd_create-Xraw.Po
 	-rm -f ./$(DEPDIR)/memfd_create-Xverbose.Po
 	-rm -f ./$(DEPDIR)/memfd_create.Po
+	-rm -f ./$(DEPDIR)/migrate_pages--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/migrate_pages.Po
 	-rm -f ./$(DEPDIR)/mincore.Po
 	-rm -f ./$(DEPDIR)/mkdir.Po
@@ -11188,6 +13494,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/mount.Po
 	-rm -f ./$(DEPDIR)/move_mount-P.Po
 	-rm -f ./$(DEPDIR)/move_mount.Po
+	-rm -f ./$(DEPDIR)/move_pages--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/move_pages-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/move_pages-Xraw.Po
 	-rm -f ./$(DEPDIR)/move_pages-Xverbose.Po
@@ -11201,12 +13508,17 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/msg_name.Po
 	-rm -f ./$(DEPDIR)/munlockall.Po
 	-rm -f ./$(DEPDIR)/nanosleep.Po
+	-rm -f ./$(DEPDIR)/net--decode-fds-dev-netlink.Po
+	-rm -f ./$(DEPDIR)/net--decode-fds-none-netlink.Po
+	-rm -f ./$(DEPDIR)/net--decode-fds-path-netlink.Po
+	-rm -f ./$(DEPDIR)/net--decode-fds-socket-netlink.Po
 	-rm -f ./$(DEPDIR)/net-accept-connect.Po
 	-rm -f ./$(DEPDIR)/net-icmp_filter.Po
 	-rm -f ./$(DEPDIR)/net-packet_mreq-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/net-packet_mreq-Xraw.Po
 	-rm -f ./$(DEPDIR)/net-packet_mreq-Xverbose.Po
 	-rm -f ./$(DEPDIR)/net-packet_mreq.Po
+	-rm -f ./$(DEPDIR)/net-sockaddr--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/net-sockaddr.Po
 	-rm -f ./$(DEPDIR)/net-tpacket_req.Po
 	-rm -f ./$(DEPDIR)/net-tpacket_stats-success.Po
@@ -11216,6 +13528,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/net-yy-inet6.Po
 	-rm -f ./$(DEPDIR)/net-yy-netlink.Po
 	-rm -f ./$(DEPDIR)/net-yy-unix.Po
+	-rm -f ./$(DEPDIR)/netlink_audit--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/netlink_audit.Po
 	-rm -f ./$(DEPDIR)/netlink_crypto.Po
 	-rm -f ./$(DEPDIR)/netlink_generic.Po
@@ -11253,6 +13566,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/nlattr_ifla_brport.Po
 	-rm -f ./$(DEPDIR)/nlattr_ifla_linkinfo.Po
 	-rm -f ./$(DEPDIR)/nlattr_ifla_port.Po
+	-rm -f ./$(DEPDIR)/nlattr_ifla_xdp-y.Po
 	-rm -f ./$(DEPDIR)/nlattr_ifla_xdp.Po
 	-rm -f ./$(DEPDIR)/nlattr_inet_diag_msg.Po
 	-rm -f ./$(DEPDIR)/nlattr_inet_diag_req_compat.Po
@@ -11292,6 +13606,16 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/open_tree-P.Po
 	-rm -f ./$(DEPDIR)/open_tree.Po
 	-rm -f ./$(DEPDIR)/openat.Po
+	-rm -f ./$(DEPDIR)/openat2-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/openat2-Xraw.Po
+	-rm -f ./$(DEPDIR)/openat2-Xverbose.Po
+	-rm -f ./$(DEPDIR)/openat2-v-y-Xabbrev.Po
+	-rm -f ./$(DEPDIR)/openat2-v-y-Xraw.Po
+	-rm -f ./$(DEPDIR)/openat2-v-y-Xverbose.Po
+	-rm -f ./$(DEPDIR)/openat2-v-y.Po
+	-rm -f ./$(DEPDIR)/openat2-v.Po
+	-rm -f ./$(DEPDIR)/openat2-y.Po
+	-rm -f ./$(DEPDIR)/openat2.Po
 	-rm -f ./$(DEPDIR)/orphaned_process_group.Po
 	-rm -f ./$(DEPDIR)/osf_utimes.Po
 	-rm -f ./$(DEPDIR)/pause.Po
@@ -11303,10 +13627,20 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/personality-Xraw.Po
 	-rm -f ./$(DEPDIR)/personality-Xverbose.Po
 	-rm -f ./$(DEPDIR)/personality.Po
+	-rm -f ./$(DEPDIR)/pidfd_getfd-y.Po
+	-rm -f ./$(DEPDIR)/pidfd_getfd-yy.Po
+	-rm -f ./$(DEPDIR)/pidfd_getfd.Po
+	-rm -f ./$(DEPDIR)/pidfd_open--decode-fd-path.Po
+	-rm -f ./$(DEPDIR)/pidfd_open--decode-fd-pidfd.Po
+	-rm -f ./$(DEPDIR)/pidfd_open--decode-fd-socket.Po
+	-rm -f ./$(DEPDIR)/pidfd_open--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/pidfd_open-P.Po
 	-rm -f ./$(DEPDIR)/pidfd_open-y.Po
+	-rm -f ./$(DEPDIR)/pidfd_open-yy.Po
 	-rm -f ./$(DEPDIR)/pidfd_open.Po
+	-rm -f ./$(DEPDIR)/pidfd_send_signal--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/pidfd_send_signal.Po
+	-rm -f ./$(DEPDIR)/pidns-cache.Po
 	-rm -f ./$(DEPDIR)/pipe.Po
 	-rm -f ./$(DEPDIR)/pipe2.Po
 	-rm -f ./$(DEPDIR)/pkey_alloc.Po
@@ -11333,6 +13667,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/preadv2-pwritev2.Po
 	-rm -f ./$(DEPDIR)/preadv_pwritev-preadv-pwritev.Po
 	-rm -f ./$(DEPDIR)/print_maxfd.Po
+	-rm -f ./$(DEPDIR)/print_ppid_tracerpid.Po
 	-rm -f ./$(DEPDIR)/printpath-umovestr-peekdata.Po
 	-rm -f ./$(DEPDIR)/printpath-umovestr-undumpable.Po
 	-rm -f ./$(DEPDIR)/printpath-umovestr.Po
@@ -11343,8 +13678,11 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/printstrn-umoven-peekdata.Po
 	-rm -f ./$(DEPDIR)/printstrn-umoven-undumpable.Po
 	-rm -f ./$(DEPDIR)/printstrn-umoven.Po
+	-rm -f ./$(DEPDIR)/prlimit64--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/prlimit64.Po
+	-rm -f ./$(DEPDIR)/process_vm_readv--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/process_vm_readv.Po
+	-rm -f ./$(DEPDIR)/process_vm_writev--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/process_vm_writev.Po
 	-rm -f ./$(DEPDIR)/pselect6.Po
 	-rm -f ./$(DEPDIR)/ptrace.Po
@@ -11393,10 +13731,12 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/rt_sigaction.Po
 	-rm -f ./$(DEPDIR)/rt_sigpending.Po
 	-rm -f ./$(DEPDIR)/rt_sigprocmask.Po
+	-rm -f ./$(DEPDIR)/rt_sigqueueinfo--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/rt_sigqueueinfo.Po
 	-rm -f ./$(DEPDIR)/rt_sigreturn.Po
 	-rm -f ./$(DEPDIR)/rt_sigsuspend.Po
 	-rm -f ./$(DEPDIR)/rt_sigtimedwait.Po
+	-rm -f ./$(DEPDIR)/rt_tgsigqueueinfo--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/rt_tgsigqueueinfo.Po
 	-rm -f ./$(DEPDIR)/run_expect_termsig.Po
 	-rm -f ./$(DEPDIR)/s390_guarded_storage-v.Po
@@ -11407,9 +13747,13 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/s390_sthyi.Po
 	-rm -f ./$(DEPDIR)/sched_get_priority_mxx.Po
 	-rm -f ./$(DEPDIR)/sched_rr_get_interval.Po
+	-rm -f ./$(DEPDIR)/sched_xetaffinity--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/sched_xetaffinity.Po
+	-rm -f ./$(DEPDIR)/sched_xetattr--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/sched_xetattr.Po
+	-rm -f ./$(DEPDIR)/sched_xetparam--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/sched_xetparam.Po
+	-rm -f ./$(DEPDIR)/sched_xetscheduler--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/sched_xetscheduler.Po
 	-rm -f ./$(DEPDIR)/sched_yield.Po
 	-rm -f ./$(DEPDIR)/scm_rights.Po
@@ -11442,6 +13786,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/setgroups32.Po
 	-rm -f ./$(DEPDIR)/sethostname.Po
 	-rm -f ./$(DEPDIR)/setns.Po
+	-rm -f ./$(DEPDIR)/setpgrp-exec.Po
 	-rm -f ./$(DEPDIR)/setregid.Po
 	-rm -f ./$(DEPDIR)/setregid32.Po
 	-rm -f ./$(DEPDIR)/setresgid.Po
@@ -11462,6 +13807,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/sigaltstack.Po
 	-rm -f ./$(DEPDIR)/siginfo.Po
 	-rm -f ./$(DEPDIR)/signal.Po
+	-rm -f ./$(DEPDIR)/signal_receive--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/signal_receive.Po
 	-rm -f ./$(DEPDIR)/signalfd4.Po
 	-rm -f ./$(DEPDIR)/sigpending.Po
@@ -11471,6 +13817,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/sleep.Po
 	-rm -f ./$(DEPDIR)/so_error.Po
 	-rm -f ./$(DEPDIR)/so_linger.Po
+	-rm -f ./$(DEPDIR)/so_peercred--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/so_peercred-Xabbrev.Po
 	-rm -f ./$(DEPDIR)/so_peercred-Xraw.Po
 	-rm -f ./$(DEPDIR)/so_peercred-Xverbose.Po
@@ -11502,14 +13849,24 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/statfs-statfs.Po
 	-rm -f ./$(DEPDIR)/statfs64.Po
 	-rm -f ./$(DEPDIR)/status-all.Po
+	-rm -f ./$(DEPDIR)/status-failed-long.Po
+	-rm -f ./$(DEPDIR)/status-failed-status.Po
 	-rm -f ./$(DEPDIR)/status-failed.Po
 	-rm -f ./$(DEPDIR)/status-none-f.Po
 	-rm -f ./$(DEPDIR)/status-none-threads.Po
 	-rm -f ./$(DEPDIR)/status-none.Po
+	-rm -f ./$(DEPDIR)/status-successful-long.Po
+	-rm -f ./$(DEPDIR)/status-successful-status.Po
 	-rm -f ./$(DEPDIR)/status-successful.Po
 	-rm -f ./$(DEPDIR)/status-unfinished-threads.Po
 	-rm -f ./$(DEPDIR)/status-unfinished.Po
 	-rm -f ./$(DEPDIR)/statx.Po
+	-rm -f ./$(DEPDIR)/strace--strings-in-hex-all.Po
+	-rm -f ./$(DEPDIR)/strace--strings-in-hex-non-ascii.Po
+	-rm -f ./$(DEPDIR)/strace--strings-in-hex.Po
+	-rm -f ./$(DEPDIR)/strace-n.Po
+	-rm -f ./$(DEPDIR)/strace-x.Po
+	-rm -f ./$(DEPDIR)/strace-xx.Po
 	-rm -f ./$(DEPDIR)/swap.Po
 	-rm -f ./$(DEPDIR)/sxetmask.Po
 	-rm -f ./$(DEPDIR)/symlink.Po
@@ -11521,6 +13878,12 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/syslog-success.Po
 	-rm -f ./$(DEPDIR)/syslog.Po
 	-rm -f ./$(DEPDIR)/tee.Po
+	-rm -f ./$(DEPDIR)/tgkill--pidns-translation.Po
+	-rm -f ./$(DEPDIR)/tgkill.Po
+	-rm -f ./$(DEPDIR)/threads-execve--quiet-thread-execve.Po
+	-rm -f ./$(DEPDIR)/threads-execve-q.Po
+	-rm -f ./$(DEPDIR)/threads-execve-qq.Po
+	-rm -f ./$(DEPDIR)/threads-execve-qqq.Po
 	-rm -f ./$(DEPDIR)/threads-execve.Po
 	-rm -f ./$(DEPDIR)/time.Po
 	-rm -f ./$(DEPDIR)/timer_create.Po
@@ -11528,7 +13891,11 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/timerfd_xettime.Po
 	-rm -f ./$(DEPDIR)/times-fail.Po
 	-rm -f ./$(DEPDIR)/times.Po
+	-rm -f ./$(DEPDIR)/tkill--pidns-translation.Po
+	-rm -f ./$(DEPDIR)/tkill.Po
 	-rm -f ./$(DEPDIR)/tracer_ppid_pgid_sid.Po
+	-rm -f ./$(DEPDIR)/trie_test-trie_for_tests.Po
+	-rm -f ./$(DEPDIR)/trie_test-trie_test.Po
 	-rm -f ./$(DEPDIR)/truncate.Po
 	-rm -f ./$(DEPDIR)/truncate64-truncate64.Po
 	-rm -f ./$(DEPDIR)/ugetrlimit.Po
@@ -11542,6 +13909,7 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/umovestr2.Po
 	-rm -f ./$(DEPDIR)/umovestr3.Po
 	-rm -f ./$(DEPDIR)/umovestr_cached.Po
+	-rm -f ./$(DEPDIR)/umovestr_cached_adjacent.Po
 	-rm -f ./$(DEPDIR)/uname.Po
 	-rm -f ./$(DEPDIR)/unblock_reset_raise.Po
 	-rm -f ./$(DEPDIR)/unix-pair-send-recv.Po
@@ -11567,10 +13935,13 @@ maintainer-clean: maintainer-clean-am
 	-rm -f ./$(DEPDIR)/waitpid.Po
 	-rm -f ./$(DEPDIR)/xattr-strings.Po
 	-rm -f ./$(DEPDIR)/xattr.Po
+	-rm -f ./$(DEPDIR)/xet_robust_list--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/xet_robust_list.Po
 	-rm -f ./$(DEPDIR)/xet_thread_area_x86.Po
 	-rm -f ./$(DEPDIR)/xetitimer.Po
+	-rm -f ./$(DEPDIR)/xetpgid--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/xetpgid.Po
+	-rm -f ./$(DEPDIR)/xetpriority--pidns-translation.Po
 	-rm -f ./$(DEPDIR)/xetpriority.Po
 	-rm -f ./$(DEPDIR)/xettimeofday.Po
 	-rm -f ./$(DEPDIR)/zeroargc.Po
@@ -11714,6 +14085,42 @@ $(srcdir)/clone3-success-Xraw.gen.test:
 $(srcdir)/clone3-success-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/clone_parent.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_parent--quiet-exit.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_parent-q.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_parent-qq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_ptrace--quiet-attach.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_ptrace--quiet-exit.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_ptrace-q.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/clone_ptrace-qq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/close_range.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/close_range-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/close_range-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/close_range-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/copy_file_range.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -11723,18 +14130,54 @@ $(srcdir)/creat.gen.test: $(abs_srcdir)/
 $(srcdir)/delete_module.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/dev--decode-fds-dev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dev--decode-fds-path.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dev--decode-fds-socket.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/dev-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/dup.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/dup-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/dup2.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/dup2-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup2-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup2-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/dup3.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/dup3-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup3-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/dup3-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/epoll_create.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -11759,7 +14202,22 @@ $(srcdir)/execveat.gen.test: $(abs_srcdi
 $(srcdir)/execveat-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
-$(srcdir)/faccessat.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+$(srcdir)/faccessat-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat2-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat2-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/faccessat2-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/fadvise64_64.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
@@ -11804,9 +14262,15 @@ $(srcdir)/fchownat.gen.test: $(abs_srcdi
 $(srcdir)/fcntl.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/fcntl--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/fcntl64.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/fcntl64--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/fdatasync.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -11909,9 +14373,15 @@ $(srcdir)/getcwd.gen.test: $(abs_srcdir)
 $(srcdir)/getdents.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getdents-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getdents64.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getdents64-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getegid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -11960,9 +14430,15 @@ $(srcdir)/getpeername.gen.test: $(abs_sr
 $(srcdir)/getpgrp.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getpgrp--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getpid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getpid--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getppid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -11990,6 +14466,9 @@ $(srcdir)/getrusage.gen.test: $(abs_srcd
 $(srcdir)/getsid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/getsid--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/getsockname.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12005,7 +14484,13 @@ $(srcdir)/getuid32.gen.test: $(abs_srcdi
 $(srcdir)/getuid32-creds.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
-$(srcdir)/getxxid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+$(srcdir)/getxgid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/getxpid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/getxuid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/group_req.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
@@ -12092,6 +14577,54 @@ $(srcdir)/ioctl_evdev-success-v-Xraw.gen
 $(srcdir)/ioctl_evdev-success-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioctl_hdio.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-v-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-v-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-v-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-v-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_hdio-success-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioctl_inotify.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12125,6 +14658,9 @@ $(srcdir)/ioctl_nsfs.gen.test: $(abs_src
 $(srcdir)/ioctl_perf.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioctl_perf-success.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioctl_ptp.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12149,12 +14685,60 @@ $(srcdir)/ioctl_sg_io_v4.gen.test: $(abs
 $(srcdir)/ioctl_sock_gifconf.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioctl_tee.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioctl_uffdio.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/ioctl_v4l2.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioctl_v4l2-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-v-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-v-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-v-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-v-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/ioctl_v4l2-success-v-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioctl_watchdog.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12167,6 +14751,9 @@ $(srcdir)/iopl.gen.test: $(abs_srcdir)/g
 $(srcdir)/ioprio.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/ioprio--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ioprio-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12233,6 +14820,9 @@ $(srcdir)/kcmp.gen.test: $(abs_srcdir)/g
 $(srcdir)/kcmp-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/kcmp-y--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/kern_features.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12269,6 +14859,9 @@ $(srcdir)/keyctl-Xverbose.gen.test: $(ab
 $(srcdir)/kill.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/kill--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/ksysent.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12299,6 +14892,9 @@ $(srcdir)/madvise.gen.test: $(abs_srcdir
 $(srcdir)/maybe_switch_current_tcp.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/maybe_switch_current_tcp--quiet-thread-execve.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/mbind.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12329,6 +14925,9 @@ $(srcdir)/memfd_create-Xverbose.gen.test
 $(srcdir)/migrate_pages.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/migrate_pages--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/mincore.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12419,6 +15018,9 @@ $(srcdir)/move_pages-Xraw.gen.test: $(ab
 $(srcdir)/move_pages-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/move_pages--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/mq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12446,6 +15048,18 @@ $(srcdir)/munlockall.gen.test: $(abs_src
 $(srcdir)/nanosleep.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/net--decode-fds-dev-netlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/net--decode-fds-none-netlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/net--decode-fds-path-netlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/net--decode-fds-socket-netlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/net-icmp_filter.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12464,6 +15078,9 @@ $(srcdir)/net-packet_mreq-Xverbose.gen.t
 $(srcdir)/net-sockaddr.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/net-sockaddr--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/net-tpacket_req.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12575,6 +15192,9 @@ $(srcdir)/nlattr_ifla_port.gen.test: $(a
 $(srcdir)/nlattr_ifla_xdp.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/nlattr_ifla_xdp-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/nlattr_inet_diag_msg.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12683,6 +15303,36 @@ $(srcdir)/open_tree-P.gen.test: $(abs_sr
 $(srcdir)/openat.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/openat2.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v-y-Xabbrev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v-y-Xraw.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-v-y-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/openat2-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/orphaned_process_group.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12710,18 +15360,45 @@ $(srcdir)/personality-Xraw.gen.test: $(a
 $(srcdir)/personality-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/pidfd_getfd.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_getfd-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_getfd-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pidfd_open.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/pidfd_open--decode-fd-path.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_open--decode-fd-pidfd.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_open--decode-fd-socket.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pidfd_open-P.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/pidfd_open-y.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/pidfd_open-yy.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/pidfd_open--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pidfd_send_signal.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/pidfd_send_signal--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pipe2.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12788,12 +15465,21 @@ $(srcdir)/printstrn-umoven-undumpable.ge
 $(srcdir)/prlimit64.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/prlimit64--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/process_vm_readv.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/process_vm_readv--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/process_vm_writev.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/process_vm_writev--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/pselect6.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12902,6 +15588,9 @@ $(srcdir)/rt_sigprocmask.gen.test: $(abs
 $(srcdir)/rt_sigqueueinfo.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/rt_sigqueueinfo--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/rt_sigreturn.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12914,6 +15603,9 @@ $(srcdir)/rt_sigtimedwait.gen.test: $(ab
 $(srcdir)/rt_tgsigqueueinfo.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/rt_tgsigqueueinfo--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/s390_guarded_storage.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -12944,15 +15636,27 @@ $(srcdir)/sched_rr_get_interval.gen.test
 $(srcdir)/sched_xetaffinity.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/sched_xetaffinity--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sched_xetattr.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/sched_xetattr--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sched_xetparam.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/sched_xetparam--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sched_xetscheduler.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/sched_xetscheduler--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sched_yield.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -13091,6 +15795,9 @@ $(srcdir)/signal.gen.test: $(abs_srcdir)
 $(srcdir)/signal_receive.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/signal_receive--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/signalfd4.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -13124,6 +15831,9 @@ $(srcdir)/so_peercred-Xraw.gen.test: $(a
 $(srcdir)/so_peercred-Xverbose.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/so_peercred--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/sock_filter-v.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -13175,18 +15885,141 @@ $(srcdir)/status-all.gen.test: $(abs_src
 $(srcdir)/status-failed.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/status-failed-long.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/status-failed-status.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/status-none.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/status-successful.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/status-successful-long.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/status-successful-status.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/status-unfinished.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/statx.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/strace--absolute-timestamps.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time-precision-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time-precision-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time-precision-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-time-precision-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-unix-precision-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-unix-precision-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-unix-precision-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--absolute-timestamps-format-unix-precision-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--follow-forks-output-separately.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--relative-timestamps-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--syscall-times-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--strings-in-hex.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--strings-in-hex-all.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--strings-in-hex-non-ascii.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-time-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-unix-s.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-unix-ms.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-unix-us.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace--timestamps-unix-ns.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace-n.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace-x.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/strace-xx.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/swap.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -13217,6 +16050,24 @@ $(srcdir)/syslog.gen.test: $(abs_srcdir)
 $(srcdir)/tee.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/tgkill.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/tgkill--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/threads-execve--quiet-thread-execve.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/threads-execve-q.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/threads-execve-qq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/threads-execve-qqq.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/time.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -13235,6 +16086,15 @@ $(srcdir)/times.gen.test: $(abs_srcdir)/
 $(srcdir)/times-fail.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/tkill.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/tkill--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
+$(srcdir)/trace_clock.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/trace_creds.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -13280,6 +16140,9 @@ $(srcdir)/trace_statfs.gen.test: $(abs_s
 $(srcdir)/trace_statfs_like.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/trie_test.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/truncate.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -13301,6 +16164,9 @@ $(srcdir)/umovestr-illptr.gen.test: $(ab
 $(srcdir)/umovestr3.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/umovestr_cached_adjacent.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/unlink.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
@@ -13367,15 +16233,24 @@ $(srcdir)/xattr-strings.gen.test: $(abs_
 $(srcdir)/xet_robust_list.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/xet_robust_list--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/xetitimer.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
 $(srcdir)/xetpgid.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/xetpgid--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/xetpriority.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
+$(srcdir)/xetpriority--pidns-translation.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
+	$(AM_V_GEN) $^ $@
+
 $(srcdir)/xettimeofday.gen.test: $(abs_srcdir)/gen_tests.sh $(srcdir)/gen_tests.in
 	$(AM_V_GEN) $^ $@
 
diff -pruN 5.5-3/tests-mx32/maybe_switch_current_tcp.c 5.9-0ubuntu2/tests-mx32/maybe_switch_current_tcp.c
--- 5.5-3/tests-mx32/maybe_switch_current_tcp.c	2019-07-16 17:46:47.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/maybe_switch_current_tcp.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,6 +2,7 @@
  * Check for PTRACE_EVENT_EXEC diagnostics.
  *
  * Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2019-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -14,6 +15,10 @@
 #include <unistd.h>
 #include "scno.h"
 
+#ifndef QUIET_MSG
+# define QUIET_MSG 0
+#endif
+
 static pid_t leader;
 static volatile unsigned int trigger;
 
@@ -25,9 +30,14 @@ thread(void *arg)
 
 	printf("%-5d execveat(AT_FDCWD, \"%s\", [\"%s\", \"%s\", \"%s\"]"
 	       ", NULL, 0 <pid changed to %d ...>\n"
-	       "%-5d +++ superseded by execve in pid %d +++\n",
-	       tid, argv[0], argv[0], argv[1], argv[2], leader,
-	       leader, tid);
+#if !QUIET_MSG
+	       "%-5d +++ superseded by execve in pid %d +++\n"
+#endif
+	       , tid, argv[0], argv[0], argv[1], argv[2], leader
+#if !QUIET_MSG
+	       , leader, tid
+#endif
+	       );
 
 	while (!trigger) {
 		/* Wait for the parent to enter the busy loop.  */
diff -pruN 5.5-3/tests-mx32/maybe_switch_current_tcp--quiet-thread-execve.c 5.9-0ubuntu2/tests-mx32/maybe_switch_current_tcp--quiet-thread-execve.c
--- 5.5-3/tests-mx32/maybe_switch_current_tcp--quiet-thread-execve.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/maybe_switch_current_tcp--quiet-thread-execve.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define QUIET_MSG 1
+#include "maybe_switch_current_tcp.c"
diff -pruN 5.5-3/tests-mx32/maybe_switch_current_tcp--quiet-thread-execve.gen.test 5.9-0ubuntu2/tests-mx32/maybe_switch_current_tcp--quiet-thread-execve.gen.test
--- 5.5-3/tests-mx32/maybe_switch_current_tcp--quiet-thread-execve.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/maybe_switch_current_tcp--quiet-thread-execve.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (maybe_switch_current_tcp--quiet-thread-execve -a30 -s48 -f -e trace=execveat --quiet=personality,thread-execve); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a30 -s48 -f -e trace=execveat --quiet=personality,thread-execve
diff -pruN 5.5-3/tests-mx32/migrate_pages.c 5.9-0ubuntu2/tests-mx32/migrate_pages.c
--- 5.5-3/tests-mx32/migrate_pages.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/migrate_pages.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of migrate_pages syscall.
  *
  * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,6 +10,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #ifdef __NR_migrate_pages
 
@@ -19,11 +20,21 @@
 int
 main(void)
 {
-	const long pid = (long) 0xfacefeedffffffffULL;
+	PIDNS_TEST_INIT;
+
+	const long pid = (long) 0xfacefeed00000000ULL | getpid();
 	long rc = syscall(__NR_migrate_pages, pid, 0, 0, 0);
-	printf("migrate_pages(%d, 0, NULL, NULL) = %ld %s (%m)\n",
-	       (int) pid, rc, errno2name());
 
+	pidns_print_leader();
+	printf("migrate_pages(%d%s, 0, NULL, NULL) = %ld",
+		(int) pid, pidns_pid2str(PT_TGID), rc);
+
+	if (rc < 0)
+		printf(" %s (%m)\n", errno2name());
+	else
+		printf("\n");
+
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/migrate_pages--pidns-translation.c 5.9-0ubuntu2/tests-mx32/migrate_pages--pidns-translation.c
--- 5.5-3/tests-mx32/migrate_pages--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/migrate_pages--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "migrate_pages.c"
diff -pruN 5.5-3/tests-mx32/migrate_pages--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/migrate_pages--pidns-translation.gen.test
--- 5.5-3/tests-mx32/migrate_pages--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/migrate_pages--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (migrate_pages--pidns-translation test_pidns -a33 -e trace=migrate_pages); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a33 -e trace=migrate_pages
diff -pruN 5.5-3/tests-mx32/mknod.c 5.9-0ubuntu2/tests-mx32/mknod.c
--- 5.5-3/tests-mx32/mknod.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/mknod.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -31,44 +31,44 @@ main(int ac, char **av)
 	sample = av[0];
 
 	long rc = call_mknod(0, dev);
-	printf("mknod(\"%s\", 000) = %ld %s (%m)\n",
-	       sample, rc, errno2name());
+	printf("mknod(\"%s\", 000) = %s\n",
+	       sample, sprintrc(rc));
 
 	rc = call_mknod(0xffff, dev);
-	printf("mknod(\"%s\", %#03ho) = %ld %s (%m)\n",
-	       sample, (unsigned short) -1, rc, errno2name());
+	printf("mknod(\"%s\", %#03ho) = %s\n",
+	       sample, (unsigned short) -1, sprintrc(rc));
 
 	rc = call_mknod(S_IFREG, 0);
-	printf("mknod(\"%s\", S_IFREG|000) = %ld %s (%m)\n",
-	       sample, rc, errno2name());
+	printf("mknod(\"%s\", S_IFREG|000) = %s\n",
+	       sample, sprintrc(rc));
 
 	rc = call_mknod(S_IFDIR | 06, 0);
-	printf("mknod(\"%s\", S_IFDIR|006) = %ld %s (%m)\n",
-	       sample, rc, errno2name());
+	printf("mknod(\"%s\", S_IFDIR|006) = %s\n",
+	       sample, sprintrc(rc));
 
 	rc = call_mknod(S_IFLNK | 060, 0);
-	printf("mknod(\"%s\", S_IFLNK|060) = %ld %s (%m)\n",
-	       sample, rc, errno2name());
+	printf("mknod(\"%s\", S_IFLNK|060) = %s\n",
+	       sample, sprintrc(rc));
 
 	rc = call_mknod(S_IFIFO | 0600, 0);
-	printf("mknod(\"%s\", S_IFIFO|0600) = %ld %s (%m)\n",
-	       sample, rc, errno2name());
+	printf("mknod(\"%s\", S_IFIFO|0600) = %s\n",
+	       sample, sprintrc(rc));
 
 	dev = (unsigned long) 0xdeadbeef00000000ULL | makedev(1, 7);
 
 	rc = call_mknod(S_IFCHR | 024, dev);
-	printf("mknod(\"%s\", S_IFCHR|024, makedev(0x1, 0x7)) = %ld %s (%m)\n",
-	       sample, rc, errno2name());
+	printf("mknod(\"%s\", S_IFCHR|024, makedev(0x1, 0x7)) = %s\n",
+	       sample, sprintrc(rc));
 
 	const unsigned short mode = (0xffff & ~S_IFMT) | S_IFBLK;
 	dev = (unsigned long) 0xdeadbeefbadc0dedULL;
 
 	rc = call_mknod(mode, dev);
 	printf("mknod(\"%s\", S_IFBLK|S_ISUID|S_ISGID|S_ISVTX|%#03ho"
-	       ", makedev(%#x, %#x)) = %ld %s (%m)\n",
+	       ", makedev(%#x, %#x)) = %s\n",
 	       sample, (short) (mode & ~(S_IFMT|S_ISUID|S_ISGID|S_ISVTX)),
 	       major((unsigned) dev), minor((unsigned) dev),
-	       rc, errno2name());
+	       sprintrc(rc));
 
 	puts("+++ exited with 0 +++");
 	return 0;
diff -pruN 5.5-3/tests-mx32/move_pages.c 5.9-0ubuntu2/tests-mx32/move_pages.c
--- 5.5-3/tests-mx32/move_pages.c	2019-07-16 17:46:47.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/move_pages.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of move_pages syscall.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,6 +10,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #ifdef __NR_move_pages
 
@@ -122,15 +123,20 @@ print_status_array(const int *const stat
 }
 
 static void
-print_stat_pages(const unsigned long pid, const unsigned long count,
-		 const void **const pages, int *const status)
+print_stat_pages(const unsigned long pid,
+		 const char *pid_str,
+		 const unsigned long count,
+		 const void **const pages,
+		 int *const status)
 {
 	const unsigned long flags = (unsigned long) 0xfacefeed00000002ULL;
 
 	long rc = syscall(__NR_move_pages,
 			  pid, count, pages, NULL, status, flags);
 	const char *errstr = sprintrc(rc);
-	printf("move_pages(%d, %lu, ", (int) pid, count);
+	pidns_print_leader();
+	printf("move_pages(%d%s, %lu, ", (int) pid, pid_str,
+		count);
 	print_page_array(pages, count, 0);
 	printf(", NULL, ");
 	if (rc) {
@@ -152,6 +158,7 @@ print_stat_pages(const unsigned long pid
 
 static void
 print_move_pages(const unsigned long pid,
+		 const char *pid_str,
 		 unsigned long count,
 		 const unsigned int offset,
 		 const void **const pages,
@@ -164,7 +171,9 @@ print_move_pages(const unsigned long pid
 	long rc = syscall(__NR_move_pages,
 			  pid, count, pages, nodes, status, flags);
 	const char *errstr = sprintrc(rc);
-	printf("move_pages(%d, %lu, ", (int) pid, count);
+	pidns_print_leader();
+	printf("move_pages(%d%s, %lu, ", (int) pid, pid_str,
+		count);
 	print_page_array(pages, count, offset);
 	printf(", ");
 	print_node_array(nodes, count, offset);
@@ -185,8 +194,11 @@ print_move_pages(const unsigned long pid
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	const unsigned long pid =
 		(unsigned long) 0xfacefeed00000000ULL | getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
 	unsigned long count = 1;
 	const unsigned page_size = get_page_size();
 	const void *const page = tail_alloc(page_size);
@@ -195,40 +207,41 @@ main(void)
 	TAIL_ALLOC_OBJECT_VAR_PTR(int, nodes);
 	TAIL_ALLOC_OBJECT_VAR_PTR(int, status);
 
-	print_stat_pages(pid, 0, pages, status);
-	print_move_pages(pid, 0, 0, pages, nodes, status);
-	print_move_pages(pid, 0, 1, pages + 1, nodes + 1, status + 1);
+	print_stat_pages(pid, pid_str, 0, pages, status);
+	print_move_pages(pid, pid_str, 0, 0, pages, nodes, status);
+	print_move_pages(pid, pid_str, 0, 1, pages + 1, nodes + 1, status + 1);
 
 	*pages = page;
-	print_stat_pages(pid, count, pages, status);
+	print_stat_pages(pid, pid_str, count, pages, status);
 	*nodes = 0xdeadbee1;
-	print_move_pages(pid, count, 0, pages, nodes, status);
-	print_move_pages(pid, count, 1, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 0, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 1, pages, nodes, status);
 
 	++count;
 	--status;
 	*(--pages) = efault;
-	print_stat_pages(pid, count, pages, status);
+	print_stat_pages(pid, pid_str, count, pages, status);
 	*(--nodes) = 0xdeadbee2;
-	print_move_pages(pid, count, 0, pages, nodes, status);
-	print_move_pages(pid, count, 1, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 0, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 1, pages, nodes, status);
 
 	++count;
 	--status;
 	*(--pages) = nodes;
-	print_stat_pages(pid, count, pages, status);
+	print_stat_pages(pid, pid_str, count, pages, status);
 	*(--nodes) = 0xdeadbee3;
-	print_move_pages(pid, count, 0, pages, nodes, status);
-	print_move_pages(pid, count, 1, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 0, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 1, pages, nodes, status);
 
 	++count;
 	--status;
 	*(--pages) = status;
-	print_stat_pages(pid, count, pages, status);
+	print_stat_pages(pid, pid_str, count, pages, status);
 	*(--nodes) = 0xdeadbee4;
-	print_move_pages(pid, count, 0, pages, nodes, status);
-	print_move_pages(pid, count, 1, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 0, pages, nodes, status);
+	print_move_pages(pid, pid_str, count, 1, pages, nodes, status);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/move_pages--pidns-translation.c 5.9-0ubuntu2/tests-mx32/move_pages--pidns-translation.c
--- 5.5-3/tests-mx32/move_pages--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/move_pages--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "move_pages.c"
diff -pruN 5.5-3/tests-mx32/move_pages--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/move_pages--pidns-translation.gen.test
--- 5.5-3/tests-mx32/move_pages--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/move_pages--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (move_pages--pidns-translation test_pidns -s3 -e trace=move_pages); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -s3 -e trace=move_pages
diff -pruN 5.5-3/tests-mx32/msg_control.c 5.9-0ubuntu2/tests-mx32/msg_control.c
--- 5.5-3/tests-mx32/msg_control.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/msg_control.c	2020-04-19 01:22:29.000000000 +0000
@@ -25,6 +25,9 @@
 # include <linux/time_types.h>
 #endif
 
+#include "kernel_timeval.h"
+#include "kernel_old_timespec.h"
+
 #include "xlat.h"
 #define XLAT_MACROS_ONLY
 #include "xlat/sock_options.h"
@@ -214,7 +217,7 @@ test_scm_rights3(struct msghdr *const mh
 static void
 test_scm_timestamp_old(struct msghdr *const mh, void *const page)
 {
-	static const struct timeval tv = {
+	static const kernel_old_timeval_t tv = {
 		.tv_sec = 123456789,
 		.tv_usec = 987654
 	};
@@ -261,7 +264,7 @@ test_scm_timestamp_old(struct msghdr *co
 static void
 test_scm_timestampns_old(struct msghdr *const mh, void *const page)
 {
-	static const struct timespec ts = {
+	static const kernel_old_timespec_t ts = {
 		.tv_sec = 123456789,
 		.tv_nsec = 987654321
 	};
@@ -309,7 +312,7 @@ test_scm_timestampns_old(struct msghdr *
 static void
 test_scm_timestamping_old(struct msghdr *const mh, void *const page)
 {
-	static const struct timespec ts[] = {
+	static const kernel_old_timespec_t ts[] = {
 		{ .tv_sec = 123456789, .tv_nsec = 987654321 },
 		{ .tv_sec = 123456790, .tv_nsec = 987654320 },
 		{ .tv_sec = 123456791, .tv_nsec = 987654319 }
diff -pruN 5.5-3/tests-mx32/net--decode-fds-dev-netlink.c 5.9-0ubuntu2/tests-mx32/net--decode-fds-dev-netlink.c
--- 5.5-3/tests-mx32/net--decode-fds-dev-netlink.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/net--decode-fds-dev-netlink.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_SOCK 1
+#include "net-yy-netlink.c"
diff -pruN 5.5-3/tests-mx32/net--decode-fds-dev-netlink.gen.test 5.9-0ubuntu2/tests-mx32/net--decode-fds-dev-netlink.gen.test
--- 5.5-3/tests-mx32/net--decode-fds-dev-netlink.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/net--decode-fds-dev-netlink.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (net--decode-fds-dev-netlink +net-yy-netlink.test --decode-fds=dev); do not edit.
+set -- --decode-fds=dev
+. "${srcdir=.}/net-yy-netlink.test"
diff -pruN 5.5-3/tests-mx32/net--decode-fds-none-netlink.c 5.9-0ubuntu2/tests-mx32/net--decode-fds-none-netlink.c
--- 5.5-3/tests-mx32/net--decode-fds-none-netlink.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/net--decode-fds-none-netlink.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_SOCK 0
+#include "net-yy-netlink.c"
diff -pruN 5.5-3/tests-mx32/net--decode-fds-none-netlink.gen.test 5.9-0ubuntu2/tests-mx32/net--decode-fds-none-netlink.gen.test
--- 5.5-3/tests-mx32/net--decode-fds-none-netlink.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/net--decode-fds-none-netlink.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (net--decode-fds-none-netlink +net-yy-netlink.test --decode-fds=none -a9); do not edit.
+set -- --decode-fds=none -a9
+. "${srcdir=.}/net-yy-netlink.test"
diff -pruN 5.5-3/tests-mx32/net--decode-fds-path-netlink.c 5.9-0ubuntu2/tests-mx32/net--decode-fds-path-netlink.c
--- 5.5-3/tests-mx32/net--decode-fds-path-netlink.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/net--decode-fds-path-netlink.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_SOCK 1
+#include "net-yy-netlink.c"
diff -pruN 5.5-3/tests-mx32/net--decode-fds-path-netlink.gen.test 5.9-0ubuntu2/tests-mx32/net--decode-fds-path-netlink.gen.test
--- 5.5-3/tests-mx32/net--decode-fds-path-netlink.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/net--decode-fds-path-netlink.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (net--decode-fds-path-netlink +net-yy-netlink.test --decode-fds=path); do not edit.
+set -- --decode-fds=path
+. "${srcdir=.}/net-yy-netlink.test"
diff -pruN 5.5-3/tests-mx32/net--decode-fds-socket-netlink.c 5.9-0ubuntu2/tests-mx32/net--decode-fds-socket-netlink.c
--- 5.5-3/tests-mx32/net--decode-fds-socket-netlink.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/net--decode-fds-socket-netlink.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_SOCK 2
+#include "net-yy-netlink.c"
diff -pruN 5.5-3/tests-mx32/net--decode-fds-socket-netlink.gen.test 5.9-0ubuntu2/tests-mx32/net--decode-fds-socket-netlink.gen.test
--- 5.5-3/tests-mx32/net--decode-fds-socket-netlink.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/net--decode-fds-socket-netlink.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (net--decode-fds-socket-netlink +net-yy-netlink.test --decode-fds=socket); do not edit.
+set -- --decode-fds=socket
+. "${srcdir=.}/net-yy-netlink.test"
diff -pruN 5.5-3/tests-mx32/netlink_audit.c 5.9-0ubuntu2/tests-mx32/netlink_audit.c
--- 5.5-3/tests-mx32/netlink_audit.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/netlink_audit.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,12 +1,13 @@
 /*
  * Copyright (c) 2017 JingPiao Chen <chenjingpiao@gmail.com>
- * Copyright (c) 2017-2018 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include "pidns.h"
 #include <stdio.h>
 #include <string.h>
 #include <unistd.h>
@@ -17,18 +18,23 @@
 static void
 test_nlmsg_type(const int fd)
 {
+	PIDNS_TEST_INIT;
+
 	long rc;
 	struct nlmsghdr nlh = {
 		.nlmsg_len = sizeof(nlh),
 		.nlmsg_type = AUDIT_GET,
 		.nlmsg_flags = NLM_F_REQUEST,
+		.nlmsg_pid = getpid(),
 	};
 
 	rc = sendto(fd, &nlh, sizeof(nlh), MSG_DONTWAIT, NULL, 0);
+	pidns_print_leader();
 	printf("sendto(%d, {len=%u, type=AUDIT_GET"
-	       ", flags=NLM_F_REQUEST, seq=0, pid=0}"
+	       ", flags=NLM_F_REQUEST, seq=0, pid=%d%s}"
 	       ", %u, MSG_DONTWAIT, NULL, 0) = %s\n",
-	       fd, nlh.nlmsg_len, (unsigned) sizeof(nlh), sprintrc(rc));
+	       fd, nlh.nlmsg_len, nlh.nlmsg_pid, pidns_pid2str(PT_TGID),
+	       (unsigned) sizeof(nlh), sprintrc(rc));
 }
 
 int main(void)
@@ -39,6 +45,7 @@ int main(void)
 
 	test_nlmsg_type(fd);
 
+	pidns_print_leader();
 	printf("+++ exited with 0 +++\n");
 
 	return 0;
diff -pruN 5.5-3/tests-mx32/netlink_audit--pidns-translation.c 5.9-0ubuntu2/tests-mx32/netlink_audit--pidns-translation.c
--- 5.5-3/tests-mx32/netlink_audit--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/netlink_audit--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "netlink_audit.c"
diff -pruN 5.5-3/tests-mx32/netlink_audit--pidns-translation.test 5.9-0ubuntu2/tests-mx32/netlink_audit--pidns-translation.test
--- 5.5-3/tests-mx32/netlink_audit--pidns-translation.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/netlink_audit--pidns-translation.test	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,13 @@
+#!/bin/sh
+#
+# Check pidns translation of NETLINK_SOCK_DIAG protocol decoding
+#
+# Copyright (c) 2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: LGPL-2.1-or-later
+
+. "${srcdir=.}/init.sh"
+
+run_prog ../netlink_netlink_diag
+test_pidns -e trace=sendto "$@"
diff -pruN 5.5-3/tests-mx32/netlink_protocol.c 5.9-0ubuntu2/tests-mx32/netlink_protocol.c
--- 5.5-3/tests-mx32/netlink_protocol.c	2018-12-30 15:35:21.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/netlink_protocol.c	2020-08-03 08:00:00.000000000 +0000
@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2014-2017 Dmitry V. Levin <ldv@altlinux.org>
  * Copyright (c) 2016 Fabien Siron <fabien.siron@epita.fr>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -264,7 +264,7 @@ test_nlmsgerr(const int fd)
 	printf("sendto(%d, {{len=%u, type=NLMSG_ERROR, flags=NLM_F_REQUEST"
 	       ", seq=0, pid=0}, {error=-EACCES"
 	       ", msg={len=%u, type=NLMSG_NOOP, flags=NLM_F_REQUEST|0x%x"
-	       ", seq=%u, pid=%u}}}, %u, MSG_DONTWAIT, NULL, 0) = %s\n",
+	       ", seq=%u, pid=%d}}}, %u, MSG_DONTWAIT, NULL, 0) = %s\n",
 	       fd, nlh->nlmsg_len, err->msg.nlmsg_len, NLM_F_DUMP,
 	       err->msg.nlmsg_seq, err->msg.nlmsg_pid,
 	       nlh->nlmsg_len, sprintrc(rc));
@@ -289,7 +289,7 @@ test_nlmsgerr(const int fd)
 	printf("sendto(%d, {{len=%u, type=NLMSG_ERROR, flags=NLM_F_REQUEST"
 	       ", seq=0, pid=0}, {error=-EACCES"
 	       ", msg={{len=%u, type=NLMSG_NOOP, flags=NLM_F_REQUEST|0x%x"
-	       ", seq=%u, pid=%u}, \"\\x61\\x62\\x63\\x64\"}}}"
+	       ", seq=%u, pid=%d}, \"\\x61\\x62\\x63\\x64\"}}}"
 	       ", %u, MSG_DONTWAIT, NULL, 0) = %s\n",
 	       fd, nlh->nlmsg_len, err->msg.nlmsg_len, NLM_F_DUMP,
 	       err->msg.nlmsg_seq, err->msg.nlmsg_pid,
diff -pruN 5.5-3/tests-mx32/netlink_sock_diag.test 5.9-0ubuntu2/tests-mx32/netlink_sock_diag.test
--- 5.5-3/tests-mx32/netlink_sock_diag.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/netlink_sock_diag.test	2020-06-01 14:15:16.000000000 +0000
@@ -2,7 +2,7 @@
 #
 # Check decoding of NETLINK_SOCK_DIAG protocol
 #
-# Copyright (c) 2017-2018 The strace developers.
+# Copyright (c) 2017-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,4 +10,4 @@
 . "${srcdir=.}/init.sh"
 
 run_prog ../netlink_netlink_diag
-run_strace_match_diff -e trace=sendto
+run_strace_match_diff -e trace=sendto "$@"
diff -pruN 5.5-3/tests-mx32/netlink_sock_diag-v.sh 5.9-0ubuntu2/tests-mx32/netlink_sock_diag-v.sh
--- 5.5-3/tests-mx32/netlink_sock_diag-v.sh	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/netlink_sock_diag-v.sh	1970-01-01 00:00:00.000000000 +0000
@@ -1,13 +0,0 @@
-#!/bin/sh
-#
-# Check verbose decoding of NETLINK_SOCK_DIAG protocol
-#
-# Copyright (c) 2017-2018 The strace developers.
-# All rights reserved.
-#
-# SPDX-License-Identifier: GPL-2.0-or-later
-
-. "${srcdir=.}/init.sh"
-
-run_prog ../netlink_netlink_diag
-run_strace_match_diff -v -e trace=sendto
diff -pruN 5.5-3/tests-mx32/net-sockaddr.c 5.9-0ubuntu2/tests-mx32/net-sockaddr.c
--- 5.5-3/tests-mx32/net-sockaddr.c	2019-08-29 17:20:57.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/net-sockaddr.c	2020-08-25 14:29:30.000000000 +0000
@@ -2,13 +2,14 @@
  * Check decoding of sockaddr structures
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include "pidns.h"
 #include <stddef.h>
 #include <stdio.h>
 #include <string.h>
@@ -40,18 +41,21 @@ check_un(void)
 	memset(un->sun_path, '0', sizeof(un->sun_path));
 	unsigned int len = sizeof(*un);
 	int ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=\"%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n",
 	       (int) sizeof(un->sun_path), 0, len, ret);
 
 	un->sun_path[1] = 0;
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=\"%u\"}, %u)"
 	       " = %d EBADF (%m)\n", 0, len, ret);
 
 	un->sun_path[0] = 0;
 	un->sun_path[2] = 1;
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=@\"\\0\\001%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n",
 	       (int) sizeof(un->sun_path) - 3, 0, len, ret);
@@ -61,12 +65,14 @@ check_un(void)
 	memset(un->sun_path, '0', sizeof(un->sun_path));
 	len = sizeof(*un) + 2;
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=\"%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n",
 	       (int) sizeof(un->sun_path), 0, len, ret);
 
 	un->sun_path[0] = 0;
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=@\"%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n",
 	       (int) sizeof(un->sun_path) - 1, 0, len, ret);
@@ -75,18 +81,21 @@ check_un(void)
 	un->sun_family = AF_UNIX;
 	len = sizeof(*un) - 2;
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=\"%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n",
 	       (int) sizeof(un->sun_path) - 2, 0, len, ret);
 
 	un->sun_path[0] = 0;
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=@\"%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n",
 	       (int) sizeof(un->sun_path) - 3, 0, len, ret);
 
 	len = sizeof(*un);
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, %p, %u) = %d EBADF (%m)\n", un, len, ret);
 
 	un = tail_alloc(sizeof(struct sockaddr_storage));
@@ -94,12 +103,14 @@ check_un(void)
 	memset(un->sun_path, '0', sizeof(un->sun_path));
 	len = sizeof(struct sockaddr_storage) + 1;
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=\"%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n",
 	       (int) sizeof(un->sun_path), 0, len, ret);
 
 	un->sun_path[0] = 0;
 	ret = connect(-1, (void *) un, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNIX, sun_path=@\"%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n",
 	       (int) sizeof(un->sun_path) - 1, 0, len, ret);
@@ -117,6 +128,7 @@ check_in(void)
 	in->sin_addr.s_addr = inet_addr(h_addr);
 	unsigned int len = sizeof(*in);
 	int ret = connect(-1, (void *) in, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_INET, sin_port=htons(%hu)"
 	       ", sin_addr=inet_addr(\"%s\")}, %u) = %d EBADF (%m)\n",
 	       h_port, h_addr, len, ret);
@@ -127,6 +139,7 @@ check_in(void)
 	in->sin_addr.s_addr = inet_addr(h_addr);
 	len = sizeof(*in) + 4;
 	ret = connect(-1, (void *) in, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_INET, sin_port=htons(%hu)"
 	       ", sin_addr=inet_addr(\"%s\")}, %u) = %d EBADF (%m)\n",
 	       h_port, h_addr, len, ret);
@@ -137,6 +150,7 @@ check_in(void)
 	in->sin_addr.s_addr = 0;
 	len = sizeof(*in) - 4;
 	ret = connect(-1, (void *) in, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_INET, sa_data=\"%s\"}, %u)"
 	       " = %d EBADF (%m)\n",
 	       "\\0\\0\\0\\0\\0\\0\\377\\377\\377\\377",
@@ -144,6 +158,7 @@ check_in(void)
 
 	len = sizeof(*in);
 	ret = connect(-1, (void *) in, len);
+	pidns_print_leader();
 	printf("connect(-1, %p, %u) = %d EBADF (%m)\n", in, len, ret);
 }
 
@@ -155,6 +170,7 @@ check_in6_linklocal(struct sockaddr_in6
 	in6->sin6_scope_id = 0xfacefeed;
 	unsigned int len = sizeof(*in6);
 	int ret = connect(-1, (void *) in6, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_INET6, sin6_port=htons(%hu)"
 	       ", sin6_flowinfo=htonl(%u)"
 	       ", inet_pton(AF_INET6, \"%s\", &sin6_addr)"
@@ -166,7 +182,8 @@ check_in6_linklocal(struct sockaddr_in6
 	in6->sin6_scope_id = ifindex_lo();
 	if (in6->sin6_scope_id) {
 		ret = connect(-1, (void *) in6, len);
-		printf("connect(-1, {sa_family=AF_INET6, sin6_port=htons(%hu)"
+		pidns_print_leader();
+	printf("connect(-1, {sa_family=AF_INET6, sin6_port=htons(%hu)"
 		       ", sin6_flowinfo=htonl(%u)"
 		       ", inet_pton(AF_INET6, \"%s\", &sin6_addr)"
 		       ", sin6_scope_id=%s}, %u)"
@@ -191,6 +208,7 @@ check_in6(void)
 	in6->sin6_scope_id = 0xfacefeed;
 	unsigned int len = sizeof(*in6);
 	int ret = connect(-1, (void *) in6, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_INET6, sin6_port=htons(%hu)"
 	       ", sin6_flowinfo=htonl(%u)"
 	       ", inet_pton(AF_INET6, \"%s\", &sin6_addr)"
@@ -209,6 +227,7 @@ check_in6(void)
 	in6->sin6_scope_id = 0xfacefeed;
 	len = sizeof(*in6) + 4;
 	ret = connect(-1, (void *) in6, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_INET6, sin6_port=htons(%hu)"
 	       ", sin6_flowinfo=htonl(%u)"
 	       ", inet_pton(AF_INET6, \"%s\", &sin6_addr)"
@@ -223,6 +242,7 @@ check_in6(void)
 	inet_pton(AF_INET6, h_addr, &in6->sin6_addr);
 	len = sizeof(*in6) - sizeof(in6->sin6_scope_id);
 	ret = connect(-1, (void *) in6, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_INET6, sin6_port=htons(%hu)"
 	       ", sin6_flowinfo=htonl(%u)"
 	       ", inet_pton(AF_INET6, \"%s\", &sin6_addr)}, %u)"
@@ -236,6 +256,7 @@ check_in6(void)
 	memset(&in6->sin6_addr, '0', sizeof(in6->sin6_addr) - 4);
 	len = sizeof(*in6) - sizeof(in6->sin6_scope_id) - 4;
 	ret = connect(-1, (void *) in6, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_INET6"
 	       ", sa_data=\"\\0\\0\\0\\0\\0\\000%.*u\"}, %u)"
 	       " = %d EBADF (%m)\n",
@@ -244,6 +265,7 @@ check_in6(void)
 
 	len = sizeof(*in6) - sizeof(in6->sin6_scope_id);
 	ret = connect(-1, (void *) in6, len);
+	pidns_print_leader();
 	printf("connect(-1, %p, %u) = %d EBADF (%m)\n", in6, len, ret);
 }
 
@@ -262,6 +284,7 @@ check_ipx(void)
 	void *ipx = tail_memdup(&c_ipx, sizeof(c_ipx));
 	unsigned int len = sizeof(c_ipx);
 	int ret = connect(-1, ipx, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_IPX, sipx_port=htons(%u)"
 	       ", sipx_network=htonl(%#x)"
 	       ", sipx_node=[%#02x, %#02x, %#02x, %#02x, %#02x, %#02x]"
@@ -316,18 +339,21 @@ check_ax25(void)
 	fill_memory(sax, size);
 	sax->fsa_ax25.sax25_family = AF_AX25;
 	rc = connect(-1, sax_void, sizeof(struct sockaddr_ax25) - 1);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_AX25, sa_data=\"\\202\\203\\204\\205"
 	       "\\206\\207\\210\\211\\212\\213\\214\\215\\216\"}, %zu) = %s\n",
 	       sizeof(struct sockaddr_ax25) - 1, sprintrc(rc));
 
 	memcpy(sax, &ax25, sizeof(ax25));
 	rc = connect(-1, sax_void, sizeof(struct sockaddr_ax25));
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_AX25, fsa_ax25={sax25_call=VALID-13"
 	       ", sax25_ndigis=8}, fsa_digipeater=[/* ??? */]}, %zu) = %s\n",
 	       sizeof(struct sockaddr_ax25), sprintrc(rc));
 
 	sax->fsa_ax25.sax25_ndigis = 0;
 	rc = connect(-1, sax_void, sizeof(struct sockaddr_ax25));
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_AX25, sax25_call=VALID-13"
 	       ", sax25_ndigis=0}, %zu) = %s\n",
 	       sizeof(struct sockaddr_ax25), sprintrc(rc));
@@ -335,6 +361,7 @@ check_ax25(void)
 	sax->fsa_ax25.sax25_ndigis = 8;
 	size = sizeof(struct sockaddr_ax25) + sizeof(ax25_address) * 3 + 1;
 	rc = connect(-1, sax_void, size);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_AX25, fsa_ax25={sax25_call=VALID-13"
 	       ", sax25_ndigis=8}, fsa_digipeater"
 	       "=[{ax25_call=\"\\xa6\\xa0\\x82\\x40\\x86\\x8a\\x00\""
@@ -348,6 +375,7 @@ check_ax25(void)
 	sax->fsa_digipeater[2].ax25_call[6] = 0x4;
 	size = sizeof(struct sockaddr_ax25) + sizeof(ax25_address) * 4;
 	rc = connect(-1, sax_void, size);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_AX25, fsa_ax25={sax25_call=VALID-13"
 	       ", sax25_ndigis=8}, fsa_digipeater"
 	       "=[{ax25_call=\"\\xa6\\xa0\\x82\\x40\\x86\\x8a\\x00\""
@@ -365,6 +393,7 @@ check_ax25(void)
 	for (size_t i = 0; i < 3; i++) {
 		size = sizeof(ax25) + sizeof(ax25_address) * (i / 2);
 		rc = connect(-1, sax_void, size);
+		pidns_print_leader();
 		printf("connect(-1, {sa_family=AF_AX25"
 		       ", fsa_ax25={sax25_call=VALID-13, sax25_ndigis=%d}"
 		       ", fsa_digipeater=[VALID2-7, OK-15, %s /* FINE-2 */"
@@ -423,25 +452,28 @@ check_x25(void)
 		.sx25_family = AF_X25,
 		.sx25_addr = { "0123456789abcdef" },
 	};
-	void *x25_void = tail_memdup(&c_x25, sizeof(c_x25) + 1);
-	struct sockaddr_x25 *x25 = x25_void;
+	void *const x25_void = tail_memdup(&c_x25, sizeof(c_x25) + 1);
 	long rc;
 
-	rc = connect(-1, x25, sizeof(c_x25) - 1);
+	rc = connect(-1, x25_void, sizeof(c_x25) - 1);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_X25"
 	       ", sa_data=\"0123456789abcde\"}, %zu) = %s\n",
 	       sizeof(c_x25) - 1, sprintrc(rc));
 
 	for (size_t i = 0; i < 2; i++) {
-		rc = connect(-1, x25, sizeof(c_x25) + i);
+		rc = connect(-1, x25_void, sizeof(c_x25) + i);
+		pidns_print_leader();
 		printf("connect(-1, {sa_family=AF_X25"
 		       ", sx25_addr={x25_addr=\"0123456789abcde\"...}"
 		       "}, %zu) = %s\n",
 		       sizeof(c_x25) + i, sprintrc(rc));
 	}
 
+	struct sockaddr_x25 *const x25 = x25_void;
 	x25->sx25_addr.x25_addr[10] = '\0';
-	rc = connect(-1, x25, sizeof(c_x25));
+	rc = connect(-1, x25_void, sizeof(c_x25));
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_X25"
 	       ", sx25_addr={x25_addr=\"0123456789\"}"
 	       "}, %zu) = %s\n",
@@ -457,19 +489,21 @@ check_nl(void)
 	nl->nl_groups = 0xfacefeed;
 	unsigned int len = sizeof(*nl);
 	int ret = connect(-1, (void *) nl, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_NETLINK, nl_pid=%d"
 	       ", nl_groups=%#08x}, %u) = %d EBADF (%m)\n",
 	       nl->nl_pid, nl->nl_groups, len, ret);
 
 	nl = ((void *) nl) - 4;
 	nl->nl_family = AF_NETLINK;
-	nl->nl_pid = 1234567890;
+	nl->nl_pid = getpid();
 	nl->nl_groups = 0xfacefeed;
 	len = sizeof(*nl) + 4;
 	ret = connect(-1, (void *) nl, len);
-	printf("connect(-1, {sa_family=AF_NETLINK, nl_pid=%d"
+	pidns_print_leader();
+	printf("connect(-1, {sa_family=AF_NETLINK, nl_pid=%d%s"
 	       ", nl_groups=%#08x}, %u) = %d EBADF (%m)\n",
-	       nl->nl_pid, nl->nl_groups, len, ret);
+	       nl->nl_pid, pidns_pid2str(PT_TGID), nl->nl_groups, len, ret);
 }
 
 static void
@@ -487,6 +521,7 @@ check_ll(void)
 	void *ll = tail_memdup(&c_ll, sizeof(c_ll));
 	unsigned int len = sizeof(c_ll);
 	int ret = connect(-1, ll, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_PACKET"
 	       ", sll_protocol=htons(ETH_P_ALL)"
 	       ", sll_ifindex=%u, sll_hatype=ARPHRD_ETHER"
@@ -502,6 +537,7 @@ check_ll(void)
 
 	((struct sockaddr_ll *) ll)->sll_halen++;
 	ret = connect(-1, ll, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_PACKET"
 	       ", sll_protocol=htons(ETH_P_ALL)"
 	       ", sll_ifindex=%u, sll_hatype=ARPHRD_ETHER"
@@ -517,6 +553,7 @@ check_ll(void)
 
 	((struct sockaddr_ll *) ll)->sll_halen = 0;
 	ret = connect(-1, ll, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_PACKET"
 	       ", sll_protocol=htons(ETH_P_ALL)"
 	       ", sll_ifindex=%u, sll_hatype=ARPHRD_ETHER"
@@ -526,6 +563,7 @@ check_ll(void)
 	((struct sockaddr_ll *) ll)->sll_ifindex = ifindex_lo();
 	if (((struct sockaddr_ll *) ll)->sll_ifindex) {
 		ret = connect(-1, ll, len);
+	pidns_print_leader();
 		printf("connect(-1, {sa_family=AF_PACKET"
 		       ", sll_protocol=htons(ETH_P_ALL)"
 		       ", sll_ifindex=%s"
@@ -549,11 +587,13 @@ check_hci(void)
 	unsigned int len = sizeof(*hci);
 
 	int ret = connect(-1, (void *) hci, 4);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH, hci_dev=htobs(%hu)"
 	       "}, 4) = %d EBADF (%m)\n",
 	       h_port, ret);
 
 	ret = connect(-1, (void *) hci, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH, hci_dev=htobs(%hu)"
 # ifdef HAVE_STRUCT_SOCKADDR_HCI_HCI_CHANNEL
 	       ", hci_channel=HCI_CHANNEL_RAW"
@@ -572,6 +612,7 @@ check_sco(void)
 	void *sco = tail_memdup(&c_sco, sizeof(c_sco));
 	unsigned int len = sizeof(c_sco);
 	int ret = connect(-1, sco, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH"
 	       ", sco_bdaddr=%02x:%02x:%02x:%02x:%02x:%02x"
 	       "}, %u) = %d EBADF (%m)\n",
@@ -592,6 +633,7 @@ check_rc(void)
 	void *rc = tail_memdup(&c_rc, sizeof(c_rc));
 	unsigned int len = sizeof(c_rc);
 	int ret = connect(-1, rc, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH"
 	       ", rc_bdaddr=%02x:%02x:%02x:%02x:%02x:%02x"
 	       ", rc_channel=%u}, %u) = %d EBADF (%m)\n",
@@ -619,6 +661,7 @@ check_l2(void)
 	unsigned int len = sizeof(c_l2);
 
 	int ret = connect(-1, l2, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH"
 	       ", l2_psm=htobs(L2CAP_PSM_DYN_START + %hu)"
 	       ", l2_bdaddr=%02x:%02x:%02x:%02x:%02x:%02x"
@@ -640,6 +683,7 @@ check_l2(void)
 # endif
 	memcpy(l2, &c_l2, sizeof(c_l2));
 	ret = connect(-1, l2, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH"
 	       ", l2_psm=htobs(L2CAP_PSM_SDP)"
 	       ", l2_bdaddr=%02x:%02x:%02x:%02x:%02x:%02x"
@@ -660,6 +704,7 @@ check_l2(void)
 # endif
 	memcpy(l2, &c_l2, sizeof(c_l2));
 	ret = connect(-1, l2, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH"
 	       ", l2_psm=htobs(0xbad /* L2CAP_PSM_??? */)"
 	       ", l2_bdaddr=%02x:%02x:%02x:%02x:%02x:%02x"
@@ -677,6 +722,7 @@ check_l2(void)
 	c_l2.l2_cid = htobs(0xffff);
 	memcpy(l2, &c_l2, 12);
 	ret = connect(-1, l2, 12);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH"
 	       ", l2_psm=htobs(L2CAP_PSM_AUTO_END)"
 	       ", l2_bdaddr=%02x:%02x:%02x:%02x:%02x:%02x"
@@ -700,6 +746,7 @@ check_raw(void)
 	u.sa->sa_family = 0xff;
 	unsigned int len = sizeof(*u.st) + 8;
 	int ret = connect(-1, (void *) u.st, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=%#x /* AF_??? */, sa_data=\"%.*u\"}"
 	       ", %u) = %d EBADF (%m)\n", u.sa->sa_family,
 	       (int) (sizeof(*u.st) - sizeof(u.sa->sa_family)), 0, len, ret);
@@ -707,11 +754,13 @@ check_raw(void)
 	u.sa->sa_family = 0;
 	len = sizeof(u.sa->sa_family) + 1;
 	ret = connect(-1, (void *) u.st, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_UNSPEC, sa_data=\"0\"}, %u)"
 	       " = %d EBADF (%m)\n", len, ret);
 
 	u.sa->sa_family = AF_BLUETOOTH;
 	ret = connect(-1, (void *) u.st, len);
+	pidns_print_leader();
 	printf("connect(-1, {sa_family=AF_BLUETOOTH, sa_data=\"0\"}, %u)"
 	       " = %d EBADF (%m)\n", len, ret);
 }
@@ -719,6 +768,8 @@ check_raw(void)
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	check_un();
 	check_in();
 	check_in6();
@@ -735,6 +786,7 @@ main(void)
 #endif
 	check_raw();
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/net-sockaddr--pidns-translation.c 5.9-0ubuntu2/tests-mx32/net-sockaddr--pidns-translation.c
--- 5.5-3/tests-mx32/net-sockaddr--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/net-sockaddr--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "net-sockaddr.c"
diff -pruN 5.5-3/tests-mx32/net-sockaddr--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/net-sockaddr--pidns-translation.gen.test
--- 5.5-3/tests-mx32/net-sockaddr--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/net-sockaddr--pidns-translation.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (net-sockaddr--pidns-translation test_pidns -a24 -e trace=connect); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a24 -e trace=connect
diff -pruN 5.5-3/tests-mx32/net-yy-netlink.c 5.9-0ubuntu2/tests-mx32/net-yy-netlink.c
--- 5.5-3/tests-mx32/net-yy-netlink.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/net-yy-netlink.c	2020-07-18 08:00:00.000000000 +0000
@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2013-2017 Dmitry V. Levin <ldv@altlinux.org>
  * Copyright (c) 2016 Fabien Siron <fabien.siron@epita.fr>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -21,6 +21,27 @@
 #include <linux/sock_diag.h>
 #include <linux/netlink_diag.h>
 
+#ifndef PRINT_SOCK
+# define PRINT_SOCK 2
+#endif
+
+#if PRINT_SOCK == 2
+# define FMT_UNBOUND "<NETLINK:[%lu]>"
+# define FMT_BOUND   "<NETLINK:[SOCK_DIAG:%u]>"
+# define ARG_UNBOUND inode
+# define ARG_BOUND   addr.nl_pid
+#elif PRINT_SOCK == 1
+# define FMT_UNBOUND "<socket:[%lu]>"
+# define FMT_BOUND   "<socket:[%lu]>"
+# define ARG_UNBOUND inode
+# define ARG_BOUND   inode
+#else
+# define FMT_UNBOUND "%s"
+# define FMT_BOUND   "%s"
+# define ARG_UNBOUND ""
+# define ARG_BOUND   ""
+#endif
+
 int
 main(void)
 {
@@ -37,25 +58,27 @@ main(void)
 	const int fd = socket(AF_NETLINK, SOCK_RAW, NETLINK_SOCK_DIAG);
 	if (fd < 0)
 		perror_msg_and_skip("socket");
+#if PRINT_SOCK
 	const unsigned long inode = inode_of_sockfd(fd);
+#endif
 	printf("socket(AF_NETLINK, SOCK_RAW, NETLINK_SOCK_DIAG) = "
-	       "%d<NETLINK:[%lu]>\n", fd, inode);
+	       "%d" FMT_UNBOUND "\n", fd, ARG_UNBOUND);
 
 	if (bind(fd, sa, *len))
 		perror_msg_and_skip("bind");
-	printf("bind(%d<NETLINK:[%lu]>, {sa_family=AF_NETLINK"
-	       ", nl_pid=%u, nl_groups=00000000}, %u) = 0\n",
-	       fd, inode, addr.nl_pid, (unsigned) *len);
+	printf("bind(%d" FMT_UNBOUND ", {sa_family=AF_NETLINK"
+	       ", nl_pid=%d, nl_groups=00000000}, %u) = 0\n",
+	       fd, ARG_UNBOUND, addr.nl_pid, (unsigned) *len);
 
 	if (getsockname(fd, sa, len))
 		perror_msg_and_fail("getsockname");
-	printf("getsockname(%d<NETLINK:[SOCK_DIAG:%u]>, {sa_family=AF_NETLINK"
-	       ", nl_pid=%u, nl_groups=00000000}, [%u]) = 0\n",
-	       fd, addr.nl_pid, addr.nl_pid, (unsigned) *len);
+	printf("getsockname(%d" FMT_BOUND ", {sa_family=AF_NETLINK"
+	       ", nl_pid=%d, nl_groups=00000000}, [%u]) = 0\n",
+	       fd, ARG_BOUND, addr.nl_pid, (unsigned) *len);
 
 	if (close(fd))
 		perror_msg_and_fail("close");
-	printf("close(%d<NETLINK:[SOCK_DIAG:%u]>) = 0\n", fd, addr.nl_pid);
+	printf("close(%d" FMT_BOUND ") = 0\n", fd, ARG_BOUND);
 
 	puts("+++ exited with 0 +++");
 	return 0;
diff -pruN 5.5-3/tests-mx32/net-yy-netlink.test 5.9-0ubuntu2/tests-mx32/net-yy-netlink.test
--- 5.5-3/tests-mx32/net-yy-netlink.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/net-yy-netlink.test	2020-04-03 22:58:26.000000000 +0000
@@ -6,7 +6,7 @@
 # Copyright (c) 2014 Masatake YAMATO <yamato@redhat.com>
 # Copyright (c) 2014-2016 Dmitry V. Levin <ldv@altlinux.org>
 # Copyright (c) 2016 Fabien Siron <fabien.siron@epita.fr>
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -15,9 +15,11 @@
 
 check_prog sed
 
+opts="${*:--yy}"
+
 run_prog ../netlink_netlink_diag
 run_prog > /dev/null
-run_strace -a22 -yy -eclose,network $args > "$EXP"
+run_strace -a22 ${opts} -eclose,network $args > "$EXP"
 
 # Filter out close() calls made by ld.so and libc.
 sed -n '/socket/,$p' < "$LOG" > "$OUT"
diff -pruN 5.5-3/tests-mx32/nlattr_ifinfomsg.c 5.9-0ubuntu2/tests-mx32/nlattr_ifinfomsg.c
--- 5.5-3/tests-mx32/nlattr_ifinfomsg.c	2019-11-28 19:30:05.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/nlattr_ifinfomsg.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2017 JingPiao Chen <chenjingpiao@gmail.com>
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -27,6 +27,8 @@
 #endif
 #define IFLA_LINK_NETNSID 37
 #define IFLA_EVENT 44
+#define IFLA_PROP_LIST 52
+#define IFLA_ALT_IFNAME 53
 
 #ifndef IFLA_INFO_KIND
 # define IFLA_INFO_KIND 1
@@ -36,6 +38,8 @@
 # define IFLA_VF_PORT 1
 #endif
 
+static const unsigned int hdrlen = sizeof(struct ifinfomsg);
+
 static void
 init_ifinfomsg(struct nlmsghdr *const nlh, const unsigned int msg_len)
 {
@@ -65,6 +69,27 @@ print_ifinfomsg(const unsigned int msg_l
 	       msg_len);
 }
 
+static void
+init_prop_list_msg(struct nlmsghdr *const nlh,
+		     const unsigned int msg_len)
+{
+	init_ifinfomsg(nlh, msg_len);
+
+	struct nlattr *nla = NLMSG_ATTR(nlh, hdrlen);
+	SET_STRUCT(struct nlattr, nla,
+		.nla_len = msg_len - NLMSG_SPACE(hdrlen),
+		.nla_type = IFLA_PROP_LIST,
+	);
+}
+
+static void
+print_prop_list_msg(const unsigned int msg_len)
+{
+	print_ifinfomsg(msg_len);
+	printf(", {{nla_len=%u, nla_type=IFLA_PROP_LIST}",
+	       msg_len - NLMSG_SPACE(hdrlen));
+}
+
 int
 main(void)
 {
@@ -96,9 +121,8 @@ main(void)
 		.tx_compressed = 0xefdadfab
 	};
 	const int fd = create_nl_socket(NETLINK_ROUTE);
-	const unsigned int hdrlen = sizeof(struct ifinfomsg);
 	void *nlh0 = midtail_alloc(NLMSG_SPACE(hdrlen),
-				   NLA_HDRLEN + sizeof(st));
+				   2 * NLA_HDRLEN + MAX(sizeof(st), 20));
 
 	static char pattern[4096];
 	fill_memory_ex(pattern, sizeof(pattern), 'a', 'z' - 'a' + 1);
@@ -339,6 +363,33 @@ main(void)
 				   printf("%s", ifla_events[i].str));
 	}
 
+	/* IFLA_PROP_LIST */
+	struct {
+		char p1[20];
+	} buf;
+	fill_memory(&buf, sizeof(buf));
+	TEST_NESTED_NLATTR_OBJECT_EX_(fd, nlh0, hdrlen,
+				      init_prop_list_msg, print_prop_list_msg,
+				      IFLA_ALT_IFNAME, "IFLA_ALT_IFNAME",
+				      pattern, buf, print_quoted_stringn, 1,
+				      print_quoted_memory(&buf, sizeof(buf));
+				      printf("..."));
+
+	/* IFLA_ALT_IFNAME */
+	static const char alt_ifname[] = "OH HAI THAR\r\n\t\377\0\v\x7e";
+	TEST_NLATTR(fd, nlh0, hdrlen,
+		    init_ifinfomsg, print_ifinfomsg,
+		    IFLA_ALT_IFNAME,
+		    sizeof(alt_ifname), alt_ifname, sizeof(alt_ifname),
+		    print_quoted_memory(alt_ifname, sizeof(alt_ifname) - 1));
+
+	TEST_NLATTR(fd, nlh0, hdrlen,
+		    init_ifinfomsg, print_ifinfomsg,
+		    IFLA_ALT_IFNAME,
+		    sizeof(alt_ifname) - 1, alt_ifname, sizeof(alt_ifname) - 1,
+		    print_quoted_memory(alt_ifname, sizeof(alt_ifname) - 1);
+		    printf("..."));
+
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/nlattr_ifla_linkinfo.c 5.9-0ubuntu2/tests-mx32/nlattr_ifla_linkinfo.c
--- 5.5-3/tests-mx32/nlattr_ifla_linkinfo.c	2019-03-18 02:40:16.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/nlattr_ifla_linkinfo.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * IFLA_LINKINFO netlink attribute decoding check.
  *
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -347,7 +347,6 @@ main(void)
 	/* bridge attrs */
 	static const struct val_name und_br_attrs[] = {
 		{ 0, "IFLA_BR_UNSPEC" },
-		{ 20, "IFLA_BR_GROUP_ADDR" },
 		{ 21, "IFLA_BR_FDB_FLUSH" },
 		{ 40, "IFLA_BR_PAD" },
 		{ 47, "0x2f /* IFLA_BR_??? */" },
@@ -367,6 +366,21 @@ main(void)
 					"\\x63\\x64\\x65\\x66\"" });
 	}
 
+	static const struct val_name hwa_br_attrs[] = {
+		{ 20, "IFLA_BR_GROUP_ADDR" },
+	};
+
+	for (size_t k = 0; k < ARRAY_SIZE(hwa_br_attrs); k++) {
+		TEST_NESTED_LINKINFO(fd, nlh0, 2, "IFLA_INFO_DATA", "bridge",
+				     hwa_br_attrs[k].val, hwa_br_attrs[k].name,
+				     unknown_msg, pattern,
+				     { 2, "ab:ac" },
+				     { 4, "ab:ac:db:cd" },
+				     { 6, "ab:ac:db:cd:61:62" },
+				     { 8, "ab:ac:db:cd:61:62:63:64" },
+				     { 10, "ab:ac:db:cd:61:62:63:64:65:66" });
+	}
+
 	static const struct val_name u64_br_attrs[] = {
 		{ 16, "IFLA_BR_HELLO_TIMER" },
 		{ 17, "IFLA_BR_TCN_TIMER" },
diff -pruN 5.5-3/tests-mx32/nlattr_ifla_xdp.c 5.9-0ubuntu2/tests-mx32/nlattr_ifla_xdp.c
--- 5.5-3/tests-mx32/nlattr_ifla_xdp.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/nlattr_ifla_xdp.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2017 JingPiao Chen <chenjingpiao@gmail.com>
- * Copyright (c) 2017-2018 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -17,44 +17,28 @@
 #endif
 #include <linux/rtnetlink.h>
 
+#define XLAT_MACROS_ONLY
+# include "xlat/rtnl_ifla_xdp_attrs.h"
+#undef XLAT_MACROS_ONLY
+
 #if !HAVE_DECL_IFLA_XDP
 enum { IFLA_XDP = 43 };
 #endif
-#ifndef IFLA_XDP_FD
-# define IFLA_XDP_FD 1
-#endif
-
-#ifndef IFLA_XDP_ATTACHED
-# define IFLA_XDP_ATTACHED 2
-#endif
-
-#ifndef IFLA_XDP_PROG_ID
-# define IFLA_XDP_PROG_ID 4
-#endif
-
-#ifndef IFLA_XDP_DRV_PROG_ID
-# define IFLA_XDP_DRV_PROG_ID 5
-#endif
 
-#ifndef IFLA_XDP_SKB_PROG_ID
-# define IFLA_XDP_SKB_PROG_ID 6
+#if !HAVE_DECL_XDP_ATTACHED_NONE
+enum { XDP_ATTACHED_NONE = 0 };
 #endif
-
-#ifndef IFLA_XDP_HW_PROG_ID
-# define IFLA_XDP_HW_PROG_ID 7
-#endif
-
-#ifndef XDP_ATTACHED_NONE
-# define XDP_ATTACHED_NONE 0
-#endif
-
-#ifndef XDP_ATTACHED_MULTI
-# define XDP_ATTACHED_MULTI 4
+#if !HAVE_DECL_XDP_ATTACHED_MULTI
+enum { XDP_ATTACHED_MULTI = 4 };
 #endif
 
 #define IFLA_ATTR IFLA_XDP
 #include "nlattr_ifla.h"
 
+#ifndef FD9_PATH
+# define FD9_PATH ""
+#endif
+
 int
 main(void)
 {
@@ -118,6 +102,18 @@ main(void)
 					      printf("%u", num));
 	}
 
+	/* IFLA_XDP_EXPECTED_FD */
+	TEST_NESTED_NLATTR_OBJECT_EX(fd, nlh0, hdrlen,
+				     init_ifinfomsg, print_ifinfomsg,
+				     IFLA_XDP_EXPECTED_FD, pattern, num, 1,
+				     printf("%d", num));
+
+	int exp_fd = 9;
+	TEST_NESTED_NLATTR_OBJECT_EX(fd, nlh0, hdrlen,
+				     init_ifinfomsg, print_ifinfomsg,
+				     IFLA_XDP_EXPECTED_FD, pattern, exp_fd, 1,
+				     printf("9" FD9_PATH));
+
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/nlattr_ifla_xdp-y.c 5.9-0ubuntu2/tests-mx32/nlattr_ifla_xdp-y.c
--- 5.5-3/tests-mx32/nlattr_ifla_xdp-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/nlattr_ifla_xdp-y.c	2020-05-30 08:00:00.000000000 +0000
@@ -0,0 +1,3 @@
+#define PRINT_SOCK 1
+#define FD9_PATH "</dev/full>"
+#include "nlattr_ifla_xdp.c"
diff -pruN 5.5-3/tests-mx32/nlattr_ifla_xdp-y.gen.test 5.9-0ubuntu2/tests-mx32/nlattr_ifla_xdp-y.gen.test
--- 5.5-3/tests-mx32/nlattr_ifla_xdp-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/nlattr_ifla_xdp-y.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (nlattr_ifla_xdp-y +netlink_sock_diag.test -y; exec 9</dev/full); do not edit.
+set -- -y; exec 9</dev/full
+. "${srcdir=.}/netlink_sock_diag.test"
diff -pruN 5.5-3/tests-mx32/nlattr_inet_diag_req_compat.c 5.9-0ubuntu2/tests-mx32/nlattr_inet_diag_req_compat.c
--- 5.5-3/tests-mx32/nlattr_inet_diag_req_compat.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/nlattr_inet_diag_req_compat.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2017 JingPiao Chen <chenjingpiao@gmail.com>
- * Copyright (c) 2017-2018 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -73,10 +73,10 @@ main(void)
 
 	char nla_type_str[256];
 	sprintf(nla_type_str, "%#x /* INET_DIAG_REQ_??? */",
-		INET_DIAG_REQ_BYTECODE + 1);
+		INET_DIAG_REQ_PROTOCOL + 1);
 	TEST_NLATTR_(fd, nlh0, hdrlen,
 		     init_inet_diag_req, print_inet_diag_req,
-		     INET_DIAG_REQ_BYTECODE + 1, nla_type_str,
+		     INET_DIAG_REQ_PROTOCOL + 1, nla_type_str,
 		     4, pattern, 4,
 		     print_quoted_hex(pattern, 4));
 
diff -pruN 5.5-3/tests-mx32/nlattr_ndmsg.c 5.9-0ubuntu2/tests-mx32/nlattr_ndmsg.c
--- 5.5-3/tests-mx32/nlattr_ndmsg.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/nlattr_ndmsg.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2017 JingPiao Chen <chenjingpiao@gmail.com>
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -100,11 +100,15 @@ main(void)
 			   printf("htons(%u)", ntohs(port)));
 
 	static const uint8_t mac[6] = "\xf8\xc2\x49\x13\x57\xbd";
-	TEST_NLATTR_OBJECT(fd, nlh0, hdrlen,
-			   init_ndmsg, print_ndmsg,
-			   NDA_LLADDR, pattern, mac,
-			   for (unsigned int i = 0; i < sizeof(mac); ++i)
-				printf("%s%02x", i ? ":" : "", mac[i]));
+	TEST_NLATTR(fd, nlh0, hdrlen, init_ndmsg, print_ndmsg,
+		    NDA_LLADDR, sizeof(mac) - 1, mac, sizeof(mac) - 1,
+		    for (unsigned int i = 0; i < sizeof(mac) - 1; ++i)
+			printf("%s%02x", i ? ":" : "", mac[i]));
+
+	TEST_NLATTR(fd, nlh0, hdrlen, init_ndmsg, print_ndmsg,
+		    NDA_LLADDR, sizeof(mac), mac, sizeof(mac),
+		    for (unsigned int i = 0; i < sizeof(mac); ++i)
+			printf("%s%02x", i ? ":" : "", mac[i]));
 
 	puts("+++ exited with 0 +++");
 	return 0;
diff -pruN 5.5-3/tests-mx32/nlattr_packet_diag_msg.gen.test 5.9-0ubuntu2/tests-mx32/nlattr_packet_diag_msg.gen.test
--- 5.5-3/tests-mx32/nlattr_packet_diag_msg.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/nlattr_packet_diag_msg.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -1,4 +1,4 @@
 #!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (nlattr_packet_diag_msg +netlink_sock_diag-v.sh ); do not edit.
-set -- 
-. "${srcdir=.}/netlink_sock_diag-v.sh"
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (nlattr_packet_diag_msg +netlink_sock_diag.test -v); do not edit.
+set -- -v
+. "${srcdir=.}/netlink_sock_diag.test"
diff -pruN 5.5-3/tests-mx32/nlattr_tcamsg.c 5.9-0ubuntu2/tests-mx32/nlattr_tcamsg.c
--- 5.5-3/tests-mx32/nlattr_tcamsg.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/nlattr_tcamsg.c	2020-05-30 08:00:00.000000000 +0000
@@ -22,6 +22,12 @@ enum { TCA_ACT_COOKIE = 6 };
 #if !HAVE_DECL_TCA_ACT_FLAGS
 enum { TCA_ACT_FLAGS = 7 };
 #endif
+#if !HAVE_DECL_TCA_ACT_HW_STATS
+enum { TCA_ACT_HW_STATS = 8 };
+#endif
+#if !HAVE_DECL_TCA_ACT_USED_HW_STATS
+enum { TCA_ACT_USED_HW_STATS = 9 };
+#endif
 
 
 static void
@@ -60,7 +66,7 @@ main(void)
 	fill_memory_ex(pattern, sizeof(pattern), 'a', 'z' - 'a' + 1);
 
 	/* Invalid */
-	static const unsigned int nla_invalid[] = { 8, 0xffff & NLA_TYPE_MASK };
+	static const unsigned int nla_invalid[] = { 10, 0xffff & NLA_TYPE_MASK };
 	for (size_t i = 0; i < ARRAY_SIZE(nla_invalid); i++) {
 		char nla_type_str[256];
 		sprintf(nla_type_str, "%#x /* TCA_ACT_??? */", nla_invalid[i]);
@@ -111,6 +117,21 @@ main(void)
 		    TCA_ACT_FLAGS, sizeof(flags), &flags, sizeof(flags),
 		    printf("TCA_ACT_FLAGS_NO_PERCPU_STATS|0xfacebeee"));
 
+	/* TCA_ACT_HW_STATS, TCA_ACT_USED_HW_STATS */
+	static const struct strval32 nla_hw_st[] = {
+		{ ARG_STR(TCA_ACT_HW_STATS) },
+		{ ARG_STR(TCA_ACT_USED_HW_STATS) },
+	};
+
+	static uint32_t hw_st = 0xfacebeef;
+	for (size_t i = 0; i < ARRAY_SIZE(nla_hw_st); i++) {
+		TEST_NLATTR_(fd, nlh0, hdrlen, init_tcamsg, print_tcamsg,
+			     nla_hw_st[i].val, nla_hw_st[i].str,
+			     sizeof(hw_st), &hw_st, sizeof(hw_st),
+			     printf("TCA_ACT_HW_STATS_IMMEDIATE|"
+				    "TCA_ACT_HW_STATS_DELAYED|0xfacebeec"));
+	}
+
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/nlattr_tc_stats.c 5.9-0ubuntu2/tests-mx32/nlattr_tc_stats.c
--- 5.5-3/tests-mx32/nlattr_tc_stats.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/nlattr_tc_stats.c	2020-04-03 22:58:26.000000000 +0000
@@ -16,9 +16,9 @@
 # include <linux/gen_stats.h>
 # include <linux/rtnetlink.h>
 
-#if !HAVE_DECL_TCA_STATS_PKT64
+# if !HAVE_DECL_TCA_STATS_PKT64
 enum { TCA_STATS_PKT64 = 8 };
-#endif
+# endif
 
 const unsigned int hdrlen = sizeof(struct tcmsg);
 
diff -pruN 5.5-3/tests-mx32/nsyscalls-d.test 5.9-0ubuntu2/tests-mx32/nsyscalls-d.test
--- 5.5-3/tests-mx32/nsyscalls-d.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/nsyscalls-d.test	2020-04-03 22:58:26.000000000 +0000
@@ -1,8 +1,8 @@
 #!/bin/sh
 #
-# Check decoding of out-of-range syscalls along with debug ouput
+# Check decoding of out-of-range syscalls along with debug output
 #
-# Copyright (c) 2017-2018 The strace developers.
+# Copyright (c) 2017-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
diff -pruN 5.5-3/tests-mx32/openat2.c 5.9-0ubuntu2/tests-mx32/openat2.c
--- 5.5-3/tests-mx32/openat2.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/openat2.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,172 @@
+/*
+ * Check decoding of openat2 syscall.
+ *
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+
+#ifdef __NR_openat2
+
+# include <errno.h>
+# include <stdint.h>
+# include <inttypes.h>
+# include <stdio.h>
+# include <string.h>
+# include <unistd.h>
+# include <asm/fcntl.h>
+
+# ifdef HAVE_LINUX_OPENAT2
+#  include <linux/openat2.h>
+# endif
+
+# ifndef HAVE_LINUX_OPENAT2
+struct open_how {
+	uint64_t flags;
+	uint64_t mode;
+	uint64_t resolve;
+};
+# endif
+
+# ifndef AT_FDCWD
+#  define AT_FDCWD -100
+# endif
+# ifndef RESOLVE_NO_XDEV
+#  define RESOLVE_NO_XDEV 0x01
+# endif
+# ifndef RESOLVE_IN_ROOT
+#  define RESOLVE_IN_ROOT 0x10
+# endif
+
+# ifndef O_TMPFILE
+#  if defined __hppa__
+#   define __O_TMPFILE     040000000
+#  elif defined __alpha__
+#   define __O_TMPFILE     0100000000
+#  elif defined __sparc__
+#   define __O_TMPFILE     0200000000
+#  else
+#   define __O_TMPFILE     020000000
+#  endif
+# endif
+
+# ifndef VERBOSE
+#  define VERBOSE 0
+# endif
+# ifndef FD0_PATH
+#  define FD0_PATH ""
+# endif
+
+static const char sample[] = "openat2.sample";
+
+int
+main(void)
+{
+	long rc;
+	const char *rcstr;
+	struct open_how *how = tail_alloc(sizeof(*how));
+	struct open_how *how_big = tail_alloc(sizeof(*how_big) + 8);
+
+	rc = syscall(__NR_openat2, 0, NULL, NULL,
+		     (kernel_ulong_t) 0xdeadc0debadc0dedULL);
+	printf("openat2(0" FD0_PATH ", NULL, NULL, %llu) = %s\n",
+	       (unsigned long long) (kernel_ulong_t) 0xdeadc0debadc0dedULL,
+	       sprintrc(rc));
+
+	rc = syscall(__NR_openat2, -100, "", how + 1, sizeof(*how));
+	printf("openat2(%s, \"\", %p, %zu) = %s\n",
+	       XLAT_KNOWN(-100, "AT_FDCWD"), how + 1, sizeof(*how),
+	       sprintrc(rc));
+
+	rc = syscall(__NR_openat2, -1, sample, how, 11);
+	printf("openat2(-1, \"%s\", %p, 11) = %s\n", sample, how, sprintrc(rc));
+
+	static struct strval64 flags[] = {
+		{ ARG_STR(O_RDONLY|O_EXCL) },
+		{ ARG_STR(O_WRONLY|O_CREAT) },
+		{ ARG_STR(O_RDWR|O_LARGEFILE) },
+# ifdef O_TMPFILE
+		{ ARG_STR(O_ACCMODE|O_TMPFILE) },
+# else
+		{ ARG_STR(O_ACCMODE|__O_TMPFILE) },
+# endif
+		{ ARG_ULL_STR(O_RDONLY|0xdeadface80000000) },
+	};
+	static uint64_t modes[] = { 0, 0777, 0xbadc0dedfacebeefULL };
+	static struct strval64 resolve[] = {
+		{ 0, NULL },
+		{ ARG_STR(RESOLVE_NO_XDEV) },
+		{ ARG_ULL_STR(RESOLVE_NO_XDEV|RESOLVE_IN_ROOT|0xfeedfacedcaffee0) },
+		{ 0xdec0dedbeefface0, NULL },
+	};
+	const size_t iters = MAX(MAX(ARRAY_SIZE(flags), ARRAY_SIZE(modes)),
+				 ARRAY_SIZE(resolve));
+
+
+	for (size_t i = 0; i < iters * 4; i++) {
+		how->flags = flags[i % ARRAY_SIZE(flags)].val;
+		how->mode = modes[i % ARRAY_SIZE(modes)];
+		how->resolve = resolve[i % ARRAY_SIZE(resolve)].val;
+
+		fill_memory(how_big + 1, 8);
+		memcpy(how_big, how, sizeof(*how));
+
+		for (size_t j = 0; j < 4; j++) {
+			rc = syscall(__NR_openat2, -1, sample,
+				     j > 1 ? how_big : how,
+				     j ? sizeof(*how) + 8 : sizeof(*how));
+			rcstr = sprintrc(rc);
+			printf("openat2(-1, \"%s\", {flags=%s",
+			       sample,
+			       sprintxlat(flags[i % ARRAY_SIZE(flags)].str,
+					  flags[i % ARRAY_SIZE(flags)].val,
+					  NULL));
+
+			if (how->mode || (i % ARRAY_SIZE(flags) == 1)
+				      || (i % ARRAY_SIZE(flags) == 3)) {
+				printf(", mode=%#03" PRIo64,
+				       modes[i % ARRAY_SIZE(modes)]);
+			}
+
+			printf(", resolve=%s",
+			       sprintxlat(resolve[i % ARRAY_SIZE(resolve)].str,
+					  resolve[i % ARRAY_SIZE(resolve)].val,
+					  resolve[i % ARRAY_SIZE(resolve)].val
+						? "RESOLVE_???" : NULL));
+			if (j == 1)
+				printf(", ???");
+			if (j == 2) {
+				printf(", /* bytes %zu..%zu */ \"\\x80\\x81"
+				       "\\x82\\x83\\x84\\x85\\x86\\x87\"",
+				       sizeof(*how), sizeof(*how) + 7);
+			}
+			printf("}, %zu) = %s\n",
+			       j ? sizeof(*how) + 8 : sizeof(*how), rcstr);
+
+			if (j == 2)
+				memset(how_big + 1, 0, 8);
+		}
+	}
+
+	how->flags = O_RDONLY | O_NOCTTY;
+	how->mode = 0;
+	how->resolve = 0;
+	rc = syscall(__NR_openat2, -100, "/dev/full", how, sizeof(*how));
+	printf("openat2(%s, \"/dev/full\", {flags=%s, resolve=0}, %zu)"
+	       " = %s%s\n",
+	       XLAT_KNOWN(-100, "AT_FDCWD"), XLAT_STR(O_RDONLY|O_NOCTTY),
+	       sizeof(*how), sprintrc(rc), rc >= 0 ? FD0_PATH : "");
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_openat2");
+
+#endif
diff -pruN 5.5-3/tests-mx32/openat2.gen.test 5.9-0ubuntu2/tests-mx32/openat2.gen.test
--- 5.5-3/tests-mx32/openat2.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/openat2.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2 -a35 ); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a35 
diff -pruN 5.5-3/tests-mx32/openat2-v.c 5.9-0ubuntu2/tests-mx32/openat2-v.c
--- 5.5-3/tests-mx32/openat2-v.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/openat2-v.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define VERBOSE 1
+#include "openat2.c"
diff -pruN 5.5-3/tests-mx32/openat2-v.gen.test 5.9-0ubuntu2/tests-mx32/openat2-v.gen.test
--- 5.5-3/tests-mx32/openat2-v.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/openat2-v.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-v --trace=openat2 -a35 -v); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a35 -v
diff -pruN 5.5-3/tests-mx32/openat2-v-y.c 5.9-0ubuntu2/tests-mx32/openat2-v-y.c
--- 5.5-3/tests-mx32/openat2-v-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/openat2-v-y.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define FD0_PATH "</dev/full>"
+#include "openat2-v.c"
diff -pruN 5.5-3/tests-mx32/openat2-v-y.gen.test 5.9-0ubuntu2/tests-mx32/openat2-v-y.gen.test
--- 5.5-3/tests-mx32/openat2-v-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/openat2-v-y.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-v-y --trace=openat2 -a36 -v -y </dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a36 -v -y </dev/full
diff -pruN 5.5-3/tests-mx32/openat2-v-y-Xabbrev.c 5.9-0ubuntu2/tests-mx32/openat2-v-y-Xabbrev.c
--- 5.5-3/tests-mx32/openat2-v-y-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/openat2-v-y-Xabbrev.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "openat2-v-y.c"
diff -pruN 5.5-3/tests-mx32/openat2-v-y-Xabbrev.gen.test 5.9-0ubuntu2/tests-mx32/openat2-v-y-Xabbrev.gen.test
--- 5.5-3/tests-mx32/openat2-v-y-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/openat2-v-y-Xabbrev.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-v-y-Xabbrev --trace=openat2 -a35 -v -y -Xabbrev </dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a35 -v -y -Xabbrev </dev/full
diff -pruN 5.5-3/tests-mx32/openat2-v-y-Xraw.c 5.9-0ubuntu2/tests-mx32/openat2-v-y-Xraw.c
--- 5.5-3/tests-mx32/openat2-v-y-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/openat2-v-y-Xraw.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "openat2-v-y.c"
diff -pruN 5.5-3/tests-mx32/openat2-v-y-Xraw.gen.test 5.9-0ubuntu2/tests-mx32/openat2-v-y-Xraw.gen.test
--- 5.5-3/tests-mx32/openat2-v-y-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/openat2-v-y-Xraw.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-v-y-Xraw --trace=openat2 -a32 -v -y -Xraw </dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a32 -v -y -Xraw </dev/full
diff -pruN 5.5-3/tests-mx32/openat2-v-y-Xverbose.c 5.9-0ubuntu2/tests-mx32/openat2-v-y-Xverbose.c
--- 5.5-3/tests-mx32/openat2-v-y-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/openat2-v-y-Xverbose.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "openat2-v-y.c"
diff -pruN 5.5-3/tests-mx32/openat2-v-y-Xverbose.gen.test 5.9-0ubuntu2/tests-mx32/openat2-v-y-Xverbose.gen.test
--- 5.5-3/tests-mx32/openat2-v-y-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/openat2-v-y-Xverbose.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-v-y-Xverbose --trace=openat2 -a44 -v -y -Xverbose </dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a44 -v -y -Xverbose </dev/full
diff -pruN 5.5-3/tests-mx32/openat2-Xabbrev.c 5.9-0ubuntu2/tests-mx32/openat2-Xabbrev.c
--- 5.5-3/tests-mx32/openat2-Xabbrev.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/openat2-Xabbrev.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_ABBREV 1
+#include "openat2.c"
diff -pruN 5.5-3/tests-mx32/openat2-Xabbrev.gen.test 5.9-0ubuntu2/tests-mx32/openat2-Xabbrev.gen.test
--- 5.5-3/tests-mx32/openat2-Xabbrev.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/openat2-Xabbrev.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-Xabbrev --trace=openat2 -a35 -Xabbrev); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a35 -Xabbrev
diff -pruN 5.5-3/tests-mx32/openat2-Xraw.c 5.9-0ubuntu2/tests-mx32/openat2-Xraw.c
--- 5.5-3/tests-mx32/openat2-Xraw.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/openat2-Xraw.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_RAW 1
+#include "openat2.c"
diff -pruN 5.5-3/tests-mx32/openat2-Xraw.gen.test 5.9-0ubuntu2/tests-mx32/openat2-Xraw.gen.test
--- 5.5-3/tests-mx32/openat2-Xraw.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/openat2-Xraw.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-Xraw --trace=openat2 -a32 -Xraw); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a32 -Xraw
diff -pruN 5.5-3/tests-mx32/openat2-Xverbose.c 5.9-0ubuntu2/tests-mx32/openat2-Xverbose.c
--- 5.5-3/tests-mx32/openat2-Xverbose.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/openat2-Xverbose.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define XLAT_VERBOSE 1
+#include "openat2.c"
diff -pruN 5.5-3/tests-mx32/openat2-Xverbose.gen.test 5.9-0ubuntu2/tests-mx32/openat2-Xverbose.gen.test
--- 5.5-3/tests-mx32/openat2-Xverbose.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/openat2-Xverbose.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-Xverbose --trace=openat2 -a35 -Xverbose); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a35 -Xverbose
diff -pruN 5.5-3/tests-mx32/openat2-y.c 5.9-0ubuntu2/tests-mx32/openat2-y.c
--- 5.5-3/tests-mx32/openat2-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/openat2-y.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,2 @@
+#define FD0_PATH "</dev/full>"
+#include "openat2.c"
diff -pruN 5.5-3/tests-mx32/openat2-y.gen.test 5.9-0ubuntu2/tests-mx32/openat2-y.gen.test
--- 5.5-3/tests-mx32/openat2-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/openat2-y.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (openat2-y --trace=openat2 -a36 -y </dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=openat2 -a36 -y </dev/full
diff -pruN 5.5-3/tests-mx32/open_tree-P.gen.test 5.9-0ubuntu2/tests-mx32/open_tree-P.gen.test
--- 5.5-3/tests-mx32/open_tree-P.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/open_tree-P.gen.test	2020-09-24 09:18:49.000000000 +0000
@@ -1,4 +1,4 @@
 #!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (open_tree-P -a30 -y -P /dev/full -e trace=open_tree); do not edit.
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (open_tree-P -a30 --decode-fds -P /dev/full -e trace=open_tree); do not edit.
 . "${srcdir=.}/init.sh"
-run_strace_match_diff -a30 -y -P /dev/full -e trace=open_tree
+run_strace_match_diff -a30 --decode-fds -P /dev/full -e trace=open_tree
diff -pruN 5.5-3/tests-mx32/options-syntax.test 5.9-0ubuntu2/tests-mx32/options-syntax.test
--- 5.5-3/tests-mx32/options-syntax.test	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/options-syntax.test	2020-08-21 16:39:24.000000000 +0000
@@ -30,55 +30,189 @@ check_e_using_grep "$ff_name: File *name
 check_e_using_grep "$ff_name: File *name too long" -ff --output="$ff_name" true
 
 check_h 'must have PROG [ARGS] or -p PID'
-check_h 'PROG [ARGS] must be specified with -D' -D -p $$
-check_h 'PROG [ARGS] must be specified with -D' -DD -p $$
-check_h 'PROG [ARGS] must be specified with -D' -DDD -p $$
-check_h 'PROG [ARGS] must be specified with -D' -DDDD -p $$
+check_h "must have PROG [ARGS] or -p PID" --absolute-timestamps
+check_h "must have PROG [ARGS] or -p PID" --absolute-timestamps=
+check_h "must have PROG [ARGS] or -p PID" --absolute-timestamps=,
+check_h "must have PROG [ARGS] or -p PID" --absolute-timestamps=,s
+check_h "must have PROG [ARGS] or -p PID" --absolute-timestamps=s,
+check_h "must have PROG [ARGS] or -p PID" --absolute-timestamps=,,
+check_h "must have PROG [ARGS] or -p PID" --absolute-timestamps=s,,none
+check_h "must have PROG [ARGS] or -p PID" --timestamps --absolute-timestamps=ns --timestamps=none --absolute-timestamps=format:time,precision:s --timestamps=ns,format:unix --absolute-timestamps=us,precision:ms,unix,precision:ns --timestamps=format:none,time,precision:us
+check_h "invalid --absolute-timestamps argument: 'ss'" --absolute-timestamps=ss
+check_h "invalid --timestamps argument: 'format:s'" --timestamps=format:s
+check_h "invalid --timestamps argument: 's,non'" --timestamps=s,non
+check_h "invalid --timestamps argument: 'precision:none'" --timestamps=precision:none
+check_e '-t and --absolute-timestamps cannot be provided simultaneously' -t --timestamps -p $$
+check_e '-t and --absolute-timestamps cannot be provided simultaneously' --absolute-timestamps -ttt -p $$
+check_e '-t and --absolute-timestamps cannot be provided simultaneously' -t --timestamps=ns -t -p $$
+check_e '-t and --absolute-timestamps cannot be provided simultaneously' --timestamps=ns -t --absolute-timestamps=unix -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' -D -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' -DD -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' -DDD -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' -DDDD -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' --daemonize -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' --daemonize=grandchild -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' --daemonize=pgroup -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' --daemonize=Pgrp -p $$
+check_h 'PROG [ARGS] must be specified with -D/--daemonize' --daemonize=SESSION -p $$
 check_h 'Too many -D'\''s (4), maximum supported -D count is 3' -DDDD /bin/true
-check_h '-c and -C are mutually exclusive' -c -C true
-check_h '-c and -C are mutually exclusive' --summary-only --summary true
-check_h '-c and -C are mutually exclusive' -C -c true
-check_h '-c and -C are mutually exclusive' --summary --summary-only true
-check_h '(-c or -C) and -ff are mutually exclusive' -c -ff true
-check_h '(-c or -C) and -ff are mutually exclusive' --summary-only -ff true
-check_h '(-c or -C) and -ff are mutually exclusive' -C -ff true
-check_h '(-c or -C) and -ff are mutually exclusive' --summary -ff true
-check_h '-w must be given with (-c or -C)' -w true
-check_h '-w must be given with (-c or -C)' --summary-wall-clock true
-check_h 'piping the output and -ff are mutually exclusive' -o '|' -ff true
-check_h 'piping the output and -ff are mutually exclusive' --output='|' -ff true
-check_h 'piping the output and -ff are mutually exclusive' -o '!' -ff true
-check_h 'piping the output and -ff are mutually exclusive' --output='!' -ff true
+check_e '-D and --daemonize cannot be provided simultaneously' -D --daemonize -p $$
+check_e '-D and --daemonize cannot be provided simultaneously' --daemonize -D -p $$
+check_e '-D and --daemonize cannot be provided simultaneously' --daemonize -v -D /bit/true
+check_h "invalid --daemonize argument: 'pgr'" --daemonize=pgr
+check_h '-c/--summary-only and -C/--summary are mutually exclusive' -c -C true
+check_h '-c/--summary-only and -C/--summary are mutually exclusive' --summary-only --summary true
+check_h '-c/--summary-only and -C/--summary are mutually exclusive' -C -c true
+check_h '-c/--summary-only and -C/--summary are mutually exclusive' --summary --summary-only true
+check_h '(-c/--summary-only or -C/--summary) and -ff/--output-separately are mutually exclusive' -c -ff true
+check_h '(-c/--summary-only or -C/--summary) and -ff/--output-separately are mutually exclusive' --summary-only -ff true
+check_h '(-c/--summary-only or -C/--summary) and -ff/--output-separately are mutually exclusive' -C -ff true
+check_h '(-c/--summary-only or -C/--summary) and -ff/--output-separately are mutually exclusive' --summary -ff true
+check_h '-w/--summary-wall-clock must be given with (-c/--summary-only or -C/--summary)' -w true
+check_h '-w/--summary-wall-clock must be given with (-c/--summary-only or -C/--summary)' --summary-wall-clock true
+check_h '-U/--summary-columns must be given with (-c/--summary-only or -C/--summary)' -U name,time,count,errors true
+check_h '-U/--summary-columns must be given with (-c/--summary-only or -C/--summary)' --summary-columns=name,time,count,errors true
+check_h 'piping the output and -ff/--output-separately are mutually exclusive' -o '|' -ff true
+check_h 'piping the output and -ff/--output-separately are mutually exclusive' --output='|' -ff true
+check_h 'piping the output and -ff/--output-separately are mutually exclusive' -o '!' -ff true
+check_h 'piping the output and -ff/--output-separately are mutually exclusive' --output='!' -ff true
 check_h "invalid -a argument: '-42'" -a -42
 check_h "invalid -O argument: '-42'" -O -42
 check_h "invalid -s argument: '-42'" -s -42
-check_h "invalid -s argument: '-42'" --string-limit=-42
+check_h "invalid --string-limit argument: '-42'" --string-limit=-42
 check_h "invalid -s argument: '1073741824'" -s 1073741824
-check_h "invalid -s argument: '1073741824'" --string-limit=1073741824
+check_h "invalid --string-limit argument: '1073741824'" --string-limit=1073741824
+check_h "must have PROG [ARGS] or -p PID" --follow-forks
+check_h "must have PROG [ARGS] or -p PID" --follow-forks --output-separately
+check_h "must have PROG [ARGS] or -p PID" -f --output-separately
+check_h "must have PROG [ARGS] or -p PID" --output-separately
+check_e '-f and --follow-forks cannot be provided simultaneously' -f --follow-forks -p $$
+check_e '-ff and --output-separately cannot be provided simultaneously' --output-separately -ff -p $$
+check_h "invalid -I argument: '0x1'" -I 0x1
+check_h "invalid -I argument: '0'" -I 0
+check_h "must have PROG [ARGS] or -p PID" -I1
+check_h "must have PROG [ARGS] or -p PID" -I 2
+check_h "must have PROG [ARGS] or -p PID" -I3
+check_h "must have PROG [ARGS] or -p PID" -I 4
 check_h "invalid -I argument: '5'" -I 5
+check_h "must have PROG [ARGS] or -p PID" -I always
+check_h "must have PROG [ARGS] or -p PID" -I anywhere
+check_h "must have PROG [ARGS] or -p PID" -Iwaiting
+check_h "must have PROG [ARGS] or -p PID" -I never
+check_h "must have PROG [ARGS] or -p PID" -Inever_tstp
+check_h "invalid -I argument: '=never'" -I=never
+check_h "invalid -I argument: 'nevertheless'" -Inevertheless
+check_h "invalid -I argument: 'nev'" -Inev
+check_h "invalid --interruptible argument: '0x1'" --interruptible=0x1
+check_h "invalid --interruptible argument: '0'" --interruptible=0
+check_h "must have PROG [ARGS] or -p PID" --interruptible 1
+check_h "must have PROG [ARGS] or -p PID" --interruptible=2
+check_h "invalid --interruptible argument: '5'" --interruptible=5
+check_h "must have PROG [ARGS] or -p PID" --interruptible=anywhere
+check_h "must have PROG [ARGS] or -p PID" --interruptible=waiting
+check_h "must have PROG [ARGS] or -p PID" --interruptible=never
+check_h "must have PROG [ARGS] or -p PID" --interruptible=never_tstp
+check_h "invalid --interruptible argument: 'nevertheless'" --interruptible=nevertheless
+check_h "invalid --interruptible argument: 'nev'" --interruptible=nev
+check_h "must have PROG [ARGS] or -p PID" --relative-timestamps
+check_h "must have PROG [ARGS] or -p PID" --relative-timestamps=s
+check_h "must have PROG [ARGS] or -p PID" --relative-timestamps=ms
+check_h "must have PROG [ARGS] or -p PID" --relative-timestamps=us
+check_h "must have PROG [ARGS] or -p PID" --relative-timestamps=ns
+check_h "invalid --relative-timestamps argument: 'n'" --relative-timestamps=n
+check_h "invalid --relative-timestamps argument: 'ss'" --relative-timestamps=ss
+check_h "must have PROG [ARGS] or -p PID" --syscall-times
+check_h "must have PROG [ARGS] or -p PID" --syscall-times=s
+check_h "must have PROG [ARGS] or -p PID" --syscall-times=ms
+check_h "must have PROG [ARGS] or -p PID" --syscall-times=us
+check_h "must have PROG [ARGS] or -p PID" --syscall-times=ns
+check_h "invalid --syscall-times argument: 'n'" --syscall-times=n
+check_h "invalid --syscall-times argument: 'ss'" --syscall-times=ss
+check_h "must have PROG [ARGS] or -p PID" --strings-in-hex
+check_h "must have PROG [ARGS] or -p PID" --strings-in-hex=all
+check_h "must have PROG [ARGS] or -p PID" --strings-in-hex=non-ascii
+check_h "invalid --strings-in-hex argument: 'al'" --strings-in-hex=al
+check_h "invalid --strings-in-hex argument: 'alll'" --strings-in-hex=alll
+check_h "invalid --strings-in-hex argument: 'ascii'" --strings-in-hex=ascii
+check_h "must have PROG [ARGS] or -p PID" --quiet=all
+check_h "must have PROG [ARGS] or -p PID" --quiet=none
+check_h "must have PROG [ARGS] or -p PID" --quiet=\!attach
+check_h "must have PROG [ARGS] or -p PID" --quiet=exit,exits,personality
+check_e "invalid quiet 'detach'" --quiet=detach -p $$
+check_e "invalid quiet 'fds'" -q --quiet=fds -p $$
+check_e "invalid quiet 'detach'" --quiet=detach -p $$
+check_e '-q and -e quiet/--quiet cannot be provided simultaneously' -q --quiet -p $$
+check_e '-q and -e quiet/--quiet cannot be provided simultaneously' -q -e q=none -p $$
+check_e '-q and -e quiet/--quiet cannot be provided simultaneously' -q -e silent=attach,personality -p $$
+
+check_h 'must have PROG [ARGS] or -p PID' -P .
+check_h 'must have PROG [ARGS] or -p PID' -P . -P..
+check_h 'must have PROG [ARGS] or -p PID' --trace-path=.
+check_h 'must have PROG [ARGS] or -p PID' --trace-path=. --trace-path ..
+check_e "Requested path \"///\" resolved into \"/\"
+$STRACE_EXE: Requested path \"/.\" resolved into \"/\"
+$STRACE_EXE: -q and -e quiet/--quiet cannot be provided simultaneously" -q --quiet -P /// -P/. .
+
+for i in time time_percent time-percent time_total time-total total_time total-time min_time min-time time_min time-min shortest max_time max-time time_max time-max longest avg_time avg-time time_avg time-avg calls count error errors name syscall syscall_name syscall-name none nothing; do
+	check_h "must have PROG [ARGS] or -p PID" -S "$i"
+	check_h "must have PROG [ARGS] or -p PID" --summary-sort-by="$i"
+	if [ "x$i" != xnone -a "x$i" != xnothing ]; then
+		check_h "must have PROG [ARGS] or -p PID" -c -U "$i"
+		check_h "must have PROG [ARGS] or -p PID" --summary-only --summary-columns="$i"
+	fi
+done
+for i in time,time_total,avg_time,calls,errors,name time_percent,total_time,time_avg,count,error,syscall_name; do
+	check_h "must have PROG [ARGS] or -p PID" -c -U "$i"
+	check_h "must have PROG [ARGS] or -p PID" --summary-only --summary-columns="$i"
+done
+for i in non syscall_names; do
+	check_h "invalid sortby: '$i'" -S "$i"
+	check_h "invalid sortby: '$i'" --summary-sort-by="$i"
+	check_h "unknown column name: '$i'" -U "$i"
+	check_h "unknown column name: '$i'" --summary-columns="$i"
+done
+check_h "unknown column name: ''" -U time,,name
+check_h "call summary column has been provided more than once: 'time_percent' (-U option residual: 'time_percent,time_total')" -U time,time_percent,time_total
+
+check_e '-x and --strings-in-hex cannot be provided simultaneously' -x --strings-in-hex -p $$
+check_e '-x and --strings-in-hex cannot be provided simultaneously' --strings-in-hex -p $$ -xx
 check_h "invalid -X argument: 'test'" -Xtest
-check_h "invalid -X argument: 'test'" --const-print-style=test
+check_h "invalid --const-print-style argument: 'test'" --const-print-style=test
 check_h "invalid -X argument: 'a'" -Xa
-check_h "invalid -X argument: 'a'" --const-print-style=a
+check_h "invalid --const-print-style argument: 'a'" --const-print-style=a
 check_h "invalid -X argument: 'abbreviated'" -X abbreviated
-check_h "invalid -X argument: 'abbreviated'" --const-print-style=abbreviated
+check_h "invalid --const-print-style argument: 'abbreviated'" --const-print-style=abbreviated
+check_h "must have PROG [ARGS] or -p PID" --decode-fds
+check_h "must have PROG [ARGS] or -p PID" --decode-fds=all
+check_h "must have PROG [ARGS] or -p PID" --decode-fds=none
+check_h "must have PROG [ARGS] or -p PID" --decode-fds=path
+check_h "must have PROG [ARGS] or -p PID" --decode-fds=socket,dev
+check_h "must have PROG [ARGS] or -p PID" --decode-fds=\!path
+check_h "must have PROG [ARGS] or -p PID" --decode-fds=socket,path,dev
+check_e "invalid decode-fds 'p'" --decode-fds=p -p $$
+check_e "invalid decode-fds 'device'" -y --decode-fds=device -p $$
+check_e "invalid decode-fds 'name'" --decode-fds=path,name -p $$
+check_e "invalid decode-fds 'sock'" -e decode-fd=sock -y -p $$
+check_e '-y and --decode-fds cannot be provided simultaneously' -y --decode-fds -p $$
+check_e '-y and --decode-fds cannot be provided simultaneously' -e decode-fd=all -yy -p $$
+check_e '-y and --decode-fds cannot be provided simultaneously' --decode-fds=none -y -p $$
 
 check_h "incorrect personality designator '' in qualification 'getcwd@'" -e trace=getcwd@
 check_h "incorrect personality designator '42' in qualification 'getcwd@42'" -e trace=getcwd@42
 check_h "incorrect personality designator '42' in qualification 'getcwd@42'" -e trace=gettid,getcwd@42
 check_h "incorrect personality designator '42' in qualification '23@42'" -e trace=23@42,123
 
-check_h '--seccomp-bpf implies -f
--w must be given with (-c or -C)' --seccomp-bpf -w /
+check_h '--seccomp-bpf cannot be used without -f/--follow-forks, disabling
+-w/--summary-wall-clock must be given with (-c/--summary-only or -C/--summary)' --seccomp-bpf -w /
 check_h '--seccomp-bpf is not enabled for processes attached with -p
--w must be given with (-c or -C)' --seccomp-bpf -f -p 1 -w
+-w/--summary-wall-clock must be given with (-c/--summary-only or -C/--summary)' --seccomp-bpf -f -p 1 -w
 
-check_h 'option -F is deprecated, please use -f instead
--w must be given with (-c or -C)' -F -w /
-check_h 'option -F is deprecated, please use -f instead
--w must be given with (-c or -C)' -FF -w /
+check_h 'option -F is deprecated, please use -f/--follow-forks instead
+-w/--summary-wall-clock must be given with (-c/--summary-only or -C/--summary)' -F -w /
+check_h 'option -F is deprecated, please use -f/--follow-forks instead
+-w/--summary-wall-clock must be given with (-c/--summary-only or -C/--summary)' -FF -w /
 check_h 'deprecated option -F ignored
--w must be given with (-c or -C)' -fF -w /
+-w/--summary-wall-clock must be given with (-c/--summary-only or -C/--summary)' -fF -w /
 
 check_e "invalid system call '/getcwd@ohmy'" -e trace=/getcwd@ohmy
 check_e "invalid -e kvm= argument: 'chdir'" -e kvm=chdir
@@ -129,25 +263,51 @@ if [ "$uid" -ge 0 ]; then
 	if [ "$uid" -eq 0 ]; then
 		umsg="Cannot find user ':nosuchuser:'"
 	else
-		umsg='You must be root to use the -u option'
+		umsg='You must be root to use the -u/--username option'
 	fi
 
 	check_e "$umsg" -u :nosuchuser: true
 
-	for c in i r t T y; do
-		check_e "-$c has no effect with -c
-$STRACE_EXE: $umsg" -u :nosuchuser: -c -$c true
+	for c in i/--instruction-pointer n/--syscall-number r/--relative-timestamps t/--absolute-timestamps T/--syscall-times y/--decode-fds; do
+		check_e "-$c has no effect with -c/--summary-only
+$STRACE_EXE: $umsg" -u :nosuchuser: -c -${c%%/*} true
+	done
+
+	check_e "-i/--instruction-pointer has no effect with -c/--summary-only
+$STRACE_EXE: -n/--syscall-number has no effect with -c/--summary-only
+$STRACE_EXE: -r/--relative-timestamps has no effect with -c/--summary-only
+$STRACE_EXE: -t/--absolute-timestamps has no effect with -c/--summary-only
+$STRACE_EXE: -T/--syscall-times has no effect with -c/--summary-only
+$STRACE_EXE: -y/--decode-fds has no effect with -c/--summary-only
+$STRACE_EXE: Only the last of -z/--successful-only/-Z/--failed-only options will take effect. See status qualifier for more complex filters.
+$STRACE_EXE: $umsg" -u :nosuchuser: -cinrtTyzZ true
+
+	for c in --output-separately -A/--output-append-mode; do
+		check_e "$c has no effect without -o/--output
+$STRACE_EXE: $umsg" -u :nosuchuser: ${c%%/*} true
 	done
 
-	check_e "-i has no effect with -c
-$STRACE_EXE: -r has no effect with -c
-$STRACE_EXE: -t has no effect with -c
-$STRACE_EXE: -T has no effect with -c
-$STRACE_EXE: -y has no effect with -c
-$STRACE_EXE: Only the last of -z/-Z options will take effect. See status qualifier for more complex filters.
-$STRACE_EXE: $umsg" -u :nosuchuser: -cirtTyzZ true
+	check_e "-S/--summary-sort-by has no effect without (-c/--summary-only or -C/--summary)
+$STRACE_EXE: $umsg" -u :nosuchuser: --summary-sort-by errors true
+
+	check_e "--output-separately has no effect without -o/--output
+$STRACE_EXE: -A/--output-append-mode has no effect without -o/--output
+$STRACE_EXE: $umsg" -u :nosuchuser: --output-separately --output-append-mode true
+
+	check_e "$umsg" -u :nosuchuser: -ff true
+	check_e "$umsg" -u :nosuchuser: --output-separately --follow-forks true
+
+	check_e "Only the last of -z/--successful-only/-Z/--failed-only options will take effect. See status qualifier for more complex filters.
+$STRACE_EXE: $umsg" -u :nosuchuser: -z --successful-only true
+	check_e "Only the last of -z/--successful-only/-Z/--failed-only options will take effect. See status qualifier for more complex filters.
+$STRACE_EXE: $umsg" -u :nosuchuser: --successful-only -Z true
+	check_e "Only the last of -z/--successful-only/-Z/--failed-only options will take effect. See status qualifier for more complex filters.
+$STRACE_EXE: $umsg" -u :nosuchuser: --successful-only --failed-only true
+
+	check_e "-n/--syscall-number has no effect with -c/--summary-only
+$STRACE_EXE: $umsg" --user=:nosuchuser: --syscall-number --summary-only true
 
-	check_e "-i has no effect with -c
+	check_e "-i/--instruction-pointer has no effect with -c/--summary-only
 $STRACE_EXE: $umsg" --user=:nosuchuser: --instruction-pointer --summary-only true
 fi
 
diff -pruN 5.5-3/tests-mx32/orphaned_process_group.c 5.9-0ubuntu2/tests-mx32/orphaned_process_group.c
--- 5.5-3/tests-mx32/orphaned_process_group.c	2019-03-06 16:02:38.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/orphaned_process_group.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check tracing of orphaned process group.
  *
- * Copyright (c) 2019 The strace developers.
+ * Copyright (c) 2019-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -139,7 +139,7 @@ main(void)
 	 */
 	leader = getpid();
 	printf("%-5d --- %s {si_signo=%s, si_code=SI_TKILL"
-	       ", si_pid=%d, si_uid=%u} ---\n",
+	       ", si_pid=%d, si_uid=%d} ---\n",
 	       stopped, "SIGSTOP", "SIGSTOP", stopped, geteuid());
 	printf("%-5d --- stopped by SIGSTOP ---\n", stopped);
 	printf("%-5d +++ exited with 0 +++\n", leader);
diff -pruN 5.5-3/tests-mx32/pc.c 5.9-0ubuntu2/tests-mx32/pc.c
--- 5.5-3/tests-mx32/pc.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pc.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2015-2020 Dmitry V. Levin <ldv@altlinux.org>
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -27,7 +27,7 @@ int main(void)
 #endif
 
 	/* write instruction pointer length to the log */
-	assert(write(-1, NULL, 2 * sizeof(void *)) < 0);
+	assert(write(-1, (void *) 8UL, 2 * sizeof(void *)) < 0);
 
 	/* just a noticeable line in the log */
 	assert(munmap(&main, 0) < 0);
diff -pruN 5.5-3/tests-mx32/pc.test 5.9-0ubuntu2/tests-mx32/pc.test
--- 5.5-3/tests-mx32/pc.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pc.test	2020-06-01 14:15:16.000000000 +0000
@@ -3,7 +3,7 @@
 # Check -i option.
 #
 # Copyright (c) 2015 Dmitry V. Levin <ldv@altlinux.org>
-# Copyright (c) 2015-2018 The strace developers.
+# Copyright (c) 2015-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -14,11 +14,11 @@ check_prog sed
 
 run_prog > /dev/null
 
-args="-if $args"
+args="--quiet=attach,personality -if $args"
 $STRACE $args 2> "$LOG" ||
 	dump_log_and_fail_with "$STRACE $args failed"
 
-len="$(sed -r -n 's/^\[[[:xdigit:]]+\] write\(-1, NULL, ([[:digit:]]{1,2})\)[[:space:]]+= -1 .*/\1/p' "$LOG")" &&
+len="$(sed -r -n 's/^\[[[:xdigit:]]+\] write\(-1, 0x8, ([[:digit:]]{1,2})\)[[:space:]]+= -1 .*/\1/p' "$LOG")" &&
 [ -n "$len" ] &&
 pid="$(sed -r -n 's/^\[[[:xdigit:]]{'"$len"'}\] --- SIGCHLD \{si_signo=SIGCHLD, si_code=CLD_(KILLED|DUMPED), si_pid=([[:digit:]]+), .*/\2/p' "$LOG")" &&
 [ -n "$pid" ] &&
diff -pruN 5.5-3/tests-mx32/perf_event_open.c 5.9-0ubuntu2/tests-mx32/perf_event_open.c
--- 5.5-3/tests-mx32/perf_event_open.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/perf_event_open.c	2020-06-02 08:00:00.000000000 +0000
@@ -511,7 +511,7 @@ end:
 }
 
 /* These require aligned access, so no byte-grain checks possible */
-# if defined SPARC || defined SPARC64 || defined POWERPC || defined POWERPC64
+# if defined SPARC || defined SPARC64 || defined POWERPC || defined POWERPC64 || defined ARM
 #  define ATTR_REC(sz) { tail_alloc((sz + 7) & ~7), sz }
 # else
 #  define ATTR_REC(sz) { tail_alloc(sz), sz }
@@ -534,7 +534,8 @@ end:
 	"PERF_SAMPLE_BRANCH_CALL|" \
 	"PERF_SAMPLE_BRANCH_NO_FLAGS|" \
 	"PERF_SAMPLE_BRANCH_NO_CYCLES|" \
-	"PERF_SAMPLE_BRANCH_TYPE_SAVE"
+	"PERF_SAMPLE_BRANCH_TYPE_SAVE|" \
+	"PERF_SAMPLE_BRANCH_HW_INDEX"
 
 int
 main(void)
@@ -667,11 +668,11 @@ main(void)
 	static const struct u64_val_str branch_sample_types[] = {
 		{ ARG_STR(0) },
 		{ 0x80, "PERF_SAMPLE_BRANCH_ABORT_TX" },
-		{ 0x1ffff, BRANCH_TYPE_ALL },
+		{ 0x3ffff, BRANCH_TYPE_ALL },
 		{ ARG_ULL_STR(0xdeadcaffeeec0000)
 			" /* PERF_SAMPLE_BRANCH_??? */" },
 		{ 0xffffffffffffffffULL,
-			BRANCH_TYPE_ALL "|0xfffffffffffe0000" }
+			BRANCH_TYPE_ALL "|0xfffffffffffc0000" }
 	};
 	static const struct s32_val_str clockids[] = {
 		{ 11, "CLOCK_TAI" },
diff -pruN 5.5-3/tests-mx32/pidfd_getfd.c 5.9-0ubuntu2/tests-mx32/pidfd_getfd.c
--- 5.5-3/tests-mx32/pidfd_getfd.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pidfd_getfd.c	2020-09-23 16:29:35.000000000 +0000
@@ -0,0 +1,103 @@
+/*
+ * Check decoding of pidfd_getfd syscall.
+ *
+ * Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+
+#ifdef __NR_pidfd_getfd
+
+# include <assert.h>
+# include <signal.h>
+# include <stdio.h>
+# include <stdlib.h>
+# include <unistd.h>
+# include <sys/wait.h>
+
+# ifndef PIDFD_PATH
+#  define PIDFD_PATH ""
+# endif
+# ifndef FD0_PATH
+#  define FD0_PATH ""
+# endif
+# ifndef PRINT_PIDFD
+#  define PRINT_PIDFD 0
+# endif
+
+static const char *errstr;
+
+static long
+k_pidfd_getfd(const unsigned int pidfd, const unsigned int fd,
+	      const unsigned int flags)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+	const kernel_ulong_t arg1 = fill | pidfd;
+	const kernel_ulong_t arg2 = fill | fd;
+	const kernel_ulong_t arg3 = fill | flags;
+	const long rc = syscall(__NR_pidfd_getfd,
+				arg1, arg2, arg3, bad, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
+
+int
+main(void)
+{
+	long rc;
+
+	rc = k_pidfd_getfd(-1U, -1U, 0);
+	printf("pidfd_getfd(-1, -1, 0) = %s\n", errstr);
+
+	rc = k_pidfd_getfd(0, 0, 0xbadc0ded);
+	printf("pidfd_getfd(0" FD0_PATH ", 0, 0xbadc0ded) = %s\n", errstr);
+
+	int child_wait_fds[2];
+	if (pipe(child_wait_fds))
+		perror_msg_and_fail("pipe");
+
+	int dupfd = dup(0);
+	int pid = fork();
+	if (pid == 0) {
+		close(0);
+		close(child_wait_fds[1]);
+		if (read(child_wait_fds[0], &child_wait_fds[1], sizeof(int)))
+			_exit(2);
+		_exit(0);
+	}
+	close(dupfd);
+
+	int pidfd = syscall(__NR_pidfd_open, pid, 0);
+# if PRINT_PIDFD
+	char pidfd_str[sizeof("<pid:>") + 3 * sizeof(int)];
+	snprintf(pidfd_str, sizeof(pidfd_str), "<pid:%d>", pid);
+# else
+	const char *pidfd_str = PIDFD_PATH;
+# endif
+	rc = k_pidfd_getfd(pidfd, dupfd, 0);
+	printf("pidfd_getfd(%d%s, %d%s, 0) = %s%s\n",
+	       pidfd, pidfd >= 0 ? pidfd_str : "",
+	       dupfd, pidfd >= 0 ? FD0_PATH : "",
+	       errstr, rc >= 0 ? FD0_PATH : "");
+
+	puts("+++ exited with 0 +++");
+
+	close(child_wait_fds[1]);
+	int status;
+	assert(wait(&status) == pid);
+	assert(status == 0);
+
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_pidfd_getfd");
+
+#endif
diff -pruN 5.5-3/tests-mx32/pidfd_getfd.gen.test 5.9-0ubuntu2/tests-mx32/pidfd_getfd.gen.test
--- 5.5-3/tests-mx32/pidfd_getfd.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pidfd_getfd.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_getfd -a18 -Xverbose -e signal=none </dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a18 -Xverbose -e signal=none </dev/full
diff -pruN 5.5-3/tests-mx32/pidfd_getfd-y.c 5.9-0ubuntu2/tests-mx32/pidfd_getfd-y.c
--- 5.5-3/tests-mx32/pidfd_getfd-y.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pidfd_getfd-y.c	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,3 @@
+#define PIDFD_PATH "<anon_inode:[pidfd]>"
+#define FD0_PATH "</dev/full>"
+#include "pidfd_getfd.c"
diff -pruN 5.5-3/tests-mx32/pidfd_getfd-y.gen.test 5.9-0ubuntu2/tests-mx32/pidfd_getfd-y.gen.test
--- 5.5-3/tests-mx32/pidfd_getfd-y.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pidfd_getfd-y.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_getfd-y --trace=pidfd_getfd -a18 -e signal=none -y </dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=pidfd_getfd -a18 -e signal=none -y </dev/full
diff -pruN 5.5-3/tests-mx32/pidfd_getfd-yy.c 5.9-0ubuntu2/tests-mx32/pidfd_getfd-yy.c
--- 5.5-3/tests-mx32/pidfd_getfd-yy.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pidfd_getfd-yy.c	2020-04-05 13:28:30.000000000 +0000
@@ -0,0 +1,3 @@
+#define PRINT_PIDFD 1
+#define FD0_PATH "</dev/full<char 1:7>>"
+#include "pidfd_getfd.c"
diff -pruN 5.5-3/tests-mx32/pidfd_getfd-yy.gen.test 5.9-0ubuntu2/tests-mx32/pidfd_getfd-yy.gen.test
--- 5.5-3/tests-mx32/pidfd_getfd-yy.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pidfd_getfd-yy.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_getfd-yy --trace=pidfd_getfd -a18 -e signal=none -yy </dev/full); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=pidfd_getfd -a18 -e signal=none -yy </dev/full
diff -pruN 5.5-3/tests-mx32/pidfd_open.c 5.9-0ubuntu2/tests-mx32/pidfd_open.c
--- 5.5-3/tests-mx32/pidfd_open.c	2019-08-15 11:54:22.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pidfd_open.c	2020-08-25 14:29:30.000000000 +0000
@@ -2,6 +2,7 @@
  * Check decoding of pidfd_open syscall.
  *
  * Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2019-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -9,6 +10,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #ifdef __NR_pidfd_open
 
@@ -36,6 +38,8 @@ k_pidfd_open(const unsigned int pid, con
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 # if defined PATH_TRACING || defined PRINT_PATHS
 	skip_if_unavailable("/proc/self/fd/");
 # endif
@@ -49,16 +53,19 @@ main(void)
 
 	k_pidfd_open(0, 0);
 # ifndef PATH_TRACING
+	pidns_print_leader();
 	printf("pidfd_open(0, 0) = %s\n", errstr);
 # endif
 
 	k_pidfd_open(-1U, 0);
 # ifndef PATH_TRACING
+	pidns_print_leader();
 	printf("pidfd_open(-1, 0) = %s\n", errstr);
 # endif
 
 	k_pidfd_open(0, -1U);
 # ifndef PATH_TRACING
+	pidns_print_leader();
 	printf("pidfd_open(0, %#x) = %s\n", -1U, errstr);
 # endif
 
@@ -67,7 +74,10 @@ main(void)
 
 	k_pidfd_open(pid, flags);
 # ifndef PATH_TRACING
-	printf("pidfd_open(%d, %#x) = %s\n", pid, flags, errstr);
+	const char *pid_str = pidns_pid2str(PT_TGID);
+	pidns_print_leader();
+	printf("pidfd_open(%d%s, %#x) = %s\n",
+		pid, pid_str, flags, errstr);
 # endif
 
 # ifdef PRINT_PATHS
@@ -79,15 +89,19 @@ main(void)
 # endif
 
 # ifndef PATH_TRACING
-	printf("pidfd_open(%d, 0) = "
-#  ifdef PRINT_PATHS
-	       "%ld<anon_inode:[pidfd]>\n", pid, rc
+	pidns_print_leader();
+	printf("pidfd_open(%d%s, 0) = "
+#  if defined PRINT_PIDFD
+	       "%ld<pid:%d>\n", pid, pid_str, rc, pid
+#  elif defined PRINT_PATHS
+	       "%ld<anon_inode:[pidfd]>\n", pid, pid_str, rc
 #  else
-	       "%s\n", pid, errstr
+	       "%s\n", pid, pid_str, errstr
 #  endif
 	       );
 # endif
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/pidfd_open--decode-fd-path.c 5.9-0ubuntu2/tests-mx32/pidfd_open--decode-fd-path.c
--- 5.5-3/tests-mx32/pidfd_open--decode-fd-path.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pidfd_open--decode-fd-path.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1 @@
+#include "pidfd_open-y.c"
diff -pruN 5.5-3/tests-mx32/pidfd_open--decode-fd-path.gen.test 5.9-0ubuntu2/tests-mx32/pidfd_open--decode-fd-path.gen.test
--- 5.5-3/tests-mx32/pidfd_open--decode-fd-path.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pidfd_open--decode-fd-path.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_open--decode-fd-path -a17 -e decode-fd=path -e trace=pidfd_open); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a17 -e decode-fd=path -e trace=pidfd_open
diff -pruN 5.5-3/tests-mx32/pidfd_open--decode-fd-pidfd.c 5.9-0ubuntu2/tests-mx32/pidfd_open--decode-fd-pidfd.c
--- 5.5-3/tests-mx32/pidfd_open--decode-fd-pidfd.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pidfd_open--decode-fd-pidfd.c	2020-04-05 13:28:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_PIDFD 1
+#include "pidfd_open-y.c"
diff -pruN 5.5-3/tests-mx32/pidfd_open--decode-fd-pidfd.gen.test 5.9-0ubuntu2/tests-mx32/pidfd_open--decode-fd-pidfd.gen.test
--- 5.5-3/tests-mx32/pidfd_open--decode-fd-pidfd.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pidfd_open--decode-fd-pidfd.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_open--decode-fd-pidfd -a17 -e decode-fd=pidfd -e trace=pidfd_open); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a17 -e decode-fd=pidfd -e trace=pidfd_open
diff -pruN 5.5-3/tests-mx32/pidfd_open--decode-fd-socket.c 5.9-0ubuntu2/tests-mx32/pidfd_open--decode-fd-socket.c
--- 5.5-3/tests-mx32/pidfd_open--decode-fd-socket.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pidfd_open--decode-fd-socket.c	2020-04-05 13:28:30.000000000 +0000
@@ -0,0 +1 @@
+#include "pidfd_open-y.c"
diff -pruN 5.5-3/tests-mx32/pidfd_open--decode-fd-socket.gen.test 5.9-0ubuntu2/tests-mx32/pidfd_open--decode-fd-socket.gen.test
--- 5.5-3/tests-mx32/pidfd_open--decode-fd-socket.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pidfd_open--decode-fd-socket.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_open--decode-fd-socket -a17 -e decode-fd=socket -e trace=pidfd_open); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a17 -e decode-fd=socket -e trace=pidfd_open
diff -pruN 5.5-3/tests-mx32/pidfd_open--pidns-translation.c 5.9-0ubuntu2/tests-mx32/pidfd_open--pidns-translation.c
--- 5.5-3/tests-mx32/pidfd_open--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pidfd_open--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "pidfd_open.c"
diff -pruN 5.5-3/tests-mx32/pidfd_open--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/pidfd_open--pidns-translation.gen.test
--- 5.5-3/tests-mx32/pidfd_open--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pidfd_open--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_open--pidns-translation test_pidns -a17 -e trace=pidfd_open); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a17 -e trace=pidfd_open
diff -pruN 5.5-3/tests-mx32/pidfd_open-yy.c 5.9-0ubuntu2/tests-mx32/pidfd_open-yy.c
--- 5.5-3/tests-mx32/pidfd_open-yy.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pidfd_open-yy.c	2020-04-05 13:28:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_PIDFD 1
+#include "pidfd_open-y.c"
diff -pruN 5.5-3/tests-mx32/pidfd_open-yy.gen.test 5.9-0ubuntu2/tests-mx32/pidfd_open-yy.gen.test
--- 5.5-3/tests-mx32/pidfd_open-yy.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pidfd_open-yy.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_open-yy -a17 -yy -e trace=pidfd_open); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a17 -yy -e trace=pidfd_open
diff -pruN 5.5-3/tests-mx32/pidfd_send_signal.c 5.9-0ubuntu2/tests-mx32/pidfd_send_signal.c
--- 5.5-3/tests-mx32/pidfd_send_signal.c	2019-08-14 11:22:32.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pidfd_send_signal.c	2020-08-25 14:29:30.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check decoding of pidfd_send_signal syscall.
  *
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,6 +10,7 @@
 #include "tests.h"
 #include <unistd.h>
 #include "scno.h"
+#include "pidns.h"
 
 #ifdef __NR_pidfd_send_signal
 
@@ -36,6 +37,8 @@ sys_pidfd_send_signal(int pidfd, int sig
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	static const char null_path[] = "/dev/null";
 
 	int fd = open(null_path, O_RDONLY);
@@ -46,19 +49,23 @@ main(void)
 	const void *esi = (const void *) si + 1;
 
 	sys_pidfd_send_signal(fd, SIGUSR1, esi, 0);
+	pidns_print_leader();
 	printf("pidfd_send_signal(%d, SIGUSR1, %p, 0) = %s\n",
 	       fd, esi, errstr);
 
 	si->si_signo = SIGUSR1;
 	si->si_code = SI_QUEUE;
+	si->si_pid = getpid();
 
 	sys_pidfd_send_signal(fd, SIGUSR2, si, -1);
+	pidns_print_leader();
 	printf("pidfd_send_signal(%d, SIGUSR2, {si_signo=SIGUSR1"
-	       ", si_code=SI_QUEUE, si_errno=%u, si_pid=%u, si_uid=%u"
+	       ", si_code=SI_QUEUE, si_errno=%u, si_pid=%d%s, si_uid=%d"
 	       ", si_value={int=%d, ptr=%p}}, %#x) = %s\n",
-	       fd, si->si_errno, si->si_pid, si->si_uid, si->si_int, si->si_ptr,
-	       -1U, errstr);
+	       fd, si->si_errno, si->si_pid, pidns_pid2str(PT_TGID), si->si_uid,
+	       si->si_int, si->si_ptr, -1U, errstr);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/pidfd_send_signal--pidns-translation.c 5.9-0ubuntu2/tests-mx32/pidfd_send_signal--pidns-translation.c
--- 5.5-3/tests-mx32/pidfd_send_signal--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pidfd_send_signal--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "pidfd_send_signal.c"
diff -pruN 5.5-3/tests-mx32/pidfd_send_signal--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/pidfd_send_signal--pidns-translation.gen.test
--- 5.5-3/tests-mx32/pidfd_send_signal--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pidfd_send_signal--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (pidfd_send_signal--pidns-translation test_pidns -e trace=pidfd_send_signal); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -e trace=pidfd_send_signal
diff -pruN 5.5-3/tests-mx32/pidns.c 5.9-0ubuntu2/tests-mx32/pidns.c
--- 5.5-3/tests-mx32/pidns.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pidns.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,237 @@
+/*
+ * Testing framework for PID namespace translation
+ *
+ * Copyright (c) 2020 Ákos Uzonyi <uzonyi.akos@gmail.com>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+#include "tests.h"
+#include "pidns.h"
+#include "nsfs.h"
+
+#include <errno.h>
+#include <stdio.h>
+#include <string.h>
+#include <sys/types.h>
+#include <signal.h>
+#include <stdlib.h>
+#include <sched.h>
+#include <unistd.h>
+#include <sys/wait.h>
+#include <linux/sched.h>
+#include <fcntl.h>
+#include <sys/ioctl.h>
+
+#ifndef CLONE_NEWUSER
+# define CLONE_NEWUSER 0x10000000
+#endif
+
+#ifndef CLONE_NEWPID
+# define CLONE_NEWPID 0x20000000
+#endif
+
+static bool pidns_translation = false;
+static bool pidns_unshared = false;
+
+/* Our PIDs in strace's namespace */
+static pid_t pidns_strace_ids[PT_COUNT];
+
+void
+pidns_print_leader(void)
+{
+	if (pidns_translation)
+		printf("%-5d ", pidns_strace_ids[PT_TID]);
+}
+
+const char *
+pidns_pid2str(enum pid_type type)
+{
+	static const char format[] = " /* %d in strace's PID NS */";
+	static char buf[PT_COUNT][sizeof(format) + sizeof(int) * 3];
+
+	if (type < 0 || type >= PT_COUNT)
+		return "";
+
+	if (!pidns_unshared || !pidns_strace_ids[type])
+		return "";
+
+	snprintf(buf[type], sizeof(buf[type]), format, pidns_strace_ids[type]);
+	return buf[type];
+}
+
+/**
+ * This function is like fork, but does a few more things. It sets up the
+ * child's PGID and SID according to the parameters. Also it fills the
+ * pidns_strace_ids array in the child's memory with the PIDs of the child in
+ * parent's PID namespace. In the parent it waits for the child to terminate
+ * (but leaves the zombie to use it later as a process group). If the child
+ * terminates with nonzero exit status, the test is failed.
+ *
+ * @param pgid     The process group the child should be moved to. It's expected
+ *                 to be a PID of a zombie process (will be reaped). If
+ *                 negative, leave the child in the process group of the parent.
+ *                 If 0, move the process to its own process group.
+ * @param new_sid  Wheather child should be moved to a new session.
+ */
+static pid_t
+pidns_fork(pid_t pgid, bool new_sid)
+{
+	int strace_ids_pipe[2];
+	if (pipe(strace_ids_pipe) < 0)
+		perror_msg_and_fail("pipe");
+
+	fflush(stdout);
+	pid_t pid = fork();
+	if (pid < 0)
+		perror_msg_and_fail("fork");
+
+	if (!pid) {
+		close(strace_ids_pipe[1]);
+
+		ssize_t len = read(strace_ids_pipe[0], pidns_strace_ids,
+				sizeof(pidns_strace_ids));
+		if (len < 0)
+			perror_msg_and_fail("read");
+		if (len != sizeof(pidns_strace_ids))
+			error_msg_and_fail("read returned < sizeof(pidns_strace_ids)");
+
+		close(strace_ids_pipe[0]);
+
+		if (pidns_strace_ids[PT_SID])
+			setsid();
+
+		return 0;
+	}
+
+	pidns_strace_ids[PT_TID] = pid;
+	pidns_strace_ids[PT_TGID] = pid;
+	pidns_strace_ids[PT_PGID] = 0;
+	pidns_strace_ids[PT_SID] = 0;
+
+	if (!pgid)
+		pgid = pid;
+
+	if (pgid > 0) {
+		if (setpgid(pid, pgid) < 0)
+			perror_msg_and_fail("setpgid");
+
+		pidns_strace_ids[PT_PGID] = pgid;
+	}
+
+	/* Reap group leader to test PGID decoding */
+	if (pgid > 0 && pgid != pid) {
+		int ret = waitpid(pgid, NULL, WNOHANG);
+		if (ret < 0)
+			perror_msg_and_fail("wait");
+		if (!ret)
+			error_msg_and_fail("could not reap group leader");
+	}
+
+	if (new_sid) {
+		pidns_strace_ids[PT_SID] = pid;
+		pidns_strace_ids[PT_PGID] = pid;
+	}
+
+	ssize_t len = write(strace_ids_pipe[1], pidns_strace_ids,
+	                     sizeof(pidns_strace_ids));
+	if (len < 0)
+		perror_msg_and_fail("write");
+	if (len != sizeof(pidns_strace_ids))
+		error_msg_and_fail("write returned < sizeof(pidns_strace_ids)");
+
+	close(strace_ids_pipe[0]);
+	close(strace_ids_pipe[1]);
+
+	/* WNOWAIT: leave the zombie, to be able to use it as a process group */
+	siginfo_t siginfo;
+	if (waitid(P_PID, pid, &siginfo, WEXITED | WNOWAIT) < 0)
+		perror_msg_and_fail("wait");
+	if (siginfo.si_code != CLD_EXITED || siginfo.si_status)
+		error_msg_and_fail("child terminated with nonzero exit status");
+
+	return pid;
+}
+
+static void
+create_init_process(void)
+{
+	int child_pipe[2];
+	if (pipe(child_pipe) < 0)
+		perror_msg_and_fail("pipe");
+
+	pid_t pid = fork();
+	if (pid < 0)
+		perror_msg_and_fail("fork");
+
+	if (!pid) {
+		close(child_pipe[1]);
+		if (read(child_pipe[0], &child_pipe[1], sizeof(int)) != 0)
+			_exit(1);
+		_exit(0);
+	}
+
+	close(child_pipe[0]);
+}
+
+void
+check_ns_ioctl(void)
+{
+	int fd = open("/proc/self/ns/pid", O_RDONLY);
+	if (fd < 0) {
+		if (errno == ENOENT)
+			perror_msg_and_skip("opening /proc/self/ns/pid");
+		else
+			perror_msg_and_fail("opening /proc/self/ns/pid");
+	}
+
+	int userns_fd = ioctl(fd, NS_GET_USERNS);
+	if (userns_fd < 0) {
+		if (errno == ENOTTY)
+			error_msg_and_skip("NS_* ioctl commands are not "
+			                   "supported by the kernel");
+		else
+			perror_msg_and_fail("ioctl(NS_GET_USERNS)");
+	}
+
+	close(userns_fd);
+	close(fd);
+}
+
+void
+pidns_test_init(void)
+{
+	pidns_translation = true;
+
+	check_ns_ioctl();
+
+	if (!pidns_fork(-1, false))
+		return;
+
+	/* Unshare user namespace too, so we do not need to be root */
+	if (unshare(CLONE_NEWUSER | CLONE_NEWPID) < 0) {
+		if (errno == EPERM)
+			perror_msg_and_skip("unshare");
+
+		perror_msg_and_fail("unshare");
+	}
+
+	pidns_unshared = true;
+
+	create_init_process();
+
+	if (!pidns_fork(-1, false))
+		return;
+
+	if (!pidns_fork(-1, true))
+		return;
+
+	pid_t pgid;
+	if (!(pgid = pidns_fork(0, false)))
+		return;
+
+	if (!pidns_fork(pgid, false))
+		return;
+
+	exit(0);
+}
diff -pruN 5.5-3/tests-mx32/pidns-cache.c 5.9-0ubuntu2/tests-mx32/pidns-cache.c
--- 5.5-3/tests-mx32/pidns-cache.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pidns-cache.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,62 @@
+/*
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+#include "pidns.h"
+
+#if defined __NR_getpid && (!defined __NR_getxpid || __NR_getxpid != __NR_getpid)
+
+# include <stdio.h>
+# include <unistd.h>
+# include <sys/time.h>
+
+# define SYSCALL_COUNT 1000
+
+/**
+ * Max ratio of the execution time with and without pidns translation.
+ */
+# define MAX_TIME_RATIO 20
+
+static long
+execute_syscalls(void)
+{
+	/* Load our PID in the cache */
+	syscall(__NR_getpid);
+
+	struct timeval stop, start;
+	gettimeofday(&start, NULL);
+
+	for (int i = 0; i < SYSCALL_COUNT; i++)
+	       syscall(__NR_getpid);
+
+	gettimeofday(&stop, NULL);
+
+	return (stop.tv_usec - start.tv_usec) +
+		(stop.tv_sec - start.tv_sec) * 1000000;
+}
+
+int
+main(void)
+{
+	long max_us = execute_syscalls() * MAX_TIME_RATIO;
+
+	pidns_test_init();
+
+	long us = execute_syscalls();
+	if (us > max_us)
+		error_msg_and_fail("pidns translation took too long: %ld us "
+		                   "(max: %ld us)", us, max_us);
+
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_getpid")
+
+#endif
diff -pruN 5.5-3/tests-mx32/pidns-cache.test 5.9-0ubuntu2/tests-mx32/pidns-cache.test
--- 5.5-3/tests-mx32/pidns-cache.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pidns-cache.test	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,15 @@
+#!/bin/sh
+#
+# Test pidns translation cache.
+#
+# Copyright (c) 2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: GPL-2.0-or-later
+
+. "${srcdir=.}/init.sh"
+
+check_prog timeout
+
+run_prog > /dev/null
+run_strace --pidns-translation -f -e trace=getpid $args
diff -pruN 5.5-3/tests-mx32/pidns.h 5.9-0ubuntu2/tests-mx32/pidns.h
--- 5.5-3/tests-mx32/pidns.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pidns.h	2020-09-23 16:29:35.000000000 +0000
@@ -0,0 +1,56 @@
+/*
+ * Test PID namespace translation
+ *
+ * Copyright (c) 2020 Ákos Uzonyi <uzonyi.akos@gmail.com>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+#ifndef STRACE_PIDNS_H
+# define STRACE_PIDNS_H
+
+# ifdef PIDNS_TRANSLATION
+#  define PIDNS_TEST_INIT pidns_test_init()
+# else
+#  define PIDNS_TEST_INIT
+# endif
+
+# include <sys/types.h>
+
+enum pid_type {
+	PT_TID,
+	PT_TGID,
+	PT_PGID,
+	PT_SID,
+
+	PT_COUNT,
+	PT_NONE = -1
+};
+
+/* Prints leader (process tid) if pidns_test_init was called */
+void pidns_print_leader(void);
+
+/*
+ * Returns a static buffer containing the translation string of our PID.
+ */
+const char *pidns_pid2str(enum pid_type type);
+
+/**
+ * Skips the test if NS_* ioctl commands are not supported by the kernel.
+ */
+void check_ns_ioctl(void);
+
+/**
+ * Init pidns testing.
+ *
+ * Should be called at the beginning of the test's main function
+ *
+ * This function calls fork a couple of times, and returns in the child
+ * processes. These child processes are in a new PID namespace with different
+ * PID configurations (group leader, session leader, ...). If any child
+ * terminates with nonzero exit status the test is failed. Otherwise the test is
+ * succesful, and the parent process exits with 0.
+ */
+void pidns_test_init(void);
+
+#endif
\ No newline at end of file
diff -pruN 5.5-3/tests-mx32/poll-P.test 5.9-0ubuntu2/tests-mx32/poll-P.test
--- 5.5-3/tests-mx32/poll-P.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/poll-P.test	2020-04-06 16:22:20.000000000 +0000
@@ -2,20 +2,20 @@
 #
 # Check path tracing of poll syscall.
 #
-# Copyright (c) 2018 The strace developers.
+# Copyright (c) 2018-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/init.sh"
 
-run_prog > /dev/null
+run_prog > /dev/null 9>>/dev/full
 run_strace -a16 -vepoll -P /dev/full 9>>/dev/full \
 	$args > "$EXP"
 match_diff "$LOG" "$EXP"
 
 for abbrev in 0 1 2 3 4 5; do
-	run_prog "../$NAME" $abbrev > /dev/null
+	run_prog "../$NAME" $abbrev > /dev/null 9>>/dev/full
 	run_strace -a16 -epoll -s$abbrev -P /dev/full 9>>/dev/full \
 		$args > "$EXP"
 	match_diff "$LOG" "$EXP"
diff -pruN 5.5-3/tests-mx32/prctl-name.c 5.9-0ubuntu2/tests-mx32/prctl-name.c
--- 5.5-3/tests-mx32/prctl-name.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/prctl-name.c	2020-04-03 22:58:26.000000000 +0000
@@ -3,19 +3,16 @@
  *
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include <sys/prctl.h>
 
-#ifdef HAVE_PRCTL
-# include <sys/prctl.h>
-#endif
-
-#if defined HAVE_PRCTL && defined PR_GET_NAME && defined PR_SET_NAME
+#if defined PR_GET_NAME && defined PR_SET_NAME
 
 # include <stdio.h>
 # include <string.h>
@@ -79,6 +76,6 @@ main(void)
 
 #else
 
-SKIP_MAIN_UNDEFINED("HAVE_PRCTL && PR_GET_NAME && PR_SET_NAME")
+SKIP_MAIN_UNDEFINED("PR_GET_NAME && PR_SET_NAME")
 
 #endif
diff -pruN 5.5-3/tests-mx32/prctl-pdeathsig.c 5.9-0ubuntu2/tests-mx32/prctl-pdeathsig.c
--- 5.5-3/tests-mx32/prctl-pdeathsig.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/prctl-pdeathsig.c	2020-04-03 22:58:26.000000000 +0000
@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2016 JingPiao Chen <chenjingpiao@foxmail.com>
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -17,7 +17,7 @@
 
 # include <stdio.h>
 # include <unistd.h>
-# include <sys/signal.h>
+# include <signal.h>
 
 int
 main(void)
diff -pruN 5.5-3/tests-mx32/prctl-seccomp-filter-v.c 5.9-0ubuntu2/tests-mx32/prctl-seccomp-filter-v.c
--- 5.5-3/tests-mx32/prctl-seccomp-filter-v.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/prctl-seccomp-filter-v.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
  * Check verbose decoding of prctl PR_SET_SECCOMP SECCOMP_MODE_FILTER.
  *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -13,18 +13,14 @@
 #include <unistd.h>
 #include <stdio.h>
 #include <errno.h>
-#include "scno.h"
-
-#ifdef HAVE_PRCTL
-# include <sys/prctl.h>
-#endif
+#include <sys/prctl.h>
 #ifdef HAVE_LINUX_SECCOMP_H
 # include <linux/seccomp.h>
 #endif
 #include <linux/filter.h>
+#include "scno.h"
 
-#if defined HAVE_PRCTL \
- && defined PR_SET_NO_NEW_PRIVS \
+#if defined PR_SET_NO_NEW_PRIVS \
  && defined PR_SET_SECCOMP \
  && defined SECCOMP_MODE_FILTER \
  && defined SECCOMP_RET_ERRNO \
@@ -117,7 +113,7 @@ main(void)
 
 #else
 
-SKIP_MAIN_UNDEFINED("HAVE_PRCTL && PR_SET_NO_NEW_PRIVS && PR_SET_SECCOMP"
+SKIP_MAIN_UNDEFINED("PR_SET_NO_NEW_PRIVS && PR_SET_SECCOMP"
 		    " && SECCOMP_MODE_FILTER && SECCOMP_RET_ERRNO"
 		    " && BPF_JUMP && BPF_STMT")
 
diff -pruN 5.5-3/tests-mx32/prctl-seccomp-strict.c 5.9-0ubuntu2/tests-mx32/prctl-seccomp-strict.c
--- 5.5-3/tests-mx32/prctl-seccomp-strict.c	2019-12-15 16:29:06.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/prctl-seccomp-strict.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,18 +1,16 @@
 /*
  * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include <sys/prctl.h>
 #include "scno.h"
-#ifdef HAVE_PRCTL
-# include <sys/prctl.h>
-#endif
 
-#if defined HAVE_PRCTL && defined PR_SET_SECCOMP && defined __NR_exit
+#if defined PR_SET_SECCOMP && defined __NR_exit
 
 # include <stdio.h>
 # include <unistd.h>
@@ -49,6 +47,6 @@ main(void)
 
 #else
 
-SKIP_MAIN_UNDEFINED("HAVE_PRCTL && PR_SET_SECCOMP && __NR_exit")
+SKIP_MAIN_UNDEFINED("PR_SET_SECCOMP && __NR_exit")
 
 #endif
diff -pruN 5.5-3/tests-mx32/preadv.c 5.9-0ubuntu2/tests-mx32/preadv.c
--- 5.5-3/tests-mx32/preadv.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/preadv.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2014-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -74,12 +74,7 @@ main(void)
 		perror_msg_and_fail("preadv");
 	printf("preadv(0, [], 0, -3) = -1 EINVAL (%m)\n");
 
-	static const char tmp[] = "preadv-tmpfile";
-	int fd = open(tmp, O_RDWR | O_CREAT | O_TRUNC, 0600);
-	if (fd < 0)
-		perror_msg_and_fail("open");
-	if (unlink(tmp))
-		perror_msg_and_fail("unlink");
+	int fd = create_tmpfile(O_RDWR);
 
 	static const char w[] = "0123456789abcde";
 	if (write(fd, w, LENGTH_OF(w)) != LENGTH_OF(w))
diff -pruN 5.5-3/tests-mx32/printpath-umovestr-undumpable.c 5.9-0ubuntu2/tests-mx32/printpath-umovestr-undumpable.c
--- 5.5-3/tests-mx32/printpath-umovestr-undumpable.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/printpath-umovestr-undumpable.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,19 +1,16 @@
 /*
  * Force legacy printpath/umovestr using PR_SET_DUMPABLE.
  *
- * Copyright (c) 2017-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2017-2020 Dmitry V. Levin <ldv@altlinux.org>
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include <sys/prctl.h>
 
-#ifdef HAVE_PRCTL
-# include <sys/prctl.h>
-#endif
-
-#if defined HAVE_PRCTL && defined PR_SET_DUMPABLE
+#ifdef PR_SET_DUMPABLE
 
 # include <stdio.h>
 # include <unistd.h>
@@ -46,6 +43,6 @@ main(void)
 
 #else
 
-SKIP_MAIN_UNDEFINED("HAVE_PRCTL && PR_SET_DUMPABLE")
+SKIP_MAIN_UNDEFINED("PR_SET_DUMPABLE")
 
 #endif
diff -pruN 5.5-3/tests-mx32/print_ppid_tracerpid.c 5.9-0ubuntu2/tests-mx32/print_ppid_tracerpid.c
--- 5.5-3/tests-mx32/print_ppid_tracerpid.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/print_ppid_tracerpid.c	2020-05-27 08:00:00.000000000 +0000
@@ -0,0 +1,42 @@
+/*
+ * Helper program for strace-D.test
+ *
+ * Copyright (c) 2019-2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <unistd.h>
+
+int
+main(void)
+{
+	static const char status[] = "/proc/self/status";
+	FILE *fp = fopen(status, "r");
+	if (!fp)
+		perror_msg_and_fail("fopen: %s", status);
+
+	static const char prefix1[] = "PPid:";
+	static const char prefix2[] = "TracerPid:";
+	char *line = NULL;
+	size_t n = 0;
+
+	while (getline(&line, &n, fp) > 0) {
+		if (strncmp(line, prefix1, sizeof(prefix1) - 1) == 0 ||
+		    strncmp(line, prefix2, sizeof(prefix2) - 1) == 0)
+			fputs(line, stdout);
+	}
+
+	if (!line)
+		perror_msg_and_fail("getline");
+
+	free(line);
+	fclose(fp);
+
+	return 0;
+}
diff -pruN 5.5-3/tests-mx32/printstrn-umoven-undumpable.c 5.9-0ubuntu2/tests-mx32/printstrn-umoven-undumpable.c
--- 5.5-3/tests-mx32/printstrn-umoven-undumpable.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/printstrn-umoven-undumpable.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,19 +1,16 @@
 /*
  * Force legacy printpath/umovestr using PR_SET_DUMPABLE.
  *
- * Copyright (c) 2017-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2017-2020 Dmitry V. Levin <ldv@altlinux.org>
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include <sys/prctl.h>
 
-#ifdef HAVE_PRCTL
-# include <sys/prctl.h>
-#endif
-
-#if defined HAVE_PRCTL && defined PR_SET_DUMPABLE
+#ifdef PR_SET_DUMPABLE
 
 # include <stdio.h>
 # include <unistd.h>
@@ -46,6 +43,6 @@ main(void)
 
 #else
 
-SKIP_MAIN_UNDEFINED("HAVE_PRCTL && PR_SET_DUMPABLE")
+SKIP_MAIN_UNDEFINED("PR_SET_DUMPABLE")
 
 #endif
diff -pruN 5.5-3/tests-mx32/prlimit64.c 5.9-0ubuntu2/tests-mx32/prlimit64.c
--- 5.5-3/tests-mx32/prlimit64.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/prlimit64.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of prlimit64 syscall.
  *
  * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -19,6 +19,7 @@
 # include <sys/resource.h>
 # include <unistd.h>
 
+# include "pidns.h"
 # include "xlat.h"
 # include "xlat/resources.h"
 
@@ -42,8 +43,11 @@ sprint_rlim(uint64_t lim)
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	unsigned long pid =
 		(unsigned long) 0xdefaced00000000ULL | (unsigned) getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
 	uint64_t *const rlimit = tail_alloc(sizeof(*rlimit) * 2);
 	const struct xlat_data *xlat;
 	size_t i = 0;
@@ -54,18 +58,23 @@ main(void)
 
 		unsigned long res = 0xfacefeed00000000ULL | xlat->val;
 		long rc = syscall(__NR_prlimit64, pid, res, 0, rlimit);
+		pidns_print_leader();
 		if (rc)
-			printf("prlimit64(%d, %s, NULL, %p) = %ld %s (%m)\n",
-			       (unsigned) pid, xlat->str, rlimit,
+			printf("prlimit64(%d%s, %s, NULL, %p) ="
+				     " %ld %s (%m)\n",
+			       (unsigned) pid, pid_str,
+			       xlat->str, rlimit,
 			       rc, errno2name());
 		else
-			printf("prlimit64(%d, %s, NULL"
+			printf("prlimit64(%d%s, %s, NULL"
 			       ", {rlim_cur=%s, rlim_max=%s}) = 0\n",
-			       (unsigned) pid, xlat->str,
+			       (unsigned) pid, pid_str,
+			       xlat->str,
 			       sprint_rlim(rlimit[0]),
 			       sprint_rlim(rlimit[1]));
 	}
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/prlimit64--pidns-translation.c 5.9-0ubuntu2/tests-mx32/prlimit64--pidns-translation.c
--- 5.5-3/tests-mx32/prlimit64--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/prlimit64--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "prlimit64.c"
diff -pruN 5.5-3/tests-mx32/prlimit64--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/prlimit64--pidns-translation.gen.test
--- 5.5-3/tests-mx32/prlimit64--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/prlimit64--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (prlimit64--pidns-translation test_pidns -e trace=prlimit64); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -e trace=prlimit64
diff -pruN 5.5-3/tests-mx32/process_vm_readv--pidns-translation.c 5.9-0ubuntu2/tests-mx32/process_vm_readv--pidns-translation.c
--- 5.5-3/tests-mx32/process_vm_readv--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/process_vm_readv--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "process_vm_readv.c"
diff -pruN 5.5-3/tests-mx32/process_vm_readv--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/process_vm_readv--pidns-translation.gen.test
--- 5.5-3/tests-mx32/process_vm_readv--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/process_vm_readv--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (process_vm_readv--pidns-translation test_pidns -s5 -a37 -e trace=process_vm_readv); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -s5 -a37 -e trace=process_vm_readv
diff -pruN 5.5-3/tests-mx32/process_vm_readv_writev.c 5.9-0ubuntu2/tests-mx32/process_vm_readv_writev.c
--- 5.5-3/tests-mx32/process_vm_readv_writev.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/process_vm_readv_writev.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of process_vm_readv/process_vm_writev syscall.
  *
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -12,6 +12,7 @@
 #include <stdio.h>
 #include <unistd.h>
 #include <sys/uio.h>
+#include "pidns.h"
 
 #if OP_WR
 # define in_iovec  rmt_iovec
@@ -121,7 +122,7 @@ print_iov(const struct iovec *iov, const
 }
 
 static void
-do_call(kernel_ulong_t pid,
+do_call(kernel_ulong_t pid, enum pid_type pid_type,
 	kernel_ulong_t local_iov, const char *local_arg,
 	kernel_ulong_t liovcnt,
 	kernel_ulong_t remote_iov, const char *remote_arg,
@@ -135,7 +136,8 @@ do_call(kernel_ulong_t pid,
 		flags);
 	errstr = sprintrc(rc);
 
-	printf("%s(%d, ", OP_STR, (int) pid);
+	pidns_print_leader();
+	printf("%s(%d%s, ", OP_STR, (int) pid, pidns_pid2str(pid_type));
 
 	if (pr_iov)
 		pr_iov((const struct iovec *) (uintptr_t) local_iov, local_arg,
@@ -164,6 +166,8 @@ ptr_cast(void *ptr)
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	enum {
 		SIZE_11 = 2,
 		SIZE_12 = 3,
@@ -243,18 +247,18 @@ main(void)
 	fill_memory_ex(data2_out, SIZE_2, SEGM2_BASE, SIZE_2);
 
 
-	do_call(bogus_pid, (kernel_ulong_t) (uintptr_t) ARG_STR(NULL),
+	do_call(bogus_pid, PT_NONE, (kernel_ulong_t) (uintptr_t) ARG_STR(NULL),
 		bogus_iovcnt1, (kernel_ulong_t) (uintptr_t) ARG_STR(NULL),
 		bogus_iovcnt2, bogus_flags, NULL);
 
-	do_call(my_pid, ptr_cast(bogus_iov + ARRAY_SIZE(bogus_iovec)),
+	do_call(my_pid, PT_TGID, ptr_cast(bogus_iov + ARRAY_SIZE(bogus_iovec)),
 		"[]", 0, ptr_cast(in_iov + ARRAY_SIZE(in_iovec)), "[]",
 		0, 0, NULL);
-	do_call(my_pid, ptr_cast(bogus_iov + ARRAY_SIZE(bogus_iovec)), NULL,
-		bogus_iovcnt1, ptr_cast(in_iov + ARRAY_SIZE(in_iovec)), NULL,
-		bogus_iovcnt2, 0, print_iov);
+	do_call(my_pid, PT_TGID, ptr_cast(bogus_iov + ARRAY_SIZE(bogus_iovec)),
+		NULL, bogus_iovcnt1, ptr_cast(in_iov + ARRAY_SIZE(in_iovec)),
+		NULL, bogus_iovcnt2, 0, print_iov);
 
-	do_call(my_pid, ptr_cast(bogus_iov), (char *) &bogus_arg,
+	do_call(my_pid, PT_TGID, ptr_cast(bogus_iov), (char *) &bogus_arg,
 		ARRAY_SIZE(bogus_iovec), ptr_cast(rmt_iov + 2),
 		(char *) &rmt_arg_cut, ARRAY_SIZE(rmt_iovec) - 2, 0, print_iov);
 
@@ -263,7 +267,7 @@ main(void)
 	lcl_arg_cut.check_rc = 1;
 #endif
 
-	do_call(my_pid, ptr_cast(lcl_iov + 2), (char *) &lcl_arg_cut,
+	do_call(my_pid, PT_TGID, ptr_cast(lcl_iov + 2), (char *) &lcl_arg_cut,
 		ARRAY_SIZE(lcl_iovec) - 1, ptr_cast(bogus_iov + 2),
 		(char *) &bogus_arg_cut, ARRAY_SIZE(bogus_iovec) - 1, 0,
 		print_iov);
@@ -273,15 +277,16 @@ main(void)
 	rmt_arg_cut.addr_term = 1;
 	rmt_arg_cut.count = 5;
 
-	do_call(my_pid, ptr_cast(lcl_iov + 2), (char *) &lcl_arg_cut,
+	do_call(my_pid, PT_TGID, ptr_cast(lcl_iov + 2), (char *) &lcl_arg_cut,
 		ARRAY_SIZE(lcl_iovec) - 2, ptr_cast(rmt_iov + 1),
 		(char *) &rmt_arg_cut, ARRAY_SIZE(rmt_iovec), 0, print_iov);
 
 	/* Correct call */
-	do_call(my_pid, ptr_cast(lcl_iov), (char *) &lcl_arg,
+	do_call(my_pid, PT_TGID, ptr_cast(lcl_iov), (char *) &lcl_arg,
 		ARRAY_SIZE(lcl_iovec), ptr_cast(rmt_iov), (char *) &rmt_arg,
 		ARRAY_SIZE(rmt_iovec), 0, print_iov);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 
 	return 0;
diff -pruN 5.5-3/tests-mx32/process_vm_writev--pidns-translation.c 5.9-0ubuntu2/tests-mx32/process_vm_writev--pidns-translation.c
--- 5.5-3/tests-mx32/process_vm_writev--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/process_vm_writev--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "process_vm_writev.c"
diff -pruN 5.5-3/tests-mx32/process_vm_writev--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/process_vm_writev--pidns-translation.gen.test
--- 5.5-3/tests-mx32/process_vm_writev--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/process_vm_writev--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (process_vm_writev--pidns-translation test_pidns -s5 -a38 -e trace=process_vm_writev); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -s5 -a38 -e trace=process_vm_writev
diff -pruN 5.5-3/tests-mx32/ptrace.c 5.9-0ubuntu2/tests-mx32/ptrace.c
--- 5.5-3/tests-mx32/ptrace.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ptrace.c	2020-08-03 08:00:00.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of ptrace syscall.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -127,16 +127,16 @@ test_peeksiginfo(unsigned long pid, cons
 			printf("ptrace(PTRACE_PEEKSIGINFO, %u"
 			       ", {off=%llu, flags=0, nr=%u}"
 			       ", [{si_signo=SIGUSR1, si_code=SI_TKILL"
-			       ", si_pid=%u, si_uid=%u}"
+			       ", si_pid=%d, si_uid=%d}"
 			       ", {si_signo=SIGUSR2, si_code=SI_TKILL"
-			       ", si_pid=%u, si_uid=%u}"
+			       ", si_pid=%d, si_uid=%d}"
 			       ", {si_signo=SIGALRM, si_code=SI_TKILL"
-			       ", si_pid=%u, si_uid=%u}"
+			       ", si_pid=%d, si_uid=%d}"
 			       "]) = %s\n",
 			       (unsigned) pid, psi->off, psi->nr,
-			       (unsigned) pid, (unsigned) uid,
-			       (unsigned) pid, (unsigned) uid,
-			       (unsigned) pid, (unsigned) uid,
+			       (int) pid, (int) uid,
+			       (int) pid, (int) uid,
+			       (int) pid, (int) uid,
 			       errstr);
 		}
 
diff -pruN 5.5-3/tests-mx32/ptrace_syscall_info.c 5.9-0ubuntu2/tests-mx32/ptrace_syscall_info.c
--- 5.5-3/tests-mx32/ptrace_syscall_info.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/ptrace_syscall_info.c	2020-05-27 08:00:00.000000000 +0000
@@ -247,7 +247,12 @@ test_entry(void)
 					break;
 				goto printed_entry_nr;
 			}
-			if (info.entry.args[i] != exp_args[i + 1])
+#if SIZEOF_KERNEL_LONG_T > SIZEOF_LONG
+# define CAST (unsigned long)
+#else
+# define CAST
+#endif
+			if (CAST info.entry.args[i] != exp_args[i + 1])
 				FAIL("#%d: entry stop mismatch", ptrace_stop);
 			printf("%s%#llx", (i ? ", " : ", arg=["),
 			       (unsigned long long) info.entry.args[i]);
diff -pruN 5.5-3/tests-mx32/pure_executables.am 5.9-0ubuntu2/tests-mx32/pure_executables.am
--- 5.5-3/tests-mx32/pure_executables.am	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pure_executables.am	2020-09-24 09:18:49.000000000 +0000
@@ -27,13 +27,29 @@ PURE_EXECUTABLES = \
   clone3-Xabbrev \
   clone3-Xraw \
   clone3-Xverbose \
+  close_range \
+  close_range-P \
+  close_range-y \
+  close_range-yy \
   copy_file_range \
   creat \
   delete_module \
+  dev--decode-fds-dev \
+  dev--decode-fds-path \
+  dev--decode-fds-socket \
   dev-yy \
   dup \
+  dup-P \
+  dup-y \
+  dup-yy \
   dup2 \
+  dup2-P \
+  dup2-y \
+  dup2-yy \
   dup3 \
+  dup3-P \
+  dup3-y \
+  dup3-yy \
   epoll_create \
   epoll_create1 \
   epoll_ctl \
@@ -44,6 +60,13 @@ PURE_EXECUTABLES = \
   execve \
   execveat \
   faccessat \
+  faccessat-P \
+  faccessat-y \
+  faccessat-yy \
+  faccessat2 \
+  faccessat2-P \
+  faccessat2-y \
+  faccessat2-yy \
   fadvise64 \
   fadvise64_64 \
   fallocate \
@@ -92,7 +115,9 @@ PURE_EXECUTABLES = \
   getcpu \
   getcwd \
   getdents \
+  getdents-v \
   getdents64 \
+  getdents64-v \
   getegid \
   getegid32 \
   geteuid \
@@ -116,7 +141,9 @@ PURE_EXECUTABLES = \
   getsockname \
   getuid \
   getuid32 \
-  getxxid \
+  getxgid \
+  getxpid \
+  getxuid \
   group_req \
   inet-cmsg \
   init_module \
@@ -139,6 +166,14 @@ PURE_EXECUTABLES = \
   ioctl_evdev-v-Xabbrev \
   ioctl_evdev-v-Xraw \
   ioctl_evdev-v-Xverbose \
+  ioctl_hdio \
+  ioctl_hdio-Xabbrev \
+  ioctl_hdio-Xraw \
+  ioctl_hdio-Xverbose \
+  ioctl_hdio-v \
+  ioctl_hdio-v-Xabbrev \
+  ioctl_hdio-v-Xraw \
+  ioctl_hdio-v-Xverbose \
   ioctl_inotify \
   ioctl_kvm_run \
   ioctl_kvm_run-v \
@@ -154,8 +189,16 @@ PURE_EXECUTABLES = \
   ioctl_sg_io_v3 \
   ioctl_sg_io_v4 \
   ioctl_sock_gifconf \
+  ioctl_tee \
   ioctl_uffdio \
   ioctl_v4l2 \
+  ioctl_v4l2-Xabbrev \
+  ioctl_v4l2-Xraw \
+  ioctl_v4l2-Xverbose \
+  ioctl_v4l2-v \
+  ioctl_v4l2-v-Xabbrev \
+  ioctl_v4l2-v-Xraw \
+  ioctl_v4l2-v-Xverbose \
   ioctl_watchdog \
   ioperm \
   iopl \
@@ -206,6 +249,7 @@ PURE_EXECUTABLES = \
   lstat64 \
   madvise \
   maybe_switch_current_tcp \
+  maybe_switch_current_tcp--quiet-thread-execve \
   mbind \
   mbind-Xabbrev \
   mbind-Xraw \
@@ -253,6 +297,10 @@ PURE_EXECUTABLES = \
   msg_name \
   munlockall \
   nanosleep \
+  net--decode-fds-dev-netlink \
+  net--decode-fds-none-netlink \
+  net--decode-fds-path-netlink \
+  net--decode-fds-socket-netlink \
   net-icmp_filter \
   net-packet_mreq \
   net-packet_mreq-Xabbrev \
@@ -335,6 +383,16 @@ PURE_EXECUTABLES = \
   open_tree \
   open_tree-P \
   openat \
+  openat2 \
+  openat2-Xabbrev \
+  openat2-Xraw \
+  openat2-Xverbose \
+  openat2-v \
+  openat2-v-y \
+  openat2-v-y-Xabbrev \
+  openat2-v-y-Xraw \
+  openat2-v-y-Xverbose \
+  openat2-y \
   osf_utimes \
   pause \
   perf_event_open \
@@ -342,9 +400,16 @@ PURE_EXECUTABLES = \
   personality-Xabbrev \
   personality-Xraw \
   personality-Xverbose \
+  pidfd_getfd \
+  pidfd_getfd-y \
+  pidfd_getfd-yy \
   pidfd_open \
+  pidfd_open--decode-fd-path \
+  pidfd_open--decode-fd-pidfd \
+  pidfd_open--decode-fd-socket \
   pidfd_open-P \
   pidfd_open-y \
+  pidfd_open-yy \
   pidfd_send_signal \
   pipe \
   pipe2 \
@@ -352,9 +417,7 @@ PURE_EXECUTABLES = \
   pkey_free \
   pkey_mprotect \
   poll \
-  poll-P \
   ppoll \
-  ppoll-P \
   prctl-arg2-intptr \
   prctl-dumpable \
   prctl-name \
@@ -503,11 +566,21 @@ PURE_EXECUTABLES = \
   statfs64 \
   status-all \
   status-failed \
+  status-failed-long \
+  status-failed-status \
   status-none \
   status-none-f \
   status-successful \
+  status-successful-long \
+  status-successful-status \
   status-unfinished \
   statx \
+  strace--strings-in-hex \
+  strace--strings-in-hex-all \
+  strace--strings-in-hex-non-ascii \
+  strace-n \
+  strace-x \
+  strace-xx \
   swap \
   sxetmask \
   symlink \
@@ -518,12 +591,14 @@ PURE_EXECUTABLES = \
   sysinfo \
   syslog \
   tee \
+  tgkill \
   time \
   timer_create \
   timer_xettime \
   timerfd_xettime \
   times \
   times-fail \
+  tkill \
   truncate \
   truncate64 \
   ugetrlimit \
@@ -537,6 +612,7 @@ PURE_EXECUTABLES = \
   umovestr2 \
   umovestr3 \
   umovestr_cached \
+  umovestr_cached_adjacent \
   uname \
   unlink \
   unlinkat \
diff -pruN 5.5-3/tests-mx32/pure_executables.list 5.9-0ubuntu2/tests-mx32/pure_executables.list
--- 5.5-3/tests-mx32/pure_executables.list	2019-12-11 22:44:53.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/pure_executables.list	2020-09-23 12:56:26.000000000 +0000
@@ -1,6 +1,6 @@
 # Executables without side effects.
 #
-# Copyright (c) 2017-2019 The strace developers.
+# Copyright (c) 2017-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -32,13 +32,29 @@ clone3
 clone3-Xabbrev
 clone3-Xraw
 clone3-Xverbose
+close_range
+close_range-P
+close_range-y
+close_range-yy
 copy_file_range
 creat
 delete_module
+dev--decode-fds-dev
+dev--decode-fds-path
+dev--decode-fds-socket
 dev-yy
 dup
+dup-P
+dup-y
+dup-yy
 dup2
+dup2-P
+dup2-y
+dup2-yy
 dup3
+dup3-P
+dup3-y
+dup3-yy
 epoll_create
 epoll_create1
 epoll_ctl
@@ -49,6 +65,13 @@ eventfd
 execve
 execveat
 faccessat
+faccessat-P
+faccessat-y
+faccessat-yy
+faccessat2
+faccessat2-P
+faccessat2-y
+faccessat2-yy
 fadvise64
 fadvise64_64
 fallocate
@@ -97,7 +120,9 @@ get_mempolicy
 getcpu
 getcwd
 getdents
+getdents-v
 getdents64
+getdents64-v
 getegid
 getegid32
 geteuid
@@ -121,7 +146,9 @@ getsid
 getsockname
 getuid
 getuid32
-getxxid
+getxgid
+getxpid
+getxuid
 group_req
 inet-cmsg
 init_module
@@ -144,6 +171,14 @@ ioctl_evdev-v
 ioctl_evdev-v-Xabbrev
 ioctl_evdev-v-Xraw
 ioctl_evdev-v-Xverbose
+ioctl_hdio
+ioctl_hdio-Xabbrev
+ioctl_hdio-Xraw
+ioctl_hdio-Xverbose
+ioctl_hdio-v
+ioctl_hdio-v-Xabbrev
+ioctl_hdio-v-Xraw
+ioctl_hdio-v-Xverbose
 ioctl_inotify
 ioctl_kvm_run
 ioctl_kvm_run-v
@@ -159,8 +194,16 @@ ioctl_scsi
 ioctl_sg_io_v3
 ioctl_sg_io_v4
 ioctl_sock_gifconf
+ioctl_tee
 ioctl_uffdio
 ioctl_v4l2
+ioctl_v4l2-Xabbrev
+ioctl_v4l2-Xraw
+ioctl_v4l2-Xverbose
+ioctl_v4l2-v
+ioctl_v4l2-v-Xabbrev
+ioctl_v4l2-v-Xraw
+ioctl_v4l2-v-Xverbose
 ioctl_watchdog
 ioperm
 iopl
@@ -211,6 +254,7 @@ lstat
 lstat64
 madvise
 maybe_switch_current_tcp
+maybe_switch_current_tcp--quiet-thread-execve
 mbind
 mbind-Xabbrev
 mbind-Xraw
@@ -258,6 +302,10 @@ msg_control
 msg_name
 munlockall
 nanosleep
+net--decode-fds-dev-netlink
+net--decode-fds-none-netlink
+net--decode-fds-path-netlink
+net--decode-fds-socket-netlink
 net-icmp_filter
 net-packet_mreq
 net-packet_mreq-Xabbrev
@@ -340,6 +388,16 @@ open
 open_tree
 open_tree-P
 openat
+openat2
+openat2-Xabbrev
+openat2-Xraw
+openat2-Xverbose
+openat2-v
+openat2-v-y
+openat2-v-y-Xabbrev
+openat2-v-y-Xraw
+openat2-v-y-Xverbose
+openat2-y
 osf_utimes
 pause
 perf_event_open
@@ -347,9 +405,16 @@ personality
 personality-Xabbrev
 personality-Xraw
 personality-Xverbose
+pidfd_getfd
+pidfd_getfd-y
+pidfd_getfd-yy
 pidfd_open
+pidfd_open--decode-fd-path
+pidfd_open--decode-fd-pidfd
+pidfd_open--decode-fd-socket
 pidfd_open-P
 pidfd_open-y
+pidfd_open-yy
 pidfd_send_signal
 pipe
 pipe2
@@ -357,9 +422,7 @@ pkey_alloc
 pkey_free
 pkey_mprotect
 poll
-poll-P
 ppoll
-ppoll-P
 prctl-arg2-intptr
 prctl-dumpable
 prctl-name
@@ -508,11 +571,21 @@ statfs
 statfs64
 status-all
 status-failed
+status-failed-long
+status-failed-status
 status-none
 status-none-f
 status-successful
+status-successful-long
+status-successful-status
 status-unfinished
 statx
+strace--strings-in-hex
+strace--strings-in-hex-all
+strace--strings-in-hex-non-ascii
+strace-n
+strace-x
+strace-xx
 swap
 sxetmask
 symlink
@@ -523,12 +596,14 @@ sync_file_range2
 sysinfo
 syslog
 tee
+tgkill
 time
 timer_create
 timer_xettime
 timerfd_xettime
 times
 times-fail
+tkill
 truncate
 truncate64
 ugetrlimit
@@ -542,6 +617,7 @@ umovestr-illptr
 umovestr2
 umovestr3
 umovestr_cached
+umovestr_cached_adjacent
 uname
 unlink
 unlinkat
diff -pruN 5.5-3/tests-mx32/qual_fault.c 5.9-0ubuntu2/tests-mx32/qual_fault.c
--- 5.5-3/tests-mx32/qual_fault.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/qual_fault.c	2020-06-01 14:15:16.000000000 +0000
@@ -2,7 +2,7 @@
  * Check that fault injection works properly.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -29,7 +29,7 @@ static int out_fd;
 #define DEFAULT_ERRNO ENOSYS
 
 static const char *errstr;
-static int is_raw, err, first, step, iter, try;
+static int is_raw, err, first, last, step, iter, try;
 
 static void
 invoke(int fail)
@@ -99,7 +99,7 @@ open_file(const char *prefix, int proc)
 int
 main(int argc, char *argv[])
 {
-	assert(argc == 11);
+	assert(argc == 12);
 
 	is_raw = !strcmp("raw", argv[1]);
 
@@ -120,13 +120,14 @@ main(int argc, char *argv[])
 	errstr = errno2name();
 
 	first = atoi(argv[3]);
-	step = atoi(argv[4]);
-	iter = atoi(argv[5]);
-	int num_procs = atoi(argv[6]);
-	char *exp_prefix = argv[7];
-	char *got_prefix = argv[8];
-	char *out_prefix = argv[9];
-	char *pid_prefix = argv[10];
+	last = atoi(argv[4]);
+	step = atoi(argv[5]);
+	iter = atoi(argv[6]);
+	int num_procs = atoi(argv[7]);
+	char *exp_prefix = argv[8];
+	char *got_prefix = argv[9];
+	char *out_prefix = argv[10];
+	char *pid_prefix = argv[11];
 
 	assert(first > 0);
 	assert(step >= 0);
@@ -164,8 +165,10 @@ main(int argc, char *argv[])
 		int i;
 		for (i = 1; i <= iter; ++i) {
 			int fail = 0;
-			if (first > 0) {
+			if (last != 0) {
 				--first;
+				if (last != -1)
+					--last;
 				if (first == 0) {
 					fail = 1;
 					first = step;
diff -pruN 5.5-3/tests-mx32/qual_fault-syntax.test 5.9-0ubuntu2/tests-mx32/qual_fault-syntax.test
--- 5.5-3/tests-mx32/qual_fault-syntax.test	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/qual_fault-syntax.test	2020-06-01 14:15:16.000000000 +0000
@@ -3,6 +3,7 @@
 # Check -e fault= syntax.
 #
 # Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
+# Copyright (c) 2017-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -72,6 +73,27 @@ for arg in chdir:42 \!chdir:42 \
 	   chdir:syscall=-42 \
 	   chdir:syscall=42 \
 	   chdir:syscall=gettid:syscall=gettid \
+	   chdir:when=. \
+	   chdir:when=.+ \
+	   chdir:when=..+ \
+	   chdir:when=+ \
+	   chdir:when=++ \
+	   chdir:when=10. \
+	   chdir:when=11.12 \
+	   chdir:when=13.14+ \
+	   chdir:when=15.. \
+	   chdir:when=16... \
+	   chdir:when=17...18 \
+	   chdir:when=.19 \
+	   chdir:when=..20 \
+	   chdir:when=..21+ \
+	   chdir:when=..22+3 \
+	   chdir:when=24..23 \
+	   chdir:when=25..26+0 \
+	   chdir:when=27..65535 \
+	   chdir:when=28..65535+ \
+	   chdir:when=65535..65535 \
+	   chdir:when=65535..65535+ \
 	   ; do
 	$STRACE -e fault="$arg" true 2> "$LOG" &&
 		fail_with "$arg"
diff -pruN 5.5-3/tests-mx32/qual_fault.test 5.9-0ubuntu2/tests-mx32/qual_fault.test
--- 5.5-3/tests-mx32/qual_fault.test	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/qual_fault.test	2020-06-01 14:15:16.000000000 +0000
@@ -3,7 +3,7 @@
 # Check that fault injection works properly.
 #
 # Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -22,24 +22,32 @@ N=100
 
 check_fault_injection()
 {
-	local trace fault err first step procs extra
+	local trace fault err first last step procs extra
 	trace=$1; shift
 	fault=$1; shift
 	err=$1; shift
 	first=$1; shift
+	last=$1; shift
 	step=$1; shift
 	procs=$1; shift
 	extra="$*"
 
 	local when=
-	if [ -z "$first$step" ]; then
+	if [ -z "$first$last$step" ]; then
 		first=1
+		last=-1
 		step=1
+	elif [ -z "$last" ]; then
+		case "$step" in
+			'') when=":when=$first"; step=1; last=$first ;;
+			+) when=":when=$first+"; step=1; last=-1 ;;
+			*) when=":when=$first+$step"; last=-1; ;;
+		esac
 	else
 		case "$step" in
-			'') when=":when=$first"; step=0 ;;
-			+) when=":when=$first+"; step=1 ;;
-			*) when=":when=$first+$step" ;;
+			'') when=":when=${first}..${last}"; step=1 ;;
+			+) when=":when=${first}..${last}+"; step=1 ;;
+			*) when=":when=${first}..${last}+${step}" ;;
 		esac
 	fi
 
@@ -63,7 +71,7 @@ check_fault_injection()
 
 	run_strace -a11 -ff -e trace=$trace \
 		"$@" -e fault=$fault$when$error$suffix $extra \
-		../$NAME $raw "$err" "$first" "$step" $N \
+		../$NAME $raw "$err" "$first" "$last" "$step" $N \
 		"$procs" "$outexp" "$outgot" "$outout" "$outpid"
 
 	for i in $(seq 0 $((procs - 1)) )
@@ -78,19 +86,37 @@ check_fault_injection()
 for err in '' ENOSYS 22 einval; do
 	for fault in writev desc,51; do
 		check_fault_injection \
-			writev $fault "$err" '' '' 1 -efault=chdir
+			writev $fault "$err" '' '' '' 1 -efault=chdir
 		check_fault_injection \
-			writev $fault "$err" '' '' 1 -efault=chdir -efault=none
+			writev $fault "$err" '' '' '' 1 -efault=chdir -efault=none
 		for F in 1 2 3 5 7 11; do
 			check_fault_injection \
-				writev $fault "$err" $F '' 1
+				writev $fault "$err" $F '' '' 1
 			check_fault_injection \
-				writev $fault "$err" $F + 1
+				writev $fault "$err" $F '' + 1
+
+			for L in 1 2 3 5 7 11; do
+				[ "$L" -ge "$F" ] ||
+					continue
+				check_fault_injection \
+					writev $fault "$err" $F $L '' 1
+				check_fault_injection \
+					writev $fault "$err" $F $L + 1
+			done
+
 			for S in 1 2 3 5 7 11; do
 				check_fault_injection \
-					writev $fault "$err" $F $S 1
+					writev $fault "$err" $F '' $S 1
 				check_fault_injection \
-					writev $fault "$err" $F $S 4
+					writev $fault "$err" $F '' $S 4
+				for L in 1 2 3 5 7 11; do
+					[ "$L" -ge "$F" ] ||
+						continue
+					check_fault_injection \
+						writev $fault "$err" $F $L $S 1
+					check_fault_injection \
+						writev $fault "$err" $F $L $S 4
+				done
 			done
 		done
 	done
diff -pruN 5.5-3/tests-mx32/qual_inject-syntax.test 5.9-0ubuntu2/tests-mx32/qual_inject-syntax.test
--- 5.5-3/tests-mx32/qual_inject-syntax.test	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/qual_inject-syntax.test	2020-06-01 14:15:16.000000000 +0000
@@ -3,6 +3,7 @@
 # Check -e inject= syntax.
 #
 # Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
+# Copyright (c) 2017-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -88,6 +89,27 @@ for arg in 42 chdir \
 	   chdir:syscall=-42 \
 	   chdir:syscall=42 \
 	   chdir:syscall=gettid:syscall=gettid \
+	   chdir:when=. \
+	   chdir:when=.+ \
+	   chdir:when=..+ \
+	   chdir:when=+ \
+	   chdir:when=++ \
+	   chdir:when=10. \
+	   chdir:when=11.12 \
+	   chdir:when=13.14+ \
+	   chdir:when=15.. \
+	   chdir:when=16... \
+	   chdir:when=17...18 \
+	   chdir:when=.19 \
+	   chdir:when=..20 \
+	   chdir:when=..21+ \
+	   chdir:when=..22+3 \
+	   chdir:when=24..23 \
+	   chdir:when=25..26+0 \
+	   chdir:when=27..65535 \
+	   chdir:when=28..65535+ \
+	   chdir:when=65535..65535 \
+	   chdir:when=65535..65535+ \
 	   ; do
 	$STRACE -e inject="$arg" true 2> "$LOG" &&
 		fail_with "$arg"
diff -pruN 5.5-3/tests-mx32/readahead.c 5.9-0ubuntu2/tests-mx32/readahead.c
--- 5.5-3/tests-mx32/readahead.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/readahead.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -11,24 +11,20 @@
 
 #ifdef HAVE_READAHEAD
 /* Check for glibc readahead argument passing bugs. */
-# ifdef __GLIBC__
 /*
  * glibc < 2.8 had an incorrect order of higher and lower parts of offset,
  * see https://sourceware.org/bugzilla/show_bug.cgi?id=5208
  */
-#  if !(defined __GLIBC_MINOR__ && \
-	(__GLIBC__ << 16) + __GLIBC_MINOR__ >= (2 << 16) + 8)
-#   undef HAVE_READAHEAD
-#  endif /* glibc < 2.8 */
+# if GLIBC_PREREQ_LT(2, 8)
+#  undef HAVE_READAHEAD
+# endif /* glibc < 2.8 */
 /*
  * glibc < 2.25 had an incorrect implementation on mips n64,
  * see https://sourceware.org/bugzilla/show_bug.cgi?id=21026
  */
-#  if defined LINUX_MIPSN64 && !(defined __GLIBC_MINOR__ && \
-	(__GLIBC__ << 16) + __GLIBC_MINOR__ >= (2 << 16) + 25)
-#   undef HAVE_READAHEAD
-#  endif /* LINUX_MIPSN64 && glibc < 2.25 */
-# endif /* __GLIBC__ */
+# if GLIBC_PREREQ_LT(2, 25) && defined LINUX_MIPSN64
+#  undef HAVE_READAHEAD
+# endif /* LINUX_MIPSN64 && glibc < 2.25 */
 #endif /* HAVE_READAHEAD */
 
 #ifdef HAVE_READAHEAD
diff -pruN 5.5-3/tests-mx32/read-write.c 5.9-0ubuntu2/tests-mx32/read-write.c
--- 5.5-3/tests-mx32/read-write.c	2019-07-16 17:46:47.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/read-write.c	2020-04-07 00:57:01.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding and dumping of read and write syscalls.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -153,9 +153,17 @@ main(void)
 	skip_if_unavailable("/proc/self/fd/");
 
 	static const char tmp[] = "read-write-tmpfile";
-	if (open(tmp, O_CREAT|O_RDONLY|O_TRUNC, 0600) != 0)
+	bool need_cleanup = true;
+	long rc;
+
+	rc = open(tmp, O_RDONLY, 0600);
+	if (rc < 0) {
+		rc = open(tmp, O_CREAT|O_EXCL|O_RDONLY, 0600);
+		need_cleanup = false;
+	}
+	if (rc != 0)
 		perror_msg_and_fail("creat: %s", tmp);
-	if (open(tmp, O_WRONLY) != 1)
+	if (open(tmp, O_TRUNC|O_WRONLY) != 1)
 		perror_msg_and_fail("open: %s", tmp);
 
 	static const char w_c[] = "0123456789abcde";
@@ -175,8 +183,6 @@ main(void)
 
 	void *efault = r1 - get_page_size();
 
-	long rc;
-
 	rc = k_write(1, w, 0);
 	if (rc)
 		perror_msg_and_fail("write: expected 0, returned %ld", rc);
@@ -270,9 +276,11 @@ main(void)
 	if (open("/dev/null", O_WRONLY) != 1)
 		perror_msg_and_fail("open");
 
+	(void) close(4);
 	if (open("/dev/zero", O_RDONLY) != 4)
 		perror_msg_and_fail("open");
 
+	(void) close(5);
 	if (open("/dev/null", O_WRONLY) != 5)
 		perror_msg_and_fail("open");
 
@@ -282,6 +290,9 @@ main(void)
 
 	test_dump(256, true);
 
+	if (need_cleanup && unlink(tmp))
+		perror_msg_and_fail("unlink: %s", tmp);
+
 	tprintf("+++ exited with 0 +++\n");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/redirect.test 5.9-0ubuntu2/tests-mx32/redirect.test
--- 5.5-3/tests-mx32/redirect.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/redirect.test	2020-04-07 00:57:01.000000000 +0000
@@ -3,7 +3,7 @@
 # Ensure that strace does not retain stdin and stdout descriptors.
 #
 # Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -16,42 +16,34 @@ run_prog_skip_if_failed \
 check_prog sleep
 check_prog yes
 
+SLEEP_3_BITS="$SLEEP_A_BIT; $SLEEP_A_BIT; $SLEEP_A_BIT"
 > "$OUT"
-> "$LOG"
+
+> lock1
+> lock2
 (
-	while [ -f "$LOG" ]; do
-		:
+	while [ -f lock1 ]; do
+		$SLEEP_A_BIT
 	done
-	$SLEEP_A_BIT &
 	yes
-	if kill -0 $! 2> /dev/null; then
-		wait
-	else
-		echo TIMEOUT >> "$OUT"
-	fi
+	[ -f lock2 ] ||
+		printf ' input' >> "$OUT"
 ) | $STRACE -qq -enone -esignal=none \
-	sh -c "exec <&- >&-; rm -f -- $LOG; $SLEEP_A_BIT; $SLEEP_A_BIT"
-
-if [ -s "$OUT" ]; then
-	fail_ "$STRACE failed to redirect standard input"
-fi
+	sh -c "exec <&- >&-; rm -f lock1; $SLEEP_3_BITS; rm -f lock2"
 
-> "$LOG"
+> lock1
+> lock2
 $STRACE -qq -enone -esignal=none \
-	sh -c "exec <&- >&-; rm -f -- $LOG; $SLEEP_A_BIT; $SLEEP_A_BIT" |
+	sh -c "exec <&- >&-; rm -f lock1; $SLEEP_3_BITS; rm -f lock2" |
 (
-	while [ -f "$LOG" ]; do
-		:
+	while [ -f lock1 ]; do
+		$SLEEP_A_BIT
 	done
-	$SLEEP_A_BIT &
 	cat > /dev/null
-	if kill -0 $! 2> /dev/null; then
-		wait
-	else
-		echo TIMEOUT >> "$OUT"
-	fi
+	[ -f lock2 ] ||
+		printf ' output' >> "$OUT"
 )
 
 if [ -s "$OUT" ]; then
-	fail_ "$STRACE failed to redirect standard output"
+	fail_ "$STRACE failed to redirect standard descriptors:$(cat "$OUT")"
 fi
diff -pruN 5.5-3/tests-mx32/rt_sigqueueinfo.c 5.9-0ubuntu2/tests-mx32/rt_sigqueueinfo.c
--- 5.5-3/tests-mx32/rt_sigqueueinfo.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/rt_sigqueueinfo.c	2020-08-25 14:29:30.000000000 +0000
@@ -1,12 +1,13 @@
 /*
  * Copyright (c) 2015 Elvira Khabirova <lineprinter0@gmail.com>
- * Copyright (c) 2015-2018 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include "pidns.h"
 #include <assert.h>
 #include <stdio.h>
 #include <signal.h>
@@ -15,6 +16,8 @@
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	struct sigaction sa = {
 		.sa_handler = SIG_IGN
 	};
@@ -22,15 +25,19 @@ main(void)
 		.sival_ptr = (void *) (unsigned long) 0xdeadbeefbadc0dedULL
 	};
 	pid_t pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
 
 	assert(sigaction(SIGUSR1, &sa, NULL) == 0);
 	if (sigqueue(pid, SIGUSR1, value))
 		perror_msg_and_skip("sigqueue");
-	printf("rt_sigqueueinfo(%u, SIGUSR1, {si_signo=SIGUSR1, "
-		"si_code=SI_QUEUE, si_pid=%u, si_uid=%u, "
+	pidns_print_leader();
+	printf("rt_sigqueueinfo(%d%s, SIGUSR1, {si_signo=SIGUSR1, "
+		"si_code=SI_QUEUE, si_pid=%d%s, si_uid=%u, "
 		"si_value={int=%d, ptr=%p}}) = 0\n",
-		pid, pid, getuid(), value.sival_int, value.sival_ptr);
-	printf("+++ exited with 0 +++\n");
+		pid, pid_str, pid, pid_str,
+		getuid(), value.sival_int, value.sival_ptr);
+	pidns_print_leader();
+	puts("+++ exited with 0 +++");
 
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/rt_sigqueueinfo--pidns-translation.c 5.9-0ubuntu2/tests-mx32/rt_sigqueueinfo--pidns-translation.c
--- 5.5-3/tests-mx32/rt_sigqueueinfo--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/rt_sigqueueinfo--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "rt_sigqueueinfo.c"
diff -pruN 5.5-3/tests-mx32/rt_sigqueueinfo--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/rt_sigqueueinfo--pidns-translation.gen.test
--- 5.5-3/tests-mx32/rt_sigqueueinfo--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/rt_sigqueueinfo--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (rt_sigqueueinfo--pidns-translation test_pidns -esignal=none -e trace=rt_sigqueueinfo); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -esignal=none -e trace=rt_sigqueueinfo
diff -pruN 5.5-3/tests-mx32/rt_tgsigqueueinfo.c 5.9-0ubuntu2/tests-mx32/rt_tgsigqueueinfo.c
--- 5.5-3/tests-mx32/rt_tgsigqueueinfo.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/rt_tgsigqueueinfo.c	2020-08-25 14:29:30.000000000 +0000
@@ -2,7 +2,7 @@
  * This file is part of rt_tgsigqueueinfo strace test.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,8 +10,9 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
-#ifdef __NR_rt_tgsigqueueinfo
+#if defined __NR_rt_tgsigqueueinfo && defined __NR_gettid
 
 # include <errno.h>
 # include <signal.h>
@@ -20,11 +21,11 @@
 # include <unistd.h>
 
 static long
-k_tgsigqueueinfo(const pid_t pid, const int sig, const void *const info)
+k_tgsigqueueinfo(const pid_t tgid, const int tid, const int sig, const void *const info)
 {
 	return syscall(__NR_rt_tgsigqueueinfo,
-		       F8ILL_KULONG_MASK | pid,
-		       F8ILL_KULONG_MASK | pid,
+		       F8ILL_KULONG_MASK | tgid,
+		       F8ILL_KULONG_MASK | tid,
 		       F8ILL_KULONG_MASK | sig,
 		       info);
 }
@@ -32,6 +33,8 @@ k_tgsigqueueinfo(const pid_t pid, const
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	const struct sigaction sa = {
 		.sa_handler = SIG_IGN
 	};
@@ -48,17 +51,22 @@ main(void)
 	info->si_value.sival_ptr =
 		(void *) (unsigned long) 0xdeadbeeffacefeedULL;
 
-	if (k_tgsigqueueinfo(info->si_pid, SIGUSR1, info))
+	if (k_tgsigqueueinfo(getpid(), syscall(__NR_gettid), SIGUSR1, info))
 		(errno == ENOSYS ? perror_msg_and_skip : perror_msg_and_fail)(
 			"rt_tgsigqueueinfo");
 
-	printf("rt_tgsigqueueinfo(%u, %u, %s, {si_signo=%s"
-		", si_code=SI_QUEUE, si_errno=ENOENT, si_pid=%u"
-		", si_uid=%u, si_value={int=%d, ptr=%p}}) = 0\n",
-		info->si_pid, info->si_pid, "SIGUSR1", "SIGUSR1",
-		info->si_pid, info->si_uid, info->si_value.sival_int,
+	pidns_print_leader();
+	printf("rt_tgsigqueueinfo(%d%s, %d%s, %s, {si_signo=%s"
+		", si_code=SI_QUEUE, si_errno=ENOENT, si_pid=%d%s"
+		", si_uid=%d, si_value={int=%d, ptr=%p}}) = 0\n",
+		info->si_pid, pidns_pid2str(PT_TGID),
+		info->si_pid, pidns_pid2str(PT_TID),
+		"SIGUSR1", "SIGUSR1",
+		info->si_pid, pidns_pid2str(PT_TGID),
+		info->si_uid, info->si_value.sival_int,
 		info->si_value.sival_ptr);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/rt_tgsigqueueinfo--pidns-translation.c 5.9-0ubuntu2/tests-mx32/rt_tgsigqueueinfo--pidns-translation.c
--- 5.5-3/tests-mx32/rt_tgsigqueueinfo--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/rt_tgsigqueueinfo--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "rt_tgsigqueueinfo.c"
diff -pruN 5.5-3/tests-mx32/rt_tgsigqueueinfo--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/rt_tgsigqueueinfo--pidns-translation.gen.test
--- 5.5-3/tests-mx32/rt_tgsigqueueinfo--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/rt_tgsigqueueinfo--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (rt_tgsigqueueinfo--pidns-translation test_pidns -esignal=none -e trace=rt_tgsigqueueinfo); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -esignal=none -e trace=rt_tgsigqueueinfo
diff -pruN 5.5-3/tests-mx32/s390_sthyi.c 5.9-0ubuntu2/tests-mx32/s390_sthyi.c
--- 5.5-3/tests-mx32/s390_sthyi.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/s390_sthyi.c	2020-07-24 08:00:00.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Check decoding of s390_sthyi syscall.
  *
- * Copyright (c) 2018-2019 The strace developers.
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -113,7 +113,7 @@ ebcdic2ascii(unsigned char *ebcdic, size
 				   size, sizeof(ascii_buf));
 	if (cd == (iconv_t) -1)
 		perror_msg_and_fail("ebcdic2ascii: unable to allocate a "
-				    "conversion descriptior for converting "
+				    "conversion descriptor for converting "
 				    "EBCDIC to ASCII");
 
 	while ((ret = iconv(cd, &ebcdic_pos, &ebcdic_left,
@@ -509,7 +509,7 @@ print_sthyi(unsigned char *buf)
 	hdr_size = *(uint16_t *) (buf + 10);
 	if (hdr_size < 44)
 		error_msg_and_fail("sthyi: header section is too small "
-			           "(got %hu, 44 expected)", hdr_size);
+				   "(got %hu, >=44 expected)", hdr_size);
 
 	/* INFHFLG1 */
 	print_0x8("{/* header */ {infhflg1", buf, 0, true);
@@ -598,7 +598,7 @@ print_sthyi(unsigned char *buf)
 	hdr_size = *(uint16_t *) (buf + 14);
 	if (hdr_size < 60)
 		error_msg_and_fail("sthyi: machine section is too small "
-			           "(got %hu, 60 expected)", hdr_size);
+				   "(got %hu, >=60 expected)", hdr_size);
 
 	cur = buf + offs;
 
@@ -670,9 +670,9 @@ partition_hdr:
 		goto hv_hdr;
 
 	hdr_size = *(uint16_t *) (buf + 18);
-	if (hdr_size < 56)
+	if (hdr_size < 40)
 		error_msg_and_fail("sthyi: partition section is too small "
-			           "(got %hu, 56 expected)", hdr_size);
+				   "(got %hu, >=40 expected)", hdr_size);
 
 	cur = buf + offs;
 
@@ -741,18 +741,18 @@ partition_hdr:
 	print_weight(", infpwbif", cur, 32, pwcap_valid);
 	print_weight(", infpabif", cur, 36, pacap_valid);
 
-	if (print_ebcdic(", infplgnm", cur, 40, 8, false, false)) {
-
-		print_weight(", infplgcp", cur, 48, false);
-		print_weight(", infplgif", cur, 52, false);
-	} else {
-		if (lpar_valid) {
-			printf(", infplgnm=");
-			print_quoted_hex((char *) (cur + 40), 8);
+	if (hdr_size >= 56) {
+		if (print_ebcdic(", infplgnm", cur, 40, 8, false, false)) {
+			print_weight(", infplgcp", cur, 48, false);
+			print_weight(", infplgif", cur, 52, false);
+		} else {
+			if (lpar_valid) {
+				printf(", infplgnm=");
+				print_quoted_hex((char *) (cur + 40), 8);
+			}
+			print_x32(", infplgcp", cur, 48, false);
+			print_x32(", infplgif", cur, 52, false);
 		}
-
-		print_x32(", infplgcp", cur, 48, false);
-		print_x32(", infplgif", cur, 52, false);
 	}
 
 	if (hdr_size >= 64) {
diff -pruN 5.5-3/tests-mx32/sched_xetaffinity.c 5.9-0ubuntu2/tests-mx32/sched_xetaffinity.c
--- 5.5-3/tests-mx32/sched_xetaffinity.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/sched_xetaffinity.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,7 +2,7 @@
  * This file is part of sched_xetaffinity strace test.
  *
  * Copyright (c) 2016-2018 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,6 +10,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 #include <sched.h>
 
 #if defined __NR_sched_getaffinity && defined __NR_sched_setaffinity \
@@ -41,8 +42,11 @@ setaffinity(unsigned long pid, unsigned
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	unsigned int cpuset_size = 1;
 	const pid_t pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
 
 	while (cpuset_size) {
 		assert(getaffinity(pid, cpuset_size, NULL) == -1);
@@ -50,18 +54,21 @@ main(void)
 			break;
 		if (EINVAL != errno)
 			perror_msg_and_skip("sched_getaffinity");
-		printf("sched_getaffinity(%d, %u, NULL) = %s\n",
-		       pid, cpuset_size, errstr);
+		pidns_print_leader();
+		printf("sched_getaffinity(%d%s, %u, NULL) = %s\n",
+		       pid, pid_str, cpuset_size, errstr);
 		cpuset_size <<= 1;
 	}
 	assert(cpuset_size);
-	printf("sched_getaffinity(%d, %u, NULL) = %s\n",
-	       pid, cpuset_size, errstr);
+	pidns_print_leader();
+	printf("sched_getaffinity(%d%s, %u, NULL) = %s\n",
+	       pid, pid_str, cpuset_size, errstr);
 
 	cpu_set_t *cpuset = tail_alloc(cpuset_size);
 	getaffinity(pid, cpuset_size, cpuset + 1);
-	printf("sched_getaffinity(%d, %u, %p) = %s\n",
-	       pid, cpuset_size, cpuset + 1, errstr);
+	pidns_print_leader();
+	printf("sched_getaffinity(%d%s, %u, %p) = %s\n",
+	       pid, pid_str, cpuset_size, cpuset + 1, errstr);
 
 	int ret_size = getaffinity(pid, cpuset_size, cpuset);
 	if (ret_size < 0)
@@ -69,7 +76,8 @@ main(void)
 				    pid, (unsigned) cpuset_size, cpuset, errstr);
 	assert(ret_size <= (int) cpuset_size);
 
-	printf("sched_getaffinity(%d, %u, [", pid, cpuset_size);
+	pidns_print_leader();
+	printf("sched_getaffinity(%d%s, %u, [", pid, pid_str, cpuset_size);
 	const char *sep;
 	unsigned int i, cpu;
 	for (i = 0, cpu = 0, sep = ""; i < (unsigned) ret_size * 8; ++i) {
@@ -85,8 +93,9 @@ main(void)
 	CPU_SET_S(cpu, cpuset_size, cpuset);
 	if (setaffinity(pid, cpuset_size, cpuset))
 		perror_msg_and_skip("sched_setaffinity");
-	printf("sched_setaffinity(%d, %u, [%u]) = 0\n",
-	       pid, cpuset_size, cpu);
+	pidns_print_leader();
+	printf("sched_setaffinity(%d%s, %u, [%u]) = 0\n",
+	       pid, pid_str, cpuset_size, cpu);
 
 	const unsigned int big_size = cpuset_size < 128 ? 128 : cpuset_size * 2;
 	cpuset = tail_alloc(big_size);
@@ -95,7 +104,8 @@ main(void)
 		perror_msg_and_fail("sched_getaffinity(%d, %u, %p) = %s\n",
 				    pid, big_size, cpuset, errstr);
 	assert(ret_size <= (int) big_size);
-	printf("sched_getaffinity(%d, %u, [", pid, big_size);
+	pidns_print_leader();
+	printf("sched_getaffinity(%d%s, %u, [", pid, pid_str, big_size);
 	for (i = 0, sep = ""; i < (unsigned) ret_size * 8; ++i) {
 		if (CPU_ISSET_S(i, (unsigned) ret_size, cpuset)) {
 			printf("%s%u", sep, i);
@@ -104,6 +114,7 @@ main(void)
 	}
 	printf("]) = %s\n", errstr);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/sched_xetaffinity--pidns-translation.c 5.9-0ubuntu2/tests-mx32/sched_xetaffinity--pidns-translation.c
--- 5.5-3/tests-mx32/sched_xetaffinity--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/sched_xetaffinity--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "sched_xetaffinity.c"
diff -pruN 5.5-3/tests-mx32/sched_xetaffinity--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/sched_xetaffinity--pidns-translation.gen.test
--- 5.5-3/tests-mx32/sched_xetaffinity--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/sched_xetaffinity--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (sched_xetaffinity--pidns-translation test_pidns -a28 -e trace=sched_getaffinity,sched_setaffinity); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a28 -e trace=sched_getaffinity,sched_setaffinity
diff -pruN 5.5-3/tests-mx32/sched_xetattr.c 5.9-0ubuntu2/tests-mx32/sched_xetattr.c
--- 5.5-3/tests-mx32/sched_xetattr.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/sched_xetattr.c	2020-08-25 14:29:30.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2017 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -15,6 +15,7 @@
 # include <stdio.h>
 # include <sched.h>
 # include <unistd.h>
+# include "pidns.h"
 # include "sched_attr.h"
 # include "xlat.h"
 # include "xlat/schedulers.h"
@@ -41,6 +42,8 @@ sys_sched_setattr(kernel_ulong_t pid, ke
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	static const kernel_ulong_t bogus_pid =
 		(kernel_ulong_t) 0xdefacedfacefeedULL;
 	static const kernel_ulong_t bogus_size =
@@ -48,20 +51,28 @@ main(void)
 	static const kernel_ulong_t bogus_flags =
 		(kernel_ulong_t) 0xdefaceddeadc0deULL;
 
+	const int pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
+
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct sched_attr, attr);
 	TAIL_ALLOC_OBJECT_CONST_PTR(unsigned int, psize);
 	void *const efault = attr + 1;
 
-	sys_sched_getattr(0, 0, 0, 0);
-	printf("sched_getattr(0, NULL, 0, 0) = %s\n", errstr);
+	sys_sched_getattr(pid, 0, 0, 0);
+	pidns_print_leader();
+	printf("sched_getattr(%d%s, NULL, 0, 0) = %s\n",
+		pid, pid_str, errstr);
 
 	sys_sched_getattr(0, (unsigned long) attr, 0, 0);
+	pidns_print_leader();
 	printf("sched_getattr(0, %p, 0, 0) = %s\n", attr, errstr);
 
 	sys_sched_getattr(bogus_pid, 0, 0, 0);
+	pidns_print_leader();
 	printf("sched_getattr(%d, NULL, 0, 0) = %s\n", (int) bogus_pid, errstr);
 
 	sys_sched_getattr(-1U, (unsigned long) attr, bogus_size, bogus_flags);
+	pidns_print_leader();
 	printf("sched_getattr(-1, %p, %s%u, %u) = %s\n",
 	       attr,
 # if defined __arm64__ || defined __aarch64__
@@ -71,24 +82,52 @@ main(void)
 # endif
 	       (unsigned) bogus_size, (unsigned) bogus_flags, errstr);
 
+	sys_sched_getattr(0, (unsigned long) efault, SCHED_ATTR_MIN_SIZE, 0);
+	pidns_print_leader();
+	printf("sched_getattr(0, %p, %u, 0) = %s\n",
+	       efault, (unsigned) SCHED_ATTR_MIN_SIZE, errstr);
+
+	if (sys_sched_getattr(0, (unsigned long) attr, SCHED_ATTR_MIN_SIZE, 0))
+		perror_msg_and_skip("sched_getattr");
+	pidns_print_leader();
+	printf("sched_getattr(0, {size=%u, sched_policy=", attr->size);
+	printxval(schedulers, attr->sched_policy, NULL);
+	printf(", sched_flags=%s, sched_nice=%d, sched_priority=%u"
+	       ", sched_runtime=%" PRIu64 ", sched_deadline=%" PRIu64
+	       ", sched_period=%" PRIu64 "}, %u, 0) = 0\n",
+	       attr->sched_flags ? "SCHED_FLAG_RESET_ON_FORK" : "0",
+	       attr->sched_nice,
+	       attr->sched_priority,
+	       attr->sched_runtime,
+	       attr->sched_deadline,
+	       attr->sched_period,
+	       (unsigned) SCHED_ATTR_MIN_SIZE);
+
 	sys_sched_getattr(0, (unsigned long) efault, sizeof(*attr), 0);
+	pidns_print_leader();
 	printf("sched_getattr(0, %p, %u, 0) = %s\n",
 	       efault, (unsigned) sizeof(*attr), errstr);
 
 	if (sys_sched_getattr(0, (unsigned long) attr, sizeof(*attr), 0))
 		perror_msg_and_skip("sched_getattr");
+	pidns_print_leader();
 	printf("sched_getattr(0, {size=%u, sched_policy=", attr->size);
 	printxval(schedulers, attr->sched_policy, NULL);
 	printf(", sched_flags=%s, sched_nice=%d, sched_priority=%u"
 	       ", sched_runtime=%" PRIu64 ", sched_deadline=%" PRIu64
-	       ", sched_period=%" PRIu64 "}, %u, 0) = 0\n",
+	       ", sched_period=%" PRIu64,
 	       attr->sched_flags ? "SCHED_FLAG_RESET_ON_FORK" : "0",
 	       attr->sched_nice,
 	       attr->sched_priority,
 	       attr->sched_runtime,
 	       attr->sched_deadline,
-	       attr->sched_period,
-	       (unsigned) sizeof(*attr));
+	       attr->sched_period);
+	if (attr->size >= SCHED_ATTR_SIZE_VER1) {
+		printf(", sched_util_min=%u, sched_util_max=%u",
+		       attr->sched_util_min,
+		       attr->sched_util_max);
+	}
+	printf("}, %u, 0) = 0\n", (unsigned) sizeof(*attr));
 
 # if defined __arm64__ || defined __aarch64__
 	long rc =
@@ -97,66 +136,91 @@ main(void)
 			  F8ILL_KULONG_MASK | sizeof(*attr), F8ILL_KULONG_MASK);
 # if defined __arm64__ || defined __aarch64__
 	if (rc) {
+		pidns_print_leader();
 		printf("sched_getattr(0, %p, 0xffffffff<<32|%u, 0) = %s\n",
 		       attr, (unsigned) sizeof(*attr), errstr);
 	} else
 # endif
 	{
+		pidns_print_leader();
 		printf("sched_getattr(0, {size=%u, sched_policy=", attr->size);
 		printxval(schedulers, attr->sched_policy, NULL);
 		printf(", sched_flags=%s, sched_nice=%d, sched_priority=%u"
 		       ", sched_runtime=%" PRIu64 ", sched_deadline=%" PRIu64
-		       ", sched_period=%" PRIu64 "}, %u, 0) = 0\n",
+		       ", sched_period=%" PRIu64,
 		       attr->sched_flags ? "SCHED_FLAG_RESET_ON_FORK" : "0",
 		       attr->sched_nice,
 		       attr->sched_priority,
 		       attr->sched_runtime,
 		       attr->sched_deadline,
-		       attr->sched_period,
-		       (unsigned) sizeof(*attr));
+		       attr->sched_period);
+		if (attr->size >= SCHED_ATTR_SIZE_VER1) {
+			printf(", sched_util_min=%u, sched_util_max=%u",
+			       attr->sched_util_min,
+			       attr->sched_util_max);
+		}
+		printf("}, %u, 0) = 0\n", (unsigned) sizeof(*attr));
 	}
 
 	sys_sched_setattr(bogus_pid, 0, 0);
+	pidns_print_leader();
 	printf("sched_setattr(%d, NULL, 0) = %s\n", (int) bogus_pid, errstr);
 
 	attr->sched_flags |= 1;
 
-	if (sys_sched_setattr(0, (unsigned long) attr, 0))
+	if (sys_sched_setattr(pid, (unsigned long) attr, 0))
 		perror_msg_and_skip("sched_setattr");
-	printf("sched_setattr(0, {size=%u, sched_policy=", attr->size);
+	pidns_print_leader();
+	printf("sched_setattr(%d%s, {size=%u, sched_policy=",
+		pid, pid_str, attr->size);
 	printxval(schedulers, attr->sched_policy, NULL);
 	printf(", sched_flags=%s, sched_nice=%d, sched_priority=%u"
 	       ", sched_runtime=%" PRIu64 ", sched_deadline=%" PRIu64
-	       ", sched_period=%" PRIu64 "}, 0) = 0\n",
+	       ", sched_period=%" PRIu64,
 	       "SCHED_FLAG_RESET_ON_FORK",
 	       attr->sched_nice,
 	       attr->sched_priority,
 	       attr->sched_runtime,
 	       attr->sched_deadline,
 	       attr->sched_period);
+	if (attr->size >= SCHED_ATTR_SIZE_VER1) {
+		printf(", sched_util_min=%u, sched_util_max=%u",
+		       attr->sched_util_min,
+		       attr->sched_util_max);
+	}
+	printf("}, 0) = 0\n");
 
 	sys_sched_setattr(F8ILL_KULONG_MASK, (unsigned long) attr,
 			  F8ILL_KULONG_MASK);
+	pidns_print_leader();
 	printf("sched_setattr(0, {size=%u, sched_policy=", attr->size);
 	printxval(schedulers, attr->sched_policy, NULL);
 	printf(", sched_flags=%s, sched_nice=%d, sched_priority=%u"
 	       ", sched_runtime=%" PRIu64 ", sched_deadline=%" PRIu64
-	       ", sched_period=%" PRIu64 "}, 0) = 0\n",
+	       ", sched_period=%" PRIu64,
 	       "SCHED_FLAG_RESET_ON_FORK",
 	       attr->sched_nice,
 	       attr->sched_priority,
 	       attr->sched_runtime,
 	       attr->sched_deadline,
 	       attr->sched_period);
+	if (attr->size >= SCHED_ATTR_SIZE_VER1) {
+		printf(", sched_util_min=%u, sched_util_max=%u",
+		       attr->sched_util_min,
+		       attr->sched_util_max);
+	}
+	printf("}, 0) = 0\n");
 
 	*psize = attr->size;
 
 	sys_sched_setattr(0, (unsigned long) psize, 0);
+	pidns_print_leader();
 	printf("sched_setattr(0, %p, 0) = %s\n", psize, errstr);
 
 	attr->size = 0;
 
 	sys_sched_setattr(0, (unsigned long) attr, 0);
+	pidns_print_leader();
 	printf("sched_setattr(0, {size=%u, sched_policy=", attr->size);
 	printxval(schedulers, attr->sched_policy, NULL);
 	printf(", sched_flags=%s, sched_nice=%d, sched_priority=%u"
@@ -172,18 +236,20 @@ main(void)
 	attr->size = 1;
 
 	sys_sched_setattr(0, (unsigned long) attr, 0);
+	pidns_print_leader();
 	printf("sched_setattr(0, {size=%u} => {size=%u}, 0) = %s\n",
 	       1, attr->size, errstr);
 
 	attr->size = SCHED_ATTR_MIN_SIZE - 1;
 
 	sys_sched_setattr(0, (unsigned long) attr, 0);
+	pidns_print_leader();
 	printf("sched_setattr(0, {size=%u} => {size=%u}, 0) = %s\n",
 	       SCHED_ATTR_MIN_SIZE - 1, attr->size, errstr);
 
 	attr->size = 0x90807060;
 	attr->sched_policy = 0xca7faced;
-	attr->sched_flags = 0xbadc0ded1057da78ULL;
+	attr->sched_flags = 0xbadc0ded1057da80ULL;
 	attr->sched_nice = 0xafbfcfdf;
 	attr->sched_priority = 0xb8c8d8e8;
 	attr->sched_runtime = 0xbadcaffedeadf157ULL;
@@ -191,11 +257,12 @@ main(void)
 	attr->sched_period = 0xded1ca7edda7aca7ULL;
 
 	sys_sched_setattr(bogus_pid, (unsigned long) attr, bogus_flags);
+	pidns_print_leader();
 	printf("sched_setattr(%d, {size=%u, sched_policy=%#x /* SCHED_??? */, "
 	       "sched_flags=%#" PRIx64 " /* SCHED_FLAG_??? */, "
 	       "sched_nice=%d, sched_priority=%u, sched_runtime=%" PRIu64 ", "
-	       "sched_deadline=%" PRIu64 ", sched_period=%" PRIu64 ", ...}, %u)"
-	       " = %s\n",
+	       "sched_deadline=%" PRIu64 ", sched_period=%" PRIu64 ", "
+	       "sched_util_min=%u, sched_util_max=%u, ...}, %u) = %s\n",
 	       (int) bogus_pid,
 	       attr->size,
 	       attr->sched_policy,
@@ -205,6 +272,8 @@ main(void)
 	       attr->sched_runtime,
 	       attr->sched_deadline,
 	       attr->sched_period,
+	       attr->sched_util_min,
+	       attr->sched_util_max,
 	       (unsigned) bogus_flags, errstr);
 
 	if (F8ILL_KULONG_SUPPORTED) {
@@ -223,7 +292,7 @@ main(void)
 
 	attr->size = 0x90807060;
 	attr->sched_policy = 0xca7faced;
-	attr->sched_flags = 0xfULL;
+	attr->sched_flags = 0x87ULL;
 	attr->sched_nice = 0xafbfcfdf;
 	attr->sched_priority = 0xb8c8d8e8;
 	attr->sched_runtime = 0xbadcaffedeadf157ULL;
@@ -231,35 +300,143 @@ main(void)
 	attr->sched_period = 0xded1ca7edda7aca7ULL;
 
 	sys_sched_setattr(bogus_pid, (unsigned long) attr, bogus_flags);
+	pidns_print_leader();
 	printf("sched_setattr(%d, {size=%u, sched_policy=%#x /* SCHED_??? */, "
 	       "sched_flags=SCHED_FLAG_RESET_ON_FORK|SCHED_FLAG_RECLAIM|"
-	       "SCHED_FLAG_DL_OVERRUN|0x8, "
+	       "SCHED_FLAG_DL_OVERRUN|0x80, "
+	       "sched_nice=%d, sched_priority=%u, sched_runtime=%" PRIu64 ", "
+	       "sched_deadline=%" PRIu64 ", sched_period=%" PRIu64 ", "
+	       "sched_util_min=%u, sched_util_max=%u, ...}, %u) = %s\n",
+	       (int) bogus_pid,
+	       attr->size,
+	       attr->sched_policy,
+	       attr->sched_nice,
+	       attr->sched_priority,
+	       attr->sched_runtime,
+	       attr->sched_deadline,
+	       attr->sched_period,
+	       attr->sched_util_min,
+	       attr->sched_util_max,
+	       (unsigned) bogus_flags, errstr);
+
+	if (F8ILL_KULONG_SUPPORTED) {
+		const kernel_ulong_t ill = f8ill_ptr_to_kulong(attr);
+
+		sys_sched_getattr(0, ill, sizeof(*attr), 0);
+		pidns_print_leader();
+		printf("sched_getattr(0, %#llx, %u, 0) = %s\n",
+		       (unsigned long long) ill, (unsigned) sizeof(*attr),
+		       errstr);
+
+		sys_sched_setattr(0, ill, 0);
+		pidns_print_leader();
+		printf("sched_setattr(0, %#llx, 0) = %s\n",
+		       (unsigned long long) ill, errstr);
+	}
+
+	attr->size = SCHED_ATTR_MIN_SIZE;
+	attr->sched_policy = 0xdefaced;
+	attr->sched_flags = 0x8fULL;
+
+	sys_sched_setattr(bogus_pid, (unsigned long) attr, bogus_flags);
+	pidns_print_leader();
+	printf("sched_setattr(%d, {size=%u, "
+	       "sched_flags=SCHED_FLAG_RESET_ON_FORK|SCHED_FLAG_RECLAIM|"
+	       "SCHED_FLAG_DL_OVERRUN|SCHED_FLAG_KEEP_POLICY|0x80, "
 	       "sched_nice=%d, sched_priority=%u, sched_runtime=%" PRIu64 ", "
-	       "sched_deadline=%" PRIu64 ", sched_period=%" PRIu64 ", ...}, %u)"
+	       "sched_deadline=%" PRIu64 ", sched_period=%" PRIu64 "}, %u)"
 	       " = %s\n",
 	       (int) bogus_pid,
 	       attr->size,
+	       attr->sched_nice,
+	       attr->sched_priority,
+	       attr->sched_runtime,
+	       attr->sched_deadline,
+	       attr->sched_period,
+	       (unsigned) bogus_flags, errstr);
+
+	if (F8ILL_KULONG_SUPPORTED) {
+		const kernel_ulong_t ill = f8ill_ptr_to_kulong(attr);
+
+		sys_sched_getattr(0, ill, sizeof(*attr), 0);
+		pidns_print_leader();
+		printf("sched_getattr(0, %#llx, %u, 0) = %s\n",
+		       (unsigned long long) ill, (unsigned) sizeof(*attr),
+		       errstr);
+
+		sys_sched_setattr(0, ill, 0);
+		pidns_print_leader();
+		printf("sched_setattr(0, %#llx, 0) = %s\n",
+		       (unsigned long long) ill, errstr);
+	}
+
+	attr->size = SCHED_ATTR_SIZE_VER1;
+	attr->sched_flags = 0xe7ULL;
+
+	sys_sched_setattr(bogus_pid, (unsigned long) attr, bogus_flags);
+	pidns_print_leader();
+	printf("sched_setattr(%d, {size=%u, sched_policy=%#x /* SCHED_??? */, "
+	       "sched_flags=SCHED_FLAG_RESET_ON_FORK|SCHED_FLAG_RECLAIM|"
+	       "SCHED_FLAG_DL_OVERRUN|SCHED_FLAG_UTIL_CLAMP_MIN"
+	       "|SCHED_FLAG_UTIL_CLAMP_MAX|0x80, "
+	       "sched_nice=%d, sched_priority=%u, sched_runtime=%" PRIu64 ", "
+	       "sched_deadline=%" PRIu64 ", sched_period=%" PRIu64 ", "
+	       "sched_util_min=%u, sched_util_max=%u}, %u) = %s\n",
+	       (int) bogus_pid,
+	       attr->size,
 	       attr->sched_policy,
 	       attr->sched_nice,
 	       attr->sched_priority,
 	       attr->sched_runtime,
 	       attr->sched_deadline,
 	       attr->sched_period,
+	       attr->sched_util_min,
+	       attr->sched_util_max,
+	       (unsigned) bogus_flags, errstr);
+
+	if (F8ILL_KULONG_SUPPORTED) {
+		const kernel_ulong_t ill = f8ill_ptr_to_kulong(attr);
+
+		sys_sched_getattr(0, ill, sizeof(*attr), 0);
+		pidns_print_leader();
+		printf("sched_getattr(0, %#llx, %u, 0) = %s\n",
+		       (unsigned long long) ill, (unsigned) sizeof(*attr),
+		       errstr);
+
+		sys_sched_setattr(0, ill, 0);
+		pidns_print_leader();
+		printf("sched_setattr(0, %#llx, 0) = %s\n",
+		       (unsigned long long) ill, errstr);
+	}
+
+	attr->sched_flags = 0xcaffee90LL;
+
+	sys_sched_setattr(bogus_pid, (unsigned long) attr, bogus_flags);
+	pidns_print_leader();
+	printf("sched_setattr(%d, {size=%u, sched_flags=SCHED_FLAG_KEEP_PARAMS"
+	       "|0xcaffee80, sched_util_min=%u, sched_util_max=%u}, %u) = %s\n",
+	       (int) bogus_pid,
+	       attr->size,
+	       attr->sched_util_min,
+	       attr->sched_util_max,
 	       (unsigned) bogus_flags, errstr);
 
 	if (F8ILL_KULONG_SUPPORTED) {
 		const kernel_ulong_t ill = f8ill_ptr_to_kulong(attr);
 
 		sys_sched_getattr(0, ill, sizeof(*attr), 0);
+		pidns_print_leader();
 		printf("sched_getattr(0, %#llx, %u, 0) = %s\n",
 		       (unsigned long long) ill, (unsigned) sizeof(*attr),
 		       errstr);
 
 		sys_sched_setattr(0, ill, 0);
+		pidns_print_leader();
 		printf("sched_setattr(0, %#llx, 0) = %s\n",
 		       (unsigned long long) ill, errstr);
 	}
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/sched_xetattr--pidns-translation.c 5.9-0ubuntu2/tests-mx32/sched_xetattr--pidns-translation.c
--- 5.5-3/tests-mx32/sched_xetattr--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/sched_xetattr--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "sched_xetattr.c"
diff -pruN 5.5-3/tests-mx32/sched_xetattr--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/sched_xetattr--pidns-translation.gen.test
--- 5.5-3/tests-mx32/sched_xetattr--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/sched_xetattr--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (sched_xetattr--pidns-translation test_pidns -a29 -e trace=sched_getattr,sched_setattr); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a29 -e trace=sched_getattr,sched_setattr
diff -pruN 5.5-3/tests-mx32/sched_xetparam.c 5.9-0ubuntu2/tests-mx32/sched_xetparam.c
--- 5.5-3/tests-mx32/sched_xetparam.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/sched_xetparam.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -7,6 +7,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #if defined __NR_sched_getparam && defined __NR_sched_setparam
 
@@ -17,18 +18,27 @@
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	struct sched_param *const param =
 		tail_alloc(sizeof(struct sched_param));
 
-	long rc = syscall(__NR_sched_getparam, 0, param);
-	printf("sched_getparam(0, [%d]) = %ld\n",
-	       param->sched_priority, rc);
+	const int pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
+
+	long rc = syscall(__NR_sched_getparam, pid, param);
+	pidns_print_leader();
+	printf("sched_getparam(%d%s, [%d]) = %ld\n",
+	       pid, pid_str, param->sched_priority, rc);
 
 	param->sched_priority = -1;
-	rc = syscall(__NR_sched_setparam, 0, param);
-	printf("sched_setparam(0, [%d]) = %ld %s (%m)\n",
+	rc = syscall(__NR_sched_setparam, pid, param);
+	pidns_print_leader();
+	printf("sched_setparam(%d%s, [%d]) = %ld %s (%m)\n",
+	       pid, pid_str,
 	       param->sched_priority, rc, errno2name());
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/sched_xetparam--pidns-translation.c 5.9-0ubuntu2/tests-mx32/sched_xetparam--pidns-translation.c
--- 5.5-3/tests-mx32/sched_xetparam--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/sched_xetparam--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "sched_xetparam.c"
diff -pruN 5.5-3/tests-mx32/sched_xetparam--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/sched_xetparam--pidns-translation.gen.test
--- 5.5-3/tests-mx32/sched_xetparam--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/sched_xetparam--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (sched_xetparam--pidns-translation test_pidns -a23 -e trace=sched_getparam,sched_setparam); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a23 -e trace=sched_getparam,sched_setparam
diff -pruN 5.5-3/tests-mx32/sched_xetscheduler.c 5.9-0ubuntu2/tests-mx32/sched_xetscheduler.c
--- 5.5-3/tests-mx32/sched_xetscheduler.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/sched_xetscheduler.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -7,6 +7,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #if defined __NR_sched_getscheduler && defined __NR_sched_setscheduler
 
@@ -17,8 +18,13 @@
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct sched_param, param);
-	long rc = syscall(__NR_sched_getscheduler, 0);
+	const int pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
+
+	long rc = syscall(__NR_sched_getscheduler, pid);
 	const char *scheduler;
 	switch (rc) {
 		case SCHED_FIFO:
@@ -50,33 +56,43 @@ main(void)
 		default:
 			scheduler = "SCHED_OTHER";
 	}
-	printf("sched_getscheduler(0) = %ld (%s)\n",
-	       rc, scheduler);
+	pidns_print_leader();
+	printf("sched_getscheduler(%d%s) = %ld (%s)\n",
+	       pid, pid_str, rc, scheduler);
 
 	rc = syscall(__NR_sched_getscheduler, -1);
+	pidns_print_leader();
 	printf("sched_getscheduler(-1) = %s\n", sprintrc(rc));
 
 	param->sched_priority = -1;
 
-	rc = syscall(__NR_sched_setscheduler, 0, SCHED_FIFO, NULL);
-	printf("sched_setscheduler(0, SCHED_FIFO, NULL) = %s\n", sprintrc(rc));
-
-	rc = syscall(__NR_sched_setscheduler, 0, SCHED_FIFO, param + 1);
-	printf("sched_setscheduler(0, SCHED_FIFO, %p) = %s\n", param + 1,
-	       sprintrc(rc));
-
-	rc = syscall(__NR_sched_setscheduler, 0, 0xfaceda7a, param);
-	printf("sched_setscheduler(0, %#x /* SCHED_??? */, [%d]) = %s\n",
-	       0xfaceda7a, param->sched_priority, sprintrc(rc));
+	rc = syscall(__NR_sched_setscheduler, pid, SCHED_FIFO, NULL);
+	pidns_print_leader();
+	printf("sched_setscheduler(%d%s, SCHED_FIFO, NULL) = %s\n",
+	       pid, pid_str, sprintrc(rc));
+
+	rc = syscall(__NR_sched_setscheduler, pid, SCHED_FIFO, param + 1);
+	pidns_print_leader();
+	printf("sched_setscheduler(%d%s, SCHED_FIFO, %p) = %s\n",
+	       pid, pid_str, param + 1, sprintrc(rc));
+
+	rc = syscall(__NR_sched_setscheduler, pid, 0xfaceda7a, param);
+	pidns_print_leader();
+	printf("sched_setscheduler(%d%s, %#x /* SCHED_??? */, [%d]) = %s\n",
+	       pid, pid_str, 0xfaceda7a,
+	       param->sched_priority, sprintrc(rc));
 
 	rc = syscall(__NR_sched_setscheduler, -1, SCHED_FIFO, param);
+	pidns_print_leader();
 	printf("sched_setscheduler(-1, SCHED_FIFO, [%d]) = %s\n",
 	       param->sched_priority, sprintrc(rc));
 
-	rc = syscall(__NR_sched_setscheduler, 0, SCHED_FIFO, param);
-	printf("sched_setscheduler(0, SCHED_FIFO, [%d]) = %s\n",
-	       param->sched_priority, sprintrc(rc));
+	rc = syscall(__NR_sched_setscheduler, pid, SCHED_FIFO, param);
+	pidns_print_leader();
+	printf("sched_setscheduler(%d%s, SCHED_FIFO, [%d]) = %s\n",
+	       pid, pid_str, param->sched_priority, sprintrc(rc));
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/sched_xetscheduler--pidns-translation.c 5.9-0ubuntu2/tests-mx32/sched_xetscheduler--pidns-translation.c
--- 5.5-3/tests-mx32/sched_xetscheduler--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/sched_xetscheduler--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "sched_xetscheduler.c"
diff -pruN 5.5-3/tests-mx32/sched_xetscheduler--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/sched_xetscheduler--pidns-translation.gen.test
--- 5.5-3/tests-mx32/sched_xetscheduler--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/sched_xetscheduler--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (sched_xetscheduler--pidns-translation test_pidns -a22 -e trace=sched_getscheduler,sched_setscheduler); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a22 -e trace=sched_getscheduler,sched_setscheduler
diff -pruN 5.5-3/tests-mx32/seccomp-filter.c 5.9-0ubuntu2/tests-mx32/seccomp-filter.c
--- 5.5-3/tests-mx32/seccomp-filter.c	2019-07-16 17:46:47.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/seccomp-filter.c	2020-06-01 14:15:16.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of seccomp SECCOMP_SET_MODE_FILTER.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -38,12 +38,13 @@ main(void)
 	       " = %ld %s (%m)\n",
 	       "SECCOMP_FILTER_FLAG_TSYNC|SECCOMP_FILTER_FLAG_LOG|"
 	       "SECCOMP_FILTER_FLAG_SPEC_ALLOW|"
-	       "SECCOMP_FILTER_FLAG_NEW_LISTENER|0xfffffff0",
+	       "SECCOMP_FILTER_FLAG_NEW_LISTENER|"
+	       "SECCOMP_FILTER_FLAG_TSYNC_ESRCH|0xffffffe0",
 	       prog->len, prog->filter, rc, errno2name());
 
-	rc = syscall(__NR_seccomp, SECCOMP_SET_MODE_FILTER, -16L, efault);
+	rc = syscall(__NR_seccomp, SECCOMP_SET_MODE_FILTER, -32L, efault);
 	printf("seccomp(SECCOMP_SET_MODE_FILTER, %s, %p) = %ld %s (%m)\n",
-	       "0xfffffff0 /* SECCOMP_FILTER_FLAG_??? */",
+	       "0xffffffe0 /* SECCOMP_FILTER_FLAG_??? */",
 	       efault, rc, errno2name());
 
 	puts("+++ exited with 0 +++");
diff -pruN 5.5-3/tests-mx32/seccomp-filter-v.c 5.9-0ubuntu2/tests-mx32/seccomp-filter-v.c
--- 5.5-3/tests-mx32/seccomp-filter-v.c	2019-09-15 15:47:01.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/seccomp-filter-v.c	2020-04-15 13:39:57.000000000 +0000
@@ -2,7 +2,7 @@
  * Check verbose decoding of seccomp SECCOMP_SET_MODE_FILTER.
  *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -13,16 +13,13 @@
 #include <errno.h>
 #include <stddef.h>
 #include <stdio.h>
-#include "scno.h"
 #include <unistd.h>
-
-#ifdef HAVE_PRCTL
-# include <sys/prctl.h>
-#endif
+#include <sys/prctl.h>
 #ifdef HAVE_LINUX_SECCOMP_H
 # include <linux/seccomp.h>
 #endif
 #include <linux/filter.h>
+#include "scno.h"
 
 #if defined __NR_seccomp \
  && defined PR_SET_NO_NEW_PRIVS \
@@ -118,7 +115,8 @@ main(void)
 	tprintf("seccomp(SECCOMP_SET_MODE_FILTER, %s, {len=%u, filter=[",
 		"SECCOMP_FILTER_FLAG_TSYNC|SECCOMP_FILTER_FLAG_LOG|"
 		"SECCOMP_FILTER_FLAG_SPEC_ALLOW|"
-		"SECCOMP_FILTER_FLAG_NEW_LISTENER|0xfffffff0",
+		"SECCOMP_FILTER_FLAG_NEW_LISTENER|"
+		"SECCOMP_FILTER_FLAG_TSYNC_ESRCH|0xffffffe0",
 		prog->len);
 	for (i = 0; i < BPF_MAXINSNS; ++i) {
 		if (i)
diff -pruN 5.5-3/tests-mx32/semtimedop.c 5.9-0ubuntu2/tests-mx32/semtimedop.c
--- 5.5-3/tests-mx32/semtimedop.c	2019-11-18 13:31:57.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/semtimedop.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,21 +1,25 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-#include <sys/ipc.h>
-#include <sys/sem.h>
-#include <stdint.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-
-#define XLAT_MACROS_ONLY
-#include "xlat/semop_flags.h"
-#undef XLAT_MACROS_ONLY
+#include "scno.h"
+
+#if defined __NR_semtimedop || defined __NR_socketcall
+
+# include <sys/ipc.h>
+# include <sys/sem.h>
+# include <stdint.h>
+# include <stdio.h>
+# include <stdlib.h>
+# include <unistd.h>
+
+# define XLAT_MACROS_ONLY
+#  include "xlat/semop_flags.h"
+# undef XLAT_MACROS_ONLY
 
 union semun {
 	int val;
@@ -143,3 +147,9 @@ main(void)
 	puts("+++ exited with 0 +++");
 	return 0;
 }
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_semtimedop || __NR_socketcall")
+
+#endif
diff -pruN 5.5-3/tests-mx32/sendfile64.c 5.9-0ubuntu2/tests-mx32/sendfile64.c
--- 5.5-3/tests-mx32/sendfile64.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/sendfile64.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -50,14 +50,9 @@ main(void)
 	const unsigned int blen = file_size / 3;
 	const unsigned int alen = file_size - blen;
 
-	static const char fname[] = "sendfile64-tmpfile";
-	int reg_in = open(fname, O_RDWR | O_CREAT | O_TRUNC, 0600);
-	if (reg_in < 0)
-		perror_msg_and_fail("open: %s", fname);
-	if (unlink(fname))
-		perror_msg_and_fail("unlink: %s", fname);
+	int reg_in = create_tmpfile(O_RDWR);
 	if (ftruncate(reg_in, file_size))
-		perror_msg_and_fail("ftruncate: %s", fname);
+		perror_msg_and_fail("ftruncate(%d, %u)", reg_in, file_size);
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(uint64_t, p_off);
 	void *p = p_off + 1;
diff -pruN 5.5-3/tests-mx32/sendfile.c 5.9-0ubuntu2/tests-mx32/sendfile.c
--- 5.5-3/tests-mx32/sendfile.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/sendfile.c	2020-06-01 14:15:16.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -50,14 +50,9 @@ main(void)
 	const unsigned int blen = file_size / 3;
 	const unsigned int alen = file_size - blen;
 
-	static const char fname[] = "sendfile-tmpfile";
-	int reg_in = open(fname, O_RDWR | O_CREAT | O_TRUNC, 0600);
-	if (reg_in < 0)
-		perror_msg_and_fail("open: %s", fname);
-	if (unlink(fname))
-		perror_msg_and_fail("unlink: %s", fname);
+	int reg_in = create_tmpfile(O_RDWR);
 	if (ftruncate(reg_in, file_size))
-		perror_msg_and_fail("ftruncate: %s", fname);
+		perror_msg_and_fail("ftruncate(%d, %u)", reg_in, file_size);
 
 	TAIL_ALLOC_OBJECT_VAR_PTR(uint32_t, p_off);
 	void *p = p_off + 1;
diff -pruN 5.5-3/tests-mx32/setpgrp-exec.c 5.9-0ubuntu2/tests-mx32/setpgrp-exec.c
--- 5.5-3/tests-mx32/setpgrp-exec.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/setpgrp-exec.c	2020-04-02 11:10:14.000000000 +0000
@@ -0,0 +1,22 @@
+/*
+ * Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include <unistd.h>
+
+int main(int argc, char **argv)
+{
+	if (argc < 2)
+		error_msg_and_fail("argc < 2");
+
+	if (setpgid(0, 0))
+		perror_msg_and_fail("setpgid");
+
+	(void) execvp(argv[1], argv + 1);
+
+	perror_msg_and_fail("execvp: %s", argv[1]);
+}
diff -pruN 5.5-3/tests-mx32/set_ptracer_any.c 5.9-0ubuntu2/tests-mx32/set_ptracer_any.c
--- 5.5-3/tests-mx32/set_ptracer_any.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/set_ptracer_any.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2013-2015 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2013-2018 The strace developers.
+ * Copyright (c) 2013-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -9,25 +9,21 @@
 #include "tests.h"
 #include <stdio.h>
 #include <unistd.h>
-#ifdef HAVE_PRCTL
-# include <sys/prctl.h>
-#endif
+#include <sys/prctl.h>
 
 int main(int argc, char **argv)
 {
 	if (argc < 2)
 		return 99;
-#ifdef HAVE_PRCTL
 	/* Turn off restrictions on tracing if applicable.  If the command
 	 * aren't available on this system, that's OK too.  */
-# ifndef PR_SET_PTRACER
-#  define PR_SET_PTRACER 0x59616d61
-# endif
-# ifndef PR_SET_PTRACER_ANY
-#  define PR_SET_PTRACER_ANY -1UL
-# endif
-	(void) prctl(PR_SET_PTRACER, PR_SET_PTRACER_ANY, 0, 0, 0);
+#ifndef PR_SET_PTRACER
+# define PR_SET_PTRACER 0x59616d61
 #endif
+#ifndef PR_SET_PTRACER_ANY
+# define PR_SET_PTRACER_ANY -1UL
+#endif
+	(void) prctl(PR_SET_PTRACER, PR_SET_PTRACER_ANY, 0, 0, 0);
 	if (write(1, "\n", 1) != 1) {
 		perror("write");
 		return 99;
diff -pruN 5.5-3/tests-mx32/sigblock.test 5.9-0ubuntu2/tests-mx32/sigblock.test
--- 5.5-3/tests-mx32/sigblock.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/sigblock.test	2020-04-03 22:58:26.000000000 +0000
@@ -4,7 +4,7 @@
 # Starting with commit v4.17-5-gf83b49b strace is expected
 # to forward the signal mask to tracees unchanged.
 #
-# Copyright (c) 2017-2018 The strace developers.
+# Copyright (c) 2017-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -20,7 +20,7 @@ for sig in $(../list_sigaction_signum);
 		check_cmd="../check_sigblock $block $sig"
 		run_prog $set_cmd $check_cmd
 		STRACE="$set_cmd $saved_STRACE"
-		for i in '' -I1 -I2 -I3 -I4; do
+		for i in '' -I1 -Iwaiting --interruptible=3 --interruptible=never_tstp; do
 			run_strace $i -enone $check_cmd
 		done
 	done
diff -pruN 5.5-3/tests-mx32/sigign.test 5.9-0ubuntu2/tests-mx32/sigign.test
--- 5.5-3/tests-mx32/sigign.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/sigign.test	2020-04-03 22:58:26.000000000 +0000
@@ -4,7 +4,7 @@
 # Starting with commit v4.17-8-ge97a66f strace is expected
 # to forward the signal disposition to tracees unchanged.
 #
-# Copyright (c) 2017-2018 The strace developers.
+# Copyright (c) 2017-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -20,7 +20,7 @@ for sig in $(../list_sigaction_signum);
 		check_cmd="../check_sigign $ign $sig"
 		run_prog $set_cmd $check_cmd
 		STRACE="$set_cmd $saved_STRACE"
-		for i in '' -I1 -I2 -I3 -I4; do
+		for i in '' --interruptible=always --interruptible=2 -Inever -I4; do
 			run_strace $i -enone $check_cmd
 		done
 	done
diff -pruN 5.5-3/tests-mx32/siginfo.c 5.9-0ubuntu2/tests-mx32/siginfo.c
--- 5.5-3/tests-mx32/siginfo.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/siginfo.c	2020-08-03 08:00:00.000000000 +0000
@@ -2,6 +2,7 @@
  * Check SIGCHLD siginfo_t decoding.
  *
  * Copyright (c) 2015-2018 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -63,7 +64,7 @@ main(void)
 
 	sigsuspend(&unblock_mask);
 	tprintf("--- SIGCHLD {si_signo=SIGCHLD, si_code=CLD_EXITED"
-		", si_pid=%d, si_uid=%u, si_status=%d"
+		", si_pid=%d, si_uid=%d, si_status=%d"
 		", si_utime=%llu, si_stime=%llu} ---\n",
 		sinfo.si_pid, sinfo.si_uid, sinfo.si_status,
 		zero_extend_signed_to_ull(sinfo.si_utime),
@@ -94,7 +95,7 @@ main(void)
 
 	sigsuspend(&unblock_mask);
 	tprintf("--- SIGCHLD {si_signo=SIGCHLD, si_code=CLD_KILLED"
-		", si_pid=%d, si_uid=%u, si_status=SIGUSR1"
+		", si_pid=%d, si_uid=%d, si_status=SIGUSR1"
 		", si_utime=%llu, si_stime=%llu} ---\n",
 		sinfo.si_pid, sinfo.si_uid,
 		zero_extend_signed_to_ull(sinfo.si_utime),
@@ -121,7 +122,7 @@ main(void)
 
 	sigsuspend(&unblock_mask);
 	tprintf("--- SIGCHLD {si_signo=SIGCHLD, si_code=CLD_STOPPED"
-		", si_pid=%d, si_uid=%u, si_status=SIGSTOP"
+		", si_pid=%d, si_uid=%d, si_status=SIGSTOP"
 		", si_utime=%llu, si_stime=%llu} ---\n",
 		sinfo.si_pid, sinfo.si_uid,
 		zero_extend_signed_to_ull(sinfo.si_utime),
@@ -131,7 +132,7 @@ main(void)
 
 	sigsuspend(&unblock_mask);
 	tprintf("--- SIGCHLD {si_signo=SIGCHLD, si_code=CLD_CONTINUED"
-		", si_pid=%d, si_uid=%u, si_status=SIGCONT"
+		", si_pid=%d, si_uid=%d, si_status=SIGCONT"
 		", si_utime=%llu, si_stime=%llu} ---\n",
 		sinfo.si_pid, sinfo.si_uid,
 		zero_extend_signed_to_ull(sinfo.si_utime),
@@ -142,7 +143,7 @@ main(void)
 
 	sigsuspend(&unblock_mask);
 	tprintf("--- SIGCHLD {si_signo=SIGCHLD, si_code=CLD_EXITED"
-		", si_pid=%d, si_uid=%u, si_status=0"
+		", si_pid=%d, si_uid=%d, si_status=0"
 		", si_utime=%llu, si_stime=%llu} ---\n",
 		sinfo.si_pid, sinfo.si_uid,
 		zero_extend_signed_to_ull(sinfo.si_utime),
diff -pruN 5.5-3/tests-mx32/signal_receive.c 5.9-0ubuntu2/tests-mx32/signal_receive.c
--- 5.5-3/tests-mx32/signal_receive.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/signal_receive.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,13 +1,14 @@
 /*
  * Check decoding of signal delivery.
  *
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include "pidns.h"
 #include <signal.h>
 #include <stdio.h>
 #include <unistd.h>
@@ -26,10 +27,13 @@ handler(int sig, siginfo_t *info, void *
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	static const char prefix[] = "KERNEL BUG";
 	int printed = 0;
 
 	const int pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
 	const int uid = geteuid();
 
 	for (int sig = 1; sig <= 31; ++sig) {
@@ -73,10 +77,13 @@ main(void)
 		const int e_pid = s_pid;
 		const int e_uid = s_uid;
 #endif
-		printf("kill(%d, %s) = 0\n", pid, signal2name(sig));
-		printf("--- %s {si_signo=%s, si_code=SI_USER, si_pid=%d"
+		pidns_print_leader();
+		printf("kill(%d%s, %s) = 0\n", pid, pid_str, signal2name(sig));
+		pidns_print_leader();
+		printf("--- %s {si_signo=%s, si_code=SI_USER, si_pid=%d%s"
 		       ", si_uid=%d} ---\n",
-		       signal2name(sig), signal2name(e_sig), e_pid, e_uid);
+		       signal2name(sig), signal2name(e_sig),
+		       e_pid, pid_str, e_uid);
 
 		if (s_code || sig != s_sig || pid != s_pid || uid != s_uid) {
 			/*
@@ -91,11 +98,11 @@ main(void)
 			}
 			fprintf(stderr,
 				"%s: expected: si_signo=%d, si_code=%d"
-				", si_pid=%d, si_uid=%d\n"
+				", si_pid=%d%s, si_uid=%d\n"
 				"%s: received: si_signo=%d, si_code=%d"
-				", si_pid=%d, si_uid=%d\n",
-				prefix, sig, SI_USER, pid, uid,
-				prefix, sig, s_code, s_pid, s_uid);
+				", si_pid=%d%s, si_uid=%d\n",
+				prefix, sig, SI_USER, pid, pid_str, uid,
+				prefix, sig, s_code, s_pid, pid_str, s_uid);
 		}
 	}
 
@@ -104,6 +111,7 @@ main(void)
 			"*** PLEASE FIX THE KERNEL ***\n", prefix);
 	}
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/signal_receive--pidns-translation.c 5.9-0ubuntu2/tests-mx32/signal_receive--pidns-translation.c
--- 5.5-3/tests-mx32/signal_receive--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/signal_receive--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "signal_receive.c"
diff -pruN 5.5-3/tests-mx32/signal_receive--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/signal_receive--pidns-translation.gen.test
--- 5.5-3/tests-mx32/signal_receive--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/signal_receive--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (signal_receive--pidns-translation test_pidns -a16 -e trace=kill); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a16 -e trace=kill
diff -pruN 5.5-3/tests-mx32/sock_filter-v.c 5.9-0ubuntu2/tests-mx32/sock_filter-v.c
--- 5.5-3/tests-mx32/sock_filter-v.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/sock_filter-v.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of socket filters.
  *
  * Copyright (c) 2017 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2017-2018 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -23,17 +23,6 @@
 
 #define HEX_FMT "%#x"
 
-#if XLAT_RAW
-# define XLAT_FMT HEX_FMT
-# define XLAT_ARGS(a_) (a_)
-#elif XLAT_VERBOSE
-# define XLAT_FMT HEX_FMT " /* %s */"
-# define XLAT_ARGS(a_) (a_), #a_
-#else
-# define XLAT_FMT "%s"
-# define XLAT_ARGS(a_) #a_
-#endif
-
 #define PRINT_STMT(pfx, code_fmt, k_fmt, ...)	\
 	printf("%sBPF_STMT(" code_fmt ", " k_fmt ")", pfx, __VA_ARGS__)
 
diff -pruN 5.5-3/tests-mx32/sockopt-timestamp.c 5.9-0ubuntu2/tests-mx32/sockopt-timestamp.c
--- 5.5-3/tests-mx32/sockopt-timestamp.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/sockopt-timestamp.c	2020-09-23 16:29:35.000000000 +0000
@@ -19,6 +19,9 @@
 # include <linux/time_types.h>
 #endif
 
+#include "kernel_timeval.h"
+#include "kernel_old_timespec.h"
+
 #define XLAT_MACROS_ONLY
 #include "xlat/sock_options.h"
 #undef XLAT_MACROS_ONLY
@@ -28,7 +31,7 @@ print_timestamp_old(const struct cmsghdr
 {
 	const void *cmsg_header = c;
 	const void *cmsg_data = CMSG_DATA(c);
-	struct timeval tv;
+	kernel_old_timeval_t tv;
 	const unsigned int expected_len = sizeof(tv);
 	const unsigned int data_len = c->cmsg_len - (cmsg_data - cmsg_header);
 
@@ -47,7 +50,7 @@ print_timestampns_old(const struct cmsgh
 {
 	const void *cmsg_header = c;
 	const void *cmsg_data = CMSG_DATA(c);
-	struct timespec ts;
+	kernel_old_timespec_t ts;
 	const unsigned int expected_len = sizeof(ts);
 	const unsigned int data_len = c->cmsg_len - (cmsg_data - cmsg_header);
 
diff -pruN 5.5-3/tests-mx32/so_error.c 5.9-0ubuntu2/tests-mx32/so_error.c
--- 5.5-3/tests-mx32/so_error.c	2018-12-17 19:19:23.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/so_error.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,6 +2,7 @@
  * Check decoding of SO_ERROR socket option.
  *
  * Copyright (c) 2018 Masatake YAMATO <yamato@redhat.com>
+ * Copyright (c) 2018-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -37,7 +38,7 @@ reserve_ephemeral_port(void)
 	for (in_port_t port = 49152; port < 61000; port++) {
 		/* Just bind here. No listen. */
 		addr.sin_port = htons(port);
-		if (bind(sd, &addr, sizeof(addr)) == 0)
+		if (bind(sd, (void *) &addr, sizeof(addr)) == 0)
 			return port;
 	}
 	error_msg_and_skip("no ephemeral port available for test purposes");
@@ -69,7 +70,7 @@ main(void)
 		.sin_addr.s_addr = htonl(INADDR_LOOPBACK),
 		.sin_port = htons(port),
 	};
-	if (connect(fd, &addr, sizeof(addr)) == 0)
+	if (connect(fd, (void *) &addr, sizeof(addr)) == 0)
 		error_msg_and_skip("connect unexpectedly succeeded");
 	if (errno != EINPROGRESS)
 		perror_msg_and_skip("connect failed for unexpected reason");
diff -pruN 5.5-3/tests-mx32/so_peercred.c 5.9-0ubuntu2/tests-mx32/so_peercred.c
--- 5.5-3/tests-mx32/so_peercred.c	2018-12-10 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/so_peercred.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,13 +2,14 @@
  * Check decoding of SO_PEERCRED socket option.
  *
  * Copyright (c) 2017 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2017-2018 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
+#include "pidns.h"
 
 #include <stddef.h>
 #include <stdio.h>
@@ -53,6 +54,8 @@ so_str(void)
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	TAIL_ALLOC_OBJECT_CONST_PTR(struct ucred, peercred);
 	TAIL_ALLOC_OBJECT_CONST_PTR(socklen_t, len);
 
@@ -75,6 +78,8 @@ main(void)
 	struct ucred *const gid_truncated =
 		tail_alloc(sizeof_gid_truncated);
 
+	const char *pid_str = pidns_pid2str(PT_TGID);
+
 	int sv[2];
 	if (socketpair(AF_UNIX, SOCK_STREAM, 0, sv))
                 perror_msg_and_skip("socketpair AF_UNIX SOCK_STREAM");
@@ -82,8 +87,10 @@ main(void)
 	/* classic getsockopt */
 	*len = sizeof(*peercred);
 	get_peercred(sv[0], peercred, len);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s", sv[0], so_str());
 	PRINT_FIELD_D(", {", *peercred, pid);
+	printf("%s", pid_str);
 	PRINT_FIELD_UID(", ", *peercred, uid);
 	PRINT_FIELD_UID(", ", *peercred, gid);
 	printf("}, [%d]) = %s\n", *len, errstr);
@@ -91,14 +98,17 @@ main(void)
 	/* getsockopt with zero optlen */
 	*len = 0;
 	get_peercred(sv[0], peercred, len);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s, %p, [0]) = %s\n",
 	       sv[0], so_str(), peercred, errstr);
 
 	/* getsockopt with optlen larger than necessary - shortened */
 	*len = sizeof(*peercred) + 1;
 	get_peercred(sv[0], peercred, len);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s", sv[0], so_str());
 	PRINT_FIELD_D(", {", *peercred, pid);
+	printf("%s", pid_str);
 	PRINT_FIELD_UID(", ", *peercred, uid);
 	PRINT_FIELD_UID(", ", *peercred, gid);
 	printf("}, [%u->%d]) = %s\n",
@@ -110,6 +120,7 @@ main(void)
 	 */
 	*len = sizeof_pid_truncated;
 	get_peercred(sv[0], pid_truncated, len);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s, {pid=", sv[0], so_str());
 	print_quoted_hex(pid_truncated, *len);
 	printf("}, [%d]) = %s\n", *len, errstr);
@@ -120,8 +131,10 @@ main(void)
 	 */
 	*len = sizeof_pid;
 	get_peercred(sv[0], pid, len);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s", sv[0], so_str());
 	PRINT_FIELD_D(", {", *pid, pid);
+	printf("%s", pid_str);
 	printf("}, [%d]) = %s\n", *len, errstr);
 
 	/*
@@ -136,8 +149,10 @@ main(void)
 	 * to struct ucred.pid field.
 	 */
 	memcpy(uid, uid_truncated, sizeof_uid_truncated);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s", sv[0], so_str());
 	PRINT_FIELD_D(", {", *uid, pid);
+	printf("%s", pid_str);
 	printf(", uid=");
 	print_quoted_hex(&uid->uid, sizeof_uid_truncated -
 				    offsetof(struct ucred, uid));
@@ -149,8 +164,10 @@ main(void)
 	 */
 	*len = sizeof_uid;
 	get_peercred(sv[0], uid, len);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s", sv[0], so_str());
 	PRINT_FIELD_D(", {", *uid, pid);
+	printf("%s", pid_str);
 	PRINT_FIELD_UID(", ", *uid, uid);
 	printf("}, [%d]) = %s\n", *len, errstr);
 
@@ -166,8 +183,10 @@ main(void)
 	 * to struct ucred.pid and struct ucred.uid fields.
 	 */
 	memcpy(peercred, gid_truncated, sizeof_gid_truncated);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s", sv[0], so_str());
 	PRINT_FIELD_D(", {", *peercred, pid);
+	printf("%s", pid_str);
 	PRINT_FIELD_UID(", ", *peercred, uid);
 	printf(", gid=");
 	print_quoted_hex(&peercred->gid, sizeof_gid_truncated -
@@ -177,14 +196,17 @@ main(void)
 	/* getsockopt optval EFAULT */
 	*len = sizeof(*peercred);
 	get_peercred(sv[0], &peercred->uid, len);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s, %p, [%d]) = %s\n",
 	       sv[0], so_str(), &peercred->uid, *len, errstr);
 
 	/* getsockopt optlen EFAULT */
 	get_peercred(sv[0], peercred, len + 1);
+	pidns_print_leader();
 	printf("getsockopt(%d, %s, %p, %p) = %s\n",
 	       sv[0], so_str(), peercred, len + 1, errstr);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/so_peercred--pidns-translation.c 5.9-0ubuntu2/tests-mx32/so_peercred--pidns-translation.c
--- 5.5-3/tests-mx32/so_peercred--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/so_peercred--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "so_peercred.c"
diff -pruN 5.5-3/tests-mx32/so_peercred--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/so_peercred--pidns-translation.gen.test
--- 5.5-3/tests-mx32/so_peercred--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/so_peercred--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (so_peercred--pidns-translation test_pidns -e trace=getsockopt); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -e trace=getsockopt
diff -pruN 5.5-3/tests-mx32/stack-fcall-0.c 5.9-0ubuntu2/tests-mx32/stack-fcall-0.c
--- 5.5-3/tests-mx32/stack-fcall-0.c	2019-07-11 17:51:22.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/stack-fcall-0.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2019 The strace developers.
+ * Copyright (c) 2014-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -7,7 +7,10 @@
 
 #include "stack-fcall.h"
 
-int f0(int i, unsigned long f)
+int
+f0(int i, unsigned long f)
 {
-	return f1(i, f ^ (unsigned long) (void *) f0) - i;
+	f ^= (unsigned long) (void *) f0;
+	COMPLEX_BODY(i, f);
+	return f1(i, f) - i;
 }
diff -pruN 5.5-3/tests-mx32/stack-fcall-1.c 5.9-0ubuntu2/tests-mx32/stack-fcall-1.c
--- 5.5-3/tests-mx32/stack-fcall-1.c	2019-07-11 17:51:22.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/stack-fcall-1.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2019 The strace developers.
+ * Copyright (c) 2014-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -7,7 +7,10 @@
 
 #include "stack-fcall.h"
 
-int f1(int i, unsigned long f)
+int
+f1(int i, unsigned long f)
 {
-	return f2(i, f ^ (unsigned long) (void *) f1) + i;
+	f ^= (unsigned long) (void *) f1;
+	COMPLEX_BODY(i, f);
+	return f2(i, f) + i;
 }
diff -pruN 5.5-3/tests-mx32/stack-fcall-2.c 5.9-0ubuntu2/tests-mx32/stack-fcall-2.c
--- 5.5-3/tests-mx32/stack-fcall-2.c	2019-07-11 17:51:22.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/stack-fcall-2.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2019 The strace developers.
+ * Copyright (c) 2014-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -7,7 +7,10 @@
 
 #include "stack-fcall.h"
 
-int f2(int i, unsigned long f)
+int
+f2(int i, unsigned long f)
 {
-	return f3(i, f ^ (unsigned long) (void *) f2) - i;
+	f ^= (unsigned long) (void *) f2;
+	COMPLEX_BODY(i, f);
+	return f3(i, f) - i;
 }
diff -pruN 5.5-3/tests-mx32/stack-fcall-3.c 5.9-0ubuntu2/tests-mx32/stack-fcall-3.c
--- 5.5-3/tests-mx32/stack-fcall-3.c	2019-07-16 17:46:47.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/stack-fcall-3.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,25 +1,28 @@
 /*
- * Copyright (c) 2014-2019 The strace developers.
+ * Copyright (c) 2014-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include <signal.h>
-#include <unistd.h>
-#include "scno.h"
-
 #include "stack-fcall.h"
 
-int f3(int i, unsigned long f)
+int
+f3(int i, unsigned long f)
 {
-	syscall(__NR_gettid, f ^ (unsigned long) (void *) f3);
+	f ^= (unsigned long) (void *) f3;
+	COMPLEX_BODY(i, f);
 	switch (i) {
 	case 1:
-		return kill(getpid(), SIGURG);
-
+		i -= chdir("");
+		break;
+	case 2:
+		i -= kill(getpid(), SIGURG) - 1;
+		break;
 	default:
-		return chdir("") + i;
+		i -= syscall(__NR_exit, i - 3);
+		break;
 	}
-
+	return i;
 }
diff -pruN 5.5-3/tests-mx32/stack-fcall.c 5.9-0ubuntu2/tests-mx32/stack-fcall.c
--- 5.5-3/tests-mx32/stack-fcall.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/stack-fcall.c	2020-06-27 08:00:00.000000000 +0000
@@ -13,14 +13,14 @@
 # define ATTACH_MODE 0
 #endif
 
-int main(void)
+int
+main(int ac, char **av)
 {
 #if ATTACH_MODE
 	/* sleep a bit to let the tracer time to catch up */
 	sleep(1);
 #endif
 
-	f0(0, (unsigned long) (void *) main);
-	f0(1, (unsigned long) (void *) main);
-	return 0;
+	for (;;)
+		ac += f0(ac, (unsigned long) (void *) main);
 }
diff -pruN 5.5-3/tests-mx32/stack-fcall.h 5.9-0ubuntu2/tests-mx32/stack-fcall.h
--- 5.5-3/tests-mx32/stack-fcall.h	2019-07-11 17:51:22.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/stack-fcall.h	2020-08-03 08:00:00.000000000 +0000
@@ -1,10 +1,13 @@
 /*
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
+#include <unistd.h>
+#include "scno.h"
+
 #ifdef MANGLE
 
 # define f0 _ZN2ns2f0Ei
@@ -18,3 +21,24 @@ int f0(int i, unsigned long);
 int f1(int i, unsigned long);
 int f2(int i, unsigned long);
 int f3(int i, unsigned long);
+
+#define COMPLEX_BODY(i, f)				\
+	do {						\
+		int tid = syscall(__NR_gettid, f);	\
+		if (i == tid)				\
+			return 0;			\
+		switch ((unsigned int) tid & 3) {	\
+			case 0:				\
+				i += f0(tid, f);	\
+				break;			\
+			case 1:				\
+				i += f1(tid, f);	\
+				break;			\
+			case 2:				\
+				i += f2(tid, f);	\
+				break;			\
+			case 3:				\
+				i += f3(tid, f);	\
+				break;			\
+		}					\
+	} while (0)
diff -pruN 5.5-3/tests-mx32/status-failed-long.c 5.9-0ubuntu2/tests-mx32/status-failed-long.c
--- 5.5-3/tests-mx32/status-failed-long.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/status-failed-long.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1 @@
+#include "status-failed.c"
diff -pruN 5.5-3/tests-mx32/status-failed-long.gen.test 5.9-0ubuntu2/tests-mx32/status-failed-long.gen.test
--- 5.5-3/tests-mx32/status-failed-long.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/status-failed-long.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (status-failed-long -a10 -e trace=chdir --failed-only); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a10 -e trace=chdir --failed-only
diff -pruN 5.5-3/tests-mx32/status-failed-status.c 5.9-0ubuntu2/tests-mx32/status-failed-status.c
--- 5.5-3/tests-mx32/status-failed-status.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/status-failed-status.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1 @@
+#include "status-failed.c"
diff -pruN 5.5-3/tests-mx32/status-failed-status.gen.test 5.9-0ubuntu2/tests-mx32/status-failed-status.gen.test
--- 5.5-3/tests-mx32/status-failed-status.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/status-failed-status.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (status-failed-status -a10 -e trace=chdir -e status=failed); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a10 -e trace=chdir -e status=failed
diff -pruN 5.5-3/tests-mx32/status-successful-long.c 5.9-0ubuntu2/tests-mx32/status-successful-long.c
--- 5.5-3/tests-mx32/status-successful-long.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/status-successful-long.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1 @@
+#include "status-successful.c"
diff -pruN 5.5-3/tests-mx32/status-successful-long.gen.test 5.9-0ubuntu2/tests-mx32/status-successful-long.gen.test
--- 5.5-3/tests-mx32/status-successful-long.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/status-successful-long.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (status-successful-long -a10 -e trace=chdir --successful-only); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a10 -e trace=chdir --successful-only
diff -pruN 5.5-3/tests-mx32/status-successful-status.c 5.9-0ubuntu2/tests-mx32/status-successful-status.c
--- 5.5-3/tests-mx32/status-successful-status.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/status-successful-status.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1 @@
+#include "status-successful.c"
diff -pruN 5.5-3/tests-mx32/status-successful-status.gen.test 5.9-0ubuntu2/tests-mx32/status-successful-status.gen.test
--- 5.5-3/tests-mx32/status-successful-status.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/status-successful-status.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (status-successful-status -a10 -e trace=chdir --status=successful); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a10 -e trace=chdir --status=successful
diff -pruN 5.5-3/tests-mx32/strace--absolute-timestamps-format-time.gen.test 5.9-0ubuntu2/tests-mx32/strace--absolute-timestamps-format-time.gen.test
--- 5.5-3/tests-mx32/strace--absolute-timestamps-format-time.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--absolute-timestamps-format-time.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-time +strace-t.test --absolute-timestamps=format:time); do not edit.
+set -- --absolute-timestamps=format:time
+. "${srcdir=.}/strace-t.test"
diff -pruN 5.5-3/tests-mx32/strace--absolute-timestamps-format-time-precision-ms.gen.test 5.9-0ubuntu2/tests-mx32/strace--absolute-timestamps-format-time-precision-ms.gen.test
--- 5.5-3/tests-mx32/strace--absolute-timestamps-format-time-precision-ms.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--absolute-timestamps-format-time-precision-ms.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-time-precision-ms +strace-tt.test 3 --absolute-timestamps=format:time --absolute-timestamps=precision:ms); do not edit.
+set -- 3 --absolute-timestamps=format:time --absolute-timestamps=precision:ms
+. "${srcdir=.}/strace-tt.test"
diff -pruN 5.5-3/tests-mx32/strace--absolute-timestamps-format-time-precision-ns.gen.test 5.9-0ubuntu2/tests-mx32/strace--absolute-timestamps-format-time-precision-ns.gen.test
--- 5.5-3/tests-mx32/strace--absolute-timestamps-format-time-precision-ns.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--absolute-timestamps-format-time-precision-ns.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-time-precision-ns +strace-tt.test 9 --absolute-timestamps=format:time --absolute-timestamps=precision:ns); do not edit.
+set -- 9 --absolute-timestamps=format:time --absolute-timestamps=precision:ns
+. "${srcdir=.}/strace-tt.test"
diff -pruN 5.5-3/tests-mx32/strace--absolute-timestamps-format-time-precision-s.gen.test 5.9-0ubuntu2/tests-mx32/strace--absolute-timestamps-format-time-precision-s.gen.test
--- 5.5-3/tests-mx32/strace--absolute-timestamps-format-time-precision-s.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--absolute-timestamps-format-time-precision-s.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-time-precision-s +strace-t.test --absolute-timestamps=format:time --absolute-timestamps=precision:s); do not edit.
+set -- --absolute-timestamps=format:time --absolute-timestamps=precision:s
+. "${srcdir=.}/strace-t.test"
diff -pruN 5.5-3/tests-mx32/strace--absolute-timestamps-format-time-precision-us.gen.test 5.9-0ubuntu2/tests-mx32/strace--absolute-timestamps-format-time-precision-us.gen.test
--- 5.5-3/tests-mx32/strace--absolute-timestamps-format-time-precision-us.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--absolute-timestamps-format-time-precision-us.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-time-precision-us +strace-tt.test 6 --absolute-timestamps=format:time --absolute-timestamps=precision:us); do not edit.
+set -- 6 --absolute-timestamps=format:time --absolute-timestamps=precision:us
+. "${srcdir=.}/strace-tt.test"
diff -pruN 5.5-3/tests-mx32/strace--absolute-timestamps-format-unix-precision-ms.gen.test 5.9-0ubuntu2/tests-mx32/strace--absolute-timestamps-format-unix-precision-ms.gen.test
--- 5.5-3/tests-mx32/strace--absolute-timestamps-format-unix-precision-ms.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--absolute-timestamps-format-unix-precision-ms.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-unix-precision-ms +strace-ttt.test 3 --absolute-timestamps=precision:ms --absolute-timestamps=format:unix); do not edit.
+set -- 3 --absolute-timestamps=precision:ms --absolute-timestamps=format:unix
+. "${srcdir=.}/strace-ttt.test"
diff -pruN 5.5-3/tests-mx32/strace--absolute-timestamps-format-unix-precision-ns.gen.test 5.9-0ubuntu2/tests-mx32/strace--absolute-timestamps-format-unix-precision-ns.gen.test
--- 5.5-3/tests-mx32/strace--absolute-timestamps-format-unix-precision-ns.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--absolute-timestamps-format-unix-precision-ns.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-unix-precision-ns +strace-ttt.test 9 --absolute-timestamps=format:unix --absolute-timestamps=precision:ns); do not edit.
+set -- 9 --absolute-timestamps=format:unix --absolute-timestamps=precision:ns
+. "${srcdir=.}/strace-ttt.test"
diff -pruN 5.5-3/tests-mx32/strace--absolute-timestamps-format-unix-precision-s.gen.test 5.9-0ubuntu2/tests-mx32/strace--absolute-timestamps-format-unix-precision-s.gen.test
--- 5.5-3/tests-mx32/strace--absolute-timestamps-format-unix-precision-s.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--absolute-timestamps-format-unix-precision-s.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-unix-precision-s +strace-ttt.test 0 --absolute-timestamps=format:unix --absolute-timestamps=precision:s); do not edit.
+set -- 0 --absolute-timestamps=format:unix --absolute-timestamps=precision:s
+. "${srcdir=.}/strace-ttt.test"
diff -pruN 5.5-3/tests-mx32/strace--absolute-timestamps-format-unix-precision-us.gen.test 5.9-0ubuntu2/tests-mx32/strace--absolute-timestamps-format-unix-precision-us.gen.test
--- 5.5-3/tests-mx32/strace--absolute-timestamps-format-unix-precision-us.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--absolute-timestamps-format-unix-precision-us.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps-format-unix-precision-us +strace-ttt.test 6 --absolute-timestamps=precision:us --absolute-timestamps=format:unix); do not edit.
+set -- 6 --absolute-timestamps=precision:us --absolute-timestamps=format:unix
+. "${srcdir=.}/strace-ttt.test"
diff -pruN 5.5-3/tests-mx32/strace--absolute-timestamps.gen.test 5.9-0ubuntu2/tests-mx32/strace--absolute-timestamps.gen.test
--- 5.5-3/tests-mx32/strace--absolute-timestamps.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--absolute-timestamps.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--absolute-timestamps +strace-t.test --absolute-timestamps); do not edit.
+set -- --absolute-timestamps
+. "${srcdir=.}/strace-t.test"
diff -pruN 5.5-3/tests-mx32/strace-DDD.test 5.9-0ubuntu2/tests-mx32/strace-DDD.test
--- 5.5-3/tests-mx32/strace-DDD.test	2019-11-07 19:58:36.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace-DDD.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
 #
 # Check -DDD option.
 #
-# Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
+# Copyright (c) 2019-2020 Dmitry V. Levin <ldv@altlinux.org>
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,6 +10,8 @@
 . "${srcdir=.}/init.sh"
 
 check_prog sed
+run_prog_skip_if_failed \
+	kill -0 $$
 
 status_file=/proc/self/status
 [ -f "$status_file" ] ||
@@ -19,10 +21,16 @@ stat_file=/proc/self/stat
 [ -f "$stat_file" ] ||
 	framework_skip_ "$stat_file is not available"
 
+reapid="$(../get_process_reaper)" && [ "$reapid" -ge 1 ] ||
+	fail_ 'get_process_reaper failed'
+
 set -- -enone -esignal=none ../tracer_ppid_pgid_sid
 run_strace "$@" > "$OUT"
-read -r ppid pgid sid < "$OUT" &&
+read -r tracer_pid ppid pgid sid < "$OUT" &&
+[ "$tracer_pid" -gt 1 ] &&
+[ "$tracer_pid" -ne "$reapid" ] &&
 [ "$ppid" -gt 1 ] &&
+[ "$ppid" -ne "$reapid" ] &&
 [ "$pgid" -ge 0 ] &&
 [ "$sid" -ge 0 ] || {
 	cat < "$OUT" > "$LOG"
@@ -34,35 +42,52 @@ pgid0="$pgid"
 sid0="$sid"
 
 run_strace -D "$@" > "$OUT"
-read -r ppid pgid sid < "$OUT" &&
-[ "$ppid" -eq 1 ] &&
+read -r tracer_pid ppid pgid sid < "$OUT" &&
+[ "$tracer_pid" -gt 1 ] &&
+[ "$tracer_pid" -ne "$reapid" ] &&
+[ "$ppid" -eq "$reapid" ] &&
 [ "$pgid" = "$pgid0" ] &&
 [ "$sid" = "$sid0" ] || {
 	cat < "$OUT" > "$LOG"
 	dump_log_and_fail_with "$STRACE $args: unexpected output"
 }
+while kill -0 "$tracer_pid" 2> /dev/null; do
+	$SLEEP_A_BIT
+done
 match_diff
 
 run_strace -DD "$@" > "$OUT"
-read -r ppid pgid sid < "$OUT" &&
-[ "$ppid" -eq 1 ] &&
+read -r tracer_pid ppid pgid sid < "$OUT" &&
+[ "$tracer_pid" -gt 1 ] &&
+[ "$tracer_pid" -ne "$reapid" ] &&
+[ "$ppid" -eq "$reapid" ] &&
 [ "$pgid" -gt 1 ] &&
+[ "$pgid" -ne "$reapid" ] &&
 [ "$pgid" != "$pgid0" ] &&
 [ "$pgid" != "$sid" ] &&
 [ "$sid" = "$sid0" ] || {
 	cat < "$OUT" > "$LOG"
 	dump_log_and_fail_with "$STRACE $args: unexpected output"
 }
+while kill -0 "$tracer_pid" 2> /dev/null; do
+	$SLEEP_A_BIT
+done
 match_diff
 
 run_strace -DDD "$@" > "$OUT"
-read -r ppid pgid sid < "$OUT" &&
-[ "$ppid" -eq 1 ] &&
+read -r tracer_pid ppid pgid sid < "$OUT" &&
+[ "$tracer_pid" -gt 1 ] &&
+[ "$tracer_pid" -ne "$reapid" ] &&
+[ "$ppid" -eq "$reapid" ] &&
 [ "$pgid" -gt 1 ] &&
+[ "$pgid" -ne "$reapid" ] &&
 [ "$pgid" != "$pgid0" ] &&
 [ "$sid" = "$pgid" ] &&
 [ "$sid" != "$sid0" ] || {
 	cat < "$OUT" > "$LOG"
 	dump_log_and_fail_with "$STRACE $args: unexpected output"
 }
+while kill -0 "$tracer_pid" 2> /dev/null; do
+	$SLEEP_A_BIT
+done
 match_diff
diff -pruN 5.5-3/tests-mx32/strace-DD.expected 5.9-0ubuntu2/tests-mx32/strace-DD.expected
--- 5.5-3/tests-mx32/strace-DD.expected	2019-10-07 11:33:37.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace-DD.expected	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-nanosleep({tv_sec=2, tv_nsec=0}, NULL)  = ? ERESTART_RESTARTBLOCK (Interrupted by signal)
diff -pruN 5.5-3/tests-mx32/strace-DD.test 5.9-0ubuntu2/tests-mx32/strace-DD.test
--- 5.5-3/tests-mx32/strace-DD.test	2019-11-19 23:17:53.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace-DD.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
 #
 # Check -DD option.
 #
-# Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
+# Copyright (c) 2019-2020 Dmitry V. Levin <ldv@altlinux.org>
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -12,27 +12,62 @@
 [ "$STRACE" = "$STRACE_EXE" ] ||
 	skip_ 'Not applicable: $STRACE != $STRACE_EXE'
 
-check_prog timeout
+run_prog_skip_if_failed \
+        kill -0 $$
+
+status_file=/proc/self/status
+get_tracer_pid()
+{
+	sed '/^TracerPid:[[:space:]]*/!d;s///' "$@"
+}
+[ "$(get_tracer_pid "$status_file")" -ge 0 ] ||
+        framework_skip_ "$status_file is not available"
+
 run_prog ../sleep 0
 
+sleep_duration="$(($TIMEOUT_DURATION/2))"
+
 test_D()
 {
-	local exp args
-	exp="$1"; shift
+	local tracee_pid tracer_pid rc sig=15
 
-	set -- -e signal=none -e trace=nanosleep "$@" ../sleep 2
-	args="$*"
-	set -- timeout -s XCPU 1 $STRACE -o "$LOG" "$@"
+	set -- $STRACE --output="$LOG" --columns=39 \
+		--interruptible=anywhere --trace=nanosleep "$@" -- \
+		../sleep "$sleep_duration"
 	> "$LOG"
-	"$@" && rc=0 || rc=$?
-	[ "$rc" = 124 ] ||
-		dump_log_and_fail_with \
-			"$* failed with unexpected exit code $rc"
+
+	../setpgrp-exec "$@" &
+	tracee_pid=$!
+
+	while tracer_pid="$(get_tracer_pid "/proc/$tracee_pid/status")"; do
+		[ "$tracer_pid" = 0 ] ||
+			break
+		$SLEEP_A_BIT
+	done
+
 	$SLEEP_A_BIT
-	match_diff "$LOG" "$exp"
+	kill -$sig -$tracee_pid
+
+	wait $tracee_pid && rc=0 || rc=$?
+	[ "$rc" -eq $((128 + $sig)) ] ||
+		dump_log_and_fail_with \
+			"$* failed with unexpected exit status $rc"
+
+	while kill -0 "$tracer_pid" 2> /dev/null; do
+		$SLEEP_A_BIT
+	done
+	match_diff "$LOG" "$EXP"
 }
 
-printf %s 'nanosleep({tv_sec=2, tv_nsec=0}, ' > "$EXP"
-test_D "$EXP" -D
-test_D "$srcdir/$NAME.expected" -DD
-test_D "$srcdir/$NAME.expected" -DDD
+printf 'nanosleep({tv_sec=%s, tv_nsec=0}, ' "$sleep_duration" > "$EXP"
+test_D -D
+
+uid="${UID:-`id -u`}"
+cat > "$EXP" <<__EOF__
+nanosleep({tv_sec=$sleep_duration, tv_nsec=0}, NULL) = ? ERESTART_RESTARTBLOCK (Interrupted by signal)
+--- SIGTERM {si_signo=SIGTERM, si_code=SI_USER, si_pid=$$, si_uid=$uid} ---
++++ killed by SIGTERM +++
+__EOF__
+
+test_D -DD
+test_D -DDD
diff -pruN 5.5-3/tests-mx32/strace-D.test 5.9-0ubuntu2/tests-mx32/strace-D.test
--- 5.5-3/tests-mx32/strace-D.test	2019-10-21 00:07:20.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace-D.test	2020-05-27 08:00:00.000000000 +0000
@@ -3,6 +3,7 @@
 # Check -D option.
 #
 # Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
+# Copyright (c) 2019-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,6 +11,8 @@
 . "${srcdir=.}/init.sh"
 
 check_prog sed
+run_prog_skip_if_failed \
+	kill -0 $$
 
 get_parent_pid()
 {
@@ -21,11 +24,7 @@ get_tracer_pid()
 	sed '/^TracerPid:[[:space:]]*/!d;s///'
 }
 
-status_file=/proc/self/status
-[ -f "$status_file" ] ||
-	framework_skip_ "$status_file is not available"
-
-set -- sed -r -n '/^(P|Tracer)Pid:/p' "$status_file"
+set -- ../print_ppid_tracerpid
 "$@" > "$LOG" ||
 	framework_skip_ "$* does not work"
 
@@ -35,7 +34,7 @@ set -- sed -r -n '/^(P|Tracer)Pid:/p' "$
 	dump_log_and_fail_with "$*: unexpected output"
 
 # !-D: PPid > 0, TracerPid > 0, PPid == TracerPid
-run_strace -q -enone "$@" > "$OUT"
+run_strace -e q=attach,personality -enone "$@" > "$OUT"
 [ "$(get_parent_pid < "$OUT")" -gt 0 ] &&
 [ "$(get_tracer_pid < "$OUT")" -gt 0 ] &&
 [ "$(get_parent_pid < "$OUT")" = "$(get_tracer_pid < "$OUT")" ] || {
@@ -46,17 +45,25 @@ match_diff
 
 test_parent_tracer_pid()
 {
-	local d
+	local d parent_pid tracer_pid
 	d="$1"; shift
 
 	# -D/-DD/-DDD: PPid > 0, TracerPid > 0, PPid != TracerPid
 	run_strace $d -q -enone "$@" > "$OUT"
-	[ "$(get_parent_pid < "$OUT")" -gt 0 ] &&
-	[ "$(get_tracer_pid < "$OUT")" -gt 0 ] &&
-	[ "$(get_parent_pid < "$OUT")" != "$(get_tracer_pid < "$OUT")" ] || {
+
+	parent_pid="$(get_parent_pid < "$OUT")" &&
+	[ "$parent_pid" -gt 0 ] &&
+	tracer_pid="$(get_tracer_pid < "$OUT")" &&
+	[ "$tracer_pid" -gt 0 ] &&
+	[ "$parent_pid" != "$tracer_pid" ] || {
 		cat < "$OUT" > "$LOG"
 		dump_log_and_fail_with "$STRACE $args: unexpected output"
 	}
+
+	while kill -0 "$tracer_pid" 2> /dev/null; do
+		$SLEEP_A_BIT
+	done
+
 	match_diff
 }
 
diff -pruN 5.5-3/tests-mx32/strace-E-override.test 5.9-0ubuntu2/tests-mx32/strace-E-override.test
--- 5.5-3/tests-mx32/strace-E-override.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace-E-override.test	2020-08-03 08:00:00.000000000 +0000
@@ -0,0 +1,14 @@
+#!/bin/sh
+#
+# Check that --env option does not affect strace's own environment.
+#
+# Copyright (c) 2019-2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: GPL-2.0-or-later
+
+. "${srcdir=.}/init.sh"
+
+check_prog true
+run_prog true
+run_strace --quiet=all --trace=none --signal=none --env=PATH=/ $args
diff -pruN 5.5-3/tests-mx32/strace-E-unset.expected 5.9-0ubuntu2/tests-mx32/strace-E-unset.expected
--- 5.5-3/tests-mx32/strace-E-unset.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace-E-unset.expected	2020-04-09 12:00:00.000000000 +0000
@@ -0,0 +1,5 @@
+execve\("\.\./sleep", \["\.\./sleep", "0"\], \[.*"option_E_var=OPTION_E_VAL".*\]\) = 0
+execve\("\.\./sleep", \["\.\./sleep", "0"\], \[.*"option_E_unsets=OPTION_E_UNSETS".*\]\) = 0
+execve\("\.\./sleep", \["\.\./sleep", "0"\], \[.*"option_E_mod=OPTION_E_NEW".*\]\) = 0
+execve\("\.\./sleep", \["\.\./sleep", "0"\], \[.*"option_E_mods=OPTION_E_MODS".*\]\) = 0
+!execve\("\.\./sleep", \["\.\./sleep", "0"\], \[.*"option_E_unset=.*\]\) = 0
diff -pruN 5.5-3/tests-mx32/strace-E-unset.test 5.9-0ubuntu2/tests-mx32/strace-E-unset.test
--- 5.5-3/tests-mx32/strace-E-unset.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace-E-unset.test	2020-08-03 08:00:00.000000000 +0000
@@ -0,0 +1,32 @@
+#!/bin/sh
+#
+# Check modify/unset behaviour of -E/--env option.
+#
+# Copyright (c) 2016-2020 The strace developers.
+# All rights reserved.
+#
+# SPDX-License-Identifier: GPL-2.0-or-later
+
+. "${srcdir=.}/init.sh"
+
+export option_E_var=OPTION_E_VAL
+export option_E_mod=OPTION_E_MOD
+export option_E_mods=OPTION_E_MODS
+export option_E_unset=OPTION_E_UNSET
+export option_E_unsets=OPTION_E_UNSETS
+
+run_prog ../sleep 0
+run_strace -qqq -e signal=none -e trace=execve -v \
+	-E option_E_mod=OPTION_E_NEW \
+	-E option_E_unset \
+	-E option_E_missing \
+	$args
+match_grep
+
+run_prog ../sleep 0
+run_strace --quiet=all --signal=none --trace=execve --no-abbrev \
+	--env=option_E_mod=OPTION_E_NEW \
+	--env=option_E_unset \
+	--env=option_E_missing \
+	$args
+match_grep
diff -pruN 5.5-3/tests-mx32/strace-ff.test 5.9-0ubuntu2/tests-mx32/strace-ff.test
--- 5.5-3/tests-mx32/strace-ff.test	2019-11-28 19:30:05.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace-ff.test	2020-04-03 22:58:26.000000000 +0000
@@ -1,14 +1,16 @@
-#!/bin/sh
+#!/bin/sh -efu
 #
 # Check -ff option.
 #
-# Copyright (c) 2016-2019 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/init.sh"
 
+ff_opt="${*:--ff}"
+
 run_prog_skip_if_failed \
 	kill -0 $$
 
@@ -22,12 +24,13 @@ while ! [ -s "$OUT" ]; do
 		fail_ 'set_ptracer_any sleep failed'
 done
 
-run_strace -a14 -eexit_group -ff -p $tracee_pid
+run_strace --quiet=personality -a14 -eexit_group ${ff_opt} -p $tracee_pid
 
 # check that output matches
 match_diff "$LOG.$tracee_pid"
 
 # check that no other output files have been created
+set +f
 set -- "$LOG".*
 [ "$LOG.$tracee_pid" = "$*" ] ||
 	fail_ "too many output files: $*"
diff -pruN 5.5-3/tests-mx32/strace--follow-forks-output-separately.expected 5.9-0ubuntu2/tests-mx32/strace--follow-forks-output-separately.expected
--- 5.5-3/tests-mx32/strace--follow-forks-output-separately.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--follow-forks-output-separately.expected	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+exit_group(0) = ?
++++ exited with 0 +++
diff -pruN 5.5-3/tests-mx32/strace--follow-forks-output-separately.gen.test 5.9-0ubuntu2/tests-mx32/strace--follow-forks-output-separately.gen.test
--- 5.5-3/tests-mx32/strace--follow-forks-output-separately.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--follow-forks-output-separately.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--follow-forks-output-separately +strace-ff.test --follow-forks --output-separately); do not edit.
+set -- --follow-forks --output-separately
+. "${srcdir=.}/strace-ff.test"
diff -pruN 5.5-3/tests-mx32/strace-n.c 5.9-0ubuntu2/tests-mx32/strace-n.c
--- 5.5-3/tests-mx32/strace-n.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace-n.c	2020-08-21 16:39:53.000000000 +0000
@@ -0,0 +1,40 @@
+/*
+ * Test strace's -n option.
+ *
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+
+#include <stdio.h>
+#include <unistd.h>
+#include <errno.h>
+
+#define SC_listen 4
+
+int
+main(void)
+{
+	int rc;
+
+#if defined __NR_socketcall
+	if (syscall(__NR_socketcall, 0L, 0L, 0L, 0L, 0L) < 0
+		&& EINVAL == errno)
+	{
+		const long args[] = { 0, 0 };
+		rc = syscall(__NR_socketcall, SC_listen, args);
+		printf("[%4u] listen(0, 0) = %s\n", __NR_socketcall, sprintrc(rc));
+	}
+#endif
+
+#if defined __NR_listen
+	rc = syscall(__NR_listen, 0, 0);
+	printf("[%4u] listen(0, 0) = %s\n", __NR_listen, sprintrc(rc));
+#endif
+
+	return 0;
+}
diff -pruN 5.5-3/tests-mx32/strace-n.gen.test 5.9-0ubuntu2/tests-mx32/strace-n.gen.test
--- 5.5-3/tests-mx32/strace-n.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace-n.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace-n -e trace=listen -n -qq -a 12); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -e trace=listen -n -qq -a 12
diff -pruN 5.5-3/tests-mx32/strace--relative-timestamps.expected 5.9-0ubuntu2/tests-mx32/strace--relative-timestamps.expected
--- 5.5-3/tests-mx32/strace--relative-timestamps.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--relative-timestamps.expected	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+[ ]{5}0\.0{6} execve\("\.\./sleep", \["\.\./sleep", "1"\], 0x[[:xdigit:]]* /\* [[:digit:]]* vars \*/\) = 0
+[ ]{5}(1\.[01]|0\.9)[[:digit:]]{5} \+\+\+ exited with 0 \+\+\+
diff -pruN 5.5-3/tests-mx32/strace--relative-timestamps.gen.test 5.9-0ubuntu2/tests-mx32/strace--relative-timestamps.gen.test
--- 5.5-3/tests-mx32/strace--relative-timestamps.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--relative-timestamps.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--relative-timestamps +strace-r.test --relative-timestamps); do not edit.
+set -- --relative-timestamps
+. "${srcdir=.}/strace-r.test"
diff -pruN 5.5-3/tests-mx32/strace--relative-timestamps-ms.expected 5.9-0ubuntu2/tests-mx32/strace--relative-timestamps-ms.expected
--- 5.5-3/tests-mx32/strace--relative-timestamps-ms.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--relative-timestamps-ms.expected	2020-02-19 17:26:58.000000000 +0000
@@ -0,0 +1,2 @@
+[ ]{5}0\.0{3} execve\("\.\./sleep", \["\.\./sleep", "1"\], 0x[[:xdigit:]]* /\* [[:digit:]]* vars \*/\) = 0
+[ ]{5}(1\.[01]|0\.9)[[:digit:]]{2} \+\+\+ exited with 0 \+\+\+
diff -pruN 5.5-3/tests-mx32/strace--relative-timestamps-ms.gen.test 5.9-0ubuntu2/tests-mx32/strace--relative-timestamps-ms.gen.test
--- 5.5-3/tests-mx32/strace--relative-timestamps-ms.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--relative-timestamps-ms.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--relative-timestamps-ms +strace-r.test --relative-timestamps=ms); do not edit.
+set -- --relative-timestamps=ms
+. "${srcdir=.}/strace-r.test"
diff -pruN 5.5-3/tests-mx32/strace--relative-timestamps-ns.expected 5.9-0ubuntu2/tests-mx32/strace--relative-timestamps-ns.expected
--- 5.5-3/tests-mx32/strace--relative-timestamps-ns.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--relative-timestamps-ns.expected	2020-02-19 17:26:58.000000000 +0000
@@ -0,0 +1,2 @@
+[ ]{5}0\.0{9} execve\("\.\./sleep", \["\.\./sleep", "1"\], 0x[[:xdigit:]]* /\* [[:digit:]]* vars \*/\) = 0
+[ ]{5}(1\.[01]|0\.9)[[:digit:]]{8} \+\+\+ exited with 0 \+\+\+
diff -pruN 5.5-3/tests-mx32/strace--relative-timestamps-ns.gen.test 5.9-0ubuntu2/tests-mx32/strace--relative-timestamps-ns.gen.test
--- 5.5-3/tests-mx32/strace--relative-timestamps-ns.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--relative-timestamps-ns.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--relative-timestamps-ns +strace-r.test --relative-timestamps=ns); do not edit.
+set -- --relative-timestamps=ns
+. "${srcdir=.}/strace-r.test"
diff -pruN 5.5-3/tests-mx32/strace--relative-timestamps-s.expected 5.9-0ubuntu2/tests-mx32/strace--relative-timestamps-s.expected
--- 5.5-3/tests-mx32/strace--relative-timestamps-s.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--relative-timestamps-s.expected	2020-02-19 17:26:58.000000000 +0000
@@ -0,0 +1,2 @@
+[ ]{5}0 execve\("\.\./sleep", \["\.\./sleep", "1"\], 0x[[:xdigit:]]* /\* [[:digit:]]* vars \*/\) = 0
+[ ]{5}[01] \+\+\+ exited with 0 \+\+\+
diff -pruN 5.5-3/tests-mx32/strace--relative-timestamps-s.gen.test 5.9-0ubuntu2/tests-mx32/strace--relative-timestamps-s.gen.test
--- 5.5-3/tests-mx32/strace--relative-timestamps-s.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--relative-timestamps-s.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--relative-timestamps-s +strace-r.test --relative-timestamps=s); do not edit.
+set -- --relative-timestamps=s
+. "${srcdir=.}/strace-r.test"
diff -pruN 5.5-3/tests-mx32/strace--relative-timestamps-us.expected 5.9-0ubuntu2/tests-mx32/strace--relative-timestamps-us.expected
--- 5.5-3/tests-mx32/strace--relative-timestamps-us.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--relative-timestamps-us.expected	2020-02-19 17:26:58.000000000 +0000
@@ -0,0 +1,2 @@
+[ ]{5}0\.0{6} execve\("\.\./sleep", \["\.\./sleep", "1"\], 0x[[:xdigit:]]* /\* [[:digit:]]* vars \*/\) = 0
+[ ]{5}(1\.[01]|0\.9)[[:digit:]]{5} \+\+\+ exited with 0 \+\+\+
diff -pruN 5.5-3/tests-mx32/strace--relative-timestamps-us.gen.test 5.9-0ubuntu2/tests-mx32/strace--relative-timestamps-us.gen.test
--- 5.5-3/tests-mx32/strace--relative-timestamps-us.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--relative-timestamps-us.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--relative-timestamps-us +strace-r.test --relative-timestamps=us); do not edit.
+set -- --relative-timestamps=us
+. "${srcdir=.}/strace-r.test"
diff -pruN 5.5-3/tests-mx32/strace-r.test 5.9-0ubuntu2/tests-mx32/strace-r.test
--- 5.5-3/tests-mx32/strace-r.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace-r.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,13 +2,15 @@
 #
 # Check -r option.
 #
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/init.sh"
 
+r_opt="${1:--r}"
+
 run_prog ../sleep 0
-run_strace -r -eexecve ../sleep 1
+run_strace "${r_opt}" -eexecve ../sleep 1
 match_grep
diff -pruN 5.5-3/tests-mx32/strace-S.test 5.9-0ubuntu2/tests-mx32/strace-S.test
--- 5.5-3/tests-mx32/strace-S.test	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace-S.test	2020-03-23 03:19:09.000000000 +0000
@@ -35,6 +35,10 @@ for s in '' '-S time' --summary-sort-by=
 	test_c "$s" '-n -r' \
 		's/^[[:space:]]+([0-9]+)[.,]([0-9]+)[[:space:]].*/\1\t\2/p'
 done
+for s in '-S avg_time' --summary-sort-by=time_avg; do
+	test_c "$s" '-n -r' \
+		'/^[[:space:]]+[0-9]/ s/^'"$c$c$c$c"'[[:space:]].*/\3/p'
+done
 for s in '-S calls' --summary-sort-by=count; do
 	test_c "$s" '-n -r' \
 		'/^[[:space:]]+[0-9]/ s/^'"$c$c$c$c"'[[:space:]].*/\4/p'
@@ -47,3 +51,11 @@ for s in '-S error' --summary-sort-by=er
 	test_c "$s" '-n -r' \
 		'/^[[:space:]]+[0-9]/ s/^'"$c$c$c$c"'([[:space:]]+([0-9]+))?'"$c"'$/\6/p'
 done
+for s in '--summary-columns=time,time-max,name -S max_time' '-U time-percent,max_time,syscall_name --summary-sort-by=longest'; do
+	test_c "$s" '-n -r' \
+		'/^[[:space:]]+[0-9]/ s/^'"$c$c"'[[:space:]].*/\2/p'
+done
+for s in '--summary-columns=time,time_min,name -S min-time' '-U time_percent,min_time,syscall-name --summary-sort-by=shortest'; do
+	test_c "$s" '-n -r' \
+		'/^[[:space:]]+[0-9]/ s/^'"$c$c"'[[:space:]].*/\2/p'
+done
diff -pruN 5.5-3/tests-mx32/strace--strings-in-hex-all.c 5.9-0ubuntu2/tests-mx32/strace--strings-in-hex-all.c
--- 5.5-3/tests-mx32/strace--strings-in-hex-all.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--strings-in-hex-all.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define STRACE_XX 1
+#include "strace-x.c"
diff -pruN 5.5-3/tests-mx32/strace--strings-in-hex-all.gen.test 5.9-0ubuntu2/tests-mx32/strace--strings-in-hex-all.gen.test
--- 5.5-3/tests-mx32/strace--strings-in-hex-all.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--strings-in-hex-all.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--strings-in-hex-all --trace=chdir --strings-in-hex=all --columns=18); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=chdir --strings-in-hex=all --columns=18
diff -pruN 5.5-3/tests-mx32/strace--strings-in-hex.c 5.9-0ubuntu2/tests-mx32/strace--strings-in-hex.c
--- 5.5-3/tests-mx32/strace--strings-in-hex.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--strings-in-hex.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define STRACE_XX 1
+#include "strace-x.c"
diff -pruN 5.5-3/tests-mx32/strace--strings-in-hex.gen.test 5.9-0ubuntu2/tests-mx32/strace--strings-in-hex.gen.test
--- 5.5-3/tests-mx32/strace--strings-in-hex.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--strings-in-hex.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--strings-in-hex --trace=chdir --strings-in-hex --columns=18); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=chdir --strings-in-hex --columns=18
diff -pruN 5.5-3/tests-mx32/strace--strings-in-hex-non-ascii.c 5.9-0ubuntu2/tests-mx32/strace--strings-in-hex-non-ascii.c
--- 5.5-3/tests-mx32/strace--strings-in-hex-non-ascii.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--strings-in-hex-non-ascii.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define STRACE_XX 0
+#include "strace-x.c"
diff -pruN 5.5-3/tests-mx32/strace--strings-in-hex-non-ascii.gen.test 5.9-0ubuntu2/tests-mx32/strace--strings-in-hex-non-ascii.gen.test
--- 5.5-3/tests-mx32/strace--strings-in-hex-non-ascii.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--strings-in-hex-non-ascii.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--strings-in-hex-non-ascii --trace=chdir --strings-in-hex=non-ascii --columns=12); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff --trace=chdir --strings-in-hex=non-ascii --columns=12
diff -pruN 5.5-3/tests-mx32/strace--syscall-times.expected 5.9-0ubuntu2/tests-mx32/strace--syscall-times.expected
--- 5.5-3/tests-mx32/strace--syscall-times.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--syscall-times.expected	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1 @@
+nanosleep\(\{tv_sec=1, tv_nsec=0\}, NULL\) = 0 <(1\.[01]|0\.9)[[:digit:]]{5}>
diff -pruN 5.5-3/tests-mx32/strace--syscall-times.gen.test 5.9-0ubuntu2/tests-mx32/strace--syscall-times.gen.test
--- 5.5-3/tests-mx32/strace--syscall-times.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--syscall-times.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--syscall-times +strace-T.test --syscall-times); do not edit.
+set -- --syscall-times
+. "${srcdir=.}/strace-T.test"
diff -pruN 5.5-3/tests-mx32/strace--syscall-times-ms.expected 5.9-0ubuntu2/tests-mx32/strace--syscall-times-ms.expected
--- 5.5-3/tests-mx32/strace--syscall-times-ms.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--syscall-times-ms.expected	2020-02-19 17:26:58.000000000 +0000
@@ -0,0 +1 @@
+nanosleep\(\{tv_sec=1, tv_nsec=0\}, NULL\) = 0 <(1\.[01]|0\.9)[[:digit:]]{2}>
diff -pruN 5.5-3/tests-mx32/strace--syscall-times-ms.gen.test 5.9-0ubuntu2/tests-mx32/strace--syscall-times-ms.gen.test
--- 5.5-3/tests-mx32/strace--syscall-times-ms.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--syscall-times-ms.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--syscall-times-ms +strace-T.test --syscall-times=ms); do not edit.
+set -- --syscall-times=ms
+. "${srcdir=.}/strace-T.test"
diff -pruN 5.5-3/tests-mx32/strace--syscall-times-ns.expected 5.9-0ubuntu2/tests-mx32/strace--syscall-times-ns.expected
--- 5.5-3/tests-mx32/strace--syscall-times-ns.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--syscall-times-ns.expected	2020-02-19 17:26:58.000000000 +0000
@@ -0,0 +1 @@
+nanosleep\(\{tv_sec=1, tv_nsec=0\}, NULL\) = 0 <(1\.[01]|0\.9)[[:digit:]]{8}>
diff -pruN 5.5-3/tests-mx32/strace--syscall-times-ns.gen.test 5.9-0ubuntu2/tests-mx32/strace--syscall-times-ns.gen.test
--- 5.5-3/tests-mx32/strace--syscall-times-ns.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--syscall-times-ns.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--syscall-times-ns +strace-T.test --syscall-times=ns); do not edit.
+set -- --syscall-times=ns
+. "${srcdir=.}/strace-T.test"
diff -pruN 5.5-3/tests-mx32/strace--syscall-times-s.expected 5.9-0ubuntu2/tests-mx32/strace--syscall-times-s.expected
--- 5.5-3/tests-mx32/strace--syscall-times-s.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--syscall-times-s.expected	2020-02-19 17:26:58.000000000 +0000
@@ -0,0 +1 @@
+nanosleep\(\{tv_sec=1, tv_nsec=0\}, NULL\) = 0 <[01]>
diff -pruN 5.5-3/tests-mx32/strace--syscall-times-s.gen.test 5.9-0ubuntu2/tests-mx32/strace--syscall-times-s.gen.test
--- 5.5-3/tests-mx32/strace--syscall-times-s.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--syscall-times-s.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--syscall-times-s +strace-T.test --syscall-times=s); do not edit.
+set -- --syscall-times=s
+. "${srcdir=.}/strace-T.test"
diff -pruN 5.5-3/tests-mx32/strace--syscall-times-us.expected 5.9-0ubuntu2/tests-mx32/strace--syscall-times-us.expected
--- 5.5-3/tests-mx32/strace--syscall-times-us.expected	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--syscall-times-us.expected	2020-02-19 17:26:58.000000000 +0000
@@ -0,0 +1 @@
+nanosleep\(\{tv_sec=1, tv_nsec=0\}, NULL\) = 0 <(1\.[01]|0\.9)[[:digit:]]{5}>
diff -pruN 5.5-3/tests-mx32/strace--syscall-times-us.gen.test 5.9-0ubuntu2/tests-mx32/strace--syscall-times-us.gen.test
--- 5.5-3/tests-mx32/strace--syscall-times-us.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--syscall-times-us.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--syscall-times-us +strace-T.test --syscall-times=us); do not edit.
+set -- --syscall-times=us
+. "${srcdir=.}/strace-T.test"
diff -pruN 5.5-3/tests-mx32/strace--timestamps.gen.test 5.9-0ubuntu2/tests-mx32/strace--timestamps.gen.test
--- 5.5-3/tests-mx32/strace--timestamps.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--timestamps.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps +strace-t.test --timestamps); do not edit.
+set -- --timestamps
+. "${srcdir=.}/strace-t.test"
diff -pruN 5.5-3/tests-mx32/strace--timestamps-time.gen.test 5.9-0ubuntu2/tests-mx32/strace--timestamps-time.gen.test
--- 5.5-3/tests-mx32/strace--timestamps-time.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--timestamps-time.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-time +strace-t.test --timestamps=time); do not edit.
+set -- --timestamps=time
+. "${srcdir=.}/strace-t.test"
diff -pruN 5.5-3/tests-mx32/strace--timestamps-time-ms.gen.test 5.9-0ubuntu2/tests-mx32/strace--timestamps-time-ms.gen.test
--- 5.5-3/tests-mx32/strace--timestamps-time-ms.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--timestamps-time-ms.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-time-ms +strace-tt.test 3 --timestamps=time,ms); do not edit.
+set -- 3 --timestamps=time,ms
+. "${srcdir=.}/strace-tt.test"
diff -pruN 5.5-3/tests-mx32/strace--timestamps-time-ns.gen.test 5.9-0ubuntu2/tests-mx32/strace--timestamps-time-ns.gen.test
--- 5.5-3/tests-mx32/strace--timestamps-time-ns.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--timestamps-time-ns.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-time-ns +strace-tt.test 9 --timestamps=time,ns); do not edit.
+set -- 9 --timestamps=time,ns
+. "${srcdir=.}/strace-tt.test"
diff -pruN 5.5-3/tests-mx32/strace--timestamps-time-s.gen.test 5.9-0ubuntu2/tests-mx32/strace--timestamps-time-s.gen.test
--- 5.5-3/tests-mx32/strace--timestamps-time-s.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--timestamps-time-s.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-time-s +strace-t.test --timestamps=time,s); do not edit.
+set -- --timestamps=time,s
+. "${srcdir=.}/strace-t.test"
diff -pruN 5.5-3/tests-mx32/strace--timestamps-time-us.gen.test 5.9-0ubuntu2/tests-mx32/strace--timestamps-time-us.gen.test
--- 5.5-3/tests-mx32/strace--timestamps-time-us.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--timestamps-time-us.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-time-us +strace-tt.test 6 --timestamps=time,us); do not edit.
+set -- 6 --timestamps=time,us
+. "${srcdir=.}/strace-tt.test"
diff -pruN 5.5-3/tests-mx32/strace--timestamps-unix-ms.gen.test 5.9-0ubuntu2/tests-mx32/strace--timestamps-unix-ms.gen.test
--- 5.5-3/tests-mx32/strace--timestamps-unix-ms.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--timestamps-unix-ms.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-unix-ms +strace-ttt.test 3 --timestamps=unix,ms); do not edit.
+set -- 3 --timestamps=unix,ms
+. "${srcdir=.}/strace-ttt.test"
diff -pruN 5.5-3/tests-mx32/strace--timestamps-unix-ns.gen.test 5.9-0ubuntu2/tests-mx32/strace--timestamps-unix-ns.gen.test
--- 5.5-3/tests-mx32/strace--timestamps-unix-ns.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--timestamps-unix-ns.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-unix-ns +strace-ttt.test 9 --timestamps=unix,ns); do not edit.
+set -- 9 --timestamps=unix,ns
+. "${srcdir=.}/strace-ttt.test"
diff -pruN 5.5-3/tests-mx32/strace--timestamps-unix-s.gen.test 5.9-0ubuntu2/tests-mx32/strace--timestamps-unix-s.gen.test
--- 5.5-3/tests-mx32/strace--timestamps-unix-s.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--timestamps-unix-s.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-unix-s +strace-ttt.test 0 --timestamps=unix,s); do not edit.
+set -- 0 --timestamps=unix,s
+. "${srcdir=.}/strace-ttt.test"
diff -pruN 5.5-3/tests-mx32/strace--timestamps-unix-us.gen.test 5.9-0ubuntu2/tests-mx32/strace--timestamps-unix-us.gen.test
--- 5.5-3/tests-mx32/strace--timestamps-unix-us.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace--timestamps-unix-us.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace--timestamps-unix-us +strace-ttt.test 6 --timestamps=unix,us); do not edit.
+set -- 6 --timestamps=unix,us
+. "${srcdir=.}/strace-ttt.test"
diff -pruN 5.5-3/tests-mx32/strace-t.test 5.9-0ubuntu2/tests-mx32/strace-t.test
--- 5.5-3/tests-mx32/strace-t.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace-t.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,19 +2,21 @@
 #
 # Check -t option.
 #
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/init.sh"
 
+opts="${*:--t}"
+
 run_prog_skip_if_failed date +%s > "$LOG"
 run_prog_skip_if_failed date +%T --date "@$(cat "$LOG")" > /dev/null
 run_prog ../sleep 0
 
 s0="$(date +%s)"
-run_strace -t -eexecve $args
+run_strace $opts -eexecve $args
 s1="$(date +%s)"
 
 s="$s0"
diff -pruN 5.5-3/tests-mx32/strace-T.test 5.9-0ubuntu2/tests-mx32/strace-T.test
--- 5.5-3/tests-mx32/strace-T.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace-T.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,13 +2,15 @@
 #
 # Check -T option.
 #
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/init.sh"
 
+T_opt="${1:--T}"
+
 run_prog ../sleep 0
-run_strace -a24 -T -enanosleep ../sleep 1
+run_strace -a24 "${T_opt}" -enanosleep ../sleep 1
 match_grep
diff -pruN 5.5-3/tests-mx32/strace-tt.test 5.9-0ubuntu2/tests-mx32/strace-tt.test
--- 5.5-3/tests-mx32/strace-tt.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace-tt.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,19 +2,23 @@
 #
 # Check -tt option.
 #
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/init.sh"
 
+precision="${1:-6}"
+[ x0 = "x$#" ] || shift
+opts="${*:--tt}"
+
 run_prog_skip_if_failed date +%s > "$LOG"
 run_prog_skip_if_failed date +%T --date "@$(cat "$LOG")" > /dev/null
 run_prog ../sleep 0
 
 s0="$(date +%s)"
-run_strace -tt -eexecve $args
+run_strace $opts -eexecve $args
 s1="$(date +%s)"
 
 s="$s0"
@@ -26,7 +30,7 @@ while [ "$s" -le "$s1" ]; do
 done
 
 cat > "$EXP" << __EOF__
-($t_reg)\\.[[:digit:]]{6} execve\\("\\.\\./sleep", \\["\\.\\./sleep", "0"\\], 0x[[:xdigit:]]* /\\* [[:digit:]]* vars \\*/\\) = 0
+($t_reg)\\.[[:digit:]]{${precision}} execve\\("\\.\\./sleep", \\["\\.\\./sleep", "0"\\], 0x[[:xdigit:]]* /\\* [[:digit:]]* vars \\*/\\) = 0
 __EOF__
 
 match_grep "$LOG" "$EXP"
diff -pruN 5.5-3/tests-mx32/strace-ttt.test 5.9-0ubuntu2/tests-mx32/strace-ttt.test
--- 5.5-3/tests-mx32/strace-ttt.test	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace-ttt.test	2020-04-03 22:58:26.000000000 +0000
@@ -2,18 +2,22 @@
 #
 # Check -ttt option.
 #
-# Copyright (c) 2016-2018 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/init.sh"
 
+precision="${1:-6}"
+[ x0 = "x$#" ] || shift
+opts="${*:--ttt}"
+
 run_prog_skip_if_failed date +%s > /dev/null
 run_prog ../sleep 0
 
 s0="$(date +%s)"
-run_strace -ttt -eexecve $args
+run_strace $opts -eexecve $args
 s1="$(date +%s)"
 
 s="$s0"
@@ -23,8 +27,14 @@ while [ "$s" -le "$s1" ]; do
 	s=$(($s + 1))
 done
 
+if [ x0 = "x${precision}" ]; then
+	subsec_re=""
+else
+	subsec_re="\\.[[:digit:]]{${precision}}"
+fi
+
 cat > "$EXP" << __EOF__
-($t_reg)\\.[[:digit:]]{6} execve\\("\\.\\./sleep", \\["\\.\\./sleep", "0"\\], 0x[[:xdigit:]]* /\\* [[:digit:]]+ vars \\*/\\) = 0
+($t_reg)${subsec_re} execve\\("\\.\\./sleep", \\["\\.\\./sleep", "0"\\], 0x[[:xdigit:]]* /\\* [[:digit:]]+ vars \\*/\\) = 0
 __EOF__
 
 match_grep "$LOG" "$EXP"
diff -pruN 5.5-3/tests-mx32/strace-x.c 5.9-0ubuntu2/tests-mx32/strace-x.c
--- 5.5-3/tests-mx32/strace-x.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace-x.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,82 @@
+/*
+ * Test strace's -x option.
+ *
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+
+#include <stdio.h>
+#include <unistd.h>
+
+#ifndef STRACE_XX
+# define STRACE_XX 0
+#endif
+
+#if STRACE_XX
+# define XOUT(x_, xx_) xx_
+#else
+# define XOUT(x_, xx_) x_
+#endif
+
+int
+main(void)
+{
+	static const struct {
+		const char *path;
+		const char *out;
+	} test_vecs[] = {
+		{ "test", XOUT("test", "\\x74\\x65\\x73\\x74") },
+		{ "\t\n\v\f\r hi~", XOUT("\\t\\n\\v\\f\\r hi~",
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e") },
+		{ "\t\n\v\f\r\16 hi~", XOUT(
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x0e\\x20\\x68\\x69\\x7e",
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x0e\\x20\\x68\\x69\\x7e") },
+		{ "\10\t\n\v\f\r hi~", XOUT(
+		  "\\x08\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e",
+		  "\\x08\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e") },
+		{ "\t\n\v\f\r\37 hi~", XOUT(
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x1f\\x20\\x68\\x69\\x7e",
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x1f\\x20\\x68\\x69\\x7e") },
+		{ "\t\n\v\f\r hi~\177", XOUT(
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e\\x7f",
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e\\x7f") },
+		{ "\t\n\v\f\r hi~\222", XOUT(
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e\\x92",
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e\\x92") },
+		{ "\t\n\v\f\r hi~\377", XOUT(
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e\\xff",
+		  "\\x09\\x0a\\x0b\\x0c\\x0d\\x20\\x68\\x69\\x7e\\xff") },
+	};
+	static char path[] = "  ";
+
+	const char *rc_str;
+
+	for (size_t i = 0; i < ARRAY_SIZE(test_vecs); i++) {
+		rc_str = sprintrc(chdir(test_vecs[i].path));
+		printf("chdir(\"%s\") = %s\n", test_vecs[i].out, rc_str);
+	}
+
+	for (unsigned char c = 1; c < 255; c++) {
+		path[1] = c;
+		rc_str = sprintrc(chdir(path));
+
+		printf("chdir(");
+#if STRACE_XX
+		print_quoted_hex(path, sizeof(path) - 1);
+#else
+		if (((c < ' ') || (c >= 0x7f)) && (c != '\t') && (c != '\n') &&
+		    (c != '\v') && (c != '\f') && (c != '\r'))
+			print_quoted_hex(path, sizeof(path) - 1);
+		else
+			print_quoted_string(path);
+#endif
+		printf(") = %s\n", rc_str);
+	}
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
diff -pruN 5.5-3/tests-mx32/strace-x.gen.test 5.9-0ubuntu2/tests-mx32/strace-x.gen.test
--- 5.5-3/tests-mx32/strace-x.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace-x.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace-x -e trace=chdir -x -a 12); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -e trace=chdir -x -a 12
diff -pruN 5.5-3/tests-mx32/strace-xx.c 5.9-0ubuntu2/tests-mx32/strace-xx.c
--- 5.5-3/tests-mx32/strace-xx.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace-xx.c	2020-02-19 17:26:57.000000000 +0000
@@ -0,0 +1,2 @@
+#define STRACE_XX 1
+#include "strace-x.c"
diff -pruN 5.5-3/tests-mx32/strace-xx.gen.test 5.9-0ubuntu2/tests-mx32/strace-xx.gen.test
--- 5.5-3/tests-mx32/strace-xx.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/strace-xx.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (strace-xx -e trace=chdir -xx -a 18); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -e trace=chdir -xx -a 18
diff -pruN 5.5-3/tests-mx32/syntax.sh 5.9-0ubuntu2/tests-mx32/syntax.sh
--- 5.5-3/tests-mx32/syntax.sh	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/syntax.sh	2020-02-24 13:08:32.000000000 +0000
@@ -10,45 +10,62 @@
 
 . "${srcdir=.}/init.sh"
 
+log_sfx()
+{
+	printf "%.128s" "$*" | tr -c '0-9A-Za-z-=,' '_'
+}
+
 check_exit_status_and_stderr()
 {
-	$STRACE "$@" 2> "$LOG" &&
-		dump_log_and_fail_with \
-			"strace $* failed to handle the error properly"
-	match_diff "$LOG" "$EXP" \
+	local sfx
+	sfx="$1"; shift
+	$STRACE "$@" 2> "$LOG.$sfx" && {
+		cat "$LOG.$sfx" >&2
+		fail_ "strace $* failed to handle the error properly"
+	}
+	match_diff "$LOG.$sfx" "$EXP.$sfx" \
 		"strace $* failed to print expected diagnostics"
 }
 
 check_exit_status_and_stderr_using_grep()
 {
-	$STRACE "$@" 2> "$LOG" &&
-		dump_log_and_fail_with \
-			"strace $* failed to handle the error properly"
-	match_grep "$LOG" "$EXP" \
+	local sfx
+	sfx="$1"; shift
+	$STRACE "$@" 2> "$LOG.$sfx" && {
+		cat "$LOG.$sfx" >&2
+		fail_ "strace $* failed to handle the error properly"
+	}
+	match_grep "$LOG.$sfx" "$EXP.$sfx" \
 		"strace $* failed to print expected diagnostics"
 }
 
 check_e()
 {
-	local pattern="$1"; shift
-	cat > "$EXP" << __EOF__
+	local pattern sfx
+	pattern="$1"; shift
+	sfx="$(log_sfx "$*")"
+	cat > "$EXP.$sfx" << __EOF__
 $STRACE_EXE: $pattern
 __EOF__
-	check_exit_status_and_stderr "$@"
+	check_exit_status_and_stderr "$sfx" "$@"
 }
 
 check_e_using_grep()
 {
-	local pattern="$1"; shift
-	cat > "$EXP" << __EOF__
+	local pattern sfx
+	pattern="$1"; shift
+	sfx="$(log_sfx "$*")"
+	cat > "$EXP.$sfx" << __EOF__
 $STRACE_EXE: $pattern
 __EOF__
-	check_exit_status_and_stderr_using_grep "$@"
+	check_exit_status_and_stderr_using_grep "$sfx" "$@"
 }
 
 check_h()
 {
-	local patterns="$1"; shift
+	local patterns sfx
+	patterns="$1"; shift
+	sfx="$(log_sfx "$*")"
 	{
 		local pattern
 		printf '%s\n' "$patterns" |
@@ -56,6 +73,6 @@ check_h()
 				printf '%s: %s\n' "$STRACE_EXE" "$pattern"
 			done
 		printf "Try '%s -h' for more information.\\n" "$STRACE_EXE"
-	} > "$EXP"
-	check_exit_status_and_stderr "$@"
+	} > "$EXP.$sfx"
+	check_exit_status_and_stderr "$sfx" "$@"
 }
diff -pruN 5.5-3/tests-mx32/test_nlattr.h 5.9-0ubuntu2/tests-mx32/test_nlattr.h
--- 5.5-3/tests-mx32/test_nlattr.h	2019-11-28 19:30:05.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/test_nlattr.h	2020-06-01 14:15:16.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -15,6 +15,10 @@
 #include "netlink.h"
 #include <linux/rtnetlink.h>
 
+#ifndef PRINT_SOCK
+# define PRINT_SOCK 0
+#endif
+
 static void
 init_nlattr(struct nlattr *const nla,
 	    const uint16_t nla_len,
@@ -37,6 +41,29 @@ print_nlattr(const unsigned int nla_len,
 	       add_data ? "[" : "", nla_len, nla_type);
 }
 
+static void
+print_sockfd(int sockfd, const char *pfx, const char *sfx)
+{
+#if PRINT_SOCK
+	static int fd = -1;
+	static unsigned long inode;
+
+	if (sockfd < 0) {
+		printf("%s%d%s", pfx, sockfd, sfx);
+		return;
+	}
+
+	if (sockfd != fd) {
+		fd = sockfd;
+		inode = inode_of_sockfd(fd);
+	}
+
+	printf("%s%d<socket:[%lu]>%s", pfx, sockfd, inode, sfx);
+#else
+	printf("%s%d%s", pfx, sockfd, sfx);
+#endif
+}
+
 #define TEST_NLATTR_EX_(fd_, nlh0_, hdrlen_,				\
 		     init_msg_, print_msg_,				\
 		     nla_type_, nla_type_str_,				\
@@ -60,7 +87,7 @@ print_nlattr(const unsigned int nla_len,
 			sprintrc(sendto((fd_), nlh, msg_len,		\
 					MSG_DONTWAIT, NULL, 0));	\
 									\
-		printf("sendto(%d, {", (fd_));				\
+		print_sockfd((fd_), "sendto(", ", {");			\
 		(print_msg_)(msg_len);					\
 		print_nlattr(nla_len, (nla_type_str_),			\
 			     (nla_total_len_) > (nla_data_len_));	\
diff -pruN 5.5-3/tests-mx32/tests.h 5.9-0ubuntu2/tests-mx32/tests.h
--- 5.5-3/tests-mx32/tests.h	2019-12-15 16:29:06.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/tests.h	2020-04-17 20:43:15.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -24,6 +24,7 @@
 # endif
 
 # include <stdbool.h>
+# include <stdint.h>
 # include <sys/types.h>
 # include "kernel_types.h"
 # include "gcc_compat.h"
@@ -55,21 +56,67 @@
 # if XLAT_RAW
 #  define XLAT_KNOWN(val_, str_) STRINGIFY_VAL(val_)
 #  define XLAT_UNKNOWN(val_, dflt_) STRINGIFY_VAL(val_)
+
+#  define XLAT_FMT "%#x"
+#  define XLAT_ARGS(a_) (a_)
+#  define XLAT_SEL(v_, s_) v_
+
+#  define ABBR(s_) ""
+#  define RAW(s_) s_
+#  define VERB(s_) ""
+#  define NABBR(s_) s_
+#  define NRAW(s_) ""
+#  define NVERB(s_) s_
 # elif XLAT_VERBOSE
 #  define XLAT_KNOWN(val_, str_) STRINGIFY_VAL(val_) " /* " str_ " */"
 #  define XLAT_UNKNOWN(val_, dflt_) STRINGIFY_VAL(val_) " /* " dflt_ " */"
-# else
+
+#  define XLAT_FMT "%#x /* %s */"
+#  define XLAT_ARGS(a_) a_, #a_
+#  define XLAT_SEL(v_, s_) v_, s_
+
+#  define ABBR(s_) ""
+#  define RAW(s_) ""
+#  define VERB(s_) s_
+#  define NABBR(s_) s_
+#  define NRAW(s_) s_
+#  define NVERB(s_) ""
+# else /* !XLAT_RAW && !XLAT_VERBOSE */
 #  define XLAT_KNOWN(val_, str_) str_
 #  define XLAT_UNKNOWN(val_, dflt_) STRINGIFY_VAL(val_) " /* " dflt_ " */"
-# endif
+
+#  define XLAT_FMT "%s"
+#  define XLAT_ARGS(a_) #a_
+#  define XLAT_SEL(v_, s_) s_
+
+#  define ABBR(s_) s_
+#  define RAW(s_) ""
+#  define VERB(s_) ""
+#  define NABBR(s_) ""
+#  define NRAW(s_) s_
+#  define NVERB(s_) s_
+# endif /* XLAT_RAW, XLAT_VERBOSE */
 
 # define XLAT_STR(v_) sprintxlat(#v_, v_, NULL)
 
+# define ARG_XLAT_KNOWN(val_, str_) val_, XLAT_KNOWN(val_, str_)
+# define ARG_XLAT_UNKNOWN(val_, str_) val_, XLAT_UNKNOWN(val_, str_)
+
 # ifndef DEFAULT_STRLEN
 /* Default maximum # of bytes printed in printstr et al. */
 #  define DEFAULT_STRLEN 32
 # endif
 
+struct strval32 {
+	uint32_t val;
+	const char *str;
+};
+
+struct strval64 {
+	uint64_t val;
+	const char *str;
+};
+
 /* Cached sysconf(_SC_PAGESIZE). */
 size_t get_page_size(void);
 
@@ -137,15 +184,26 @@ void *tail_memdup(const void *, const si
 # define TAIL_ALLOC_OBJECT_VAR_PTR(type_name, type_ptr)		\
 	type_name *type_ptr = tail_alloc(sizeof(*type_ptr))
 
-/*
+/**
  * Fill memory (pointed by ptr, having size bytes) with different bytes (with
  * values starting with start and resetting every period) in order to catch
  * sign, byte order and/or alignment errors.
  */
 void fill_memory_ex(void *ptr, size_t size, unsigned char start,
 		    unsigned int period);
-/* Shortcut for fill_memory_ex(ptr, size, 0x80, 0x80) */
+/** Shortcut for fill_memory_ex(ptr, size, 0x80, 0x80) */
 void fill_memory(void *ptr, size_t size);
+/** Variant of fill_memory_ex for arrays of 16-bit (2-byte) values. */
+void fill_memory16_ex(void *ptr, size_t size, uint16_t start,
+		      unsigned int period);
+/** Shortcut for fill_memory16_ex(ptr, size, 0x80c0, 0x8000) */
+void fill_memory16(void *ptr, size_t size);
+/** Variant of fill_memory_ex for arrays of 32-bit (4-byte) values. */
+void fill_memory32_ex(void *ptr, size_t size, uint32_t start,
+		      unsigned int period);
+/** Shortcut for fill_memory32_ex(ptr, size, 0x80a0c0e0, 0x80000000) */
+void fill_memory32(void *ptr, size_t size);
+
 
 /* Close stdin, move stdout to a non-standard descriptor, and print. */
 void tprintf(const char *, ...)
@@ -276,6 +334,9 @@ int send_mmsg(int, struct mmsghdr *, uns
 int create_nl_socket_ext(int proto, const char *name);
 # define create_nl_socket(proto)	create_nl_socket_ext((proto), #proto)
 
+/* Create a temporary file in the current directory. */
+int create_tmpfile(unsigned int flags);
+
 /* Create a pipe with maximized descriptor numbers. */
 void pipe_maxfd(int pipefd[2]);
 
diff -pruN 5.5-3/tests-mx32/tgkill.c 5.9-0ubuntu2/tests-mx32/tgkill.c
--- 5.5-3/tests-mx32/tgkill.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/tgkill.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,88 @@
+/*
+ * Check decoding of tgkill syscall.
+ *
+ * Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+#include "pidns.h"
+
+#ifdef __NR_tgkill
+
+# include <signal.h>
+# include <stdio.h>
+# include <unistd.h>
+
+static const char *errstr;
+
+static long
+k_tgkill(const unsigned int tgid,
+	 const unsigned int tid,
+	 const unsigned int sig)
+{
+        const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+        const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+        const kernel_ulong_t arg1 = fill | tgid;
+        const kernel_ulong_t arg2 = fill | tid;
+        const kernel_ulong_t arg3 = fill | sig;
+        const long rc = syscall(__NR_tgkill, arg1, arg2, arg3, bad, bad, bad);
+        errstr = sprintrc(rc);
+        return rc;
+}
+
+int
+main(void)
+{
+	PIDNS_TEST_INIT;
+
+	const int pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
+	const int tid = syscall(__NR_gettid);
+	const char *tid_str = pidns_pid2str(PT_TID);
+	const int bad_pid = -1;
+	const int bad_sig = 0xface;
+
+	k_tgkill(pid, tid, 0);
+	pidns_print_leader();
+	printf("tgkill(%d%s, %d%s, 0) = %s\n",
+		pid, pid_str, tid, tid_str, errstr);
+
+	k_tgkill(pid, bad_pid, 0);
+	pidns_print_leader();
+	printf("tgkill(%d%s, %d, 0) = %s\n",
+		pid, pid_str, bad_pid, errstr);
+
+	k_tgkill(bad_pid, tid, 0);
+	pidns_print_leader();
+	printf("tgkill(%d, %d%s, 0) = %s\n",
+		bad_pid, tid, tid_str, errstr);
+
+	k_tgkill(pid, tid, SIGCONT);
+	pidns_print_leader();
+	printf("tgkill(%d%s, %d%s, SIGCONT) = %s\n",
+		pid, pid_str, tid, tid_str, errstr);
+
+	k_tgkill(pid, tid, bad_sig);
+	pidns_print_leader();
+	printf("tgkill(%d%s, %d%s, %d) = %s\n",
+		pid, pid_str, tid, tid_str, bad_sig, errstr);
+
+	k_tgkill(pid, tid, -bad_sig);
+	pidns_print_leader();
+	printf("tgkill(%d%s, %d%s, %d) = %s\n",
+		pid, pid_str, tid, tid_str, -bad_sig, errstr);
+
+	pidns_print_leader();
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_tgkill")
+
+#endif
diff -pruN 5.5-3/tests-mx32/tgkill.gen.test 5.9-0ubuntu2/tests-mx32/tgkill.gen.test
--- 5.5-3/tests-mx32/tgkill.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/tgkill.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (tgkill -a15 --signal='!cont'); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a15 --signal='!cont'
diff -pruN 5.5-3/tests-mx32/tgkill--pidns-translation.c 5.9-0ubuntu2/tests-mx32/tgkill--pidns-translation.c
--- 5.5-3/tests-mx32/tgkill--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/tgkill--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "tgkill.c"
diff -pruN 5.5-3/tests-mx32/tgkill--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/tgkill--pidns-translation.gen.test
--- 5.5-3/tests-mx32/tgkill--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/tgkill--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (tgkill--pidns-translation test_pidns -a15 --signal='!cont' -e trace=tgkill); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a15 --signal='!cont' -e trace=tgkill
diff -pruN 5.5-3/tests-mx32/threads-execve.c 5.9-0ubuntu2/tests-mx32/threads-execve.c
--- 5.5-3/tests-mx32/threads-execve.c	2019-11-19 23:17:53.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/threads-execve.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of threads when a non-leader thread invokes execve.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -23,6 +23,13 @@
 
 # include "kernel_old_timespec.h"
 
+# ifndef PRINT_EXITED
+#  define PRINT_EXITED 1
+# endif
+# ifndef PRINT_SUPERSEDED
+#  define PRINT_SUPERSEDED 1
+# endif
+
 static pid_t leader;
 static pid_t tid;
 
@@ -145,10 +152,10 @@ thread(void *arg)
 			break;
 	}
 
-	printf("%-5d +++ superseded by execve in pid %u +++\n"
-	       "%-5d <... execve resumed>) = 0\n",
-	       leader, tid,
-	       leader);
+# if PRINT_SUPERSEDED
+	printf("%-5d +++ superseded by execve in pid %u +++\n", leader, tid);
+# endif
+	printf("%-5d <... execve resumed>) = 0\n", leader);
 
 	(void) syscall(__NR_nanosleep, (unsigned long) &ots, 0UL);
 	execve(argv[0], argv, environ);
@@ -183,7 +190,9 @@ main(int ac, char **av)
 	action = atoi(av[2]);
 
 	if (action >= NUMBER_OF_ACTIONS * NUMBER_OF_ITERATIONS) {
+# if PRINT_EXITED
 		printf("%-5d +++ exited with 0 +++\n", leader);
+# endif
 		return 0;
 	}
 
diff -pruN 5.5-3/tests-mx32/threads-execve-q.c 5.9-0ubuntu2/tests-mx32/threads-execve-q.c
--- 5.5-3/tests-mx32/threads-execve-q.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/threads-execve-q.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1 @@
+#include "threads-execve.c"
diff -pruN 5.5-3/tests-mx32/threads-execve-q.gen.test 5.9-0ubuntu2/tests-mx32/threads-execve-q.gen.test
--- 5.5-3/tests-mx32/threads-execve-q.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/threads-execve-q.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (threads-execve-q +threads-execve.test -q); do not edit.
+set -- -q
+. "${srcdir=.}/threads-execve.test"
diff -pruN 5.5-3/tests-mx32/threads-execve-qq.c 5.9-0ubuntu2/tests-mx32/threads-execve-qq.c
--- 5.5-3/tests-mx32/threads-execve-qq.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/threads-execve-qq.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_EXITED 0
+#include "threads-execve.c"
diff -pruN 5.5-3/tests-mx32/threads-execve-qq.gen.test 5.9-0ubuntu2/tests-mx32/threads-execve-qq.gen.test
--- 5.5-3/tests-mx32/threads-execve-qq.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/threads-execve-qq.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (threads-execve-qq +threads-execve.test -qq); do not edit.
+set -- -qq
+. "${srcdir=.}/threads-execve.test"
diff -pruN 5.5-3/tests-mx32/threads-execve-qqq.c 5.9-0ubuntu2/tests-mx32/threads-execve-qqq.c
--- 5.5-3/tests-mx32/threads-execve-qqq.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/threads-execve-qqq.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,3 @@
+#define PRINT_SUPERSEDED 0
+#define PRINT_EXITED 0
+#include "threads-execve.c"
diff -pruN 5.5-3/tests-mx32/threads-execve-qqq.gen.test 5.9-0ubuntu2/tests-mx32/threads-execve-qqq.gen.test
--- 5.5-3/tests-mx32/threads-execve-qqq.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/threads-execve-qqq.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (threads-execve-qqq +threads-execve.test -qqq); do not edit.
+set -- -qqq
+. "${srcdir=.}/threads-execve.test"
diff -pruN 5.5-3/tests-mx32/threads-execve--quiet-thread-execve.c 5.9-0ubuntu2/tests-mx32/threads-execve--quiet-thread-execve.c
--- 5.5-3/tests-mx32/threads-execve--quiet-thread-execve.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/threads-execve--quiet-thread-execve.c	2020-02-24 13:08:33.000000000 +0000
@@ -0,0 +1,2 @@
+#define PRINT_SUPERSEDED 0
+#include "threads-execve.c"
diff -pruN 5.5-3/tests-mx32/threads-execve--quiet-thread-execve.gen.test 5.9-0ubuntu2/tests-mx32/threads-execve--quiet-thread-execve.gen.test
--- 5.5-3/tests-mx32/threads-execve--quiet-thread-execve.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/threads-execve--quiet-thread-execve.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (threads-execve--quiet-thread-execve +threads-execve.test -s40 --quiet=personality,thread-execve); do not edit.
+set -- -s40 --quiet=personality,thread-execve
+. "${srcdir=.}/threads-execve.test"
diff -pruN 5.5-3/tests-mx32/threads-execve.test 5.9-0ubuntu2/tests-mx32/threads-execve.test
--- 5.5-3/tests-mx32/threads-execve.test	2019-10-28 19:52:59.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/threads-execve.test	2020-04-03 22:58:26.000000000 +0000
@@ -3,7 +3,7 @@
 # Check decoding of threads when a non-leader thread invokes execve.
 #
 # Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
-# Copyright (c) 2016-2019 The strace developers.
+# Copyright (c) 2016-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
@@ -17,13 +17,15 @@ require_min_kernel_version_or_skip 3.1
 # This test requires some concurrency between threads.
 require_min_nproc 2
 
+opts="${*:-}"
+
 check_prog diff
 run_prog_skip_if_failed date +%s > /dev/null
 s0="$(date +%s)"
 
 run_prog > /dev/null
 
-set -- -a21 -f -esignal=none -e trace=execve,exit,nanosleep,rt_sigsuspend $args
+set -- -a21 -f -esignal=none -e trace=execve,exit,nanosleep,rt_sigsuspend $opts $args
 
 # Due to probabilistic nature of the test, try it several times.
 while :; do
diff -pruN 5.5-3/tests-mx32/tkill.c 5.9-0ubuntu2/tests-mx32/tkill.c
--- 5.5-3/tests-mx32/tkill.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/tkill.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,69 @@
+/*
+ * Check decoding of tkill syscall.
+ *
+ * Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "scno.h"
+#include "pidns.h"
+
+#ifdef __NR_tkill
+
+# include <signal.h>
+# include <stdio.h>
+# include <unistd.h>
+
+static const char *errstr;
+
+static long
+k_tkill(const unsigned int tid, const unsigned int sig)
+{
+        const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+        const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+        const kernel_ulong_t arg1 = fill | tid;
+        const kernel_ulong_t arg2 = fill | sig;
+        const long rc = syscall(__NR_tkill, arg1, arg2, bad, bad, bad, bad);
+        errstr = sprintrc(rc);
+        return rc;
+}
+
+int
+main(void)
+{
+	PIDNS_TEST_INIT;
+
+	const int tid = syscall(__NR_gettid);
+	const char *tid_str = pidns_pid2str(PT_TID);
+	const int bad_pid = -1;
+	const int bad_sig = 0xface;
+
+	k_tkill(tid, 0);
+	pidns_print_leader();
+	printf("tkill(%d%s, 0) = %s\n", tid, tid_str, errstr);
+
+	k_tkill(tid, SIGCONT);
+	pidns_print_leader();
+	printf("tkill(%d%s, SIGCONT) = %s\n", tid, tid_str, errstr);
+
+	k_tkill(bad_pid, bad_sig);
+	pidns_print_leader();
+	printf("tkill(%d, %d) = %s\n", bad_pid, bad_sig, errstr);
+
+	k_tkill(bad_pid, -bad_sig);
+	pidns_print_leader();
+	printf("tkill(%d, %d) = %s\n", bad_pid, -bad_sig, errstr);
+
+	pidns_print_leader();
+	puts("+++ exited with 0 +++");
+	return 0;
+}
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_tkill")
+
+#endif
diff -pruN 5.5-3/tests-mx32/tkill.gen.test 5.9-0ubuntu2/tests-mx32/tkill.gen.test
--- 5.5-3/tests-mx32/tkill.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/tkill.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (tkill -a12 --signal='!cont'); do not edit.
+. "${srcdir=.}/init.sh"
+run_strace_match_diff -a12 --signal='!cont'
diff -pruN 5.5-3/tests-mx32/tkill--pidns-translation.c 5.9-0ubuntu2/tests-mx32/tkill--pidns-translation.c
--- 5.5-3/tests-mx32/tkill--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/tkill--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "tkill.c"
diff -pruN 5.5-3/tests-mx32/tkill--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/tkill--pidns-translation.gen.test
--- 5.5-3/tests-mx32/tkill--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/tkill--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (tkill--pidns-translation test_pidns --signal='!cont' -a12 -e trace=tkill); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns --signal='!cont' -a12 -e trace=tkill
diff -pruN 5.5-3/tests-mx32/trace_clock.gen.test 5.9-0ubuntu2/tests-mx32/trace_clock.gen.test
--- 5.5-3/tests-mx32/trace_clock.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/trace_clock.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (trace_clock test_trace_expr 'clock_nanosleep|times' -e%clock); do not edit.
+. "${srcdir=.}/init.sh"
+test_trace_expr 'clock_nanosleep|times' -e%clock
diff -pruN 5.5-3/tests-mx32/trace_clock.in 5.9-0ubuntu2/tests-mx32/trace_clock.in
--- 5.5-3/tests-mx32/trace_clock.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/trace_clock.in	2020-04-17 20:43:15.000000000 +0000
@@ -0,0 +1,5 @@
+adjtimex -a13
+clock_adjtime -a21
+clock_xettime -a21
+xettimeofday -a20
+time -a9
diff -pruN 5.5-3/tests-mx32/trace_fstat.in 5.9-0ubuntu2/tests-mx32/trace_fstat.in
--- 5.5-3/tests-mx32/trace_fstat.in	2018-12-10 23:45:11.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/trace_fstat.in	2020-06-14 08:00:00.000000000 +0000
@@ -9,3 +9,4 @@ fstat64-Xverbose	-a17 -Xverbose
 fstatat64	-a32
 newfstatat	-a32
 oldfstat	-a21
+statx	-a32
diff -pruN 5.5-3/tests-mx32/tracer_ppid_pgid_sid.c 5.9-0ubuntu2/tests-mx32/tracer_ppid_pgid_sid.c
--- 5.5-3/tests-mx32/tracer_ppid_pgid_sid.c	2019-10-07 11:33:37.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/tracer_ppid_pgid_sid.c	2020-04-03 22:58:26.000000000 +0000
@@ -1,7 +1,7 @@
 /*
  * Helper program for strace-DDD.test
  *
- * Copyright (c) 2019 Dmitry V. Levin <ldv@altlinux.org>
+ * Copyright (c) 2019-2020 Dmitry V. Levin <ldv@altlinux.org>
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -86,7 +86,7 @@ main(void)
 
 	int ppid = 0, pgid = 0, sid = 0;
 	get_ppid_pgid_sid(tracer_pid, &ppid, &pgid, &sid);
-	printf("%d %d %d\n", ppid, pgid, sid);
+	printf("%d %d %d %d\n", tracer_pid, ppid, pgid, sid);
 
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/trie_for_tests.c 5.9-0ubuntu2/tests-mx32/trie_for_tests.c
--- 5.5-3/tests-mx32/trie_for_tests.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/trie_for_tests.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1 @@
+#include "trie.c"
diff -pruN 5.5-3/tests-mx32/trie_test.c 5.9-0ubuntu2/tests-mx32/trie_test.c
--- 5.5-3/tests-mx32/trie_test.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/trie_test.c	2020-09-23 16:29:35.000000000 +0000
@@ -0,0 +1,121 @@
+/*
+ * Copyright (c) 2017-2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+#include "trie.h"
+
+#include <stdio.h>
+#include <inttypes.h>
+
+static void
+assert_equals(const char *msg, uint64_t expected, uint64_t actual) {
+	if (actual != expected)
+		error_msg_and_fail("%s: expected: %" PRIu64
+		                   ", actual: %" PRIu64, msg, expected, actual);
+}
+
+static void
+iterate_fn(void *data, uint64_t key, uint64_t value)
+{
+	uint64_t expected = key < 256 && key % 10 == 0 ? key + 42 : -1ULL;
+	assert_equals("iterate_fn", expected, value);
+
+	int *count = (int *) data;
+	if (value != -1ULL)
+		(*count)++;
+}
+
+static void
+test_trie_iterate_fn(void)
+{
+	struct trie *t = trie_create(8, 6, 3, 3, -1);
+	for (int i = 0; i < 26; i++)
+		trie_set(t, i * 10, i * 10 + 42);
+
+	static const struct {
+		uint64_t start;
+		uint64_t end;
+		int expected_count;
+	} iterate_params[] = {
+		{0, 256, 26},
+		{0, UINT64_MAX, 26},
+		{20, 90, 8},
+		{99, 999, 16},
+		{10000, 100000, 0},
+		{200, 100, 0},
+	};
+
+	for (size_t i = 0; i < ARRAY_SIZE(iterate_params); i++) {
+		int count = 0;
+		trie_iterate_keys(t, iterate_params[i].start, iterate_params[i].end, iterate_fn, &count);
+		assert_equals("iteration count", iterate_params[i].expected_count, count);
+	}
+}
+
+struct key_value_pair {
+	uint64_t key, value;
+};
+
+static void
+test_trie_get(void)
+{
+	static const struct {
+		uint8_t key_size;
+		uint8_t item_size_lg;
+		uint8_t node_key_bits;
+		uint8_t data_block_key_bits;
+		uint64_t empty_value;
+
+		struct key_value_pair set_values[3], get_values[3];
+	} params[] = {
+		{64, 6, 10, 10, 0,
+			{{300, 1}, {0xfacefeed, 0xabcdef123456}, {-1ULL, -1ULL}},
+			{{301, 0}, {0xfacefeed, 0xabcdef123456}, {-1ULL, -1ULL}}},
+		{8, 2, 4, 4, 10,
+			{{0xab, 0xcd}, {0xface, 2}, {0, 3}},
+			{{0xab, 0xd}, {0xface, 10}, {0, 3}}},
+		{30, 0, 6, 3, -1,
+			{{0xaaaa, 127}, {0xface, 0}, {0, 0}},
+			{{0xaaaa, 1}, {0xface, 0}, {1, 1}}},
+		{16, 4, 5, 11, 0xffffff,
+			{{0xabcdef, 42}, {0xabcd, 42}, {0xffff, 0}},
+			{{0xabcdef, 0xffff}, {0xabcd, 42}, {0xffff, 0}}},
+		{41, 5, 1, 1, -1,
+			{{0xabcdef01, 0x22222222}, {-1, 0x33333333}, {10, 10}},
+			{{0xabcdef01, 0x22222222}, {-1, 0xffffffff}, {10, 10}}},
+	};
+
+	for (size_t i = 0; i < ARRAY_SIZE(params); i++) {
+		struct trie *t = trie_create(params[i].key_size,
+		                             params[i].item_size_lg,
+					     params[i].node_key_bits,
+					     params[i].data_block_key_bits,
+					     params[i].empty_value);
+
+		if (!t)
+			error_msg_and_fail("trie creation failed");
+
+		for (size_t j = 0; j < ARRAY_SIZE(params[i].set_values); j++) {
+			struct key_value_pair kv = params[i].set_values[j];
+			trie_set(t, kv.key, kv.value);
+		}
+		for (size_t j = 0; j < ARRAY_SIZE(params[i].get_values); j++) {
+			struct key_value_pair kv = params[i].get_values[j];
+			assert_equals("trie_get", kv.value, trie_get(t, kv.key));
+		}
+
+		trie_free(t);
+	}
+}
+
+int
+main(void)
+{
+	test_trie_get();
+	test_trie_iterate_fn();
+	return 0;
+}
diff -pruN 5.5-3/tests-mx32/trie_test.gen.test 5.9-0ubuntu2/tests-mx32/trie_test.gen.test
--- 5.5-3/tests-mx32/trie_test.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/trie_test.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (trie_test run_prog ); do not edit.
+. "${srcdir=.}/init.sh"
+run_prog 
diff -pruN 5.5-3/tests-mx32/umovestr_cached_adjacent.c 5.9-0ubuntu2/tests-mx32/umovestr_cached_adjacent.c
--- 5.5-3/tests-mx32/umovestr_cached_adjacent.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/umovestr_cached_adjacent.c	2020-04-16 00:04:10.000000000 +0000
@@ -0,0 +1,48 @@
+/*
+ * Check effectiveness of umovestr memory caching.
+ *
+ * Copyright (c) 2019-2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include "tests.h"
+
+#include <stdio.h>
+#include <string.h>
+#include <unistd.h>
+#include <sys/uio.h>
+
+int
+main(void)
+{
+	const size_t size = get_page_size() + (DEFAULT_STRLEN - 1);
+	char *const buf = tail_alloc(size);
+	fill_memory_ex(buf, DEFAULT_STRLEN * 2, 'a', 'z' - 'a' + 1);
+
+	struct iovec *const io = tail_alloc(sizeof(*io) * DEFAULT_STRLEN);
+	for (unsigned int i = 0; i < DEFAULT_STRLEN; ++i) {
+		io[i].iov_base = buf + i;
+		io[i].iov_len = DEFAULT_STRLEN;
+	}
+
+	tprintf("%s", "");
+
+	int rc = writev(-1, io, DEFAULT_STRLEN);
+	const char *errstr = sprintrc(rc);
+
+	tprintf("writev(-1, [");
+	for (unsigned int i = 0; i < DEFAULT_STRLEN; ++i) {
+		if (i)
+			tprintf(", ");
+		tprintf("{iov_base=\"%.*s\", iov_len=%u}",
+			(int) io[i].iov_len,
+			(char *) io[i].iov_base,
+			(unsigned int) io[i].iov_len);
+	}
+	tprintf("], %u) = %s\n", DEFAULT_STRLEN, errstr);
+
+	tprintf("+++ exited with 0 +++\n");
+	return 0;
+}
diff -pruN 5.5-3/tests-mx32/umovestr_cached_adjacent.gen.test 5.9-0ubuntu2/tests-mx32/umovestr_cached_adjacent.gen.test
--- 5.5-3/tests-mx32/umovestr_cached_adjacent.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/umovestr_cached_adjacent.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (umovestr_cached_adjacent +umovestr_cached.test 3); do not edit.
+set -- 3
+. "${srcdir=.}/umovestr_cached.test"
diff -pruN 5.5-3/tests-mx32/umovestr_cached.test 5.9-0ubuntu2/tests-mx32/umovestr_cached.test
--- 5.5-3/tests-mx32/umovestr_cached.test	2019-09-23 10:19:22.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/umovestr_cached.test	2020-04-16 00:04:10.000000000 +0000
@@ -2,22 +2,32 @@
 #
 # Check effectiveness of umovestr memory caching.
 #
-# Copyright (c) 2017-2019 Dmitry V. Levin <ldv@altlinux.org>
+# Copyright (c) 2017-2020 Dmitry V. Levin <ldv@altlinux.org>
 # All rights reserved.
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 . "${srcdir=.}/init.sh"
 
-run_strace_match_diff -e trace=writev
-
-if [ "$STRACE_ARCH" = ia64 ]; then
-	# ia64 invokes extra process_vm_readv syscalls to obtain syscall
-	# arguments, see linux/ia64/get_syscall_args.c for details.
-	skip_ "the test is not supported on $STRACE_ARCH yet"
-fi
+expected_count="${1:-2}"
 
 check_prog grep
+$STRACE -d -enone / > /dev/null 2> "$LOG" ||:
+grep -x "[^:]*strace: PTRACE_GET_SYSCALL_INFO works" "$LOG" > /dev/null || {
+	# PTRACE_GET_SYSCALL_INFO does not work
+	case "$STRACE_ARCH:$MIPS_ABI" in
+		ia64:|mips:o32)
+		# ia64 invokes extra process_vm_readv syscalls to obtain syscall
+		# arguments, see linux/ia64/get_syscall_args.c for details.
+		# mips o32 obtains the first four syscalls arguments from registers
+		# and invokes extra process_vm_readv syscalls to obtain remaining
+		# syscall arguments, see linux/mips/get_syscall_args.c for details.
+		skip_ "the test is not supported on $STRACE_ARCH yet"
+		;;
+	esac
+}
+
+run_strace_match_diff -e trace=writev
 
 run_strace -qq -esignal=none -eprocess_vm_readv -z \
 	-o '|grep -c ^process_vm_readv > count' \
@@ -26,6 +36,6 @@ run_strace -qq -esignal=none -eprocess_v
 count="$(cat count)"
 case "$count" in
 	0) skip_ "$STRACE $args made no process_vm_readv syscall invocations" ;;
-	2) ;;
-	*) fail_ "$STRACE $args made $count != 2 process_vm_readv syscall invocations" ;;
+	$expected_count) ;;
+	*) fail_ "$STRACE $args made $count != $expected_count process_vm_readv syscall invocations" ;;
 esac
diff -pruN 5.5-3/tests-mx32/unshare.c 5.9-0ubuntu2/tests-mx32/unshare.c
--- 5.5-3/tests-mx32/unshare.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/unshare.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of unshare syscall.
  *
  * Copyright (c) 2016 Eugene Syromyatnikov <evgsyr@gmail.com>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -28,12 +28,12 @@ main(void)
 		const char *str;
 	} unshare_flags[] = {
 		{ ARG_STR(0) },
-		{ 0xdeadca75,
-			"CLONE_THREAD|CLONE_FS|CLONE_SIGHAND|CLONE_SYSVSEM|"
-			"CLONE_NEWUTS|CLONE_NEWIPC|CLONE_NEWNET|CLONE_NEWUSER|"
-			"CLONE_NEWCGROUP|0x80a8c075" },
+		{ 0xdeadcaf5,
+			"CLONE_NEWTIME|CLONE_FS|CLONE_SIGHAND|CLONE_THREAD"
+			"|CLONE_SYSVSEM|CLONE_NEWCGROUP|CLONE_NEWUTS"
+			"|CLONE_NEWIPC|CLONE_NEWUSER|CLONE_NEWNET|0x80a8c075" },
 		{ 0x2000000, "CLONE_NEWCGROUP" },
-		{ ARG_STR(0x81f8f0ff) " /* CLONE_??? */" },
+		{ ARG_STR(0x81f8f07f) " /* CLONE_??? */" },
 	};
 
 	long rc;
diff -pruN 5.5-3/tests-mx32/wait4.c 5.9-0ubuntu2/tests-mx32/wait4.c
--- 5.5-3/tests-mx32/wait4.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/wait4.c	2020-06-02 08:00:00.000000000 +0000
@@ -2,77 +2,98 @@
  * Check decoding of wait4 syscall.
  *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2018 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-#include <assert.h>
-#include <signal.h>
-#include <stdio.h>
-#include <unistd.h>
-#include <sys/wait.h>
-#include <sys/resource.h>
+#include "scno.h"
+
+#ifdef __NR_wait4
+
+# include <assert.h>
+# include <signal.h>
+# include <stdio.h>
+# include <unistd.h>
+# include <sys/wait.h>
+# include "kernel_rusage.h"
 
 static const char *
-sprint_rusage(const struct rusage *const ru)
+sprint_rusage(const kernel_rusage_t *const ru)
 {
 	static char buf[1024];
 	snprintf(buf, sizeof(buf),
-		 "{ru_utime={tv_sec=%lld, tv_usec=%llu}"
-		 ", ru_stime={tv_sec=%lld, tv_usec=%llu}"
-#if VERBOSE
-		 ", ru_maxrss=%lu"
-		 ", ru_ixrss=%lu"
-		 ", ru_idrss=%lu"
-		 ", ru_isrss=%lu"
-		 ", ru_minflt=%lu"
-		 ", ru_majflt=%lu"
-		 ", ru_nswap=%lu"
-		 ", ru_inblock=%lu"
-		 ", ru_oublock=%lu"
-		 ", ru_msgsnd=%lu"
-		 ", ru_msgrcv=%lu"
-		 ", ru_nsignals=%lu"
-		 ", ru_nvcsw=%lu"
-		 ", ru_nivcsw=%lu}"
-#else
+		 "{ru_utime={tv_sec=%llu, tv_usec=%llu}"
+		 ", ru_stime={tv_sec=%llu, tv_usec=%llu}"
+# if VERBOSE
+		 ", ru_maxrss=%llu"
+		 ", ru_ixrss=%llu"
+		 ", ru_idrss=%llu"
+		 ", ru_isrss=%llu"
+		 ", ru_minflt=%llu"
+		 ", ru_majflt=%llu"
+		 ", ru_nswap=%llu"
+		 ", ru_inblock=%llu"
+		 ", ru_oublock=%llu"
+		 ", ru_msgsnd=%llu"
+		 ", ru_msgrcv=%llu"
+		 ", ru_nsignals=%llu"
+		 ", ru_nvcsw=%llu"
+		 ", ru_nivcsw=%llu}"
+# else
 		 ", ...}"
-#endif
-		 , (long long) ru->ru_utime.tv_sec
+# endif
+		 , zero_extend_signed_to_ull(ru->ru_utime.tv_sec)
 		 , zero_extend_signed_to_ull(ru->ru_utime.tv_usec)
-		 , (long long) ru->ru_stime.tv_sec
+		 , zero_extend_signed_to_ull(ru->ru_stime.tv_sec)
 		 , zero_extend_signed_to_ull(ru->ru_stime.tv_usec)
-#if VERBOSE
-		 , (long) ru->ru_maxrss
-		 , (long) ru->ru_ixrss
-		 , (long) ru->ru_idrss
-		 , (long) ru->ru_isrss
-		 , (long) ru->ru_minflt
-		 , (long) ru->ru_majflt
-		 , (long) ru->ru_nswap
-		 , (long) ru->ru_inblock
-		 , (long) ru->ru_oublock
-		 , (long) ru->ru_msgsnd
-		 , (long) ru->ru_msgrcv
-		 , (long) ru->ru_nsignals
-		 , (long) ru->ru_nvcsw
-		 , (long) ru->ru_nivcsw
-#endif
+# if VERBOSE
+		 , zero_extend_signed_to_ull(ru->ru_maxrss)
+		 , zero_extend_signed_to_ull(ru->ru_ixrss)
+		 , zero_extend_signed_to_ull(ru->ru_idrss)
+		 , zero_extend_signed_to_ull(ru->ru_isrss)
+		 , zero_extend_signed_to_ull(ru->ru_minflt)
+		 , zero_extend_signed_to_ull(ru->ru_majflt)
+		 , zero_extend_signed_to_ull(ru->ru_nswap)
+		 , zero_extend_signed_to_ull(ru->ru_inblock)
+		 , zero_extend_signed_to_ull(ru->ru_oublock)
+		 , zero_extend_signed_to_ull(ru->ru_msgsnd)
+		 , zero_extend_signed_to_ull(ru->ru_msgrcv)
+		 , zero_extend_signed_to_ull(ru->ru_nsignals)
+		 , zero_extend_signed_to_ull(ru->ru_nvcsw)
+		 , zero_extend_signed_to_ull(ru->ru_nivcsw)
+# endif
 		 );
 	return buf;
 }
 
+static const char *errstr;
+
+static long
+k_wait4(const unsigned int pid, void const *wstatus,
+	const unsigned int options, void const *ru)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+	const kernel_ulong_t arg1 = fill | pid;
+	const kernel_ulong_t arg2 = (uintptr_t) wstatus;
+	const kernel_ulong_t arg3 = fill | options;
+	const kernel_ulong_t arg4 = (uintptr_t) ru;
+	const long rc = syscall(__NR_wait4, arg1, arg2, arg3, arg4, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
+
 static pid_t
-do_wait4(pid_t pid, int *wstatus, int options, struct rusage *ru)
+do_wait4(pid_t pid, int *wstatus, int options, kernel_rusage_t *ru)
 {
 	sigset_t mask = {};
 	sigaddset(&mask, SIGCHLD);
 
 	assert(sigprocmask(SIG_BLOCK, &mask, NULL) == 0);
-	pid_t rc = wait4(pid, wstatus, options, ru);
+	pid_t rc = k_wait4(pid, wstatus, options, ru);
 	assert(sigprocmask(SIG_UNBLOCK, &mask, NULL) == 0);
 	return rc;
 }
@@ -101,12 +122,12 @@ main(void)
 	(void) close(0);
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(int, s);
-	if (wait4(pid, s, WNOHANG|__WALL, NULL))
+	if (k_wait4(pid, s, WNOHANG|__WALL, NULL))
 		perror_msg_and_fail("wait4 #1");
 	tprintf("wait4(%d, %p, WNOHANG|__WALL, NULL) = 0\n", pid, s);
 
-	TAIL_ALLOC_OBJECT_CONST_PTR(struct rusage, rusage);
-	if (wait4(pid, s, WNOHANG|__WALL, rusage))
+	TAIL_ALLOC_OBJECT_CONST_PTR(kernel_rusage_t, rusage);
+	if (k_wait4(pid, s, WNOHANG|__WALL, rusage))
 		perror_msg_and_fail("wait4 #2");
 	tprintf("wait4(%d, %p, WNOHANG|__WALL, %p) = 0\n", pid, s, rusage);
 
@@ -156,12 +177,12 @@ main(void)
 	if (kill(pid, SIGCONT))
 		perror_msg_and_fail("kill(SIGCONT)");
 
-#if defined WCONTINUED && defined WIFCONTINUED
+# if defined WCONTINUED && defined WIFCONTINUED
 	assert(do_wait4(pid, s, WCONTINUED, rusage) == pid);
 	assert(WIFCONTINUED(*s));
 	tprintf("wait4(%d, [{WIFCONTINUED(s)}], WCONTINUED"
 		", %s) = %d\n", pid, sprint_rusage(rusage), pid);
-#endif /* WCONTINUED && WIFCONTINUED */
+# endif /* WCONTINUED && WIFCONTINUED */
 
 	assert(write(1, "", 1) == 1);
 	(void) close(1);
@@ -171,10 +192,16 @@ main(void)
 	tprintf("wait4(%d, [{WIFEXITED(s) && WEXITSTATUS(s) == 0}], 0"
 		", %s) = %d\n", pid, sprint_rusage(rusage), pid);
 
-	assert(wait4(-1, s, WNOHANG|WSTOPPED|__WALL, rusage) == -1);
-	tprintf("wait4(-1, %p, WNOHANG|WSTOPPED|__WALL, %p) = -1 %s (%m)\n",
-		s, rusage, errno2name());
+	assert(k_wait4(-1, s, WNOHANG|WSTOPPED|__WALL, rusage) == -1);
+	tprintf("wait4(-1, %p, WNOHANG|WSTOPPED|__WALL, %p) = %s\n",
+		s, rusage, errstr);
 
 	tprintf("%s\n", "+++ exited with 0 +++");
 	return 0;
 }
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_wait4")
+
+#endif /* __NR_wait4 */
diff -pruN 5.5-3/tests-mx32/waitid.c 5.9-0ubuntu2/tests-mx32/waitid.c
--- 5.5-3/tests-mx32/waitid.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/waitid.c	2020-07-17 08:00:00.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of waitid syscall.
  *
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -15,11 +15,11 @@
 #include <string.h>
 #include <unistd.h>
 #include <sys/wait.h>
-#include <sys/resource.h>
+#include "kernel_rusage.h"
 #include "scno.h"
 
 static const char *
-sprint_rusage(const struct rusage *const ru)
+sprint_rusage(const kernel_rusage_t *const ru)
 {
 	static char buf[1024];
 	snprintf(buf, sizeof(buf),
@@ -103,8 +103,8 @@ sprint_siginfo(const siginfo_t *const si
 	snprintf(buf, sizeof(buf),
 		 "{si_signo=SIGCHLD"
 		 ", si_code=%s"
-		 ", si_pid=%u"
-		 ", si_uid=%u"
+		 ", si_pid=%d"
+		 ", si_uid=%d"
 		 ", si_status=%s"
 		 ", si_utime=%llu"
 		 ", si_stime=%llu}",
@@ -128,7 +128,7 @@ do_waitid(const unsigned int idtype,
 	  const unsigned int id,
 	  const siginfo_t *const infop,
 	  const unsigned int options,
-	  const struct rusage *const rusage)
+	  const kernel_rusage_t *const rusage)
 {
 	sigset_t mask = {};
 	sigaddset(&mask, SIGCHLD);
@@ -169,7 +169,7 @@ main(void)
 
 	TAIL_ALLOC_OBJECT_CONST_PTR(siginfo_t, sinfo);
 	memset(sinfo, 0, sizeof(*sinfo));
-	TAIL_ALLOC_OBJECT_CONST_PTR(struct rusage, rusage);
+	TAIL_ALLOC_OBJECT_CONST_PTR(kernel_rusage_t, rusage);
 	if (do_waitid(P_PID, pid, sinfo, WNOHANG|WEXITED|WSTOPPED, rusage))
 		perror_msg_and_fail("waitid #2");
 	tprintf("waitid(P_PID, %d, {}, WNOHANG|WEXITED|WSTOPPED, %s) = 0\n",
diff -pruN 5.5-3/tests-mx32/xetitimer.c 5.9-0ubuntu2/tests-mx32/xetitimer.c
--- 5.5-3/tests-mx32/xetitimer.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/xetitimer.c	2020-06-01 14:15:16.000000000 +0000
@@ -2,7 +2,7 @@
  * Check decoding of setitimer and getitimer syscalls.
  *
  * Copyright (c) 2015-2018 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -14,11 +14,17 @@
 #include <sys/time.h>
 #include <unistd.h>
 #include "scno.h"
+#include "kernel_timeval.h"
+
+typedef struct {
+	kernel_old_timeval_t it_interval;
+	kernel_old_timeval_t it_value;
+} kernel_old_itimerval_t;
 
 int
 main(void)
 {
-	static const struct itimerval new = {
+	static const kernel_old_itimerval_t new = {
 		.it_interval = { 0xc0de1, 0xc0de2 },
 		.it_value = { 0xc0de3, 0xc0de4 }
 	};
@@ -27,12 +33,12 @@ main(void)
 	static const kernel_ulong_t bogus_timer =
 		(kernel_ulong_t) 0xfacefeeddeadbeefULL;
 
-	TAIL_ALLOC_OBJECT_CONST_PTR(struct itimerval, p_old);
-	struct itimerval *const p_new = tail_memdup(&new, sizeof(new));
+	TAIL_ALLOC_OBJECT_CONST_PTR(kernel_old_itimerval_t, p_old);
+	kernel_old_itimerval_t *const p_new = tail_memdup(&new, sizeof(new));
 	void *const efault = tail_alloc(sizeof(new) - 8);
 	long rc;
 
-	if (setitimer(ITIMER_REAL, p_new, NULL))
+	if (syscall(__NR_setitimer, ITIMER_REAL, p_new, NULL))
 		perror_msg_and_skip("setitimer");
 	printf("setitimer(ITIMER_REAL"
 	       ", {it_interval={tv_sec=%lld, tv_usec=%llu}"
@@ -44,7 +50,7 @@ main(void)
 	       zero_extend_signed_to_ull(new.it_value.tv_usec));
 
 	fill_memory(p_old, sizeof(*p_old));
-	if (getitimer(ITIMER_REAL, p_old))
+	if (syscall(__NR_getitimer, ITIMER_REAL, p_old))
 		perror_msg_and_skip("getitimer");
 	printf("getitimer(ITIMER_REAL"
 	       ", {it_interval={tv_sec=%lld, tv_usec=%llu}"
@@ -55,7 +61,7 @@ main(void)
 	       zero_extend_signed_to_ull(p_old->it_value.tv_usec));
 
 	fill_memory(p_old, sizeof(*p_old));
-	setitimer(ITIMER_REAL, p_new, p_old);
+	syscall(__NR_setitimer, ITIMER_REAL, p_new, p_old);
 	printf("setitimer(ITIMER_REAL"
 	       ", {it_interval={tv_sec=%lld, tv_usec=%llu}"
 	       ", it_value={tv_sec=%lld, tv_usec=%llu}}"
@@ -70,10 +76,10 @@ main(void)
 	       (long long) p_old->it_value.tv_sec,
 	       zero_extend_signed_to_ull(p_old->it_value.tv_usec));
 
-	rc = getitimer(ITIMER_REAL, efault);
+	rc = syscall(__NR_getitimer, ITIMER_REAL, efault);
 	printf("getitimer(ITIMER_REAL, %p) = %s\n", efault, sprintrc(rc));
 
-	rc = setitimer(ITIMER_REAL, p_new, efault);
+	rc = syscall(__NR_setitimer, ITIMER_REAL, p_new, efault);
 	printf("setitimer(ITIMER_REAL"
 	       ", {it_interval={tv_sec=%lld, tv_usec=%llu}"
 	       ", it_value={tv_sec=%lld, tv_usec=%llu}}, %p) = %s\n",
@@ -83,7 +89,7 @@ main(void)
 	       zero_extend_signed_to_ull(new.it_value.tv_usec),
 	       efault, sprintrc(rc));
 
-	rc = setitimer(ITIMER_REAL, efault, p_old);
+	rc = syscall(__NR_setitimer, ITIMER_REAL, efault, p_old);
 	printf("setitimer(ITIMER_REAL, %p, %p) = %s\n",
 	       efault, p_old, sprintrc(rc));
 
@@ -147,10 +153,12 @@ main(void)
 
 	p_new->it_interval.tv_sec = 0xdeadbeefU;
 	p_new->it_interval.tv_usec = 0xfacefeedU;
-	p_new->it_value.tv_sec = (time_t) 0xcafef00ddeadbeefLL;
-	p_new->it_value.tv_usec = (suseconds_t) 0xbadc0dedfacefeedLL;
+	p_new->it_value.tv_sec =
+		(typeof(p_new->it_value.tv_sec)) 0xcafef00ddeadbeefLL;
+	p_new->it_value.tv_usec =
+		(typeof(p_new->it_value.tv_usec)) 0xbadc0dedfacefeedLL;
 
-	rc = setitimer(ITIMER_REAL, p_new, p_old);
+	rc = syscall(__NR_setitimer, ITIMER_REAL, p_new, p_old);
 	printf("setitimer(ITIMER_REAL"
 	       ", {it_interval={tv_sec=%lld, tv_usec=%llu}"
 	       ", it_value={tv_sec=%lld, tv_usec=%llu}}, %p) = %s\n",
diff -pruN 5.5-3/tests-mx32/xetpgid.c 5.9-0ubuntu2/tests-mx32/xetpgid.c
--- 5.5-3/tests-mx32/xetpgid.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/xetpgid.c	2020-09-23 16:29:35.000000000 +0000
@@ -2,7 +2,7 @@
  * This file is part of xetpgid strace test.
  *
  * Copyright (c) 2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -10,6 +10,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #if defined __NR_getpgid && defined __NR_setpgid
 
@@ -19,13 +20,21 @@
 int
 main(void)
 {
-	const int pid = getpid();
-	long rc = syscall(__NR_getpgid, F8ILL_KULONG_MASK | pid);
-	printf("getpgid(%d) = %ld\n", pid, rc);
+	PIDNS_TEST_INIT;
 
-	rc = syscall(__NR_setpgid, F8ILL_KULONG_MASK, F8ILL_KULONG_MASK | pid);
-	printf("setpgid(0, %d) = %ld\n", pid, rc);
+	const int pid = getpid();
+	long pgid = syscall(__NR_getpgid, F8ILL_KULONG_MASK | pid);
+	pidns_print_leader();
+	printf("getpgid(%d%s) = %ld%s\n", pid, pidns_pid2str(PT_TGID),
+		pgid, pidns_pid2str(PT_PGID));
+
+	long rc = syscall(__NR_setpgid, F8ILL_KULONG_MASK,
+		F8ILL_KULONG_MASK | pgid);
+	pidns_print_leader();
+	printf("setpgid(0, %ld%s) = %s\n", pgid, pidns_pid2str(PT_PGID),
+		sprintrc(rc));
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/xetpgid--pidns-translation.c 5.9-0ubuntu2/tests-mx32/xetpgid--pidns-translation.c
--- 5.5-3/tests-mx32/xetpgid--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/xetpgid--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "xetpgid.c"
diff -pruN 5.5-3/tests-mx32/xetpgid--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/xetpgid--pidns-translation.gen.test
--- 5.5-3/tests-mx32/xetpgid--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/xetpgid--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (xetpgid--pidns-translation test_pidns -a11 -e trace=getpgid,setpgid); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a11 -e trace=getpgid,setpgid
diff -pruN 5.5-3/tests-mx32/xetpriority.c 5.9-0ubuntu2/tests-mx32/xetpriority.c
--- 5.5-3/tests-mx32/xetpriority.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/xetpriority.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2019 The strace developers.
+ * Copyright (c) 2016-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -7,6 +7,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #if defined __NR_getpriority && defined __NR_setpriority
 
@@ -17,15 +18,30 @@
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	const int pid = getpid();
+	const int pgid = getpgid(0);
+
 	long rc = syscall(__NR_getpriority, PRIO_PROCESS,
 			  F8ILL_KULONG_MASK | pid);
-	printf("getpriority(PRIO_PROCESS, %d) = %ld\n", pid, rc);
+	pidns_print_leader();
+	printf("getpriority(PRIO_PROCESS, %d%s) = %ld\n",
+		pid, pidns_pid2str(PT_TGID), rc);
 
 	rc = syscall(__NR_setpriority, PRIO_PROCESS,
 		     F8ILL_KULONG_MASK | pid, F8ILL_KULONG_MASK);
-	printf("setpriority(PRIO_PROCESS, %d, 0) = %s\n", pid, sprintrc(rc));
+	pidns_print_leader();
+	printf("setpriority(PRIO_PROCESS, %d%s, 0) = %s\n",
+		pid, pidns_pid2str(PT_TGID), sprintrc(rc));
+
+	rc = syscall(__NR_getpriority, PRIO_PGRP,
+			  F8ILL_KULONG_MASK | pgid);
+	pidns_print_leader();
+	printf("getpriority(PRIO_PGRP, %d%s) = %ld\n",
+		pgid, pidns_pid2str(PT_PGID), rc);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/xetpriority.gen.test 5.9-0ubuntu2/tests-mx32/xetpriority.gen.test
--- 5.5-3/tests-mx32/xetpriority.gen.test	2020-02-06 16:23:27.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/xetpriority.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -1,4 +1,4 @@
 #!/bin/sh -efu
-# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (xetpriority -a29 -e trace=getpriority,setpriority); do not edit.
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (xetpriority -a27 -e trace=getpriority,setpriority); do not edit.
 . "${srcdir=.}/init.sh"
-run_strace_match_diff -a29 -e trace=getpriority,setpriority
+run_strace_match_diff -a27 -e trace=getpriority,setpriority
diff -pruN 5.5-3/tests-mx32/xetpriority--pidns-translation.c 5.9-0ubuntu2/tests-mx32/xetpriority--pidns-translation.c
--- 5.5-3/tests-mx32/xetpriority--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/xetpriority--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "xetpriority.c"
diff -pruN 5.5-3/tests-mx32/xetpriority--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/xetpriority--pidns-translation.gen.test
--- 5.5-3/tests-mx32/xetpriority--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/xetpriority--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (xetpriority--pidns-translation test_pidns -a27 -e trace=getpriority,setpriority); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a27 -e trace=getpriority,setpriority
diff -pruN 5.5-3/tests-mx32/xet_robust_list.c 5.9-0ubuntu2/tests-mx32/xet_robust_list.c
--- 5.5-3/tests-mx32/xet_robust_list.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/xet_robust_list.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -8,6 +8,7 @@
 
 #include "tests.h"
 #include "scno.h"
+#include "pidns.h"
 
 #if defined __NR_get_robust_list && defined __NR_set_robust_list
 
@@ -30,27 +31,36 @@ sprintaddr(void *addr)
 int
 main(void)
 {
+	PIDNS_TEST_INIT;
+
 	const pid_t pid = getpid();
+	const char *pid_str = pidns_pid2str(PT_TGID);
 	const long long_pid = (unsigned long) (0xdeadbeef00000000LL | pid);
 	TAIL_ALLOC_OBJECT_CONST_PTR(void *, p_head);
 	TAIL_ALLOC_OBJECT_CONST_PTR(size_t, p_len);
 
 	if (syscall(__NR_get_robust_list, long_pid, p_head, p_len))
 		perror_msg_and_skip("get_robust_list");
-	printf("get_robust_list(%d, [%s], [%lu]) = 0\n",
-	       (int) pid, sprintaddr(*p_head), (unsigned long) *p_len);
+	pidns_print_leader();
+	printf("get_robust_list(%d%s, [%s], [%lu]) = 0\n",
+	       pid, pid_str, sprintaddr(*p_head),
+	       (unsigned long) *p_len);
 
 	void *head = tail_alloc(*p_len);
 	if (syscall(__NR_set_robust_list, head, *p_len))
 		perror_msg_and_skip("set_robust_list");
+	pidns_print_leader();
 	printf("set_robust_list(%p, %lu) = 0\n",
 	       head, (unsigned long) *p_len);
 
 	if (syscall(__NR_get_robust_list, long_pid, p_head, p_len))
 		perror_msg_and_skip("get_robust_list");
-	printf("get_robust_list(%d, [%s], [%lu]) = 0\n",
-	       (int) pid, sprintaddr(*p_head), (unsigned long) *p_len);
+	pidns_print_leader();
+	printf("get_robust_list(%d%s, [%s], [%lu]) = 0\n",
+	       pid, pid_str, sprintaddr(*p_head),
+	       (unsigned long) *p_len);
 
+	pidns_print_leader();
 	puts("+++ exited with 0 +++");
 	return 0;
 }
diff -pruN 5.5-3/tests-mx32/xet_robust_list--pidns-translation.c 5.9-0ubuntu2/tests-mx32/xet_robust_list--pidns-translation.c
--- 5.5-3/tests-mx32/xet_robust_list--pidns-translation.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/xet_robust_list--pidns-translation.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define PIDNS_TRANSLATION
+#include "xet_robust_list.c"
diff -pruN 5.5-3/tests-mx32/xet_robust_list--pidns-translation.gen.test 5.9-0ubuntu2/tests-mx32/xet_robust_list--pidns-translation.gen.test
--- 5.5-3/tests-mx32/xet_robust_list--pidns-translation.gen.test	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/xet_robust_list--pidns-translation.gen.test	2020-09-24 09:18:50.000000000 +0000
@@ -0,0 +1,4 @@
+#!/bin/sh -efu
+# Generated by ./tests/gen_tests.sh from ./tests/gen_tests.in (xet_robust_list--pidns-translation test_pidns -a24 -e trace=get_robust_list,set_robust_list); do not edit.
+. "${srcdir=.}/init.sh"
+test_pidns -a24 -e trace=get_robust_list,set_robust_list
diff -pruN 5.5-3/tests-mx32/xettimeofday.c 5.9-0ubuntu2/tests-mx32/xettimeofday.c
--- 5.5-3/tests-mx32/xettimeofday.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/xettimeofday.c	2020-09-23 16:29:35.000000000 +0000
@@ -1,19 +1,23 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "tests.h"
-#include <assert.h>
-#include <stdio.h>
-#include <stdint.h>
-#include <unistd.h>
-#include <sys/time.h>
 #include "scno.h"
 
+#ifdef __NR_gettimeofday
+
+# include <assert.h>
+# include <stdio.h>
+# include <stdint.h>
+# include <unistd.h>
+# include <sys/time.h>
+# include "scno.h"
+
 int
 main(void)
 {
@@ -64,3 +68,9 @@ main(void)
 	puts("+++ exited with 0 +++");
 	return 0;
 }
+
+#else
+
+SKIP_MAIN_UNDEFINED("__NR_gettimeofday")
+
+#endif /* __NR_gettimeofday */
diff -pruN 5.5-3/tests-mx32/xgetdents.c 5.9-0ubuntu2/tests-mx32/xgetdents.c
--- 5.5-3/tests-mx32/xgetdents.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/xgetdents.c	2020-04-11 18:09:11.000000000 +0000
@@ -0,0 +1,141 @@
+/*
+ * Check decoding of getdents and getdents64 syscalls.
+ *
+ * Copyright (c) 2015-2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+
+#include <dirent.h>
+#include <fcntl.h>
+#include <stdio.h>
+#include <unistd.h>
+#include <sys/stat.h>
+#include "kernel_dirent.h"
+#include "print_fields.h"
+
+#if VERBOSE
+static const char *
+str_d_type(const unsigned char d_type)
+{
+	switch (d_type) {
+		case DT_DIR:
+			return "DT_DIR";
+		case DT_REG:
+			return "DT_REG";
+		default:
+			return "DT_UNKNOWN";
+	}
+}
+
+static void
+print_dirent(const kernel_dirent_type *d);
+#endif
+
+static const char *errstr;
+
+static long
+k_getdents(const unsigned int fd,
+	   const void *dirp,
+	   const unsigned int count)
+{
+	const kernel_ulong_t fill = (kernel_ulong_t) 0xdefaced00000000ULL;
+	const kernel_ulong_t bad = (kernel_ulong_t) 0xbadc0dedbadc0dedULL;
+	const kernel_ulong_t arg1 = fill | fd;
+	const kernel_ulong_t arg2 = (uintptr_t) dirp;
+	const kernel_ulong_t arg3 = fill | count;
+	const long rc = syscall(NR_getdents, arg1, arg2, arg3, bad, bad, bad);
+	errstr = sprintrc(rc);
+	return rc;
+}
+
+static void
+ls(int fd, char *buf, unsigned int size)
+{
+	long rc;
+	while ((rc = k_getdents(fd, buf, size))) {
+		if (rc < 0)
+			perror_msg_and_skip(STR_getdents);
+		printf("%s(%d, ", STR_getdents, fd);
+#if VERBOSE
+		printf("[");
+#else
+		unsigned long entries = 0;
+#endif
+		kernel_dirent_type *d;
+		for (long i = 0; i < rc; i += d->d_reclen) {
+			d = (kernel_dirent_type *) &buf[i];
+#if VERBOSE
+			if (i)
+				printf(", ");
+			print_dirent(d);
+#else
+			++entries;
+#endif
+		}
+#if VERBOSE
+		printf("]");
+#else
+		printf("%p /* %lu entries */", buf, entries);
+#endif
+		printf(", %u) = %ld\n", size, rc);
+	}
+#if VERBOSE
+	printf("%s(%d, [], %u) = 0\n", STR_getdents, fd, size);
+#else
+	printf("%s(%d, %p /* 0 entries */, %u) = 0\n",
+	       STR_getdents, fd, buf, size);
+#endif
+}
+
+int
+main(void)
+{
+	static const char dot[] = ".";
+	static const char dot_dot[] = "..";
+	static const char dname[] = STR_getdents
+#if VERBOSE
+		"-v"
+#endif
+		".test.tmp.dir";
+	static const char fname[] =
+		"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
+		"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
+		"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
+		"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
+		"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
+		"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
+		"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\n"
+		"A\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nA\nZ";
+
+	if (mkdir(dname, 0700))
+		perror_msg_and_fail("mkdir: %s", dname);
+	if (chdir(dname))
+		perror_msg_and_fail("chdir: %s", dname);
+	int fd = creat(fname, 0600);
+	if (fd < 0)
+		perror_msg_and_fail("creat: %s", fname);
+	if (close(fd))
+		perror_msg_and_fail("close: %s", fname);
+	fd = open(dot, O_RDONLY | O_DIRECTORY);
+	if (fd < 0)
+		perror_msg_and_fail("open: %s", dot);
+
+	unsigned int count = 0xdeadbeefU;
+	k_getdents(-1U, NULL, count);
+	printf("%s(-1, NULL, %u) = %s\n", STR_getdents, count, errstr);
+
+	static char buf[8192];
+	ls(fd, buf, sizeof(buf));
+
+	if (unlink(fname))
+		perror_msg_and_fail("unlink: %s", fname);
+	if (chdir(dot_dot))
+		perror_msg_and_fail("chdir: %s", dot_dot);
+	if (rmdir(dname))
+		perror_msg_and_fail("rmdir: %s", dname);
+
+	puts("+++ exited with 0 +++");
+	return 0;
+}
diff -pruN 5.5-3/tests-mx32/xmalloc_for_tests.c 5.9-0ubuntu2/tests-mx32/xmalloc_for_tests.c
--- 5.5-3/tests-mx32/xmalloc_for_tests.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/xmalloc_for_tests.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,2 @@
+#define error_msg_and_die error_msg_and_fail
+#include "xmalloc.c"
diff -pruN 5.5-3/tests-mx32/xstatx.c 5.9-0ubuntu2/tests-mx32/xstatx.c
--- 5.5-3/tests-mx32/xstatx.c	2019-07-11 17:51:22.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/xstatx.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2015-2016 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2015-2019 The strace developers.
+ * Copyright (c) 2015-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -468,12 +468,12 @@ main(void)
 	TEST_SYSCALL_STATX_FLAGS_STR = old_flags_str;
 
 	SET_MASK_INVOKE(0, "0");
-	SET_MASK_INVOKE(0xfffff000U, "0xfffff000 /* STATX_??? */");
+	SET_MASK_INVOKE(0xffffe000U, "0xffffe000 /* STATX_??? */");
 
 	SET_MASK_INVOKE(0xfffffffbU,
 		"STATX_TYPE|STATX_MODE|STATX_UID|STATX_GID|STATX_ATIME|"
 		"STATX_MTIME|STATX_CTIME|STATX_INO|STATX_SIZE|STATX_BLOCKS|"
-		"STATX_BTIME|0xfffff000");
+		"STATX_BTIME|STATX_MNT_ID|0xffffe000");
 
 	SET_MASK_INVOKE(STATX_UID, "STATX_UID");
 
diff -pruN 5.5-3/tests-mx32/zeroargc.c 5.9-0ubuntu2/tests-mx32/zeroargc.c
--- 5.5-3/tests-mx32/zeroargc.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/tests-mx32/zeroargc.c	2020-04-03 22:58:26.000000000 +0000
@@ -2,7 +2,7 @@
  * Execute an executable with zero argc and specified environment.
  *
  * Copyright (c) 2017-2018 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2017-2019 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
diff -pruN 5.5-3/time.c 5.9-0ubuntu2/time.c
--- 5.5-3/time.c	2019-07-24 17:12:18.000000000 +0000
+++ 5.9-0ubuntu2/time.c	2020-04-19 01:22:29.000000000 +0000
@@ -2,7 +2,7 @@
  * Copyright (c) 1991, 1992 Paul Kranenburg <pk@cs.few.eur.nl>
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995, 1996 Rick Sladkey <jrs@world.std.com>
- * Copyright (c) 1996-2019 The strace developers.
+ * Copyright (c) 1996-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -13,6 +13,7 @@
 #include <signal.h>
 #include <sys/timex.h>
 
+#if HAVE_ARCH_TIME32_SYSCALLS || HAVE_ARCH_OLD_TIME64_SYSCALLS
 static void
 print_timezone(struct tcb *const tcp, const kernel_ulong_t addr)
 {
@@ -35,6 +36,16 @@ SYS_FUNC(gettimeofday)
 	return 0;
 }
 
+SYS_FUNC(settimeofday)
+{
+	print_timeval(tcp, tcp->u_arg[0]);
+	tprints(", ");
+	print_timezone(tcp, tcp->u_arg[1]);
+
+	return RVAL_DECODED;
+}
+#endif
+
 #ifdef ALPHA
 SYS_FUNC(osf_gettimeofday)
 {
@@ -47,15 +58,6 @@ SYS_FUNC(osf_gettimeofday)
 }
 #endif
 
-SYS_FUNC(settimeofday)
-{
-	print_timeval(tcp, tcp->u_arg[0]);
-	tprints(", ");
-	print_timezone(tcp, tcp->u_arg[1]);
-
-	return RVAL_DECODED;
-}
-
 #ifdef ALPHA
 SYS_FUNC(osf_settimeofday)
 {
diff -pruN 5.5-3/trie.c 5.9-0ubuntu2/trie.c
--- 5.5-3/trie.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/trie.c	2020-08-25 14:29:30.000000000 +0000
@@ -0,0 +1,290 @@
+/*
+ * Simple trie implementation for key-value mapping storage
+ *
+ * Copyright (c) 2020 Ákos Uzonyi <uzonyi.akos@gmail.com>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
+#include <stdlib.h>
+#include <stdio.h>
+
+#include "trie.h"
+#include "xmalloc.h"
+
+static const uint8_t ptr_sz_lg = (sizeof(void *) == 8 ? 6 : 5);
+
+/**
+ * Returns lg2 of node size in bits for the specific level of the trie.
+ */
+static uint8_t
+trie_get_node_size(struct trie *t, uint8_t depth)
+{
+	/* Last level contains data and we allow it having a different size */
+	if (depth == t->max_depth)
+		return t->data_block_key_bits + t->item_size_lg;
+	/* Last level of the tree can be smaller */
+	if (depth == t->max_depth - 1)
+		return (t->key_size - t->data_block_key_bits - 1) %
+		t->node_key_bits + 1 + ptr_sz_lg;
+
+	return t->node_key_bits + ptr_sz_lg;
+}
+
+/**
+ * Provides starting offset of bits in key corresponding to the node index
+ * at the specific level.
+ */
+static uint8_t
+trie_get_node_bit_offs(struct trie *t, uint8_t depth)
+{
+	uint8_t offs;
+
+	if (depth == t->max_depth)
+		return 0;
+
+	offs = t->data_block_key_bits;
+
+	if (depth == t->max_depth - 1)
+		return offs;
+
+	/* data_block_size + remainder */
+	offs += trie_get_node_size(t, t->max_depth - 1) - ptr_sz_lg;
+	offs += (t->max_depth - depth - 2) * t->node_key_bits;
+
+	return offs;
+}
+
+struct trie *
+trie_create(uint8_t key_size, uint8_t item_size_lg, uint8_t node_key_bits,
+            uint8_t data_block_key_bits, uint64_t empty_value)
+{
+	if (item_size_lg > 6)
+		return NULL;
+	if (key_size > 64)
+		return NULL;
+	if (node_key_bits < 1)
+		return NULL;
+	if (data_block_key_bits < 1 || data_block_key_bits > key_size)
+		return NULL;
+
+	struct trie *t = malloc(sizeof(*t));
+	if (!t)
+		return NULL;
+
+	t->empty_value = empty_value;
+	t->data = NULL;
+	t->item_size_lg = item_size_lg;
+	t->node_key_bits = node_key_bits;
+	t->data_block_key_bits = data_block_key_bits;
+	t->key_size = key_size;
+	t->max_depth = (key_size - data_block_key_bits + node_key_bits - 1)
+		/ t->node_key_bits;
+
+	if (item_size_lg != 6)
+		t->empty_value &= (((uint64_t) 1 << (1 << t->item_size_lg)) - 1);
+
+	return t;
+}
+
+static void *
+trie_create_data_block(struct trie *t)
+{
+	uint64_t fill_value = t->empty_value;
+	for (int i = 1; i < 1 << (6 - t->item_size_lg); i++) {
+		fill_value <<= (1 << t->item_size_lg);
+		fill_value |= t->empty_value;
+	}
+
+	uint8_t sz = t->data_block_key_bits + t->item_size_lg;
+	if (sz < 6)
+		sz = 6;
+
+	size_t count = 1 << (sz - 6);
+	uint64_t *data_block = xcalloc(count, 8);
+
+	for (size_t i = 0; i < count; i++)
+		data_block[i] = fill_value;
+
+	return data_block;
+}
+
+static uint64_t *
+trie_get_node(struct trie *t, uint64_t key, bool auto_create)
+{
+	void **cur_node = &(t->data);
+
+	if (t->key_size < 64 && key > (uint64_t) 1 << t->key_size)
+		return NULL;
+
+	for (uint8_t cur_depth = 0; cur_depth <= t->max_depth; cur_depth++) {
+		uint8_t offs = trie_get_node_bit_offs(t, cur_depth);
+		uint8_t sz = trie_get_node_size(t, cur_depth);
+
+		if (!*cur_node) {
+			if (!auto_create)
+				return NULL;
+
+			if (cur_depth == t->max_depth)
+				*cur_node = trie_create_data_block(t);
+			else
+				*cur_node = xcalloc(1 << sz, 1);
+		}
+
+		if (cur_depth == t->max_depth)
+			break;
+
+		size_t pos = (key >> offs) & ((1 << (sz - ptr_sz_lg)) - 1);
+		cur_node = (((void **) (*cur_node)) + pos);
+	}
+
+	return (uint64_t *) (*cur_node);
+}
+
+static void
+trie_data_block_calc_pos(struct trie *t, uint64_t key,
+                         uint64_t *pos, uint64_t *mask, uint64_t *offs)
+{
+	uint64_t key_mask;
+
+	key_mask = (1 << t->data_block_key_bits) - 1;
+	*pos = (key & key_mask) >> (6 - t->item_size_lg);
+
+	if (t->item_size_lg == 6) {
+		*offs = 0;
+		*mask = -1;
+		return;
+	}
+
+	key_mask = (1 << (6 - t->item_size_lg)) - 1;
+	*offs = (key & key_mask) * (1 << t->item_size_lg);
+
+	*mask = (((uint64_t) 1 << (1 << t->item_size_lg)) - 1) << *offs;
+}
+
+bool
+trie_set(struct trie *t, uint64_t key, uint64_t val)
+{
+	uint64_t *data = trie_get_node(t, key, true);
+	if (!data)
+		return false;
+
+	uint64_t pos, mask, offs;
+	trie_data_block_calc_pos(t, key, &pos, &mask, &offs);
+
+	data[pos] &= ~mask;
+	data[pos] |= (val << offs) & mask;
+
+	return true;
+}
+
+static uint64_t
+trie_data_block_get(struct trie *t, uint64_t *data, uint64_t key)
+{
+	if (!data)
+		return t->empty_value;
+
+	uint64_t pos, mask, offs;
+	trie_data_block_calc_pos(t, key, &pos, &mask, &offs);
+
+	return (data[pos] & mask) >> offs;
+}
+
+uint64_t
+trie_get(struct trie *b, uint64_t key)
+{
+	return trie_data_block_get(b, trie_get_node(b, key, false), key);
+}
+
+static uint64_t
+trie_iterate_keys_node(struct trie *t,
+                       trie_iterate_fn fn, void *fn_data,
+                       void *node, uint64_t start, uint64_t end,
+                       uint8_t depth)
+{
+	if (start > end || !node)
+		return 0;
+
+	if (t->key_size < 64) {
+		uint64_t key_max = ((uint64_t) 1 << t->key_size) - 1;
+		if (end > key_max)
+			end = key_max;
+	}
+
+	if (depth == t->max_depth) {
+		for (uint64_t i = start; i <= end; i++)
+			fn(fn_data, i, trie_data_block_get(t,
+				(uint64_t *) node, i));
+
+		return end - start + 1;
+	}
+
+	uint8_t parent_node_bit_off = depth == 0 ?
+		t->key_size :
+		trie_get_node_bit_offs(t, depth - 1);
+
+	uint64_t first_key_in_node = start &
+		(uint64_t) -1 << parent_node_bit_off;
+
+	uint8_t node_bit_off = trie_get_node_bit_offs(t, depth);
+	uint8_t node_key_bits = parent_node_bit_off - node_bit_off;
+	uint64_t mask = ((uint64_t) 1 << (node_key_bits)) - 1;
+	uint64_t start_index = (start >> node_bit_off) & mask;
+	uint64_t end_index = (end >> node_bit_off) & mask;
+	uint64_t child_key_count = (uint64_t) 1 << node_bit_off;
+
+	uint64_t count = 0;
+
+	for (uint64_t i = start_index; i <= end_index; i++) {
+		uint64_t child_start = first_key_in_node + i * child_key_count;
+		uint64_t child_end = first_key_in_node +
+			(i + 1) * child_key_count - 1;
+
+		if (child_start < start)
+			child_start = start;
+		if (child_end > end)
+			child_end = end;
+
+		count += trie_iterate_keys_node(t, fn, fn_data,
+			((void **) node)[i], child_start, child_end,
+			depth + 1);
+	}
+
+	return count;
+}
+
+uint64_t trie_iterate_keys(struct trie *t, uint64_t start, uint64_t end,
+                           trie_iterate_fn fn, void *fn_data)
+{
+	return trie_iterate_keys_node(t, fn, fn_data, t->data,
+		start, end, 0);
+}
+
+static void
+trie_free_node(struct trie *t, void *node, uint8_t depth)
+{
+	if (!node)
+		return;
+
+	if (depth >= t->max_depth)
+		goto free_node;
+
+	size_t sz = 1 << (trie_get_node_size(t, depth) - ptr_sz_lg);
+	for (size_t i = 0; i < sz; i++)
+		trie_free_node(t, ((void **) node)[i], depth + 1);
+
+free_node:
+	free(node);
+}
+
+void
+trie_free(struct trie *t)
+{
+	trie_free_node(t, t->data, 0);
+	free(t);
+}
diff -pruN 5.5-3/trie.h 5.9-0ubuntu2/trie.h
--- 5.5-3/trie.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/trie.h	2020-09-23 16:29:35.000000000 +0000
@@ -0,0 +1,92 @@
+/*
+ * Simple trie interface
+ *
+ * Copyright (c) 2020 Ákos Uzonyi <uzonyi.akos@gmail.com>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
+#ifndef STRACE_TRIE_H
+# define STRACE_TRIE_H
+
+# include <stdbool.h>
+# include <stdint.h>
+
+/**
+ * Trie control structure.
+ * Trie implemented here has the following properties:
+ *  * It allows storing values of the same size, the size can vary from 1 bit to
+ *    64 bit values (only power of 2 sizes are allowed).
+ *  * The key can be up to 64 bits in size.
+ *  * It has separate configuration for node size and data block size.
+ *
+ * How bits of key are used for different node levels:
+ *
+ *   highest bits                                                  lowest bits
+ *  | node_key_bits | node_key_bits | ... | <remainder> | data_block_key_bits |
+ *  \_________________________________________________________________________/
+ *                                 key_size
+ *
+ * So, the remainder is used on the lowest non-data node level.
+ *
+ * As of now, it doesn't implement any mechanisms for resizing/changing key
+ * size.  De-fragmentation is also unsupported currently.
+ */
+struct trie {
+	/** Return value of trie_get if key is not found */
+	uint64_t empty_value;
+
+	/** Pointer to root node */
+	void *data;
+
+	/** Key size in bits (0..64). */
+	uint8_t key_size;
+
+	/**
+	 * Size of the stored values in log2 bits (0..6).
+	 * (6: 64 bit values, 5: 32 bit values, ...)
+	 */
+	uint8_t item_size_lg;
+
+	/**
+	 * Number of bits in the key that make a symbol for a node.
+	 * (equals to log2 of the child count of the node)
+	 */
+	uint8_t node_key_bits;
+
+	/**
+	 * Number of bits in the key that make a symbol for the data block (leaf).
+	 * (equals to log2 of the value count stored in a data block)
+	 */
+	uint8_t data_block_key_bits;
+
+	/** The depth of the data block. Calculated from the values above */
+	uint8_t max_depth;
+};
+
+struct trie* trie_create(uint8_t key_size, uint8_t item_size_lg,
+			uint8_t node_key_bits, uint8_t data_block_key_bits,
+			uint64_t empty_value);
+
+bool trie_set(struct trie *t, uint64_t key, uint64_t val);
+uint64_t trie_get(struct trie *t, uint64_t key);
+
+typedef void (*trie_iterate_fn)(void *data, uint64_t key, uint64_t val);
+
+/**
+ * Calls trie_iterate_fn for each key-value pair where
+ * key is inside the [start, end] interval (inclusive).
+ *
+ * @param t        The trie.
+ * @param start    The start of the key interval (inclusive).
+ * @param end      The end of the key interval (inclusive).
+ * @param fn       The function to be called.
+ * @param fn_data  The value to be passed to fn.
+ */
+uint64_t trie_iterate_keys(struct trie *t, uint64_t start, uint64_t end,
+			    trie_iterate_fn fn, void *fn_data);
+
+void trie_free(struct trie *t);
+
+#endif /* !STRACE_TRIE_H */
diff -pruN 5.5-3/types/btrfs.h 5.9-0ubuntu2/types/btrfs.h
--- 5.5-3/types/btrfs.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/types/btrfs.h	2020-07-12 08:00:00.000000000 +0000
@@ -0,0 +1,25 @@
+/*
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
+#ifndef STRACE_TYPES_BTRFS_H
+# define STRACE_TYPES_BTRFS_H
+
+# ifdef HAVE_LINUX_BTRFS_H
+#  include <stdio.h>
+#  include <stdint.h>
+#  include <linux/btrfs.h>
+# endif
+
+typedef struct {
+	uint64_t logical;
+	uint64_t size;
+	uint64_t reserved[3];
+	uint64_t flags;
+	uint64_t inodes;
+} struct_btrfs_ioctl_logical_ino_args;
+
+#endif /* STRACE_TYPES_BTRFS_H */
diff -pruN 5.5-3/types/check-btrfs.c 5.9-0ubuntu2/types/check-btrfs.c
--- 5.5-3/types/check-btrfs.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/types/check-btrfs.c	2020-09-24 09:18:43.000000000 +0000
@@ -0,0 +1,14 @@
+/* Generated by ./types/gen.sh from ./types/btrfs.h; do not edit. */
+#include "defs.h"
+#include "static_assert.h"
+#include "types/btrfs.h"
+
+#ifdef HAVE_STRUCT_BTRFS_IOCTL_LOGICAL_INO_ARGS
+# ifdef HAVE_STRUCT_BTRFS_IOCTL_LOGICAL_INO_ARGS_INODES
+static_assert(sizeof(struct btrfs_ioctl_logical_ino_args) == sizeof(struct_btrfs_ioctl_logical_ino_args),
+      "struct btrfs_ioctl_logical_ino_args size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct btrfs_ioctl_logical_ino_args) <= offsetof(struct_btrfs_ioctl_logical_ino_args, inodes),
+"struct btrfs_ioctl_logical_ino_args size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_BTRFS_IOCTL_LOGICAL_INO_ARGS_INODES */
+#endif /* HAVE_STRUCT_BTRFS_IOCTL_LOGICAL_INO_ARGS */
diff -pruN 5.5-3/types/check-btrfs.m4 5.9-0ubuntu2/types/check-btrfs.m4
--- 5.5-3/types/check-btrfs.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/types/check-btrfs.m4	2020-09-24 09:18:43.000000000 +0000
@@ -0,0 +1,15 @@
+dnl Generated by ./types/gen.sh from ./types/btrfs.h; do not edit.
+AC_DEFUN([st_CHECK_TYPES_BTRFS],[
+AC_CHECK_HEADERS([linux/btrfs.h],[
+
+AC_CHECK_TYPES([struct btrfs_ioctl_logical_ino_args],
+[AC_CHECK_MEMBERS([struct btrfs_ioctl_logical_ino_args.inodes],,,[AC_INCLUDES_DEFAULT
+#include <stdio.h>
+#include <stdint.h>
+#include <linux/btrfs.h>])],,[AC_INCLUDES_DEFAULT
+#include <stdio.h>
+#include <stdint.h>
+#include <linux/btrfs.h>])
+],[],[AC_INCLUDES_DEFAULT
+#include <stdio.h>
+#include <stdint.h>])])
diff -pruN 5.5-3/types/check-cryptouser.m4 5.9-0ubuntu2/types/check-cryptouser.m4
--- 5.5-3/types/check-cryptouser.m4	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/types/check-cryptouser.m4	2020-09-24 09:18:43.000000000 +0000
@@ -31,4 +31,5 @@ AC_CHECK_TYPES([struct crypto_report_rng
 [AC_CHECK_MEMBERS([struct crypto_report_rng.seedsize],,,[AC_INCLUDES_DEFAULT
 #include <linux/cryptouser.h>])],,[AC_INCLUDES_DEFAULT
 #include <linux/cryptouser.h>])
+],[],[AC_INCLUDES_DEFAULT
 ])])
diff -pruN 5.5-3/types/check-evdev.m4 5.9-0ubuntu2/types/check-evdev.m4
--- 5.5-3/types/check-evdev.m4	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/types/check-evdev.m4	2020-09-24 09:18:43.000000000 +0000
@@ -16,4 +16,5 @@ AC_CHECK_TYPES([struct input_mask],
 [AC_CHECK_MEMBERS([struct input_mask.codes_ptr],,,[AC_INCLUDES_DEFAULT
 #include <linux/input.h>])],,[AC_INCLUDES_DEFAULT
 #include <linux/input.h>])
+],[],[AC_INCLUDES_DEFAULT
 ])])
diff -pruN 5.5-3/types/check-io_uring.c 5.9-0ubuntu2/types/check-io_uring.c
--- 5.5-3/types/check-io_uring.c	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/types/check-io_uring.c	2020-09-24 09:18:43.000000000 +0000
@@ -14,13 +14,13 @@ static_assert(sizeof(struct io_sqring_of
 #endif /* HAVE_STRUCT_IO_SQRING_OFFSETS */
 
 #ifdef HAVE_STRUCT_IO_CQRING_OFFSETS
-# ifdef HAVE_STRUCT_IO_CQRING_OFFSETS_RESV
+# ifdef HAVE_STRUCT_IO_CQRING_OFFSETS_CQES
 static_assert(sizeof(struct io_cqring_offsets) == sizeof(struct_io_cqring_offsets),
       "struct io_cqring_offsets size mismatch, please update the decoder or fix the kernel");
 # else
-static_assert(sizeof(struct io_cqring_offsets) <= offsetof(struct_io_cqring_offsets, resv),
+static_assert(sizeof(struct io_cqring_offsets) <= offsetof(struct_io_cqring_offsets, cqes),
 "struct io_cqring_offsets size mismatch, please update the decoder or fix the kernel");
-# endif /* HAVE_STRUCT_IO_CQRING_OFFSETS_RESV */
+# endif /* HAVE_STRUCT_IO_CQRING_OFFSETS_CQES */
 #endif /* HAVE_STRUCT_IO_CQRING_OFFSETS */
 
 #ifdef HAVE_STRUCT_IO_URING_PARAMS
@@ -42,3 +42,23 @@ static_assert(sizeof(struct io_uring_fil
 "struct io_uring_files_update size mismatch, please update the decoder or fix the kernel");
 # endif /* HAVE_STRUCT_IO_URING_FILES_UPDATE_FDS */
 #endif /* HAVE_STRUCT_IO_URING_FILES_UPDATE */
+
+#ifdef HAVE_STRUCT_IO_URING_PROBE_OP
+# ifdef HAVE_STRUCT_IO_URING_PROBE_OP_RESV2
+static_assert(sizeof(struct io_uring_probe_op) == sizeof(struct_io_uring_probe_op),
+      "struct io_uring_probe_op size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct io_uring_probe_op) <= offsetof(struct_io_uring_probe_op, resv2),
+"struct io_uring_probe_op size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_IO_URING_PROBE_OP_RESV2 */
+#endif /* HAVE_STRUCT_IO_URING_PROBE_OP */
+
+#ifdef HAVE_STRUCT_IO_URING_PROBE
+# ifdef HAVE_STRUCT_IO_URING_PROBE_OPS
+static_assert(sizeof(struct io_uring_probe) == sizeof(struct_io_uring_probe),
+      "struct io_uring_probe size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct io_uring_probe) <= offsetof(struct_io_uring_probe, ops),
+"struct io_uring_probe size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_IO_URING_PROBE_OPS */
+#endif /* HAVE_STRUCT_IO_URING_PROBE */
diff -pruN 5.5-3/types/check-io_uring.m4 5.9-0ubuntu2/types/check-io_uring.m4
--- 5.5-3/types/check-io_uring.m4	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/types/check-io_uring.m4	2020-09-24 09:18:43.000000000 +0000
@@ -8,7 +8,7 @@ AC_CHECK_TYPES([struct io_sqring_offsets
 #include <linux/io_uring.h>])
 
 AC_CHECK_TYPES([struct io_cqring_offsets],
-[AC_CHECK_MEMBERS([struct io_cqring_offsets.resv],,,[AC_INCLUDES_DEFAULT
+[AC_CHECK_MEMBERS([struct io_cqring_offsets.cqes],,,[AC_INCLUDES_DEFAULT
 #include <linux/io_uring.h>])],,[AC_INCLUDES_DEFAULT
 #include <linux/io_uring.h>])
 
@@ -21,4 +21,15 @@ AC_CHECK_TYPES([struct io_uring_files_up
 [AC_CHECK_MEMBERS([struct io_uring_files_update.fds],,,[AC_INCLUDES_DEFAULT
 #include <linux/io_uring.h>])],,[AC_INCLUDES_DEFAULT
 #include <linux/io_uring.h>])
+
+AC_CHECK_TYPES([struct io_uring_probe_op],
+[AC_CHECK_MEMBERS([struct io_uring_probe_op.resv2],,,[AC_INCLUDES_DEFAULT
+#include <linux/io_uring.h>])],,[AC_INCLUDES_DEFAULT
+#include <linux/io_uring.h>])
+
+AC_CHECK_TYPES([struct io_uring_probe],
+[AC_CHECK_MEMBERS([struct io_uring_probe.ops],,,[AC_INCLUDES_DEFAULT
+#include <linux/io_uring.h>])],,[AC_INCLUDES_DEFAULT
+#include <linux/io_uring.h>])
+],[],[AC_INCLUDES_DEFAULT
 ])])
diff -pruN 5.5-3/types/check-loop.c 5.9-0ubuntu2/types/check-loop.c
--- 5.5-3/types/check-loop.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/types/check-loop.c	2020-09-24 09:18:43.000000000 +0000
@@ -0,0 +1,14 @@
+/* Generated by ./types/gen.sh from ./types/loop.h; do not edit. */
+#include "defs.h"
+#include "static_assert.h"
+#include "types/loop.h"
+
+#ifdef HAVE_STRUCT_LOOP_CONFIG
+# ifdef HAVE_STRUCT_LOOP_CONFIG___RESERVED
+static_assert(sizeof(struct loop_config) == sizeof(struct_loop_config),
+      "struct loop_config size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct loop_config) <= offsetof(struct_loop_config, __reserved),
+"struct loop_config size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_LOOP_CONFIG___RESERVED */
+#endif /* HAVE_STRUCT_LOOP_CONFIG */
diff -pruN 5.5-3/types/check-loop.m4 5.9-0ubuntu2/types/check-loop.m4
--- 5.5-3/types/check-loop.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/types/check-loop.m4	2020-09-24 09:18:43.000000000 +0000
@@ -0,0 +1,12 @@
+dnl Generated by ./types/gen.sh from ./types/loop.h; do not edit.
+AC_DEFUN([st_CHECK_TYPES_LOOP],[
+AC_CHECK_HEADERS([linux/loop.h],[
+
+AC_CHECK_TYPES([struct loop_config],
+[AC_CHECK_MEMBERS([struct loop_config.__reserved],,,[AC_INCLUDES_DEFAULT
+#include <linux/ioctl.h>
+#include <linux/loop.h>])],,[AC_INCLUDES_DEFAULT
+#include <linux/ioctl.h>
+#include <linux/loop.h>])
+],[],[AC_INCLUDES_DEFAULT
+#include <linux/ioctl.h>])])
diff -pruN 5.5-3/types/check-openat2.c 5.9-0ubuntu2/types/check-openat2.c
--- 5.5-3/types/check-openat2.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/types/check-openat2.c	2020-09-24 09:18:43.000000000 +0000
@@ -0,0 +1,14 @@
+/* Generated by ./types/gen.sh from ./types/openat2.h; do not edit. */
+#include "defs.h"
+#include "static_assert.h"
+#include "types/openat2.h"
+
+#ifdef HAVE_STRUCT_OPEN_HOW
+# ifdef HAVE_STRUCT_OPEN_HOW_RESOLVE
+static_assert(sizeof(struct open_how) == sizeof(struct_open_how),
+      "struct open_how size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct open_how) <= offsetof(struct_open_how, resolve),
+"struct open_how size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_OPEN_HOW_RESOLVE */
+#endif /* HAVE_STRUCT_OPEN_HOW */
diff -pruN 5.5-3/types/check-openat2.m4 5.9-0ubuntu2/types/check-openat2.m4
--- 5.5-3/types/check-openat2.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/types/check-openat2.m4	2020-09-24 09:18:43.000000000 +0000
@@ -0,0 +1,10 @@
+dnl Generated by ./types/gen.sh from ./types/openat2.h; do not edit.
+AC_DEFUN([st_CHECK_TYPES_OPENAT2],[
+AC_CHECK_HEADERS([linux/openat2.h],[
+
+AC_CHECK_TYPES([struct open_how],
+[AC_CHECK_MEMBERS([struct open_how.resolve],,,[AC_INCLUDES_DEFAULT
+#include <linux/openat2.h>])],,[AC_INCLUDES_DEFAULT
+#include <linux/openat2.h>])
+],[],[AC_INCLUDES_DEFAULT
+])])
diff -pruN 5.5-3/types/check-rtnl_link.m4 5.9-0ubuntu2/types/check-rtnl_link.m4
--- 5.5-3/types/check-rtnl_link.m4	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/types/check-rtnl_link.m4	2020-09-24 09:18:43.000000000 +0000
@@ -29,4 +29,5 @@ AC_CHECK_TYPES([struct ifla_port_vsi],
 #include <linux/rtnetlink.h>])],,[AC_INCLUDES_DEFAULT
 #include "$srcdir/netlink.h"
 #include <linux/rtnetlink.h>])
-])])
+],[],[AC_INCLUDES_DEFAULT
+#include "$srcdir/netlink.h"])])
diff -pruN 5.5-3/types/check-rtnl_mdb.m4 5.9-0ubuntu2/types/check-rtnl_mdb.m4
--- 5.5-3/types/check-rtnl_mdb.m4	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/types/check-rtnl_mdb.m4	2020-09-24 09:18:43.000000000 +0000
@@ -15,4 +15,5 @@ AC_CHECK_TYPES([struct br_mdb_entry],
 #include <linux/if_bridge.h>])],,[AC_INCLUDES_DEFAULT
 #include <netinet/in.h>
 #include <linux/if_bridge.h>])
-])])
+],[],[AC_INCLUDES_DEFAULT
+#include <netinet/in.h>])])
diff -pruN 5.5-3/types/check-rtnl_neightbl.m4 5.9-0ubuntu2/types/check-rtnl_neightbl.m4
--- 5.5-3/types/check-rtnl_neightbl.m4	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/types/check-rtnl_neightbl.m4	2020-09-24 09:18:43.000000000 +0000
@@ -15,4 +15,5 @@ AC_CHECK_TYPES([struct ndt_stats],
 #include <linux/rtnetlink.h>])],,[AC_INCLUDES_DEFAULT
 #include "$srcdir/netlink.h"
 #include <linux/rtnetlink.h>])
-])])
+],[],[AC_INCLUDES_DEFAULT
+#include "$srcdir/netlink.h"])])
diff -pruN 5.5-3/types/check-rtnl_route.m4 5.9-0ubuntu2/types/check-rtnl_route.m4
--- 5.5-3/types/check-rtnl_route.m4	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/types/check-rtnl_route.m4	2020-09-24 09:18:43.000000000 +0000
@@ -15,4 +15,5 @@ AC_CHECK_TYPES([struct rtvia],
 #include <linux/rtnetlink.h>])],,[AC_INCLUDES_DEFAULT
 #include "$srcdir/netlink.h"
 #include <linux/rtnetlink.h>])
-])])
+],[],[AC_INCLUDES_DEFAULT
+#include "$srcdir/netlink.h"])])
diff -pruN 5.5-3/types/check-tee.c 5.9-0ubuntu2/types/check-tee.c
--- 5.5-3/types/check-tee.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/types/check-tee.c	2020-09-24 09:18:43.000000000 +0000
@@ -0,0 +1,114 @@
+/* Generated by ./types/gen.sh from ./types/tee.h; do not edit. */
+#include "defs.h"
+#include "static_assert.h"
+#include "types/tee.h"
+
+#ifdef HAVE_STRUCT_TEE_IOCTL_BUF_DATA
+# ifdef HAVE_STRUCT_TEE_IOCTL_BUF_DATA_BUF_LEN
+static_assert(sizeof(struct tee_ioctl_buf_data) == sizeof(struct_tee_ioctl_buf_data),
+      "struct tee_ioctl_buf_data size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct tee_ioctl_buf_data) <= offsetof(struct_tee_ioctl_buf_data, buf_len),
+"struct tee_ioctl_buf_data size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_TEE_IOCTL_BUF_DATA_BUF_LEN */
+#endif /* HAVE_STRUCT_TEE_IOCTL_BUF_DATA */
+
+#ifdef HAVE_STRUCT_TEE_IOCTL_CANCEL_ARG
+# ifdef HAVE_STRUCT_TEE_IOCTL_CANCEL_ARG_SESSION
+static_assert(sizeof(struct tee_ioctl_cancel_arg) == sizeof(struct_tee_ioctl_cancel_arg),
+      "struct tee_ioctl_cancel_arg size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct tee_ioctl_cancel_arg) <= offsetof(struct_tee_ioctl_cancel_arg, session),
+"struct tee_ioctl_cancel_arg size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_TEE_IOCTL_CANCEL_ARG_SESSION */
+#endif /* HAVE_STRUCT_TEE_IOCTL_CANCEL_ARG */
+
+#ifdef HAVE_STRUCT_TEE_IOCTL_CLOSE_SESSION_ARG
+# ifdef HAVE_STRUCT_TEE_IOCTL_CLOSE_SESSION_ARG_SESSION
+static_assert(sizeof(struct tee_ioctl_close_session_arg) == sizeof(struct_tee_ioctl_close_session_arg),
+      "struct tee_ioctl_close_session_arg size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct tee_ioctl_close_session_arg) <= offsetof(struct_tee_ioctl_close_session_arg, session),
+"struct tee_ioctl_close_session_arg size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_TEE_IOCTL_CLOSE_SESSION_ARG_SESSION */
+#endif /* HAVE_STRUCT_TEE_IOCTL_CLOSE_SESSION_ARG */
+
+#ifdef HAVE_STRUCT_TEE_IOCTL_SHM_ALLOC_DATA
+# ifdef HAVE_STRUCT_TEE_IOCTL_SHM_ALLOC_DATA_ID
+static_assert(sizeof(struct tee_ioctl_shm_alloc_data) == sizeof(struct_tee_ioctl_shm_alloc_data),
+      "struct tee_ioctl_shm_alloc_data size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct tee_ioctl_shm_alloc_data) <= offsetof(struct_tee_ioctl_shm_alloc_data, id),
+"struct tee_ioctl_shm_alloc_data size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_TEE_IOCTL_SHM_ALLOC_DATA_ID */
+#endif /* HAVE_STRUCT_TEE_IOCTL_SHM_ALLOC_DATA */
+
+#ifdef HAVE_STRUCT_TEE_IOCTL_SHM_REGISTER_DATA
+# ifdef HAVE_STRUCT_TEE_IOCTL_SHM_REGISTER_DATA_ID
+static_assert(sizeof(struct tee_ioctl_shm_register_data) == sizeof(struct_tee_ioctl_shm_register_data),
+      "struct tee_ioctl_shm_register_data size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct tee_ioctl_shm_register_data) <= offsetof(struct_tee_ioctl_shm_register_data, id),
+"struct tee_ioctl_shm_register_data size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_TEE_IOCTL_SHM_REGISTER_DATA_ID */
+#endif /* HAVE_STRUCT_TEE_IOCTL_SHM_REGISTER_DATA */
+
+#ifdef HAVE_STRUCT_TEE_IOCTL_VERSION_DATA
+# ifdef HAVE_STRUCT_TEE_IOCTL_VERSION_DATA_GEN_CAPS
+static_assert(sizeof(struct tee_ioctl_version_data) == sizeof(struct_tee_ioctl_version_data),
+      "struct tee_ioctl_version_data size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct tee_ioctl_version_data) <= offsetof(struct_tee_ioctl_version_data, gen_caps),
+"struct tee_ioctl_version_data size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_TEE_IOCTL_VERSION_DATA_GEN_CAPS */
+#endif /* HAVE_STRUCT_TEE_IOCTL_VERSION_DATA */
+
+#ifdef HAVE_STRUCT_TEE_IOCTL_PARAM
+# ifdef HAVE_STRUCT_TEE_IOCTL_PARAM_C
+static_assert(sizeof(struct tee_ioctl_param) == sizeof(struct_tee_ioctl_param),
+      "struct tee_ioctl_param size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct tee_ioctl_param) <= offsetof(struct_tee_ioctl_param, c),
+"struct tee_ioctl_param size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_TEE_IOCTL_PARAM_C */
+#endif /* HAVE_STRUCT_TEE_IOCTL_PARAM */
+
+#ifdef HAVE_STRUCT_TEE_IOCTL_INVOKE_ARG
+# ifdef HAVE_STRUCT_TEE_IOCTL_INVOKE_ARG_PARAMS
+static_assert(sizeof(struct tee_ioctl_invoke_arg) == sizeof(struct_tee_ioctl_invoke_arg),
+      "struct tee_ioctl_invoke_arg size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct tee_ioctl_invoke_arg) <= offsetof(struct_tee_ioctl_invoke_arg, params),
+"struct tee_ioctl_invoke_arg size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_TEE_IOCTL_INVOKE_ARG_PARAMS */
+#endif /* HAVE_STRUCT_TEE_IOCTL_INVOKE_ARG */
+
+#ifdef HAVE_STRUCT_TEE_IOCL_SUPP_RECV_ARG
+# ifdef HAVE_STRUCT_TEE_IOCL_SUPP_RECV_ARG_PARAMS
+static_assert(sizeof(struct tee_iocl_supp_recv_arg) == sizeof(struct_tee_iocl_supp_recv_arg),
+      "struct tee_iocl_supp_recv_arg size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct tee_iocl_supp_recv_arg) <= offsetof(struct_tee_iocl_supp_recv_arg, params),
+"struct tee_iocl_supp_recv_arg size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_TEE_IOCL_SUPP_RECV_ARG_PARAMS */
+#endif /* HAVE_STRUCT_TEE_IOCL_SUPP_RECV_ARG */
+
+#ifdef HAVE_STRUCT_TEE_IOCL_SUPP_SEND_ARG
+# ifdef HAVE_STRUCT_TEE_IOCL_SUPP_SEND_ARG_PARAMS
+static_assert(sizeof(struct tee_iocl_supp_send_arg) == sizeof(struct_tee_iocl_supp_send_arg),
+      "struct tee_iocl_supp_send_arg size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct tee_iocl_supp_send_arg) <= offsetof(struct_tee_iocl_supp_send_arg, params),
+"struct tee_iocl_supp_send_arg size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_TEE_IOCL_SUPP_SEND_ARG_PARAMS */
+#endif /* HAVE_STRUCT_TEE_IOCL_SUPP_SEND_ARG */
+
+#ifdef HAVE_STRUCT_TEE_IOCTL_OPEN_SESSION_ARG
+# ifdef HAVE_STRUCT_TEE_IOCTL_OPEN_SESSION_ARG_PARAMS
+static_assert(sizeof(struct tee_ioctl_open_session_arg) == sizeof(struct_tee_ioctl_open_session_arg),
+      "struct tee_ioctl_open_session_arg size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct tee_ioctl_open_session_arg) <= offsetof(struct_tee_ioctl_open_session_arg, params),
+"struct tee_ioctl_open_session_arg size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_TEE_IOCTL_OPEN_SESSION_ARG_PARAMS */
+#endif /* HAVE_STRUCT_TEE_IOCTL_OPEN_SESSION_ARG */
diff -pruN 5.5-3/types/check-tee.m4 5.9-0ubuntu2/types/check-tee.m4
--- 5.5-3/types/check-tee.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/types/check-tee.m4	2020-09-24 09:18:43.000000000 +0000
@@ -0,0 +1,82 @@
+dnl Generated by ./types/gen.sh from ./types/tee.h; do not edit.
+AC_DEFUN([st_CHECK_TYPES_TEE],[
+AC_CHECK_HEADERS([linux/tee.h],[
+
+AC_CHECK_TYPES([struct tee_ioctl_buf_data],
+[AC_CHECK_MEMBERS([struct tee_ioctl_buf_data.buf_len],,,[AC_INCLUDES_DEFAULT
+#include <linux/ioctl.h>
+#include <linux/tee.h>])],,[AC_INCLUDES_DEFAULT
+#include <linux/ioctl.h>
+#include <linux/tee.h>])
+
+AC_CHECK_TYPES([struct tee_ioctl_cancel_arg],
+[AC_CHECK_MEMBERS([struct tee_ioctl_cancel_arg.session],,,[AC_INCLUDES_DEFAULT
+#include <linux/ioctl.h>
+#include <linux/tee.h>])],,[AC_INCLUDES_DEFAULT
+#include <linux/ioctl.h>
+#include <linux/tee.h>])
+
+AC_CHECK_TYPES([struct tee_ioctl_close_session_arg],
+[AC_CHECK_MEMBERS([struct tee_ioctl_close_session_arg.session],,,[AC_INCLUDES_DEFAULT
+#include <linux/ioctl.h>
+#include <linux/tee.h>])],,[AC_INCLUDES_DEFAULT
+#include <linux/ioctl.h>
+#include <linux/tee.h>])
+
+AC_CHECK_TYPES([struct tee_ioctl_shm_alloc_data],
+[AC_CHECK_MEMBERS([struct tee_ioctl_shm_alloc_data.id],,,[AC_INCLUDES_DEFAULT
+#include <linux/ioctl.h>
+#include <linux/tee.h>])],,[AC_INCLUDES_DEFAULT
+#include <linux/ioctl.h>
+#include <linux/tee.h>])
+
+AC_CHECK_TYPES([struct tee_ioctl_shm_register_data],
+[AC_CHECK_MEMBERS([struct tee_ioctl_shm_register_data.id],,,[AC_INCLUDES_DEFAULT
+#include <linux/ioctl.h>
+#include <linux/tee.h>])],,[AC_INCLUDES_DEFAULT
+#include <linux/ioctl.h>
+#include <linux/tee.h>])
+
+AC_CHECK_TYPES([struct tee_ioctl_version_data],
+[AC_CHECK_MEMBERS([struct tee_ioctl_version_data.gen_caps],,,[AC_INCLUDES_DEFAULT
+#include <linux/ioctl.h>
+#include <linux/tee.h>])],,[AC_INCLUDES_DEFAULT
+#include <linux/ioctl.h>
+#include <linux/tee.h>])
+
+AC_CHECK_TYPES([struct tee_ioctl_param],
+[AC_CHECK_MEMBERS([struct tee_ioctl_param.c],,,[AC_INCLUDES_DEFAULT
+#include <linux/ioctl.h>
+#include <linux/tee.h>])],,[AC_INCLUDES_DEFAULT
+#include <linux/ioctl.h>
+#include <linux/tee.h>])
+
+AC_CHECK_TYPES([struct tee_ioctl_invoke_arg],
+[AC_CHECK_MEMBERS([struct tee_ioctl_invoke_arg.params],,,[AC_INCLUDES_DEFAULT
+#include <linux/ioctl.h>
+#include <linux/tee.h>])],,[AC_INCLUDES_DEFAULT
+#include <linux/ioctl.h>
+#include <linux/tee.h>])
+
+AC_CHECK_TYPES([struct tee_iocl_supp_recv_arg],
+[AC_CHECK_MEMBERS([struct tee_iocl_supp_recv_arg.params],,,[AC_INCLUDES_DEFAULT
+#include <linux/ioctl.h>
+#include <linux/tee.h>])],,[AC_INCLUDES_DEFAULT
+#include <linux/ioctl.h>
+#include <linux/tee.h>])
+
+AC_CHECK_TYPES([struct tee_iocl_supp_send_arg],
+[AC_CHECK_MEMBERS([struct tee_iocl_supp_send_arg.params],,,[AC_INCLUDES_DEFAULT
+#include <linux/ioctl.h>
+#include <linux/tee.h>])],,[AC_INCLUDES_DEFAULT
+#include <linux/ioctl.h>
+#include <linux/tee.h>])
+
+AC_CHECK_TYPES([struct tee_ioctl_open_session_arg],
+[AC_CHECK_MEMBERS([struct tee_ioctl_open_session_arg.params],,,[AC_INCLUDES_DEFAULT
+#include <linux/ioctl.h>
+#include <linux/tee.h>])],,[AC_INCLUDES_DEFAULT
+#include <linux/ioctl.h>
+#include <linux/tee.h>])
+],[],[AC_INCLUDES_DEFAULT
+#include <linux/ioctl.h>])])
diff -pruN 5.5-3/types/check-v4l2.c 5.9-0ubuntu2/types/check-v4l2.c
--- 5.5-3/types/check-v4l2.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/types/check-v4l2.c	2020-09-24 09:18:43.000000000 +0000
@@ -0,0 +1,174 @@
+/* Generated by ./types/gen.sh from ./types/v4l2.h; do not edit. */
+#include "defs.h"
+#include "static_assert.h"
+#include "types/v4l2.h"
+
+#ifdef HAVE_STRUCT_V4L2_CAPABILITY
+# ifdef HAVE_STRUCT_V4L2_CAPABILITY_RESERVED
+static_assert(sizeof(struct v4l2_capability) == sizeof(struct_v4l2_capability),
+      "struct v4l2_capability size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct v4l2_capability) <= offsetof(struct_v4l2_capability, reserved),
+"struct v4l2_capability size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_V4L2_CAPABILITY_RESERVED */
+#endif /* HAVE_STRUCT_V4L2_CAPABILITY */
+
+#ifdef HAVE_STRUCT_V4L2_PIX_FORMAT
+# ifdef HAVE_STRUCT_V4L2_PIX_FORMAT_XFER_FUNC
+static_assert(sizeof(struct v4l2_pix_format) == sizeof(struct_v4l2_pix_format),
+      "struct v4l2_pix_format size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct v4l2_pix_format) <= offsetof(struct_v4l2_pix_format, xfer_func),
+"struct v4l2_pix_format size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_V4L2_PIX_FORMAT_XFER_FUNC */
+#endif /* HAVE_STRUCT_V4L2_PIX_FORMAT */
+
+#ifdef HAVE_STRUCT_V4L2_PLANE_PIX_FORMAT
+# ifdef HAVE_STRUCT_V4L2_PLANE_PIX_FORMAT_RESERVED
+static_assert(sizeof(struct v4l2_plane_pix_format) == sizeof(struct_v4l2_plane_pix_format),
+      "struct v4l2_plane_pix_format size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct v4l2_plane_pix_format) <= offsetof(struct_v4l2_plane_pix_format, reserved),
+"struct v4l2_plane_pix_format size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_V4L2_PLANE_PIX_FORMAT_RESERVED */
+#endif /* HAVE_STRUCT_V4L2_PLANE_PIX_FORMAT */
+
+#ifdef HAVE_STRUCT_V4L2_CLIP
+# ifdef HAVE_STRUCT_V4L2_CLIP_NEXT
+static_assert(sizeof(struct v4l2_clip) == sizeof(struct_v4l2_clip),
+      "struct v4l2_clip size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct v4l2_clip) <= offsetof(struct_v4l2_clip, next),
+"struct v4l2_clip size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_V4L2_CLIP_NEXT */
+#endif /* HAVE_STRUCT_V4L2_CLIP */
+
+#ifdef HAVE_STRUCT_V4L2_WINDOW
+# ifdef HAVE_STRUCT_V4L2_WINDOW_GLOBAL_ALPHA
+static_assert(sizeof(struct v4l2_window) == sizeof(struct_v4l2_window),
+      "struct v4l2_window size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct v4l2_window) <= offsetof(struct_v4l2_window, global_alpha),
+"struct v4l2_window size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_V4L2_WINDOW_GLOBAL_ALPHA */
+#endif /* HAVE_STRUCT_V4L2_WINDOW */
+
+#ifdef HAVE_STRUCT_V4L2_VBI_FORMAT
+# ifdef HAVE_STRUCT_V4L2_VBI_FORMAT_RESERVED
+static_assert(sizeof(struct v4l2_vbi_format) == sizeof(struct_v4l2_vbi_format),
+      "struct v4l2_vbi_format size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct v4l2_vbi_format) <= offsetof(struct_v4l2_vbi_format, reserved),
+"struct v4l2_vbi_format size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_V4L2_VBI_FORMAT_RESERVED */
+#endif /* HAVE_STRUCT_V4L2_VBI_FORMAT */
+
+#ifdef HAVE_STRUCT_V4L2_SLICED_VBI_FORMAT
+# ifdef HAVE_STRUCT_V4L2_SLICED_VBI_FORMAT_RESERVED
+static_assert(sizeof(struct v4l2_sliced_vbi_format) == sizeof(struct_v4l2_sliced_vbi_format),
+      "struct v4l2_sliced_vbi_format size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct v4l2_sliced_vbi_format) <= offsetof(struct_v4l2_sliced_vbi_format, reserved),
+"struct v4l2_sliced_vbi_format size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_V4L2_SLICED_VBI_FORMAT_RESERVED */
+#endif /* HAVE_STRUCT_V4L2_SLICED_VBI_FORMAT */
+
+#ifdef HAVE_STRUCT_V4L2_SLICED_VBI_CAP
+# ifdef HAVE_STRUCT_V4L2_SLICED_VBI_CAP_RESERVED
+static_assert(sizeof(struct v4l2_sliced_vbi_cap) == sizeof(struct_v4l2_sliced_vbi_cap),
+      "struct v4l2_sliced_vbi_cap size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct v4l2_sliced_vbi_cap) <= offsetof(struct_v4l2_sliced_vbi_cap, reserved),
+"struct v4l2_sliced_vbi_cap size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_V4L2_SLICED_VBI_CAP_RESERVED */
+#endif /* HAVE_STRUCT_V4L2_SLICED_VBI_CAP */
+
+#ifdef HAVE_STRUCT_V4L2_FORMAT
+# ifdef HAVE_STRUCT_V4L2_FORMAT_FMT
+static_assert(sizeof(struct v4l2_format) == sizeof(struct_v4l2_format),
+      "struct v4l2_format size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct v4l2_format) <= offsetof(struct_v4l2_format, fmt),
+"struct v4l2_format size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_V4L2_FORMAT_FMT */
+#endif /* HAVE_STRUCT_V4L2_FORMAT */
+
+#ifdef HAVE_STRUCT_V4L2_AREA
+# ifdef HAVE_STRUCT_V4L2_AREA_HEIGHT
+static_assert(sizeof(struct v4l2_area) == sizeof(struct_v4l2_area),
+      "struct v4l2_area size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct v4l2_area) <= offsetof(struct_v4l2_area, height),
+"struct v4l2_area size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_V4L2_AREA_HEIGHT */
+#endif /* HAVE_STRUCT_V4L2_AREA */
+
+#ifdef HAVE_STRUCT_V4L2_EXT_CONTROLS
+# ifdef HAVE_STRUCT_V4L2_EXT_CONTROLS_CONTROLS
+static_assert(sizeof(struct v4l2_ext_controls) == sizeof(struct_v4l2_ext_controls),
+      "struct v4l2_ext_controls size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct v4l2_ext_controls) <= offsetof(struct_v4l2_ext_controls, controls),
+"struct v4l2_ext_controls size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_V4L2_EXT_CONTROLS_CONTROLS */
+#endif /* HAVE_STRUCT_V4L2_EXT_CONTROLS */
+
+#ifdef HAVE_STRUCT_V4L2_FRMSIZE_DISCRETE
+# ifdef HAVE_STRUCT_V4L2_FRMSIZE_DISCRETE_HEIGHT
+static_assert(sizeof(struct v4l2_frmsize_discrete) == sizeof(struct_v4l2_frmsize_discrete),
+      "struct v4l2_frmsize_discrete size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct v4l2_frmsize_discrete) <= offsetof(struct_v4l2_frmsize_discrete, height),
+"struct v4l2_frmsize_discrete size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_V4L2_FRMSIZE_DISCRETE_HEIGHT */
+#endif /* HAVE_STRUCT_V4L2_FRMSIZE_DISCRETE */
+
+#ifdef HAVE_STRUCT_V4L2_FRMSIZE_STEPWISE
+# ifdef HAVE_STRUCT_V4L2_FRMSIZE_STEPWISE_STEP_HEIGHT
+static_assert(sizeof(struct v4l2_frmsize_stepwise) == sizeof(struct_v4l2_frmsize_stepwise),
+      "struct v4l2_frmsize_stepwise size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct v4l2_frmsize_stepwise) <= offsetof(struct_v4l2_frmsize_stepwise, step_height),
+"struct v4l2_frmsize_stepwise size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_V4L2_FRMSIZE_STEPWISE_STEP_HEIGHT */
+#endif /* HAVE_STRUCT_V4L2_FRMSIZE_STEPWISE */
+
+#ifdef HAVE_STRUCT_V4L2_FRMSIZEENUM
+# ifdef HAVE_STRUCT_V4L2_FRMSIZEENUM_RESERVED
+static_assert(sizeof(struct v4l2_frmsizeenum) == sizeof(struct_v4l2_frmsizeenum),
+      "struct v4l2_frmsizeenum size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct v4l2_frmsizeenum) <= offsetof(struct_v4l2_frmsizeenum, reserved),
+"struct v4l2_frmsizeenum size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_V4L2_FRMSIZEENUM_RESERVED */
+#endif /* HAVE_STRUCT_V4L2_FRMSIZEENUM */
+
+#ifdef HAVE_STRUCT_V4L2_FRMIVAL_STEPWISE
+# ifdef HAVE_STRUCT_V4L2_FRMIVAL_STEPWISE_STEP
+static_assert(sizeof(struct v4l2_frmival_stepwise) == sizeof(struct_v4l2_frmival_stepwise),
+      "struct v4l2_frmival_stepwise size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct v4l2_frmival_stepwise) <= offsetof(struct_v4l2_frmival_stepwise, step),
+"struct v4l2_frmival_stepwise size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_V4L2_FRMIVAL_STEPWISE_STEP */
+#endif /* HAVE_STRUCT_V4L2_FRMIVAL_STEPWISE */
+
+#ifdef HAVE_STRUCT_V4L2_FRMIVALENUM
+# ifdef HAVE_STRUCT_V4L2_FRMIVALENUM_RESERVED
+static_assert(sizeof(struct v4l2_frmivalenum) == sizeof(struct_v4l2_frmivalenum),
+      "struct v4l2_frmivalenum size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct v4l2_frmivalenum) <= offsetof(struct_v4l2_frmivalenum, reserved),
+"struct v4l2_frmivalenum size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_V4L2_FRMIVALENUM_RESERVED */
+#endif /* HAVE_STRUCT_V4L2_FRMIVALENUM */
+
+#ifdef HAVE_STRUCT_V4L2_CREATE_BUFFERS
+# ifdef HAVE_STRUCT_V4L2_CREATE_BUFFERS_RESERVED
+static_assert(sizeof(struct v4l2_create_buffers) == sizeof(struct_v4l2_create_buffers),
+      "struct v4l2_create_buffers size mismatch, please update the decoder or fix the kernel");
+# else
+static_assert(sizeof(struct v4l2_create_buffers) <= offsetof(struct_v4l2_create_buffers, reserved),
+"struct v4l2_create_buffers size mismatch, please update the decoder or fix the kernel");
+# endif /* HAVE_STRUCT_V4L2_CREATE_BUFFERS_RESERVED */
+#endif /* HAVE_STRUCT_V4L2_CREATE_BUFFERS */
diff -pruN 5.5-3/types/check-v4l2.m4 5.9-0ubuntu2/types/check-v4l2.m4
--- 5.5-3/types/check-v4l2.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/types/check-v4l2.m4	2020-09-24 09:18:43.000000000 +0000
@@ -0,0 +1,194 @@
+dnl Generated by ./types/gen.sh from ./types/v4l2.h; do not edit.
+AC_DEFUN([st_CHECK_TYPES_V4L2],[
+AC_CHECK_HEADERS([linux/videodev2.h],[
+
+AC_CHECK_TYPES([struct v4l2_capability],
+[AC_CHECK_MEMBERS([struct v4l2_capability.reserved],,,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])],,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])
+
+AC_CHECK_TYPES([struct v4l2_pix_format],
+[AC_CHECK_MEMBERS([struct v4l2_pix_format.xfer_func],,,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])],,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])
+
+AC_CHECK_TYPES([struct v4l2_plane_pix_format],
+[AC_CHECK_MEMBERS([struct v4l2_plane_pix_format.reserved],,,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])],,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])
+
+AC_CHECK_TYPES([struct v4l2_clip],
+[AC_CHECK_MEMBERS([struct v4l2_clip.next],,,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])],,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])
+
+AC_CHECK_TYPES([struct v4l2_window],
+[AC_CHECK_MEMBERS([struct v4l2_window.global_alpha],,,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])],,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])
+
+AC_CHECK_TYPES([struct v4l2_vbi_format],
+[AC_CHECK_MEMBERS([struct v4l2_vbi_format.reserved],,,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])],,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])
+
+AC_CHECK_TYPES([struct v4l2_sliced_vbi_format],
+[AC_CHECK_MEMBERS([struct v4l2_sliced_vbi_format.reserved],,,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])],,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])
+
+AC_CHECK_TYPES([struct v4l2_sliced_vbi_cap],
+[AC_CHECK_MEMBERS([struct v4l2_sliced_vbi_cap.reserved],,,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])],,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])
+
+AC_CHECK_TYPES([struct v4l2_format],
+[AC_CHECK_MEMBERS([struct v4l2_format.fmt],,,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])],,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])
+
+AC_CHECK_TYPES([struct v4l2_area],
+[AC_CHECK_MEMBERS([struct v4l2_area.height],,,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])],,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])
+
+AC_CHECK_TYPES([struct v4l2_ext_controls],
+[AC_CHECK_MEMBERS([struct v4l2_ext_controls.controls],,,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])],,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])
+
+AC_CHECK_TYPES([struct v4l2_frmsize_discrete],
+[AC_CHECK_MEMBERS([struct v4l2_frmsize_discrete.height],,,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])],,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])
+
+AC_CHECK_TYPES([struct v4l2_frmsize_stepwise],
+[AC_CHECK_MEMBERS([struct v4l2_frmsize_stepwise.step_height],,,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])],,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])
+
+AC_CHECK_TYPES([struct v4l2_frmsizeenum],
+[AC_CHECK_MEMBERS([struct v4l2_frmsizeenum.reserved],,,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])],,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])
+
+AC_CHECK_TYPES([struct v4l2_frmival_stepwise],
+[AC_CHECK_MEMBERS([struct v4l2_frmival_stepwise.step],,,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])],,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])
+
+AC_CHECK_TYPES([struct v4l2_frmivalenum],
+[AC_CHECK_MEMBERS([struct v4l2_frmivalenum.reserved],,,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])],,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])
+
+AC_CHECK_TYPES([struct v4l2_create_buffers],
+[AC_CHECK_MEMBERS([struct v4l2_create_buffers.reserved],,,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])],,[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>])
+],[],[AC_INCLUDES_DEFAULT
+#include <stdint.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>])])
diff -pruN 5.5-3/types/evdev.h 5.9-0ubuntu2/types/evdev.h
--- 5.5-3/types/evdev.h	2020-01-21 18:02:38.000000000 +0000
+++ 5.9-0ubuntu2/types/evdev.h	2020-04-03 22:58:26.000000000 +0000
@@ -8,9 +8,9 @@
 #ifndef STRACE_TYPES_EVDEV_H
 # define STRACE_TYPES_EVDEV_H
 
-#ifdef HAVE_LINUX_INPUT_H
-# include <linux/input.h>
-#endif
+# ifdef HAVE_LINUX_INPUT_H
+#  include <linux/input.h>
+# endif
 
 typedef struct {
 	int32_t value;
diff -pruN 5.5-3/types/find_last_type_fields.awk 5.9-0ubuntu2/types/find_last_type_fields.awk
--- 5.5-3/types/find_last_type_fields.awk	2020-01-21 18:02:38.000000000 +0000
+++ 5.9-0ubuntu2/types/find_last_type_fields.awk	2020-06-16 08:00:00.000000000 +0000
@@ -17,7 +17,7 @@
 		print a[1] "." last_field
 		next
 	}
-	if (match($0, /^[[:space:]]+[^];:[]+[[:space:]]+([^][:space:];:[]+)(\[[^];:[]*\])?;.*$/, a)) {
+	if (match($0, /^[[:space:]]+[^];[:space:]:\/[][^];:[]*[[:space:]]+([^][:space:];:[]+)(\[[^];:[]*\])?;.*$/, a)) {
 		last_field = a[1]
 		next
 	}
diff -pruN 5.5-3/types/gen.sh 5.9-0ubuntu2/types/gen.sh
--- 5.5-3/types/gen.sh	2020-01-21 18:02:38.000000000 +0000
+++ 5.9-0ubuntu2/types/gen.sh	2020-04-18 01:23:45.000000000 +0000
@@ -88,10 +88,11 @@ gen_m4_check()
 		return 1
 	}
 
-	local inc_expr1 inc_expr2 includes
+	local inc_expr1 inc_expr2 includes header_includes
 	inc_expr1='s/^#[[:space:]]*include[[:space:]]\+\(<[^>]\+>\).*/#include \1/p'
 	inc_expr2='s/^#[[:space:]]*include[[:space:]]\+"\([^"]\+\)".*/#include "\$srcdir\/\1"/p'
 	includes="$(sed -n "$inc_expr1; $inc_expr2" "$input")"
+	header_includes="$(printf %s "$includes" |sed '$d')"
 
 	echo "generating $output"
 	{
@@ -112,7 +113,10 @@ gen_m4_check()
 				$includes])
 			EOF
 		done
-		echo '])])'
+		cat <<-EOF
+			],[],[AC_INCLUDES_DEFAULT
+			$header_includes])])
+		EOF
 	} > "$output"
 }
 
@@ -154,10 +158,6 @@ gen_makefile()
 		[ $# -eq 0 ] ||
 			printf 'types/check-%s.c ' "$@"
 		echo
-		printf 'TYPES_M4_FILES = '
-		[ $# -eq 0 ] ||
-			printf 'types/check-%s.m4 ' "$@"
-		echo
 	} >"$output"
 }
 
diff -pruN 5.5-3/types/io_uring.h 5.9-0ubuntu2/types/io_uring.h
--- 5.5-3/types/io_uring.h	2020-02-03 01:15:25.000000000 +0000
+++ 5.9-0ubuntu2/types/io_uring.h	2020-06-16 08:00:00.000000000 +0000
@@ -8,9 +8,9 @@
 #ifndef STRACE_TYPES_IO_URING_H
 # define STRACE_TYPES_IO_URING_H
 
-#ifdef HAVE_LINUX_IO_URING_H
-# include <linux/io_uring.h>
-#endif
+# ifdef HAVE_LINUX_IO_URING_H
+#  include <linux/io_uring.h>
+# endif
 
 typedef struct {
 	uint32_t head;
@@ -31,7 +31,9 @@ typedef struct {
 	uint32_t ring_entries;
 	uint32_t overflow;
 	uint32_t cqes;
-	uint64_t resv[2];
+	/** Added by v5.8-rc1~190^2~22 */	uint32_t flags;
+	/** Added by v5.8-rc1~190^2~22 */	uint32_t resv1;
+	/** Added by v5.8-rc1~190^2~22 */	uint64_t resv2;
 } struct_io_cqring_offsets;
 
 typedef struct {
@@ -53,4 +55,19 @@ typedef struct {
 	uint64_t /* int * */ fds;
 } struct_io_uring_files_update;
 
+typedef struct {
+	uint8_t  op;
+	uint8_t  resv;
+	uint16_t flags;    /* IO_URING_OP_* flags */
+	uint32_t resv2;
+} struct_io_uring_probe_op;
+
+typedef struct {
+	uint8_t  last_op;   /* last opcode supported */
+	uint8_t  ops_len;   /* length of ops[] array below */
+	uint16_t resv;
+	uint32_t resv2[3];
+	struct_io_uring_probe_op ops[0];
+} struct_io_uring_probe;
+
 #endif /* !STRACE_TYPES_IO_URING_H */
diff -pruN 5.5-3/types/loop.h 5.9-0ubuntu2/types/loop.h
--- 5.5-3/types/loop.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/types/loop.h	2020-07-08 08:00:00.000000000 +0000
@@ -0,0 +1,21 @@
+/*
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
+#ifndef STRACE_TYPES_LOOP_H
+# define STRACE_TYPES_LOOP_H
+
+# include <linux/ioctl.h>
+# include <linux/loop.h>
+
+typedef struct {
+	uint32_t fd;
+	uint32_t block_size;
+	struct loop_info64 info;
+	uint64_t __reserved[8];
+} struct_loop_config;
+
+#endif /* STRACE_TYPES_LOOP_H */
diff -pruN 5.5-3/types/Makemodule.am 5.9-0ubuntu2/types/Makemodule.am
--- 5.5-3/types/Makemodule.am	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/types/Makemodule.am	2020-09-24 09:18:43.000000000 +0000
@@ -1,3 +1,2 @@
-TYPES_HEADER_FILES = types/cryptouser.h types/evdev.h types/io_uring.h types/rtnl_link.h types/rtnl_mdb.h types/rtnl_neightbl.h types/rtnl_route.h 
-TYPES_CHECK_FILES = types/check-cryptouser.c types/check-evdev.c types/check-io_uring.c types/check-rtnl_link.c types/check-rtnl_mdb.c types/check-rtnl_neightbl.c types/check-rtnl_route.c 
-TYPES_M4_FILES = types/check-cryptouser.m4 types/check-evdev.m4 types/check-io_uring.m4 types/check-rtnl_link.m4 types/check-rtnl_mdb.m4 types/check-rtnl_neightbl.m4 types/check-rtnl_route.m4 
+TYPES_HEADER_FILES = types/btrfs.h types/cryptouser.h types/evdev.h types/io_uring.h types/loop.h types/openat2.h types/rtnl_link.h types/rtnl_mdb.h types/rtnl_neightbl.h types/rtnl_route.h types/tee.h types/v4l2.h 
+TYPES_CHECK_FILES = types/check-btrfs.c types/check-cryptouser.c types/check-evdev.c types/check-io_uring.c types/check-loop.c types/check-openat2.c types/check-rtnl_link.c types/check-rtnl_mdb.c types/check-rtnl_neightbl.c types/check-rtnl_route.c types/check-tee.c types/check-v4l2.c 
diff -pruN 5.5-3/types/openat2.h 5.9-0ubuntu2/types/openat2.h
--- 5.5-3/types/openat2.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/types/openat2.h	2020-04-03 22:58:26.000000000 +0000
@@ -0,0 +1,21 @@
+/*
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
+#ifndef STRACE_TYPES_OPENAT2_H
+# define STRACE_TYPES_OPENAT2_H
+
+# ifdef HAVE_LINUX_OPENAT2_H
+#  include <linux/openat2.h>
+# endif
+
+typedef struct {
+	uint64_t flags;
+	uint64_t mode;
+	uint64_t resolve;
+} struct_open_how;
+
+#endif /* STRACE_TYPES_OPENAT2_H */
diff -pruN 5.5-3/types/st_check_types.m4 5.9-0ubuntu2/types/st_check_types.m4
--- 5.5-3/types/st_check_types.m4	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/types/st_check_types.m4	2020-09-24 09:18:43.000000000 +0000
@@ -1,9 +1,14 @@
 AC_DEFUN([st_CHECK_TYPES],[
+	st_CHECK_TYPES_BTRFS
 	st_CHECK_TYPES_CRYPTOUSER
 	st_CHECK_TYPES_EVDEV
 	st_CHECK_TYPES_IO_URING
+	st_CHECK_TYPES_LOOP
+	st_CHECK_TYPES_OPENAT2
 	st_CHECK_TYPES_RTNL_LINK
 	st_CHECK_TYPES_RTNL_MDB
 	st_CHECK_TYPES_RTNL_NEIGHTBL
 	st_CHECK_TYPES_RTNL_ROUTE
+	st_CHECK_TYPES_TEE
+	st_CHECK_TYPES_V4L2
 ])
diff -pruN 5.5-3/types/tee.h 5.9-0ubuntu2/types/tee.h
--- 5.5-3/types/tee.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/types/tee.h	2020-09-23 16:29:35.000000000 +0000
@@ -0,0 +1,107 @@
+/*
+ * Copyright (c) 2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
+#ifndef STRACE_TYPES_TEE_H
+# define STRACE_TYPES_TEE_H
+
+# include <linux/ioctl.h>
+
+# ifdef HAVE_LINUX_TEE_H
+#  include <linux/tee.h>
+# else
+#  define TEE_IOCTL_UUID_LEN 16
+# endif
+
+typedef struct {
+	uint64_t buf_ptr;
+	uint64_t buf_len;
+} struct_tee_ioctl_buf_data;
+
+typedef struct {
+	uint32_t cancel_id;
+	uint32_t session;
+} struct_tee_ioctl_cancel_arg;
+
+typedef struct {
+	uint32_t session;
+} struct_tee_ioctl_close_session_arg;
+
+typedef struct {
+	uint64_t size;
+	uint32_t flags;
+	int32_t id;
+} struct_tee_ioctl_shm_alloc_data;
+
+/* Not in mainline */
+typedef struct {
+	int64_t fd;
+	uint64_t size;
+	uint32_t flags;
+	uint8_t _pad1[4];
+	int32_t id;
+	uint8_t _pad2[4];
+} ATTRIBUTE_ALIGNED(8) struct_tee_ioctl_shm_register_fd_data;
+
+typedef struct {
+	uint64_t addr;
+	uint64_t length;
+	uint32_t flags;
+	int32_t id;
+} struct_tee_ioctl_shm_register_data;
+
+typedef struct {
+	uint32_t impl_id;
+	uint32_t impl_caps;
+	uint32_t gen_caps;
+} struct_tee_ioctl_version_data;
+
+typedef struct {
+	uint64_t attr;
+	uint64_t a;
+	uint64_t b;
+	uint64_t c;
+} struct_tee_ioctl_param;
+
+typedef struct {
+	uint32_t func;
+	uint32_t session;
+	uint32_t cancel_id;
+	uint32_t ret;
+	uint32_t ret_origin;
+	uint32_t num_params;
+	/* num_params tells the actual number of element in params */
+	struct_tee_ioctl_param params[];
+} struct_tee_ioctl_invoke_arg;
+
+typedef struct {
+	uint32_t func;
+	uint32_t num_params;
+	/* num_params tells the actual number of element in params */
+	struct_tee_ioctl_param params[];
+} struct_tee_iocl_supp_recv_arg;
+
+typedef struct {
+	uint32_t ret;
+	uint32_t num_params;
+	/* num_params tells the actual number of element in params */
+	struct_tee_ioctl_param params[];
+} struct_tee_iocl_supp_send_arg;
+
+typedef struct {
+	uint8_t uuid[TEE_IOCTL_UUID_LEN];
+	uint8_t clnt_uuid[TEE_IOCTL_UUID_LEN];
+	uint32_t clnt_login;
+	uint32_t cancel_id;
+	uint32_t session;
+	uint32_t ret;
+	uint32_t ret_origin;
+	uint32_t num_params;
+	/* num_params tells the actual number of element in params */
+	struct_tee_ioctl_param params[];
+} struct_tee_ioctl_open_session_arg;
+
+#endif /* STRACE_TYPES_TEE_H */
diff -pruN 5.5-3/types/v4l2.h 5.9-0ubuntu2/types/v4l2.h
--- 5.5-3/types/v4l2.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/types/v4l2.h	2020-09-06 08:00:00.000000000 +0000
@@ -0,0 +1,257 @@
+/*
+ * V4L2-related type definitions.
+ *
+ * Copyright (c) 2016-2020 The strace developers.
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
+#ifndef STRACE_TYPES_V4L2_H
+# define STRACE_TYPES_V4L2_H
+
+# include <stdint.h>
+# include <linux/ioctl.h>
+# include <linux/types.h>
+# include <linux/videodev2.h>
+
+typedef struct v4l2_framebuffer struct_v4l2_framebuffer;
+typedef struct v4l2_input struct_v4l2_input;
+typedef struct v4l2_standard struct_v4l2_standard;
+
+
+typedef struct {
+	uint8_t  driver[16];
+	uint8_t  card[32];
+	uint8_t  bus_info[32];
+	uint32_t version;
+	uint32_t capabilities;
+	uint32_t device_caps; /**< Added by v3.4-rc1~110^2^2~259 */
+	uint32_t reserved[3];
+} struct_v4l2_capability;
+
+
+typedef struct {
+	uint32_t width;
+	uint32_t height;
+	uint32_t pixelformat;
+	uint32_t field;
+	uint32_t bytesperline;
+	uint32_t sizeimage;
+	uint32_t colorspace; /**< enum v4l2_colorspace */
+	uint32_t priv;
+	/** Format flags (V4L2_PIX_FMT_FLAG_*), added by v3.17-rc1~112^2~326 */
+	uint32_t flags;
+	union {
+		/** enum v4l2_ycbcr_encoding, added by v3.19-rc1~29^2~72 */
+		uint32_t ycbcr_enc;
+		/** enum v4l2_hsv_encoding, added by v4.10-rc1~71^2^2~352 */
+		uint32_t hsv_enc;
+	};
+	/** enum v4l2_quantization, added by v3.19-rc1~29^2~72 */
+	uint32_t quantization;
+	/** enum v4l2_xfer_func, added by Linux commit v4.2-rc1~107^2~136 */
+	uint32_t xfer_func;
+} struct_v4l2_pix_format;
+
+/** Added by Linux commit v2.6.39-rc1~86^2~437 */
+typedef struct {
+	uint32_t sizeimage;
+	uint32_t bytesperline; /**< Type has changed in v4.1-rc1~59^2~1^2~88 */
+	uint16_t reserved[6];
+} struct_v4l2_plane_pix_format;
+
+/** Added by Linux commit v2.6.39-rc1~86^2~437 */
+typedef struct {
+	uint32_t width;
+	uint32_t height;
+	uint32_t pixelformat;
+	uint32_t field;
+	uint32_t colorspace;
+
+	struct_v4l2_plane_pix_format plane_fmt[8 /* VIDEO_MAX_PLANES */];
+	uint8_t num_planes;
+	/** Format flags (V4L2_PIX_FMT_FLAG_*), added by v3.17-rc1~112^2~326 */
+	uint8_t flags;
+	union {
+		/** enum v4l2_ycbcr_encoding, added by v3.19-rc1~29^2~72 */
+		uint8_t ycbcr_enc;
+		/** enum v4l2_hsv_encoding, added by v4.10-rc1~71^2^2~352 */
+		uint8_t hsv_enc;
+	};
+	/** enum v4l2_quantization, added by v3.19-rc1~29^2~72 */
+	uint8_t quantization;
+	/** enum v4l2_xfer_func, added by Linux commit v4.2-rc1~107^2~136 */
+	uint8_t xfer_func;
+	uint8_t reserved[7];
+} ATTRIBUTE_PACKED struct_v4l2_pix_format_mplane;
+
+typedef struct strace_v4l2_clip {
+	struct v4l2_rect c;
+	struct strace_v4l2_clip * next;
+} struct_v4l2_clip;
+
+typedef struct {
+	struct v4l2_rect w;
+	uint32_t field; /* enum v4l2_field */
+	uint32_t chromakey;
+	struct_v4l2_clip *clips;
+	uint32_t clipcount;
+	void *bitmap;
+	uint8_t global_alpha; /**< Added by v2.6.22-rc1~1118^2~179 */
+} struct_v4l2_window;
+
+typedef struct {
+	uint32_t sampling_rate;
+	uint32_t offset;
+	uint32_t samples_per_line;
+	uint32_t sample_format; /* V4L2_PIX_FMT_* */
+	int32_t  start[2];
+	uint32_t count[2];
+	uint32_t flags; /* V4L2_VBI_* */
+	uint32_t reserved[2];
+} struct_v4l2_vbi_format;
+
+/** Added by Linux commit v2.6.16.28-rc1~3732 */
+typedef struct {
+	uint16_t service_set;
+	uint16_t service_lines[2][24];
+	uint32_t io_size;
+	uint32_t reserved[2];
+} struct_v4l2_sliced_vbi_format;
+
+typedef struct {
+	uint16_t service_set;
+	uint16_t service_lines[2][24];
+	uint32_t type; /**< enum v4l2_buf_type, added by v2.6.19-rc1~643^2~52 */
+	uint32_t reserved[3];
+} struct_v4l2_sliced_vbi_cap;
+
+/** Added by Linux commits v3.15-rc1~85^2~213, v3.15-rc1~85^2~41 */
+typedef struct {
+	uint32_t pixelformat;
+	uint32_t buffersize; /**< Added by Linux commit v3.17-rc1~112^2~230 */
+	uint8_t  reserved[24];
+} ATTRIBUTE_PACKED struct_v4l2_sdr_format;
+
+/** Added by Linux commit v4.12-rc1~85^2~71 */
+typedef struct {
+	uint32_t dataformat;
+	uint32_t buffersize;
+} ATTRIBUTE_PACKED struct_v4l2_meta_format;
+
+typedef struct {
+	uint32_t type;
+	union {
+		struct_v4l2_pix_format		pix;
+		/** Added by Linux commit v2.6.39-rc1~86^2~437 */
+		struct_v4l2_pix_format_mplane	pix_mp;
+		struct_v4l2_window		win;
+		struct_v4l2_vbi_format		vbi;
+		/** Added by Linux commit v2.6.16.28-rc1~3732 */
+		struct_v4l2_sliced_vbi_format	sliced;
+		/** Added by v3.15-rc1~85^2~213, v3.15-rc1~85^2~41 */
+		struct_v4l2_sdr_format		sdr;
+		/** Added by Linux commit v4.12-rc1~85^2~71 */
+		struct_v4l2_meta_format		meta;
+		uint8_t raw_data[200];
+	} fmt;
+} struct_v4l2_format;
+
+
+/** Added by Linux v5.5-rc1~143^2^2~225 */
+typedef struct {
+	__u32   width;
+	__u32   height;
+} struct_v4l2_area;
+
+/** Added by Linux commit v2.6.18-rc1~862^2~18 */
+typedef struct {
+        uint32_t id;
+        uint32_t size; /* Added by v2.6.32-rc1~679^2~72 */
+        uint32_t reserved2[1];
+        union {
+                int32_t value;
+                int64_t value64;
+                char * string;             /**< Added by v2.6.32-rc1~679^2~72 */
+                uint8_t * p_u8;            /**< Added by v3.17-rc1~112^2~343 */
+                uint16_t * p_u16;          /**< Added by v3.17-rc1~112^2~343 */
+                uint32_t * p_u32;          /**< Added by v3.17-rc1~112^2~112 */
+                struct_v4l2_area * p_area; /**< Added by v5.5-rc1~143^2^2~51 */
+                void * ptr;                /**< Added by v3.17-rc1~112^2~363 */
+        };
+} ATTRIBUTE_PACKED struct_v4l2_ext_control;
+
+/** Added by Linux commit v2.6.18-rc1~862^2~18 */
+typedef struct {
+        union {
+		uint32_t ctrl_class;
+		uint32_t which;
+	};
+        uint32_t count;
+	uint32_t error_idx;
+	int32_t  request_fd; /**< Added by Linux commit v4.20-rc1~51^2~44 */
+	uint32_t reserved[1];
+	struct_v4l2_ext_control * controls;
+} struct_v4l2_ext_controls;
+
+
+typedef struct {
+	uint32_t width;
+	uint32_t height;
+} struct_v4l2_frmsize_discrete;
+
+typedef struct {
+	uint32_t min_width;
+	uint32_t max_width;
+	uint32_t step_width;
+	uint32_t min_height;
+	uint32_t max_height;
+	uint32_t step_height;
+} struct_v4l2_frmsize_stepwise;
+
+/** Added by Linux commit v2.6.19-rc1~183 */
+typedef struct {
+	uint32_t index;
+	uint32_t pixel_format;
+	uint32_t type; /**< enum v4l2_frmsizetypes */
+	union {
+		struct_v4l2_frmsize_discrete discrete;
+		struct_v4l2_frmsize_stepwise stepwise;
+	};
+	uint32_t reserved[2];
+} struct_v4l2_frmsizeenum;
+
+typedef struct {
+	struct v4l2_fract min;
+	struct v4l2_fract max;
+	struct v4l2_fract step;
+} struct_v4l2_frmival_stepwise;
+
+typedef struct {
+	uint32_t index;
+	uint32_t pixel_format;
+	uint32_t width;
+	uint32_t height;
+	uint32_t type; /**< enum v4l2_frmivaltypes */
+	union {
+		struct v4l2_fract		discrete;
+		struct_v4l2_frmival_stepwise	stepwise;
+	};
+	uint32_t reserved[2];
+} struct_v4l2_frmivalenum;
+
+
+typedef struct {
+	uint32_t index;
+	uint32_t count;
+	uint32_t memory;
+	struct_v4l2_format format;
+	/** V4L2_BUF_CAP_*, added by Linux commit v4.20-rc1~51^2~14 */
+	uint32_t capabilities;
+	/** V4L2_FLAG_MEMORY_NON_CONSISTENT, added by Linux commit v5.9-rc1~94^2~295 */
+	uint32_t flags;
+	uint32_t reserved[6];
+} struct_v4l2_create_buffers;
+
+#endif /* STRACE_TYPES_V4L2_H */
diff -pruN 5.5-3/ucopy.c 5.9-0ubuntu2/ucopy.c
--- 5.5-3/ucopy.c	2019-09-25 01:02:03.000000000 +0000
+++ 5.9-0ubuntu2/ucopy.c	2020-06-01 14:15:16.000000000 +0000
@@ -6,7 +6,7 @@
  * Copyright (c) 1999 IBM Deutschland Entwicklung GmbH, IBM Corporation
  *                     Linux for s390 port by D.J. Barrow
  *                    <barrow_dj@mail.yahoo.com,djbarrow@de.ibm.com>
- * Copyright (c) 1999-2019 The strace developers.
+ * Copyright (c) 1999-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -61,7 +61,7 @@ process_read_mem(const pid_t pid, void *
 }
 
 static int cached_idx = -1;
-static unsigned long cached_raddr[2];
+static unsigned long cached_raddr[4];
 
 void
 invalidate_umove_cache(void)
@@ -69,17 +69,47 @@ invalidate_umove_cache(void)
 	cached_idx = -1;
 }
 
+static int
+get_next_unused_idx(void)
+{
+	return (cached_idx + 1) % ARRAY_SIZE(cached_raddr);
+}
+
+static int
+lookup_cached_raddr_idx(const unsigned long raddr)
+{
+	if (cached_idx >= 0) {
+		for (int i = cached_idx; i >= 0; --i)
+			if (raddr == cached_raddr[i])
+				return i;
+		for (int i = (int) ARRAY_SIZE(cached_raddr) - 1;
+		     i > cached_idx; --i)
+			if (raddr == cached_raddr[i])
+				return i;
+	}
+	return -1;
+}
+
+static void
+set_cached_raddr_idx(const unsigned long raddr, const int idx)
+{
+	if (cached_idx < 0)
+		memset(cached_raddr, 0, sizeof(cached_raddr));
+	cached_raddr[idx] = raddr;
+	cached_idx = idx;
+}
+
 static ssize_t
-vm_read_mem(const pid_t pid, void *const laddr,
-	    const kernel_ulong_t raddr, const size_t len)
+vm_read_mem(const pid_t pid, void *laddr,
+	    const kernel_ulong_t kraddr, size_t len)
 {
 	if (!len)
 		return len;
 
-	const unsigned long taddr = raddr;
+	unsigned long taddr = kraddr;
 
 #if SIZEOF_LONG < SIZEOF_KERNEL_LONG_T
-	if (raddr != (kernel_ulong_t) taddr) {
+	if (kraddr != (kernel_ulong_t) taddr) {
 		errno = EIO;
 		return -1;
 	}
@@ -87,46 +117,60 @@ vm_read_mem(const pid_t pid, void *const
 
 	const size_t page_size = get_pagesize();
 	const size_t page_mask = page_size - 1;
-	const unsigned long raddr_page_start =
-		taddr & ~page_mask;
-	const unsigned long raddr_page_next =
+	unsigned long page_start = taddr & ~page_mask;
+	const unsigned long page_after_last =
 		(taddr + len + page_mask) & ~page_mask;
 
-	if (!raddr_page_start ||
-	    raddr_page_next < raddr_page_start ||
-	    raddr_page_next - raddr_page_start != page_size)
+	if (!page_start ||
+	    page_after_last < page_start ||
+	    page_after_last - page_start > ARRAY_SIZE(cached_raddr) * page_size)
 		return process_read_mem(pid, laddr, (void *) taddr, len);
 
-	int idx = -1;
-	if (cached_idx >= 0) {
-		if (raddr_page_start == cached_raddr[cached_idx])
-			idx = cached_idx;
-		else if (raddr_page_start == cached_raddr[!cached_idx])
-			idx = !cached_idx;
-	}
-
-	static char *buf[2];
-
-	if (idx == -1) {
-		idx = !cached_idx;
-
-		if (!buf[idx])
-			buf[idx] = xmalloc(page_size);
+	size_t total_read = 0;
 
-		const ssize_t rc =
-			process_read_mem(pid, buf[idx],
-					 (void *) raddr_page_start, page_size);
-		if (rc < 0)
-			return rc;
-
-		cached_raddr[idx] = raddr_page_start;
-		if (cached_idx < 0)
-			cached_raddr[!idx] = 0;
-		cached_idx = idx;
+	for (;;) {
+		static char *buf[ARRAY_SIZE(cached_raddr)];
+		int idx = lookup_cached_raddr_idx(page_start);
+
+		if (idx == -1) {
+			idx = get_next_unused_idx();
+
+			if (!buf[idx])
+				buf[idx] = xmalloc(page_size);
+
+			const ssize_t rc =
+				process_read_mem(pid, buf[idx],
+						 (void *) page_start, page_size);
+			if (rc < 0)
+				return total_read ? (ssize_t) total_read : rc;
+
+			set_cached_raddr_idx(page_start, idx);
+		}
+
+		const unsigned long offset = taddr - page_start;
+		size_t copy_len, next_len;
+
+		if (len <= page_size - offset) {
+			copy_len = len;
+			next_len = 0;
+		} else {
+			copy_len = page_size - offset;
+			next_len = len - copy_len;
+		}
+
+		memcpy(laddr, buf[idx] + offset, copy_len);
+		total_read += copy_len;
+
+		if (!next_len)
+			break;
+
+		len = next_len;
+		laddr += copy_len;
+		page_start += page_size;
+		taddr = page_start;
 	}
 
-	memcpy(laddr, buf[idx] + (taddr - cached_raddr[idx]), len);
-	return len;
+	return total_read;
 }
 
 static bool
diff -pruN 5.5-3/unwind-libdw.c 5.9-0ubuntu2/unwind-libdw.c
--- 5.5-3/unwind-libdw.c	2020-02-06 15:16:17.000000000 +0000
+++ 5.9-0ubuntu2/unwind-libdw.c	2020-04-03 17:41:29.000000000 +0000
@@ -17,14 +17,37 @@
 #include "defs.h"
 #include "unwind.h"
 #include "mmap_notify.h"
+#include "static_assert.h"
 #include <elfutils/libdwfl.h>
 
+#define STRACE_UW_CACHE_SIZE 2048
+#define STRACE_UW_CACHE_ASSOC 32
+static_assert(STRACE_UW_CACHE_SIZE % STRACE_UW_CACHE_ASSOC == 0,
+	     "STRACE_UW_CACHE_SIZE % STRACE_UW_CACHE_ASSOC != 0");
+
+struct cache_entry {
+	/* key */
+	Dwarf_Addr pc;
+	unsigned long long generation;
+
+	/* value */
+	const char *modname;
+	const char *symname;
+	GElf_Off off;
+	Dwarf_Addr true_offset;
+
+	/* replacement */
+	unsigned long long last_use;
+};
+
 struct ctx {
 	Dwfl *dwfl;
-	unsigned int last_proc_updating;
+	unsigned long long last_proc_updating;
+	struct cache_entry cache[STRACE_UW_CACHE_SIZE];
 };
 
-static unsigned int mapping_generation;
+static unsigned long long mapping_generation = 1;
+static unsigned long long uwcache_clock;
 
 static void
 update_mapping_generation(struct tcb *tcp, void *unused)
@@ -70,6 +93,7 @@ tcb_init(struct tcb *tcp)
 	struct ctx *ctx = xmalloc(sizeof(*ctx));
 	ctx->dwfl = dwfl;
 	ctx->last_proc_updating = mapping_generation - 1;
+	memset(ctx->cache, 0, sizeof(ctx->cache));
 	return ctx;
 }
 
@@ -113,8 +137,34 @@ struct frame_user_data {
 	unwind_error_action_fn error_action;
 	void *data;
 	int stack_depth;
+	struct ctx *ctx;
 };
 
+static bool
+find_bucket(struct ctx *ctx, Dwarf_Addr pc, struct cache_entry **res) {
+	unsigned int idx = pc & ((STRACE_UW_CACHE_SIZE-1) &
+				 ~(STRACE_UW_CACHE_ASSOC-1));
+	struct cache_entry *unused = NULL;
+	struct cache_entry *lru = ctx->cache + idx;
+	for (unsigned int i = 0; i < STRACE_UW_CACHE_ASSOC; ++i) {
+		struct cache_entry *ce = ctx->cache + (idx + i);
+		if (ce->generation == mapping_generation && ce->pc == pc) {
+			ce->last_use = uwcache_clock++;
+			*res = ce;
+			return true;
+		}
+		if (ce->generation != mapping_generation) {
+			unused = ce;
+			continue;
+		}
+		if (ce->last_use < lru->last_use)
+			lru = ce;
+	}
+	*res = unused ? unused : lru;
+
+	return false;
+}
+
 static int
 frame_callback(Dwfl_Frame *state, void *arg)
 {
@@ -130,24 +180,40 @@ frame_callback(Dwfl_Frame *state, void *
 	if (!isactivation)
 		pc--;
 
-	Dwfl *dwfl = dwfl_thread_dwfl(dwfl_frame_thread(state));
-	Dwfl_Module *mod = dwfl_addrmodule(dwfl, pc);
-	GElf_Off off = 0;
-
-	if (mod != NULL) {
-		const char *modname = NULL;
-		const char *symname = NULL;
-		GElf_Sym sym;
-		Dwarf_Addr true_offset = pc;
-
-		modname = dwfl_module_info(mod, NULL, NULL, NULL, NULL,
-					   NULL, NULL, NULL);
-		symname = dwfl_module_addrinfo(mod, pc, &off, &sym,
-					       NULL, NULL, NULL);
-		dwfl_module_relocate_address(mod, &true_offset);
-		user_data->call_action(user_data->data, modname, symname,
-				       off, true_offset);
+	struct cache_entry *ce;
+	if (find_bucket(user_data->ctx, pc, &ce)) {
+		user_data->call_action(user_data->data,
+				       ce->modname, ce->symname,
+			               ce->off, ce->true_offset);
+	} else {
+		Dwfl *dwfl = dwfl_thread_dwfl(dwfl_frame_thread(state));
+		Dwfl_Module *mod = dwfl_addrmodule(dwfl, pc);
+		GElf_Off off = 0;
+
+		if (mod != NULL) {
+			const char *modname = NULL;
+			const char *symname = NULL;
+			GElf_Sym sym;
+			Dwarf_Addr true_offset = pc;
+
+			modname = dwfl_module_info(mod, NULL, NULL, NULL, NULL,
+						   NULL, NULL, NULL);
+			symname = dwfl_module_addrinfo(mod, pc, &off, &sym,
+						       NULL, NULL, NULL);
+			dwfl_module_relocate_address(mod, &true_offset);
+			user_data->call_action(user_data->data, modname, symname,
+					       off, true_offset);
+
+			ce->generation = mapping_generation;
+			ce->pc = pc;
+			ce->modname = modname;
+			ce->symname = symname;
+			ce->off = off;
+			ce->true_offset = true_offset;
+			ce->last_use = uwcache_clock++;
+		}
 	}
+
 	/* Max number of frames to print reached? */
 	if (user_data->stack_depth-- == 0)
 		return DWARF_CB_ABORT;
@@ -170,6 +236,7 @@ tcb_walk(struct tcb *tcp,
 		.error_action = error_action,
 		.data = data,
 		.stack_depth = 256,
+		.ctx = ctx,
 	};
 
 	flush_cache_maybe(tcp);
diff -pruN 5.5-3/ustat.c 5.9-0ubuntu2/ustat.c
--- 5.5-3/ustat.c	2018-12-24 23:46:43.000000000 +0000
+++ 5.9-0ubuntu2/ustat.c	2020-08-03 08:00:00.000000000 +0000
@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2017 JingPiao Chen <chenjingpiao@gmail.com>
- * Copyright (c) 2017-2018 The strace developers.
+ * Copyright (c) 2017-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -15,6 +15,8 @@ typedef struct ustat struct_ustat;
 
 #include MPERS_DEFS
 
+#include "print_fields.h"
+
 SYS_FUNC(ustat)
 {
 	if (entering(tcp))
@@ -24,10 +26,11 @@ SYS_FUNC(ustat)
 #ifdef HAVE_USTAT_H
 		struct_ustat ust;
 
-		if (!umove_or_printaddr(tcp, tcp->u_arg[1], &ust))
-			tprintf("{f_tfree=%llu, f_tinode=%llu}",
-				zero_extend_signed_to_ull(ust.f_tfree),
-				zero_extend_signed_to_ull(ust.f_tinode));
+		if (!umove_or_printaddr(tcp, tcp->u_arg[1], &ust)) {
+			PRINT_FIELD_U("{", ust, f_tfree);
+			PRINT_FIELD_U(", ", ust, f_tinode);
+			tprints("}");
+		}
 #else /* !HAVE_USTAT_H */
 		printaddr(tcp->u_arg[1]);
 #endif /* HAVE_USTAT_H */
diff -pruN 5.5-3/util.c 5.9-0ubuntu2/util.c
--- 5.5-3/util.c	2019-10-04 13:16:33.000000000 +0000
+++ 5.9-0ubuntu2/util.c	2020-08-25 14:29:30.000000000 +0000
@@ -6,7 +6,7 @@
  * Copyright (c) 1999 IBM Deutschland Entwicklung GmbH, IBM Corporation
  *                     Linux for s390 port by D.J. Barrow
  *                    <barrow_dj@mail.yahoo.com,djbarrow@de.ibm.com>
- * Copyright (c) 1999-2019 The strace developers.
+ * Copyright (c) 1999-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -24,12 +24,62 @@
 #include <sys/uio.h>
 
 #include "largefile_wrappers.h"
+#include "number_set.h"
 #include "print_utils.h"
 #include "static_assert.h"
 #include "string_to_uint.h"
 #include "xlat.h"
 #include "xstring.h"
 
+const struct xlat_data *
+find_xlat_val_ex(const struct xlat_data *items, const char *s, size_t num_items,
+		 unsigned int flags)
+{
+	for (size_t i = 0; i < num_items; i++) {
+		if (!(flags & FXL_CASE_SENSITIVE ? strcmp
+						 : strcasecmp)(items[i].str, s))
+			return items + i;
+	}
+
+	return NULL;
+}
+
+uint64_t
+find_arg_val_(const char *arg, const struct xlat_data *strs, size_t strs_size,
+	       uint64_t default_val, uint64_t not_found)
+{
+	if (!arg)
+		return default_val;
+
+	const struct xlat_data *res = find_xlat_val_ex(strs, arg, strs_size, 0);
+
+	return  res ? res->val : not_found;
+}
+
+int
+str2timescale_ex(const char *arg, int empty_dflt, int null_dflt,
+		 int *width)
+{
+	static const struct xlat_data units[] = {
+		{ 1000000000U | (0ULL << 32), "s" },
+		{ 1000000U    | (3ULL << 32), "ms" },
+		{ 1000U       | (6ULL << 32), "us" },
+		{ 1U          | (9ULL << 32), "ns" },
+	};
+
+	if (!arg)
+		return null_dflt;
+	if (!arg[0])
+		return empty_dflt;
+
+	uint64_t res = find_arg_val(arg, units, null_dflt, -1ULL);
+
+	if (width && res != -1ULL)
+		*width = res >> 32;
+
+	return res & 0xffffffff;
+}
+
 int
 ts_nz(const struct timespec *a)
 {
@@ -77,7 +127,7 @@ ts_sub(struct timespec *tv, const struct
 }
 
 void
-ts_div(struct timespec *tv, const struct timespec *a, int n)
+ts_div(struct timespec *tv, const struct timespec *a, uint64_t n)
 {
 	long long nsec = (a->tv_sec % n * 1000000000LL + a->tv_nsec + n / 2) / n;
 	tv->tv_sec = a->tv_sec / n + nsec / 1000000000;
@@ -85,7 +135,7 @@ ts_div(struct timespec *tv, const struct
 }
 
 void
-ts_mul(struct timespec *tv, const struct timespec *a, int n)
+ts_mul(struct timespec *tv, const struct timespec *a, uint64_t n)
 {
 	long long nsec = a->tv_nsec * n;
 	tv->tv_sec = a->tv_sec * n + nsec / 1000000000;
@@ -109,22 +159,11 @@ parse_ts(const char *s, struct timespec
 {
 	enum { NS_IN_S = 1000000000 };
 
-	static const struct time_unit {
-		const char *s;
-		unsigned int mul;
-	} units[] = {
-		{ "",   1000 }, /* default is microseconds */
-		{ "s",  1000000000 },
-		{ "ms", 1000000 },
-		{ "us", 1000 },
-		{ "ns", 1 },
-	};
 	static const char float_accept[] =  "eE.-+0123456789";
 	static const char int_accept[] = "+0123456789";
 
 	size_t float_len = strspn(s, float_accept);
 	size_t int_len = strspn(s, int_accept);
-	const struct time_unit *unit = NULL;
 	char *endptr = NULL;
 	double float_val = -1;
 	long long int_val = -1;
@@ -145,25 +184,18 @@ parse_ts(const char *s, struct timespec
 			return -1;
 	}
 
-	for (size_t i = 0; i < ARRAY_SIZE(units); i++) {
-		if (strcmp(endptr, units[i].s))
-			continue;
-
-		unit = units + i;
-		break;
-	}
-
-	if (!unit)
+	int scale = str2timescale_sfx(endptr, NULL);
+	if (scale <= 0)
 		return -1;
 
 	if (float_len > int_len) {
-		t->tv_sec = float_val / (NS_IN_S / unit->mul);
+		t->tv_sec = float_val / (NS_IN_S / scale);
 		t->tv_nsec = ((uint64_t) ((float_val -
-					   (t->tv_sec * (NS_IN_S / unit->mul)))
-					  * unit->mul)) % NS_IN_S;
+					   (t->tv_sec * (NS_IN_S / scale)))
+					  * scale)) % NS_IN_S;
 	} else {
-		t->tv_sec = int_val / (NS_IN_S / unit->mul);
-		t->tv_nsec = (int_val % (NS_IN_S / unit->mul)) * unit->mul;
+		t->tv_sec = int_val / (NS_IN_S / scale);
+		t->tv_nsec = (int_val % (NS_IN_S / scale)) * scale;
 	}
 
 	return 0;
@@ -360,6 +392,18 @@ printnum_fd(struct tcb *const tcp, const
 	return true;
 }
 
+bool
+printnum_pid(struct tcb *const tcp, const kernel_ulong_t addr, enum pid_type type)
+{
+	int pid;
+	if (umove_or_printaddr(tcp, addr, &pid))
+		return false;
+	tprints("[");
+	printpid(tcp, pid, type);
+	tprints("]");
+	return true;
+}
+
 /**
  * Prints time to a (static internal) buffer and returns pointer to it.
  * Returns NULL if the provided time specification is not correct.
@@ -457,7 +501,7 @@ getfdproto(struct tcb *tcp, int fd)
 	if (fd < 0)
 		return SOCK_PROTO_UNKNOWN;
 
-	xsprintf(path, "/proc/%u/fd/%u", tcp->pid, fd);
+	xsprintf(path, "/proc/%u/fd/%u", get_proc_pid(tcp), fd);
 	r = getxattr(path, "system.sockprotoname", buf, bufsize - 1);
 	if (r <= 0)
 		return SOCK_PROTO_UNKNOWN;
@@ -535,21 +579,87 @@ printdev(struct tcb *tcp, int fd, const
 	return false;
 }
 
+pid_t
+pidfd_get_pid(pid_t pid_of_fd, int fd)
+{
+	int proc_pid = 0;
+	translate_pid(NULL, pid_of_fd, PT_TID, &proc_pid);
+	if (!proc_pid)
+		return -1;
+
+	char fdi_path[sizeof("/proc/%u/fdinfo/%u") + 2 * sizeof(int) * 3];
+	xsprintf(fdi_path, "/proc/%u/fdinfo/%u", proc_pid, fd);
+
+	FILE *f = fopen_stream(fdi_path, "r");
+	if (!f)
+		return -1;
+
+	static const char pid_pfx[] = "Pid:\t";
+	char *line = NULL;
+	size_t sz = 0;
+	pid_t pid = -1;
+	while (getline(&line, &sz, f) > 0) {
+		const char *pos = STR_STRIP_PREFIX(line, pid_pfx);
+		if (pos == line)
+			continue;
+
+		pid = string_to_uint_ex(pos, NULL, INT_MAX, "\n");
+		break;
+	}
+
+	free(line);
+	fclose(f);
+
+	return pid;
+}
+
+static bool
+printpidfd(pid_t pid_of_fd, int fd, const char *path)
+{
+	static const char pidfd_path[] = "anon_inode:[pidfd]";
+
+	if (strcmp(path, pidfd_path))
+		return false;
+
+	pid_t pid = pidfd_get_pid(pid_of_fd, fd);
+	if (pid <= 0)
+		return false;
+
+	tprintf("pid:%d", pid);
+	return true;
+}
+
 void
-printfd(struct tcb *tcp, int fd)
+printfd_pid(struct tcb *tcp, pid_t pid, int fd)
 {
 	char path[PATH_MAX + 1];
-	if (show_fd_path && getfdpath(tcp, fd, path, sizeof(path)) >= 0) {
-		tprintf("%d<", fd);
-		if (show_fd_path <= 1
-		    || (!printsocket(tcp, fd, path)
-		         && !printdev(tcp, fd, path))) {
-			print_quoted_string_ex(path, strlen(path),
-				QUOTE_OMIT_LEADING_TRAILING_QUOTES, "<>");
-		}
+	if (pid > 0 && !number_set_array_is_empty(decode_fd_set, 0)
+	    && getfdpath_pid(pid, fd, path, sizeof(path)) >= 0) {
+		tprintf("%d<", (int) fd);
+		if (is_number_in_set(DECODE_FD_SOCKET, decode_fd_set) &&
+		    printsocket(tcp, fd, path))
+			goto printed;
+		if (is_number_in_set(DECODE_FD_DEV, decode_fd_set) &&
+		    printdev(tcp, fd, path))
+			goto printed;
+		if (is_number_in_set(DECODE_FD_PIDFD, decode_fd_set) &&
+		    printpidfd(pid, fd, path))
+			goto printed;
+		print_quoted_string_ex(path, strlen(path),
+			QUOTE_OMIT_LEADING_TRAILING_QUOTES, "<>");
+
+printed:
 		tprints(">");
-	} else
+	} else {
 		tprintf("%d", fd);
+	}
+}
+
+void
+printfd_pid_tracee_ns(struct tcb *tcp, pid_t pid, int fd)
+{
+	int strace_pid = translate_pid(tcp, pid, PT_TGID, NULL);
+	printfd_pid(tcp, strace_pid, fd);
 }
 
 /*
@@ -912,7 +1022,7 @@ printstr_ex(struct tcb *const tcp, const
 	 */
 	ellipsis = string_quote(str, outstr, size, style, NULL)
 		   && len
-		   && ((style & QUOTE_0_TERMINATED)
+		   && ((style & (QUOTE_0_TERMINATED | QUOTE_EXPECT_TRAILING_0))
 		       || len > max_strlen);
 
 	tprints(outstr);
@@ -922,6 +1032,49 @@ printstr_ex(struct tcb *const tcp, const
 	return rc;
 }
 
+bool
+print_nonzero_bytes(struct tcb *const tcp, const char *prefix,
+		    const kernel_ulong_t start_addr,
+		    const unsigned int start_offs,
+		    const unsigned int total_len,
+		    const unsigned int style)
+{
+	if (start_offs >= total_len)
+		return false;
+
+	const kernel_ulong_t addr = start_addr + start_offs;
+	const unsigned int len = total_len - start_offs;
+	const unsigned int size = MIN(len, max_strlen);
+
+	char *str = malloc(len);
+
+	if (!str) {
+		error_func_msg("memory exhausted when tried to allocate"
+                               " %u bytes", len);
+		tprintf("%s???", prefix);
+		return true;
+	}
+
+	bool ret = true;
+
+	if (umoven(tcp, addr, len, str)) {
+		tprintf("%s???", prefix);
+	} else if (is_filled(str, 0, len)) {
+		ret = false;
+	} else {
+		tprints(prefix);
+		tprintf("/* bytes %u..%u */ ", start_offs, total_len - 1);
+
+		print_quoted_string(str, size, style);
+
+		if (size < len)
+			tprints("...");
+	}
+
+	free(str);
+	return ret;
+}
+
 void
 dumpiov_upto(struct tcb *const tcp, const int len, const kernel_ulong_t addr,
 	     kernel_ulong_t data_size)
@@ -980,66 +1133,6 @@ dumpiov_upto(struct tcb *const tcp, cons
 #undef iov
 }
 
-#define ILOG2_ITER_(val_, ret_, bit_)					\
-	do {								\
-		typeof(ret_) shift_ =					\
-			((val_) > ((((typeof(val_)) 1)			\
-				   << (1 << (bit_))) - 1)) << (bit_);	\
-		(val_) >>= shift_;					\
-		(ret_) |= shift_;					\
-	} while (0)
-
-/**
- * Calculate floor(log2(val)), with the exception of val == 0, for which 0
- * is returned as well.
- *
- * @param val 64-bit value to calculate integer base-2 logarithm for.
- * @return    (unsigned int) floor(log2(val)) if val > 0, 0 if val == 0.
- */
-static inline unsigned int
-ilog2_64(uint64_t val)
-{
-	unsigned int ret = 0;
-
-	ILOG2_ITER_(val, ret, 5);
-	ILOG2_ITER_(val, ret, 4);
-	ILOG2_ITER_(val, ret, 3);
-	ILOG2_ITER_(val, ret, 2);
-	ILOG2_ITER_(val, ret, 1);
-	ILOG2_ITER_(val, ret, 0);
-
-	return ret;
-}
-
-/**
- * Calculate floor(log2(val)), with the exception of val == 0, for which 0
- * is returned as well.
- *
- * @param val 32-bit value to calculate integer base-2 logarithm for.
- * @return    (unsigned int) floor(log2(val)) if val > 0, 0 if val == 0.
- */
-static inline unsigned int
-ilog2_32(uint32_t val)
-{
-	unsigned int ret = 0;
-
-	ILOG2_ITER_(val, ret, 4);
-	ILOG2_ITER_(val, ret, 3);
-	ILOG2_ITER_(val, ret, 2);
-	ILOG2_ITER_(val, ret, 1);
-	ILOG2_ITER_(val, ret, 0);
-
-	return ret;
-}
-
-#undef ILOG2_ITER_
-
-#if SIZEOF_KERNEL_LONG_T > 4
-# define ilog2_klong ilog2_64
-#else
-# define ilog2_klong ilog2_32
-#endif
-
 void
 dumpstr(struct tcb *const tcp, const kernel_ulong_t addr,
 	const kernel_ulong_t len)
@@ -1437,7 +1530,7 @@ print_abnormal_hi(const kernel_ulong_t v
 }
 
 int
-read_int_from_file(struct tcb *tcp, const char *const fname, int *const pvalue)
+read_int_from_file(const char *const fname, int *const pvalue)
 {
 	const int fd = open_file(fname, O_RDONLY);
 	if (fd < 0)
diff -pruN 5.5-3/v4l2.c 5.9-0ubuntu2/v4l2.c
--- 5.5-3/v4l2.c	2019-10-22 17:44:08.000000000 +0000
+++ 5.9-0ubuntu2/v4l2.c	2020-07-30 08:00:00.000000000 +0000
@@ -2,7 +2,7 @@
  * Copyright (c) 2014 Philippe De Muyter <phdm@macqel.be>
  * Copyright (c) 2014 William Manley <will@williammanley.net>
  * Copyright (c) 2011 Peter Zotov <whitequark@whitequark.org>
- * Copyright (c) 2014-2019 The strace developers.
+ * Copyright (c) 2014-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -10,16 +10,28 @@
 
 #include "defs.h"
 
-#include <stdint.h>
-#include <linux/ioctl.h>
-#include <linux/types.h>
-#include <linux/videodev2.h>
+#include "static_assert.h"
 
-#include DEF_MPERS_TYPE(struct_v4l2_buffer)
+#define CHECK_V4L2_STRUCT_SIZE(s_) \
+	static_assert(sizeof(struct s_) == sizeof(struct_##s_), \
+		      "Unexpected struct " #s_ " size")
+#define CHECK_V4L2_STRUCT_SIZE_LE(s_) \
+	static_assert(sizeof(struct s_) <= sizeof(struct_##s_), \
+		      "Unexpected struct " #s_ " size, " \
+		      "please update the decoder")
+#define CHECK_V4L2_RESERVED_SIZE(s_) \
+	static_assert(sizeof_field(struct s_, reserved) \
+		      >= sizeof_field(struct_##s_, reserved), \
+		      "Unexpected struct " #s_ ".reserved size, " \
+		      "please update the decoder")
+#define CHECK_V4L2_STRUCT_RESERVED_SIZE(s_) \
+	CHECK_V4L2_STRUCT_SIZE(s_); \
+	CHECK_V4L2_RESERVED_SIZE(s_)
+
+#include DEF_MPERS_TYPE(kernel_v4l2_buffer_t)
+#include DEF_MPERS_TYPE(kernel_v4l2_event_t)
 #include DEF_MPERS_TYPE(struct_v4l2_clip)
-#ifdef VIDIOC_CREATE_BUFS
-# include DEF_MPERS_TYPE(struct_v4l2_create_buffers)
-#endif
+#include DEF_MPERS_TYPE(struct_v4l2_create_buffers)
 #include DEF_MPERS_TYPE(struct_v4l2_ext_control)
 #include DEF_MPERS_TYPE(struct_v4l2_ext_controls)
 #include DEF_MPERS_TYPE(struct_v4l2_format)
@@ -27,17 +39,37 @@
 #include DEF_MPERS_TYPE(struct_v4l2_input)
 #include DEF_MPERS_TYPE(struct_v4l2_standard)
 
-typedef struct v4l2_buffer struct_v4l2_buffer;
-typedef struct v4l2_clip struct_v4l2_clip;
-#ifdef VIDIOC_CREATE_BUFS
-typedef struct v4l2_create_buffers struct_v4l2_create_buffers;
+#include "kernel_v4l2_types.h"
+
+CHECK_V4L2_STRUCT_RESERVED_SIZE(v4l2_capability);
+CHECK_V4L2_STRUCT_SIZE_LE(v4l2_pix_format);
+#ifdef HAVE_STRUCT_V4L2_PLANE_PIX_FORMAT
+CHECK_V4L2_STRUCT_RESERVED_SIZE(v4l2_plane_pix_format);
+#endif
+#ifdef HAVE_STRUCT_V4L2_PIX_FORMAT_MPLANE
+CHECK_V4L2_STRUCT_RESERVED_SIZE(v4l2_pix_format_mplane);
+#endif
+CHECK_V4L2_STRUCT_SIZE(v4l2_clip);
+CHECK_V4L2_STRUCT_SIZE_LE(v4l2_window);
+CHECK_V4L2_STRUCT_RESERVED_SIZE(v4l2_vbi_format);
+CHECK_V4L2_STRUCT_RESERVED_SIZE(v4l2_sliced_vbi_format);
+CHECK_V4L2_STRUCT_RESERVED_SIZE(v4l2_sliced_vbi_cap);
+#ifdef HAVE_STRUCT_V4L2_SDR_FORMAT
+CHECK_V4L2_STRUCT_RESERVED_SIZE(v4l2_sdr_format);
+#endif
+#ifdef HAVE_STRUCT_V4L2_META_FORMAT
+CHECK_V4L2_STRUCT_SIZE(v4l2_meta_format);
+#endif
+CHECK_V4L2_STRUCT_SIZE(v4l2_format);
+#ifdef HAVE_STRUCT_V4L2_FRMSIZEENUM
+CHECK_V4L2_STRUCT_RESERVED_SIZE(v4l2_frmsizeenum);
+#endif
+#ifdef HAVE_STRUCT_V4L2_FRMIVALENUM
+CHECK_V4L2_STRUCT_RESERVED_SIZE(v4l2_frmivalenum);
+#endif
+#ifdef HAVE_STRUCT_V4L2_CREATE_BUFFERS
+CHECK_V4L2_STRUCT_RESERVED_SIZE(v4l2_create_buffers);
 #endif
-typedef struct v4l2_ext_control struct_v4l2_ext_control;
-typedef struct v4l2_ext_controls struct_v4l2_ext_controls;
-typedef struct v4l2_format struct_v4l2_format;
-typedef struct v4l2_framebuffer struct_v4l2_framebuffer;
-typedef struct v4l2_input struct_v4l2_input;
-typedef struct v4l2_standard struct_v4l2_standard;
 
 #include MPERS_DEFS
 
@@ -50,6 +82,10 @@ typedef struct v4l2_standard struct_v4l2
 # define v4l2_fourcc_be(a, b, c, d) (v4l2_fourcc(a, b, c, d) | (1U << 31))
 #endif
 
+#ifndef VIDEO_MAX_PLANES
+# define VIDEO_MAX_PLANES 8
+#endif
+
 #define FMT_FRACT "%u/%u"
 #define ARGS_FRACT(x) ((x).numerator), ((x).denominator)
 
@@ -59,9 +95,18 @@ typedef struct v4l2_standard struct_v4l2
 #include "xlat/v4l2_pix_fmts.h"
 #include "xlat/v4l2_sdr_fmts.h"
 
+#define XLAT_MACROS_ONLY
+# include "xlat/v4l2_ioctl_cmds.h"
+#undef XLAT_MACROS_ONLY
+
 static void
 print_pixelformat(uint32_t fourcc, const struct xlat *xlat)
 {
+	if (xlat_verbose(xlat_verbosity) == XLAT_STYLE_RAW) {
+		tprintf("%#x", fourcc);
+		return;
+	}
+
 	unsigned char a[] = {
 		(unsigned char) fourcc,
 		(unsigned char) (fourcc >> 8),
@@ -117,7 +162,7 @@ print_pixelformat(uint32_t fourcc, const
 static int
 print_v4l2_capability(struct tcb *const tcp, const kernel_ulong_t arg)
 {
-	struct v4l2_capability caps;
+	struct_v4l2_capability caps;
 
 	if (entering(tcp))
 		return 0;
@@ -127,17 +172,16 @@ print_v4l2_capability(struct tcb *const
 	PRINT_FIELD_CSTRING("{", caps, driver);
 	PRINT_FIELD_CSTRING(", ", caps, card);
 	PRINT_FIELD_CSTRING(", ", caps, bus_info);
-	tprintf(", version=%u.%u.%u, capabilities=",
-		(caps.version >> 16) & 0xFF,
-		(caps.version >> 8) & 0xFF,
-		caps.version & 0xFF);
+	tprints(", version=");
+	print_kernel_version(caps.version);
+	tprints(", capabilities=");
 	printflags(v4l2_device_capabilities_flags, caps.capabilities,
 		   "V4L2_CAP_???");
-#ifdef HAVE_STRUCT_V4L2_CAPABILITY_DEVICE_CAPS
-	tprints(", device_caps=");
-	printflags(v4l2_device_capabilities_flags, caps.device_caps,
-		   "V4L2_CAP_???");
-#endif
+	if (caps.device_caps) {
+		tprints(", device_caps=");
+		printflags(v4l2_device_capabilities_flags, caps.device_caps,
+			   "V4L2_CAP_???");
+	}
 	tprints("}");
 	return RVAL_IOCTL_DECODED;
 }
@@ -204,7 +248,6 @@ print_v4l2_format_fmt(struct tcb *const
 			  "V4L2_COLORSPACE_???");
 		tprints("}");
 		break;
-#if HAVE_STRUCT_V4L2_FORMAT_FMT_PIX_MP
 	case V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE:
 	case V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE: {
 		unsigned int i, max;
@@ -233,7 +276,6 @@ print_v4l2_format_fmt(struct tcb *const
 			(unsigned) f->fmt.pix_mp.num_planes);
 		break;
 	}
-#endif
 	/* OUTPUT_OVERLAY since Linux v2.6.22-rc1~1118^2~179 */
 	case V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY:
 	case V4L2_BUF_TYPE_VIDEO_OVERLAY: {
@@ -248,9 +290,8 @@ print_v4l2_format_fmt(struct tcb *const
 				  tfetch_mem, print_v4l2_clip, 0);
 		tprintf(", clipcount=%u, bitmap=", f->fmt.win.clipcount);
 		printaddr(ptr_to_kulong(f->fmt.win.bitmap));
-#ifdef HAVE_STRUCT_V4L2_WINDOW_GLOBAL_ALPHA
-		tprintf(", global_alpha=%#x", f->fmt.win.global_alpha);
-#endif
+		if (f->fmt.win.global_alpha)
+			tprintf(", global_alpha=%#x", f->fmt.win.global_alpha);
 		tprints("}");
 		break;
 	}
@@ -262,15 +303,14 @@ print_v4l2_format_fmt(struct tcb *const
 			f->fmt.vbi.sampling_rate, f->fmt.vbi.offset,
 			f->fmt.vbi.samples_per_line);
 		print_pixelformat(f->fmt.vbi.sample_format, v4l2_pix_fmts);
-		tprintf(", start=[%u, %u], count=[%u, %u], ",
+		tprintf(", start=[%d, %d], count=[%u, %u], ",
 			f->fmt.vbi.start[0], f->fmt.vbi.start[1],
 			f->fmt.vbi.count[0], f->fmt.vbi.count[1]);
 		tprints("flags=");
-		printxval(v4l2_vbi_flags, f->fmt.vbi.flags, "V4L2_VBI_???");
+		printflags(v4l2_vbi_flags, f->fmt.vbi.flags, "V4L2_VBI_???");
 		tprints("}");
 		break;
 	/* both since Linux v2.6.14-rc2~64 */
-#if HAVE_STRUCT_V4L2_FORMAT_FMT_SLICED
 	case V4L2_BUF_TYPE_SLICED_VBI_CAPTURE:
 	case V4L2_BUF_TYPE_SLICED_VBI_OUTPUT: {
 		unsigned int i, j;
@@ -298,8 +338,6 @@ print_v4l2_format_fmt(struct tcb *const
 		tprints("]}");
 		break;
 	}
-#endif
-#if HAVE_STRUCT_V4L2_FORMAT_FMT_SDR
 	/* since Linux v4.4-rc1~118^2~14 */
 	case V4L2_BUF_TYPE_SDR_OUTPUT:
 	/* since Linux v3.15-rc1~85^2~213 */
@@ -307,13 +345,13 @@ print_v4l2_format_fmt(struct tcb *const
 		tprints(prefix);
 		tprints("fmt.sdr={pixelformat=");
 		print_pixelformat(f->fmt.sdr.pixelformat, v4l2_sdr_fmts);
-# ifdef HAVE_STRUCT_V4L2_SDR_FORMAT_BUFFERSIZE
-		tprintf(", buffersize=%u",
-			f->fmt.sdr.buffersize);
-# endif
+		if (f->fmt.sdr.buffersize)
+			tprintf(", buffersize=%u",
+				f->fmt.sdr.buffersize);
 		tprints("}");
 		break;
-#endif
+	default:
+		return false;
 	}
 	return ret;
 }
@@ -341,7 +379,7 @@ print_v4l2_format(struct tcb *const tcp,
 	}
 
 	if (!syserror(tcp) && !umove(tcp, arg, &f))
-		print_v4l2_format_fmt(tcp, is_get ? ", " : " => ", &f);
+		print_v4l2_format_fmt(tcp, is_get ? ", " : "} => {", &f);
 
 	tprints("}");
 
@@ -361,7 +399,7 @@ print_v4l2_requestbuffers(struct tcb *co
 		if (umove_or_printaddr(tcp, arg, &reqbufs))
 			return RVAL_IOCTL_DECODED;
 
-		tprintf("{type=");
+		tprints("{type=");
 		printxval(v4l2_buf_types, reqbufs.type, "V4L2_BUF_TYPE_???");
 		tprints(", memory=");
 		printxval(v4l2_memories, reqbufs.memory, "V4L2_MEMORY_???");
@@ -385,12 +423,41 @@ print_v4l2_requestbuffers(struct tcb *co
 }
 
 #include "xlat/v4l2_buf_flags.h"
+#include "xlat/v4l2_buf_flags_ts_type.h"
+#include "xlat/v4l2_buf_flags_ts_src.h"
+
+#define XLAT_MACROS_ONLY
+# include "xlat/v4l2_buf_flags_masks.h"
+#undef XLAT_MACROS_ONLY
+
+static void
+print_v4l2_buffer_flags(uint32_t val)
+{
+	const uint32_t ts_type = val & V4L2_BUF_FLAG_TIMESTAMP_MASK;
+	const uint32_t ts_src  = val & V4L2_BUF_FLAG_TSTAMP_SRC_MASK;
+	const uint32_t flags   = val & ~ts_type & ~ts_src;
+
+	if (xlat_verbose(xlat_verbosity) == XLAT_STYLE_RAW) {
+		tprintf("%#" PRIx32, val);
+		return;
+	}
+
+	if (flags) {
+		printflags(v4l2_buf_flags, flags, "V4L2_BUF_FLAG_???");
+		tprints("|");
+	}
+	printxval(v4l2_buf_flags_ts_type, ts_type,
+		  "V4L2_BUF_FLAG_TIMESTAMP_???");
+	tprints("|");
+	printxval(v4l2_buf_flags_ts_src, ts_src,
+		  "V4L2_BUF_FLAG_TSTAMP_SRC_???");
+}
 
 static int
 print_v4l2_buffer(struct tcb *const tcp, const unsigned int code,
 		  const kernel_ulong_t arg)
 {
-	struct_v4l2_buffer b;
+	kernel_v4l2_buffer_t b;
 
 	if (entering(tcp)) {
 		tprints(", ");
@@ -419,10 +486,18 @@ print_v4l2_buffer(struct tcb *const tcp,
 
 		tprintf(", length=%u, bytesused=%u, flags=",
 			b.length, b.bytesused);
-		printflags(v4l2_buf_flags, b.flags, "V4L2_BUF_FLAG_???");
+		print_v4l2_buffer_flags(b.flags);
 		if (code == VIDIOC_DQBUF) {
-			tprints(", timestamp = ");
-			MPERS_FUNC_NAME(print_struct_timeval)(&b.timestamp);
+			tprints(", timestamp=");
+			kernel_timeval64_t t;
+			if (sizeof(t.tv_usec) == sizeof(b.timestamp.tv_usec)) {
+				print_timeval64_data_size(&b.timestamp,
+							  sizeof(b.timestamp));
+			} else {
+				t.tv_sec = b.timestamp.tv_sec;
+				t.tv_usec = zero_extend_signed_to_ull(b.timestamp.tv_usec);
+				print_timeval64_data_size(&t, sizeof(t));
+			}
 		}
 		tprints(", ...");
 	}
@@ -493,7 +568,7 @@ print_v4l2_streamparm(struct tcb *const
 			tprints("}");
 			return RVAL_IOCTL_DECODED;
 		}
-		tprints(is_get ? ", " : " => ");
+		tprints(is_get ? ", " : "} => {");
 	}
 
 	if (s.type == V4L2_BUF_TYPE_VIDEO_CAPTURE) {
@@ -508,7 +583,7 @@ print_v4l2_streamparm(struct tcb *const
 		tprintf(", timeperframe=" FMT_FRACT,
 			ARGS_FRACT(s.parm.capture.timeperframe));
 
-		tprintf(", extendedmode=%u, readbuffers=%u}",
+		tprintf(", extendedmode=%#x, readbuffers=%u}",
 			s.parm.capture.extendedmode,
 			s.parm.capture.readbuffers);
 	} else {
@@ -516,12 +591,14 @@ print_v4l2_streamparm(struct tcb *const
 		printflags(v4l2_streaming_capabilities,
 			   s.parm.output.capability, "V4L2_CAP_???");
 
-		tprintf(", outputmode=%u", s.parm.output.outputmode);
+		tprints(", outputmode=");
+		printflags(v4l2_capture_modes,
+			   s.parm.output.outputmode, "V4L2_MODE_???");
 
 		tprintf(", timeperframe=" FMT_FRACT,
 			ARGS_FRACT(s.parm.output.timeperframe));
 
-		tprintf(", extendedmode=%u, writebuffers=%u}",
+		tprintf(", extendedmode=%#x, writebuffers=%u}",
 			s.parm.output.extendedmode,
 			s.parm.output.writebuffers);
 	}
@@ -551,7 +628,7 @@ print_v4l2_standard(struct tcb *const tc
 		PRINT_FIELD_CSTRING(", ", s, name);
 		tprintf(", frameperiod=" FMT_FRACT,
 			ARGS_FRACT(s.frameperiod));
-		tprintf(", framelines=%d", s.framelines);
+		tprintf(", framelines=%u", s.framelines);
 	}
 
 	tprints("}");
@@ -593,10 +670,28 @@ print_v4l2_input(struct tcb *const tcp,
 #include "xlat/v4l2_control_classes.h"
 #include "xlat/v4l2_control_id_bases.h"
 #include "xlat/v4l2_control_ids.h"
+#include "xlat/v4l2_control_query_flags.h"
 
 static void
-print_v4l2_cid(const uint32_t cid)
+print_v4l2_cid(uint32_t cid, bool next_flags)
 {
+	if (xlat_verbose(xlat_verbosity) == XLAT_STYLE_RAW) {
+		tprintf("%#x", cid);
+		return;
+	}
+
+	if (next_flags) {
+		uint32_t flags = cid & v4l2_control_query_flags->flags_mask;
+
+		if (flags) {
+			printflags(v4l2_control_query_flags, flags,
+				   "V4L2_CTRL_FLAG_NEXT_???");
+			tprints("|");
+
+			cid &= ~flags;
+		}
+	}
+
 	const char *id_name = xlookup(v4l2_control_ids, cid);
 
 	if (id_name) {
@@ -612,14 +707,14 @@ print_v4l2_cid(const uint32_t cid)
 		return;
 	}
 
-	char *tmp_str;
-
-	if (asprintf(&tmp_str, "%s+%#" PRIx64,
-		     class_str, cid - class_id) < 0)
-		tmp_str = NULL;
+	/*
+	 * As of now, the longest control class name is V4L2_CTRL_CLASS_IMAGE_SOURCE,
+	 * of 28 characters long.
+	 */
+	char tmp_str[64 + sizeof("+%#") + sizeof(class_id) * 2];
 
+	xsprintf(tmp_str, "%s+%#" PRIx64, class_str, cid - class_id);
 	print_xlat_ex(cid, tmp_str, XLAT_STYLE_DEFAULT);
-	free(tmp_str);
 }
 
 static int
@@ -634,15 +729,14 @@ print_v4l2_control(struct tcb *const tcp
 			return RVAL_IOCTL_DECODED;
 
 		tprints("{id=");
-		print_v4l2_cid(c.id);
+		print_v4l2_cid(c.id, false);
 		if (!is_get)
 			tprintf(", value=%d", c.value);
 		return 0;
 	}
 
 	if (!syserror(tcp) && !umove(tcp, arg, &c)) {
-		tprints(is_get ? ", " : " => ");
-		tprintf("value=%d", c.value);
+		tprintf("%s%d", is_get ? ", value=" : " => ", c.value);
 	}
 
 	tprints("}");
@@ -673,18 +767,18 @@ print_v4l2_tuner(struct tcb *const tcp,
 			tprints("}");
 			return RVAL_IOCTL_DECODED;
 		}
-		tprints(is_get ? ", " : " => ");
+		tprints(is_get ? ", " : "} => {");
 	}
 
 	PRINT_FIELD_CSTRING("", c, name);
 	tprints(", type=");
-	printxval(v4l2_tuner_types, c.type, "V4L2_TUNER_TYPE_???");
+	printxval(v4l2_tuner_types, c.type, "V4L2_TUNER_???");
 	tprints(", capability=");
-	printxval(v4l2_tuner_capabilities, c.capability,
+	printflags(v4l2_tuner_capabilities, c.capability,
 		  "V4L2_TUNER_CAP_???");
 	tprintf(", rangelow=%u, rangehigh=%u, rxsubchans=",
 		c.rangelow, c.rangehigh);
-	printxval(v4l2_tuner_rxsubchanses, c.rxsubchans,
+	printflags(v4l2_tuner_rxsubchanses, c.rxsubchans,
 		  "V4L2_TUNER_SUB_???");
 	tprints(", audmode=");
 	printxval(v4l2_tuner_audmodes, c.audmode,
@@ -711,40 +805,45 @@ print_v4l2_queryctrl(struct tcb *const t
 		tprints(", ");
 		if (umove_or_printaddr(tcp, arg, &c))
 			return RVAL_IOCTL_DECODED;
+		set_tcb_priv_ulong(tcp, c.id);
 		tprints("{id=");
-	} else {
-		if (syserror(tcp) || umove(tcp, arg, &c) < 0) {
-			tprints("}");
-			return RVAL_IOCTL_DECODED;
-		}
-		if (get_tcb_priv_ulong(tcp))
-			tprints(" => ");
-	}
+		print_v4l2_cid(c.id, true);
 
-	if (entering(tcp) || get_tcb_priv_ulong(tcp)) {
-#ifdef V4L2_CTRL_FLAG_NEXT_CTRL
-		const unsigned long next = c.id & V4L2_CTRL_FLAG_NEXT_CTRL;
-		set_tcb_priv_ulong(tcp, next);
-		if (next) {
-			print_xlat(V4L2_CTRL_FLAG_NEXT_CTRL);
-			tprints("|");
-			c.id &= ~V4L2_CTRL_FLAG_NEXT_CTRL;
-		}
-#endif
-		printxval(v4l2_control_ids, c.id, "V4L2_CID_???");
+		return 0;
 	}
 
-	if (exiting(tcp)) {
-		tprints(", type=");
-		printxval(v4l2_control_types, c.type, "V4L2_CTRL_TYPE_???");
-		PRINT_FIELD_CSTRING(", ", c, name);
-		tprintf(", minimum=%d, maximum=%d, step=%d"
-			", default_value=%d, flags=",
-			c.minimum, c.maximum, c.step, c.default_value);
-		printflags(v4l2_control_flags, c.flags, "V4L2_CTRL_FLAG_???");
+	/* exiting */
+	if (syserror(tcp) || umove(tcp, arg, &c) < 0) {
 		tprints("}");
+		return RVAL_IOCTL_DECODED;
 	}
-	return entering(tcp) ? 0 : RVAL_IOCTL_DECODED;
+
+	unsigned long entry_id = get_tcb_priv_ulong(tcp);
+
+	if (c.id != entry_id) {
+		tprints(" => ");
+		print_v4l2_cid(c.id, false);
+	}
+
+	PRINT_FIELD_XVAL(", ", c, type, v4l2_control_types,
+			 "V4L2_CTRL_TYPE_???");
+	PRINT_FIELD_CSTRING(", ", c, name);
+	if (!abbrev(tcp)) {
+		PRINT_FIELD_D(", ", c, minimum);
+		PRINT_FIELD_D(", ", c, maximum);
+		PRINT_FIELD_D(", ", c, step);
+		PRINT_FIELD_D(", ", c, default_value);
+		PRINT_FIELD_FLAGS(", ", c, flags, v4l2_control_flags,
+				  "V4L2_CTRL_FLAG_???");
+		if (!IS_ARRAY_ZERO(c.reserved))
+			PRINT_FIELD_ARRAY(", ", c, reserved, tcp,
+					  print_xint32_array_member);
+	} else {
+		tprints(", ...");
+	}
+	tprints("}");
+
+	return RVAL_IOCTL_DECODED;
 }
 
 static int
@@ -801,7 +900,6 @@ print_v4l2_crop(struct tcb *const tcp, c
 	return RVAL_IOCTL_DECODED;
 }
 
-#ifdef VIDIOC_S_EXT_CTRLS
 static bool
 print_v4l2_ext_control(struct tcb *tcp, void *elem_buf, size_t elem_size, void *data)
 {
@@ -809,14 +907,13 @@ print_v4l2_ext_control(struct tcb *tcp,
 
 	tprints("{id=");
 	printxval(v4l2_control_ids, p->id, "V4L2_CID_???");
-# if HAVE_STRUCT_V4L2_EXT_CONTROL_STRING
 	tprintf(", size=%u", p->size);
 	if (p->size > 0) {
 		tprints(", string=");
 		printstrn(tcp, ptr_to_kulong(p->string), p->size);
-	} else
-# endif
-	tprintf(", value=%d, value64=%" PRId64, p->value, (int64_t) p->value64);
+	} else {
+		tprintf(", value=%d, value64=%" PRId64, p->value, p->value64);
+	}
 	tprints("}");
 
 	return true;
@@ -848,7 +945,7 @@ print_v4l2_ext_controls(struct tcb *cons
 			tprints("}");
 			return RVAL_IOCTL_DECODED;
 		}
-		tprints(is_get ? ", " : " => ");
+		tprints(is_get ? ", " : "} => {");
 	}
 
 	tprints("controls=");
@@ -869,15 +966,13 @@ print_v4l2_ext_controls(struct tcb *cons
 	/* entering */
 	return 0;
 }
-#endif /* VIDIOC_S_EXT_CTRLS */
 
-#ifdef VIDIOC_ENUM_FRAMESIZES
-# include "xlat/v4l2_framesize_types.h"
+#include "xlat/v4l2_framesize_types.h"
 
 static int
 print_v4l2_frmsizeenum(struct tcb *const tcp, const kernel_ulong_t arg)
 {
-	struct v4l2_frmsizeenum s;
+	struct_v4l2_frmsizeenum s;
 
 	if (entering(tcp)) {
 		tprints(", ");
@@ -909,15 +1004,13 @@ print_v4l2_frmsizeenum(struct tcb *const
 	tprints("}");
 	return RVAL_IOCTL_DECODED;
 }
-#endif /* VIDIOC_ENUM_FRAMESIZES */
 
-#ifdef VIDIOC_ENUM_FRAMEINTERVALS
-# include "xlat/v4l2_frameinterval_types.h"
+#include "xlat/v4l2_frameinterval_types.h"
 
 static int
 print_v4l2_frmivalenum(struct tcb *const tcp, const kernel_ulong_t arg)
 {
-	struct v4l2_frmivalenum f;
+	struct_v4l2_frmivalenum f;
 
 	if (entering(tcp)) {
 		tprints(", ");
@@ -953,9 +1046,7 @@ print_v4l2_frmivalenum(struct tcb *const
 
 	return RVAL_IOCTL_DECODED;
 }
-#endif /* VIDIOC_ENUM_FRAMEINTERVALS */
 
-#ifdef VIDIOC_CREATE_BUFS
 static int
 print_v4l2_create_buffers(struct tcb *const tcp, const kernel_ulong_t arg)
 {
@@ -987,7 +1078,6 @@ print_v4l2_create_buffers(struct tcb *co
 
 	return RVAL_IOCTL_DECODED | RVAL_STR;
 }
-#endif /* VIDIOC_CREATE_BUFS */
 
 MPERS_PRINTER_DECL(int, v4l2_ioctl, struct tcb *const tcp,
 		   const unsigned int code, const kernel_ulong_t arg)
@@ -1072,28 +1162,20 @@ MPERS_PRINTER_DECL(int, v4l2_ioctl, stru
 	case VIDIOC_S_CROP: /* W */
 		return print_v4l2_crop(tcp, arg, code == VIDIOC_G_CROP);
 
-#ifdef VIDIOC_S_EXT_CTRLS
 	case VIDIOC_S_EXT_CTRLS: /* RW */
 	case VIDIOC_TRY_EXT_CTRLS: /* RW */
 	case VIDIOC_G_EXT_CTRLS: /* RW */
 		return print_v4l2_ext_controls(tcp, arg,
 					       code == VIDIOC_G_EXT_CTRLS);
-#endif /* VIDIOC_S_EXT_CTRLS */
 
-#ifdef VIDIOC_ENUM_FRAMESIZES
 	case VIDIOC_ENUM_FRAMESIZES: /* RW */
 		return print_v4l2_frmsizeenum(tcp, arg);
-#endif /* VIDIOC_ENUM_FRAMESIZES */
 
-#ifdef VIDIOC_ENUM_FRAMEINTERVALS
 	case VIDIOC_ENUM_FRAMEINTERVALS: /* RW */
 		return print_v4l2_frmivalenum(tcp, arg);
-#endif /* VIDIOC_ENUM_FRAMEINTERVALS */
 
-#ifdef VIDIOC_CREATE_BUFS
 	case VIDIOC_CREATE_BUFS: /* RW */
 		return print_v4l2_create_buffers(tcp, arg);
-#endif /* VIDIOC_CREATE_BUFS */
 
 	default:
 		return RVAL_DECODED;
diff -pruN 5.5-3/.version 5.9-0ubuntu2/.version
--- 5.5-3/.version	2020-02-06 16:23:59.000000000 +0000
+++ 5.9-0ubuntu2/.version	2020-09-24 09:19:42.000000000 +0000
@@ -1 +1 @@
-5.5
+5.9
diff -pruN 5.5-3/wait.c 5.9-0ubuntu2/wait.c
--- 5.5-3/wait.c	2018-12-17 19:19:23.000000000 +0000
+++ 5.9-0ubuntu2/wait.c	2020-08-25 14:29:30.000000000 +0000
@@ -7,7 +7,7 @@
  * Copyright (c) 2004 Ulrich Drepper <drepper@redhat.com>
  * Copyright (c) 2009-2013 Denys Vlasenko <dvlasenk@redhat.com>
  * Copyright (c) 2014-2015 Dmitry V. Levin <ldv@altlinux.org>
- * Copyright (c) 2014-2018 The strace developers.
+ * Copyright (c) 2014-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -80,14 +80,8 @@ printwaitn(struct tcb *const tcp,
 	   void (*const print_rusage)(struct tcb *, kernel_ulong_t))
 {
 	if (entering(tcp)) {
-		/* On Linux, kernel-side pid_t is typedef'ed to int
-		 * on all arches. Also, glibc-2.8 truncates wait3 and wait4
-		 * pid argument to int on 64bit arches, producing,
-		 * for example, wait4(4294967295, ...) instead of -1
-		 * in strace. We have to use int here, not long.
-		 */
-		int pid = tcp->u_arg[0];
-		tprintf("%d, ", pid);
+		printpid_tgid_pgid(tcp, tcp->u_arg[0]);
+		tprintf(", ");
 	} else {
 		int status;
 
@@ -108,7 +102,7 @@ printwaitn(struct tcb *const tcp,
 				printaddr(tcp->u_arg[3]);
 		}
 	}
-	return 0;
+	return RVAL_TGID;
 }
 
 SYS_FUNC(waitpid)
@@ -116,10 +110,12 @@ SYS_FUNC(waitpid)
 	return printwaitn(tcp, NULL);
 }
 
+#if HAVE_ARCH_TIME32_SYSCALLS || HAVE_ARCH_OLD_TIME64_SYSCALLS
 SYS_FUNC(wait4)
 {
 	return printwaitn(tcp, printrusage);
 }
+#endif
 
 #ifdef ALPHA
 SYS_FUNC(osf_wait4)
@@ -132,10 +128,28 @@ SYS_FUNC(osf_wait4)
 
 SYS_FUNC(waitid)
 {
+	unsigned int idtype = (unsigned int) tcp->u_arg[0];
+	int id = tcp->u_arg[1];
+
 	if (entering(tcp)) {
-		printxval(waitid_types, tcp->u_arg[0], "P_???");
-		int pid = tcp->u_arg[1];
-		tprintf(", %d, ", pid);
+		printxval(waitid_types, idtype, "P_???");
+		tprints(", ");
+		switch (idtype)
+		{
+		case P_PID:
+			printpid(tcp, id, PT_TGID);
+			break;
+		case P_PIDFD:
+			printfd(tcp, id);
+			break;
+		case P_PGID:
+			printpid(tcp, id, PT_PGID);
+			break;
+		default:
+			tprintf("%d", id);
+			break;
+		}
+		tprints(", ");
 	} else {
 		/* siginfo */
 		printsiginfo_at(tcp, tcp->u_arg[2]);
diff -pruN 5.5-3/xgetdents.c 5.9-0ubuntu2/xgetdents.c
--- 5.5-3/xgetdents.c	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xgetdents.c	2020-04-12 00:32:29.000000000 +0000
@@ -0,0 +1,141 @@
+/*
+ * Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
+#include "xgetdents.h"
+#include "kernel_dirent.h"
+
+static void
+decode_dents(struct tcb *const tcp, kernel_ulong_t addr, unsigned int len,
+	     const unsigned int header_size,
+	     const decode_dentry_head_fn decode_dentry_head,
+	     const decode_dentry_tail_fn decode_dentry_tail)
+{
+	union {
+		kernel_dirent_t ent;
+		kernel_dirent64_t ent64;
+	} dent;
+	unsigned int count = 0;
+
+	if (abbrev(tcp))
+		printaddr(addr);
+
+	for (;;) {
+		if (len < header_size) {
+			if (!abbrev(tcp)) {
+				if (!len) {
+					tprints("[");
+					++count;
+				} else {
+					printstr_ex(tcp, addr, len,
+						    QUOTE_FORCE_HEX);
+				}
+			}
+			break;
+		}
+
+		/* len >= header_size after this point.  */
+		if (!tfetch_mem(tcp, addr, header_size, &dent)) {
+			if (!abbrev(tcp)) {
+				if (count) {
+					tprints("...");
+					printaddr_comment(addr);
+				} else {
+					printaddr(addr);
+				}
+			}
+
+			break;
+		}
+
+		if (!abbrev(tcp)) {
+			if (!count)
+				tprints("[");
+		}
+		++count;
+
+		kernel_ulong_t next_addr = 0;
+		unsigned int next_len = 0;
+		unsigned int d_reclen = decode_dentry_head(tcp, &dent);
+
+		if (d_reclen > len) {
+			/* cannot happen? */
+			tprintf_comment("%s%u bytes overflow",
+					(abbrev(tcp) ? "d_reclen " : ""),
+					d_reclen - len);
+			d_reclen = len;
+		} else if (d_reclen < header_size) {
+			/* cannot happen? */
+			tprintf_comment("%s%u bytes underflow",
+					(abbrev(tcp) ? "d_reclen " : ""),
+					header_size - d_reclen);
+			d_reclen = header_size;
+			next_len = len - header_size;
+		} else {
+			next_len = len - d_reclen;
+			if (next_len) {
+				if (addr + d_reclen > addr) {
+					next_addr = addr + d_reclen;
+				} else {
+					/* cannot happen? */
+					tprints_comment("address overflow");
+				}
+			}
+		}
+
+		len = next_len;
+		/* Do not use len inside the loop after this point.  */
+
+		if (!abbrev(tcp)) {
+			int rc = decode_dentry_tail(tcp, addr + header_size,
+						   &dent,
+						   d_reclen - header_size);
+			if (next_addr) {
+				tprints(", ");
+				if (rc < 0) {
+					tprints("...");
+					break;
+				}
+			}
+		}
+
+		if (!next_addr)
+			break;
+		addr = next_addr;
+	}
+
+	if (!abbrev(tcp)) {
+		if (count)
+			tprints("]");
+	} else {
+		tprintf_comment("%u%s entries", count, len ? "+" : "");
+	}
+}
+
+int
+xgetdents(struct tcb *const tcp, const unsigned int header_size,
+	  const decode_dentry_head_fn decode_dentry_head,
+	  const decode_dentry_tail_fn decode_dentry_tail)
+{
+	if (entering(tcp)) {
+		printfd(tcp, tcp->u_arg[0]);
+		tprints(", ");
+		return 0;
+	}
+
+	const unsigned int count = tcp->u_arg[2];
+
+	if (syserror(tcp) || !verbose(tcp) ||
+	    (kernel_ulong_t) tcp->u_rval > count /* kernel gone bananas? */) {
+		printaddr(tcp->u_arg[1]);
+	} else {
+		decode_dents(tcp, tcp->u_arg[1], tcp->u_rval, header_size,
+			     decode_dentry_head, decode_dentry_tail);
+	}
+
+	tprintf(", %u", count);
+	return 0;
+}
diff -pruN 5.5-3/xgetdents.h 5.9-0ubuntu2/xgetdents.h
--- 5.5-3/xgetdents.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xgetdents.h	2020-09-23 16:29:35.000000000 +0000
@@ -0,0 +1,21 @@
+/*
+ * Copyright (c) 2020 Dmitry V. Levin <ldv@altlinux.org>
+ * All rights reserved.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
+ */
+
+#ifndef STRACE_XGETDENTS_H
+# define STRACE_XGETDENTS_H
+
+# include "defs.h"
+
+typedef unsigned int (*decode_dentry_head_fn)(struct tcb *, const void *);
+typedef int (*decode_dentry_tail_fn)(struct tcb *, kernel_ulong_t,
+				     const void *, unsigned int);
+
+extern int
+xgetdents(struct tcb *, unsigned int header_size,
+	  decode_dentry_head_fn, decode_dentry_tail_fn);
+
+#endif /* !STRACE_XGETDENTS_H */
diff -pruN 5.5-3/xlat/access_flags.h 5.9-0ubuntu2/xlat/access_flags.h
--- 5.5-3/xlat/access_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/access_flags.h	1970-01-01 00:00:00.000000000 +0000
@@ -1,44 +0,0 @@
-/* Generated by ./xlat/gen.sh from ./xlat/access_flags.in; do not edit. */
-
-#include "gcc_compat.h"
-#include "static_assert.h"
-
-
-#ifndef XLAT_MACROS_ONLY
-
-# ifdef IN_MPERS
-
-#  error static const struct xlat access_flags in mpers mode
-
-# else
-
-static const struct xlat_data access_flags_xdata[] = {
-#if defined(F_OK) || (defined(HAVE_DECL_F_OK) && HAVE_DECL_F_OK)
-  XLAT(F_OK),
-#endif
-#if defined(R_OK) || (defined(HAVE_DECL_R_OK) && HAVE_DECL_R_OK)
-  XLAT(R_OK),
-#endif
-#if defined(W_OK) || (defined(HAVE_DECL_W_OK) && HAVE_DECL_W_OK)
-  XLAT(W_OK),
-#endif
-#if defined(X_OK) || (defined(HAVE_DECL_X_OK) && HAVE_DECL_X_OK)
-  XLAT(X_OK),
-#endif
-#if defined(EFF_ONLY_OK) || (defined(HAVE_DECL_EFF_ONLY_OK) && HAVE_DECL_EFF_ONLY_OK)
-  XLAT(EFF_ONLY_OK),
-#endif
-#if defined(EX_OK) || (defined(HAVE_DECL_EX_OK) && HAVE_DECL_EX_OK)
-  XLAT(EX_OK),
-#endif
-};
-static
-const struct xlat access_flags[1] = { {
- .data = access_flags_xdata,
- .size = ARRAY_SIZE(access_flags_xdata),
- .type = XT_NORMAL,
-} };
-
-# endif /* !IN_MPERS */
-
-#endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/access_flags.in 5.9-0ubuntu2/xlat/access_flags.in
--- 5.5-3/xlat/access_flags.in	2014-05-30 21:40:03.000000000 +0000
+++ 5.9-0ubuntu2/xlat/access_flags.in	1970-01-01 00:00:00.000000000 +0000
@@ -1,6 +0,0 @@
-F_OK
-R_OK
-W_OK
-X_OK
-EFF_ONLY_OK
-EX_OK
diff -pruN 5.5-3/xlat/access_modes.h 5.9-0ubuntu2/xlat/access_modes.h
--- 5.5-3/xlat/access_modes.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/access_modes.h	2020-09-24 09:18:43.000000000 +0000
@@ -0,0 +1,102 @@
+/* Generated by ./xlat/gen.sh from ./xlat/access_modes.in; do not edit. */
+
+#include "gcc_compat.h"
+#include "static_assert.h"
+
+#if defined(F_OK) || (defined(HAVE_DECL_F_OK) && HAVE_DECL_F_OK)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((F_OK) == (0), "F_OK != 0");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define F_OK 0
+#endif
+#if defined(R_OK) || (defined(HAVE_DECL_R_OK) && HAVE_DECL_R_OK)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((R_OK) == (4), "R_OK != 4");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define R_OK 4
+#endif
+#if defined(W_OK) || (defined(HAVE_DECL_W_OK) && HAVE_DECL_W_OK)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((W_OK) == (2), "W_OK != 2");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define W_OK 2
+#endif
+#if defined(X_OK) || (defined(HAVE_DECL_X_OK) && HAVE_DECL_X_OK)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((X_OK) == (1), "X_OK != 1");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define X_OK 1
+#endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+#  error static const struct xlat access_modes in mpers mode
+
+# else
+
+static const struct xlat_data access_modes_xdata[] = {
+ XLAT(F_OK),
+ #define XLAT_VAL_0 ((unsigned) (F_OK))
+ #define XLAT_STR_0 STRINGIFY(F_OK)
+ XLAT(R_OK),
+ #define XLAT_VAL_1 ((unsigned) (R_OK))
+ #define XLAT_STR_1 STRINGIFY(R_OK)
+ XLAT(W_OK),
+ #define XLAT_VAL_2 ((unsigned) (W_OK))
+ #define XLAT_STR_2 STRINGIFY(W_OK)
+ XLAT(X_OK),
+ #define XLAT_VAL_3 ((unsigned) (X_OK))
+ #define XLAT_STR_3 STRINGIFY(X_OK)
+};
+static
+const struct xlat access_modes[1] = { {
+ .data = access_modes_xdata,
+ .size = ARRAY_SIZE(access_modes_xdata),
+ .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
+} };
+
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+# endif /* !IN_MPERS */
+
+#endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/access_modes.in 5.9-0ubuntu2/xlat/access_modes.in
--- 5.5-3/xlat/access_modes.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/access_modes.in	2020-07-04 08:00:00.000000000 +0000
@@ -0,0 +1,4 @@
+F_OK 0
+R_OK 4
+W_OK 2
+X_OK 1
diff -pruN 5.5-3/xlat/addrfams.h 5.9-0ubuntu2/xlat/addrfams.h
--- 5.5-3/xlat/addrfams.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/addrfams.h	2020-09-24 09:18:44.000000000 +0000
@@ -325,57 +325,511 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data addrfams_xdata[] = {
  [AF_UNSPEC] = XLAT(AF_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (AF_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(AF_UNSPEC)
  [AF_UNIX] = XLAT(AF_UNIX),
+ #define XLAT_VAL_1 ((unsigned) (AF_UNIX))
+ #define XLAT_STR_1 STRINGIFY(AF_UNIX)
  [AF_INET] = XLAT(AF_INET),
+ #define XLAT_VAL_2 ((unsigned) (AF_INET))
+ #define XLAT_STR_2 STRINGIFY(AF_INET)
  [AF_AX25] = XLAT(AF_AX25),
+ #define XLAT_VAL_3 ((unsigned) (AF_AX25))
+ #define XLAT_STR_3 STRINGIFY(AF_AX25)
  [AF_IPX] = XLAT(AF_IPX),
+ #define XLAT_VAL_4 ((unsigned) (AF_IPX))
+ #define XLAT_STR_4 STRINGIFY(AF_IPX)
  [AF_APPLETALK] = XLAT(AF_APPLETALK),
+ #define XLAT_VAL_5 ((unsigned) (AF_APPLETALK))
+ #define XLAT_STR_5 STRINGIFY(AF_APPLETALK)
  [AF_NETROM] = XLAT(AF_NETROM),
+ #define XLAT_VAL_6 ((unsigned) (AF_NETROM))
+ #define XLAT_STR_6 STRINGIFY(AF_NETROM)
  [AF_BRIDGE] = XLAT(AF_BRIDGE),
+ #define XLAT_VAL_7 ((unsigned) (AF_BRIDGE))
+ #define XLAT_STR_7 STRINGIFY(AF_BRIDGE)
  [AF_ATMPVC] = XLAT(AF_ATMPVC),
+ #define XLAT_VAL_8 ((unsigned) (AF_ATMPVC))
+ #define XLAT_STR_8 STRINGIFY(AF_ATMPVC)
  [AF_X25] = XLAT(AF_X25),
+ #define XLAT_VAL_9 ((unsigned) (AF_X25))
+ #define XLAT_STR_9 STRINGIFY(AF_X25)
  [AF_INET6] = XLAT(AF_INET6),
+ #define XLAT_VAL_10 ((unsigned) (AF_INET6))
+ #define XLAT_STR_10 STRINGIFY(AF_INET6)
  [AF_ROSE] = XLAT(AF_ROSE),
+ #define XLAT_VAL_11 ((unsigned) (AF_ROSE))
+ #define XLAT_STR_11 STRINGIFY(AF_ROSE)
  [AF_DECnet] = XLAT(AF_DECnet),
+ #define XLAT_VAL_12 ((unsigned) (AF_DECnet))
+ #define XLAT_STR_12 STRINGIFY(AF_DECnet)
  [AF_NETBEUI] = XLAT(AF_NETBEUI),
+ #define XLAT_VAL_13 ((unsigned) (AF_NETBEUI))
+ #define XLAT_STR_13 STRINGIFY(AF_NETBEUI)
  [AF_SECURITY] = XLAT(AF_SECURITY),
+ #define XLAT_VAL_14 ((unsigned) (AF_SECURITY))
+ #define XLAT_STR_14 STRINGIFY(AF_SECURITY)
  [AF_KEY] = XLAT(AF_KEY),
+ #define XLAT_VAL_15 ((unsigned) (AF_KEY))
+ #define XLAT_STR_15 STRINGIFY(AF_KEY)
  [AF_NETLINK] = XLAT(AF_NETLINK),
+ #define XLAT_VAL_16 ((unsigned) (AF_NETLINK))
+ #define XLAT_STR_16 STRINGIFY(AF_NETLINK)
  [AF_PACKET] = XLAT(AF_PACKET),
+ #define XLAT_VAL_17 ((unsigned) (AF_PACKET))
+ #define XLAT_STR_17 STRINGIFY(AF_PACKET)
  [AF_ASH] = XLAT(AF_ASH),
+ #define XLAT_VAL_18 ((unsigned) (AF_ASH))
+ #define XLAT_STR_18 STRINGIFY(AF_ASH)
  [AF_ECONET] = XLAT(AF_ECONET),
+ #define XLAT_VAL_19 ((unsigned) (AF_ECONET))
+ #define XLAT_STR_19 STRINGIFY(AF_ECONET)
  [AF_ATMSVC] = XLAT(AF_ATMSVC),
+ #define XLAT_VAL_20 ((unsigned) (AF_ATMSVC))
+ #define XLAT_STR_20 STRINGIFY(AF_ATMSVC)
  [AF_RDS] = XLAT(AF_RDS),
+ #define XLAT_VAL_21 ((unsigned) (AF_RDS))
+ #define XLAT_STR_21 STRINGIFY(AF_RDS)
  [AF_SNA] = XLAT(AF_SNA),
+ #define XLAT_VAL_22 ((unsigned) (AF_SNA))
+ #define XLAT_STR_22 STRINGIFY(AF_SNA)
  [AF_IRDA] = XLAT(AF_IRDA),
+ #define XLAT_VAL_23 ((unsigned) (AF_IRDA))
+ #define XLAT_STR_23 STRINGIFY(AF_IRDA)
  [AF_PPPOX] = XLAT(AF_PPPOX),
+ #define XLAT_VAL_24 ((unsigned) (AF_PPPOX))
+ #define XLAT_STR_24 STRINGIFY(AF_PPPOX)
  [AF_WANPIPE] = XLAT(AF_WANPIPE),
+ #define XLAT_VAL_25 ((unsigned) (AF_WANPIPE))
+ #define XLAT_STR_25 STRINGIFY(AF_WANPIPE)
  [AF_LLC] = XLAT(AF_LLC),
+ #define XLAT_VAL_26 ((unsigned) (AF_LLC))
+ #define XLAT_STR_26 STRINGIFY(AF_LLC)
  [AF_IB] = XLAT(AF_IB),
+ #define XLAT_VAL_27 ((unsigned) (AF_IB))
+ #define XLAT_STR_27 STRINGIFY(AF_IB)
  [AF_MPLS] = XLAT(AF_MPLS),
+ #define XLAT_VAL_28 ((unsigned) (AF_MPLS))
+ #define XLAT_STR_28 STRINGIFY(AF_MPLS)
  [AF_CAN] = XLAT(AF_CAN),
+ #define XLAT_VAL_29 ((unsigned) (AF_CAN))
+ #define XLAT_STR_29 STRINGIFY(AF_CAN)
  [AF_TIPC] = XLAT(AF_TIPC),
+ #define XLAT_VAL_30 ((unsigned) (AF_TIPC))
+ #define XLAT_STR_30 STRINGIFY(AF_TIPC)
  [AF_BLUETOOTH] = XLAT(AF_BLUETOOTH),
+ #define XLAT_VAL_31 ((unsigned) (AF_BLUETOOTH))
+ #define XLAT_STR_31 STRINGIFY(AF_BLUETOOTH)
  [AF_IUCV] = XLAT(AF_IUCV),
+ #define XLAT_VAL_32 ((unsigned) (AF_IUCV))
+ #define XLAT_STR_32 STRINGIFY(AF_IUCV)
  [AF_RXRPC] = XLAT(AF_RXRPC),
+ #define XLAT_VAL_33 ((unsigned) (AF_RXRPC))
+ #define XLAT_STR_33 STRINGIFY(AF_RXRPC)
  [AF_ISDN] = XLAT(AF_ISDN),
+ #define XLAT_VAL_34 ((unsigned) (AF_ISDN))
+ #define XLAT_STR_34 STRINGIFY(AF_ISDN)
  [AF_PHONET] = XLAT(AF_PHONET),
+ #define XLAT_VAL_35 ((unsigned) (AF_PHONET))
+ #define XLAT_STR_35 STRINGIFY(AF_PHONET)
  [AF_IEEE802154] = XLAT(AF_IEEE802154),
+ #define XLAT_VAL_36 ((unsigned) (AF_IEEE802154))
+ #define XLAT_STR_36 STRINGIFY(AF_IEEE802154)
  [AF_CAIF] = XLAT(AF_CAIF),
+ #define XLAT_VAL_37 ((unsigned) (AF_CAIF))
+ #define XLAT_STR_37 STRINGIFY(AF_CAIF)
  [AF_ALG] = XLAT(AF_ALG),
+ #define XLAT_VAL_38 ((unsigned) (AF_ALG))
+ #define XLAT_STR_38 STRINGIFY(AF_ALG)
  [AF_NFC] = XLAT(AF_NFC),
+ #define XLAT_VAL_39 ((unsigned) (AF_NFC))
+ #define XLAT_STR_39 STRINGIFY(AF_NFC)
  [AF_VSOCK] = XLAT(AF_VSOCK),
+ #define XLAT_VAL_40 ((unsigned) (AF_VSOCK))
+ #define XLAT_STR_40 STRINGIFY(AF_VSOCK)
  [AF_KCM] = XLAT(AF_KCM),
+ #define XLAT_VAL_41 ((unsigned) (AF_KCM))
+ #define XLAT_STR_41 STRINGIFY(AF_KCM)
  [AF_QIPCRTR] = XLAT(AF_QIPCRTR),
+ #define XLAT_VAL_42 ((unsigned) (AF_QIPCRTR))
+ #define XLAT_STR_42 STRINGIFY(AF_QIPCRTR)
  [AF_SMC] = XLAT(AF_SMC),
+ #define XLAT_VAL_43 ((unsigned) (AF_SMC))
+ #define XLAT_STR_43 STRINGIFY(AF_SMC)
  [AF_XDP] = XLAT(AF_XDP),
+ #define XLAT_VAL_44 ((unsigned) (AF_XDP))
+ #define XLAT_STR_44 STRINGIFY(AF_XDP)
 };
 const struct xlat addrfams[1] = { {
  .data = addrfams_xdata,
  .size = ARRAY_SIZE(addrfams_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/adjtimex_modes.h 5.9-0ubuntu2/xlat/adjtimex_modes.h
--- 5.5-3/xlat/adjtimex_modes.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/adjtimex_modes.h	2020-09-24 09:18:44.000000000 +0000
@@ -105,26 +105,160 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data adjtimex_modes_xdata[] = {
  XLAT(ADJ_OFFSET_SS_READ),
+ #define XLAT_VAL_0 ((unsigned) (ADJ_OFFSET_SS_READ))
+ #define XLAT_STR_0 STRINGIFY(ADJ_OFFSET_SS_READ)
  XLAT(ADJ_OFFSET_SINGLESHOT),
+ #define XLAT_VAL_1 ((unsigned) (ADJ_OFFSET_SINGLESHOT))
+ #define XLAT_STR_1 STRINGIFY(ADJ_OFFSET_SINGLESHOT)
  XLAT(ADJ_OFFSET),
+ #define XLAT_VAL_2 ((unsigned) (ADJ_OFFSET))
+ #define XLAT_STR_2 STRINGIFY(ADJ_OFFSET)
  XLAT(ADJ_FREQUENCY),
+ #define XLAT_VAL_3 ((unsigned) (ADJ_FREQUENCY))
+ #define XLAT_STR_3 STRINGIFY(ADJ_FREQUENCY)
  XLAT(ADJ_MAXERROR),
+ #define XLAT_VAL_4 ((unsigned) (ADJ_MAXERROR))
+ #define XLAT_STR_4 STRINGIFY(ADJ_MAXERROR)
  XLAT(ADJ_ESTERROR),
+ #define XLAT_VAL_5 ((unsigned) (ADJ_ESTERROR))
+ #define XLAT_STR_5 STRINGIFY(ADJ_ESTERROR)
  XLAT(ADJ_STATUS),
+ #define XLAT_VAL_6 ((unsigned) (ADJ_STATUS))
+ #define XLAT_STR_6 STRINGIFY(ADJ_STATUS)
  XLAT(ADJ_TIMECONST),
+ #define XLAT_VAL_7 ((unsigned) (ADJ_TIMECONST))
+ #define XLAT_STR_7 STRINGIFY(ADJ_TIMECONST)
  XLAT(ADJ_TAI),
+ #define XLAT_VAL_8 ((unsigned) (ADJ_TAI))
+ #define XLAT_STR_8 STRINGIFY(ADJ_TAI)
  XLAT(ADJ_SETOFFSET),
+ #define XLAT_VAL_9 ((unsigned) (ADJ_SETOFFSET))
+ #define XLAT_STR_9 STRINGIFY(ADJ_SETOFFSET)
  XLAT(ADJ_MICRO),
+ #define XLAT_VAL_10 ((unsigned) (ADJ_MICRO))
+ #define XLAT_STR_10 STRINGIFY(ADJ_MICRO)
  XLAT(ADJ_NANO),
+ #define XLAT_VAL_11 ((unsigned) (ADJ_NANO))
+ #define XLAT_STR_11 STRINGIFY(ADJ_NANO)
  XLAT(ADJ_TICK),
+ #define XLAT_VAL_12 ((unsigned) (ADJ_TICK))
+ #define XLAT_STR_12 STRINGIFY(ADJ_TICK)
 };
 static
 const struct xlat adjtimex_modes[1] = { {
  .data = adjtimex_modes_xdata,
  .size = ARRAY_SIZE(adjtimex_modes_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/adjtimex_state.h 5.9-0ubuntu2/xlat/adjtimex_state.h
--- 5.5-3/xlat/adjtimex_state.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/adjtimex_state.h	2020-09-24 09:18:44.000000000 +0000
@@ -56,19 +56,83 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data adjtimex_state_xdata[] = {
  [TIME_OK] = XLAT(TIME_OK),
+ #define XLAT_VAL_0 ((unsigned) (TIME_OK))
+ #define XLAT_STR_0 STRINGIFY(TIME_OK)
  [TIME_INS] = XLAT(TIME_INS),
+ #define XLAT_VAL_1 ((unsigned) (TIME_INS))
+ #define XLAT_STR_1 STRINGIFY(TIME_INS)
  [TIME_DEL] = XLAT(TIME_DEL),
+ #define XLAT_VAL_2 ((unsigned) (TIME_DEL))
+ #define XLAT_STR_2 STRINGIFY(TIME_DEL)
  [TIME_OOP] = XLAT(TIME_OOP),
+ #define XLAT_VAL_3 ((unsigned) (TIME_OOP))
+ #define XLAT_STR_3 STRINGIFY(TIME_OOP)
  [TIME_WAIT] = XLAT(TIME_WAIT),
+ #define XLAT_VAL_4 ((unsigned) (TIME_WAIT))
+ #define XLAT_STR_4 STRINGIFY(TIME_WAIT)
  [TIME_ERROR] = XLAT(TIME_ERROR),
+ #define XLAT_VAL_5 ((unsigned) (TIME_ERROR))
+ #define XLAT_STR_5 STRINGIFY(TIME_ERROR)
 };
 static
 const struct xlat adjtimex_state[1] = { {
  .data = adjtimex_state_xdata,
  .size = ARRAY_SIZE(adjtimex_state_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/adjtimex_status.h 5.9-0ubuntu2/xlat/adjtimex_status.h
--- 5.5-3/xlat/adjtimex_status.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/adjtimex_status.h	2020-09-24 09:18:44.000000000 +0000
@@ -126,29 +126,193 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data adjtimex_status_xdata[] = {
  XLAT(STA_PLL),
+ #define XLAT_VAL_0 ((unsigned) (STA_PLL))
+ #define XLAT_STR_0 STRINGIFY(STA_PLL)
  XLAT(STA_PPSFREQ),
+ #define XLAT_VAL_1 ((unsigned) (STA_PPSFREQ))
+ #define XLAT_STR_1 STRINGIFY(STA_PPSFREQ)
  XLAT(STA_PPSTIME),
+ #define XLAT_VAL_2 ((unsigned) (STA_PPSTIME))
+ #define XLAT_STR_2 STRINGIFY(STA_PPSTIME)
  XLAT(STA_FLL),
+ #define XLAT_VAL_3 ((unsigned) (STA_FLL))
+ #define XLAT_STR_3 STRINGIFY(STA_FLL)
  XLAT(STA_INS),
+ #define XLAT_VAL_4 ((unsigned) (STA_INS))
+ #define XLAT_STR_4 STRINGIFY(STA_INS)
  XLAT(STA_DEL),
+ #define XLAT_VAL_5 ((unsigned) (STA_DEL))
+ #define XLAT_STR_5 STRINGIFY(STA_DEL)
  XLAT(STA_UNSYNC),
+ #define XLAT_VAL_6 ((unsigned) (STA_UNSYNC))
+ #define XLAT_STR_6 STRINGIFY(STA_UNSYNC)
  XLAT(STA_FREQHOLD),
+ #define XLAT_VAL_7 ((unsigned) (STA_FREQHOLD))
+ #define XLAT_STR_7 STRINGIFY(STA_FREQHOLD)
  XLAT(STA_PPSSIGNAL),
+ #define XLAT_VAL_8 ((unsigned) (STA_PPSSIGNAL))
+ #define XLAT_STR_8 STRINGIFY(STA_PPSSIGNAL)
  XLAT(STA_PPSJITTER),
+ #define XLAT_VAL_9 ((unsigned) (STA_PPSJITTER))
+ #define XLAT_STR_9 STRINGIFY(STA_PPSJITTER)
  XLAT(STA_PPSWANDER),
+ #define XLAT_VAL_10 ((unsigned) (STA_PPSWANDER))
+ #define XLAT_STR_10 STRINGIFY(STA_PPSWANDER)
  XLAT(STA_PPSERROR),
+ #define XLAT_VAL_11 ((unsigned) (STA_PPSERROR))
+ #define XLAT_STR_11 STRINGIFY(STA_PPSERROR)
  XLAT(STA_CLOCKERR),
+ #define XLAT_VAL_12 ((unsigned) (STA_CLOCKERR))
+ #define XLAT_STR_12 STRINGIFY(STA_CLOCKERR)
  XLAT(STA_NANO),
+ #define XLAT_VAL_13 ((unsigned) (STA_NANO))
+ #define XLAT_STR_13 STRINGIFY(STA_NANO)
  XLAT(STA_MODE),
+ #define XLAT_VAL_14 ((unsigned) (STA_MODE))
+ #define XLAT_STR_14 STRINGIFY(STA_MODE)
  XLAT(STA_CLK),
+ #define XLAT_VAL_15 ((unsigned) (STA_CLK))
+ #define XLAT_STR_15 STRINGIFY(STA_CLK)
 };
 static
 const struct xlat adjtimex_status[1] = { {
  .data = adjtimex_status_xdata,
  .size = ARRAY_SIZE(adjtimex_status_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/advise.h 5.9-0ubuntu2/xlat/advise.h
--- 5.5-3/xlat/advise.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/advise.h	2020-09-24 09:18:44.000000000 +0000
@@ -73,15 +73,31 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data advise_xdata[] = {
  XLAT(POSIX_FADV_NORMAL),
+ #define XLAT_VAL_0 ((unsigned) (POSIX_FADV_NORMAL))
+ #define XLAT_STR_0 STRINGIFY(POSIX_FADV_NORMAL)
  XLAT(POSIX_FADV_RANDOM),
+ #define XLAT_VAL_1 ((unsigned) (POSIX_FADV_RANDOM))
+ #define XLAT_STR_1 STRINGIFY(POSIX_FADV_RANDOM)
  XLAT(POSIX_FADV_SEQUENTIAL),
+ #define XLAT_VAL_2 ((unsigned) (POSIX_FADV_SEQUENTIAL))
+ #define XLAT_STR_2 STRINGIFY(POSIX_FADV_SEQUENTIAL)
  XLAT(POSIX_FADV_WILLNEED),
+ #define XLAT_VAL_3 ((unsigned) (POSIX_FADV_WILLNEED))
+ #define XLAT_STR_3 STRINGIFY(POSIX_FADV_WILLNEED)
 #if defined __s390x__
  XLAT(POSIX_FADV_DONTNEED),
+ #define XLAT_VAL_4 ((unsigned) (POSIX_FADV_DONTNEED))
+ #define XLAT_STR_4 STRINGIFY(POSIX_FADV_DONTNEED)
  XLAT(POSIX_FADV_NOREUSE),
+ #define XLAT_VAL_5 ((unsigned) (POSIX_FADV_NOREUSE))
+ #define XLAT_STR_5 STRINGIFY(POSIX_FADV_NOREUSE)
 #else
  XLAT(POSIX_FADV_DONTNEED),
+ #define XLAT_VAL_6 ((unsigned) (POSIX_FADV_DONTNEED))
+ #define XLAT_STR_6 STRINGIFY(POSIX_FADV_DONTNEED)
  XLAT(POSIX_FADV_NOREUSE),
+ #define XLAT_VAL_7 ((unsigned) (POSIX_FADV_NOREUSE))
+ #define XLAT_STR_7 STRINGIFY(POSIX_FADV_NOREUSE)
 #endif
 };
 static
@@ -89,8 +105,76 @@ const struct xlat advise[1] = { {
  .data = advise_xdata,
  .size = ARRAY_SIZE(advise_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/af_packet_types.h 5.9-0ubuntu2/xlat/af_packet_types.h
--- 5.5-3/xlat/af_packet_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/af_packet_types.h	2020-09-24 09:18:44.000000000 +0000
@@ -70,21 +70,105 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data af_packet_types_xdata[] = {
  [PACKET_HOST] = XLAT(PACKET_HOST),
+ #define XLAT_VAL_0 ((unsigned) (PACKET_HOST))
+ #define XLAT_STR_0 STRINGIFY(PACKET_HOST)
  [PACKET_BROADCAST] = XLAT(PACKET_BROADCAST),
+ #define XLAT_VAL_1 ((unsigned) (PACKET_BROADCAST))
+ #define XLAT_STR_1 STRINGIFY(PACKET_BROADCAST)
  [PACKET_MULTICAST] = XLAT(PACKET_MULTICAST),
+ #define XLAT_VAL_2 ((unsigned) (PACKET_MULTICAST))
+ #define XLAT_STR_2 STRINGIFY(PACKET_MULTICAST)
  [PACKET_OTHERHOST] = XLAT(PACKET_OTHERHOST),
+ #define XLAT_VAL_3 ((unsigned) (PACKET_OTHERHOST))
+ #define XLAT_STR_3 STRINGIFY(PACKET_OTHERHOST)
  [PACKET_OUTGOING] = XLAT(PACKET_OUTGOING),
+ #define XLAT_VAL_4 ((unsigned) (PACKET_OUTGOING))
+ #define XLAT_STR_4 STRINGIFY(PACKET_OUTGOING)
  [PACKET_LOOPBACK] = XLAT(PACKET_LOOPBACK),
+ #define XLAT_VAL_5 ((unsigned) (PACKET_LOOPBACK))
+ #define XLAT_STR_5 STRINGIFY(PACKET_LOOPBACK)
  [PACKET_USER] = XLAT(PACKET_USER),
+ #define XLAT_VAL_6 ((unsigned) (PACKET_USER))
+ #define XLAT_STR_6 STRINGIFY(PACKET_USER)
  [PACKET_KERNEL] = XLAT(PACKET_KERNEL),
+ #define XLAT_VAL_7 ((unsigned) (PACKET_KERNEL))
+ #define XLAT_STR_7 STRINGIFY(PACKET_KERNEL)
 };
 static
 const struct xlat af_packet_types[1] = { {
  .data = af_packet_types_xdata,
  .size = ARRAY_SIZE(af_packet_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/af_packet_versions.h 5.9-0ubuntu2/xlat/af_packet_versions.h
--- 5.5-3/xlat/af_packet_versions.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/af_packet_versions.h	2020-09-24 09:18:43.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data af_packet_versions_xdata[] = {
  [TPACKET_V1] = XLAT(TPACKET_V1),
+ #define XLAT_VAL_0 ((unsigned) (TPACKET_V1))
+ #define XLAT_STR_0 STRINGIFY(TPACKET_V1)
  [TPACKET_V2] = XLAT(TPACKET_V2),
+ #define XLAT_VAL_1 ((unsigned) (TPACKET_V2))
+ #define XLAT_STR_1 STRINGIFY(TPACKET_V2)
  [TPACKET_V3] = XLAT(TPACKET_V3),
+ #define XLAT_VAL_2 ((unsigned) (TPACKET_V3))
+ #define XLAT_STR_2 STRINGIFY(TPACKET_V3)
 };
 static
 const struct xlat af_packet_versions[1] = { {
  .data = af_packet_versions_xdata,
  .size = ARRAY_SIZE(af_packet_versions_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/aio_cmds.h 5.9-0ubuntu2/xlat/aio_cmds.h
--- 5.5-3/xlat/aio_cmds.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/aio_cmds.h	2020-09-24 09:18:44.000000000 +0000
@@ -77,22 +77,116 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data aio_cmds_xdata[] = {
  [IOCB_CMD_PREAD] = XLAT(IOCB_CMD_PREAD),
+ #define XLAT_VAL_0 ((unsigned) (IOCB_CMD_PREAD))
+ #define XLAT_STR_0 STRINGIFY(IOCB_CMD_PREAD)
  [IOCB_CMD_PWRITE] = XLAT(IOCB_CMD_PWRITE),
+ #define XLAT_VAL_1 ((unsigned) (IOCB_CMD_PWRITE))
+ #define XLAT_STR_1 STRINGIFY(IOCB_CMD_PWRITE)
  [IOCB_CMD_FSYNC] = XLAT(IOCB_CMD_FSYNC),
+ #define XLAT_VAL_2 ((unsigned) (IOCB_CMD_FSYNC))
+ #define XLAT_STR_2 STRINGIFY(IOCB_CMD_FSYNC)
  [IOCB_CMD_FDSYNC] = XLAT(IOCB_CMD_FDSYNC),
+ #define XLAT_VAL_3 ((unsigned) (IOCB_CMD_FDSYNC))
+ #define XLAT_STR_3 STRINGIFY(IOCB_CMD_FDSYNC)
  [IOCB_CMD_PREADX] = XLAT(IOCB_CMD_PREADX),
+ #define XLAT_VAL_4 ((unsigned) (IOCB_CMD_PREADX))
+ #define XLAT_STR_4 STRINGIFY(IOCB_CMD_PREADX)
  [IOCB_CMD_POLL] = XLAT(IOCB_CMD_POLL),
+ #define XLAT_VAL_5 ((unsigned) (IOCB_CMD_POLL))
+ #define XLAT_STR_5 STRINGIFY(IOCB_CMD_POLL)
  [IOCB_CMD_NOOP] = XLAT(IOCB_CMD_NOOP),
+ #define XLAT_VAL_6 ((unsigned) (IOCB_CMD_NOOP))
+ #define XLAT_STR_6 STRINGIFY(IOCB_CMD_NOOP)
  [IOCB_CMD_PREADV] = XLAT(IOCB_CMD_PREADV),
+ #define XLAT_VAL_7 ((unsigned) (IOCB_CMD_PREADV))
+ #define XLAT_STR_7 STRINGIFY(IOCB_CMD_PREADV)
  [IOCB_CMD_PWRITEV] = XLAT(IOCB_CMD_PWRITEV),
+ #define XLAT_VAL_8 ((unsigned) (IOCB_CMD_PWRITEV))
+ #define XLAT_STR_8 STRINGIFY(IOCB_CMD_PWRITEV)
 };
 static
 const struct xlat aio_cmds[1] = { {
  .data = aio_cmds_xdata,
  .size = ARRAY_SIZE(aio_cmds_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/aio_iocb_flags.h 5.9-0ubuntu2/xlat/aio_iocb_flags.h
--- 5.5-3/xlat/aio_iocb_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/aio_iocb_flags.h	2020-09-24 09:18:43.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data aio_iocb_flags_xdata[] = {
  XLAT(IOCB_FLAG_RESFD),
+ #define XLAT_VAL_0 ((unsigned) (IOCB_FLAG_RESFD))
+ #define XLAT_STR_0 STRINGIFY(IOCB_FLAG_RESFD)
  XLAT(IOCB_FLAG_IOPRIO),
+ #define XLAT_VAL_1 ((unsigned) (IOCB_FLAG_IOPRIO))
+ #define XLAT_STR_1 STRINGIFY(IOCB_FLAG_IOPRIO)
 };
 static
 const struct xlat aio_iocb_flags[1] = { {
  .data = aio_iocb_flags_xdata,
  .size = ARRAY_SIZE(aio_iocb_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/archvals.h 5.9-0ubuntu2/xlat/archvals.h
--- 5.5-3/xlat/archvals.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/archvals.h	2020-09-24 09:18:44.000000000 +0000
@@ -77,22 +77,116 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data archvals_xdata[] = {
  XLAT(ARCH_SET_GS),
+ #define XLAT_VAL_0 ((unsigned) (ARCH_SET_GS))
+ #define XLAT_STR_0 STRINGIFY(ARCH_SET_GS)
  XLAT(ARCH_SET_FS),
+ #define XLAT_VAL_1 ((unsigned) (ARCH_SET_FS))
+ #define XLAT_STR_1 STRINGIFY(ARCH_SET_FS)
  XLAT(ARCH_GET_FS),
+ #define XLAT_VAL_2 ((unsigned) (ARCH_GET_FS))
+ #define XLAT_STR_2 STRINGIFY(ARCH_GET_FS)
  XLAT(ARCH_GET_GS),
+ #define XLAT_VAL_3 ((unsigned) (ARCH_GET_GS))
+ #define XLAT_STR_3 STRINGIFY(ARCH_GET_GS)
  XLAT(ARCH_GET_CPUID),
+ #define XLAT_VAL_4 ((unsigned) (ARCH_GET_CPUID))
+ #define XLAT_STR_4 STRINGIFY(ARCH_GET_CPUID)
  XLAT(ARCH_SET_CPUID),
+ #define XLAT_VAL_5 ((unsigned) (ARCH_SET_CPUID))
+ #define XLAT_STR_5 STRINGIFY(ARCH_SET_CPUID)
  XLAT(ARCH_MAP_VDSO_X32),
+ #define XLAT_VAL_6 ((unsigned) (ARCH_MAP_VDSO_X32))
+ #define XLAT_STR_6 STRINGIFY(ARCH_MAP_VDSO_X32)
  XLAT(ARCH_MAP_VDSO_32),
+ #define XLAT_VAL_7 ((unsigned) (ARCH_MAP_VDSO_32))
+ #define XLAT_STR_7 STRINGIFY(ARCH_MAP_VDSO_32)
  XLAT(ARCH_MAP_VDSO_64),
+ #define XLAT_VAL_8 ((unsigned) (ARCH_MAP_VDSO_64))
+ #define XLAT_STR_8 STRINGIFY(ARCH_MAP_VDSO_64)
 };
 static
 const struct xlat archvals[1] = { {
  .data = archvals_xdata,
  .size = ARRAY_SIZE(archvals_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/arp_hardware_types.h 5.9-0ubuntu2/xlat/arp_hardware_types.h
--- 5.5-3/xlat/arp_hardware_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/arp_hardware_types.h	2020-09-24 09:18:45.000000000 +0000
@@ -472,78 +472,742 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data arp_hardware_types_xdata[] = {
  XLAT(ARPHRD_NETROM),
+ #define XLAT_VAL_0 ((unsigned) (ARPHRD_NETROM))
+ #define XLAT_STR_0 STRINGIFY(ARPHRD_NETROM)
  XLAT(ARPHRD_ETHER),
+ #define XLAT_VAL_1 ((unsigned) (ARPHRD_ETHER))
+ #define XLAT_STR_1 STRINGIFY(ARPHRD_ETHER)
  XLAT(ARPHRD_EETHER),
+ #define XLAT_VAL_2 ((unsigned) (ARPHRD_EETHER))
+ #define XLAT_STR_2 STRINGIFY(ARPHRD_EETHER)
  XLAT(ARPHRD_AX25),
+ #define XLAT_VAL_3 ((unsigned) (ARPHRD_AX25))
+ #define XLAT_STR_3 STRINGIFY(ARPHRD_AX25)
  XLAT(ARPHRD_PRONET),
+ #define XLAT_VAL_4 ((unsigned) (ARPHRD_PRONET))
+ #define XLAT_STR_4 STRINGIFY(ARPHRD_PRONET)
  XLAT(ARPHRD_CHAOS),
+ #define XLAT_VAL_5 ((unsigned) (ARPHRD_CHAOS))
+ #define XLAT_STR_5 STRINGIFY(ARPHRD_CHAOS)
  XLAT(ARPHRD_IEEE802),
+ #define XLAT_VAL_6 ((unsigned) (ARPHRD_IEEE802))
+ #define XLAT_STR_6 STRINGIFY(ARPHRD_IEEE802)
  XLAT(ARPHRD_ARCNET),
+ #define XLAT_VAL_7 ((unsigned) (ARPHRD_ARCNET))
+ #define XLAT_STR_7 STRINGIFY(ARPHRD_ARCNET)
  XLAT(ARPHRD_APPLETLK),
+ #define XLAT_VAL_8 ((unsigned) (ARPHRD_APPLETLK))
+ #define XLAT_STR_8 STRINGIFY(ARPHRD_APPLETLK)
  XLAT(ARPHRD_DLCI),
+ #define XLAT_VAL_9 ((unsigned) (ARPHRD_DLCI))
+ #define XLAT_STR_9 STRINGIFY(ARPHRD_DLCI)
  XLAT(ARPHRD_ATM),
+ #define XLAT_VAL_10 ((unsigned) (ARPHRD_ATM))
+ #define XLAT_STR_10 STRINGIFY(ARPHRD_ATM)
  XLAT(ARPHRD_METRICOM),
+ #define XLAT_VAL_11 ((unsigned) (ARPHRD_METRICOM))
+ #define XLAT_STR_11 STRINGIFY(ARPHRD_METRICOM)
  XLAT(ARPHRD_IEEE1394),
+ #define XLAT_VAL_12 ((unsigned) (ARPHRD_IEEE1394))
+ #define XLAT_STR_12 STRINGIFY(ARPHRD_IEEE1394)
  XLAT(ARPHRD_EUI64),
+ #define XLAT_VAL_13 ((unsigned) (ARPHRD_EUI64))
+ #define XLAT_STR_13 STRINGIFY(ARPHRD_EUI64)
  XLAT(ARPHRD_INFINIBAND),
+ #define XLAT_VAL_14 ((unsigned) (ARPHRD_INFINIBAND))
+ #define XLAT_STR_14 STRINGIFY(ARPHRD_INFINIBAND)
  XLAT(ARPHRD_SLIP),
+ #define XLAT_VAL_15 ((unsigned) (ARPHRD_SLIP))
+ #define XLAT_STR_15 STRINGIFY(ARPHRD_SLIP)
  XLAT(ARPHRD_CSLIP),
+ #define XLAT_VAL_16 ((unsigned) (ARPHRD_CSLIP))
+ #define XLAT_STR_16 STRINGIFY(ARPHRD_CSLIP)
  XLAT(ARPHRD_SLIP6),
+ #define XLAT_VAL_17 ((unsigned) (ARPHRD_SLIP6))
+ #define XLAT_STR_17 STRINGIFY(ARPHRD_SLIP6)
  XLAT(ARPHRD_CSLIP6),
+ #define XLAT_VAL_18 ((unsigned) (ARPHRD_CSLIP6))
+ #define XLAT_STR_18 STRINGIFY(ARPHRD_CSLIP6)
  XLAT(ARPHRD_RSRVD),
+ #define XLAT_VAL_19 ((unsigned) (ARPHRD_RSRVD))
+ #define XLAT_STR_19 STRINGIFY(ARPHRD_RSRVD)
  XLAT(ARPHRD_ADAPT),
+ #define XLAT_VAL_20 ((unsigned) (ARPHRD_ADAPT))
+ #define XLAT_STR_20 STRINGIFY(ARPHRD_ADAPT)
  XLAT(ARPHRD_ROSE),
+ #define XLAT_VAL_21 ((unsigned) (ARPHRD_ROSE))
+ #define XLAT_STR_21 STRINGIFY(ARPHRD_ROSE)
  XLAT(ARPHRD_X25),
+ #define XLAT_VAL_22 ((unsigned) (ARPHRD_X25))
+ #define XLAT_STR_22 STRINGIFY(ARPHRD_X25)
  XLAT(ARPHRD_HWX25),
+ #define XLAT_VAL_23 ((unsigned) (ARPHRD_HWX25))
+ #define XLAT_STR_23 STRINGIFY(ARPHRD_HWX25)
  XLAT(ARPHRD_CAN),
+ #define XLAT_VAL_24 ((unsigned) (ARPHRD_CAN))
+ #define XLAT_STR_24 STRINGIFY(ARPHRD_CAN)
  XLAT(ARPHRD_PPP),
+ #define XLAT_VAL_25 ((unsigned) (ARPHRD_PPP))
+ #define XLAT_STR_25 STRINGIFY(ARPHRD_PPP)
  XLAT(ARPHRD_CISCO),
+ #define XLAT_VAL_26 ((unsigned) (ARPHRD_CISCO))
+ #define XLAT_STR_26 STRINGIFY(ARPHRD_CISCO)
  XLAT(ARPHRD_LAPB),
+ #define XLAT_VAL_27 ((unsigned) (ARPHRD_LAPB))
+ #define XLAT_STR_27 STRINGIFY(ARPHRD_LAPB)
  XLAT(ARPHRD_DDCMP),
+ #define XLAT_VAL_28 ((unsigned) (ARPHRD_DDCMP))
+ #define XLAT_STR_28 STRINGIFY(ARPHRD_DDCMP)
  XLAT(ARPHRD_RAWHDLC),
+ #define XLAT_VAL_29 ((unsigned) (ARPHRD_RAWHDLC))
+ #define XLAT_STR_29 STRINGIFY(ARPHRD_RAWHDLC)
  XLAT(ARPHRD_RAWIP),
+ #define XLAT_VAL_30 ((unsigned) (ARPHRD_RAWIP))
+ #define XLAT_STR_30 STRINGIFY(ARPHRD_RAWIP)
  XLAT(ARPHRD_TUNNEL),
+ #define XLAT_VAL_31 ((unsigned) (ARPHRD_TUNNEL))
+ #define XLAT_STR_31 STRINGIFY(ARPHRD_TUNNEL)
  XLAT(ARPHRD_TUNNEL6),
+ #define XLAT_VAL_32 ((unsigned) (ARPHRD_TUNNEL6))
+ #define XLAT_STR_32 STRINGIFY(ARPHRD_TUNNEL6)
  XLAT(ARPHRD_FRAD),
+ #define XLAT_VAL_33 ((unsigned) (ARPHRD_FRAD))
+ #define XLAT_STR_33 STRINGIFY(ARPHRD_FRAD)
  XLAT(ARPHRD_SKIP),
+ #define XLAT_VAL_34 ((unsigned) (ARPHRD_SKIP))
+ #define XLAT_STR_34 STRINGIFY(ARPHRD_SKIP)
  XLAT(ARPHRD_LOOPBACK),
+ #define XLAT_VAL_35 ((unsigned) (ARPHRD_LOOPBACK))
+ #define XLAT_STR_35 STRINGIFY(ARPHRD_LOOPBACK)
  XLAT(ARPHRD_LOCALTLK),
+ #define XLAT_VAL_36 ((unsigned) (ARPHRD_LOCALTLK))
+ #define XLAT_STR_36 STRINGIFY(ARPHRD_LOCALTLK)
  XLAT(ARPHRD_FDDI),
+ #define XLAT_VAL_37 ((unsigned) (ARPHRD_FDDI))
+ #define XLAT_STR_37 STRINGIFY(ARPHRD_FDDI)
  XLAT(ARPHRD_BIF),
+ #define XLAT_VAL_38 ((unsigned) (ARPHRD_BIF))
+ #define XLAT_STR_38 STRINGIFY(ARPHRD_BIF)
  XLAT(ARPHRD_SIT),
+ #define XLAT_VAL_39 ((unsigned) (ARPHRD_SIT))
+ #define XLAT_STR_39 STRINGIFY(ARPHRD_SIT)
  XLAT(ARPHRD_IPDDP),
+ #define XLAT_VAL_40 ((unsigned) (ARPHRD_IPDDP))
+ #define XLAT_STR_40 STRINGIFY(ARPHRD_IPDDP)
  XLAT(ARPHRD_IPGRE),
+ #define XLAT_VAL_41 ((unsigned) (ARPHRD_IPGRE))
+ #define XLAT_STR_41 STRINGIFY(ARPHRD_IPGRE)
  XLAT(ARPHRD_PIMREG),
+ #define XLAT_VAL_42 ((unsigned) (ARPHRD_PIMREG))
+ #define XLAT_STR_42 STRINGIFY(ARPHRD_PIMREG)
  XLAT(ARPHRD_HIPPI),
+ #define XLAT_VAL_43 ((unsigned) (ARPHRD_HIPPI))
+ #define XLAT_STR_43 STRINGIFY(ARPHRD_HIPPI)
  XLAT(ARPHRD_ASH),
+ #define XLAT_VAL_44 ((unsigned) (ARPHRD_ASH))
+ #define XLAT_STR_44 STRINGIFY(ARPHRD_ASH)
  XLAT(ARPHRD_ECONET),
+ #define XLAT_VAL_45 ((unsigned) (ARPHRD_ECONET))
+ #define XLAT_STR_45 STRINGIFY(ARPHRD_ECONET)
  XLAT(ARPHRD_IRDA),
+ #define XLAT_VAL_46 ((unsigned) (ARPHRD_IRDA))
+ #define XLAT_STR_46 STRINGIFY(ARPHRD_IRDA)
  XLAT(ARPHRD_FCPP),
+ #define XLAT_VAL_47 ((unsigned) (ARPHRD_FCPP))
+ #define XLAT_STR_47 STRINGIFY(ARPHRD_FCPP)
  XLAT(ARPHRD_FCAL),
+ #define XLAT_VAL_48 ((unsigned) (ARPHRD_FCAL))
+ #define XLAT_STR_48 STRINGIFY(ARPHRD_FCAL)
  XLAT(ARPHRD_FCPL),
+ #define XLAT_VAL_49 ((unsigned) (ARPHRD_FCPL))
+ #define XLAT_STR_49 STRINGIFY(ARPHRD_FCPL)
  XLAT(ARPHRD_FCFABRIC),
+ #define XLAT_VAL_50 ((unsigned) (ARPHRD_FCFABRIC))
+ #define XLAT_STR_50 STRINGIFY(ARPHRD_FCFABRIC)
  XLAT(ARPHRD_IEEE802_TR),
+ #define XLAT_VAL_51 ((unsigned) (ARPHRD_IEEE802_TR))
+ #define XLAT_STR_51 STRINGIFY(ARPHRD_IEEE802_TR)
  XLAT(ARPHRD_IEEE80211),
+ #define XLAT_VAL_52 ((unsigned) (ARPHRD_IEEE80211))
+ #define XLAT_STR_52 STRINGIFY(ARPHRD_IEEE80211)
  XLAT(ARPHRD_IEEE80211_PRISM),
+ #define XLAT_VAL_53 ((unsigned) (ARPHRD_IEEE80211_PRISM))
+ #define XLAT_STR_53 STRINGIFY(ARPHRD_IEEE80211_PRISM)
  XLAT(ARPHRD_IEEE80211_RADIOTAP),
+ #define XLAT_VAL_54 ((unsigned) (ARPHRD_IEEE80211_RADIOTAP))
+ #define XLAT_STR_54 STRINGIFY(ARPHRD_IEEE80211_RADIOTAP)
  XLAT(ARPHRD_IEEE802154),
+ #define XLAT_VAL_55 ((unsigned) (ARPHRD_IEEE802154))
+ #define XLAT_STR_55 STRINGIFY(ARPHRD_IEEE802154)
  XLAT(ARPHRD_IEEE802154_MONITOR),
+ #define XLAT_VAL_56 ((unsigned) (ARPHRD_IEEE802154_MONITOR))
+ #define XLAT_STR_56 STRINGIFY(ARPHRD_IEEE802154_MONITOR)
  XLAT(ARPHRD_PHONET),
+ #define XLAT_VAL_57 ((unsigned) (ARPHRD_PHONET))
+ #define XLAT_STR_57 STRINGIFY(ARPHRD_PHONET)
  XLAT(ARPHRD_PHONET_PIPE),
+ #define XLAT_VAL_58 ((unsigned) (ARPHRD_PHONET_PIPE))
+ #define XLAT_STR_58 STRINGIFY(ARPHRD_PHONET_PIPE)
  XLAT(ARPHRD_CAIF),
+ #define XLAT_VAL_59 ((unsigned) (ARPHRD_CAIF))
+ #define XLAT_STR_59 STRINGIFY(ARPHRD_CAIF)
  XLAT(ARPHRD_IP6GRE),
+ #define XLAT_VAL_60 ((unsigned) (ARPHRD_IP6GRE))
+ #define XLAT_STR_60 STRINGIFY(ARPHRD_IP6GRE)
  XLAT(ARPHRD_NETLINK),
+ #define XLAT_VAL_61 ((unsigned) (ARPHRD_NETLINK))
+ #define XLAT_STR_61 STRINGIFY(ARPHRD_NETLINK)
  XLAT(ARPHRD_6LOWPAN),
+ #define XLAT_VAL_62 ((unsigned) (ARPHRD_6LOWPAN))
+ #define XLAT_STR_62 STRINGIFY(ARPHRD_6LOWPAN)
  XLAT(ARPHRD_VSOCKMON),
+ #define XLAT_VAL_63 ((unsigned) (ARPHRD_VSOCKMON))
+ #define XLAT_STR_63 STRINGIFY(ARPHRD_VSOCKMON)
  XLAT(ARPHRD_NONE),
+ #define XLAT_VAL_64 ((unsigned) (ARPHRD_NONE))
+ #define XLAT_STR_64 STRINGIFY(ARPHRD_NONE)
  XLAT(ARPHRD_VOID),
+ #define XLAT_VAL_65 ((unsigned) (ARPHRD_VOID))
+ #define XLAT_STR_65 STRINGIFY(ARPHRD_VOID)
 };
 const struct xlat arp_hardware_types[1] = { {
  .data = arp_hardware_types_xdata,
  .size = ARRAY_SIZE(arp_hardware_types_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+#  ifdef XLAT_VAL_47
+  | XLAT_VAL_47
+#  endif
+#  ifdef XLAT_VAL_48
+  | XLAT_VAL_48
+#  endif
+#  ifdef XLAT_VAL_49
+  | XLAT_VAL_49
+#  endif
+#  ifdef XLAT_VAL_50
+  | XLAT_VAL_50
+#  endif
+#  ifdef XLAT_VAL_51
+  | XLAT_VAL_51
+#  endif
+#  ifdef XLAT_VAL_52
+  | XLAT_VAL_52
+#  endif
+#  ifdef XLAT_VAL_53
+  | XLAT_VAL_53
+#  endif
+#  ifdef XLAT_VAL_54
+  | XLAT_VAL_54
+#  endif
+#  ifdef XLAT_VAL_55
+  | XLAT_VAL_55
+#  endif
+#  ifdef XLAT_VAL_56
+  | XLAT_VAL_56
+#  endif
+#  ifdef XLAT_VAL_57
+  | XLAT_VAL_57
+#  endif
+#  ifdef XLAT_VAL_58
+  | XLAT_VAL_58
+#  endif
+#  ifdef XLAT_VAL_59
+  | XLAT_VAL_59
+#  endif
+#  ifdef XLAT_VAL_60
+  | XLAT_VAL_60
+#  endif
+#  ifdef XLAT_VAL_61
+  | XLAT_VAL_61
+#  endif
+#  ifdef XLAT_VAL_62
+  | XLAT_VAL_62
+#  endif
+#  ifdef XLAT_VAL_63
+  | XLAT_VAL_63
+#  endif
+#  ifdef XLAT_VAL_64
+  | XLAT_VAL_64
+#  endif
+#  ifdef XLAT_VAL_65
+  | XLAT_VAL_65
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+#  ifdef XLAT_STR_47
+  + sizeof(XLAT_STR_47)
+#  endif
+#  ifdef XLAT_STR_48
+  + sizeof(XLAT_STR_48)
+#  endif
+#  ifdef XLAT_STR_49
+  + sizeof(XLAT_STR_49)
+#  endif
+#  ifdef XLAT_STR_50
+  + sizeof(XLAT_STR_50)
+#  endif
+#  ifdef XLAT_STR_51
+  + sizeof(XLAT_STR_51)
+#  endif
+#  ifdef XLAT_STR_52
+  + sizeof(XLAT_STR_52)
+#  endif
+#  ifdef XLAT_STR_53
+  + sizeof(XLAT_STR_53)
+#  endif
+#  ifdef XLAT_STR_54
+  + sizeof(XLAT_STR_54)
+#  endif
+#  ifdef XLAT_STR_55
+  + sizeof(XLAT_STR_55)
+#  endif
+#  ifdef XLAT_STR_56
+  + sizeof(XLAT_STR_56)
+#  endif
+#  ifdef XLAT_STR_57
+  + sizeof(XLAT_STR_57)
+#  endif
+#  ifdef XLAT_STR_58
+  + sizeof(XLAT_STR_58)
+#  endif
+#  ifdef XLAT_STR_59
+  + sizeof(XLAT_STR_59)
+#  endif
+#  ifdef XLAT_STR_60
+  + sizeof(XLAT_STR_60)
+#  endif
+#  ifdef XLAT_STR_61
+  + sizeof(XLAT_STR_61)
+#  endif
+#  ifdef XLAT_STR_62
+  + sizeof(XLAT_STR_62)
+#  endif
+#  ifdef XLAT_STR_63
+  + sizeof(XLAT_STR_63)
+#  endif
+#  ifdef XLAT_STR_64
+  + sizeof(XLAT_STR_64)
+#  endif
+#  ifdef XLAT_STR_65
+  + sizeof(XLAT_STR_65)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
+#  undef XLAT_STR_47
+#  undef XLAT_VAL_47
+#  undef XLAT_STR_48
+#  undef XLAT_VAL_48
+#  undef XLAT_STR_49
+#  undef XLAT_VAL_49
+#  undef XLAT_STR_50
+#  undef XLAT_VAL_50
+#  undef XLAT_STR_51
+#  undef XLAT_VAL_51
+#  undef XLAT_STR_52
+#  undef XLAT_VAL_52
+#  undef XLAT_STR_53
+#  undef XLAT_VAL_53
+#  undef XLAT_STR_54
+#  undef XLAT_VAL_54
+#  undef XLAT_STR_55
+#  undef XLAT_VAL_55
+#  undef XLAT_STR_56
+#  undef XLAT_VAL_56
+#  undef XLAT_STR_57
+#  undef XLAT_VAL_57
+#  undef XLAT_STR_58
+#  undef XLAT_VAL_58
+#  undef XLAT_STR_59
+#  undef XLAT_VAL_59
+#  undef XLAT_STR_60
+#  undef XLAT_VAL_60
+#  undef XLAT_STR_61
+#  undef XLAT_VAL_61
+#  undef XLAT_STR_62
+#  undef XLAT_VAL_62
+#  undef XLAT_STR_63
+#  undef XLAT_VAL_63
+#  undef XLAT_STR_64
+#  undef XLAT_VAL_64
+#  undef XLAT_STR_65
+#  undef XLAT_VAL_65
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/at_flags.h 5.9-0ubuntu2/xlat/at_flags.h
--- 5.5-3/xlat/at_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/at_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -52,18 +52,82 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data at_flags_xdata[] = {
  XLAT(AT_SYMLINK_NOFOLLOW),
+ #define XLAT_VAL_0 ((unsigned) (AT_SYMLINK_NOFOLLOW))
+ #define XLAT_STR_0 STRINGIFY(AT_SYMLINK_NOFOLLOW)
  XLAT(AT_REMOVEDIR),
+ #define XLAT_VAL_1 ((unsigned) (AT_REMOVEDIR))
+ #define XLAT_STR_1 STRINGIFY(AT_REMOVEDIR)
  XLAT(AT_SYMLINK_FOLLOW),
+ #define XLAT_VAL_2 ((unsigned) (AT_SYMLINK_FOLLOW))
+ #define XLAT_STR_2 STRINGIFY(AT_SYMLINK_FOLLOW)
  XLAT(AT_NO_AUTOMOUNT),
+ #define XLAT_VAL_3 ((unsigned) (AT_NO_AUTOMOUNT))
+ #define XLAT_STR_3 STRINGIFY(AT_NO_AUTOMOUNT)
  XLAT(AT_EMPTY_PATH),
+ #define XLAT_VAL_4 ((unsigned) (AT_EMPTY_PATH))
+ #define XLAT_STR_4 STRINGIFY(AT_EMPTY_PATH)
  XLAT(AT_RECURSIVE),
+ #define XLAT_VAL_5 ((unsigned) (AT_RECURSIVE))
+ #define XLAT_STR_5 STRINGIFY(AT_RECURSIVE)
 };
 const struct xlat at_flags[1] = { {
  .data = at_flags_xdata,
  .size = ARRAY_SIZE(at_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/atomic_ops.h 5.9-0ubuntu2/xlat/atomic_ops.h
--- 5.5-3/xlat/atomic_ops.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/atomic_ops.h	2020-09-24 09:18:43.000000000 +0000
@@ -28,6 +28,10 @@ const struct xlat atomic_ops[1] = { {
  .data = atomic_ops_xdata,
  .size = ARRAY_SIZE(atomic_ops_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+  ,
+ .flags_strsz = 0
+  ,
 } };
 
 # endif /* !IN_MPERS */
diff -pruN 5.5-3/xlat/at_statx_sync_types.h 5.9-0ubuntu2/xlat/at_statx_sync_types.h
--- 5.5-3/xlat/at_statx_sync_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/at_statx_sync_types.h	2020-09-24 09:18:44.000000000 +0000
@@ -42,18 +42,62 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data at_statx_sync_types_xdata[] = {
  XLAT(AT_STATX_SYNC_AS_STAT),
+ #define XLAT_VAL_0 ((unsigned) (AT_STATX_SYNC_AS_STAT))
+ #define XLAT_STR_0 STRINGIFY(AT_STATX_SYNC_AS_STAT)
  XLAT(AT_STATX_FORCE_SYNC),
+ #define XLAT_VAL_1 ((unsigned) (AT_STATX_FORCE_SYNC))
+ #define XLAT_STR_1 STRINGIFY(AT_STATX_FORCE_SYNC)
  XLAT(AT_STATX_DONT_SYNC),
+ #define XLAT_VAL_2 ((unsigned) (AT_STATX_DONT_SYNC))
+ #define XLAT_STR_2 STRINGIFY(AT_STATX_DONT_SYNC)
 
  XLAT(AT_STATX_SYNC_TYPE),
+ #define XLAT_VAL_3 ((unsigned) (AT_STATX_SYNC_TYPE))
+ #define XLAT_STR_3 STRINGIFY(AT_STATX_SYNC_TYPE)
 };
 static
 const struct xlat at_statx_sync_types[1] = { {
  .data = at_statx_sync_types_xdata,
  .size = ARRAY_SIZE(at_statx_sync_types_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/audit_arch.h 5.9-0ubuntu2/xlat/audit_arch.h
--- 5.5-3/xlat/audit_arch.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/audit_arch.h	2020-09-24 09:18:45.000000000 +0000
@@ -393,64 +393,588 @@ static const struct xlat_data audit_arch
 #endif
 
  XLAT(AUDIT_ARCH_AARCH64),
+ #define XLAT_VAL_0 ((unsigned) (AUDIT_ARCH_AARCH64))
+ #define XLAT_STR_0 STRINGIFY(AUDIT_ARCH_AARCH64)
  XLAT(AUDIT_ARCH_ALPHA),
+ #define XLAT_VAL_1 ((unsigned) (AUDIT_ARCH_ALPHA))
+ #define XLAT_STR_1 STRINGIFY(AUDIT_ARCH_ALPHA)
  XLAT(AUDIT_ARCH_ARCOMPACT),
+ #define XLAT_VAL_2 ((unsigned) (AUDIT_ARCH_ARCOMPACT))
+ #define XLAT_STR_2 STRINGIFY(AUDIT_ARCH_ARCOMPACT)
  XLAT(AUDIT_ARCH_ARCOMPACTBE),
+ #define XLAT_VAL_3 ((unsigned) (AUDIT_ARCH_ARCOMPACTBE))
+ #define XLAT_STR_3 STRINGIFY(AUDIT_ARCH_ARCOMPACTBE)
  XLAT(AUDIT_ARCH_ARCV2),
+ #define XLAT_VAL_4 ((unsigned) (AUDIT_ARCH_ARCV2))
+ #define XLAT_STR_4 STRINGIFY(AUDIT_ARCH_ARCV2)
  XLAT(AUDIT_ARCH_ARCV2BE),
+ #define XLAT_VAL_5 ((unsigned) (AUDIT_ARCH_ARCV2BE))
+ #define XLAT_STR_5 STRINGIFY(AUDIT_ARCH_ARCV2BE)
  XLAT(AUDIT_ARCH_ARM),
+ #define XLAT_VAL_6 ((unsigned) (AUDIT_ARCH_ARM))
+ #define XLAT_STR_6 STRINGIFY(AUDIT_ARCH_ARM)
  XLAT(AUDIT_ARCH_ARMEB),
+ #define XLAT_VAL_7 ((unsigned) (AUDIT_ARCH_ARMEB))
+ #define XLAT_STR_7 STRINGIFY(AUDIT_ARCH_ARMEB)
  XLAT(AUDIT_ARCH_C6X),
+ #define XLAT_VAL_8 ((unsigned) (AUDIT_ARCH_C6X))
+ #define XLAT_STR_8 STRINGIFY(AUDIT_ARCH_C6X)
  XLAT(AUDIT_ARCH_C6XBE),
+ #define XLAT_VAL_9 ((unsigned) (AUDIT_ARCH_C6XBE))
+ #define XLAT_STR_9 STRINGIFY(AUDIT_ARCH_C6XBE)
  XLAT(AUDIT_ARCH_CRIS),
+ #define XLAT_VAL_10 ((unsigned) (AUDIT_ARCH_CRIS))
+ #define XLAT_STR_10 STRINGIFY(AUDIT_ARCH_CRIS)
  XLAT(AUDIT_ARCH_CSKY),
+ #define XLAT_VAL_11 ((unsigned) (AUDIT_ARCH_CSKY))
+ #define XLAT_STR_11 STRINGIFY(AUDIT_ARCH_CSKY)
  XLAT(AUDIT_ARCH_FRV),
+ #define XLAT_VAL_12 ((unsigned) (AUDIT_ARCH_FRV))
+ #define XLAT_STR_12 STRINGIFY(AUDIT_ARCH_FRV)
  XLAT(AUDIT_ARCH_H8300),
+ #define XLAT_VAL_13 ((unsigned) (AUDIT_ARCH_H8300))
+ #define XLAT_STR_13 STRINGIFY(AUDIT_ARCH_H8300)
  XLAT(AUDIT_ARCH_HEXAGON),
+ #define XLAT_VAL_14 ((unsigned) (AUDIT_ARCH_HEXAGON))
+ #define XLAT_STR_14 STRINGIFY(AUDIT_ARCH_HEXAGON)
  XLAT(AUDIT_ARCH_I386),
+ #define XLAT_VAL_15 ((unsigned) (AUDIT_ARCH_I386))
+ #define XLAT_STR_15 STRINGIFY(AUDIT_ARCH_I386)
  XLAT(AUDIT_ARCH_IA64),
+ #define XLAT_VAL_16 ((unsigned) (AUDIT_ARCH_IA64))
+ #define XLAT_STR_16 STRINGIFY(AUDIT_ARCH_IA64)
  XLAT(AUDIT_ARCH_M32R),
+ #define XLAT_VAL_17 ((unsigned) (AUDIT_ARCH_M32R))
+ #define XLAT_STR_17 STRINGIFY(AUDIT_ARCH_M32R)
  XLAT(AUDIT_ARCH_M68K),
+ #define XLAT_VAL_18 ((unsigned) (AUDIT_ARCH_M68K))
+ #define XLAT_STR_18 STRINGIFY(AUDIT_ARCH_M68K)
  XLAT(AUDIT_ARCH_MICROBLAZE),
+ #define XLAT_VAL_19 ((unsigned) (AUDIT_ARCH_MICROBLAZE))
+ #define XLAT_STR_19 STRINGIFY(AUDIT_ARCH_MICROBLAZE)
  XLAT(AUDIT_ARCH_MIPS),
+ #define XLAT_VAL_20 ((unsigned) (AUDIT_ARCH_MIPS))
+ #define XLAT_STR_20 STRINGIFY(AUDIT_ARCH_MIPS)
  XLAT(AUDIT_ARCH_MIPS64),
+ #define XLAT_VAL_21 ((unsigned) (AUDIT_ARCH_MIPS64))
+ #define XLAT_STR_21 STRINGIFY(AUDIT_ARCH_MIPS64)
  XLAT(AUDIT_ARCH_MIPS64N32),
+ #define XLAT_VAL_22 ((unsigned) (AUDIT_ARCH_MIPS64N32))
+ #define XLAT_STR_22 STRINGIFY(AUDIT_ARCH_MIPS64N32)
  XLAT(AUDIT_ARCH_MIPSEL),
+ #define XLAT_VAL_23 ((unsigned) (AUDIT_ARCH_MIPSEL))
+ #define XLAT_STR_23 STRINGIFY(AUDIT_ARCH_MIPSEL)
  XLAT(AUDIT_ARCH_MIPSEL64),
+ #define XLAT_VAL_24 ((unsigned) (AUDIT_ARCH_MIPSEL64))
+ #define XLAT_STR_24 STRINGIFY(AUDIT_ARCH_MIPSEL64)
  XLAT(AUDIT_ARCH_MIPSEL64N32),
+ #define XLAT_VAL_25 ((unsigned) (AUDIT_ARCH_MIPSEL64N32))
+ #define XLAT_STR_25 STRINGIFY(AUDIT_ARCH_MIPSEL64N32)
  XLAT(AUDIT_ARCH_NDS32),
+ #define XLAT_VAL_26 ((unsigned) (AUDIT_ARCH_NDS32))
+ #define XLAT_STR_26 STRINGIFY(AUDIT_ARCH_NDS32)
  XLAT(AUDIT_ARCH_NDS32BE),
+ #define XLAT_VAL_27 ((unsigned) (AUDIT_ARCH_NDS32BE))
+ #define XLAT_STR_27 STRINGIFY(AUDIT_ARCH_NDS32BE)
  XLAT(AUDIT_ARCH_NIOS2),
+ #define XLAT_VAL_28 ((unsigned) (AUDIT_ARCH_NIOS2))
+ #define XLAT_STR_28 STRINGIFY(AUDIT_ARCH_NIOS2)
  XLAT(AUDIT_ARCH_OPENRISC),
+ #define XLAT_VAL_29 ((unsigned) (AUDIT_ARCH_OPENRISC))
+ #define XLAT_STR_29 STRINGIFY(AUDIT_ARCH_OPENRISC)
  XLAT(AUDIT_ARCH_PARISC),
+ #define XLAT_VAL_30 ((unsigned) (AUDIT_ARCH_PARISC))
+ #define XLAT_STR_30 STRINGIFY(AUDIT_ARCH_PARISC)
  XLAT(AUDIT_ARCH_PARISC64),
+ #define XLAT_VAL_31 ((unsigned) (AUDIT_ARCH_PARISC64))
+ #define XLAT_STR_31 STRINGIFY(AUDIT_ARCH_PARISC64)
  XLAT(AUDIT_ARCH_PPC),
+ #define XLAT_VAL_32 ((unsigned) (AUDIT_ARCH_PPC))
+ #define XLAT_STR_32 STRINGIFY(AUDIT_ARCH_PPC)
  XLAT(AUDIT_ARCH_PPC64),
+ #define XLAT_VAL_33 ((unsigned) (AUDIT_ARCH_PPC64))
+ #define XLAT_STR_33 STRINGIFY(AUDIT_ARCH_PPC64)
  XLAT(AUDIT_ARCH_PPC64LE),
+ #define XLAT_VAL_34 ((unsigned) (AUDIT_ARCH_PPC64LE))
+ #define XLAT_STR_34 STRINGIFY(AUDIT_ARCH_PPC64LE)
  XLAT(AUDIT_ARCH_RISCV32),
+ #define XLAT_VAL_35 ((unsigned) (AUDIT_ARCH_RISCV32))
+ #define XLAT_STR_35 STRINGIFY(AUDIT_ARCH_RISCV32)
  XLAT(AUDIT_ARCH_RISCV64),
+ #define XLAT_VAL_36 ((unsigned) (AUDIT_ARCH_RISCV64))
+ #define XLAT_STR_36 STRINGIFY(AUDIT_ARCH_RISCV64)
  XLAT(AUDIT_ARCH_S390),
+ #define XLAT_VAL_37 ((unsigned) (AUDIT_ARCH_S390))
+ #define XLAT_STR_37 STRINGIFY(AUDIT_ARCH_S390)
  XLAT(AUDIT_ARCH_S390X),
+ #define XLAT_VAL_38 ((unsigned) (AUDIT_ARCH_S390X))
+ #define XLAT_STR_38 STRINGIFY(AUDIT_ARCH_S390X)
  XLAT(AUDIT_ARCH_SH),
+ #define XLAT_VAL_39 ((unsigned) (AUDIT_ARCH_SH))
+ #define XLAT_STR_39 STRINGIFY(AUDIT_ARCH_SH)
  XLAT(AUDIT_ARCH_SH64),
+ #define XLAT_VAL_40 ((unsigned) (AUDIT_ARCH_SH64))
+ #define XLAT_STR_40 STRINGIFY(AUDIT_ARCH_SH64)
  XLAT(AUDIT_ARCH_SHEL),
+ #define XLAT_VAL_41 ((unsigned) (AUDIT_ARCH_SHEL))
+ #define XLAT_STR_41 STRINGIFY(AUDIT_ARCH_SHEL)
  XLAT(AUDIT_ARCH_SHEL64),
+ #define XLAT_VAL_42 ((unsigned) (AUDIT_ARCH_SHEL64))
+ #define XLAT_STR_42 STRINGIFY(AUDIT_ARCH_SHEL64)
  XLAT(AUDIT_ARCH_SPARC),
+ #define XLAT_VAL_43 ((unsigned) (AUDIT_ARCH_SPARC))
+ #define XLAT_STR_43 STRINGIFY(AUDIT_ARCH_SPARC)
  XLAT(AUDIT_ARCH_SPARC64),
+ #define XLAT_VAL_44 ((unsigned) (AUDIT_ARCH_SPARC64))
+ #define XLAT_STR_44 STRINGIFY(AUDIT_ARCH_SPARC64)
  XLAT(AUDIT_ARCH_TILEGX),
+ #define XLAT_VAL_45 ((unsigned) (AUDIT_ARCH_TILEGX))
+ #define XLAT_STR_45 STRINGIFY(AUDIT_ARCH_TILEGX)
  XLAT(AUDIT_ARCH_TILEGX32),
+ #define XLAT_VAL_46 ((unsigned) (AUDIT_ARCH_TILEGX32))
+ #define XLAT_STR_46 STRINGIFY(AUDIT_ARCH_TILEGX32)
  XLAT(AUDIT_ARCH_TILEPRO),
+ #define XLAT_VAL_47 ((unsigned) (AUDIT_ARCH_TILEPRO))
+ #define XLAT_STR_47 STRINGIFY(AUDIT_ARCH_TILEPRO)
  XLAT(AUDIT_ARCH_UNICORE),
+ #define XLAT_VAL_48 ((unsigned) (AUDIT_ARCH_UNICORE))
+ #define XLAT_STR_48 STRINGIFY(AUDIT_ARCH_UNICORE)
  XLAT(AUDIT_ARCH_V850),
+ #define XLAT_VAL_49 ((unsigned) (AUDIT_ARCH_V850))
+ #define XLAT_STR_49 STRINGIFY(AUDIT_ARCH_V850)
  XLAT(AUDIT_ARCH_X86_64),
+ #define XLAT_VAL_50 ((unsigned) (AUDIT_ARCH_X86_64))
+ #define XLAT_STR_50 STRINGIFY(AUDIT_ARCH_X86_64)
  XLAT(AUDIT_ARCH_XTENSA),
+ #define XLAT_VAL_51 ((unsigned) (AUDIT_ARCH_XTENSA))
+ #define XLAT_STR_51 STRINGIFY(AUDIT_ARCH_XTENSA)
 };
 const struct xlat audit_arch[1] = { {
  .data = audit_arch_xdata,
  .size = ARRAY_SIZE(audit_arch_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+#  ifdef XLAT_VAL_47
+  | XLAT_VAL_47
+#  endif
+#  ifdef XLAT_VAL_48
+  | XLAT_VAL_48
+#  endif
+#  ifdef XLAT_VAL_49
+  | XLAT_VAL_49
+#  endif
+#  ifdef XLAT_VAL_50
+  | XLAT_VAL_50
+#  endif
+#  ifdef XLAT_VAL_51
+  | XLAT_VAL_51
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+#  ifdef XLAT_STR_47
+  + sizeof(XLAT_STR_47)
+#  endif
+#  ifdef XLAT_STR_48
+  + sizeof(XLAT_STR_48)
+#  endif
+#  ifdef XLAT_STR_49
+  + sizeof(XLAT_STR_49)
+#  endif
+#  ifdef XLAT_STR_50
+  + sizeof(XLAT_STR_50)
+#  endif
+#  ifdef XLAT_STR_51
+  + sizeof(XLAT_STR_51)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
+#  undef XLAT_STR_47
+#  undef XLAT_VAL_47
+#  undef XLAT_STR_48
+#  undef XLAT_VAL_48
+#  undef XLAT_STR_49
+#  undef XLAT_VAL_49
+#  undef XLAT_STR_50
+#  undef XLAT_VAL_50
+#  undef XLAT_STR_51
+#  undef XLAT_VAL_51
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ax25_protocols.h 5.9-0ubuntu2/xlat/ax25_protocols.h
--- 5.5-3/xlat/ax25_protocols.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ax25_protocols.h	2020-09-24 09:18:44.000000000 +0000
@@ -106,28 +106,162 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 static const struct xlat_data ax25_protocols_xdata[] = {
 
  XLAT(AX25_P_ROSE),
+ #define XLAT_VAL_0 ((unsigned) (AX25_P_ROSE))
+ #define XLAT_STR_0 STRINGIFY(AX25_P_ROSE)
  XLAT(AX25_P_VJCOMP),
+ #define XLAT_VAL_1 ((unsigned) (AX25_P_VJCOMP))
+ #define XLAT_STR_1 STRINGIFY(AX25_P_VJCOMP)
 
  XLAT(AX25_P_VJUNCOMP),
+ #define XLAT_VAL_2 ((unsigned) (AX25_P_VJUNCOMP))
+ #define XLAT_STR_2 STRINGIFY(AX25_P_VJUNCOMP)
 
  XLAT(AX25_P_SEGMENT),
+ #define XLAT_VAL_3 ((unsigned) (AX25_P_SEGMENT))
+ #define XLAT_STR_3 STRINGIFY(AX25_P_SEGMENT)
  XLAT(AX25_P_TEXNET),
+ #define XLAT_VAL_4 ((unsigned) (AX25_P_TEXNET))
+ #define XLAT_STR_4 STRINGIFY(AX25_P_TEXNET)
  XLAT(AX25_P_LQ),
+ #define XLAT_VAL_5 ((unsigned) (AX25_P_LQ))
+ #define XLAT_STR_5 STRINGIFY(AX25_P_LQ)
  XLAT(AX25_P_ATALK),
+ #define XLAT_VAL_6 ((unsigned) (AX25_P_ATALK))
+ #define XLAT_STR_6 STRINGIFY(AX25_P_ATALK)
  XLAT(AX25_P_ATALK_ARP),
+ #define XLAT_VAL_7 ((unsigned) (AX25_P_ATALK_ARP))
+ #define XLAT_STR_7 STRINGIFY(AX25_P_ATALK_ARP)
  XLAT(AX25_P_IP),
+ #define XLAT_VAL_8 ((unsigned) (AX25_P_IP))
+ #define XLAT_STR_8 STRINGIFY(AX25_P_IP)
  XLAT(AX25_P_ARP),
+ #define XLAT_VAL_9 ((unsigned) (AX25_P_ARP))
+ #define XLAT_STR_9 STRINGIFY(AX25_P_ARP)
  XLAT(AX25_P_FLEXNET),
+ #define XLAT_VAL_10 ((unsigned) (AX25_P_FLEXNET))
+ #define XLAT_STR_10 STRINGIFY(AX25_P_FLEXNET)
  XLAT(AX25_P_NETROM),
+ #define XLAT_VAL_11 ((unsigned) (AX25_P_NETROM))
+ #define XLAT_STR_11 STRINGIFY(AX25_P_NETROM)
  XLAT(AX25_P_TEXT),
+ #define XLAT_VAL_12 ((unsigned) (AX25_P_TEXT))
+ #define XLAT_STR_12 STRINGIFY(AX25_P_TEXT)
 };
 static
 const struct xlat ax25_protocols[1] = { {
  .data = ax25_protocols_xdata,
  .size = ARRAY_SIZE(ax25_protocols_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/baud_options.h 5.9-0ubuntu2/xlat/baud_options.h
--- 5.5-3/xlat/baud_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/baud_options.h	2020-09-24 09:18:45.000000000 +0000
@@ -15,102 +15,168 @@
 static const struct xlat_data baud_options_xdata[] = {
 #if defined(B0) || (defined(HAVE_DECL_B0) && HAVE_DECL_B0)
   XLAT(B0),
+ #define XLAT_VAL_0 ((unsigned) (B0))
+ #define XLAT_STR_0 STRINGIFY(B0)
 #endif
 #if defined(B50) || (defined(HAVE_DECL_B50) && HAVE_DECL_B50)
   XLAT(B50),
+ #define XLAT_VAL_1 ((unsigned) (B50))
+ #define XLAT_STR_1 STRINGIFY(B50)
 #endif
 #if defined(B75) || (defined(HAVE_DECL_B75) && HAVE_DECL_B75)
   XLAT(B75),
+ #define XLAT_VAL_2 ((unsigned) (B75))
+ #define XLAT_STR_2 STRINGIFY(B75)
 #endif
 #if defined(B110) || (defined(HAVE_DECL_B110) && HAVE_DECL_B110)
   XLAT(B110),
+ #define XLAT_VAL_3 ((unsigned) (B110))
+ #define XLAT_STR_3 STRINGIFY(B110)
 #endif
 #if defined(B134) || (defined(HAVE_DECL_B134) && HAVE_DECL_B134)
   XLAT(B134),
+ #define XLAT_VAL_4 ((unsigned) (B134))
+ #define XLAT_STR_4 STRINGIFY(B134)
 #endif
 #if defined(B150) || (defined(HAVE_DECL_B150) && HAVE_DECL_B150)
   XLAT(B150),
+ #define XLAT_VAL_5 ((unsigned) (B150))
+ #define XLAT_STR_5 STRINGIFY(B150)
 #endif
 #if defined(B200) || (defined(HAVE_DECL_B200) && HAVE_DECL_B200)
   XLAT(B200),
+ #define XLAT_VAL_6 ((unsigned) (B200))
+ #define XLAT_STR_6 STRINGIFY(B200)
 #endif
 #if defined(B300) || (defined(HAVE_DECL_B300) && HAVE_DECL_B300)
   XLAT(B300),
+ #define XLAT_VAL_7 ((unsigned) (B300))
+ #define XLAT_STR_7 STRINGIFY(B300)
 #endif
 #if defined(B600) || (defined(HAVE_DECL_B600) && HAVE_DECL_B600)
   XLAT(B600),
+ #define XLAT_VAL_8 ((unsigned) (B600))
+ #define XLAT_STR_8 STRINGIFY(B600)
 #endif
 #if defined(B1200) || (defined(HAVE_DECL_B1200) && HAVE_DECL_B1200)
   XLAT(B1200),
+ #define XLAT_VAL_9 ((unsigned) (B1200))
+ #define XLAT_STR_9 STRINGIFY(B1200)
 #endif
 #if defined(B1800) || (defined(HAVE_DECL_B1800) && HAVE_DECL_B1800)
   XLAT(B1800),
+ #define XLAT_VAL_10 ((unsigned) (B1800))
+ #define XLAT_STR_10 STRINGIFY(B1800)
 #endif
 #if defined(B2400) || (defined(HAVE_DECL_B2400) && HAVE_DECL_B2400)
   XLAT(B2400),
+ #define XLAT_VAL_11 ((unsigned) (B2400))
+ #define XLAT_STR_11 STRINGIFY(B2400)
 #endif
 #if defined(B4800) || (defined(HAVE_DECL_B4800) && HAVE_DECL_B4800)
   XLAT(B4800),
+ #define XLAT_VAL_12 ((unsigned) (B4800))
+ #define XLAT_STR_12 STRINGIFY(B4800)
 #endif
 #if defined(B9600) || (defined(HAVE_DECL_B9600) && HAVE_DECL_B9600)
   XLAT(B9600),
+ #define XLAT_VAL_13 ((unsigned) (B9600))
+ #define XLAT_STR_13 STRINGIFY(B9600)
 #endif
 #if defined(B19200) || (defined(HAVE_DECL_B19200) && HAVE_DECL_B19200)
   XLAT(B19200),
+ #define XLAT_VAL_14 ((unsigned) (B19200))
+ #define XLAT_STR_14 STRINGIFY(B19200)
 #endif
 #if defined(B38400) || (defined(HAVE_DECL_B38400) && HAVE_DECL_B38400)
   XLAT(B38400),
+ #define XLAT_VAL_15 ((unsigned) (B38400))
+ #define XLAT_STR_15 STRINGIFY(B38400)
 #endif
 #if defined(B57600) || (defined(HAVE_DECL_B57600) && HAVE_DECL_B57600)
   XLAT(B57600),
+ #define XLAT_VAL_16 ((unsigned) (B57600))
+ #define XLAT_STR_16 STRINGIFY(B57600)
 #endif
 #if defined(B115200) || (defined(HAVE_DECL_B115200) && HAVE_DECL_B115200)
   XLAT(B115200),
+ #define XLAT_VAL_17 ((unsigned) (B115200))
+ #define XLAT_STR_17 STRINGIFY(B115200)
 #endif
 #if defined(B230400) || (defined(HAVE_DECL_B230400) && HAVE_DECL_B230400)
   XLAT(B230400),
+ #define XLAT_VAL_18 ((unsigned) (B230400))
+ #define XLAT_STR_18 STRINGIFY(B230400)
 #endif
 #if defined(B460800) || (defined(HAVE_DECL_B460800) && HAVE_DECL_B460800)
   XLAT(B460800),
+ #define XLAT_VAL_19 ((unsigned) (B460800))
+ #define XLAT_STR_19 STRINGIFY(B460800)
 #endif
 #if defined(B500000) || (defined(HAVE_DECL_B500000) && HAVE_DECL_B500000)
   XLAT(B500000),
+ #define XLAT_VAL_20 ((unsigned) (B500000))
+ #define XLAT_STR_20 STRINGIFY(B500000)
 #endif
 #if defined(B576000) || (defined(HAVE_DECL_B576000) && HAVE_DECL_B576000)
   XLAT(B576000),
+ #define XLAT_VAL_21 ((unsigned) (B576000))
+ #define XLAT_STR_21 STRINGIFY(B576000)
 #endif
 #if defined(B921600) || (defined(HAVE_DECL_B921600) && HAVE_DECL_B921600)
   XLAT(B921600),
+ #define XLAT_VAL_22 ((unsigned) (B921600))
+ #define XLAT_STR_22 STRINGIFY(B921600)
 #endif
 #if defined(B1000000) || (defined(HAVE_DECL_B1000000) && HAVE_DECL_B1000000)
   XLAT(B1000000),
+ #define XLAT_VAL_23 ((unsigned) (B1000000))
+ #define XLAT_STR_23 STRINGIFY(B1000000)
 #endif
 #if defined(B1152000) || (defined(HAVE_DECL_B1152000) && HAVE_DECL_B1152000)
   XLAT(B1152000),
+ #define XLAT_VAL_24 ((unsigned) (B1152000))
+ #define XLAT_STR_24 STRINGIFY(B1152000)
 #endif
 #if defined(B1500000) || (defined(HAVE_DECL_B1500000) && HAVE_DECL_B1500000)
   XLAT(B1500000),
+ #define XLAT_VAL_25 ((unsigned) (B1500000))
+ #define XLAT_STR_25 STRINGIFY(B1500000)
 #endif
 #if defined(B2000000) || (defined(HAVE_DECL_B2000000) && HAVE_DECL_B2000000)
   XLAT(B2000000),
+ #define XLAT_VAL_26 ((unsigned) (B2000000))
+ #define XLAT_STR_26 STRINGIFY(B2000000)
 #endif
 #if defined(B2500000) || (defined(HAVE_DECL_B2500000) && HAVE_DECL_B2500000)
   XLAT(B2500000),
+ #define XLAT_VAL_27 ((unsigned) (B2500000))
+ #define XLAT_STR_27 STRINGIFY(B2500000)
 #endif
 #if defined(B3000000) || (defined(HAVE_DECL_B3000000) && HAVE_DECL_B3000000)
   XLAT(B3000000),
+ #define XLAT_VAL_28 ((unsigned) (B3000000))
+ #define XLAT_STR_28 STRINGIFY(B3000000)
 #endif
 #if defined(B3500000) || (defined(HAVE_DECL_B3500000) && HAVE_DECL_B3500000)
   XLAT(B3500000),
+ #define XLAT_VAL_29 ((unsigned) (B3500000))
+ #define XLAT_STR_29 STRINGIFY(B3500000)
 #endif
 #if defined(B4000000) || (defined(HAVE_DECL_B4000000) && HAVE_DECL_B4000000)
   XLAT(B4000000),
+ #define XLAT_VAL_30 ((unsigned) (B4000000))
+ #define XLAT_STR_30 STRINGIFY(B4000000)
 #endif
 #if defined(EXTA) || (defined(HAVE_DECL_EXTA) && HAVE_DECL_EXTA)
   XLAT(EXTA),
+ #define XLAT_VAL_31 ((unsigned) (EXTA))
+ #define XLAT_STR_31 STRINGIFY(EXTA)
 #endif
 #if defined(EXTB) || (defined(HAVE_DECL_EXTB) && HAVE_DECL_EXTB)
   XLAT(EXTB),
+ #define XLAT_VAL_32 ((unsigned) (EXTB))
+ #define XLAT_STR_32 STRINGIFY(EXTB)
 #endif
 };
 static
@@ -118,8 +184,276 @@ const struct xlat baud_options[1] = { {
  .data = baud_options_xdata,
  .size = ARRAY_SIZE(baud_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bdaddr_types.h 5.9-0ubuntu2/xlat/bdaddr_types.h
--- 5.5-3/xlat/bdaddr_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bdaddr_types.h	2020-09-24 09:18:43.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bdaddr_types_xdata[] = {
  [BDADDR_BREDR] = XLAT(BDADDR_BREDR),
+ #define XLAT_VAL_0 ((unsigned) (BDADDR_BREDR))
+ #define XLAT_STR_0 STRINGIFY(BDADDR_BREDR)
  [BDADDR_LE_PUBLIC] = XLAT(BDADDR_LE_PUBLIC),
+ #define XLAT_VAL_1 ((unsigned) (BDADDR_LE_PUBLIC))
+ #define XLAT_STR_1 STRINGIFY(BDADDR_LE_PUBLIC)
  [BDADDR_LE_RANDOM] = XLAT(BDADDR_LE_RANDOM),
+ #define XLAT_VAL_2 ((unsigned) (BDADDR_LE_RANDOM))
+ #define XLAT_STR_2 STRINGIFY(BDADDR_LE_RANDOM)
 };
 static
 const struct xlat bdaddr_types[1] = { {
  .data = bdaddr_types_xdata,
  .size = ARRAY_SIZE(bdaddr_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/blkpg_ops.h 5.9-0ubuntu2/xlat/blkpg_ops.h
--- 5.5-3/xlat/blkpg_ops.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/blkpg_ops.h	2020-09-24 09:18:43.000000000 +0000
@@ -35,8 +35,14 @@ extern const struct xlat blkpg_ops[];
 
 static const struct xlat_data blkpg_ops_xdata[] = {
  [BLKPG_ADD_PARTITION] = XLAT(BLKPG_ADD_PARTITION),
+ #define XLAT_VAL_0 ((unsigned) (BLKPG_ADD_PARTITION))
+ #define XLAT_STR_0 STRINGIFY(BLKPG_ADD_PARTITION)
  [BLKPG_DEL_PARTITION] = XLAT(BLKPG_DEL_PARTITION),
+ #define XLAT_VAL_1 ((unsigned) (BLKPG_DEL_PARTITION))
+ #define XLAT_STR_1 STRINGIFY(BLKPG_DEL_PARTITION)
  [BLKPG_RESIZE_PARTITION] = XLAT(BLKPG_RESIZE_PARTITION),
+ #define XLAT_VAL_2 ((unsigned) (BLKPG_RESIZE_PARTITION))
+ #define XLAT_STR_2 STRINGIFY(BLKPG_RESIZE_PARTITION)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -45,8 +51,36 @@ const struct xlat blkpg_ops[1] = { {
  .data = blkpg_ops_xdata,
  .size = ARRAY_SIZE(blkpg_ops_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/block_ioctl_cmds.h 5.9-0ubuntu2/xlat/block_ioctl_cmds.h
--- 5.5-3/xlat/block_ioctl_cmds.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/block_ioctl_cmds.h	2020-09-24 09:18:44.000000000 +0000
@@ -252,44 +252,112 @@ extern const struct xlat block_ioctl_cmd
 
 static const struct xlat_data block_ioctl_cmds_xdata[] = {
  XLAT(BLKROSET),
+ #define XLAT_VAL_0 ((unsigned) (BLKROSET))
+ #define XLAT_STR_0 STRINGIFY(BLKROSET)
  XLAT(BLKROGET),
+ #define XLAT_VAL_1 ((unsigned) (BLKROGET))
+ #define XLAT_STR_1 STRINGIFY(BLKROGET)
  XLAT(BLKRRPART),
+ #define XLAT_VAL_2 ((unsigned) (BLKRRPART))
+ #define XLAT_STR_2 STRINGIFY(BLKRRPART)
  XLAT(BLKGETSIZE),
+ #define XLAT_VAL_3 ((unsigned) (BLKGETSIZE))
+ #define XLAT_STR_3 STRINGIFY(BLKGETSIZE)
  XLAT(BLKFLSBUF),
+ #define XLAT_VAL_4 ((unsigned) (BLKFLSBUF))
+ #define XLAT_STR_4 STRINGIFY(BLKFLSBUF)
  XLAT(BLKRASET),
+ #define XLAT_VAL_5 ((unsigned) (BLKRASET))
+ #define XLAT_STR_5 STRINGIFY(BLKRASET)
  XLAT(BLKRAGET),
+ #define XLAT_VAL_6 ((unsigned) (BLKRAGET))
+ #define XLAT_STR_6 STRINGIFY(BLKRAGET)
  XLAT(BLKFRASET),
+ #define XLAT_VAL_7 ((unsigned) (BLKFRASET))
+ #define XLAT_STR_7 STRINGIFY(BLKFRASET)
  XLAT(BLKFRAGET),
+ #define XLAT_VAL_8 ((unsigned) (BLKFRAGET))
+ #define XLAT_STR_8 STRINGIFY(BLKFRAGET)
  XLAT(BLKSECTSET),
+ #define XLAT_VAL_9 ((unsigned) (BLKSECTSET))
+ #define XLAT_STR_9 STRINGIFY(BLKSECTSET)
  XLAT(BLKSECTGET),
+ #define XLAT_VAL_10 ((unsigned) (BLKSECTGET))
+ #define XLAT_STR_10 STRINGIFY(BLKSECTGET)
  XLAT(BLKSSZGET),
+ #define XLAT_VAL_11 ((unsigned) (BLKSSZGET))
+ #define XLAT_STR_11 STRINGIFY(BLKSSZGET)
  XLAT(BLKPG),
+ #define XLAT_VAL_12 ((unsigned) (BLKPG))
+ #define XLAT_STR_12 STRINGIFY(BLKPG)
  XLAT(BLKELVGET),
+ #define XLAT_VAL_13 ((unsigned) (BLKELVGET))
+ #define XLAT_STR_13 STRINGIFY(BLKELVGET)
  XLAT(BLKELVSET),
+ #define XLAT_VAL_14 ((unsigned) (BLKELVSET))
+ #define XLAT_STR_14 STRINGIFY(BLKELVSET)
  XLAT(BLKBSZGET),
+ #define XLAT_VAL_15 ((unsigned) (BLKBSZGET))
+ #define XLAT_STR_15 STRINGIFY(BLKBSZGET)
  XLAT(BLKBSZSET),
+ #define XLAT_VAL_16 ((unsigned) (BLKBSZSET))
+ #define XLAT_STR_16 STRINGIFY(BLKBSZSET)
  XLAT(BLKGETSIZE64),
+ #define XLAT_VAL_17 ((unsigned) (BLKGETSIZE64))
+ #define XLAT_STR_17 STRINGIFY(BLKGETSIZE64)
  XLAT(BLKTRACESETUP),
+ #define XLAT_VAL_18 ((unsigned) (BLKTRACESETUP))
+ #define XLAT_STR_18 STRINGIFY(BLKTRACESETUP)
  XLAT(BLKTRACESTART),
+ #define XLAT_VAL_19 ((unsigned) (BLKTRACESTART))
+ #define XLAT_STR_19 STRINGIFY(BLKTRACESTART)
  XLAT(BLKTRACESTOP),
+ #define XLAT_VAL_20 ((unsigned) (BLKTRACESTOP))
+ #define XLAT_STR_20 STRINGIFY(BLKTRACESTOP)
  XLAT(BLKTRACETEARDOWN),
+ #define XLAT_VAL_21 ((unsigned) (BLKTRACETEARDOWN))
+ #define XLAT_STR_21 STRINGIFY(BLKTRACETEARDOWN)
  XLAT(BLKDISCARD),
+ #define XLAT_VAL_22 ((unsigned) (BLKDISCARD))
+ #define XLAT_STR_22 STRINGIFY(BLKDISCARD)
  XLAT(BLKIOMIN),
+ #define XLAT_VAL_23 ((unsigned) (BLKIOMIN))
+ #define XLAT_STR_23 STRINGIFY(BLKIOMIN)
  XLAT(BLKIOOPT),
+ #define XLAT_VAL_24 ((unsigned) (BLKIOOPT))
+ #define XLAT_STR_24 STRINGIFY(BLKIOOPT)
  XLAT(BLKALIGNOFF),
+ #define XLAT_VAL_25 ((unsigned) (BLKALIGNOFF))
+ #define XLAT_STR_25 STRINGIFY(BLKALIGNOFF)
  XLAT(BLKPBSZGET),
+ #define XLAT_VAL_26 ((unsigned) (BLKPBSZGET))
+ #define XLAT_STR_26 STRINGIFY(BLKPBSZGET)
  XLAT(BLKDISCARDZEROES),
+ #define XLAT_VAL_27 ((unsigned) (BLKDISCARDZEROES))
+ #define XLAT_STR_27 STRINGIFY(BLKDISCARDZEROES)
  XLAT(BLKSECDISCARD),
+ #define XLAT_VAL_28 ((unsigned) (BLKSECDISCARD))
+ #define XLAT_STR_28 STRINGIFY(BLKSECDISCARD)
  XLAT(BLKROTATIONAL),
+ #define XLAT_VAL_29 ((unsigned) (BLKROTATIONAL))
+ #define XLAT_STR_29 STRINGIFY(BLKROTATIONAL)
  XLAT(BLKZEROOUT),
+ #define XLAT_VAL_30 ((unsigned) (BLKZEROOUT))
+ #define XLAT_STR_30 STRINGIFY(BLKZEROOUT)
 
 
 
  XLAT(BLKDAXGET),
+ #define XLAT_VAL_31 ((unsigned) (BLKDAXGET))
+ #define XLAT_STR_31 STRINGIFY(BLKDAXGET)
 
 
  XLAT(BLKGETZONESZ),
+ #define XLAT_VAL_32 ((unsigned) (BLKGETZONESZ))
+ #define XLAT_STR_32 STRINGIFY(BLKGETZONESZ)
  XLAT(BLKGETNRZONES),
+ #define XLAT_VAL_33 ((unsigned) (BLKGETNRZONES))
+ #define XLAT_STR_33 STRINGIFY(BLKGETNRZONES)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -298,8 +366,284 @@ const struct xlat block_ioctl_cmds[1] =
  .data = block_ioctl_cmds_xdata,
  .size = ARRAY_SIZE(block_ioctl_cmds_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bluetooth_l2_cid.h 5.9-0ubuntu2/xlat/bluetooth_l2_cid.h
--- 5.5-3/xlat/bluetooth_l2_cid.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bluetooth_l2_cid.h	2020-09-24 09:18:44.000000000 +0000
@@ -84,23 +84,127 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bluetooth_l2_cid_xdata[] = {
  XLAT(L2CAP_CID_SIGNALING),
+ #define XLAT_VAL_0 ((unsigned) (L2CAP_CID_SIGNALING))
+ #define XLAT_STR_0 STRINGIFY(L2CAP_CID_SIGNALING)
  XLAT(L2CAP_CID_CONN_LESS),
+ #define XLAT_VAL_1 ((unsigned) (L2CAP_CID_CONN_LESS))
+ #define XLAT_STR_1 STRINGIFY(L2CAP_CID_CONN_LESS)
  XLAT(L2CAP_CID_A2MP),
+ #define XLAT_VAL_2 ((unsigned) (L2CAP_CID_A2MP))
+ #define XLAT_STR_2 STRINGIFY(L2CAP_CID_A2MP)
  XLAT(L2CAP_CID_ATT),
+ #define XLAT_VAL_3 ((unsigned) (L2CAP_CID_ATT))
+ #define XLAT_STR_3 STRINGIFY(L2CAP_CID_ATT)
  XLAT(L2CAP_CID_LE_SIGNALING),
+ #define XLAT_VAL_4 ((unsigned) (L2CAP_CID_LE_SIGNALING))
+ #define XLAT_STR_4 STRINGIFY(L2CAP_CID_LE_SIGNALING)
  XLAT(L2CAP_CID_SMP),
+ #define XLAT_VAL_5 ((unsigned) (L2CAP_CID_SMP))
+ #define XLAT_STR_5 STRINGIFY(L2CAP_CID_SMP)
  XLAT(L2CAP_CID_SMP_BREDR),
+ #define XLAT_VAL_6 ((unsigned) (L2CAP_CID_SMP_BREDR))
+ #define XLAT_STR_6 STRINGIFY(L2CAP_CID_SMP_BREDR)
  XLAT(L2CAP_CID_DYN_START),
+ #define XLAT_VAL_7 ((unsigned) (L2CAP_CID_DYN_START))
+ #define XLAT_STR_7 STRINGIFY(L2CAP_CID_DYN_START)
  XLAT(L2CAP_CID_LE_DYN_END),
+ #define XLAT_VAL_8 ((unsigned) (L2CAP_CID_LE_DYN_END))
+ #define XLAT_STR_8 STRINGIFY(L2CAP_CID_LE_DYN_END)
  XLAT(L2CAP_CID_DYN_END),
+ #define XLAT_VAL_9 ((unsigned) (L2CAP_CID_DYN_END))
+ #define XLAT_STR_9 STRINGIFY(L2CAP_CID_DYN_END)
 };
 static
 const struct xlat bluetooth_l2_cid[1] = { {
  .data = bluetooth_l2_cid_xdata,
  .size = ARRAY_SIZE(bluetooth_l2_cid_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bluetooth_l2_psm.h 5.9-0ubuntu2/xlat/bluetooth_l2_psm.h
--- 5.5-3/xlat/bluetooth_l2_psm.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bluetooth_l2_psm.h	2020-09-24 09:18:44.000000000 +0000
@@ -77,22 +77,116 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bluetooth_l2_psm_xdata[] = {
  XLAT(L2CAP_PSM_SDP),
+ #define XLAT_VAL_0 ((unsigned) (L2CAP_PSM_SDP))
+ #define XLAT_STR_0 STRINGIFY(L2CAP_PSM_SDP)
  XLAT(L2CAP_PSM_RFCOMM),
+ #define XLAT_VAL_1 ((unsigned) (L2CAP_PSM_RFCOMM))
+ #define XLAT_STR_1 STRINGIFY(L2CAP_PSM_RFCOMM)
  XLAT(L2CAP_PSM_3DSP),
+ #define XLAT_VAL_2 ((unsigned) (L2CAP_PSM_3DSP))
+ #define XLAT_STR_2 STRINGIFY(L2CAP_PSM_3DSP)
  XLAT(L2CAP_PSM_IPSP),
+ #define XLAT_VAL_3 ((unsigned) (L2CAP_PSM_IPSP))
+ #define XLAT_STR_3 STRINGIFY(L2CAP_PSM_IPSP)
  XLAT(L2CAP_PSM_LE_DYN_START),
+ #define XLAT_VAL_4 ((unsigned) (L2CAP_PSM_LE_DYN_START))
+ #define XLAT_STR_4 STRINGIFY(L2CAP_PSM_LE_DYN_START)
  XLAT(L2CAP_PSM_LE_DYN_END),
+ #define XLAT_VAL_5 ((unsigned) (L2CAP_PSM_LE_DYN_END))
+ #define XLAT_STR_5 STRINGIFY(L2CAP_PSM_LE_DYN_END)
  XLAT(L2CAP_PSM_DYN_START),
+ #define XLAT_VAL_6 ((unsigned) (L2CAP_PSM_DYN_START))
+ #define XLAT_STR_6 STRINGIFY(L2CAP_PSM_DYN_START)
  XLAT(L2CAP_PSM_AUTO_END),
+ #define XLAT_VAL_7 ((unsigned) (L2CAP_PSM_AUTO_END))
+ #define XLAT_STR_7 STRINGIFY(L2CAP_PSM_AUTO_END)
  XLAT(L2CAP_PSM_DYN_END),
+ #define XLAT_VAL_8 ((unsigned) (L2CAP_PSM_DYN_END))
+ #define XLAT_STR_8 STRINGIFY(L2CAP_PSM_DYN_END)
 };
 static
 const struct xlat bluetooth_l2_psm[1] = { {
  .data = bluetooth_l2_psm_xdata,
  .size = ARRAY_SIZE(bluetooth_l2_psm_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bootflags1.h 5.9-0ubuntu2/xlat/bootflags1.h
--- 5.5-3/xlat/bootflags1.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bootflags1.h	2020-09-24 09:18:44.000000000 +0000
@@ -21,14 +21,28 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bootflags1_xdata[] = {
  XLAT(LINUX_REBOOT_MAGIC1),
+ #define XLAT_VAL_0 ((unsigned) (LINUX_REBOOT_MAGIC1))
+ #define XLAT_STR_0 STRINGIFY(LINUX_REBOOT_MAGIC1)
 };
 static
 const struct xlat bootflags1[1] = { {
  .data = bootflags1_xdata,
  .size = ARRAY_SIZE(bootflags1_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bootflags2.h 5.9-0ubuntu2/xlat/bootflags2.h
--- 5.5-3/xlat/bootflags2.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bootflags2.h	2020-09-24 09:18:44.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bootflags2_xdata[] = {
  XLAT(LINUX_REBOOT_MAGIC2),
+ #define XLAT_VAL_0 ((unsigned) (LINUX_REBOOT_MAGIC2))
+ #define XLAT_STR_0 STRINGIFY(LINUX_REBOOT_MAGIC2)
  XLAT(LINUX_REBOOT_MAGIC2A),
+ #define XLAT_VAL_1 ((unsigned) (LINUX_REBOOT_MAGIC2A))
+ #define XLAT_STR_1 STRINGIFY(LINUX_REBOOT_MAGIC2A)
  XLAT(LINUX_REBOOT_MAGIC2B),
+ #define XLAT_VAL_2 ((unsigned) (LINUX_REBOOT_MAGIC2B))
+ #define XLAT_STR_2 STRINGIFY(LINUX_REBOOT_MAGIC2B)
  XLAT(LINUX_REBOOT_MAGIC2C),
+ #define XLAT_VAL_3 ((unsigned) (LINUX_REBOOT_MAGIC2C))
+ #define XLAT_STR_3 STRINGIFY(LINUX_REBOOT_MAGIC2C)
 };
 static
 const struct xlat bootflags2[1] = { {
  .data = bootflags2_xdata,
  .size = ARRAY_SIZE(bootflags2_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bootflags3.h 5.9-0ubuntu2/xlat/bootflags3.h
--- 5.5-3/xlat/bootflags3.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bootflags3.h	2020-09-24 09:18:44.000000000 +0000
@@ -70,21 +70,105 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bootflags3_xdata[] = {
  XLAT(LINUX_REBOOT_CMD_RESTART),
+ #define XLAT_VAL_0 ((unsigned) (LINUX_REBOOT_CMD_RESTART))
+ #define XLAT_STR_0 STRINGIFY(LINUX_REBOOT_CMD_RESTART)
  XLAT(LINUX_REBOOT_CMD_HALT),
+ #define XLAT_VAL_1 ((unsigned) (LINUX_REBOOT_CMD_HALT))
+ #define XLAT_STR_1 STRINGIFY(LINUX_REBOOT_CMD_HALT)
  XLAT(LINUX_REBOOT_CMD_CAD_ON),
+ #define XLAT_VAL_2 ((unsigned) (LINUX_REBOOT_CMD_CAD_ON))
+ #define XLAT_STR_2 STRINGIFY(LINUX_REBOOT_CMD_CAD_ON)
  XLAT(LINUX_REBOOT_CMD_CAD_OFF),
+ #define XLAT_VAL_3 ((unsigned) (LINUX_REBOOT_CMD_CAD_OFF))
+ #define XLAT_STR_3 STRINGIFY(LINUX_REBOOT_CMD_CAD_OFF)
  XLAT(LINUX_REBOOT_CMD_POWER_OFF),
+ #define XLAT_VAL_4 ((unsigned) (LINUX_REBOOT_CMD_POWER_OFF))
+ #define XLAT_STR_4 STRINGIFY(LINUX_REBOOT_CMD_POWER_OFF)
  XLAT(LINUX_REBOOT_CMD_RESTART2),
+ #define XLAT_VAL_5 ((unsigned) (LINUX_REBOOT_CMD_RESTART2))
+ #define XLAT_STR_5 STRINGIFY(LINUX_REBOOT_CMD_RESTART2)
  XLAT(LINUX_REBOOT_CMD_SW_SUSPEND),
+ #define XLAT_VAL_6 ((unsigned) (LINUX_REBOOT_CMD_SW_SUSPEND))
+ #define XLAT_STR_6 STRINGIFY(LINUX_REBOOT_CMD_SW_SUSPEND)
  XLAT(LINUX_REBOOT_CMD_KEXEC),
+ #define XLAT_VAL_7 ((unsigned) (LINUX_REBOOT_CMD_KEXEC))
+ #define XLAT_STR_7 STRINGIFY(LINUX_REBOOT_CMD_KEXEC)
 };
 static
 const struct xlat bootflags3[1] = { {
  .data = bootflags3_xdata,
  .size = ARRAY_SIZE(bootflags3_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bpf_attach_flags.h 5.9-0ubuntu2/xlat/bpf_attach_flags.h
--- 5.5-3/xlat/bpf_attach_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bpf_attach_flags.h	2020-09-24 09:18:43.000000000 +0000
@@ -5,17 +5,24 @@
 
 #if defined(BPF_F_ALLOW_OVERRIDE) || (defined(HAVE_DECL_BPF_F_ALLOW_OVERRIDE) && HAVE_DECL_BPF_F_ALLOW_OVERRIDE)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
-static_assert((BPF_F_ALLOW_OVERRIDE) == (1), "BPF_F_ALLOW_OVERRIDE != 1");
+static_assert((BPF_F_ALLOW_OVERRIDE) == (1U), "BPF_F_ALLOW_OVERRIDE != 1U");
 DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
-# define BPF_F_ALLOW_OVERRIDE 1
+# define BPF_F_ALLOW_OVERRIDE 1U
 #endif
 #if defined(BPF_F_ALLOW_MULTI) || (defined(HAVE_DECL_BPF_F_ALLOW_MULTI) && HAVE_DECL_BPF_F_ALLOW_MULTI)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
-static_assert((BPF_F_ALLOW_MULTI) == (2), "BPF_F_ALLOW_MULTI != 2");
+static_assert((BPF_F_ALLOW_MULTI) == ((1U << 1)), "BPF_F_ALLOW_MULTI != (1U << 1)");
 DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
-# define BPF_F_ALLOW_MULTI 2
+# define BPF_F_ALLOW_MULTI (1U << 1)
+#endif
+#if defined(BPF_F_REPLACE) || (defined(HAVE_DECL_BPF_F_REPLACE) && HAVE_DECL_BPF_F_REPLACE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_F_REPLACE) == ((1U << 2)), "BPF_F_REPLACE != (1U << 2)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_F_REPLACE (1U << 2)
 #endif
 
 #ifndef XLAT_MACROS_ONLY
@@ -28,15 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bpf_attach_flags_xdata[] = {
  XLAT(BPF_F_ALLOW_OVERRIDE),
+ #define XLAT_VAL_0 ((unsigned) (BPF_F_ALLOW_OVERRIDE))
+ #define XLAT_STR_0 STRINGIFY(BPF_F_ALLOW_OVERRIDE)
  XLAT(BPF_F_ALLOW_MULTI),
+ #define XLAT_VAL_1 ((unsigned) (BPF_F_ALLOW_MULTI))
+ #define XLAT_STR_1 STRINGIFY(BPF_F_ALLOW_MULTI)
+ XLAT(BPF_F_REPLACE),
+ #define XLAT_VAL_2 ((unsigned) (BPF_F_REPLACE))
+ #define XLAT_STR_2 STRINGIFY(BPF_F_REPLACE)
 };
 static
 const struct xlat bpf_attach_flags[1] = { {
  .data = bpf_attach_flags_xdata,
  .size = ARRAY_SIZE(bpf_attach_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bpf_attach_flags.in 5.9-0ubuntu2/xlat/bpf_attach_flags.in
--- 5.5-3/xlat/bpf_attach_flags.in	2018-03-06 23:52:08.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bpf_attach_flags.in	2020-03-02 22:32:34.000000000 +0000
@@ -1,2 +1,3 @@
-BPF_F_ALLOW_OVERRIDE	1
-BPF_F_ALLOW_MULTI	2
+BPF_F_ALLOW_OVERRIDE	1U
+BPF_F_ALLOW_MULTI	(1U << 1)
+BPF_F_REPLACE		(1U << 2)
diff -pruN 5.5-3/xlat/bpf_attach_type.h 5.9-0ubuntu2/xlat/bpf_attach_type.h
--- 5.5-3/xlat/bpf_attach_type.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bpf_attach_type.h	2020-09-24 09:18:45.000000000 +0000
@@ -185,6 +185,90 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define BPF_TRACE_FEXIT 25
 #endif
+#if defined(BPF_MODIFY_RETURN) || (defined(HAVE_DECL_BPF_MODIFY_RETURN) && HAVE_DECL_BPF_MODIFY_RETURN)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_MODIFY_RETURN) == (26), "BPF_MODIFY_RETURN != 26");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_MODIFY_RETURN 26
+#endif
+#if defined(BPF_LSM_MAC) || (defined(HAVE_DECL_BPF_LSM_MAC) && HAVE_DECL_BPF_LSM_MAC)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_LSM_MAC) == (27), "BPF_LSM_MAC != 27");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_LSM_MAC 27
+#endif
+#if defined(BPF_TRACE_ITER) || (defined(HAVE_DECL_BPF_TRACE_ITER) && HAVE_DECL_BPF_TRACE_ITER)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_TRACE_ITER) == (28), "BPF_TRACE_ITER != 28");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_TRACE_ITER 28
+#endif
+#if defined(BPF_CGROUP_INET4_GETPEERNAME) || (defined(HAVE_DECL_BPF_CGROUP_INET4_GETPEERNAME) && HAVE_DECL_BPF_CGROUP_INET4_GETPEERNAME)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_CGROUP_INET4_GETPEERNAME) == (29), "BPF_CGROUP_INET4_GETPEERNAME != 29");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_CGROUP_INET4_GETPEERNAME 29
+#endif
+#if defined(BPF_CGROUP_INET6_GETPEERNAME) || (defined(HAVE_DECL_BPF_CGROUP_INET6_GETPEERNAME) && HAVE_DECL_BPF_CGROUP_INET6_GETPEERNAME)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_CGROUP_INET6_GETPEERNAME) == (30), "BPF_CGROUP_INET6_GETPEERNAME != 30");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_CGROUP_INET6_GETPEERNAME 30
+#endif
+#if defined(BPF_CGROUP_INET4_GETSOCKNAME) || (defined(HAVE_DECL_BPF_CGROUP_INET4_GETSOCKNAME) && HAVE_DECL_BPF_CGROUP_INET4_GETSOCKNAME)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_CGROUP_INET4_GETSOCKNAME) == (31), "BPF_CGROUP_INET4_GETSOCKNAME != 31");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_CGROUP_INET4_GETSOCKNAME 31
+#endif
+#if defined(BPF_CGROUP_INET6_GETSOCKNAME) || (defined(HAVE_DECL_BPF_CGROUP_INET6_GETSOCKNAME) && HAVE_DECL_BPF_CGROUP_INET6_GETSOCKNAME)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_CGROUP_INET6_GETSOCKNAME) == (32), "BPF_CGROUP_INET6_GETSOCKNAME != 32");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_CGROUP_INET6_GETSOCKNAME 32
+#endif
+#if defined(BPF_XDP_DEVMAP) || (defined(HAVE_DECL_BPF_XDP_DEVMAP) && HAVE_DECL_BPF_XDP_DEVMAP)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_XDP_DEVMAP) == (33), "BPF_XDP_DEVMAP != 33");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_XDP_DEVMAP 33
+#endif
+#if defined(BPF_CGROUP_INET_SOCK_RELEASE) || (defined(HAVE_DECL_BPF_CGROUP_INET_SOCK_RELEASE) && HAVE_DECL_BPF_CGROUP_INET_SOCK_RELEASE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_CGROUP_INET_SOCK_RELEASE) == (34), "BPF_CGROUP_INET_SOCK_RELEASE != 34");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_CGROUP_INET_SOCK_RELEASE 34
+#endif
+#if defined(BPF_XDP_CPUMAP) || (defined(HAVE_DECL_BPF_XDP_CPUMAP) && HAVE_DECL_BPF_XDP_CPUMAP)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_XDP_CPUMAP) == (35), "BPF_XDP_CPUMAP != 35");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_XDP_CPUMAP 35
+#endif
+#if defined(BPF_SK_LOOKUP) || (defined(HAVE_DECL_BPF_SK_LOOKUP) && HAVE_DECL_BPF_SK_LOOKUP)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_SK_LOOKUP) == (36), "BPF_SK_LOOKUP != 36");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_SK_LOOKUP 36
+#endif
+#if defined(BPF_XDP) || (defined(HAVE_DECL_BPF_XDP) && HAVE_DECL_BPF_XDP)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_XDP) == (37), "BPF_XDP != 37");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_XDP 37
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -196,39 +280,435 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bpf_attach_type_xdata[] = {
  [BPF_CGROUP_INET_INGRESS] = XLAT(BPF_CGROUP_INET_INGRESS),
+ #define XLAT_VAL_0 ((unsigned) (BPF_CGROUP_INET_INGRESS))
+ #define XLAT_STR_0 STRINGIFY(BPF_CGROUP_INET_INGRESS)
  [BPF_CGROUP_INET_EGRESS] = XLAT(BPF_CGROUP_INET_EGRESS),
+ #define XLAT_VAL_1 ((unsigned) (BPF_CGROUP_INET_EGRESS))
+ #define XLAT_STR_1 STRINGIFY(BPF_CGROUP_INET_EGRESS)
  [BPF_CGROUP_INET_SOCK_CREATE] = XLAT(BPF_CGROUP_INET_SOCK_CREATE),
+ #define XLAT_VAL_2 ((unsigned) (BPF_CGROUP_INET_SOCK_CREATE))
+ #define XLAT_STR_2 STRINGIFY(BPF_CGROUP_INET_SOCK_CREATE)
  [BPF_CGROUP_SOCK_OPS] = XLAT(BPF_CGROUP_SOCK_OPS),
+ #define XLAT_VAL_3 ((unsigned) (BPF_CGROUP_SOCK_OPS))
+ #define XLAT_STR_3 STRINGIFY(BPF_CGROUP_SOCK_OPS)
  [BPF_SK_SKB_STREAM_PARSER] = XLAT(BPF_SK_SKB_STREAM_PARSER),
+ #define XLAT_VAL_4 ((unsigned) (BPF_SK_SKB_STREAM_PARSER))
+ #define XLAT_STR_4 STRINGIFY(BPF_SK_SKB_STREAM_PARSER)
  [BPF_SK_SKB_STREAM_VERDICT] = XLAT(BPF_SK_SKB_STREAM_VERDICT),
+ #define XLAT_VAL_5 ((unsigned) (BPF_SK_SKB_STREAM_VERDICT))
+ #define XLAT_STR_5 STRINGIFY(BPF_SK_SKB_STREAM_VERDICT)
  [BPF_CGROUP_DEVICE] = XLAT(BPF_CGROUP_DEVICE),
+ #define XLAT_VAL_6 ((unsigned) (BPF_CGROUP_DEVICE))
+ #define XLAT_STR_6 STRINGIFY(BPF_CGROUP_DEVICE)
  [BPF_SK_MSG_VERDICT] = XLAT(BPF_SK_MSG_VERDICT),
+ #define XLAT_VAL_7 ((unsigned) (BPF_SK_MSG_VERDICT))
+ #define XLAT_STR_7 STRINGIFY(BPF_SK_MSG_VERDICT)
  [BPF_CGROUP_INET4_BIND] = XLAT(BPF_CGROUP_INET4_BIND),
+ #define XLAT_VAL_8 ((unsigned) (BPF_CGROUP_INET4_BIND))
+ #define XLAT_STR_8 STRINGIFY(BPF_CGROUP_INET4_BIND)
  [BPF_CGROUP_INET6_BIND] = XLAT(BPF_CGROUP_INET6_BIND),
+ #define XLAT_VAL_9 ((unsigned) (BPF_CGROUP_INET6_BIND))
+ #define XLAT_STR_9 STRINGIFY(BPF_CGROUP_INET6_BIND)
  [BPF_CGROUP_INET4_CONNECT] = XLAT(BPF_CGROUP_INET4_CONNECT),
+ #define XLAT_VAL_10 ((unsigned) (BPF_CGROUP_INET4_CONNECT))
+ #define XLAT_STR_10 STRINGIFY(BPF_CGROUP_INET4_CONNECT)
  [BPF_CGROUP_INET6_CONNECT] = XLAT(BPF_CGROUP_INET6_CONNECT),
+ #define XLAT_VAL_11 ((unsigned) (BPF_CGROUP_INET6_CONNECT))
+ #define XLAT_STR_11 STRINGIFY(BPF_CGROUP_INET6_CONNECT)
  [BPF_CGROUP_INET4_POST_BIND] = XLAT(BPF_CGROUP_INET4_POST_BIND),
+ #define XLAT_VAL_12 ((unsigned) (BPF_CGROUP_INET4_POST_BIND))
+ #define XLAT_STR_12 STRINGIFY(BPF_CGROUP_INET4_POST_BIND)
  [BPF_CGROUP_INET6_POST_BIND] = XLAT(BPF_CGROUP_INET6_POST_BIND),
+ #define XLAT_VAL_13 ((unsigned) (BPF_CGROUP_INET6_POST_BIND))
+ #define XLAT_STR_13 STRINGIFY(BPF_CGROUP_INET6_POST_BIND)
  [BPF_CGROUP_UDP4_SENDMSG] = XLAT(BPF_CGROUP_UDP4_SENDMSG),
+ #define XLAT_VAL_14 ((unsigned) (BPF_CGROUP_UDP4_SENDMSG))
+ #define XLAT_STR_14 STRINGIFY(BPF_CGROUP_UDP4_SENDMSG)
  [BPF_CGROUP_UDP6_SENDMSG] = XLAT(BPF_CGROUP_UDP6_SENDMSG),
+ #define XLAT_VAL_15 ((unsigned) (BPF_CGROUP_UDP6_SENDMSG))
+ #define XLAT_STR_15 STRINGIFY(BPF_CGROUP_UDP6_SENDMSG)
  [BPF_LIRC_MODE2] = XLAT(BPF_LIRC_MODE2),
+ #define XLAT_VAL_16 ((unsigned) (BPF_LIRC_MODE2))
+ #define XLAT_STR_16 STRINGIFY(BPF_LIRC_MODE2)
  [BPF_FLOW_DISSECTOR] = XLAT(BPF_FLOW_DISSECTOR),
+ #define XLAT_VAL_17 ((unsigned) (BPF_FLOW_DISSECTOR))
+ #define XLAT_STR_17 STRINGIFY(BPF_FLOW_DISSECTOR)
  [BPF_CGROUP_SYSCTL] = XLAT(BPF_CGROUP_SYSCTL),
+ #define XLAT_VAL_18 ((unsigned) (BPF_CGROUP_SYSCTL))
+ #define XLAT_STR_18 STRINGIFY(BPF_CGROUP_SYSCTL)
  [BPF_CGROUP_UDP4_RECVMSG] = XLAT(BPF_CGROUP_UDP4_RECVMSG),
+ #define XLAT_VAL_19 ((unsigned) (BPF_CGROUP_UDP4_RECVMSG))
+ #define XLAT_STR_19 STRINGIFY(BPF_CGROUP_UDP4_RECVMSG)
  [BPF_CGROUP_UDP6_RECVMSG] = XLAT(BPF_CGROUP_UDP6_RECVMSG),
+ #define XLAT_VAL_20 ((unsigned) (BPF_CGROUP_UDP6_RECVMSG))
+ #define XLAT_STR_20 STRINGIFY(BPF_CGROUP_UDP6_RECVMSG)
  [BPF_CGROUP_GETSOCKOPT] = XLAT(BPF_CGROUP_GETSOCKOPT),
+ #define XLAT_VAL_21 ((unsigned) (BPF_CGROUP_GETSOCKOPT))
+ #define XLAT_STR_21 STRINGIFY(BPF_CGROUP_GETSOCKOPT)
  [BPF_CGROUP_SETSOCKOPT] = XLAT(BPF_CGROUP_SETSOCKOPT),
+ #define XLAT_VAL_22 ((unsigned) (BPF_CGROUP_SETSOCKOPT))
+ #define XLAT_STR_22 STRINGIFY(BPF_CGROUP_SETSOCKOPT)
  [BPF_TRACE_RAW_TP] = XLAT(BPF_TRACE_RAW_TP),
+ #define XLAT_VAL_23 ((unsigned) (BPF_TRACE_RAW_TP))
+ #define XLAT_STR_23 STRINGIFY(BPF_TRACE_RAW_TP)
  [BPF_TRACE_FENTRY] = XLAT(BPF_TRACE_FENTRY),
+ #define XLAT_VAL_24 ((unsigned) (BPF_TRACE_FENTRY))
+ #define XLAT_STR_24 STRINGIFY(BPF_TRACE_FENTRY)
  [BPF_TRACE_FEXIT] = XLAT(BPF_TRACE_FEXIT),
+ #define XLAT_VAL_25 ((unsigned) (BPF_TRACE_FEXIT))
+ #define XLAT_STR_25 STRINGIFY(BPF_TRACE_FEXIT)
+ [BPF_MODIFY_RETURN] = XLAT(BPF_MODIFY_RETURN),
+ #define XLAT_VAL_26 ((unsigned) (BPF_MODIFY_RETURN))
+ #define XLAT_STR_26 STRINGIFY(BPF_MODIFY_RETURN)
+ [BPF_LSM_MAC] = XLAT(BPF_LSM_MAC),
+ #define XLAT_VAL_27 ((unsigned) (BPF_LSM_MAC))
+ #define XLAT_STR_27 STRINGIFY(BPF_LSM_MAC)
+ [BPF_TRACE_ITER] = XLAT(BPF_TRACE_ITER),
+ #define XLAT_VAL_28 ((unsigned) (BPF_TRACE_ITER))
+ #define XLAT_STR_28 STRINGIFY(BPF_TRACE_ITER)
+ [BPF_CGROUP_INET4_GETPEERNAME] = XLAT(BPF_CGROUP_INET4_GETPEERNAME),
+ #define XLAT_VAL_29 ((unsigned) (BPF_CGROUP_INET4_GETPEERNAME))
+ #define XLAT_STR_29 STRINGIFY(BPF_CGROUP_INET4_GETPEERNAME)
+ [BPF_CGROUP_INET6_GETPEERNAME] = XLAT(BPF_CGROUP_INET6_GETPEERNAME),
+ #define XLAT_VAL_30 ((unsigned) (BPF_CGROUP_INET6_GETPEERNAME))
+ #define XLAT_STR_30 STRINGIFY(BPF_CGROUP_INET6_GETPEERNAME)
+ [BPF_CGROUP_INET4_GETSOCKNAME] = XLAT(BPF_CGROUP_INET4_GETSOCKNAME),
+ #define XLAT_VAL_31 ((unsigned) (BPF_CGROUP_INET4_GETSOCKNAME))
+ #define XLAT_STR_31 STRINGIFY(BPF_CGROUP_INET4_GETSOCKNAME)
+ [BPF_CGROUP_INET6_GETSOCKNAME] = XLAT(BPF_CGROUP_INET6_GETSOCKNAME),
+ #define XLAT_VAL_32 ((unsigned) (BPF_CGROUP_INET6_GETSOCKNAME))
+ #define XLAT_STR_32 STRINGIFY(BPF_CGROUP_INET6_GETSOCKNAME)
+ [BPF_XDP_DEVMAP] = XLAT(BPF_XDP_DEVMAP),
+ #define XLAT_VAL_33 ((unsigned) (BPF_XDP_DEVMAP))
+ #define XLAT_STR_33 STRINGIFY(BPF_XDP_DEVMAP)
+ [BPF_CGROUP_INET_SOCK_RELEASE] = XLAT(BPF_CGROUP_INET_SOCK_RELEASE),
+ #define XLAT_VAL_34 ((unsigned) (BPF_CGROUP_INET_SOCK_RELEASE))
+ #define XLAT_STR_34 STRINGIFY(BPF_CGROUP_INET_SOCK_RELEASE)
+ [BPF_XDP_CPUMAP] = XLAT(BPF_XDP_CPUMAP),
+ #define XLAT_VAL_35 ((unsigned) (BPF_XDP_CPUMAP))
+ #define XLAT_STR_35 STRINGIFY(BPF_XDP_CPUMAP)
+ [BPF_SK_LOOKUP] = XLAT(BPF_SK_LOOKUP),
+ #define XLAT_VAL_36 ((unsigned) (BPF_SK_LOOKUP))
+ #define XLAT_STR_36 STRINGIFY(BPF_SK_LOOKUP)
+ [BPF_XDP] = XLAT(BPF_XDP),
+ #define XLAT_VAL_37 ((unsigned) (BPF_XDP))
+ #define XLAT_STR_37 STRINGIFY(BPF_XDP)
 };
 static
 const struct xlat bpf_attach_type[1] = { {
  .data = bpf_attach_type_xdata,
  .size = ARRAY_SIZE(bpf_attach_type_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bpf_attach_type.in 5.9-0ubuntu2/xlat/bpf_attach_type.in
--- 5.5-3/xlat/bpf_attach_type.in	2019-12-10 09:43:48.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bpf_attach_type.in	2020-09-06 08:00:00.000000000 +0000
@@ -25,3 +25,15 @@ BPF_CGROUP_SETSOCKOPT 22
 BPF_TRACE_RAW_TP 23
 BPF_TRACE_FENTRY 24
 BPF_TRACE_FEXIT 25
+BPF_MODIFY_RETURN 26
+BPF_LSM_MAC 27
+BPF_TRACE_ITER 28
+BPF_CGROUP_INET4_GETPEERNAME 29
+BPF_CGROUP_INET6_GETPEERNAME 30
+BPF_CGROUP_INET4_GETSOCKNAME 31
+BPF_CGROUP_INET6_GETSOCKNAME 32
+BPF_XDP_DEVMAP 33
+BPF_CGROUP_INET_SOCK_RELEASE 34
+BPF_XDP_CPUMAP 35
+BPF_SK_LOOKUP 36
+BPF_XDP 37
diff -pruN 5.5-3/xlat/bpf_class.h 5.9-0ubuntu2/xlat/bpf_class.h
--- 5.5-3/xlat/bpf_class.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bpf_class.h	2020-09-24 09:18:44.000000000 +0000
@@ -70,21 +70,105 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bpf_class_xdata[] = {
  [BPF_LD] = XLAT(BPF_LD),
+ #define XLAT_VAL_0 ((unsigned) (BPF_LD))
+ #define XLAT_STR_0 STRINGIFY(BPF_LD)
  [BPF_LDX] = XLAT(BPF_LDX),
+ #define XLAT_VAL_1 ((unsigned) (BPF_LDX))
+ #define XLAT_STR_1 STRINGIFY(BPF_LDX)
  [BPF_ST] = XLAT(BPF_ST),
+ #define XLAT_VAL_2 ((unsigned) (BPF_ST))
+ #define XLAT_STR_2 STRINGIFY(BPF_ST)
  [BPF_STX] = XLAT(BPF_STX),
+ #define XLAT_VAL_3 ((unsigned) (BPF_STX))
+ #define XLAT_STR_3 STRINGIFY(BPF_STX)
  [BPF_ALU] = XLAT(BPF_ALU),
+ #define XLAT_VAL_4 ((unsigned) (BPF_ALU))
+ #define XLAT_STR_4 STRINGIFY(BPF_ALU)
  [BPF_JMP] = XLAT(BPF_JMP),
+ #define XLAT_VAL_5 ((unsigned) (BPF_JMP))
+ #define XLAT_STR_5 STRINGIFY(BPF_JMP)
  [BPF_RET] = XLAT(BPF_RET),
+ #define XLAT_VAL_6 ((unsigned) (BPF_RET))
+ #define XLAT_STR_6 STRINGIFY(BPF_RET)
  [BPF_MISC] = XLAT(BPF_MISC),
+ #define XLAT_VAL_7 ((unsigned) (BPF_MISC))
+ #define XLAT_STR_7 STRINGIFY(BPF_MISC)
 };
 static
 const struct xlat bpf_class[1] = { {
  .data = bpf_class_xdata,
  .size = ARRAY_SIZE(bpf_class_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bpf_commands.h 5.9-0ubuntu2/xlat/bpf_commands.h
--- 5.5-3/xlat/bpf_commands.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bpf_commands.h	2020-09-24 09:18:44.000000000 +0000
@@ -171,6 +171,83 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define BPF_BTF_GET_NEXT_ID 23
 #endif
+#if defined(BPF_MAP_LOOKUP_BATCH) || (defined(HAVE_DECL_BPF_MAP_LOOKUP_BATCH) && HAVE_DECL_BPF_MAP_LOOKUP_BATCH)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_MAP_LOOKUP_BATCH) == (24), "BPF_MAP_LOOKUP_BATCH != 24");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_MAP_LOOKUP_BATCH 24
+#endif
+#if defined(BPF_MAP_LOOKUP_AND_DELETE_BATCH) || (defined(HAVE_DECL_BPF_MAP_LOOKUP_AND_DELETE_BATCH) && HAVE_DECL_BPF_MAP_LOOKUP_AND_DELETE_BATCH)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_MAP_LOOKUP_AND_DELETE_BATCH) == (25), "BPF_MAP_LOOKUP_AND_DELETE_BATCH != 25");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_MAP_LOOKUP_AND_DELETE_BATCH 25
+#endif
+#if defined(BPF_MAP_UPDATE_BATCH) || (defined(HAVE_DECL_BPF_MAP_UPDATE_BATCH) && HAVE_DECL_BPF_MAP_UPDATE_BATCH)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_MAP_UPDATE_BATCH) == (26), "BPF_MAP_UPDATE_BATCH != 26");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_MAP_UPDATE_BATCH 26
+#endif
+#if defined(BPF_MAP_DELETE_BATCH) || (defined(HAVE_DECL_BPF_MAP_DELETE_BATCH) && HAVE_DECL_BPF_MAP_DELETE_BATCH)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_MAP_DELETE_BATCH) == (27), "BPF_MAP_DELETE_BATCH != 27");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_MAP_DELETE_BATCH 27
+#endif
+#if defined(BPF_LINK_CREATE) || (defined(HAVE_DECL_BPF_LINK_CREATE) && HAVE_DECL_BPF_LINK_CREATE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_LINK_CREATE) == (28), "BPF_LINK_CREATE != 28");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_LINK_CREATE 28
+#endif
+#if defined(BPF_LINK_UPDATE) || (defined(HAVE_DECL_BPF_LINK_UPDATE) && HAVE_DECL_BPF_LINK_UPDATE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_LINK_UPDATE) == (29), "BPF_LINK_UPDATE != 29");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_LINK_UPDATE 29
+#endif
+#if defined(BPF_LINK_GET_FD_BY_ID) || (defined(HAVE_DECL_BPF_LINK_GET_FD_BY_ID) && HAVE_DECL_BPF_LINK_GET_FD_BY_ID)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_LINK_GET_FD_BY_ID) == (30), "BPF_LINK_GET_FD_BY_ID != 30");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_LINK_GET_FD_BY_ID 30
+#endif
+#if defined(BPF_LINK_GET_NEXT_ID) || (defined(HAVE_DECL_BPF_LINK_GET_NEXT_ID) && HAVE_DECL_BPF_LINK_GET_NEXT_ID)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_LINK_GET_NEXT_ID) == (31), "BPF_LINK_GET_NEXT_ID != 31");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_LINK_GET_NEXT_ID 31
+#endif
+#if defined(BPF_ENABLE_STATS) || (defined(HAVE_DECL_BPF_ENABLE_STATS) && HAVE_DECL_BPF_ENABLE_STATS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_ENABLE_STATS) == (32), "BPF_ENABLE_STATS != 32");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_ENABLE_STATS 32
+#endif
+#if defined(BPF_ITER_CREATE) || (defined(HAVE_DECL_BPF_ITER_CREATE) && HAVE_DECL_BPF_ITER_CREATE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_ITER_CREATE) == (33), "BPF_ITER_CREATE != 33");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_ITER_CREATE 33
+#endif
+#if defined(BPF_LINK_DETACH) || (defined(HAVE_DECL_BPF_LINK_DETACH) && HAVE_DECL_BPF_LINK_DETACH)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_LINK_DETACH) == (34), "BPF_LINK_DETACH != 34");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_LINK_DETACH 34
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -182,37 +259,402 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bpf_commands_xdata[] = {
  [BPF_MAP_CREATE] = XLAT(BPF_MAP_CREATE),
+ #define XLAT_VAL_0 ((unsigned) (BPF_MAP_CREATE))
+ #define XLAT_STR_0 STRINGIFY(BPF_MAP_CREATE)
  [BPF_MAP_LOOKUP_ELEM] = XLAT(BPF_MAP_LOOKUP_ELEM),
+ #define XLAT_VAL_1 ((unsigned) (BPF_MAP_LOOKUP_ELEM))
+ #define XLAT_STR_1 STRINGIFY(BPF_MAP_LOOKUP_ELEM)
  [BPF_MAP_UPDATE_ELEM] = XLAT(BPF_MAP_UPDATE_ELEM),
+ #define XLAT_VAL_2 ((unsigned) (BPF_MAP_UPDATE_ELEM))
+ #define XLAT_STR_2 STRINGIFY(BPF_MAP_UPDATE_ELEM)
  [BPF_MAP_DELETE_ELEM] = XLAT(BPF_MAP_DELETE_ELEM),
+ #define XLAT_VAL_3 ((unsigned) (BPF_MAP_DELETE_ELEM))
+ #define XLAT_STR_3 STRINGIFY(BPF_MAP_DELETE_ELEM)
  [BPF_MAP_GET_NEXT_KEY] = XLAT(BPF_MAP_GET_NEXT_KEY),
+ #define XLAT_VAL_4 ((unsigned) (BPF_MAP_GET_NEXT_KEY))
+ #define XLAT_STR_4 STRINGIFY(BPF_MAP_GET_NEXT_KEY)
  [BPF_PROG_LOAD] = XLAT(BPF_PROG_LOAD),
+ #define XLAT_VAL_5 ((unsigned) (BPF_PROG_LOAD))
+ #define XLAT_STR_5 STRINGIFY(BPF_PROG_LOAD)
  [BPF_OBJ_PIN] = XLAT(BPF_OBJ_PIN),
+ #define XLAT_VAL_6 ((unsigned) (BPF_OBJ_PIN))
+ #define XLAT_STR_6 STRINGIFY(BPF_OBJ_PIN)
  [BPF_OBJ_GET] = XLAT(BPF_OBJ_GET),
+ #define XLAT_VAL_7 ((unsigned) (BPF_OBJ_GET))
+ #define XLAT_STR_7 STRINGIFY(BPF_OBJ_GET)
  [BPF_PROG_ATTACH] = XLAT(BPF_PROG_ATTACH),
+ #define XLAT_VAL_8 ((unsigned) (BPF_PROG_ATTACH))
+ #define XLAT_STR_8 STRINGIFY(BPF_PROG_ATTACH)
  [BPF_PROG_DETACH] = XLAT(BPF_PROG_DETACH),
+ #define XLAT_VAL_9 ((unsigned) (BPF_PROG_DETACH))
+ #define XLAT_STR_9 STRINGIFY(BPF_PROG_DETACH)
  [BPF_PROG_TEST_RUN] = XLAT(BPF_PROG_TEST_RUN),
+ #define XLAT_VAL_10 ((unsigned) (BPF_PROG_TEST_RUN))
+ #define XLAT_STR_10 STRINGIFY(BPF_PROG_TEST_RUN)
  [BPF_PROG_GET_NEXT_ID] = XLAT(BPF_PROG_GET_NEXT_ID),
+ #define XLAT_VAL_11 ((unsigned) (BPF_PROG_GET_NEXT_ID))
+ #define XLAT_STR_11 STRINGIFY(BPF_PROG_GET_NEXT_ID)
  [BPF_MAP_GET_NEXT_ID] = XLAT(BPF_MAP_GET_NEXT_ID),
+ #define XLAT_VAL_12 ((unsigned) (BPF_MAP_GET_NEXT_ID))
+ #define XLAT_STR_12 STRINGIFY(BPF_MAP_GET_NEXT_ID)
  [BPF_PROG_GET_FD_BY_ID] = XLAT(BPF_PROG_GET_FD_BY_ID),
+ #define XLAT_VAL_13 ((unsigned) (BPF_PROG_GET_FD_BY_ID))
+ #define XLAT_STR_13 STRINGIFY(BPF_PROG_GET_FD_BY_ID)
  [BPF_MAP_GET_FD_BY_ID] = XLAT(BPF_MAP_GET_FD_BY_ID),
+ #define XLAT_VAL_14 ((unsigned) (BPF_MAP_GET_FD_BY_ID))
+ #define XLAT_STR_14 STRINGIFY(BPF_MAP_GET_FD_BY_ID)
  [BPF_OBJ_GET_INFO_BY_FD] = XLAT(BPF_OBJ_GET_INFO_BY_FD),
+ #define XLAT_VAL_15 ((unsigned) (BPF_OBJ_GET_INFO_BY_FD))
+ #define XLAT_STR_15 STRINGIFY(BPF_OBJ_GET_INFO_BY_FD)
  [BPF_PROG_QUERY] = XLAT(BPF_PROG_QUERY),
+ #define XLAT_VAL_16 ((unsigned) (BPF_PROG_QUERY))
+ #define XLAT_STR_16 STRINGIFY(BPF_PROG_QUERY)
  [BPF_RAW_TRACEPOINT_OPEN] = XLAT(BPF_RAW_TRACEPOINT_OPEN),
+ #define XLAT_VAL_17 ((unsigned) (BPF_RAW_TRACEPOINT_OPEN))
+ #define XLAT_STR_17 STRINGIFY(BPF_RAW_TRACEPOINT_OPEN)
  [BPF_BTF_LOAD] = XLAT(BPF_BTF_LOAD),
+ #define XLAT_VAL_18 ((unsigned) (BPF_BTF_LOAD))
+ #define XLAT_STR_18 STRINGIFY(BPF_BTF_LOAD)
  [BPF_BTF_GET_FD_BY_ID] = XLAT(BPF_BTF_GET_FD_BY_ID),
+ #define XLAT_VAL_19 ((unsigned) (BPF_BTF_GET_FD_BY_ID))
+ #define XLAT_STR_19 STRINGIFY(BPF_BTF_GET_FD_BY_ID)
  [BPF_TASK_FD_QUERY] = XLAT(BPF_TASK_FD_QUERY),
+ #define XLAT_VAL_20 ((unsigned) (BPF_TASK_FD_QUERY))
+ #define XLAT_STR_20 STRINGIFY(BPF_TASK_FD_QUERY)
  [BPF_MAP_LOOKUP_AND_DELETE_ELEM] = XLAT(BPF_MAP_LOOKUP_AND_DELETE_ELEM),
+ #define XLAT_VAL_21 ((unsigned) (BPF_MAP_LOOKUP_AND_DELETE_ELEM))
+ #define XLAT_STR_21 STRINGIFY(BPF_MAP_LOOKUP_AND_DELETE_ELEM)
  [BPF_MAP_FREEZE] = XLAT(BPF_MAP_FREEZE),
+ #define XLAT_VAL_22 ((unsigned) (BPF_MAP_FREEZE))
+ #define XLAT_STR_22 STRINGIFY(BPF_MAP_FREEZE)
  [BPF_BTF_GET_NEXT_ID] = XLAT(BPF_BTF_GET_NEXT_ID),
+ #define XLAT_VAL_23 ((unsigned) (BPF_BTF_GET_NEXT_ID))
+ #define XLAT_STR_23 STRINGIFY(BPF_BTF_GET_NEXT_ID)
+ [BPF_MAP_LOOKUP_BATCH] = XLAT(BPF_MAP_LOOKUP_BATCH),
+ #define XLAT_VAL_24 ((unsigned) (BPF_MAP_LOOKUP_BATCH))
+ #define XLAT_STR_24 STRINGIFY(BPF_MAP_LOOKUP_BATCH)
+ [BPF_MAP_LOOKUP_AND_DELETE_BATCH] = XLAT(BPF_MAP_LOOKUP_AND_DELETE_BATCH),
+ #define XLAT_VAL_25 ((unsigned) (BPF_MAP_LOOKUP_AND_DELETE_BATCH))
+ #define XLAT_STR_25 STRINGIFY(BPF_MAP_LOOKUP_AND_DELETE_BATCH)
+ [BPF_MAP_UPDATE_BATCH] = XLAT(BPF_MAP_UPDATE_BATCH),
+ #define XLAT_VAL_26 ((unsigned) (BPF_MAP_UPDATE_BATCH))
+ #define XLAT_STR_26 STRINGIFY(BPF_MAP_UPDATE_BATCH)
+ [BPF_MAP_DELETE_BATCH] = XLAT(BPF_MAP_DELETE_BATCH),
+ #define XLAT_VAL_27 ((unsigned) (BPF_MAP_DELETE_BATCH))
+ #define XLAT_STR_27 STRINGIFY(BPF_MAP_DELETE_BATCH)
+ [BPF_LINK_CREATE] = XLAT(BPF_LINK_CREATE),
+ #define XLAT_VAL_28 ((unsigned) (BPF_LINK_CREATE))
+ #define XLAT_STR_28 STRINGIFY(BPF_LINK_CREATE)
+ [BPF_LINK_UPDATE] = XLAT(BPF_LINK_UPDATE),
+ #define XLAT_VAL_29 ((unsigned) (BPF_LINK_UPDATE))
+ #define XLAT_STR_29 STRINGIFY(BPF_LINK_UPDATE)
+ [BPF_LINK_GET_FD_BY_ID] = XLAT(BPF_LINK_GET_FD_BY_ID),
+ #define XLAT_VAL_30 ((unsigned) (BPF_LINK_GET_FD_BY_ID))
+ #define XLAT_STR_30 STRINGIFY(BPF_LINK_GET_FD_BY_ID)
+ [BPF_LINK_GET_NEXT_ID] = XLAT(BPF_LINK_GET_NEXT_ID),
+ #define XLAT_VAL_31 ((unsigned) (BPF_LINK_GET_NEXT_ID))
+ #define XLAT_STR_31 STRINGIFY(BPF_LINK_GET_NEXT_ID)
+ [BPF_ENABLE_STATS] = XLAT(BPF_ENABLE_STATS),
+ #define XLAT_VAL_32 ((unsigned) (BPF_ENABLE_STATS))
+ #define XLAT_STR_32 STRINGIFY(BPF_ENABLE_STATS)
+ [BPF_ITER_CREATE] = XLAT(BPF_ITER_CREATE),
+ #define XLAT_VAL_33 ((unsigned) (BPF_ITER_CREATE))
+ #define XLAT_STR_33 STRINGIFY(BPF_ITER_CREATE)
+ [BPF_LINK_DETACH] = XLAT(BPF_LINK_DETACH),
+ #define XLAT_VAL_34 ((unsigned) (BPF_LINK_DETACH))
+ #define XLAT_STR_34 STRINGIFY(BPF_LINK_DETACH)
 };
 static
 const struct xlat bpf_commands[1] = { {
  .data = bpf_commands_xdata,
  .size = ARRAY_SIZE(bpf_commands_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bpf_commands.in 5.9-0ubuntu2/xlat/bpf_commands.in
--- 5.5-3/xlat/bpf_commands.in	2019-11-14 23:27:47.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bpf_commands.in	2020-09-06 08:00:00.000000000 +0000
@@ -23,3 +23,14 @@ BPF_TASK_FD_QUERY 20
 BPF_MAP_LOOKUP_AND_DELETE_ELEM 21
 BPF_MAP_FREEZE 22
 BPF_BTF_GET_NEXT_ID 23
+BPF_MAP_LOOKUP_BATCH 24
+BPF_MAP_LOOKUP_AND_DELETE_BATCH 25
+BPF_MAP_UPDATE_BATCH 26
+BPF_MAP_DELETE_BATCH 27
+BPF_LINK_CREATE 28
+BPF_LINK_UPDATE 29
+BPF_LINK_GET_FD_BY_ID 30
+BPF_LINK_GET_NEXT_ID 31
+BPF_ENABLE_STATS 32
+BPF_ITER_CREATE 33
+BPF_LINK_DETACH 34
diff -pruN 5.5-3/xlat/bpf_file_mode_flags.h 5.9-0ubuntu2/xlat/bpf_file_mode_flags.h
--- 5.5-3/xlat/bpf_file_mode_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bpf_file_mode_flags.h	2020-09-24 09:18:43.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bpf_file_mode_flags_xdata[] = {
  XLAT(BPF_F_RDONLY),
+ #define XLAT_VAL_0 ((unsigned) (BPF_F_RDONLY))
+ #define XLAT_STR_0 STRINGIFY(BPF_F_RDONLY)
  XLAT(BPF_F_WRONLY),
+ #define XLAT_VAL_1 ((unsigned) (BPF_F_WRONLY))
+ #define XLAT_STR_1 STRINGIFY(BPF_F_WRONLY)
 };
 static
 const struct xlat bpf_file_mode_flags[1] = { {
  .data = bpf_file_mode_flags_xdata,
  .size = ARRAY_SIZE(bpf_file_mode_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bpf_map_flags.h 5.9-0ubuntu2/xlat/bpf_map_flags.h
--- 5.5-3/xlat/bpf_map_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bpf_map_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -91,24 +91,138 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bpf_map_flags_xdata[] = {
  XLAT(BPF_F_NO_PREALLOC),
+ #define XLAT_VAL_0 ((unsigned) (BPF_F_NO_PREALLOC))
+ #define XLAT_STR_0 STRINGIFY(BPF_F_NO_PREALLOC)
  XLAT(BPF_F_NO_COMMON_LRU),
+ #define XLAT_VAL_1 ((unsigned) (BPF_F_NO_COMMON_LRU))
+ #define XLAT_STR_1 STRINGIFY(BPF_F_NO_COMMON_LRU)
  XLAT(BPF_F_NUMA_NODE),
+ #define XLAT_VAL_2 ((unsigned) (BPF_F_NUMA_NODE))
+ #define XLAT_STR_2 STRINGIFY(BPF_F_NUMA_NODE)
  XLAT(BPF_F_RDONLY),
+ #define XLAT_VAL_3 ((unsigned) (BPF_F_RDONLY))
+ #define XLAT_STR_3 STRINGIFY(BPF_F_RDONLY)
  XLAT(BPF_F_WRONLY),
+ #define XLAT_VAL_4 ((unsigned) (BPF_F_WRONLY))
+ #define XLAT_STR_4 STRINGIFY(BPF_F_WRONLY)
  XLAT(BPF_F_STACK_BUILD_ID),
+ #define XLAT_VAL_5 ((unsigned) (BPF_F_STACK_BUILD_ID))
+ #define XLAT_STR_5 STRINGIFY(BPF_F_STACK_BUILD_ID)
  XLAT(BPF_F_ZERO_SEED),
+ #define XLAT_VAL_6 ((unsigned) (BPF_F_ZERO_SEED))
+ #define XLAT_STR_6 STRINGIFY(BPF_F_ZERO_SEED)
  XLAT(BPF_F_RDONLY_PROG),
+ #define XLAT_VAL_7 ((unsigned) (BPF_F_RDONLY_PROG))
+ #define XLAT_STR_7 STRINGIFY(BPF_F_RDONLY_PROG)
  XLAT(BPF_F_WRONLY_PROG),
+ #define XLAT_VAL_8 ((unsigned) (BPF_F_WRONLY_PROG))
+ #define XLAT_STR_8 STRINGIFY(BPF_F_WRONLY_PROG)
  XLAT(BPF_F_CLONE),
+ #define XLAT_VAL_9 ((unsigned) (BPF_F_CLONE))
+ #define XLAT_STR_9 STRINGIFY(BPF_F_CLONE)
  XLAT(BPF_F_MMAPABLE),
+ #define XLAT_VAL_10 ((unsigned) (BPF_F_MMAPABLE))
+ #define XLAT_STR_10 STRINGIFY(BPF_F_MMAPABLE)
 };
 static
 const struct xlat bpf_map_flags[1] = { {
  .data = bpf_map_flags_xdata,
  .size = ARRAY_SIZE(bpf_map_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bpf_map_lookup_elem_flags.h 5.9-0ubuntu2/xlat/bpf_map_lookup_elem_flags.h
--- 5.5-3/xlat/bpf_map_lookup_elem_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bpf_map_lookup_elem_flags.h	2020-09-24 09:18:43.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bpf_map_lookup_elem_flags_xdata[] = {
  XLAT(BPF_ANY),
+ #define XLAT_VAL_0 ((unsigned) (BPF_ANY))
+ #define XLAT_STR_0 STRINGIFY(BPF_ANY)
  XLAT(BPF_F_LOCK),
+ #define XLAT_VAL_1 ((unsigned) (BPF_F_LOCK))
+ #define XLAT_STR_1 STRINGIFY(BPF_F_LOCK)
 };
 static
 const struct xlat bpf_map_lookup_elem_flags[1] = { {
  .data = bpf_map_lookup_elem_flags_xdata,
  .size = ARRAY_SIZE(bpf_map_lookup_elem_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bpf_map_types.h 5.9-0ubuntu2/xlat/bpf_map_types.h
--- 5.5-3/xlat/bpf_map_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bpf_map_types.h	2020-09-24 09:18:44.000000000 +0000
@@ -185,6 +185,20 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define BPF_MAP_TYPE_DEVMAP_HASH 25
 #endif
+#if defined(BPF_MAP_TYPE_STRUCT_OPS) || (defined(HAVE_DECL_BPF_MAP_TYPE_STRUCT_OPS) && HAVE_DECL_BPF_MAP_TYPE_STRUCT_OPS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_MAP_TYPE_STRUCT_OPS) == (26), "BPF_MAP_TYPE_STRUCT_OPS != 26");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_MAP_TYPE_STRUCT_OPS 26
+#endif
+#if defined(BPF_MAP_TYPE_RINGBUF) || (defined(HAVE_DECL_BPF_MAP_TYPE_RINGBUF) && HAVE_DECL_BPF_MAP_TYPE_RINGBUF)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_MAP_TYPE_RINGBUF) == (27), "BPF_MAP_TYPE_RINGBUF != 27");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_MAP_TYPE_RINGBUF 27
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -196,39 +210,325 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bpf_map_types_xdata[] = {
  [BPF_MAP_TYPE_UNSPEC] = XLAT(BPF_MAP_TYPE_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (BPF_MAP_TYPE_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(BPF_MAP_TYPE_UNSPEC)
  [BPF_MAP_TYPE_HASH] = XLAT(BPF_MAP_TYPE_HASH),
+ #define XLAT_VAL_1 ((unsigned) (BPF_MAP_TYPE_HASH))
+ #define XLAT_STR_1 STRINGIFY(BPF_MAP_TYPE_HASH)
  [BPF_MAP_TYPE_ARRAY] = XLAT(BPF_MAP_TYPE_ARRAY),
+ #define XLAT_VAL_2 ((unsigned) (BPF_MAP_TYPE_ARRAY))
+ #define XLAT_STR_2 STRINGIFY(BPF_MAP_TYPE_ARRAY)
  [BPF_MAP_TYPE_PROG_ARRAY] = XLAT(BPF_MAP_TYPE_PROG_ARRAY),
+ #define XLAT_VAL_3 ((unsigned) (BPF_MAP_TYPE_PROG_ARRAY))
+ #define XLAT_STR_3 STRINGIFY(BPF_MAP_TYPE_PROG_ARRAY)
  [BPF_MAP_TYPE_PERF_EVENT_ARRAY] = XLAT(BPF_MAP_TYPE_PERF_EVENT_ARRAY),
+ #define XLAT_VAL_4 ((unsigned) (BPF_MAP_TYPE_PERF_EVENT_ARRAY))
+ #define XLAT_STR_4 STRINGIFY(BPF_MAP_TYPE_PERF_EVENT_ARRAY)
  [BPF_MAP_TYPE_PERCPU_HASH] = XLAT(BPF_MAP_TYPE_PERCPU_HASH),
+ #define XLAT_VAL_5 ((unsigned) (BPF_MAP_TYPE_PERCPU_HASH))
+ #define XLAT_STR_5 STRINGIFY(BPF_MAP_TYPE_PERCPU_HASH)
  [BPF_MAP_TYPE_PERCPU_ARRAY] = XLAT(BPF_MAP_TYPE_PERCPU_ARRAY),
+ #define XLAT_VAL_6 ((unsigned) (BPF_MAP_TYPE_PERCPU_ARRAY))
+ #define XLAT_STR_6 STRINGIFY(BPF_MAP_TYPE_PERCPU_ARRAY)
  [BPF_MAP_TYPE_STACK_TRACE] = XLAT(BPF_MAP_TYPE_STACK_TRACE),
+ #define XLAT_VAL_7 ((unsigned) (BPF_MAP_TYPE_STACK_TRACE))
+ #define XLAT_STR_7 STRINGIFY(BPF_MAP_TYPE_STACK_TRACE)
  [BPF_MAP_TYPE_CGROUP_ARRAY] = XLAT(BPF_MAP_TYPE_CGROUP_ARRAY),
+ #define XLAT_VAL_8 ((unsigned) (BPF_MAP_TYPE_CGROUP_ARRAY))
+ #define XLAT_STR_8 STRINGIFY(BPF_MAP_TYPE_CGROUP_ARRAY)
  [BPF_MAP_TYPE_LRU_HASH] = XLAT(BPF_MAP_TYPE_LRU_HASH),
+ #define XLAT_VAL_9 ((unsigned) (BPF_MAP_TYPE_LRU_HASH))
+ #define XLAT_STR_9 STRINGIFY(BPF_MAP_TYPE_LRU_HASH)
  [BPF_MAP_TYPE_LRU_PERCPU_HASH] = XLAT(BPF_MAP_TYPE_LRU_PERCPU_HASH),
+ #define XLAT_VAL_10 ((unsigned) (BPF_MAP_TYPE_LRU_PERCPU_HASH))
+ #define XLAT_STR_10 STRINGIFY(BPF_MAP_TYPE_LRU_PERCPU_HASH)
  [BPF_MAP_TYPE_LPM_TRIE] = XLAT(BPF_MAP_TYPE_LPM_TRIE),
+ #define XLAT_VAL_11 ((unsigned) (BPF_MAP_TYPE_LPM_TRIE))
+ #define XLAT_STR_11 STRINGIFY(BPF_MAP_TYPE_LPM_TRIE)
  [BPF_MAP_TYPE_ARRAY_OF_MAPS] = XLAT(BPF_MAP_TYPE_ARRAY_OF_MAPS),
+ #define XLAT_VAL_12 ((unsigned) (BPF_MAP_TYPE_ARRAY_OF_MAPS))
+ #define XLAT_STR_12 STRINGIFY(BPF_MAP_TYPE_ARRAY_OF_MAPS)
  [BPF_MAP_TYPE_HASH_OF_MAPS] = XLAT(BPF_MAP_TYPE_HASH_OF_MAPS),
+ #define XLAT_VAL_13 ((unsigned) (BPF_MAP_TYPE_HASH_OF_MAPS))
+ #define XLAT_STR_13 STRINGIFY(BPF_MAP_TYPE_HASH_OF_MAPS)
  [BPF_MAP_TYPE_DEVMAP] = XLAT(BPF_MAP_TYPE_DEVMAP),
+ #define XLAT_VAL_14 ((unsigned) (BPF_MAP_TYPE_DEVMAP))
+ #define XLAT_STR_14 STRINGIFY(BPF_MAP_TYPE_DEVMAP)
  [BPF_MAP_TYPE_SOCKMAP] = XLAT(BPF_MAP_TYPE_SOCKMAP),
+ #define XLAT_VAL_15 ((unsigned) (BPF_MAP_TYPE_SOCKMAP))
+ #define XLAT_STR_15 STRINGIFY(BPF_MAP_TYPE_SOCKMAP)
  [BPF_MAP_TYPE_CPUMAP] = XLAT(BPF_MAP_TYPE_CPUMAP),
+ #define XLAT_VAL_16 ((unsigned) (BPF_MAP_TYPE_CPUMAP))
+ #define XLAT_STR_16 STRINGIFY(BPF_MAP_TYPE_CPUMAP)
  [BPF_MAP_TYPE_XSKMAP] = XLAT(BPF_MAP_TYPE_XSKMAP),
+ #define XLAT_VAL_17 ((unsigned) (BPF_MAP_TYPE_XSKMAP))
+ #define XLAT_STR_17 STRINGIFY(BPF_MAP_TYPE_XSKMAP)
  [BPF_MAP_TYPE_SOCKHASH] = XLAT(BPF_MAP_TYPE_SOCKHASH),
+ #define XLAT_VAL_18 ((unsigned) (BPF_MAP_TYPE_SOCKHASH))
+ #define XLAT_STR_18 STRINGIFY(BPF_MAP_TYPE_SOCKHASH)
  [BPF_MAP_TYPE_CGROUP_STORAGE] = XLAT(BPF_MAP_TYPE_CGROUP_STORAGE),
+ #define XLAT_VAL_19 ((unsigned) (BPF_MAP_TYPE_CGROUP_STORAGE))
+ #define XLAT_STR_19 STRINGIFY(BPF_MAP_TYPE_CGROUP_STORAGE)
  [BPF_MAP_TYPE_REUSEPORT_SOCKARRAY] = XLAT(BPF_MAP_TYPE_REUSEPORT_SOCKARRAY),
+ #define XLAT_VAL_20 ((unsigned) (BPF_MAP_TYPE_REUSEPORT_SOCKARRAY))
+ #define XLAT_STR_20 STRINGIFY(BPF_MAP_TYPE_REUSEPORT_SOCKARRAY)
  [BPF_MAP_TYPE_PERCPU_CGROUP_STORAGE] = XLAT(BPF_MAP_TYPE_PERCPU_CGROUP_STORAGE),
+ #define XLAT_VAL_21 ((unsigned) (BPF_MAP_TYPE_PERCPU_CGROUP_STORAGE))
+ #define XLAT_STR_21 STRINGIFY(BPF_MAP_TYPE_PERCPU_CGROUP_STORAGE)
  [BPF_MAP_TYPE_QUEUE] = XLAT(BPF_MAP_TYPE_QUEUE),
+ #define XLAT_VAL_22 ((unsigned) (BPF_MAP_TYPE_QUEUE))
+ #define XLAT_STR_22 STRINGIFY(BPF_MAP_TYPE_QUEUE)
  [BPF_MAP_TYPE_STACK] = XLAT(BPF_MAP_TYPE_STACK),
+ #define XLAT_VAL_23 ((unsigned) (BPF_MAP_TYPE_STACK))
+ #define XLAT_STR_23 STRINGIFY(BPF_MAP_TYPE_STACK)
  [BPF_MAP_TYPE_SK_STORAGE] = XLAT(BPF_MAP_TYPE_SK_STORAGE),
+ #define XLAT_VAL_24 ((unsigned) (BPF_MAP_TYPE_SK_STORAGE))
+ #define XLAT_STR_24 STRINGIFY(BPF_MAP_TYPE_SK_STORAGE)
  [BPF_MAP_TYPE_DEVMAP_HASH] = XLAT(BPF_MAP_TYPE_DEVMAP_HASH),
+ #define XLAT_VAL_25 ((unsigned) (BPF_MAP_TYPE_DEVMAP_HASH))
+ #define XLAT_STR_25 STRINGIFY(BPF_MAP_TYPE_DEVMAP_HASH)
+ [BPF_MAP_TYPE_STRUCT_OPS] = XLAT(BPF_MAP_TYPE_STRUCT_OPS),
+ #define XLAT_VAL_26 ((unsigned) (BPF_MAP_TYPE_STRUCT_OPS))
+ #define XLAT_STR_26 STRINGIFY(BPF_MAP_TYPE_STRUCT_OPS)
+ [BPF_MAP_TYPE_RINGBUF] = XLAT(BPF_MAP_TYPE_RINGBUF),
+ #define XLAT_VAL_27 ((unsigned) (BPF_MAP_TYPE_RINGBUF))
+ #define XLAT_STR_27 STRINGIFY(BPF_MAP_TYPE_RINGBUF)
 };
 static
 const struct xlat bpf_map_types[1] = { {
  .data = bpf_map_types_xdata,
  .size = ARRAY_SIZE(bpf_map_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bpf_map_types.in 5.9-0ubuntu2/xlat/bpf_map_types.in
--- 5.5-3/xlat/bpf_map_types.in	2019-10-20 18:12:37.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bpf_map_types.in	2020-06-30 08:00:00.000000000 +0000
@@ -25,3 +25,5 @@ BPF_MAP_TYPE_QUEUE 22
 BPF_MAP_TYPE_STACK 23
 BPF_MAP_TYPE_SK_STORAGE 24
 BPF_MAP_TYPE_DEVMAP_HASH 25
+BPF_MAP_TYPE_STRUCT_OPS 26
+BPF_MAP_TYPE_RINGBUF 27
diff -pruN 5.5-3/xlat/bpf_map_update_elem_flags.h 5.9-0ubuntu2/xlat/bpf_map_update_elem_flags.h
--- 5.5-3/xlat/bpf_map_update_elem_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bpf_map_update_elem_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bpf_map_update_elem_flags_xdata[] = {
  [BPF_ANY] = XLAT(BPF_ANY),
+ #define XLAT_VAL_0 ((unsigned) (BPF_ANY))
+ #define XLAT_STR_0 STRINGIFY(BPF_ANY)
  [BPF_NOEXIST] = XLAT(BPF_NOEXIST),
+ #define XLAT_VAL_1 ((unsigned) (BPF_NOEXIST))
+ #define XLAT_STR_1 STRINGIFY(BPF_NOEXIST)
  [BPF_EXIST] = XLAT(BPF_EXIST),
+ #define XLAT_VAL_2 ((unsigned) (BPF_EXIST))
+ #define XLAT_STR_2 STRINGIFY(BPF_EXIST)
  [BPF_F_LOCK] = XLAT(BPF_F_LOCK),
+ #define XLAT_VAL_3 ((unsigned) (BPF_F_LOCK))
+ #define XLAT_STR_3 STRINGIFY(BPF_F_LOCK)
 };
 static
 const struct xlat bpf_map_update_elem_flags[1] = { {
  .data = bpf_map_update_elem_flags_xdata,
  .size = ARRAY_SIZE(bpf_map_update_elem_flags_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bpf_miscop.h 5.9-0ubuntu2/xlat/bpf_miscop.h
--- 5.5-3/xlat/bpf_miscop.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bpf_miscop.h	2020-09-24 09:18:43.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bpf_miscop_xdata[] = {
  XLAT(BPF_TAX),
+ #define XLAT_VAL_0 ((unsigned) (BPF_TAX))
+ #define XLAT_STR_0 STRINGIFY(BPF_TAX)
  XLAT(BPF_TXA),
+ #define XLAT_VAL_1 ((unsigned) (BPF_TXA))
+ #define XLAT_STR_1 STRINGIFY(BPF_TXA)
 };
 static
 const struct xlat bpf_miscop[1] = { {
  .data = bpf_miscop_xdata,
  .size = ARRAY_SIZE(bpf_miscop_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bpf_mode.h 5.9-0ubuntu2/xlat/bpf_mode.h
--- 5.5-3/xlat/bpf_mode.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bpf_mode.h	2020-09-24 09:18:44.000000000 +0000
@@ -63,20 +63,94 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bpf_mode_xdata[] = {
  XLAT(BPF_IMM),
+ #define XLAT_VAL_0 ((unsigned) (BPF_IMM))
+ #define XLAT_STR_0 STRINGIFY(BPF_IMM)
  XLAT(BPF_ABS),
+ #define XLAT_VAL_1 ((unsigned) (BPF_ABS))
+ #define XLAT_STR_1 STRINGIFY(BPF_ABS)
  XLAT(BPF_IND),
+ #define XLAT_VAL_2 ((unsigned) (BPF_IND))
+ #define XLAT_STR_2 STRINGIFY(BPF_IND)
  XLAT(BPF_MEM),
+ #define XLAT_VAL_3 ((unsigned) (BPF_MEM))
+ #define XLAT_STR_3 STRINGIFY(BPF_MEM)
  XLAT(BPF_LEN),
+ #define XLAT_VAL_4 ((unsigned) (BPF_LEN))
+ #define XLAT_STR_4 STRINGIFY(BPF_LEN)
  XLAT(BPF_MSH),
+ #define XLAT_VAL_5 ((unsigned) (BPF_MSH))
+ #define XLAT_STR_5 STRINGIFY(BPF_MSH)
  XLAT(BPF_XADD),
+ #define XLAT_VAL_6 ((unsigned) (BPF_XADD))
+ #define XLAT_STR_6 STRINGIFY(BPF_XADD)
 };
 static
 const struct xlat bpf_mode[1] = { {
  .data = bpf_mode_xdata,
  .size = ARRAY_SIZE(bpf_mode_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bpf_op_alu.h 5.9-0ubuntu2/xlat/bpf_op_alu.h
--- 5.5-3/xlat/bpf_op_alu.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bpf_op_alu.h	2020-09-24 09:18:44.000000000 +0000
@@ -112,27 +112,171 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bpf_op_alu_xdata[] = {
  XLAT(BPF_ADD),
+ #define XLAT_VAL_0 ((unsigned) (BPF_ADD))
+ #define XLAT_STR_0 STRINGIFY(BPF_ADD)
  XLAT(BPF_SUB),
+ #define XLAT_VAL_1 ((unsigned) (BPF_SUB))
+ #define XLAT_STR_1 STRINGIFY(BPF_SUB)
  XLAT(BPF_MUL),
+ #define XLAT_VAL_2 ((unsigned) (BPF_MUL))
+ #define XLAT_STR_2 STRINGIFY(BPF_MUL)
  XLAT(BPF_DIV),
+ #define XLAT_VAL_3 ((unsigned) (BPF_DIV))
+ #define XLAT_STR_3 STRINGIFY(BPF_DIV)
  XLAT(BPF_OR),
+ #define XLAT_VAL_4 ((unsigned) (BPF_OR))
+ #define XLAT_STR_4 STRINGIFY(BPF_OR)
  XLAT(BPF_AND),
+ #define XLAT_VAL_5 ((unsigned) (BPF_AND))
+ #define XLAT_STR_5 STRINGIFY(BPF_AND)
  XLAT(BPF_LSH),
+ #define XLAT_VAL_6 ((unsigned) (BPF_LSH))
+ #define XLAT_STR_6 STRINGIFY(BPF_LSH)
  XLAT(BPF_RSH),
+ #define XLAT_VAL_7 ((unsigned) (BPF_RSH))
+ #define XLAT_STR_7 STRINGIFY(BPF_RSH)
  XLAT(BPF_NEG),
+ #define XLAT_VAL_8 ((unsigned) (BPF_NEG))
+ #define XLAT_STR_8 STRINGIFY(BPF_NEG)
  XLAT(BPF_MOD),
+ #define XLAT_VAL_9 ((unsigned) (BPF_MOD))
+ #define XLAT_STR_9 STRINGIFY(BPF_MOD)
  XLAT(BPF_XOR),
+ #define XLAT_VAL_10 ((unsigned) (BPF_XOR))
+ #define XLAT_STR_10 STRINGIFY(BPF_XOR)
  XLAT(BPF_MOV),
+ #define XLAT_VAL_11 ((unsigned) (BPF_MOV))
+ #define XLAT_STR_11 STRINGIFY(BPF_MOV)
  XLAT(BPF_ARSH),
+ #define XLAT_VAL_12 ((unsigned) (BPF_ARSH))
+ #define XLAT_STR_12 STRINGIFY(BPF_ARSH)
  XLAT(BPF_END),
+ #define XLAT_VAL_13 ((unsigned) (BPF_END))
+ #define XLAT_STR_13 STRINGIFY(BPF_END)
 };
 static
 const struct xlat bpf_op_alu[1] = { {
  .data = bpf_op_alu_xdata,
  .size = ARRAY_SIZE(bpf_op_alu_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bpf_op_jmp.h 5.9-0ubuntu2/xlat/bpf_op_jmp.h
--- 5.5-3/xlat/bpf_op_jmp.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bpf_op_jmp.h	2020-09-24 09:18:44.000000000 +0000
@@ -112,27 +112,171 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bpf_op_jmp_xdata[] = {
  XLAT(BPF_JA),
+ #define XLAT_VAL_0 ((unsigned) (BPF_JA))
+ #define XLAT_STR_0 STRINGIFY(BPF_JA)
  XLAT(BPF_JEQ),
+ #define XLAT_VAL_1 ((unsigned) (BPF_JEQ))
+ #define XLAT_STR_1 STRINGIFY(BPF_JEQ)
  XLAT(BPF_JGT),
+ #define XLAT_VAL_2 ((unsigned) (BPF_JGT))
+ #define XLAT_STR_2 STRINGIFY(BPF_JGT)
  XLAT(BPF_JGE),
+ #define XLAT_VAL_3 ((unsigned) (BPF_JGE))
+ #define XLAT_STR_3 STRINGIFY(BPF_JGE)
  XLAT(BPF_JSET),
+ #define XLAT_VAL_4 ((unsigned) (BPF_JSET))
+ #define XLAT_STR_4 STRINGIFY(BPF_JSET)
  XLAT(BPF_JNE),
+ #define XLAT_VAL_5 ((unsigned) (BPF_JNE))
+ #define XLAT_STR_5 STRINGIFY(BPF_JNE)
  XLAT(BPF_JSGT),
+ #define XLAT_VAL_6 ((unsigned) (BPF_JSGT))
+ #define XLAT_STR_6 STRINGIFY(BPF_JSGT)
  XLAT(BPF_JSGE),
+ #define XLAT_VAL_7 ((unsigned) (BPF_JSGE))
+ #define XLAT_STR_7 STRINGIFY(BPF_JSGE)
  XLAT(BPF_CALL),
+ #define XLAT_VAL_8 ((unsigned) (BPF_CALL))
+ #define XLAT_STR_8 STRINGIFY(BPF_CALL)
  XLAT(BPF_EXIT),
+ #define XLAT_VAL_9 ((unsigned) (BPF_EXIT))
+ #define XLAT_STR_9 STRINGIFY(BPF_EXIT)
  XLAT(BPF_JLT),
+ #define XLAT_VAL_10 ((unsigned) (BPF_JLT))
+ #define XLAT_STR_10 STRINGIFY(BPF_JLT)
  XLAT(BPF_JLE),
+ #define XLAT_VAL_11 ((unsigned) (BPF_JLE))
+ #define XLAT_STR_11 STRINGIFY(BPF_JLE)
  XLAT(BPF_JSLT),
+ #define XLAT_VAL_12 ((unsigned) (BPF_JSLT))
+ #define XLAT_STR_12 STRINGIFY(BPF_JSLT)
  XLAT(BPF_JSLE),
+ #define XLAT_VAL_13 ((unsigned) (BPF_JSLE))
+ #define XLAT_STR_13 STRINGIFY(BPF_JSLE)
 };
 static
 const struct xlat bpf_op_jmp[1] = { {
  .data = bpf_op_jmp_xdata,
  .size = ARRAY_SIZE(bpf_op_jmp_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bpf_prog_flags.h 5.9-0ubuntu2/xlat/bpf_prog_flags.h
--- 5.5-3/xlat/bpf_prog_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bpf_prog_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bpf_prog_flags_xdata[] = {
  XLAT(BPF_F_STRICT_ALIGNMENT),
+ #define XLAT_VAL_0 ((unsigned) (BPF_F_STRICT_ALIGNMENT))
+ #define XLAT_STR_0 STRINGIFY(BPF_F_STRICT_ALIGNMENT)
  XLAT(BPF_F_ANY_ALIGNMENT),
+ #define XLAT_VAL_1 ((unsigned) (BPF_F_ANY_ALIGNMENT))
+ #define XLAT_STR_1 STRINGIFY(BPF_F_ANY_ALIGNMENT)
  XLAT(BPF_F_TEST_RND_HI32),
+ #define XLAT_VAL_2 ((unsigned) (BPF_F_TEST_RND_HI32))
+ #define XLAT_STR_2 STRINGIFY(BPF_F_TEST_RND_HI32)
  XLAT(BPF_F_TEST_STATE_FREQ),
+ #define XLAT_VAL_3 ((unsigned) (BPF_F_TEST_STATE_FREQ))
+ #define XLAT_STR_3 STRINGIFY(BPF_F_TEST_STATE_FREQ)
 };
 static
 const struct xlat bpf_prog_flags[1] = { {
  .data = bpf_prog_flags_xdata,
  .size = ARRAY_SIZE(bpf_prog_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bpf_prog_types.h 5.9-0ubuntu2/xlat/bpf_prog_types.h
--- 5.5-3/xlat/bpf_prog_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bpf_prog_types.h	2020-09-24 09:18:45.000000000 +0000
@@ -192,6 +192,34 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define BPF_PROG_TYPE_TRACING 26
 #endif
+#if defined(BPF_PROG_TYPE_STRUCT_OPS) || (defined(HAVE_DECL_BPF_PROG_TYPE_STRUCT_OPS) && HAVE_DECL_BPF_PROG_TYPE_STRUCT_OPS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_PROG_TYPE_STRUCT_OPS) == (27), "BPF_PROG_TYPE_STRUCT_OPS != 27");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_PROG_TYPE_STRUCT_OPS 27
+#endif
+#if defined(BPF_PROG_TYPE_EXT) || (defined(HAVE_DECL_BPF_PROG_TYPE_EXT) && HAVE_DECL_BPF_PROG_TYPE_EXT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_PROG_TYPE_EXT) == (28), "BPF_PROG_TYPE_EXT != 28");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_PROG_TYPE_EXT 28
+#endif
+#if defined(BPF_PROG_TYPE_LSM) || (defined(HAVE_DECL_BPF_PROG_TYPE_LSM) && HAVE_DECL_BPF_PROG_TYPE_LSM)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_PROG_TYPE_LSM) == (29), "BPF_PROG_TYPE_LSM != 29");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_PROG_TYPE_LSM 29
+#endif
+#if defined(BPF_PROG_TYPE_SK_LOOKUP) || (defined(HAVE_DECL_BPF_PROG_TYPE_SK_LOOKUP) && HAVE_DECL_BPF_PROG_TYPE_SK_LOOKUP)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BPF_PROG_TYPE_SK_LOOKUP) == (30), "BPF_PROG_TYPE_SK_LOOKUP != 30");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BPF_PROG_TYPE_SK_LOOKUP 30
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -203,40 +231,358 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bpf_prog_types_xdata[] = {
  [BPF_PROG_TYPE_UNSPEC] = XLAT(BPF_PROG_TYPE_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (BPF_PROG_TYPE_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(BPF_PROG_TYPE_UNSPEC)
  [BPF_PROG_TYPE_SOCKET_FILTER] = XLAT(BPF_PROG_TYPE_SOCKET_FILTER),
+ #define XLAT_VAL_1 ((unsigned) (BPF_PROG_TYPE_SOCKET_FILTER))
+ #define XLAT_STR_1 STRINGIFY(BPF_PROG_TYPE_SOCKET_FILTER)
  [BPF_PROG_TYPE_KPROBE] = XLAT(BPF_PROG_TYPE_KPROBE),
+ #define XLAT_VAL_2 ((unsigned) (BPF_PROG_TYPE_KPROBE))
+ #define XLAT_STR_2 STRINGIFY(BPF_PROG_TYPE_KPROBE)
  [BPF_PROG_TYPE_SCHED_CLS] = XLAT(BPF_PROG_TYPE_SCHED_CLS),
+ #define XLAT_VAL_3 ((unsigned) (BPF_PROG_TYPE_SCHED_CLS))
+ #define XLAT_STR_3 STRINGIFY(BPF_PROG_TYPE_SCHED_CLS)
  [BPF_PROG_TYPE_SCHED_ACT] = XLAT(BPF_PROG_TYPE_SCHED_ACT),
+ #define XLAT_VAL_4 ((unsigned) (BPF_PROG_TYPE_SCHED_ACT))
+ #define XLAT_STR_4 STRINGIFY(BPF_PROG_TYPE_SCHED_ACT)
  [BPF_PROG_TYPE_TRACEPOINT] = XLAT(BPF_PROG_TYPE_TRACEPOINT),
+ #define XLAT_VAL_5 ((unsigned) (BPF_PROG_TYPE_TRACEPOINT))
+ #define XLAT_STR_5 STRINGIFY(BPF_PROG_TYPE_TRACEPOINT)
  [BPF_PROG_TYPE_XDP] = XLAT(BPF_PROG_TYPE_XDP),
+ #define XLAT_VAL_6 ((unsigned) (BPF_PROG_TYPE_XDP))
+ #define XLAT_STR_6 STRINGIFY(BPF_PROG_TYPE_XDP)
  [BPF_PROG_TYPE_PERF_EVENT] = XLAT(BPF_PROG_TYPE_PERF_EVENT),
+ #define XLAT_VAL_7 ((unsigned) (BPF_PROG_TYPE_PERF_EVENT))
+ #define XLAT_STR_7 STRINGIFY(BPF_PROG_TYPE_PERF_EVENT)
  [BPF_PROG_TYPE_CGROUP_SKB] = XLAT(BPF_PROG_TYPE_CGROUP_SKB),
+ #define XLAT_VAL_8 ((unsigned) (BPF_PROG_TYPE_CGROUP_SKB))
+ #define XLAT_STR_8 STRINGIFY(BPF_PROG_TYPE_CGROUP_SKB)
  [BPF_PROG_TYPE_CGROUP_SOCK] = XLAT(BPF_PROG_TYPE_CGROUP_SOCK),
+ #define XLAT_VAL_9 ((unsigned) (BPF_PROG_TYPE_CGROUP_SOCK))
+ #define XLAT_STR_9 STRINGIFY(BPF_PROG_TYPE_CGROUP_SOCK)
  [BPF_PROG_TYPE_LWT_IN] = XLAT(BPF_PROG_TYPE_LWT_IN),
+ #define XLAT_VAL_10 ((unsigned) (BPF_PROG_TYPE_LWT_IN))
+ #define XLAT_STR_10 STRINGIFY(BPF_PROG_TYPE_LWT_IN)
  [BPF_PROG_TYPE_LWT_OUT] = XLAT(BPF_PROG_TYPE_LWT_OUT),
+ #define XLAT_VAL_11 ((unsigned) (BPF_PROG_TYPE_LWT_OUT))
+ #define XLAT_STR_11 STRINGIFY(BPF_PROG_TYPE_LWT_OUT)
  [BPF_PROG_TYPE_LWT_XMIT] = XLAT(BPF_PROG_TYPE_LWT_XMIT),
+ #define XLAT_VAL_12 ((unsigned) (BPF_PROG_TYPE_LWT_XMIT))
+ #define XLAT_STR_12 STRINGIFY(BPF_PROG_TYPE_LWT_XMIT)
  [BPF_PROG_TYPE_SOCK_OPS] = XLAT(BPF_PROG_TYPE_SOCK_OPS),
+ #define XLAT_VAL_13 ((unsigned) (BPF_PROG_TYPE_SOCK_OPS))
+ #define XLAT_STR_13 STRINGIFY(BPF_PROG_TYPE_SOCK_OPS)
  [BPF_PROG_TYPE_SK_SKB] = XLAT(BPF_PROG_TYPE_SK_SKB),
+ #define XLAT_VAL_14 ((unsigned) (BPF_PROG_TYPE_SK_SKB))
+ #define XLAT_STR_14 STRINGIFY(BPF_PROG_TYPE_SK_SKB)
  [BPF_PROG_TYPE_CGROUP_DEVICE] = XLAT(BPF_PROG_TYPE_CGROUP_DEVICE),
+ #define XLAT_VAL_15 ((unsigned) (BPF_PROG_TYPE_CGROUP_DEVICE))
+ #define XLAT_STR_15 STRINGIFY(BPF_PROG_TYPE_CGROUP_DEVICE)
  [BPF_PROG_TYPE_SK_MSG] = XLAT(BPF_PROG_TYPE_SK_MSG),
+ #define XLAT_VAL_16 ((unsigned) (BPF_PROG_TYPE_SK_MSG))
+ #define XLAT_STR_16 STRINGIFY(BPF_PROG_TYPE_SK_MSG)
  [BPF_PROG_TYPE_RAW_TRACEPOINT] = XLAT(BPF_PROG_TYPE_RAW_TRACEPOINT),
+ #define XLAT_VAL_17 ((unsigned) (BPF_PROG_TYPE_RAW_TRACEPOINT))
+ #define XLAT_STR_17 STRINGIFY(BPF_PROG_TYPE_RAW_TRACEPOINT)
  [BPF_PROG_TYPE_CGROUP_SOCK_ADDR] = XLAT(BPF_PROG_TYPE_CGROUP_SOCK_ADDR),
+ #define XLAT_VAL_18 ((unsigned) (BPF_PROG_TYPE_CGROUP_SOCK_ADDR))
+ #define XLAT_STR_18 STRINGIFY(BPF_PROG_TYPE_CGROUP_SOCK_ADDR)
  [BPF_PROG_TYPE_LWT_SEG6LOCAL] = XLAT(BPF_PROG_TYPE_LWT_SEG6LOCAL),
+ #define XLAT_VAL_19 ((unsigned) (BPF_PROG_TYPE_LWT_SEG6LOCAL))
+ #define XLAT_STR_19 STRINGIFY(BPF_PROG_TYPE_LWT_SEG6LOCAL)
  [BPF_PROG_TYPE_LIRC_MODE2] = XLAT(BPF_PROG_TYPE_LIRC_MODE2),
+ #define XLAT_VAL_20 ((unsigned) (BPF_PROG_TYPE_LIRC_MODE2))
+ #define XLAT_STR_20 STRINGIFY(BPF_PROG_TYPE_LIRC_MODE2)
  [BPF_PROG_TYPE_SK_REUSEPORT] = XLAT(BPF_PROG_TYPE_SK_REUSEPORT),
+ #define XLAT_VAL_21 ((unsigned) (BPF_PROG_TYPE_SK_REUSEPORT))
+ #define XLAT_STR_21 STRINGIFY(BPF_PROG_TYPE_SK_REUSEPORT)
  [BPF_PROG_TYPE_FLOW_DISSECTOR] = XLAT(BPF_PROG_TYPE_FLOW_DISSECTOR),
+ #define XLAT_VAL_22 ((unsigned) (BPF_PROG_TYPE_FLOW_DISSECTOR))
+ #define XLAT_STR_22 STRINGIFY(BPF_PROG_TYPE_FLOW_DISSECTOR)
  [BPF_PROG_TYPE_CGROUP_SYSCTL] = XLAT(BPF_PROG_TYPE_CGROUP_SYSCTL),
+ #define XLAT_VAL_23 ((unsigned) (BPF_PROG_TYPE_CGROUP_SYSCTL))
+ #define XLAT_STR_23 STRINGIFY(BPF_PROG_TYPE_CGROUP_SYSCTL)
  [BPF_PROG_TYPE_RAW_TRACEPOINT_WRITABLE] = XLAT(BPF_PROG_TYPE_RAW_TRACEPOINT_WRITABLE),
+ #define XLAT_VAL_24 ((unsigned) (BPF_PROG_TYPE_RAW_TRACEPOINT_WRITABLE))
+ #define XLAT_STR_24 STRINGIFY(BPF_PROG_TYPE_RAW_TRACEPOINT_WRITABLE)
  [BPF_PROG_TYPE_CGROUP_SOCKOPT] = XLAT(BPF_PROG_TYPE_CGROUP_SOCKOPT),
+ #define XLAT_VAL_25 ((unsigned) (BPF_PROG_TYPE_CGROUP_SOCKOPT))
+ #define XLAT_STR_25 STRINGIFY(BPF_PROG_TYPE_CGROUP_SOCKOPT)
  [BPF_PROG_TYPE_TRACING] = XLAT(BPF_PROG_TYPE_TRACING),
+ #define XLAT_VAL_26 ((unsigned) (BPF_PROG_TYPE_TRACING))
+ #define XLAT_STR_26 STRINGIFY(BPF_PROG_TYPE_TRACING)
+ [BPF_PROG_TYPE_STRUCT_OPS] = XLAT(BPF_PROG_TYPE_STRUCT_OPS),
+ #define XLAT_VAL_27 ((unsigned) (BPF_PROG_TYPE_STRUCT_OPS))
+ #define XLAT_STR_27 STRINGIFY(BPF_PROG_TYPE_STRUCT_OPS)
+ [BPF_PROG_TYPE_EXT] = XLAT(BPF_PROG_TYPE_EXT),
+ #define XLAT_VAL_28 ((unsigned) (BPF_PROG_TYPE_EXT))
+ #define XLAT_STR_28 STRINGIFY(BPF_PROG_TYPE_EXT)
+ [BPF_PROG_TYPE_LSM] = XLAT(BPF_PROG_TYPE_LSM),
+ #define XLAT_VAL_29 ((unsigned) (BPF_PROG_TYPE_LSM))
+ #define XLAT_STR_29 STRINGIFY(BPF_PROG_TYPE_LSM)
+ [BPF_PROG_TYPE_SK_LOOKUP] = XLAT(BPF_PROG_TYPE_SK_LOOKUP),
+ #define XLAT_VAL_30 ((unsigned) (BPF_PROG_TYPE_SK_LOOKUP))
+ #define XLAT_STR_30 STRINGIFY(BPF_PROG_TYPE_SK_LOOKUP)
 };
 static
 const struct xlat bpf_prog_types[1] = { {
  .data = bpf_prog_types_xdata,
  .size = ARRAY_SIZE(bpf_prog_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bpf_prog_types.in 5.9-0ubuntu2/xlat/bpf_prog_types.in
--- 5.5-3/xlat/bpf_prog_types.in	2019-12-10 09:43:48.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bpf_prog_types.in	2020-09-06 08:00:00.000000000 +0000
@@ -26,3 +26,7 @@ BPF_PROG_TYPE_CGROUP_SYSCTL 23
 BPF_PROG_TYPE_RAW_TRACEPOINT_WRITABLE 24
 BPF_PROG_TYPE_CGROUP_SOCKOPT 25
 BPF_PROG_TYPE_TRACING 26
+BPF_PROG_TYPE_STRUCT_OPS 27
+BPF_PROG_TYPE_EXT 28
+BPF_PROG_TYPE_LSM 29
+BPF_PROG_TYPE_SK_LOOKUP 30
diff -pruN 5.5-3/xlat/bpf_query_flags.h 5.9-0ubuntu2/xlat/bpf_query_flags.h
--- 5.5-3/xlat/bpf_query_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bpf_query_flags.h	2020-09-24 09:18:43.000000000 +0000
@@ -21,14 +21,28 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bpf_query_flags_xdata[] = {
  XLAT(BPF_F_QUERY_EFFECTIVE),
+ #define XLAT_VAL_0 ((unsigned) (BPF_F_QUERY_EFFECTIVE))
+ #define XLAT_STR_0 STRINGIFY(BPF_F_QUERY_EFFECTIVE)
 };
 static
 const struct xlat bpf_query_flags[1] = { {
  .data = bpf_query_flags_xdata,
  .size = ARRAY_SIZE(bpf_query_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bpf_rval.h 5.9-0ubuntu2/xlat/bpf_rval.h
--- 5.5-3/xlat/bpf_rval.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bpf_rval.h	2020-09-24 09:18:44.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bpf_rval_xdata[] = {
  XLAT(BPF_K),
+ #define XLAT_VAL_0 ((unsigned) (BPF_K))
+ #define XLAT_STR_0 STRINGIFY(BPF_K)
  XLAT(BPF_X),
+ #define XLAT_VAL_1 ((unsigned) (BPF_X))
+ #define XLAT_STR_1 STRINGIFY(BPF_X)
  XLAT(BPF_A),
+ #define XLAT_VAL_2 ((unsigned) (BPF_A))
+ #define XLAT_STR_2 STRINGIFY(BPF_A)
 };
 static
 const struct xlat bpf_rval[1] = { {
  .data = bpf_rval_xdata,
  .size = ARRAY_SIZE(bpf_rval_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bpf_size.h 5.9-0ubuntu2/xlat/bpf_size.h
--- 5.5-3/xlat/bpf_size.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bpf_size.h	2020-09-24 09:18:44.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bpf_size_xdata[] = {
  XLAT(BPF_W),
+ #define XLAT_VAL_0 ((unsigned) (BPF_W))
+ #define XLAT_STR_0 STRINGIFY(BPF_W)
  XLAT(BPF_H),
+ #define XLAT_VAL_1 ((unsigned) (BPF_H))
+ #define XLAT_STR_1 STRINGIFY(BPF_H)
  XLAT(BPF_B),
+ #define XLAT_VAL_2 ((unsigned) (BPF_B))
+ #define XLAT_STR_2 STRINGIFY(BPF_B)
  XLAT(BPF_DW),
+ #define XLAT_VAL_3 ((unsigned) (BPF_DW))
+ #define XLAT_STR_3 STRINGIFY(BPF_DW)
 };
 static
 const struct xlat bpf_size[1] = { {
  .data = bpf_size_xdata,
  .size = ARRAY_SIZE(bpf_size_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bpf_src.h 5.9-0ubuntu2/xlat/bpf_src.h
--- 5.5-3/xlat/bpf_src.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bpf_src.h	2020-09-24 09:18:43.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bpf_src_xdata[] = {
  XLAT(BPF_K),
+ #define XLAT_VAL_0 ((unsigned) (BPF_K))
+ #define XLAT_STR_0 STRINGIFY(BPF_K)
  XLAT(BPF_X),
+ #define XLAT_VAL_1 ((unsigned) (BPF_X))
+ #define XLAT_STR_1 STRINGIFY(BPF_X)
 };
 static
 const struct xlat bpf_src[1] = { {
  .data = bpf_src_xdata,
  .size = ARRAY_SIZE(bpf_src_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bpf_task_fd_type.h 5.9-0ubuntu2/xlat/bpf_task_fd_type.h
--- 5.5-3/xlat/bpf_task_fd_type.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bpf_task_fd_type.h	2020-09-24 09:18:44.000000000 +0000
@@ -56,19 +56,83 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bpf_task_fd_type_xdata[] = {
  [BPF_FD_TYPE_RAW_TRACEPOINT] = XLAT(BPF_FD_TYPE_RAW_TRACEPOINT),
+ #define XLAT_VAL_0 ((unsigned) (BPF_FD_TYPE_RAW_TRACEPOINT))
+ #define XLAT_STR_0 STRINGIFY(BPF_FD_TYPE_RAW_TRACEPOINT)
  [BPF_FD_TYPE_TRACEPOINT] = XLAT(BPF_FD_TYPE_TRACEPOINT),
+ #define XLAT_VAL_1 ((unsigned) (BPF_FD_TYPE_TRACEPOINT))
+ #define XLAT_STR_1 STRINGIFY(BPF_FD_TYPE_TRACEPOINT)
  [BPF_FD_TYPE_KPROBE] = XLAT(BPF_FD_TYPE_KPROBE),
+ #define XLAT_VAL_2 ((unsigned) (BPF_FD_TYPE_KPROBE))
+ #define XLAT_STR_2 STRINGIFY(BPF_FD_TYPE_KPROBE)
  [BPF_FD_TYPE_KRETPROBE] = XLAT(BPF_FD_TYPE_KRETPROBE),
+ #define XLAT_VAL_3 ((unsigned) (BPF_FD_TYPE_KRETPROBE))
+ #define XLAT_STR_3 STRINGIFY(BPF_FD_TYPE_KRETPROBE)
  [BPF_FD_TYPE_UPROBE] = XLAT(BPF_FD_TYPE_UPROBE),
+ #define XLAT_VAL_4 ((unsigned) (BPF_FD_TYPE_UPROBE))
+ #define XLAT_STR_4 STRINGIFY(BPF_FD_TYPE_UPROBE)
  [BPF_FD_TYPE_URETPROBE] = XLAT(BPF_FD_TYPE_URETPROBE),
+ #define XLAT_VAL_5 ((unsigned) (BPF_FD_TYPE_URETPROBE))
+ #define XLAT_STR_5 STRINGIFY(BPF_FD_TYPE_URETPROBE)
 };
 static
 const struct xlat bpf_task_fd_type[1] = { {
  .data = bpf_task_fd_type_xdata,
  .size = ARRAY_SIZE(bpf_task_fd_type_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bsg_flags.h 5.9-0ubuntu2/xlat/bsg_flags.h
--- 5.5-3/xlat/bsg_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bsg_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bsg_flags_xdata[] = {
  XLAT(BSG_FLAG_Q_AT_TAIL),
+ #define XLAT_VAL_0 ((unsigned) (BSG_FLAG_Q_AT_TAIL))
+ #define XLAT_STR_0 STRINGIFY(BSG_FLAG_Q_AT_TAIL)
  XLAT(BSG_FLAG_Q_AT_HEAD),
+ #define XLAT_VAL_1 ((unsigned) (BSG_FLAG_Q_AT_HEAD))
+ #define XLAT_STR_1 STRINGIFY(BSG_FLAG_Q_AT_HEAD)
 };
 static
 const struct xlat bsg_flags[1] = { {
  .data = bsg_flags_xdata,
  .size = ARRAY_SIZE(bsg_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bsg_protocol.h 5.9-0ubuntu2/xlat/bsg_protocol.h
--- 5.5-3/xlat/bsg_protocol.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bsg_protocol.h	2020-09-24 09:18:43.000000000 +0000
@@ -15,6 +15,8 @@
 static const struct xlat_data bsg_protocol_xdata[] = {
 #if defined(BSG_PROTOCOL_SCSI) || (defined(HAVE_DECL_BSG_PROTOCOL_SCSI) && HAVE_DECL_BSG_PROTOCOL_SCSI)
   XLAT(BSG_PROTOCOL_SCSI),
+ #define XLAT_VAL_0 ((unsigned) (BSG_PROTOCOL_SCSI))
+ #define XLAT_STR_0 STRINGIFY(BSG_PROTOCOL_SCSI)
 #endif
 };
 static
@@ -22,8 +24,20 @@ const struct xlat bsg_protocol[1] = { {
  .data = bsg_protocol_xdata,
  .size = ARRAY_SIZE(bsg_protocol_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bsg_subprotocol.h 5.9-0ubuntu2/xlat/bsg_subprotocol.h
--- 5.5-3/xlat/bsg_subprotocol.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bsg_subprotocol.h	2020-09-24 09:18:43.000000000 +0000
@@ -15,12 +15,18 @@
 static const struct xlat_data bsg_subprotocol_xdata[] = {
 #if defined(BSG_SUB_PROTOCOL_SCSI_CMD) || (defined(HAVE_DECL_BSG_SUB_PROTOCOL_SCSI_CMD) && HAVE_DECL_BSG_SUB_PROTOCOL_SCSI_CMD)
   XLAT(BSG_SUB_PROTOCOL_SCSI_CMD),
+ #define XLAT_VAL_0 ((unsigned) (BSG_SUB_PROTOCOL_SCSI_CMD))
+ #define XLAT_STR_0 STRINGIFY(BSG_SUB_PROTOCOL_SCSI_CMD)
 #endif
 #if defined(BSG_SUB_PROTOCOL_SCSI_TMF) || (defined(HAVE_DECL_BSG_SUB_PROTOCOL_SCSI_TMF) && HAVE_DECL_BSG_SUB_PROTOCOL_SCSI_TMF)
   XLAT(BSG_SUB_PROTOCOL_SCSI_TMF),
+ #define XLAT_VAL_1 ((unsigned) (BSG_SUB_PROTOCOL_SCSI_TMF))
+ #define XLAT_STR_1 STRINGIFY(BSG_SUB_PROTOCOL_SCSI_TMF)
 #endif
 #if defined(BSG_SUB_PROTOCOL_SCSI_TRANSPORT) || (defined(HAVE_DECL_BSG_SUB_PROTOCOL_SCSI_TRANSPORT) && HAVE_DECL_BSG_SUB_PROTOCOL_SCSI_TRANSPORT)
   XLAT(BSG_SUB_PROTOCOL_SCSI_TRANSPORT),
+ #define XLAT_VAL_2 ((unsigned) (BSG_SUB_PROTOCOL_SCSI_TRANSPORT))
+ #define XLAT_STR_2 STRINGIFY(BSG_SUB_PROTOCOL_SCSI_TRANSPORT)
 #endif
 };
 static
@@ -28,8 +34,36 @@ const struct xlat bsg_subprotocol[1] = {
  .data = bsg_subprotocol_xdata,
  .size = ARRAY_SIZE(bsg_subprotocol_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/bt_protocols.h 5.9-0ubuntu2/xlat/bt_protocols.h
--- 5.5-3/xlat/bt_protocols.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/bt_protocols.h	2020-09-24 09:18:44.000000000 +0000
@@ -70,21 +70,105 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data bt_protocols_xdata[] = {
  [BTPROTO_L2CAP] = XLAT(BTPROTO_L2CAP),
+ #define XLAT_VAL_0 ((unsigned) (BTPROTO_L2CAP))
+ #define XLAT_STR_0 STRINGIFY(BTPROTO_L2CAP)
  [BTPROTO_HCI] = XLAT(BTPROTO_HCI),
+ #define XLAT_VAL_1 ((unsigned) (BTPROTO_HCI))
+ #define XLAT_STR_1 STRINGIFY(BTPROTO_HCI)
  [BTPROTO_SCO] = XLAT(BTPROTO_SCO),
+ #define XLAT_VAL_2 ((unsigned) (BTPROTO_SCO))
+ #define XLAT_STR_2 STRINGIFY(BTPROTO_SCO)
  [BTPROTO_RFCOMM] = XLAT(BTPROTO_RFCOMM),
+ #define XLAT_VAL_3 ((unsigned) (BTPROTO_RFCOMM))
+ #define XLAT_STR_3 STRINGIFY(BTPROTO_RFCOMM)
  [BTPROTO_BNEP] = XLAT(BTPROTO_BNEP),
+ #define XLAT_VAL_4 ((unsigned) (BTPROTO_BNEP))
+ #define XLAT_STR_4 STRINGIFY(BTPROTO_BNEP)
  [BTPROTO_CMTP] = XLAT(BTPROTO_CMTP),
+ #define XLAT_VAL_5 ((unsigned) (BTPROTO_CMTP))
+ #define XLAT_STR_5 STRINGIFY(BTPROTO_CMTP)
  [BTPROTO_HIDP] = XLAT(BTPROTO_HIDP),
+ #define XLAT_VAL_6 ((unsigned) (BTPROTO_HIDP))
+ #define XLAT_STR_6 STRINGIFY(BTPROTO_HIDP)
  [BTPROTO_AVDTP] = XLAT(BTPROTO_AVDTP),
+ #define XLAT_VAL_7 ((unsigned) (BTPROTO_AVDTP))
+ #define XLAT_STR_7 STRINGIFY(BTPROTO_AVDTP)
 };
 static
 const struct xlat bt_protocols[1] = { {
  .data = bt_protocols_xdata,
  .size = ARRAY_SIZE(bt_protocols_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/btrfs_balance_args.h 5.9-0ubuntu2/xlat/btrfs_balance_args.h
--- 5.5-3/xlat/btrfs_balance_args.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_balance_args.h	2020-09-24 09:18:44.000000000 +0000
@@ -91,16 +91,38 @@ extern const struct xlat btrfs_balance_a
 
 static const struct xlat_data btrfs_balance_args_xdata[] = {
  XLAT_TYPE(uint64_t, BTRFS_BALANCE_ARGS_PROFILES),
+ #define XLAT_VAL_0 ((uint64_t) (BTRFS_BALANCE_ARGS_PROFILES))
+ #define XLAT_STR_0 STRINGIFY(BTRFS_BALANCE_ARGS_PROFILES)
  XLAT_TYPE(uint64_t, BTRFS_BALANCE_ARGS_USAGE),
+ #define XLAT_VAL_1 ((uint64_t) (BTRFS_BALANCE_ARGS_USAGE))
+ #define XLAT_STR_1 STRINGIFY(BTRFS_BALANCE_ARGS_USAGE)
  XLAT_TYPE(uint64_t, BTRFS_BALANCE_ARGS_DEVID),
+ #define XLAT_VAL_2 ((uint64_t) (BTRFS_BALANCE_ARGS_DEVID))
+ #define XLAT_STR_2 STRINGIFY(BTRFS_BALANCE_ARGS_DEVID)
  XLAT_TYPE(uint64_t, BTRFS_BALANCE_ARGS_DRANGE),
+ #define XLAT_VAL_3 ((uint64_t) (BTRFS_BALANCE_ARGS_DRANGE))
+ #define XLAT_STR_3 STRINGIFY(BTRFS_BALANCE_ARGS_DRANGE)
  XLAT_TYPE(uint64_t, BTRFS_BALANCE_ARGS_VRANGE),
+ #define XLAT_VAL_4 ((uint64_t) (BTRFS_BALANCE_ARGS_VRANGE))
+ #define XLAT_STR_4 STRINGIFY(BTRFS_BALANCE_ARGS_VRANGE)
  XLAT_TYPE(uint64_t, BTRFS_BALANCE_ARGS_LIMIT),
+ #define XLAT_VAL_5 ((uint64_t) (BTRFS_BALANCE_ARGS_LIMIT))
+ #define XLAT_STR_5 STRINGIFY(BTRFS_BALANCE_ARGS_LIMIT)
  XLAT_TYPE(uint64_t, BTRFS_BALANCE_ARGS_LIMIT_RANGE),
+ #define XLAT_VAL_6 ((uint64_t) (BTRFS_BALANCE_ARGS_LIMIT_RANGE))
+ #define XLAT_STR_6 STRINGIFY(BTRFS_BALANCE_ARGS_LIMIT_RANGE)
  XLAT_TYPE(uint64_t, BTRFS_BALANCE_ARGS_STRIPES_RANGE),
+ #define XLAT_VAL_7 ((uint64_t) (BTRFS_BALANCE_ARGS_STRIPES_RANGE))
+ #define XLAT_STR_7 STRINGIFY(BTRFS_BALANCE_ARGS_STRIPES_RANGE)
  XLAT_TYPE(uint64_t, BTRFS_BALANCE_ARGS_CONVERT),
+ #define XLAT_VAL_8 ((uint64_t) (BTRFS_BALANCE_ARGS_CONVERT))
+ #define XLAT_STR_8 STRINGIFY(BTRFS_BALANCE_ARGS_CONVERT)
  XLAT_TYPE(uint64_t, BTRFS_BALANCE_ARGS_SOFT),
+ #define XLAT_VAL_9 ((uint64_t) (BTRFS_BALANCE_ARGS_SOFT))
+ #define XLAT_STR_9 STRINGIFY(BTRFS_BALANCE_ARGS_SOFT)
  XLAT_TYPE(uint64_t, BTRFS_BALANCE_ARGS_USAGE_RANGE),
+ #define XLAT_VAL_10 ((uint64_t) (BTRFS_BALANCE_ARGS_USAGE_RANGE))
+ #define XLAT_STR_10 STRINGIFY(BTRFS_BALANCE_ARGS_USAGE_RANGE)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -109,8 +131,100 @@ const struct xlat btrfs_balance_args[1]
  .data = btrfs_balance_args_xdata,
  .size = ARRAY_SIZE(btrfs_balance_args_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/btrfs_balance_ctl_cmds.h 5.9-0ubuntu2/xlat/btrfs_balance_ctl_cmds.h
--- 5.5-3/xlat/btrfs_balance_ctl_cmds.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_balance_ctl_cmds.h	2020-09-24 09:18:43.000000000 +0000
@@ -28,7 +28,11 @@ extern const struct xlat btrfs_balance_c
 
 static const struct xlat_data btrfs_balance_ctl_cmds_xdata[] = {
  [BTRFS_BALANCE_CTL_PAUSE] = XLAT(BTRFS_BALANCE_CTL_PAUSE),
+ #define XLAT_VAL_0 ((unsigned) (BTRFS_BALANCE_CTL_PAUSE))
+ #define XLAT_STR_0 STRINGIFY(BTRFS_BALANCE_CTL_PAUSE)
  [BTRFS_BALANCE_CTL_CANCEL] = XLAT(BTRFS_BALANCE_CTL_CANCEL),
+ #define XLAT_VAL_1 ((unsigned) (BTRFS_BALANCE_CTL_CANCEL))
+ #define XLAT_STR_1 STRINGIFY(BTRFS_BALANCE_CTL_CANCEL)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -37,8 +41,28 @@ const struct xlat btrfs_balance_ctl_cmds
  .data = btrfs_balance_ctl_cmds_xdata,
  .size = ARRAY_SIZE(btrfs_balance_ctl_cmds_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/btrfs_balance_flags.h 5.9-0ubuntu2/xlat/btrfs_balance_flags.h
--- 5.5-3/xlat/btrfs_balance_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_balance_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -49,10 +49,20 @@ extern const struct xlat btrfs_balance_f
 
 static const struct xlat_data btrfs_balance_flags_xdata[] = {
  XLAT_TYPE(uint64_t, BTRFS_BALANCE_DATA),
+ #define XLAT_VAL_0 ((uint64_t) (BTRFS_BALANCE_DATA))
+ #define XLAT_STR_0 STRINGIFY(BTRFS_BALANCE_DATA)
  XLAT_TYPE(uint64_t, BTRFS_BALANCE_SYSTEM),
+ #define XLAT_VAL_1 ((uint64_t) (BTRFS_BALANCE_SYSTEM))
+ #define XLAT_STR_1 STRINGIFY(BTRFS_BALANCE_SYSTEM)
  XLAT_TYPE(uint64_t, BTRFS_BALANCE_METADATA),
+ #define XLAT_VAL_2 ((uint64_t) (BTRFS_BALANCE_METADATA))
+ #define XLAT_STR_2 STRINGIFY(BTRFS_BALANCE_METADATA)
  XLAT_TYPE(uint64_t, BTRFS_BALANCE_FORCE),
+ #define XLAT_VAL_3 ((uint64_t) (BTRFS_BALANCE_FORCE))
+ #define XLAT_STR_3 STRINGIFY(BTRFS_BALANCE_FORCE)
  XLAT_TYPE(uint64_t, BTRFS_BALANCE_RESUME),
+ #define XLAT_VAL_4 ((uint64_t) (BTRFS_BALANCE_RESUME))
+ #define XLAT_STR_4 STRINGIFY(BTRFS_BALANCE_RESUME)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -61,8 +71,52 @@ const struct xlat btrfs_balance_flags[1]
  .data = btrfs_balance_flags_xdata,
  .size = ARRAY_SIZE(btrfs_balance_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/btrfs_balance_state.h 5.9-0ubuntu2/xlat/btrfs_balance_state.h
--- 5.5-3/xlat/btrfs_balance_state.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_balance_state.h	2020-09-24 09:18:43.000000000 +0000
@@ -35,8 +35,14 @@ extern const struct xlat btrfs_balance_s
 
 static const struct xlat_data btrfs_balance_state_xdata[] = {
  XLAT(BTRFS_BALANCE_STATE_RUNNING),
+ #define XLAT_VAL_0 ((unsigned) (BTRFS_BALANCE_STATE_RUNNING))
+ #define XLAT_STR_0 STRINGIFY(BTRFS_BALANCE_STATE_RUNNING)
  XLAT(BTRFS_BALANCE_STATE_PAUSE_REQ),
+ #define XLAT_VAL_1 ((unsigned) (BTRFS_BALANCE_STATE_PAUSE_REQ))
+ #define XLAT_STR_1 STRINGIFY(BTRFS_BALANCE_STATE_PAUSE_REQ)
  XLAT(BTRFS_BALANCE_STATE_CANCEL_REQ),
+ #define XLAT_VAL_2 ((unsigned) (BTRFS_BALANCE_STATE_CANCEL_REQ))
+ #define XLAT_STR_2 STRINGIFY(BTRFS_BALANCE_STATE_CANCEL_REQ)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -45,8 +51,36 @@ const struct xlat btrfs_balance_state[1]
  .data = btrfs_balance_state_xdata,
  .size = ARRAY_SIZE(btrfs_balance_state_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/btrfs_compress_types.h 5.9-0ubuntu2/xlat/btrfs_compress_types.h
--- 5.5-3/xlat/btrfs_compress_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_compress_types.h	2020-09-24 09:18:44.000000000 +0000
@@ -24,6 +24,13 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define BTRFS_COMPRESS_LZO 2
 #endif
+#if defined(BTRFS_COMPRESS_ZSTD) || (defined(HAVE_DECL_BTRFS_COMPRESS_ZSTD) && HAVE_DECL_BTRFS_COMPRESS_ZSTD)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((BTRFS_COMPRESS_ZSTD) == (3), "BTRFS_COMPRESS_ZSTD != 3");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define BTRFS_COMPRESS_ZSTD 3
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -35,8 +42,17 @@ extern const struct xlat btrfs_compress_
 
 static const struct xlat_data btrfs_compress_types_xdata[] = {
  [BTRFS_COMPRESS_NONE] = XLAT(BTRFS_COMPRESS_NONE),
+ #define XLAT_VAL_0 ((unsigned) (BTRFS_COMPRESS_NONE))
+ #define XLAT_STR_0 STRINGIFY(BTRFS_COMPRESS_NONE)
  [BTRFS_COMPRESS_ZLIB] = XLAT(BTRFS_COMPRESS_ZLIB),
+ #define XLAT_VAL_1 ((unsigned) (BTRFS_COMPRESS_ZLIB))
+ #define XLAT_STR_1 STRINGIFY(BTRFS_COMPRESS_ZLIB)
  [BTRFS_COMPRESS_LZO] = XLAT(BTRFS_COMPRESS_LZO),
+ #define XLAT_VAL_2 ((unsigned) (BTRFS_COMPRESS_LZO))
+ #define XLAT_STR_2 STRINGIFY(BTRFS_COMPRESS_LZO)
+ [BTRFS_COMPRESS_ZSTD] = XLAT(BTRFS_COMPRESS_ZSTD),
+ #define XLAT_VAL_3 ((unsigned) (BTRFS_COMPRESS_ZSTD))
+ #define XLAT_STR_3 STRINGIFY(BTRFS_COMPRESS_ZSTD)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -45,8 +61,44 @@ const struct xlat btrfs_compress_types[1
  .data = btrfs_compress_types_xdata,
  .size = ARRAY_SIZE(btrfs_compress_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/btrfs_compress_types.in 5.9-0ubuntu2/xlat/btrfs_compress_types.in
--- 5.5-3/xlat/btrfs_compress_types.in	2019-08-14 19:05:08.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_compress_types.in	2020-05-30 08:00:00.000000000 +0000
@@ -1,4 +1,8 @@
 #value_indexed
+#enum
+#include <stdio.h>
+#include <linux/btrfs.h>
 BTRFS_COMPRESS_NONE 0
 BTRFS_COMPRESS_ZLIB 1
 BTRFS_COMPRESS_LZO 2
+BTRFS_COMPRESS_ZSTD 3
diff -pruN 5.5-3/xlat/btrfs_compress_types.m4 5.9-0ubuntu2/xlat/btrfs_compress_types.m4
--- 5.5-3/xlat/btrfs_compress_types.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_compress_types.m4	2020-09-24 09:18:43.000000000 +0000
@@ -0,0 +1,11 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/btrfs_compress_types.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_btrfs_compress_types],[
+AC_CHECK_DECLS(m4_normalize([
+BTRFS_COMPRESS_NONE,
+BTRFS_COMPRESS_ZLIB,
+BTRFS_COMPRESS_LZO,
+BTRFS_COMPRESS_ZSTD
+]),,, [
+#include <stdio.h>
+#include <linux/btrfs.h>
+])])])
diff -pruN 5.5-3/xlat/btrfs_cont_reading_from_srcdev_mode.h 5.9-0ubuntu2/xlat/btrfs_cont_reading_from_srcdev_mode.h
--- 5.5-3/xlat/btrfs_cont_reading_from_srcdev_mode.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_cont_reading_from_srcdev_mode.h	2020-09-24 09:18:43.000000000 +0000
@@ -28,7 +28,11 @@ extern const struct xlat btrfs_cont_read
 
 static const struct xlat_data btrfs_cont_reading_from_srcdev_mode_xdata[] = {
  [BTRFS_IOCTL_DEV_REPLACE_CONT_READING_FROM_SRCDEV_MODE_ALWAYS] = XLAT(BTRFS_IOCTL_DEV_REPLACE_CONT_READING_FROM_SRCDEV_MODE_ALWAYS),
+ #define XLAT_VAL_0 ((unsigned) (BTRFS_IOCTL_DEV_REPLACE_CONT_READING_FROM_SRCDEV_MODE_ALWAYS))
+ #define XLAT_STR_0 STRINGIFY(BTRFS_IOCTL_DEV_REPLACE_CONT_READING_FROM_SRCDEV_MODE_ALWAYS)
  [BTRFS_IOCTL_DEV_REPLACE_CONT_READING_FROM_SRCDEV_MODE_AVOID] = XLAT(BTRFS_IOCTL_DEV_REPLACE_CONT_READING_FROM_SRCDEV_MODE_AVOID),
+ #define XLAT_VAL_1 ((unsigned) (BTRFS_IOCTL_DEV_REPLACE_CONT_READING_FROM_SRCDEV_MODE_AVOID))
+ #define XLAT_STR_1 STRINGIFY(BTRFS_IOCTL_DEV_REPLACE_CONT_READING_FROM_SRCDEV_MODE_AVOID)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -37,8 +41,28 @@ const struct xlat btrfs_cont_reading_fro
  .data = btrfs_cont_reading_from_srcdev_mode_xdata,
  .size = ARRAY_SIZE(btrfs_cont_reading_from_srcdev_mode_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/btrfs_defrag_flags.h 5.9-0ubuntu2/xlat/btrfs_defrag_flags.h
--- 5.5-3/xlat/btrfs_defrag_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_defrag_flags.h	2020-09-24 09:18:43.000000000 +0000
@@ -15,9 +15,13 @@ extern const struct xlat btrfs_defrag_fl
 static const struct xlat_data btrfs_defrag_flags_xdata[] = {
 #if defined(BTRFS_DEFRAG_RANGE_COMPRESS) || (defined(HAVE_DECL_BTRFS_DEFRAG_RANGE_COMPRESS) && HAVE_DECL_BTRFS_DEFRAG_RANGE_COMPRESS)
   XLAT_TYPE(uint64_t, BTRFS_DEFRAG_RANGE_COMPRESS),
+ #define XLAT_VAL_0 ((uint64_t) (BTRFS_DEFRAG_RANGE_COMPRESS))
+ #define XLAT_STR_0 STRINGIFY(BTRFS_DEFRAG_RANGE_COMPRESS)
 #endif
 #if defined(BTRFS_DEFRAG_RANGE_START_IO) || (defined(HAVE_DECL_BTRFS_DEFRAG_RANGE_START_IO) && HAVE_DECL_BTRFS_DEFRAG_RANGE_START_IO)
   XLAT_TYPE(uint64_t, BTRFS_DEFRAG_RANGE_START_IO),
+ #define XLAT_VAL_1 ((uint64_t) (BTRFS_DEFRAG_RANGE_START_IO))
+ #define XLAT_STR_1 STRINGIFY(BTRFS_DEFRAG_RANGE_START_IO)
 #endif
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
@@ -27,8 +31,28 @@ const struct xlat btrfs_defrag_flags[1]
  .data = btrfs_defrag_flags_xdata,
  .size = ARRAY_SIZE(btrfs_defrag_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/btrfs_dev_replace_cmds.h 5.9-0ubuntu2/xlat/btrfs_dev_replace_cmds.h
--- 5.5-3/xlat/btrfs_dev_replace_cmds.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_dev_replace_cmds.h	2020-09-24 09:18:43.000000000 +0000
@@ -15,12 +15,18 @@ extern const struct xlat btrfs_dev_repla
 static const struct xlat_data btrfs_dev_replace_cmds_xdata[] = {
 #if defined(BTRFS_IOCTL_DEV_REPLACE_CMD_START) || (defined(HAVE_DECL_BTRFS_IOCTL_DEV_REPLACE_CMD_START) && HAVE_DECL_BTRFS_IOCTL_DEV_REPLACE_CMD_START)
   XLAT_TYPE(uint64_t, BTRFS_IOCTL_DEV_REPLACE_CMD_START),
+ #define XLAT_VAL_0 ((uint64_t) (BTRFS_IOCTL_DEV_REPLACE_CMD_START))
+ #define XLAT_STR_0 STRINGIFY(BTRFS_IOCTL_DEV_REPLACE_CMD_START)
 #endif
 #if defined(BTRFS_IOCTL_DEV_REPLACE_CMD_STATUS) || (defined(HAVE_DECL_BTRFS_IOCTL_DEV_REPLACE_CMD_STATUS) && HAVE_DECL_BTRFS_IOCTL_DEV_REPLACE_CMD_STATUS)
   XLAT_TYPE(uint64_t, BTRFS_IOCTL_DEV_REPLACE_CMD_STATUS),
+ #define XLAT_VAL_1 ((uint64_t) (BTRFS_IOCTL_DEV_REPLACE_CMD_STATUS))
+ #define XLAT_STR_1 STRINGIFY(BTRFS_IOCTL_DEV_REPLACE_CMD_STATUS)
 #endif
 #if defined(BTRFS_IOCTL_DEV_REPLACE_CMD_CANCEL) || (defined(HAVE_DECL_BTRFS_IOCTL_DEV_REPLACE_CMD_CANCEL) && HAVE_DECL_BTRFS_IOCTL_DEV_REPLACE_CMD_CANCEL)
   XLAT_TYPE(uint64_t, BTRFS_IOCTL_DEV_REPLACE_CMD_CANCEL),
+ #define XLAT_VAL_2 ((uint64_t) (BTRFS_IOCTL_DEV_REPLACE_CMD_CANCEL))
+ #define XLAT_STR_2 STRINGIFY(BTRFS_IOCTL_DEV_REPLACE_CMD_CANCEL)
 #endif
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
@@ -30,8 +36,36 @@ const struct xlat btrfs_dev_replace_cmds
  .data = btrfs_dev_replace_cmds_xdata,
  .size = ARRAY_SIZE(btrfs_dev_replace_cmds_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/btrfs_dev_replace_results.h 5.9-0ubuntu2/xlat/btrfs_dev_replace_results.h
--- 5.5-3/xlat/btrfs_dev_replace_results.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_dev_replace_results.h	2020-09-24 09:18:43.000000000 +0000
@@ -15,15 +15,23 @@ extern const struct xlat btrfs_dev_repla
 static const struct xlat_data btrfs_dev_replace_results_xdata[] = {
 #if defined(BTRFS_IOCTL_DEV_REPLACE_RESULT_NO_ERROR) || (defined(HAVE_DECL_BTRFS_IOCTL_DEV_REPLACE_RESULT_NO_ERROR) && HAVE_DECL_BTRFS_IOCTL_DEV_REPLACE_RESULT_NO_ERROR)
   XLAT_TYPE(uint64_t, BTRFS_IOCTL_DEV_REPLACE_RESULT_NO_ERROR),
+ #define XLAT_VAL_0 ((uint64_t) (BTRFS_IOCTL_DEV_REPLACE_RESULT_NO_ERROR))
+ #define XLAT_STR_0 STRINGIFY(BTRFS_IOCTL_DEV_REPLACE_RESULT_NO_ERROR)
 #endif
 #if defined(BTRFS_IOCTL_DEV_REPLACE_RESULT_NOT_STARTED) || (defined(HAVE_DECL_BTRFS_IOCTL_DEV_REPLACE_RESULT_NOT_STARTED) && HAVE_DECL_BTRFS_IOCTL_DEV_REPLACE_RESULT_NOT_STARTED)
   XLAT_TYPE(uint64_t, BTRFS_IOCTL_DEV_REPLACE_RESULT_NOT_STARTED),
+ #define XLAT_VAL_1 ((uint64_t) (BTRFS_IOCTL_DEV_REPLACE_RESULT_NOT_STARTED))
+ #define XLAT_STR_1 STRINGIFY(BTRFS_IOCTL_DEV_REPLACE_RESULT_NOT_STARTED)
 #endif
 #if defined(BTRFS_IOCTL_DEV_REPLACE_RESULT_ALREADY_STARTED) || (defined(HAVE_DECL_BTRFS_IOCTL_DEV_REPLACE_RESULT_ALREADY_STARTED) && HAVE_DECL_BTRFS_IOCTL_DEV_REPLACE_RESULT_ALREADY_STARTED)
   XLAT_TYPE(uint64_t, BTRFS_IOCTL_DEV_REPLACE_RESULT_ALREADY_STARTED),
+ #define XLAT_VAL_2 ((uint64_t) (BTRFS_IOCTL_DEV_REPLACE_RESULT_ALREADY_STARTED))
+ #define XLAT_STR_2 STRINGIFY(BTRFS_IOCTL_DEV_REPLACE_RESULT_ALREADY_STARTED)
 #endif
 #if defined(BTRFS_IOCTL_DEV_REPLACE_RESULT_SCRUB_INPROGRESS) || (defined(HAVE_DECL_BTRFS_IOCTL_DEV_REPLACE_RESULT_SCRUB_INPROGRESS) && HAVE_DECL_BTRFS_IOCTL_DEV_REPLACE_RESULT_SCRUB_INPROGRESS)
   XLAT_TYPE(uint64_t, BTRFS_IOCTL_DEV_REPLACE_RESULT_SCRUB_INPROGRESS),
+ #define XLAT_VAL_3 ((uint64_t) (BTRFS_IOCTL_DEV_REPLACE_RESULT_SCRUB_INPROGRESS))
+ #define XLAT_STR_3 STRINGIFY(BTRFS_IOCTL_DEV_REPLACE_RESULT_SCRUB_INPROGRESS)
 #endif
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
@@ -33,8 +41,44 @@ const struct xlat btrfs_dev_replace_resu
  .data = btrfs_dev_replace_results_xdata,
  .size = ARRAY_SIZE(btrfs_dev_replace_results_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/btrfs_dev_replace_state.h 5.9-0ubuntu2/xlat/btrfs_dev_replace_state.h
--- 5.5-3/xlat/btrfs_dev_replace_state.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_dev_replace_state.h	2020-09-24 09:18:44.000000000 +0000
@@ -15,18 +15,28 @@ extern const struct xlat btrfs_dev_repla
 static const struct xlat_data btrfs_dev_replace_state_xdata[] = {
 #if defined(BTRFS_IOCTL_DEV_REPLACE_STATE_NEVER_STARTED) || (defined(HAVE_DECL_BTRFS_IOCTL_DEV_REPLACE_STATE_NEVER_STARTED) && HAVE_DECL_BTRFS_IOCTL_DEV_REPLACE_STATE_NEVER_STARTED)
   XLAT_TYPE(uint64_t, BTRFS_IOCTL_DEV_REPLACE_STATE_NEVER_STARTED),
+ #define XLAT_VAL_0 ((uint64_t) (BTRFS_IOCTL_DEV_REPLACE_STATE_NEVER_STARTED))
+ #define XLAT_STR_0 STRINGIFY(BTRFS_IOCTL_DEV_REPLACE_STATE_NEVER_STARTED)
 #endif
 #if defined(BTRFS_IOCTL_DEV_REPLACE_STATE_STARTED) || (defined(HAVE_DECL_BTRFS_IOCTL_DEV_REPLACE_STATE_STARTED) && HAVE_DECL_BTRFS_IOCTL_DEV_REPLACE_STATE_STARTED)
   XLAT_TYPE(uint64_t, BTRFS_IOCTL_DEV_REPLACE_STATE_STARTED),
+ #define XLAT_VAL_1 ((uint64_t) (BTRFS_IOCTL_DEV_REPLACE_STATE_STARTED))
+ #define XLAT_STR_1 STRINGIFY(BTRFS_IOCTL_DEV_REPLACE_STATE_STARTED)
 #endif
 #if defined(BTRFS_IOCTL_DEV_REPLACE_STATE_FINISHED) || (defined(HAVE_DECL_BTRFS_IOCTL_DEV_REPLACE_STATE_FINISHED) && HAVE_DECL_BTRFS_IOCTL_DEV_REPLACE_STATE_FINISHED)
   XLAT_TYPE(uint64_t, BTRFS_IOCTL_DEV_REPLACE_STATE_FINISHED),
+ #define XLAT_VAL_2 ((uint64_t) (BTRFS_IOCTL_DEV_REPLACE_STATE_FINISHED))
+ #define XLAT_STR_2 STRINGIFY(BTRFS_IOCTL_DEV_REPLACE_STATE_FINISHED)
 #endif
 #if defined(BTRFS_IOCTL_DEV_REPLACE_STATE_CANCELED) || (defined(HAVE_DECL_BTRFS_IOCTL_DEV_REPLACE_STATE_CANCELED) && HAVE_DECL_BTRFS_IOCTL_DEV_REPLACE_STATE_CANCELED)
   XLAT_TYPE(uint64_t, BTRFS_IOCTL_DEV_REPLACE_STATE_CANCELED),
+ #define XLAT_VAL_3 ((uint64_t) (BTRFS_IOCTL_DEV_REPLACE_STATE_CANCELED))
+ #define XLAT_STR_3 STRINGIFY(BTRFS_IOCTL_DEV_REPLACE_STATE_CANCELED)
 #endif
 #if defined(BTRFS_IOCTL_DEV_REPLACE_STATE_SUSPENDED) || (defined(HAVE_DECL_BTRFS_IOCTL_DEV_REPLACE_STATE_SUSPENDED) && HAVE_DECL_BTRFS_IOCTL_DEV_REPLACE_STATE_SUSPENDED)
   XLAT_TYPE(uint64_t, BTRFS_IOCTL_DEV_REPLACE_STATE_SUSPENDED),
+ #define XLAT_VAL_4 ((uint64_t) (BTRFS_IOCTL_DEV_REPLACE_STATE_SUSPENDED))
+ #define XLAT_STR_4 STRINGIFY(BTRFS_IOCTL_DEV_REPLACE_STATE_SUSPENDED)
 #endif
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
@@ -36,8 +46,52 @@ const struct xlat btrfs_dev_replace_stat
  .data = btrfs_dev_replace_state_xdata,
  .size = ARRAY_SIZE(btrfs_dev_replace_state_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/btrfs_dev_stats_flags.h 5.9-0ubuntu2/xlat/btrfs_dev_stats_flags.h
--- 5.5-3/xlat/btrfs_dev_stats_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_dev_stats_flags.h	2020-09-24 09:18:43.000000000 +0000
@@ -15,6 +15,8 @@ extern const struct xlat btrfs_dev_stats
 static const struct xlat_data btrfs_dev_stats_flags_xdata[] = {
 #if defined(BTRFS_DEV_STATS_RESET) || (defined(HAVE_DECL_BTRFS_DEV_STATS_RESET) && HAVE_DECL_BTRFS_DEV_STATS_RESET)
   XLAT_TYPE(uint64_t, BTRFS_DEV_STATS_RESET),
+ #define XLAT_VAL_0 ((uint64_t) (BTRFS_DEV_STATS_RESET))
+ #define XLAT_STR_0 STRINGIFY(BTRFS_DEV_STATS_RESET)
 #endif
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
@@ -24,8 +26,20 @@ const struct xlat btrfs_dev_stats_flags[
  .data = btrfs_dev_stats_flags_xdata,
  .size = ARRAY_SIZE(btrfs_dev_stats_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/btrfs_dev_stats_values.h 5.9-0ubuntu2/xlat/btrfs_dev_stats_values.h
--- 5.5-3/xlat/btrfs_dev_stats_values.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_dev_stats_values.h	2020-09-24 09:18:44.000000000 +0000
@@ -14,10 +14,20 @@ extern const struct xlat btrfs_dev_stats
 
 static const struct xlat_data btrfs_dev_stats_values_xdata[] = {
  XLAT_TYPE(uint64_t, BTRFS_DEV_STAT_WRITE_ERRS),
+ #define XLAT_VAL_0 ((uint64_t) (BTRFS_DEV_STAT_WRITE_ERRS))
+ #define XLAT_STR_0 STRINGIFY(BTRFS_DEV_STAT_WRITE_ERRS)
  XLAT_TYPE(uint64_t, BTRFS_DEV_STAT_READ_ERRS),
+ #define XLAT_VAL_1 ((uint64_t) (BTRFS_DEV_STAT_READ_ERRS))
+ #define XLAT_STR_1 STRINGIFY(BTRFS_DEV_STAT_READ_ERRS)
  XLAT_TYPE(uint64_t, BTRFS_DEV_STAT_FLUSH_ERRS),
+ #define XLAT_VAL_2 ((uint64_t) (BTRFS_DEV_STAT_FLUSH_ERRS))
+ #define XLAT_STR_2 STRINGIFY(BTRFS_DEV_STAT_FLUSH_ERRS)
  XLAT_TYPE(uint64_t, BTRFS_DEV_STAT_CORRUPTION_ERRS),
+ #define XLAT_VAL_3 ((uint64_t) (BTRFS_DEV_STAT_CORRUPTION_ERRS))
+ #define XLAT_STR_3 STRINGIFY(BTRFS_DEV_STAT_CORRUPTION_ERRS)
  XLAT_TYPE(uint64_t, BTRFS_DEV_STAT_GENERATION_ERRS),
+ #define XLAT_VAL_4 ((uint64_t) (BTRFS_DEV_STAT_GENERATION_ERRS))
+ #define XLAT_STR_4 STRINGIFY(BTRFS_DEV_STAT_GENERATION_ERRS)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -26,8 +36,52 @@ const struct xlat btrfs_dev_stats_values
  .data = btrfs_dev_stats_values_xdata,
  .size = ARRAY_SIZE(btrfs_dev_stats_values_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/btrfs_features_compat.h 5.9-0ubuntu2/xlat/btrfs_features_compat.h
--- 5.5-3/xlat/btrfs_features_compat.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_features_compat.h	2020-09-24 09:18:43.000000000 +0000
@@ -21,6 +21,10 @@ const struct xlat btrfs_features_compat[
  .data = btrfs_features_compat_xdata,
  .size = ARRAY_SIZE(btrfs_features_compat_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+  ,
+ .flags_strsz = 0
+  ,
 } };
 
 # endif /* !IN_MPERS */
diff -pruN 5.5-3/xlat/btrfs_features_compat_ro.h 5.9-0ubuntu2/xlat/btrfs_features_compat_ro.h
--- 5.5-3/xlat/btrfs_features_compat_ro.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_features_compat_ro.h	2020-09-24 09:18:43.000000000 +0000
@@ -28,7 +28,11 @@ extern const struct xlat btrfs_features_
 
 static const struct xlat_data btrfs_features_compat_ro_xdata[] = {
  XLAT_TYPE(uint64_t, BTRFS_FEATURE_COMPAT_RO_FREE_SPACE_TREE),
+ #define XLAT_VAL_0 ((uint64_t) (BTRFS_FEATURE_COMPAT_RO_FREE_SPACE_TREE))
+ #define XLAT_STR_0 STRINGIFY(BTRFS_FEATURE_COMPAT_RO_FREE_SPACE_TREE)
  XLAT_TYPE(uint64_t, BTRFS_FEATURE_COMPAT_RO_FREE_SPACE_TREE_VALID),
+ #define XLAT_VAL_1 ((uint64_t) (BTRFS_FEATURE_COMPAT_RO_FREE_SPACE_TREE_VALID))
+ #define XLAT_STR_1 STRINGIFY(BTRFS_FEATURE_COMPAT_RO_FREE_SPACE_TREE_VALID)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -37,8 +41,28 @@ const struct xlat btrfs_features_compat_
  .data = btrfs_features_compat_ro_xdata,
  .size = ARRAY_SIZE(btrfs_features_compat_ro_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/btrfs_features_incompat.h 5.9-0ubuntu2/xlat/btrfs_features_incompat.h
--- 5.5-3/xlat/btrfs_features_incompat.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_features_incompat.h	2020-09-24 09:18:44.000000000 +0000
@@ -91,16 +91,38 @@ extern const struct xlat btrfs_features_
 
 static const struct xlat_data btrfs_features_incompat_xdata[] = {
  XLAT_TYPE(uint64_t, BTRFS_FEATURE_INCOMPAT_MIXED_BACKREF),
+ #define XLAT_VAL_0 ((uint64_t) (BTRFS_FEATURE_INCOMPAT_MIXED_BACKREF))
+ #define XLAT_STR_0 STRINGIFY(BTRFS_FEATURE_INCOMPAT_MIXED_BACKREF)
  XLAT_TYPE(uint64_t, BTRFS_FEATURE_INCOMPAT_DEFAULT_SUBVOL),
+ #define XLAT_VAL_1 ((uint64_t) (BTRFS_FEATURE_INCOMPAT_DEFAULT_SUBVOL))
+ #define XLAT_STR_1 STRINGIFY(BTRFS_FEATURE_INCOMPAT_DEFAULT_SUBVOL)
  XLAT_TYPE(uint64_t, BTRFS_FEATURE_INCOMPAT_MIXED_GROUPS),
+ #define XLAT_VAL_2 ((uint64_t) (BTRFS_FEATURE_INCOMPAT_MIXED_GROUPS))
+ #define XLAT_STR_2 STRINGIFY(BTRFS_FEATURE_INCOMPAT_MIXED_GROUPS)
  XLAT_TYPE(uint64_t, BTRFS_FEATURE_INCOMPAT_COMPRESS_LZO),
+ #define XLAT_VAL_3 ((uint64_t) (BTRFS_FEATURE_INCOMPAT_COMPRESS_LZO))
+ #define XLAT_STR_3 STRINGIFY(BTRFS_FEATURE_INCOMPAT_COMPRESS_LZO)
  XLAT_TYPE(uint64_t, BTRFS_FEATURE_INCOMPAT_COMPRESS_LZOv2),
+ #define XLAT_VAL_4 ((uint64_t) (BTRFS_FEATURE_INCOMPAT_COMPRESS_LZOv2))
+ #define XLAT_STR_4 STRINGIFY(BTRFS_FEATURE_INCOMPAT_COMPRESS_LZOv2)
  XLAT_TYPE(uint64_t, BTRFS_FEATURE_INCOMPAT_BIG_METADATA),
+ #define XLAT_VAL_5 ((uint64_t) (BTRFS_FEATURE_INCOMPAT_BIG_METADATA))
+ #define XLAT_STR_5 STRINGIFY(BTRFS_FEATURE_INCOMPAT_BIG_METADATA)
  XLAT_TYPE(uint64_t, BTRFS_FEATURE_INCOMPAT_EXTENDED_IREF),
+ #define XLAT_VAL_6 ((uint64_t) (BTRFS_FEATURE_INCOMPAT_EXTENDED_IREF))
+ #define XLAT_STR_6 STRINGIFY(BTRFS_FEATURE_INCOMPAT_EXTENDED_IREF)
  XLAT_TYPE(uint64_t, BTRFS_FEATURE_INCOMPAT_RAID56),
+ #define XLAT_VAL_7 ((uint64_t) (BTRFS_FEATURE_INCOMPAT_RAID56))
+ #define XLAT_STR_7 STRINGIFY(BTRFS_FEATURE_INCOMPAT_RAID56)
  XLAT_TYPE(uint64_t, BTRFS_FEATURE_INCOMPAT_SKINNY_METADATA),
+ #define XLAT_VAL_8 ((uint64_t) (BTRFS_FEATURE_INCOMPAT_SKINNY_METADATA))
+ #define XLAT_STR_8 STRINGIFY(BTRFS_FEATURE_INCOMPAT_SKINNY_METADATA)
  XLAT_TYPE(uint64_t, BTRFS_FEATURE_INCOMPAT_NO_HOLES),
+ #define XLAT_VAL_9 ((uint64_t) (BTRFS_FEATURE_INCOMPAT_NO_HOLES))
+ #define XLAT_STR_9 STRINGIFY(BTRFS_FEATURE_INCOMPAT_NO_HOLES)
  XLAT_TYPE(uint64_t, BTRFS_FEATURE_INCOMPAT_METADATA_UUID),
+ #define XLAT_VAL_10 ((uint64_t) (BTRFS_FEATURE_INCOMPAT_METADATA_UUID))
+ #define XLAT_STR_10 STRINGIFY(BTRFS_FEATURE_INCOMPAT_METADATA_UUID)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -109,8 +131,100 @@ const struct xlat btrfs_features_incompa
  .data = btrfs_features_incompat_xdata,
  .size = ARRAY_SIZE(btrfs_features_incompat_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/btrfs_key_types.h 5.9-0ubuntu2/xlat/btrfs_key_types.h
--- 5.5-3/xlat/btrfs_key_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_key_types.h	2020-09-24 09:18:45.000000000 +0000
@@ -301,46 +301,128 @@ extern const struct xlat btrfs_key_types
 
 static const struct xlat_data btrfs_key_types_xdata[] = {
  XLAT_TYPE(uint64_t, BTRFS_INODE_ITEM_KEY),
+ #define XLAT_VAL_0 ((uint64_t) (BTRFS_INODE_ITEM_KEY))
+ #define XLAT_STR_0 STRINGIFY(BTRFS_INODE_ITEM_KEY)
  XLAT_TYPE(uint64_t, BTRFS_INODE_REF_KEY),
+ #define XLAT_VAL_1 ((uint64_t) (BTRFS_INODE_REF_KEY))
+ #define XLAT_STR_1 STRINGIFY(BTRFS_INODE_REF_KEY)
  XLAT_TYPE(uint64_t, BTRFS_INODE_EXTREF_KEY),
+ #define XLAT_VAL_2 ((uint64_t) (BTRFS_INODE_EXTREF_KEY))
+ #define XLAT_STR_2 STRINGIFY(BTRFS_INODE_EXTREF_KEY)
  XLAT_TYPE(uint64_t, BTRFS_XATTR_ITEM_KEY),
+ #define XLAT_VAL_3 ((uint64_t) (BTRFS_XATTR_ITEM_KEY))
+ #define XLAT_STR_3 STRINGIFY(BTRFS_XATTR_ITEM_KEY)
  XLAT_TYPE(uint64_t, BTRFS_ORPHAN_ITEM_KEY),
+ #define XLAT_VAL_4 ((uint64_t) (BTRFS_ORPHAN_ITEM_KEY))
+ #define XLAT_STR_4 STRINGIFY(BTRFS_ORPHAN_ITEM_KEY)
  XLAT_TYPE(uint64_t, BTRFS_DIR_LOG_ITEM_KEY),
+ #define XLAT_VAL_5 ((uint64_t) (BTRFS_DIR_LOG_ITEM_KEY))
+ #define XLAT_STR_5 STRINGIFY(BTRFS_DIR_LOG_ITEM_KEY)
  XLAT_TYPE(uint64_t, BTRFS_DIR_LOG_INDEX_KEY),
+ #define XLAT_VAL_6 ((uint64_t) (BTRFS_DIR_LOG_INDEX_KEY))
+ #define XLAT_STR_6 STRINGIFY(BTRFS_DIR_LOG_INDEX_KEY)
  XLAT_TYPE(uint64_t, BTRFS_DIR_ITEM_KEY),
+ #define XLAT_VAL_7 ((uint64_t) (BTRFS_DIR_ITEM_KEY))
+ #define XLAT_STR_7 STRINGIFY(BTRFS_DIR_ITEM_KEY)
  XLAT_TYPE(uint64_t, BTRFS_DIR_INDEX_KEY),
+ #define XLAT_VAL_8 ((uint64_t) (BTRFS_DIR_INDEX_KEY))
+ #define XLAT_STR_8 STRINGIFY(BTRFS_DIR_INDEX_KEY)
  XLAT_TYPE(uint64_t, BTRFS_EXTENT_DATA_KEY),
+ #define XLAT_VAL_9 ((uint64_t) (BTRFS_EXTENT_DATA_KEY))
+ #define XLAT_STR_9 STRINGIFY(BTRFS_EXTENT_DATA_KEY)
  XLAT_TYPE(uint64_t, BTRFS_EXTENT_CSUM_KEY),
+ #define XLAT_VAL_10 ((uint64_t) (BTRFS_EXTENT_CSUM_KEY))
+ #define XLAT_STR_10 STRINGIFY(BTRFS_EXTENT_CSUM_KEY)
  XLAT_TYPE(uint64_t, BTRFS_ROOT_ITEM_KEY),
+ #define XLAT_VAL_11 ((uint64_t) (BTRFS_ROOT_ITEM_KEY))
+ #define XLAT_STR_11 STRINGIFY(BTRFS_ROOT_ITEM_KEY)
  XLAT_TYPE(uint64_t, BTRFS_ROOT_BACKREF_KEY),
+ #define XLAT_VAL_12 ((uint64_t) (BTRFS_ROOT_BACKREF_KEY))
+ #define XLAT_STR_12 STRINGIFY(BTRFS_ROOT_BACKREF_KEY)
  XLAT_TYPE(uint64_t, BTRFS_ROOT_REF_KEY),
+ #define XLAT_VAL_13 ((uint64_t) (BTRFS_ROOT_REF_KEY))
+ #define XLAT_STR_13 STRINGIFY(BTRFS_ROOT_REF_KEY)
  XLAT_TYPE(uint64_t, BTRFS_EXTENT_ITEM_KEY),
+ #define XLAT_VAL_14 ((uint64_t) (BTRFS_EXTENT_ITEM_KEY))
+ #define XLAT_STR_14 STRINGIFY(BTRFS_EXTENT_ITEM_KEY)
  XLAT_TYPE(uint64_t, BTRFS_METADATA_ITEM_KEY),
+ #define XLAT_VAL_15 ((uint64_t) (BTRFS_METADATA_ITEM_KEY))
+ #define XLAT_STR_15 STRINGIFY(BTRFS_METADATA_ITEM_KEY)
  XLAT_TYPE(uint64_t, BTRFS_TREE_BLOCK_REF_KEY),
+ #define XLAT_VAL_16 ((uint64_t) (BTRFS_TREE_BLOCK_REF_KEY))
+ #define XLAT_STR_16 STRINGIFY(BTRFS_TREE_BLOCK_REF_KEY)
  XLAT_TYPE(uint64_t, BTRFS_EXTENT_DATA_REF_KEY),
+ #define XLAT_VAL_17 ((uint64_t) (BTRFS_EXTENT_DATA_REF_KEY))
+ #define XLAT_STR_17 STRINGIFY(BTRFS_EXTENT_DATA_REF_KEY)
  XLAT_TYPE(uint64_t, BTRFS_EXTENT_REF_V0_KEY),
+ #define XLAT_VAL_18 ((uint64_t) (BTRFS_EXTENT_REF_V0_KEY))
+ #define XLAT_STR_18 STRINGIFY(BTRFS_EXTENT_REF_V0_KEY)
  XLAT_TYPE(uint64_t, BTRFS_SHARED_BLOCK_REF_KEY),
+ #define XLAT_VAL_19 ((uint64_t) (BTRFS_SHARED_BLOCK_REF_KEY))
+ #define XLAT_STR_19 STRINGIFY(BTRFS_SHARED_BLOCK_REF_KEY)
  XLAT_TYPE(uint64_t, BTRFS_SHARED_DATA_REF_KEY),
+ #define XLAT_VAL_20 ((uint64_t) (BTRFS_SHARED_DATA_REF_KEY))
+ #define XLAT_STR_20 STRINGIFY(BTRFS_SHARED_DATA_REF_KEY)
  XLAT_TYPE(uint64_t, BTRFS_BLOCK_GROUP_ITEM_KEY),
+ #define XLAT_VAL_21 ((uint64_t) (BTRFS_BLOCK_GROUP_ITEM_KEY))
+ #define XLAT_STR_21 STRINGIFY(BTRFS_BLOCK_GROUP_ITEM_KEY)
  XLAT_TYPE(uint64_t, BTRFS_FREE_SPACE_INFO_KEY),
+ #define XLAT_VAL_22 ((uint64_t) (BTRFS_FREE_SPACE_INFO_KEY))
+ #define XLAT_STR_22 STRINGIFY(BTRFS_FREE_SPACE_INFO_KEY)
  XLAT_TYPE(uint64_t, BTRFS_FREE_SPACE_EXTENT_KEY),
+ #define XLAT_VAL_23 ((uint64_t) (BTRFS_FREE_SPACE_EXTENT_KEY))
+ #define XLAT_STR_23 STRINGIFY(BTRFS_FREE_SPACE_EXTENT_KEY)
  XLAT_TYPE(uint64_t, BTRFS_FREE_SPACE_BITMAP_KEY),
+ #define XLAT_VAL_24 ((uint64_t) (BTRFS_FREE_SPACE_BITMAP_KEY))
+ #define XLAT_STR_24 STRINGIFY(BTRFS_FREE_SPACE_BITMAP_KEY)
  XLAT_TYPE(uint64_t, BTRFS_DEV_EXTENT_KEY),
+ #define XLAT_VAL_25 ((uint64_t) (BTRFS_DEV_EXTENT_KEY))
+ #define XLAT_STR_25 STRINGIFY(BTRFS_DEV_EXTENT_KEY)
  XLAT_TYPE(uint64_t, BTRFS_DEV_ITEM_KEY),
+ #define XLAT_VAL_26 ((uint64_t) (BTRFS_DEV_ITEM_KEY))
+ #define XLAT_STR_26 STRINGIFY(BTRFS_DEV_ITEM_KEY)
  XLAT_TYPE(uint64_t, BTRFS_CHUNK_ITEM_KEY),
+ #define XLAT_VAL_27 ((uint64_t) (BTRFS_CHUNK_ITEM_KEY))
+ #define XLAT_STR_27 STRINGIFY(BTRFS_CHUNK_ITEM_KEY)
  XLAT_TYPE(uint64_t, BTRFS_QGROUP_STATUS_KEY),
+ #define XLAT_VAL_28 ((uint64_t) (BTRFS_QGROUP_STATUS_KEY))
+ #define XLAT_STR_28 STRINGIFY(BTRFS_QGROUP_STATUS_KEY)
  XLAT_TYPE(uint64_t, BTRFS_QGROUP_INFO_KEY),
+ #define XLAT_VAL_29 ((uint64_t) (BTRFS_QGROUP_INFO_KEY))
+ #define XLAT_STR_29 STRINGIFY(BTRFS_QGROUP_INFO_KEY)
  XLAT_TYPE(uint64_t, BTRFS_QGROUP_LIMIT_KEY),
+ #define XLAT_VAL_30 ((uint64_t) (BTRFS_QGROUP_LIMIT_KEY))
+ #define XLAT_STR_30 STRINGIFY(BTRFS_QGROUP_LIMIT_KEY)
  XLAT_TYPE(uint64_t, BTRFS_QGROUP_RELATION_KEY),
+ #define XLAT_VAL_31 ((uint64_t) (BTRFS_QGROUP_RELATION_KEY))
+ #define XLAT_STR_31 STRINGIFY(BTRFS_QGROUP_RELATION_KEY)
  XLAT_TYPE(uint64_t, BTRFS_BALANCE_ITEM_KEY),
+ #define XLAT_VAL_32 ((uint64_t) (BTRFS_BALANCE_ITEM_KEY))
+ #define XLAT_STR_32 STRINGIFY(BTRFS_BALANCE_ITEM_KEY)
  XLAT_TYPE(uint64_t, BTRFS_TEMPORARY_ITEM_KEY),
+ #define XLAT_VAL_33 ((uint64_t) (BTRFS_TEMPORARY_ITEM_KEY))
+ #define XLAT_STR_33 STRINGIFY(BTRFS_TEMPORARY_ITEM_KEY)
  XLAT_TYPE(uint64_t, BTRFS_DEV_STATS_KEY),
+ #define XLAT_VAL_34 ((uint64_t) (BTRFS_DEV_STATS_KEY))
+ #define XLAT_STR_34 STRINGIFY(BTRFS_DEV_STATS_KEY)
  XLAT_TYPE(uint64_t, BTRFS_PERSISTENT_ITEM_KEY),
+ #define XLAT_VAL_35 ((uint64_t) (BTRFS_PERSISTENT_ITEM_KEY))
+ #define XLAT_STR_35 STRINGIFY(BTRFS_PERSISTENT_ITEM_KEY)
  XLAT_TYPE(uint64_t, BTRFS_DEV_REPLACE_KEY),
+ #define XLAT_VAL_36 ((uint64_t) (BTRFS_DEV_REPLACE_KEY))
+ #define XLAT_STR_36 STRINGIFY(BTRFS_DEV_REPLACE_KEY)
  XLAT_TYPE(uint64_t, BTRFS_UUID_KEY_SUBVOL),
+ #define XLAT_VAL_37 ((uint64_t) (BTRFS_UUID_KEY_SUBVOL))
+ #define XLAT_STR_37 STRINGIFY(BTRFS_UUID_KEY_SUBVOL)
  XLAT_TYPE(uint64_t, BTRFS_UUID_KEY_RECEIVED_SUBVOL),
+ #define XLAT_VAL_38 ((uint64_t) (BTRFS_UUID_KEY_RECEIVED_SUBVOL))
+ #define XLAT_STR_38 STRINGIFY(BTRFS_UUID_KEY_RECEIVED_SUBVOL)
  XLAT_TYPE(uint64_t, BTRFS_STRING_ITEM_KEY),
+ #define XLAT_VAL_39 ((uint64_t) (BTRFS_STRING_ITEM_KEY))
+ #define XLAT_STR_39 STRINGIFY(BTRFS_STRING_ITEM_KEY)
  XLAT_TYPE(uint64_t, UINT32_MAX),
+ #define XLAT_VAL_40 ((uint64_t) (UINT32_MAX))
+ #define XLAT_STR_40 STRINGIFY(UINT32_MAX)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -349,8 +431,340 @@ const struct xlat btrfs_key_types[1] = {
  .data = btrfs_key_types_xdata,
  .size = ARRAY_SIZE(btrfs_key_types_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/btrfs_logical_ino_args_flags.h 5.9-0ubuntu2/xlat/btrfs_logical_ino_args_flags.h
--- 5.5-3/xlat/btrfs_logical_ino_args_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_logical_ino_args_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -21,6 +21,8 @@ extern const struct xlat btrfs_logical_i
 
 static const struct xlat_data btrfs_logical_ino_args_flags_xdata[] = {
  XLAT(BTRFS_LOGICAL_INO_ARGS_IGNORE_OFFSET),
+ #define XLAT_VAL_0 ((unsigned) (BTRFS_LOGICAL_INO_ARGS_IGNORE_OFFSET))
+ #define XLAT_STR_0 STRINGIFY(BTRFS_LOGICAL_INO_ARGS_IGNORE_OFFSET)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -29,8 +31,20 @@ const struct xlat btrfs_logical_ino_args
  .data = btrfs_logical_ino_args_flags_xdata,
  .size = ARRAY_SIZE(btrfs_logical_ino_args_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/btrfs_qgroup_ctl_cmds.h 5.9-0ubuntu2/xlat/btrfs_qgroup_ctl_cmds.h
--- 5.5-3/xlat/btrfs_qgroup_ctl_cmds.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_qgroup_ctl_cmds.h	2020-09-24 09:18:44.000000000 +0000
@@ -15,12 +15,18 @@ extern const struct xlat btrfs_qgroup_ct
 static const struct xlat_data btrfs_qgroup_ctl_cmds_xdata[] = {
 #if defined(BTRFS_QUOTA_CTL_ENABLE) || (defined(HAVE_DECL_BTRFS_QUOTA_CTL_ENABLE) && HAVE_DECL_BTRFS_QUOTA_CTL_ENABLE)
   XLAT_TYPE(uint64_t, BTRFS_QUOTA_CTL_ENABLE),
+ #define XLAT_VAL_0 ((uint64_t) (BTRFS_QUOTA_CTL_ENABLE))
+ #define XLAT_STR_0 STRINGIFY(BTRFS_QUOTA_CTL_ENABLE)
 #endif
 #if defined(BTRFS_QUOTA_CTL_DISABLE) || (defined(HAVE_DECL_BTRFS_QUOTA_CTL_DISABLE) && HAVE_DECL_BTRFS_QUOTA_CTL_DISABLE)
   XLAT_TYPE(uint64_t, BTRFS_QUOTA_CTL_DISABLE),
+ #define XLAT_VAL_1 ((uint64_t) (BTRFS_QUOTA_CTL_DISABLE))
+ #define XLAT_STR_1 STRINGIFY(BTRFS_QUOTA_CTL_DISABLE)
 #endif
 #if defined(BTRFS_QUOTA_CTL_RESCAN__NOTUSED) || (defined(HAVE_DECL_BTRFS_QUOTA_CTL_RESCAN__NOTUSED) && HAVE_DECL_BTRFS_QUOTA_CTL_RESCAN__NOTUSED)
   XLAT_TYPE(uint64_t, BTRFS_QUOTA_CTL_RESCAN__NOTUSED),
+ #define XLAT_VAL_2 ((uint64_t) (BTRFS_QUOTA_CTL_RESCAN__NOTUSED))
+ #define XLAT_STR_2 STRINGIFY(BTRFS_QUOTA_CTL_RESCAN__NOTUSED)
 #endif
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
@@ -30,8 +36,36 @@ const struct xlat btrfs_qgroup_ctl_cmds[
  .data = btrfs_qgroup_ctl_cmds_xdata,
  .size = ARRAY_SIZE(btrfs_qgroup_ctl_cmds_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/btrfs_qgroup_inherit_flags.h 5.9-0ubuntu2/xlat/btrfs_qgroup_inherit_flags.h
--- 5.5-3/xlat/btrfs_qgroup_inherit_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_qgroup_inherit_flags.h	2020-09-24 09:18:43.000000000 +0000
@@ -15,6 +15,8 @@ extern const struct xlat btrfs_qgroup_in
 static const struct xlat_data btrfs_qgroup_inherit_flags_xdata[] = {
 #if defined(BTRFS_QGROUP_INHERIT_SET_LIMITS) || (defined(HAVE_DECL_BTRFS_QGROUP_INHERIT_SET_LIMITS) && HAVE_DECL_BTRFS_QGROUP_INHERIT_SET_LIMITS)
   XLAT_TYPE(uint64_t, BTRFS_QGROUP_INHERIT_SET_LIMITS),
+ #define XLAT_VAL_0 ((uint64_t) (BTRFS_QGROUP_INHERIT_SET_LIMITS))
+ #define XLAT_STR_0 STRINGIFY(BTRFS_QGROUP_INHERIT_SET_LIMITS)
 #endif
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
@@ -24,8 +26,20 @@ const struct xlat btrfs_qgroup_inherit_f
  .data = btrfs_qgroup_inherit_flags_xdata,
  .size = ARRAY_SIZE(btrfs_qgroup_inherit_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/btrfs_qgroup_limit_flags.h 5.9-0ubuntu2/xlat/btrfs_qgroup_limit_flags.h
--- 5.5-3/xlat/btrfs_qgroup_limit_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_qgroup_limit_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -56,11 +56,23 @@ extern const struct xlat btrfs_qgroup_li
 
 static const struct xlat_data btrfs_qgroup_limit_flags_xdata[] = {
  XLAT_TYPE(uint64_t, BTRFS_QGROUP_LIMIT_MAX_RFER),
+ #define XLAT_VAL_0 ((uint64_t) (BTRFS_QGROUP_LIMIT_MAX_RFER))
+ #define XLAT_STR_0 STRINGIFY(BTRFS_QGROUP_LIMIT_MAX_RFER)
  XLAT_TYPE(uint64_t, BTRFS_QGROUP_LIMIT_MAX_EXCL),
+ #define XLAT_VAL_1 ((uint64_t) (BTRFS_QGROUP_LIMIT_MAX_EXCL))
+ #define XLAT_STR_1 STRINGIFY(BTRFS_QGROUP_LIMIT_MAX_EXCL)
  XLAT_TYPE(uint64_t, BTRFS_QGROUP_LIMIT_RSV_RFER),
+ #define XLAT_VAL_2 ((uint64_t) (BTRFS_QGROUP_LIMIT_RSV_RFER))
+ #define XLAT_STR_2 STRINGIFY(BTRFS_QGROUP_LIMIT_RSV_RFER)
  XLAT_TYPE(uint64_t, BTRFS_QGROUP_LIMIT_RSV_EXCL),
+ #define XLAT_VAL_3 ((uint64_t) (BTRFS_QGROUP_LIMIT_RSV_EXCL))
+ #define XLAT_STR_3 STRINGIFY(BTRFS_QGROUP_LIMIT_RSV_EXCL)
  XLAT_TYPE(uint64_t, BTRFS_QGROUP_LIMIT_RFER_CMPR),
+ #define XLAT_VAL_4 ((uint64_t) (BTRFS_QGROUP_LIMIT_RFER_CMPR))
+ #define XLAT_STR_4 STRINGIFY(BTRFS_QGROUP_LIMIT_RFER_CMPR)
  XLAT_TYPE(uint64_t, BTRFS_QGROUP_LIMIT_EXCL_CMPR),
+ #define XLAT_VAL_5 ((uint64_t) (BTRFS_QGROUP_LIMIT_EXCL_CMPR))
+ #define XLAT_STR_5 STRINGIFY(BTRFS_QGROUP_LIMIT_EXCL_CMPR)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -69,8 +81,60 @@ const struct xlat btrfs_qgroup_limit_fla
  .data = btrfs_qgroup_limit_flags_xdata,
  .size = ARRAY_SIZE(btrfs_qgroup_limit_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/btrfs_qgroup_status_flags.h 5.9-0ubuntu2/xlat/btrfs_qgroup_status_flags.h
--- 5.5-3/xlat/btrfs_qgroup_status_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_qgroup_status_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -28,7 +28,11 @@ extern const struct xlat btrfs_qgroup_st
 
 static const struct xlat_data btrfs_qgroup_status_flags_xdata[] = {
  XLAT_TYPE(uint64_t, BTRFS_QGROUP_STATUS_FLAG_ON),
+ #define XLAT_VAL_0 ((uint64_t) (BTRFS_QGROUP_STATUS_FLAG_ON))
+ #define XLAT_STR_0 STRINGIFY(BTRFS_QGROUP_STATUS_FLAG_ON)
  XLAT_TYPE(uint64_t, BTRFS_QGROUP_STATUS_FLAG_RESCAN),
+ #define XLAT_VAL_1 ((uint64_t) (BTRFS_QGROUP_STATUS_FLAG_RESCAN))
+ #define XLAT_STR_1 STRINGIFY(BTRFS_QGROUP_STATUS_FLAG_RESCAN)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -37,8 +41,28 @@ const struct xlat btrfs_qgroup_status_fl
  .data = btrfs_qgroup_status_flags_xdata,
  .size = ARRAY_SIZE(btrfs_qgroup_status_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/btrfs_scrub_flags.h 5.9-0ubuntu2/xlat/btrfs_scrub_flags.h
--- 5.5-3/xlat/btrfs_scrub_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_scrub_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -21,6 +21,8 @@ extern const struct xlat btrfs_scrub_fla
 
 static const struct xlat_data btrfs_scrub_flags_xdata[] = {
  XLAT_TYPE(uint64_t, BTRFS_SCRUB_READONLY),
+ #define XLAT_VAL_0 ((uint64_t) (BTRFS_SCRUB_READONLY))
+ #define XLAT_STR_0 STRINGIFY(BTRFS_SCRUB_READONLY)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -29,8 +31,20 @@ const struct xlat btrfs_scrub_flags[1] =
  .data = btrfs_scrub_flags_xdata,
  .size = ARRAY_SIZE(btrfs_scrub_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/btrfs_send_flags.h 5.9-0ubuntu2/xlat/btrfs_send_flags.h
--- 5.5-3/xlat/btrfs_send_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_send_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -35,8 +35,14 @@ extern const struct xlat btrfs_send_flag
 
 static const struct xlat_data btrfs_send_flags_xdata[] = {
  XLAT(BTRFS_SEND_FLAG_NO_FILE_DATA),
+ #define XLAT_VAL_0 ((unsigned) (BTRFS_SEND_FLAG_NO_FILE_DATA))
+ #define XLAT_STR_0 STRINGIFY(BTRFS_SEND_FLAG_NO_FILE_DATA)
  XLAT(BTRFS_SEND_FLAG_OMIT_STREAM_HEADER),
+ #define XLAT_VAL_1 ((unsigned) (BTRFS_SEND_FLAG_OMIT_STREAM_HEADER))
+ #define XLAT_STR_1 STRINGIFY(BTRFS_SEND_FLAG_OMIT_STREAM_HEADER)
  XLAT(BTRFS_SEND_FLAG_OMIT_END_CMD),
+ #define XLAT_VAL_2 ((unsigned) (BTRFS_SEND_FLAG_OMIT_END_CMD))
+ #define XLAT_STR_2 STRINGIFY(BTRFS_SEND_FLAG_OMIT_END_CMD)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -45,8 +51,36 @@ const struct xlat btrfs_send_flags[1] =
  .data = btrfs_send_flags_xdata,
  .size = ARRAY_SIZE(btrfs_send_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/btrfs_snap_flags_v2.h 5.9-0ubuntu2/xlat/btrfs_snap_flags_v2.h
--- 5.5-3/xlat/btrfs_snap_flags_v2.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_snap_flags_v2.h	2020-09-24 09:18:44.000000000 +0000
@@ -15,12 +15,18 @@ extern const struct xlat btrfs_snap_flag
 static const struct xlat_data btrfs_snap_flags_v2_xdata[] = {
 #if defined(BTRFS_SUBVOL_CREATE_ASYNC) || (defined(HAVE_DECL_BTRFS_SUBVOL_CREATE_ASYNC) && HAVE_DECL_BTRFS_SUBVOL_CREATE_ASYNC)
   XLAT_TYPE(uint64_t, BTRFS_SUBVOL_CREATE_ASYNC),
+ #define XLAT_VAL_0 ((uint64_t) (BTRFS_SUBVOL_CREATE_ASYNC))
+ #define XLAT_STR_0 STRINGIFY(BTRFS_SUBVOL_CREATE_ASYNC)
 #endif
 #if defined(BTRFS_SUBVOL_RDONLY) || (defined(HAVE_DECL_BTRFS_SUBVOL_RDONLY) && HAVE_DECL_BTRFS_SUBVOL_RDONLY)
   XLAT_TYPE(uint64_t, BTRFS_SUBVOL_RDONLY),
+ #define XLAT_VAL_1 ((uint64_t) (BTRFS_SUBVOL_RDONLY))
+ #define XLAT_STR_1 STRINGIFY(BTRFS_SUBVOL_RDONLY)
 #endif
 #if defined(BTRFS_SUBVOL_QGROUP_INHERIT) || (defined(HAVE_DECL_BTRFS_SUBVOL_QGROUP_INHERIT) && HAVE_DECL_BTRFS_SUBVOL_QGROUP_INHERIT)
   XLAT_TYPE(uint64_t, BTRFS_SUBVOL_QGROUP_INHERIT),
+ #define XLAT_VAL_2 ((uint64_t) (BTRFS_SUBVOL_QGROUP_INHERIT))
+ #define XLAT_STR_2 STRINGIFY(BTRFS_SUBVOL_QGROUP_INHERIT)
 #endif
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
@@ -30,8 +36,36 @@ const struct xlat btrfs_snap_flags_v2[1]
  .data = btrfs_snap_flags_v2_xdata,
  .size = ARRAY_SIZE(btrfs_snap_flags_v2_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/btrfs_space_info_flags.h 5.9-0ubuntu2/xlat/btrfs_space_info_flags.h
--- 5.5-3/xlat/btrfs_space_info_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_space_info_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -91,16 +91,38 @@ extern const struct xlat btrfs_space_inf
 
 static const struct xlat_data btrfs_space_info_flags_xdata[] = {
  XLAT_TYPE(uint64_t, BTRFS_BLOCK_GROUP_DATA),
+ #define XLAT_VAL_0 ((uint64_t) (BTRFS_BLOCK_GROUP_DATA))
+ #define XLAT_STR_0 STRINGIFY(BTRFS_BLOCK_GROUP_DATA)
  XLAT_TYPE(uint64_t, BTRFS_BLOCK_GROUP_SYSTEM),
+ #define XLAT_VAL_1 ((uint64_t) (BTRFS_BLOCK_GROUP_SYSTEM))
+ #define XLAT_STR_1 STRINGIFY(BTRFS_BLOCK_GROUP_SYSTEM)
  XLAT_TYPE(uint64_t, BTRFS_BLOCK_GROUP_METADATA),
+ #define XLAT_VAL_2 ((uint64_t) (BTRFS_BLOCK_GROUP_METADATA))
+ #define XLAT_STR_2 STRINGIFY(BTRFS_BLOCK_GROUP_METADATA)
  XLAT_TYPE(uint64_t, BTRFS_BLOCK_GROUP_RAID0),
+ #define XLAT_VAL_3 ((uint64_t) (BTRFS_BLOCK_GROUP_RAID0))
+ #define XLAT_STR_3 STRINGIFY(BTRFS_BLOCK_GROUP_RAID0)
  XLAT_TYPE(uint64_t, BTRFS_BLOCK_GROUP_RAID1),
+ #define XLAT_VAL_4 ((uint64_t) (BTRFS_BLOCK_GROUP_RAID1))
+ #define XLAT_STR_4 STRINGIFY(BTRFS_BLOCK_GROUP_RAID1)
  XLAT_TYPE(uint64_t, BTRFS_BLOCK_GROUP_DUP),
+ #define XLAT_VAL_5 ((uint64_t) (BTRFS_BLOCK_GROUP_DUP))
+ #define XLAT_STR_5 STRINGIFY(BTRFS_BLOCK_GROUP_DUP)
  XLAT_TYPE(uint64_t, BTRFS_BLOCK_GROUP_RAID10),
+ #define XLAT_VAL_6 ((uint64_t) (BTRFS_BLOCK_GROUP_RAID10))
+ #define XLAT_STR_6 STRINGIFY(BTRFS_BLOCK_GROUP_RAID10)
  XLAT_TYPE(uint64_t, BTRFS_BLOCK_GROUP_RAID5),
+ #define XLAT_VAL_7 ((uint64_t) (BTRFS_BLOCK_GROUP_RAID5))
+ #define XLAT_STR_7 STRINGIFY(BTRFS_BLOCK_GROUP_RAID5)
  XLAT_TYPE(uint64_t, BTRFS_BLOCK_GROUP_RAID6),
+ #define XLAT_VAL_8 ((uint64_t) (BTRFS_BLOCK_GROUP_RAID6))
+ #define XLAT_STR_8 STRINGIFY(BTRFS_BLOCK_GROUP_RAID6)
  XLAT_TYPE(uint64_t, BTRFS_AVAIL_ALLOC_BIT_SINGLE),
+ #define XLAT_VAL_9 ((uint64_t) (BTRFS_AVAIL_ALLOC_BIT_SINGLE))
+ #define XLAT_STR_9 STRINGIFY(BTRFS_AVAIL_ALLOC_BIT_SINGLE)
  XLAT_TYPE(uint64_t, BTRFS_SPACE_INFO_GLOBAL_RSV),
+ #define XLAT_VAL_10 ((uint64_t) (BTRFS_SPACE_INFO_GLOBAL_RSV))
+ #define XLAT_STR_10 STRINGIFY(BTRFS_SPACE_INFO_GLOBAL_RSV)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -109,8 +131,100 @@ const struct xlat btrfs_space_info_flags
  .data = btrfs_space_info_flags_xdata,
  .size = ARRAY_SIZE(btrfs_space_info_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/btrfs_tree_objectids.h 5.9-0ubuntu2/xlat/btrfs_tree_objectids.h
--- 5.5-3/xlat/btrfs_tree_objectids.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/btrfs_tree_objectids.h	2020-09-24 09:18:44.000000000 +0000
@@ -105,18 +105,44 @@ extern const struct xlat btrfs_tree_obje
 
 static const struct xlat_data btrfs_tree_objectids_xdata[] = {
  XLAT_TYPE(uint64_t, BTRFS_ROOT_TREE_OBJECTID),
+ #define XLAT_VAL_0 ((uint64_t) (BTRFS_ROOT_TREE_OBJECTID))
+ #define XLAT_STR_0 STRINGIFY(BTRFS_ROOT_TREE_OBJECTID)
  XLAT_TYPE(uint64_t, BTRFS_EXTENT_TREE_OBJECTID),
+ #define XLAT_VAL_1 ((uint64_t) (BTRFS_EXTENT_TREE_OBJECTID))
+ #define XLAT_STR_1 STRINGIFY(BTRFS_EXTENT_TREE_OBJECTID)
  XLAT_TYPE(uint64_t, BTRFS_CHUNK_TREE_OBJECTID),
+ #define XLAT_VAL_2 ((uint64_t) (BTRFS_CHUNK_TREE_OBJECTID))
+ #define XLAT_STR_2 STRINGIFY(BTRFS_CHUNK_TREE_OBJECTID)
  XLAT_TYPE(uint64_t, BTRFS_DEV_TREE_OBJECTID),
+ #define XLAT_VAL_3 ((uint64_t) (BTRFS_DEV_TREE_OBJECTID))
+ #define XLAT_STR_3 STRINGIFY(BTRFS_DEV_TREE_OBJECTID)
  XLAT_TYPE(uint64_t, BTRFS_FS_TREE_OBJECTID),
+ #define XLAT_VAL_4 ((uint64_t) (BTRFS_FS_TREE_OBJECTID))
+ #define XLAT_STR_4 STRINGIFY(BTRFS_FS_TREE_OBJECTID)
  XLAT_TYPE(uint64_t, BTRFS_ROOT_TREE_DIR_OBJECTID),
+ #define XLAT_VAL_5 ((uint64_t) (BTRFS_ROOT_TREE_DIR_OBJECTID))
+ #define XLAT_STR_5 STRINGIFY(BTRFS_ROOT_TREE_DIR_OBJECTID)
  XLAT_TYPE(uint64_t, BTRFS_CSUM_TREE_OBJECTID),
+ #define XLAT_VAL_6 ((uint64_t) (BTRFS_CSUM_TREE_OBJECTID))
+ #define XLAT_STR_6 STRINGIFY(BTRFS_CSUM_TREE_OBJECTID)
  XLAT_TYPE(uint64_t, BTRFS_QUOTA_TREE_OBJECTID),
+ #define XLAT_VAL_7 ((uint64_t) (BTRFS_QUOTA_TREE_OBJECTID))
+ #define XLAT_STR_7 STRINGIFY(BTRFS_QUOTA_TREE_OBJECTID)
  XLAT_TYPE(uint64_t, BTRFS_UUID_TREE_OBJECTID),
+ #define XLAT_VAL_8 ((uint64_t) (BTRFS_UUID_TREE_OBJECTID))
+ #define XLAT_STR_8 STRINGIFY(BTRFS_UUID_TREE_OBJECTID)
  XLAT_TYPE(uint64_t, BTRFS_FREE_SPACE_TREE_OBJECTID),
+ #define XLAT_VAL_9 ((uint64_t) (BTRFS_FREE_SPACE_TREE_OBJECTID))
+ #define XLAT_STR_9 STRINGIFY(BTRFS_FREE_SPACE_TREE_OBJECTID)
  XLAT_TYPE(uint64_t, BTRFS_FIRST_FREE_OBJECTID),
+ #define XLAT_VAL_10 ((uint64_t) (BTRFS_FIRST_FREE_OBJECTID))
+ #define XLAT_STR_10 STRINGIFY(BTRFS_FIRST_FREE_OBJECTID)
  XLAT_TYPE(uint64_t, BTRFS_LAST_FREE_OBJECTID),
+ #define XLAT_VAL_11 ((uint64_t) (BTRFS_LAST_FREE_OBJECTID))
+ #define XLAT_STR_11 STRINGIFY(BTRFS_LAST_FREE_OBJECTID)
  XLAT_TYPE(uint64_t, UINT64_MAX),
+ #define XLAT_VAL_12 ((uint64_t) (UINT64_MAX))
+ #define XLAT_STR_12 STRINGIFY(UINT64_MAX)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -125,8 +151,116 @@ const struct xlat btrfs_tree_objectids[1
  .data = btrfs_tree_objectids_xdata,
  .size = ARRAY_SIZE(btrfs_tree_objectids_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/cacheflush_flags.h 5.9-0ubuntu2/xlat/cacheflush_flags.h
--- 5.5-3/xlat/cacheflush_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/cacheflush_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -97,22 +97,44 @@ static const struct xlat_data cacheflush
 #if defined M68K
 
  XLAT(FLUSH_CACHE_BOTH),
+ #define XLAT_VAL_0 ((unsigned) (FLUSH_CACHE_BOTH))
+ #define XLAT_STR_0 STRINGIFY(FLUSH_CACHE_BOTH)
  XLAT(FLUSH_CACHE_DATA),
+ #define XLAT_VAL_1 ((unsigned) (FLUSH_CACHE_DATA))
+ #define XLAT_STR_1 STRINGIFY(FLUSH_CACHE_DATA)
  XLAT(FLUSH_CACHE_INSN),
+ #define XLAT_VAL_2 ((unsigned) (FLUSH_CACHE_INSN))
+ #define XLAT_STR_2 STRINGIFY(FLUSH_CACHE_INSN)
 
 #elif defined BFIN || defined CSKY
 
  XLAT(BCACHE),
+ #define XLAT_VAL_3 ((unsigned) (BCACHE))
+ #define XLAT_STR_3 STRINGIFY(BCACHE)
  XLAT(ICACHE),
+ #define XLAT_VAL_4 ((unsigned) (ICACHE))
+ #define XLAT_STR_4 STRINGIFY(ICACHE)
  XLAT(DCACHE),
+ #define XLAT_VAL_5 ((unsigned) (DCACHE))
+ #define XLAT_STR_5 STRINGIFY(DCACHE)
 
 #elif defined SH
 
  XLAT(BCACHE),
+ #define XLAT_VAL_6 ((unsigned) (BCACHE))
+ #define XLAT_STR_6 STRINGIFY(BCACHE)
  XLAT(ICACHE),
+ #define XLAT_VAL_7 ((unsigned) (ICACHE))
+ #define XLAT_STR_7 STRINGIFY(ICACHE)
  XLAT(DCACHE),
+ #define XLAT_VAL_8 ((unsigned) (DCACHE))
+ #define XLAT_STR_8 STRINGIFY(DCACHE)
  XLAT(CACHEFLUSH_D_INVAL),
+ #define XLAT_VAL_9 ((unsigned) (CACHEFLUSH_D_INVAL))
+ #define XLAT_STR_9 STRINGIFY(CACHEFLUSH_D_INVAL)
  XLAT(CACHEFLUSH_D_WB),
+ #define XLAT_VAL_10 ((unsigned) (CACHEFLUSH_D_WB))
+ #define XLAT_STR_10 STRINGIFY(CACHEFLUSH_D_WB)
 
 #endif
 };
@@ -121,8 +143,100 @@ const struct xlat cacheflush_flags[1] =
  .data = cacheflush_flags_xdata,
  .size = ARRAY_SIZE(cacheflush_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/cacheflush_scope.h 5.9-0ubuntu2/xlat/cacheflush_scope.h
--- 5.5-3/xlat/cacheflush_scope.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/cacheflush_scope.h	2020-09-24 09:18:44.000000000 +0000
@@ -15,12 +15,18 @@
 static const struct xlat_data cacheflush_scope_xdata[] = {
 #if defined(FLUSH_SCOPE_LINE) || (defined(HAVE_DECL_FLUSH_SCOPE_LINE) && HAVE_DECL_FLUSH_SCOPE_LINE)
   XLAT(FLUSH_SCOPE_LINE),
+ #define XLAT_VAL_0 ((unsigned) (FLUSH_SCOPE_LINE))
+ #define XLAT_STR_0 STRINGIFY(FLUSH_SCOPE_LINE)
 #endif
 #if defined(FLUSH_SCOPE_PAGE) || (defined(HAVE_DECL_FLUSH_SCOPE_PAGE) && HAVE_DECL_FLUSH_SCOPE_PAGE)
   XLAT(FLUSH_SCOPE_PAGE),
+ #define XLAT_VAL_1 ((unsigned) (FLUSH_SCOPE_PAGE))
+ #define XLAT_STR_1 STRINGIFY(FLUSH_SCOPE_PAGE)
 #endif
 #if defined(FLUSH_SCOPE_ALL) || (defined(HAVE_DECL_FLUSH_SCOPE_ALL) && HAVE_DECL_FLUSH_SCOPE_ALL)
   XLAT(FLUSH_SCOPE_ALL),
+ #define XLAT_VAL_2 ((unsigned) (FLUSH_SCOPE_ALL))
+ #define XLAT_STR_2 STRINGIFY(FLUSH_SCOPE_ALL)
 #endif
 };
 static
@@ -28,8 +34,36 @@ const struct xlat cacheflush_scope[1] =
  .data = cacheflush_scope_xdata,
  .size = ARRAY_SIZE(cacheflush_scope_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/caif_protocols.h 5.9-0ubuntu2/xlat/caif_protocols.h
--- 5.5-3/xlat/caif_protocols.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/caif_protocols.h	2020-09-24 09:18:44.000000000 +0000
@@ -56,19 +56,83 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data caif_protocols_xdata[] = {
  [CAIFPROTO_AT] = XLAT(CAIFPROTO_AT),
+ #define XLAT_VAL_0 ((unsigned) (CAIFPROTO_AT))
+ #define XLAT_STR_0 STRINGIFY(CAIFPROTO_AT)
  [CAIFPROTO_DATAGRAM] = XLAT(CAIFPROTO_DATAGRAM),
+ #define XLAT_VAL_1 ((unsigned) (CAIFPROTO_DATAGRAM))
+ #define XLAT_STR_1 STRINGIFY(CAIFPROTO_DATAGRAM)
  [CAIFPROTO_DATAGRAM_LOOP] = XLAT(CAIFPROTO_DATAGRAM_LOOP),
+ #define XLAT_VAL_2 ((unsigned) (CAIFPROTO_DATAGRAM_LOOP))
+ #define XLAT_STR_2 STRINGIFY(CAIFPROTO_DATAGRAM_LOOP)
  [CAIFPROTO_UTIL] = XLAT(CAIFPROTO_UTIL),
+ #define XLAT_VAL_3 ((unsigned) (CAIFPROTO_UTIL))
+ #define XLAT_STR_3 STRINGIFY(CAIFPROTO_UTIL)
  [CAIFPROTO_RFM] = XLAT(CAIFPROTO_RFM),
+ #define XLAT_VAL_4 ((unsigned) (CAIFPROTO_RFM))
+ #define XLAT_STR_4 STRINGIFY(CAIFPROTO_RFM)
  [CAIFPROTO_DEBUG] = XLAT(CAIFPROTO_DEBUG),
+ #define XLAT_VAL_5 ((unsigned) (CAIFPROTO_DEBUG))
+ #define XLAT_STR_5 STRINGIFY(CAIFPROTO_DEBUG)
 };
 static
 const struct xlat caif_protocols[1] = { {
  .data = caif_protocols_xdata,
  .size = ARRAY_SIZE(caif_protocols_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/can_protocols.h 5.9-0ubuntu2/xlat/can_protocols.h
--- 5.5-3/xlat/can_protocols.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/can_protocols.h	2020-09-24 09:18:44.000000000 +0000
@@ -63,20 +63,94 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data can_protocols_xdata[] = {
  [CAN_RAW] = XLAT(CAN_RAW),
+ #define XLAT_VAL_0 ((unsigned) (CAN_RAW))
+ #define XLAT_STR_0 STRINGIFY(CAN_RAW)
  [CAN_BCM] = XLAT(CAN_BCM),
+ #define XLAT_VAL_1 ((unsigned) (CAN_BCM))
+ #define XLAT_STR_1 STRINGIFY(CAN_BCM)
  [CAN_TP16] = XLAT(CAN_TP16),
+ #define XLAT_VAL_2 ((unsigned) (CAN_TP16))
+ #define XLAT_STR_2 STRINGIFY(CAN_TP16)
  [CAN_TP20] = XLAT(CAN_TP20),
+ #define XLAT_VAL_3 ((unsigned) (CAN_TP20))
+ #define XLAT_STR_3 STRINGIFY(CAN_TP20)
  [CAN_MCNET] = XLAT(CAN_MCNET),
+ #define XLAT_VAL_4 ((unsigned) (CAN_MCNET))
+ #define XLAT_STR_4 STRINGIFY(CAN_MCNET)
  [CAN_ISOTP] = XLAT(CAN_ISOTP),
+ #define XLAT_VAL_5 ((unsigned) (CAN_ISOTP))
+ #define XLAT_STR_5 STRINGIFY(CAN_ISOTP)
  [CAN_J1939] = XLAT(CAN_J1939),
+ #define XLAT_VAL_6 ((unsigned) (CAN_J1939))
+ #define XLAT_STR_6 STRINGIFY(CAN_J1939)
 };
 static
 const struct xlat can_protocols[1] = { {
  .data = can_protocols_xdata,
  .size = ARRAY_SIZE(can_protocols_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/cap.h 5.9-0ubuntu2/xlat/cap.h
--- 5.5-3/xlat/cap.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/cap.h	2020-09-24 09:18:45.000000000 +0000
@@ -14,51 +14,468 @@
 
 static const struct xlat_data cap_xdata[] = {
  XLAT(CAP_CHOWN),
+ #define XLAT_VAL_0 ((unsigned) (CAP_CHOWN))
+ #define XLAT_STR_0 STRINGIFY(CAP_CHOWN)
  XLAT(CAP_DAC_OVERRIDE),
+ #define XLAT_VAL_1 ((unsigned) (CAP_DAC_OVERRIDE))
+ #define XLAT_STR_1 STRINGIFY(CAP_DAC_OVERRIDE)
  XLAT(CAP_DAC_READ_SEARCH),
+ #define XLAT_VAL_2 ((unsigned) (CAP_DAC_READ_SEARCH))
+ #define XLAT_STR_2 STRINGIFY(CAP_DAC_READ_SEARCH)
  XLAT(CAP_FOWNER),
+ #define XLAT_VAL_3 ((unsigned) (CAP_FOWNER))
+ #define XLAT_STR_3 STRINGIFY(CAP_FOWNER)
  XLAT(CAP_FSETID),
+ #define XLAT_VAL_4 ((unsigned) (CAP_FSETID))
+ #define XLAT_STR_4 STRINGIFY(CAP_FSETID)
  XLAT(CAP_KILL),
+ #define XLAT_VAL_5 ((unsigned) (CAP_KILL))
+ #define XLAT_STR_5 STRINGIFY(CAP_KILL)
  XLAT(CAP_SETGID),
+ #define XLAT_VAL_6 ((unsigned) (CAP_SETGID))
+ #define XLAT_STR_6 STRINGIFY(CAP_SETGID)
  XLAT(CAP_SETUID),
+ #define XLAT_VAL_7 ((unsigned) (CAP_SETUID))
+ #define XLAT_STR_7 STRINGIFY(CAP_SETUID)
  XLAT(CAP_SETPCAP),
+ #define XLAT_VAL_8 ((unsigned) (CAP_SETPCAP))
+ #define XLAT_STR_8 STRINGIFY(CAP_SETPCAP)
  XLAT(CAP_LINUX_IMMUTABLE),
+ #define XLAT_VAL_9 ((unsigned) (CAP_LINUX_IMMUTABLE))
+ #define XLAT_STR_9 STRINGIFY(CAP_LINUX_IMMUTABLE)
  XLAT(CAP_NET_BIND_SERVICE),
+ #define XLAT_VAL_10 ((unsigned) (CAP_NET_BIND_SERVICE))
+ #define XLAT_STR_10 STRINGIFY(CAP_NET_BIND_SERVICE)
  XLAT(CAP_NET_BROADCAST),
+ #define XLAT_VAL_11 ((unsigned) (CAP_NET_BROADCAST))
+ #define XLAT_STR_11 STRINGIFY(CAP_NET_BROADCAST)
  XLAT(CAP_NET_ADMIN),
+ #define XLAT_VAL_12 ((unsigned) (CAP_NET_ADMIN))
+ #define XLAT_STR_12 STRINGIFY(CAP_NET_ADMIN)
  XLAT(CAP_NET_RAW),
+ #define XLAT_VAL_13 ((unsigned) (CAP_NET_RAW))
+ #define XLAT_STR_13 STRINGIFY(CAP_NET_RAW)
  XLAT(CAP_IPC_LOCK),
+ #define XLAT_VAL_14 ((unsigned) (CAP_IPC_LOCK))
+ #define XLAT_STR_14 STRINGIFY(CAP_IPC_LOCK)
  XLAT(CAP_IPC_OWNER),
+ #define XLAT_VAL_15 ((unsigned) (CAP_IPC_OWNER))
+ #define XLAT_STR_15 STRINGIFY(CAP_IPC_OWNER)
  XLAT(CAP_SYS_MODULE),
+ #define XLAT_VAL_16 ((unsigned) (CAP_SYS_MODULE))
+ #define XLAT_STR_16 STRINGIFY(CAP_SYS_MODULE)
  XLAT(CAP_SYS_RAWIO),
+ #define XLAT_VAL_17 ((unsigned) (CAP_SYS_RAWIO))
+ #define XLAT_STR_17 STRINGIFY(CAP_SYS_RAWIO)
  XLAT(CAP_SYS_CHROOT),
+ #define XLAT_VAL_18 ((unsigned) (CAP_SYS_CHROOT))
+ #define XLAT_STR_18 STRINGIFY(CAP_SYS_CHROOT)
  XLAT(CAP_SYS_PTRACE),
+ #define XLAT_VAL_19 ((unsigned) (CAP_SYS_PTRACE))
+ #define XLAT_STR_19 STRINGIFY(CAP_SYS_PTRACE)
  XLAT(CAP_SYS_PACCT),
+ #define XLAT_VAL_20 ((unsigned) (CAP_SYS_PACCT))
+ #define XLAT_STR_20 STRINGIFY(CAP_SYS_PACCT)
  XLAT(CAP_SYS_ADMIN),
+ #define XLAT_VAL_21 ((unsigned) (CAP_SYS_ADMIN))
+ #define XLAT_STR_21 STRINGIFY(CAP_SYS_ADMIN)
  XLAT(CAP_SYS_BOOT),
+ #define XLAT_VAL_22 ((unsigned) (CAP_SYS_BOOT))
+ #define XLAT_STR_22 STRINGIFY(CAP_SYS_BOOT)
  XLAT(CAP_SYS_NICE),
+ #define XLAT_VAL_23 ((unsigned) (CAP_SYS_NICE))
+ #define XLAT_STR_23 STRINGIFY(CAP_SYS_NICE)
  XLAT(CAP_SYS_RESOURCE),
+ #define XLAT_VAL_24 ((unsigned) (CAP_SYS_RESOURCE))
+ #define XLAT_STR_24 STRINGIFY(CAP_SYS_RESOURCE)
  XLAT(CAP_SYS_TIME),
+ #define XLAT_VAL_25 ((unsigned) (CAP_SYS_TIME))
+ #define XLAT_STR_25 STRINGIFY(CAP_SYS_TIME)
  XLAT(CAP_SYS_TTY_CONFIG),
+ #define XLAT_VAL_26 ((unsigned) (CAP_SYS_TTY_CONFIG))
+ #define XLAT_STR_26 STRINGIFY(CAP_SYS_TTY_CONFIG)
  XLAT(CAP_MKNOD),
+ #define XLAT_VAL_27 ((unsigned) (CAP_MKNOD))
+ #define XLAT_STR_27 STRINGIFY(CAP_MKNOD)
  XLAT(CAP_LEASE),
+ #define XLAT_VAL_28 ((unsigned) (CAP_LEASE))
+ #define XLAT_STR_28 STRINGIFY(CAP_LEASE)
  XLAT(CAP_AUDIT_WRITE),
+ #define XLAT_VAL_29 ((unsigned) (CAP_AUDIT_WRITE))
+ #define XLAT_STR_29 STRINGIFY(CAP_AUDIT_WRITE)
  XLAT(CAP_AUDIT_CONTROL),
+ #define XLAT_VAL_30 ((unsigned) (CAP_AUDIT_CONTROL))
+ #define XLAT_STR_30 STRINGIFY(CAP_AUDIT_CONTROL)
  XLAT(CAP_SETFCAP),
+ #define XLAT_VAL_31 ((unsigned) (CAP_SETFCAP))
+ #define XLAT_STR_31 STRINGIFY(CAP_SETFCAP)
  XLAT(CAP_MAC_OVERRIDE),
+ #define XLAT_VAL_32 ((unsigned) (CAP_MAC_OVERRIDE))
+ #define XLAT_STR_32 STRINGIFY(CAP_MAC_OVERRIDE)
  XLAT(CAP_MAC_ADMIN),
+ #define XLAT_VAL_33 ((unsigned) (CAP_MAC_ADMIN))
+ #define XLAT_STR_33 STRINGIFY(CAP_MAC_ADMIN)
  XLAT(CAP_SYSLOG),
+ #define XLAT_VAL_34 ((unsigned) (CAP_SYSLOG))
+ #define XLAT_STR_34 STRINGIFY(CAP_SYSLOG)
  XLAT(CAP_WAKE_ALARM),
+ #define XLAT_VAL_35 ((unsigned) (CAP_WAKE_ALARM))
+ #define XLAT_STR_35 STRINGIFY(CAP_WAKE_ALARM)
  XLAT(CAP_BLOCK_SUSPEND),
+ #define XLAT_VAL_36 ((unsigned) (CAP_BLOCK_SUSPEND))
+ #define XLAT_STR_36 STRINGIFY(CAP_BLOCK_SUSPEND)
  XLAT(CAP_AUDIT_READ),
+ #define XLAT_VAL_37 ((unsigned) (CAP_AUDIT_READ))
+ #define XLAT_STR_37 STRINGIFY(CAP_AUDIT_READ)
+ XLAT(CAP_PERFMON),
+ #define XLAT_VAL_38 ((unsigned) (CAP_PERFMON))
+ #define XLAT_STR_38 STRINGIFY(CAP_PERFMON)
+ XLAT(CAP_BPF),
+ #define XLAT_VAL_39 ((unsigned) (CAP_BPF))
+ #define XLAT_STR_39 STRINGIFY(CAP_BPF)
+ XLAT(CAP_CHECKPOINT_RESTORE),
+ #define XLAT_VAL_40 ((unsigned) (CAP_CHECKPOINT_RESTORE))
+ #define XLAT_STR_40 STRINGIFY(CAP_CHECKPOINT_RESTORE)
 };
 static
 const struct xlat cap[1] = { {
  .data = cap_xdata,
  .size = ARRAY_SIZE(cap_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/cap.in 5.9-0ubuntu2/xlat/cap.in
--- 5.5-3/xlat/cap.in	2015-02-19 01:54:38.000000000 +0000
+++ 5.9-0ubuntu2/xlat/cap.in	2020-09-06 08:00:00.000000000 +0000
@@ -37,3 +37,6 @@ CAP_SYSLOG
 CAP_WAKE_ALARM
 CAP_BLOCK_SUSPEND
 CAP_AUDIT_READ
+CAP_PERFMON
+CAP_BPF
+CAP_CHECKPOINT_RESTORE
diff -pruN 5.5-3/xlat/cap_mask0.h 5.9-0ubuntu2/xlat/cap_mask0.h
--- 5.5-3/xlat/cap_mask0.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/cap_mask0.h	2020-09-24 09:18:44.000000000 +0000
@@ -14,45 +14,369 @@
 
 static const struct xlat_data cap_mask0_xdata[] = {
  XLAT_PAIR(1ULL<<CAP_CHOWN, "1<<CAP_CHOWN"),
+ #define XLAT_VAL_0 ((unsigned) (1ULL<<CAP_CHOWN))
+ #define XLAT_STR_0 "1<<CAP_CHOWN"
  XLAT_PAIR(1ULL<<CAP_DAC_OVERRIDE, "1<<CAP_DAC_OVERRIDE"),
+ #define XLAT_VAL_1 ((unsigned) (1ULL<<CAP_DAC_OVERRIDE))
+ #define XLAT_STR_1 "1<<CAP_DAC_OVERRIDE"
  XLAT_PAIR(1ULL<<CAP_DAC_READ_SEARCH, "1<<CAP_DAC_READ_SEARCH"),
+ #define XLAT_VAL_2 ((unsigned) (1ULL<<CAP_DAC_READ_SEARCH))
+ #define XLAT_STR_2 "1<<CAP_DAC_READ_SEARCH"
  XLAT_PAIR(1ULL<<CAP_FOWNER, "1<<CAP_FOWNER"),
+ #define XLAT_VAL_3 ((unsigned) (1ULL<<CAP_FOWNER))
+ #define XLAT_STR_3 "1<<CAP_FOWNER"
  XLAT_PAIR(1ULL<<CAP_FSETID, "1<<CAP_FSETID"),
+ #define XLAT_VAL_4 ((unsigned) (1ULL<<CAP_FSETID))
+ #define XLAT_STR_4 "1<<CAP_FSETID"
  XLAT_PAIR(1ULL<<CAP_KILL, "1<<CAP_KILL"),
+ #define XLAT_VAL_5 ((unsigned) (1ULL<<CAP_KILL))
+ #define XLAT_STR_5 "1<<CAP_KILL"
  XLAT_PAIR(1ULL<<CAP_SETGID, "1<<CAP_SETGID"),
+ #define XLAT_VAL_6 ((unsigned) (1ULL<<CAP_SETGID))
+ #define XLAT_STR_6 "1<<CAP_SETGID"
  XLAT_PAIR(1ULL<<CAP_SETUID, "1<<CAP_SETUID"),
+ #define XLAT_VAL_7 ((unsigned) (1ULL<<CAP_SETUID))
+ #define XLAT_STR_7 "1<<CAP_SETUID"
  XLAT_PAIR(1ULL<<CAP_SETPCAP, "1<<CAP_SETPCAP"),
+ #define XLAT_VAL_8 ((unsigned) (1ULL<<CAP_SETPCAP))
+ #define XLAT_STR_8 "1<<CAP_SETPCAP"
  XLAT_PAIR(1ULL<<CAP_LINUX_IMMUTABLE, "1<<CAP_LINUX_IMMUTABLE"),
+ #define XLAT_VAL_9 ((unsigned) (1ULL<<CAP_LINUX_IMMUTABLE))
+ #define XLAT_STR_9 "1<<CAP_LINUX_IMMUTABLE"
  XLAT_PAIR(1ULL<<CAP_NET_BIND_SERVICE, "1<<CAP_NET_BIND_SERVICE"),
+ #define XLAT_VAL_10 ((unsigned) (1ULL<<CAP_NET_BIND_SERVICE))
+ #define XLAT_STR_10 "1<<CAP_NET_BIND_SERVICE"
  XLAT_PAIR(1ULL<<CAP_NET_BROADCAST, "1<<CAP_NET_BROADCAST"),
+ #define XLAT_VAL_11 ((unsigned) (1ULL<<CAP_NET_BROADCAST))
+ #define XLAT_STR_11 "1<<CAP_NET_BROADCAST"
  XLAT_PAIR(1ULL<<CAP_NET_ADMIN, "1<<CAP_NET_ADMIN"),
+ #define XLAT_VAL_12 ((unsigned) (1ULL<<CAP_NET_ADMIN))
+ #define XLAT_STR_12 "1<<CAP_NET_ADMIN"
  XLAT_PAIR(1ULL<<CAP_NET_RAW, "1<<CAP_NET_RAW"),
+ #define XLAT_VAL_13 ((unsigned) (1ULL<<CAP_NET_RAW))
+ #define XLAT_STR_13 "1<<CAP_NET_RAW"
  XLAT_PAIR(1ULL<<CAP_IPC_LOCK, "1<<CAP_IPC_LOCK"),
+ #define XLAT_VAL_14 ((unsigned) (1ULL<<CAP_IPC_LOCK))
+ #define XLAT_STR_14 "1<<CAP_IPC_LOCK"
  XLAT_PAIR(1ULL<<CAP_IPC_OWNER, "1<<CAP_IPC_OWNER"),
+ #define XLAT_VAL_15 ((unsigned) (1ULL<<CAP_IPC_OWNER))
+ #define XLAT_STR_15 "1<<CAP_IPC_OWNER"
  XLAT_PAIR(1ULL<<CAP_SYS_MODULE, "1<<CAP_SYS_MODULE"),
+ #define XLAT_VAL_16 ((unsigned) (1ULL<<CAP_SYS_MODULE))
+ #define XLAT_STR_16 "1<<CAP_SYS_MODULE"
  XLAT_PAIR(1ULL<<CAP_SYS_RAWIO, "1<<CAP_SYS_RAWIO"),
+ #define XLAT_VAL_17 ((unsigned) (1ULL<<CAP_SYS_RAWIO))
+ #define XLAT_STR_17 "1<<CAP_SYS_RAWIO"
  XLAT_PAIR(1ULL<<CAP_SYS_CHROOT, "1<<CAP_SYS_CHROOT"),
+ #define XLAT_VAL_18 ((unsigned) (1ULL<<CAP_SYS_CHROOT))
+ #define XLAT_STR_18 "1<<CAP_SYS_CHROOT"
  XLAT_PAIR(1ULL<<CAP_SYS_PTRACE, "1<<CAP_SYS_PTRACE"),
+ #define XLAT_VAL_19 ((unsigned) (1ULL<<CAP_SYS_PTRACE))
+ #define XLAT_STR_19 "1<<CAP_SYS_PTRACE"
  XLAT_PAIR(1ULL<<CAP_SYS_PACCT, "1<<CAP_SYS_PACCT"),
+ #define XLAT_VAL_20 ((unsigned) (1ULL<<CAP_SYS_PACCT))
+ #define XLAT_STR_20 "1<<CAP_SYS_PACCT"
  XLAT_PAIR(1ULL<<CAP_SYS_ADMIN, "1<<CAP_SYS_ADMIN"),
+ #define XLAT_VAL_21 ((unsigned) (1ULL<<CAP_SYS_ADMIN))
+ #define XLAT_STR_21 "1<<CAP_SYS_ADMIN"
  XLAT_PAIR(1ULL<<CAP_SYS_BOOT, "1<<CAP_SYS_BOOT"),
+ #define XLAT_VAL_22 ((unsigned) (1ULL<<CAP_SYS_BOOT))
+ #define XLAT_STR_22 "1<<CAP_SYS_BOOT"
  XLAT_PAIR(1ULL<<CAP_SYS_NICE, "1<<CAP_SYS_NICE"),
+ #define XLAT_VAL_23 ((unsigned) (1ULL<<CAP_SYS_NICE))
+ #define XLAT_STR_23 "1<<CAP_SYS_NICE"
  XLAT_PAIR(1ULL<<CAP_SYS_RESOURCE, "1<<CAP_SYS_RESOURCE"),
+ #define XLAT_VAL_24 ((unsigned) (1ULL<<CAP_SYS_RESOURCE))
+ #define XLAT_STR_24 "1<<CAP_SYS_RESOURCE"
  XLAT_PAIR(1ULL<<CAP_SYS_TIME, "1<<CAP_SYS_TIME"),
+ #define XLAT_VAL_25 ((unsigned) (1ULL<<CAP_SYS_TIME))
+ #define XLAT_STR_25 "1<<CAP_SYS_TIME"
  XLAT_PAIR(1ULL<<CAP_SYS_TTY_CONFIG, "1<<CAP_SYS_TTY_CONFIG"),
+ #define XLAT_VAL_26 ((unsigned) (1ULL<<CAP_SYS_TTY_CONFIG))
+ #define XLAT_STR_26 "1<<CAP_SYS_TTY_CONFIG"
  XLAT_PAIR(1ULL<<CAP_MKNOD, "1<<CAP_MKNOD"),
+ #define XLAT_VAL_27 ((unsigned) (1ULL<<CAP_MKNOD))
+ #define XLAT_STR_27 "1<<CAP_MKNOD"
  XLAT_PAIR(1ULL<<CAP_LEASE, "1<<CAP_LEASE"),
+ #define XLAT_VAL_28 ((unsigned) (1ULL<<CAP_LEASE))
+ #define XLAT_STR_28 "1<<CAP_LEASE"
  XLAT_PAIR(1ULL<<CAP_AUDIT_WRITE, "1<<CAP_AUDIT_WRITE"),
+ #define XLAT_VAL_29 ((unsigned) (1ULL<<CAP_AUDIT_WRITE))
+ #define XLAT_STR_29 "1<<CAP_AUDIT_WRITE"
  XLAT_PAIR(1ULL<<CAP_AUDIT_CONTROL, "1<<CAP_AUDIT_CONTROL"),
+ #define XLAT_VAL_30 ((unsigned) (1ULL<<CAP_AUDIT_CONTROL))
+ #define XLAT_STR_30 "1<<CAP_AUDIT_CONTROL"
  XLAT_PAIR(1ULL<<CAP_SETFCAP, "1<<CAP_SETFCAP"),
+ #define XLAT_VAL_31 ((unsigned) (1ULL<<CAP_SETFCAP))
+ #define XLAT_STR_31 "1<<CAP_SETFCAP"
 };
 static
 const struct xlat cap_mask0[1] = { {
  .data = cap_mask0_xdata,
  .size = ARRAY_SIZE(cap_mask0_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/cap_mask1.h 5.9-0ubuntu2/xlat/cap_mask1.h
--- 5.5-3/xlat/cap_mask1.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/cap_mask1.h	2020-09-24 09:18:44.000000000 +0000
@@ -14,19 +14,116 @@
 
 static const struct xlat_data cap_mask1_xdata[] = {
  XLAT_PAIR(1ULL<<CAP_MAC_OVERRIDE, "1<<CAP_MAC_OVERRIDE"),
+ #define XLAT_VAL_0 ((unsigned) (1ULL<<CAP_MAC_OVERRIDE))
+ #define XLAT_STR_0 "1<<CAP_MAC_OVERRIDE"
  XLAT_PAIR(1ULL<<CAP_MAC_ADMIN, "1<<CAP_MAC_ADMIN"),
+ #define XLAT_VAL_1 ((unsigned) (1ULL<<CAP_MAC_ADMIN))
+ #define XLAT_STR_1 "1<<CAP_MAC_ADMIN"
  XLAT_PAIR(1ULL<<CAP_SYSLOG, "1<<CAP_SYSLOG"),
+ #define XLAT_VAL_2 ((unsigned) (1ULL<<CAP_SYSLOG))
+ #define XLAT_STR_2 "1<<CAP_SYSLOG"
  XLAT_PAIR(1ULL<<CAP_WAKE_ALARM, "1<<CAP_WAKE_ALARM"),
+ #define XLAT_VAL_3 ((unsigned) (1ULL<<CAP_WAKE_ALARM))
+ #define XLAT_STR_3 "1<<CAP_WAKE_ALARM"
  XLAT_PAIR(1ULL<<CAP_BLOCK_SUSPEND, "1<<CAP_BLOCK_SUSPEND"),
+ #define XLAT_VAL_4 ((unsigned) (1ULL<<CAP_BLOCK_SUSPEND))
+ #define XLAT_STR_4 "1<<CAP_BLOCK_SUSPEND"
  XLAT_PAIR(1ULL<<CAP_AUDIT_READ, "1<<CAP_AUDIT_READ"),
+ #define XLAT_VAL_5 ((unsigned) (1ULL<<CAP_AUDIT_READ))
+ #define XLAT_STR_5 "1<<CAP_AUDIT_READ"
+ XLAT_PAIR(1ULL<<CAP_PERFMON, "1<<CAP_PERFMON"),
+ #define XLAT_VAL_6 ((unsigned) (1ULL<<CAP_PERFMON))
+ #define XLAT_STR_6 "1<<CAP_PERFMON"
+ XLAT_PAIR(1ULL<<CAP_BPF, "1<<CAP_BPF"),
+ #define XLAT_VAL_7 ((unsigned) (1ULL<<CAP_BPF))
+ #define XLAT_STR_7 "1<<CAP_BPF"
+ XLAT_PAIR(1ULL<<CAP_CHECKPOINT_RESTORE, "1<<CAP_CHECKPOINT_RESTORE"),
+ #define XLAT_VAL_8 ((unsigned) (1ULL<<CAP_CHECKPOINT_RESTORE))
+ #define XLAT_STR_8 "1<<CAP_CHECKPOINT_RESTORE"
 };
 static
 const struct xlat cap_mask1[1] = { {
  .data = cap_mask1_xdata,
  .size = ARRAY_SIZE(cap_mask1_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/cap_mask1.in 5.9-0ubuntu2/xlat/cap_mask1.in
--- 5.5-3/xlat/cap_mask1.in	2015-02-19 00:33:39.000000000 +0000
+++ 5.9-0ubuntu2/xlat/cap_mask1.in	2020-09-06 08:00:00.000000000 +0000
@@ -5,3 +5,6 @@
 1<<CAP_WAKE_ALARM
 1<<CAP_BLOCK_SUSPEND
 1<<CAP_AUDIT_READ
+1<<CAP_PERFMON
+1<<CAP_BPF
+1<<CAP_CHECKPOINT_RESTORE
diff -pruN 5.5-3/xlat/cap_version.h 5.9-0ubuntu2/xlat/cap_version.h
--- 5.5-3/xlat/cap_version.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/cap_version.h	2020-09-24 09:18:44.000000000 +0000
@@ -14,16 +14,50 @@
 
 static const struct xlat_data cap_version_xdata[] = {
  XLAT(_LINUX_CAPABILITY_VERSION_1),
+ #define XLAT_VAL_0 ((unsigned) (_LINUX_CAPABILITY_VERSION_1))
+ #define XLAT_STR_0 STRINGIFY(_LINUX_CAPABILITY_VERSION_1)
  XLAT(_LINUX_CAPABILITY_VERSION_2),
+ #define XLAT_VAL_1 ((unsigned) (_LINUX_CAPABILITY_VERSION_2))
+ #define XLAT_STR_1 STRINGIFY(_LINUX_CAPABILITY_VERSION_2)
  XLAT(_LINUX_CAPABILITY_VERSION_3),
+ #define XLAT_VAL_2 ((unsigned) (_LINUX_CAPABILITY_VERSION_3))
+ #define XLAT_STR_2 STRINGIFY(_LINUX_CAPABILITY_VERSION_3)
 };
 static
 const struct xlat cap_version[1] = { {
  .data = cap_version_xdata,
  .size = ARRAY_SIZE(cap_version_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/clockflags.h 5.9-0ubuntu2/xlat/clockflags.h
--- 5.5-3/xlat/clockflags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/clockflags.h	2020-09-24 09:18:44.000000000 +0000
@@ -15,6 +15,8 @@
 static const struct xlat_data clockflags_xdata[] = {
 #if defined(TIMER_ABSTIME) || (defined(HAVE_DECL_TIMER_ABSTIME) && HAVE_DECL_TIMER_ABSTIME)
   XLAT(TIMER_ABSTIME),
+ #define XLAT_VAL_0 ((unsigned) (TIMER_ABSTIME))
+ #define XLAT_STR_0 STRINGIFY(TIMER_ABSTIME)
 #endif
 };
 static
@@ -22,8 +24,20 @@ const struct xlat clockflags[1] = { {
  .data = clockflags_xdata,
  .size = ARRAY_SIZE(clockflags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/clocknames.h 5.9-0ubuntu2/xlat/clocknames.h
--- 5.5-3/xlat/clocknames.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/clocknames.h	2020-09-24 09:18:44.000000000 +0000
@@ -94,24 +94,148 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data clocknames_xdata[] = {
  [CLOCK_REALTIME] = XLAT(CLOCK_REALTIME),
+ #define XLAT_VAL_0 ((unsigned) (CLOCK_REALTIME))
+ #define XLAT_STR_0 STRINGIFY(CLOCK_REALTIME)
  [CLOCK_MONOTONIC] = XLAT(CLOCK_MONOTONIC),
+ #define XLAT_VAL_1 ((unsigned) (CLOCK_MONOTONIC))
+ #define XLAT_STR_1 STRINGIFY(CLOCK_MONOTONIC)
  [CLOCK_PROCESS_CPUTIME_ID] = XLAT(CLOCK_PROCESS_CPUTIME_ID),
+ #define XLAT_VAL_2 ((unsigned) (CLOCK_PROCESS_CPUTIME_ID))
+ #define XLAT_STR_2 STRINGIFY(CLOCK_PROCESS_CPUTIME_ID)
  [CLOCK_THREAD_CPUTIME_ID] = XLAT(CLOCK_THREAD_CPUTIME_ID),
+ #define XLAT_VAL_3 ((unsigned) (CLOCK_THREAD_CPUTIME_ID))
+ #define XLAT_STR_3 STRINGIFY(CLOCK_THREAD_CPUTIME_ID)
  [CLOCK_MONOTONIC_RAW] = XLAT(CLOCK_MONOTONIC_RAW),
+ #define XLAT_VAL_4 ((unsigned) (CLOCK_MONOTONIC_RAW))
+ #define XLAT_STR_4 STRINGIFY(CLOCK_MONOTONIC_RAW)
  [CLOCK_REALTIME_COARSE] = XLAT(CLOCK_REALTIME_COARSE),
+ #define XLAT_VAL_5 ((unsigned) (CLOCK_REALTIME_COARSE))
+ #define XLAT_STR_5 STRINGIFY(CLOCK_REALTIME_COARSE)
  [CLOCK_MONOTONIC_COARSE] = XLAT(CLOCK_MONOTONIC_COARSE),
+ #define XLAT_VAL_6 ((unsigned) (CLOCK_MONOTONIC_COARSE))
+ #define XLAT_STR_6 STRINGIFY(CLOCK_MONOTONIC_COARSE)
  [CLOCK_BOOTTIME] = XLAT(CLOCK_BOOTTIME),
+ #define XLAT_VAL_7 ((unsigned) (CLOCK_BOOTTIME))
+ #define XLAT_STR_7 STRINGIFY(CLOCK_BOOTTIME)
  [CLOCK_REALTIME_ALARM] = XLAT(CLOCK_REALTIME_ALARM),
+ #define XLAT_VAL_8 ((unsigned) (CLOCK_REALTIME_ALARM))
+ #define XLAT_STR_8 STRINGIFY(CLOCK_REALTIME_ALARM)
  [CLOCK_BOOTTIME_ALARM] = XLAT(CLOCK_BOOTTIME_ALARM),
+ #define XLAT_VAL_9 ((unsigned) (CLOCK_BOOTTIME_ALARM))
+ #define XLAT_STR_9 STRINGIFY(CLOCK_BOOTTIME_ALARM)
  [CLOCK_SGI_CYCLE] = XLAT(CLOCK_SGI_CYCLE),
+ #define XLAT_VAL_10 ((unsigned) (CLOCK_SGI_CYCLE))
+ #define XLAT_STR_10 STRINGIFY(CLOCK_SGI_CYCLE)
  [CLOCK_TAI] = XLAT(CLOCK_TAI),
+ #define XLAT_VAL_11 ((unsigned) (CLOCK_TAI))
+ #define XLAT_STR_11 STRINGIFY(CLOCK_TAI)
 };
 const struct xlat clocknames[1] = { {
  .data = clocknames_xdata,
  .size = ARRAY_SIZE(clocknames_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/clone3_flags.h 5.9-0ubuntu2/xlat/clone3_flags.h
--- 5.5-3/xlat/clone3_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/clone3_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -3,6 +3,13 @@
 #include "gcc_compat.h"
 #include "static_assert.h"
 
+#if defined(CLONE_NEWTIME) || (defined(HAVE_DECL_CLONE_NEWTIME) && HAVE_DECL_CLONE_NEWTIME)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((CLONE_NEWTIME) == (0x80), "CLONE_NEWTIME != 0x80");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define CLONE_NEWTIME 0x80
+#endif
 #if defined(CLONE_CLEAR_SIGHAND) || (defined(HAVE_DECL_CLONE_CLEAR_SIGHAND) && HAVE_DECL_CLONE_CLEAR_SIGHAND)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
 static_assert((CLONE_CLEAR_SIGHAND) == (0x100000000ULL), "CLONE_CLEAR_SIGHAND != 0x100000000ULL");
@@ -10,6 +17,13 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define CLONE_CLEAR_SIGHAND 0x100000000ULL
 #endif
+#if defined(CLONE_INTO_CGROUP) || (defined(HAVE_DECL_CLONE_INTO_CGROUP) && HAVE_DECL_CLONE_INTO_CGROUP)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((CLONE_INTO_CGROUP) == (0x200000000ULL), "CLONE_INTO_CGROUP != 0x200000000ULL");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define CLONE_INTO_CGROUP 0x200000000ULL
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -20,15 +34,51 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 # else
 
 static const struct xlat_data clone3_flags_xdata[] = {
+ XLAT_TYPE(uint64_t, CLONE_NEWTIME),
+ #define XLAT_VAL_0 ((uint64_t) (CLONE_NEWTIME))
+ #define XLAT_STR_0 STRINGIFY(CLONE_NEWTIME)
  XLAT_TYPE(uint64_t, CLONE_CLEAR_SIGHAND),
+ #define XLAT_VAL_1 ((uint64_t) (CLONE_CLEAR_SIGHAND))
+ #define XLAT_STR_1 STRINGIFY(CLONE_CLEAR_SIGHAND)
+ XLAT_TYPE(uint64_t, CLONE_INTO_CGROUP),
+ #define XLAT_VAL_2 ((uint64_t) (CLONE_INTO_CGROUP))
+ #define XLAT_STR_2 STRINGIFY(CLONE_INTO_CGROUP)
 };
 static
 const struct xlat clone3_flags[1] = { {
  .data = clone3_flags_xdata,
  .size = ARRAY_SIZE(clone3_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/clone3_flags.in 5.9-0ubuntu2/xlat/clone3_flags.in
--- 5.5-3/xlat/clone3_flags.in	2020-01-14 09:28:05.000000000 +0000
+++ 5.9-0ubuntu2/xlat/clone3_flags.in	2020-05-27 08:00:00.000000000 +0000
@@ -1,2 +1,4 @@
 #val_type uint64_t
+CLONE_NEWTIME		0x80
 CLONE_CLEAR_SIGHAND	0x100000000ULL
+CLONE_INTO_CGROUP	0x200000000ULL
diff -pruN 5.5-3/xlat/clone_flags.h 5.9-0ubuntu2/xlat/clone_flags.h
--- 5.5-3/xlat/clone_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/clone_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -175,37 +175,271 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data clone_flags_xdata[] = {
  XLAT(CLONE_VM),
+ #define XLAT_VAL_0 ((unsigned) (CLONE_VM))
+ #define XLAT_STR_0 STRINGIFY(CLONE_VM)
  XLAT(CLONE_FS),
+ #define XLAT_VAL_1 ((unsigned) (CLONE_FS))
+ #define XLAT_STR_1 STRINGIFY(CLONE_FS)
  XLAT(CLONE_FILES),
+ #define XLAT_VAL_2 ((unsigned) (CLONE_FILES))
+ #define XLAT_STR_2 STRINGIFY(CLONE_FILES)
  XLAT(CLONE_SIGHAND),
+ #define XLAT_VAL_3 ((unsigned) (CLONE_SIGHAND))
+ #define XLAT_STR_3 STRINGIFY(CLONE_SIGHAND)
  XLAT(CLONE_PIDFD),
+ #define XLAT_VAL_4 ((unsigned) (CLONE_PIDFD))
+ #define XLAT_STR_4 STRINGIFY(CLONE_PIDFD)
  XLAT(CLONE_PTRACE),
+ #define XLAT_VAL_5 ((unsigned) (CLONE_PTRACE))
+ #define XLAT_STR_5 STRINGIFY(CLONE_PTRACE)
  XLAT(CLONE_VFORK),
+ #define XLAT_VAL_6 ((unsigned) (CLONE_VFORK))
+ #define XLAT_STR_6 STRINGIFY(CLONE_VFORK)
  XLAT(CLONE_PARENT),
+ #define XLAT_VAL_7 ((unsigned) (CLONE_PARENT))
+ #define XLAT_STR_7 STRINGIFY(CLONE_PARENT)
  XLAT(CLONE_THREAD),
+ #define XLAT_VAL_8 ((unsigned) (CLONE_THREAD))
+ #define XLAT_STR_8 STRINGIFY(CLONE_THREAD)
  XLAT(CLONE_NEWNS),
+ #define XLAT_VAL_9 ((unsigned) (CLONE_NEWNS))
+ #define XLAT_STR_9 STRINGIFY(CLONE_NEWNS)
  XLAT(CLONE_SYSVSEM),
+ #define XLAT_VAL_10 ((unsigned) (CLONE_SYSVSEM))
+ #define XLAT_STR_10 STRINGIFY(CLONE_SYSVSEM)
  XLAT(CLONE_SETTLS),
+ #define XLAT_VAL_11 ((unsigned) (CLONE_SETTLS))
+ #define XLAT_STR_11 STRINGIFY(CLONE_SETTLS)
  XLAT(CLONE_PARENT_SETTID),
+ #define XLAT_VAL_12 ((unsigned) (CLONE_PARENT_SETTID))
+ #define XLAT_STR_12 STRINGIFY(CLONE_PARENT_SETTID)
  XLAT(CLONE_CHILD_CLEARTID),
+ #define XLAT_VAL_13 ((unsigned) (CLONE_CHILD_CLEARTID))
+ #define XLAT_STR_13 STRINGIFY(CLONE_CHILD_CLEARTID)
 
  XLAT(CLONE_UNTRACED),
+ #define XLAT_VAL_14 ((unsigned) (CLONE_UNTRACED))
+ #define XLAT_STR_14 STRINGIFY(CLONE_UNTRACED)
  XLAT(CLONE_CHILD_SETTID),
+ #define XLAT_VAL_15 ((unsigned) (CLONE_CHILD_SETTID))
+ #define XLAT_STR_15 STRINGIFY(CLONE_CHILD_SETTID)
  XLAT(CLONE_NEWCGROUP),
+ #define XLAT_VAL_16 ((unsigned) (CLONE_NEWCGROUP))
+ #define XLAT_STR_16 STRINGIFY(CLONE_NEWCGROUP)
  XLAT(CLONE_NEWUTS),
+ #define XLAT_VAL_17 ((unsigned) (CLONE_NEWUTS))
+ #define XLAT_STR_17 STRINGIFY(CLONE_NEWUTS)
  XLAT(CLONE_NEWIPC),
+ #define XLAT_VAL_18 ((unsigned) (CLONE_NEWIPC))
+ #define XLAT_STR_18 STRINGIFY(CLONE_NEWIPC)
  XLAT(CLONE_NEWUSER),
+ #define XLAT_VAL_19 ((unsigned) (CLONE_NEWUSER))
+ #define XLAT_STR_19 STRINGIFY(CLONE_NEWUSER)
  XLAT(CLONE_NEWPID),
+ #define XLAT_VAL_20 ((unsigned) (CLONE_NEWPID))
+ #define XLAT_STR_20 STRINGIFY(CLONE_NEWPID)
  XLAT(CLONE_NEWNET),
+ #define XLAT_VAL_21 ((unsigned) (CLONE_NEWNET))
+ #define XLAT_STR_21 STRINGIFY(CLONE_NEWNET)
  XLAT(CLONE_IO),
+ #define XLAT_VAL_22 ((unsigned) (CLONE_IO))
+ #define XLAT_STR_22 STRINGIFY(CLONE_IO)
 };
 static
 const struct xlat clone_flags[1] = { {
  .data = clone_flags_xdata,
  .size = ARRAY_SIZE(clone_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/close_range_flags.h 5.9-0ubuntu2/xlat/close_range_flags.h
--- 5.5-3/xlat/close_range_flags.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/close_range_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -0,0 +1,48 @@
+/* Generated by ./xlat/gen.sh from ./xlat/close_range_flags.in; do not edit. */
+
+#include "gcc_compat.h"
+#include "static_assert.h"
+
+#if defined(CLOSE_RANGE_UNSHARE) || (defined(HAVE_DECL_CLOSE_RANGE_UNSHARE) && HAVE_DECL_CLOSE_RANGE_UNSHARE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((CLOSE_RANGE_UNSHARE) == ((1U << 1)), "CLOSE_RANGE_UNSHARE != (1U << 1)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define CLOSE_RANGE_UNSHARE (1U << 1)
+#endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+#  error static const struct xlat close_range_flags in mpers mode
+
+# else
+
+static const struct xlat_data close_range_flags_xdata[] = {
+ XLAT(CLOSE_RANGE_UNSHARE),
+ #define XLAT_VAL_0 ((unsigned) (CLOSE_RANGE_UNSHARE))
+ #define XLAT_STR_0 STRINGIFY(CLOSE_RANGE_UNSHARE)
+};
+static
+const struct xlat close_range_flags[1] = { {
+ .data = close_range_flags_xdata,
+ .size = ARRAY_SIZE(close_range_flags_xdata),
+ .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
+} };
+
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+# endif /* !IN_MPERS */
+
+#endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/close_range_flags.in 5.9-0ubuntu2/xlat/close_range_flags.in
--- 5.5-3/xlat/close_range_flags.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/close_range_flags.in	2020-09-06 08:00:00.000000000 +0000
@@ -0,0 +1,3 @@
+#enum
+#include <linux/close_range.h>
+CLOSE_RANGE_UNSHARE	(1U << 1)
diff -pruN 5.5-3/xlat/close_range_flags.m4 5.9-0ubuntu2/xlat/close_range_flags.m4
--- 5.5-3/xlat/close_range_flags.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/close_range_flags.m4	2020-09-24 09:18:44.000000000 +0000
@@ -0,0 +1,7 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/close_range_flags.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_close_range_flags],[
+AC_CHECK_DECLS(m4_normalize([
+CLOSE_RANGE_UNSHARE
+]),,, [
+#include <linux/close_range.h>
+])])])
diff -pruN 5.5-3/xlat/cpuclocknames.h 5.9-0ubuntu2/xlat/cpuclocknames.h
--- 5.5-3/xlat/cpuclocknames.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/cpuclocknames.h	2020-09-24 09:18:44.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data cpuclocknames_xdata[] = {
  [CPUCLOCK_PROF] = XLAT(CPUCLOCK_PROF),
+ #define XLAT_VAL_0 ((unsigned) (CPUCLOCK_PROF))
+ #define XLAT_STR_0 STRINGIFY(CPUCLOCK_PROF)
  [CPUCLOCK_VIRT] = XLAT(CPUCLOCK_VIRT),
+ #define XLAT_VAL_1 ((unsigned) (CPUCLOCK_VIRT))
+ #define XLAT_STR_1 STRINGIFY(CPUCLOCK_VIRT)
  [CPUCLOCK_SCHED] = XLAT(CPUCLOCK_SCHED),
+ #define XLAT_VAL_2 ((unsigned) (CPUCLOCK_SCHED))
+ #define XLAT_STR_2 STRINGIFY(CPUCLOCK_SCHED)
 };
 static
 const struct xlat cpuclocknames[1] = { {
  .data = cpuclocknames_xdata,
  .size = ARRAY_SIZE(cpuclocknames_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/crypto_msgs.h 5.9-0ubuntu2/xlat/crypto_msgs.h
--- 5.5-3/xlat/crypto_msgs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/crypto_msgs.h	2020-09-24 09:18:44.000000000 +0000
@@ -56,19 +56,83 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data crypto_msgs_xdata[] = {
  XLAT(CRYPTO_MSG_NEWALG),
+ #define XLAT_VAL_0 ((unsigned) (CRYPTO_MSG_NEWALG))
+ #define XLAT_STR_0 STRINGIFY(CRYPTO_MSG_NEWALG)
  XLAT(CRYPTO_MSG_DELALG),
+ #define XLAT_VAL_1 ((unsigned) (CRYPTO_MSG_DELALG))
+ #define XLAT_STR_1 STRINGIFY(CRYPTO_MSG_DELALG)
  XLAT(CRYPTO_MSG_UPDATEALG),
+ #define XLAT_VAL_2 ((unsigned) (CRYPTO_MSG_UPDATEALG))
+ #define XLAT_STR_2 STRINGIFY(CRYPTO_MSG_UPDATEALG)
  XLAT(CRYPTO_MSG_GETALG),
+ #define XLAT_VAL_3 ((unsigned) (CRYPTO_MSG_GETALG))
+ #define XLAT_STR_3 STRINGIFY(CRYPTO_MSG_GETALG)
  XLAT(CRYPTO_MSG_DELRNG),
+ #define XLAT_VAL_4 ((unsigned) (CRYPTO_MSG_DELRNG))
+ #define XLAT_STR_4 STRINGIFY(CRYPTO_MSG_DELRNG)
  XLAT(CRYPTO_MSG_GETSTAT),
+ #define XLAT_VAL_5 ((unsigned) (CRYPTO_MSG_GETSTAT))
+ #define XLAT_STR_5 STRINGIFY(CRYPTO_MSG_GETSTAT)
 };
 static
 const struct xlat crypto_msgs[1] = { {
  .data = crypto_msgs_xdata,
  .size = ARRAY_SIZE(crypto_msgs_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/crypto_nl_attrs.h 5.9-0ubuntu2/xlat/crypto_nl_attrs.h
--- 5.5-3/xlat/crypto_nl_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/crypto_nl_attrs.h	2020-09-24 09:18:44.000000000 +0000
@@ -98,25 +98,149 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data crypto_nl_attrs_xdata[] = {
  [CRYPTOCFGA_UNSPEC] = XLAT(CRYPTOCFGA_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (CRYPTOCFGA_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(CRYPTOCFGA_UNSPEC)
  [CRYPTOCFGA_PRIORITY_VAL] = XLAT(CRYPTOCFGA_PRIORITY_VAL),
+ #define XLAT_VAL_1 ((unsigned) (CRYPTOCFGA_PRIORITY_VAL))
+ #define XLAT_STR_1 STRINGIFY(CRYPTOCFGA_PRIORITY_VAL)
  [CRYPTOCFGA_REPORT_LARVAL] = XLAT(CRYPTOCFGA_REPORT_LARVAL),
+ #define XLAT_VAL_2 ((unsigned) (CRYPTOCFGA_REPORT_LARVAL))
+ #define XLAT_STR_2 STRINGIFY(CRYPTOCFGA_REPORT_LARVAL)
  [CRYPTOCFGA_REPORT_HASH] = XLAT(CRYPTOCFGA_REPORT_HASH),
+ #define XLAT_VAL_3 ((unsigned) (CRYPTOCFGA_REPORT_HASH))
+ #define XLAT_STR_3 STRINGIFY(CRYPTOCFGA_REPORT_HASH)
  [CRYPTOCFGA_REPORT_BLKCIPHER] = XLAT(CRYPTOCFGA_REPORT_BLKCIPHER),
+ #define XLAT_VAL_4 ((unsigned) (CRYPTOCFGA_REPORT_BLKCIPHER))
+ #define XLAT_STR_4 STRINGIFY(CRYPTOCFGA_REPORT_BLKCIPHER)
  [CRYPTOCFGA_REPORT_AEAD] = XLAT(CRYPTOCFGA_REPORT_AEAD),
+ #define XLAT_VAL_5 ((unsigned) (CRYPTOCFGA_REPORT_AEAD))
+ #define XLAT_STR_5 STRINGIFY(CRYPTOCFGA_REPORT_AEAD)
  [CRYPTOCFGA_REPORT_COMPRESS] = XLAT(CRYPTOCFGA_REPORT_COMPRESS),
+ #define XLAT_VAL_6 ((unsigned) (CRYPTOCFGA_REPORT_COMPRESS))
+ #define XLAT_STR_6 STRINGIFY(CRYPTOCFGA_REPORT_COMPRESS)
  [CRYPTOCFGA_REPORT_RNG] = XLAT(CRYPTOCFGA_REPORT_RNG),
+ #define XLAT_VAL_7 ((unsigned) (CRYPTOCFGA_REPORT_RNG))
+ #define XLAT_STR_7 STRINGIFY(CRYPTOCFGA_REPORT_RNG)
  [CRYPTOCFGA_REPORT_CIPHER] = XLAT(CRYPTOCFGA_REPORT_CIPHER),
+ #define XLAT_VAL_8 ((unsigned) (CRYPTOCFGA_REPORT_CIPHER))
+ #define XLAT_STR_8 STRINGIFY(CRYPTOCFGA_REPORT_CIPHER)
  [CRYPTOCFGA_REPORT_AKCIPHER] = XLAT(CRYPTOCFGA_REPORT_AKCIPHER),
+ #define XLAT_VAL_9 ((unsigned) (CRYPTOCFGA_REPORT_AKCIPHER))
+ #define XLAT_STR_9 STRINGIFY(CRYPTOCFGA_REPORT_AKCIPHER)
  [CRYPTOCFGA_REPORT_KPP] = XLAT(CRYPTOCFGA_REPORT_KPP),
+ #define XLAT_VAL_10 ((unsigned) (CRYPTOCFGA_REPORT_KPP))
+ #define XLAT_STR_10 STRINGIFY(CRYPTOCFGA_REPORT_KPP)
  [CRYPTOCFGA_REPORT_ACOMP] = XLAT(CRYPTOCFGA_REPORT_ACOMP),
+ #define XLAT_VAL_11 ((unsigned) (CRYPTOCFGA_REPORT_ACOMP))
+ #define XLAT_STR_11 STRINGIFY(CRYPTOCFGA_REPORT_ACOMP)
 };
 static
 const struct xlat crypto_nl_attrs[1] = { {
  .data = crypto_nl_attrs_xdata,
  .size = ARRAY_SIZE(crypto_nl_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/dcb_commands.h 5.9-0ubuntu2/xlat/dcb_commands.h
--- 5.5-3/xlat/dcb_commands.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/dcb_commands.h	2020-09-24 09:18:44.000000000 +0000
@@ -210,41 +210,325 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data dcb_commands_xdata[] = {
  [DCB_CMD_UNDEFINED] = XLAT(DCB_CMD_UNDEFINED),
+ #define XLAT_VAL_0 ((unsigned) (DCB_CMD_UNDEFINED))
+ #define XLAT_STR_0 STRINGIFY(DCB_CMD_UNDEFINED)
  [DCB_CMD_GSTATE] = XLAT(DCB_CMD_GSTATE),
+ #define XLAT_VAL_1 ((unsigned) (DCB_CMD_GSTATE))
+ #define XLAT_STR_1 STRINGIFY(DCB_CMD_GSTATE)
  [DCB_CMD_SSTATE] = XLAT(DCB_CMD_SSTATE),
+ #define XLAT_VAL_2 ((unsigned) (DCB_CMD_SSTATE))
+ #define XLAT_STR_2 STRINGIFY(DCB_CMD_SSTATE)
  [DCB_CMD_PGTX_GCFG] = XLAT(DCB_CMD_PGTX_GCFG),
+ #define XLAT_VAL_3 ((unsigned) (DCB_CMD_PGTX_GCFG))
+ #define XLAT_STR_3 STRINGIFY(DCB_CMD_PGTX_GCFG)
  [DCB_CMD_PGTX_SCFG] = XLAT(DCB_CMD_PGTX_SCFG),
+ #define XLAT_VAL_4 ((unsigned) (DCB_CMD_PGTX_SCFG))
+ #define XLAT_STR_4 STRINGIFY(DCB_CMD_PGTX_SCFG)
  [DCB_CMD_PGRX_GCFG] = XLAT(DCB_CMD_PGRX_GCFG),
+ #define XLAT_VAL_5 ((unsigned) (DCB_CMD_PGRX_GCFG))
+ #define XLAT_STR_5 STRINGIFY(DCB_CMD_PGRX_GCFG)
  [DCB_CMD_PGRX_SCFG] = XLAT(DCB_CMD_PGRX_SCFG),
+ #define XLAT_VAL_6 ((unsigned) (DCB_CMD_PGRX_SCFG))
+ #define XLAT_STR_6 STRINGIFY(DCB_CMD_PGRX_SCFG)
  [DCB_CMD_PFC_GCFG] = XLAT(DCB_CMD_PFC_GCFG),
+ #define XLAT_VAL_7 ((unsigned) (DCB_CMD_PFC_GCFG))
+ #define XLAT_STR_7 STRINGIFY(DCB_CMD_PFC_GCFG)
  [DCB_CMD_PFC_SCFG] = XLAT(DCB_CMD_PFC_SCFG),
+ #define XLAT_VAL_8 ((unsigned) (DCB_CMD_PFC_SCFG))
+ #define XLAT_STR_8 STRINGIFY(DCB_CMD_PFC_SCFG)
  [DCB_CMD_SET_ALL] = XLAT(DCB_CMD_SET_ALL),
+ #define XLAT_VAL_9 ((unsigned) (DCB_CMD_SET_ALL))
+ #define XLAT_STR_9 STRINGIFY(DCB_CMD_SET_ALL)
  [DCB_CMD_GPERM_HWADDR] = XLAT(DCB_CMD_GPERM_HWADDR),
+ #define XLAT_VAL_10 ((unsigned) (DCB_CMD_GPERM_HWADDR))
+ #define XLAT_STR_10 STRINGIFY(DCB_CMD_GPERM_HWADDR)
  [DCB_CMD_GCAP] = XLAT(DCB_CMD_GCAP),
+ #define XLAT_VAL_11 ((unsigned) (DCB_CMD_GCAP))
+ #define XLAT_STR_11 STRINGIFY(DCB_CMD_GCAP)
  [DCB_CMD_GNUMTCS] = XLAT(DCB_CMD_GNUMTCS),
+ #define XLAT_VAL_12 ((unsigned) (DCB_CMD_GNUMTCS))
+ #define XLAT_STR_12 STRINGIFY(DCB_CMD_GNUMTCS)
  [DCB_CMD_SNUMTCS] = XLAT(DCB_CMD_SNUMTCS),
+ #define XLAT_VAL_13 ((unsigned) (DCB_CMD_SNUMTCS))
+ #define XLAT_STR_13 STRINGIFY(DCB_CMD_SNUMTCS)
  [DCB_CMD_PFC_GSTATE] = XLAT(DCB_CMD_PFC_GSTATE),
+ #define XLAT_VAL_14 ((unsigned) (DCB_CMD_PFC_GSTATE))
+ #define XLAT_STR_14 STRINGIFY(DCB_CMD_PFC_GSTATE)
  [DCB_CMD_PFC_SSTATE] = XLAT(DCB_CMD_PFC_SSTATE),
+ #define XLAT_VAL_15 ((unsigned) (DCB_CMD_PFC_SSTATE))
+ #define XLAT_STR_15 STRINGIFY(DCB_CMD_PFC_SSTATE)
  [DCB_CMD_BCN_GCFG] = XLAT(DCB_CMD_BCN_GCFG),
+ #define XLAT_VAL_16 ((unsigned) (DCB_CMD_BCN_GCFG))
+ #define XLAT_STR_16 STRINGIFY(DCB_CMD_BCN_GCFG)
  [DCB_CMD_BCN_SCFG] = XLAT(DCB_CMD_BCN_SCFG),
+ #define XLAT_VAL_17 ((unsigned) (DCB_CMD_BCN_SCFG))
+ #define XLAT_STR_17 STRINGIFY(DCB_CMD_BCN_SCFG)
  [DCB_CMD_GAPP] = XLAT(DCB_CMD_GAPP),
+ #define XLAT_VAL_18 ((unsigned) (DCB_CMD_GAPP))
+ #define XLAT_STR_18 STRINGIFY(DCB_CMD_GAPP)
  [DCB_CMD_SAPP] = XLAT(DCB_CMD_SAPP),
+ #define XLAT_VAL_19 ((unsigned) (DCB_CMD_SAPP))
+ #define XLAT_STR_19 STRINGIFY(DCB_CMD_SAPP)
  [DCB_CMD_IEEE_SET] = XLAT(DCB_CMD_IEEE_SET),
+ #define XLAT_VAL_20 ((unsigned) (DCB_CMD_IEEE_SET))
+ #define XLAT_STR_20 STRINGIFY(DCB_CMD_IEEE_SET)
  [DCB_CMD_IEEE_GET] = XLAT(DCB_CMD_IEEE_GET),
+ #define XLAT_VAL_21 ((unsigned) (DCB_CMD_IEEE_GET))
+ #define XLAT_STR_21 STRINGIFY(DCB_CMD_IEEE_GET)
  [DCB_CMD_GDCBX] = XLAT(DCB_CMD_GDCBX),
+ #define XLAT_VAL_22 ((unsigned) (DCB_CMD_GDCBX))
+ #define XLAT_STR_22 STRINGIFY(DCB_CMD_GDCBX)
  [DCB_CMD_SDCBX] = XLAT(DCB_CMD_SDCBX),
+ #define XLAT_VAL_23 ((unsigned) (DCB_CMD_SDCBX))
+ #define XLAT_STR_23 STRINGIFY(DCB_CMD_SDCBX)
  [DCB_CMD_GFEATCFG] = XLAT(DCB_CMD_GFEATCFG),
+ #define XLAT_VAL_24 ((unsigned) (DCB_CMD_GFEATCFG))
+ #define XLAT_STR_24 STRINGIFY(DCB_CMD_GFEATCFG)
  [DCB_CMD_SFEATCFG] = XLAT(DCB_CMD_SFEATCFG),
+ #define XLAT_VAL_25 ((unsigned) (DCB_CMD_SFEATCFG))
+ #define XLAT_STR_25 STRINGIFY(DCB_CMD_SFEATCFG)
  [DCB_CMD_CEE_GET] = XLAT(DCB_CMD_CEE_GET),
+ #define XLAT_VAL_26 ((unsigned) (DCB_CMD_CEE_GET))
+ #define XLAT_STR_26 STRINGIFY(DCB_CMD_CEE_GET)
  [DCB_CMD_IEEE_DEL] = XLAT(DCB_CMD_IEEE_DEL),
+ #define XLAT_VAL_27 ((unsigned) (DCB_CMD_IEEE_DEL))
+ #define XLAT_STR_27 STRINGIFY(DCB_CMD_IEEE_DEL)
 };
 static
 const struct xlat dcb_commands[1] = { {
  .data = dcb_commands_xdata,
  .size = ARRAY_SIZE(dcb_commands_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/delete_module_flags.h 5.9-0ubuntu2/xlat/delete_module_flags.h
--- 5.5-3/xlat/delete_module_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/delete_module_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -15,9 +15,13 @@
 static const struct xlat_data delete_module_flags_xdata[] = {
 #if defined(O_NONBLOCK) || (defined(HAVE_DECL_O_NONBLOCK) && HAVE_DECL_O_NONBLOCK)
   XLAT(O_NONBLOCK),
+ #define XLAT_VAL_0 ((unsigned) (O_NONBLOCK))
+ #define XLAT_STR_0 STRINGIFY(O_NONBLOCK)
 #endif
 #if defined(O_TRUNC) || (defined(HAVE_DECL_O_TRUNC) && HAVE_DECL_O_TRUNC)
   XLAT(O_TRUNC),
+ #define XLAT_VAL_1 ((unsigned) (O_TRUNC))
+ #define XLAT_STR_1 STRINGIFY(O_TRUNC)
 #endif
 };
 static
@@ -25,8 +29,28 @@ const struct xlat delete_module_flags[1]
  .data = delete_module_flags_xdata,
  .size = ARRAY_SIZE(delete_module_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/dirent_types.h 5.9-0ubuntu2/xlat/dirent_types.h
--- 5.5-3/xlat/dirent_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/dirent_types.h	2020-09-24 09:18:44.000000000 +0000
@@ -11,38 +11,132 @@
 static const struct xlat_data dirent_types_xdata[] = {
 #if defined(DT_UNKNOWN) || (defined(HAVE_DECL_DT_UNKNOWN) && HAVE_DECL_DT_UNKNOWN)
   XLAT(DT_UNKNOWN),
+ #define XLAT_VAL_0 ((unsigned) (DT_UNKNOWN))
+ #define XLAT_STR_0 STRINGIFY(DT_UNKNOWN)
 #endif
 #if defined(DT_FIFO) || (defined(HAVE_DECL_DT_FIFO) && HAVE_DECL_DT_FIFO)
   XLAT(DT_FIFO),
+ #define XLAT_VAL_1 ((unsigned) (DT_FIFO))
+ #define XLAT_STR_1 STRINGIFY(DT_FIFO)
 #endif
 #if defined(DT_CHR) || (defined(HAVE_DECL_DT_CHR) && HAVE_DECL_DT_CHR)
   XLAT(DT_CHR),
+ #define XLAT_VAL_2 ((unsigned) (DT_CHR))
+ #define XLAT_STR_2 STRINGIFY(DT_CHR)
 #endif
 #if defined(DT_DIR) || (defined(HAVE_DECL_DT_DIR) && HAVE_DECL_DT_DIR)
   XLAT(DT_DIR),
+ #define XLAT_VAL_3 ((unsigned) (DT_DIR))
+ #define XLAT_STR_3 STRINGIFY(DT_DIR)
 #endif
 #if defined(DT_BLK) || (defined(HAVE_DECL_DT_BLK) && HAVE_DECL_DT_BLK)
   XLAT(DT_BLK),
+ #define XLAT_VAL_4 ((unsigned) (DT_BLK))
+ #define XLAT_STR_4 STRINGIFY(DT_BLK)
 #endif
 #if defined(DT_REG) || (defined(HAVE_DECL_DT_REG) && HAVE_DECL_DT_REG)
   XLAT(DT_REG),
+ #define XLAT_VAL_5 ((unsigned) (DT_REG))
+ #define XLAT_STR_5 STRINGIFY(DT_REG)
 #endif
 #if defined(DT_LNK) || (defined(HAVE_DECL_DT_LNK) && HAVE_DECL_DT_LNK)
   XLAT(DT_LNK),
+ #define XLAT_VAL_6 ((unsigned) (DT_LNK))
+ #define XLAT_STR_6 STRINGIFY(DT_LNK)
 #endif
 #if defined(DT_SOCK) || (defined(HAVE_DECL_DT_SOCK) && HAVE_DECL_DT_SOCK)
   XLAT(DT_SOCK),
+ #define XLAT_VAL_7 ((unsigned) (DT_SOCK))
+ #define XLAT_STR_7 STRINGIFY(DT_SOCK)
 #endif
 #if defined(DT_WHT) || (defined(HAVE_DECL_DT_WHT) && HAVE_DECL_DT_WHT)
   XLAT(DT_WHT),
+ #define XLAT_VAL_8 ((unsigned) (DT_WHT))
+ #define XLAT_STR_8 STRINGIFY(DT_WHT)
 #endif
 };
 const struct xlat dirent_types[1] = { {
  .data = dirent_types_xdata,
  .size = ARRAY_SIZE(dirent_types_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/dm_flags.h 5.9-0ubuntu2/xlat/dm_flags.h
--- 5.5-3/xlat/dm_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/dm_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -140,32 +140,216 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data dm_flags_xdata[] = {
  XLAT(DM_READONLY_FLAG),
+ #define XLAT_VAL_0 ((unsigned) (DM_READONLY_FLAG))
+ #define XLAT_STR_0 STRINGIFY(DM_READONLY_FLAG)
  XLAT(DM_SUSPEND_FLAG),
+ #define XLAT_VAL_1 ((unsigned) (DM_SUSPEND_FLAG))
+ #define XLAT_STR_1 STRINGIFY(DM_SUSPEND_FLAG)
 
  XLAT(DM_EXISTS_FLAG),
+ #define XLAT_VAL_2 ((unsigned) (DM_EXISTS_FLAG))
+ #define XLAT_STR_2 STRINGIFY(DM_EXISTS_FLAG)
  XLAT(DM_PERSISTENT_DEV_FLAG),
+ #define XLAT_VAL_3 ((unsigned) (DM_PERSISTENT_DEV_FLAG))
+ #define XLAT_STR_3 STRINGIFY(DM_PERSISTENT_DEV_FLAG)
  XLAT(DM_STATUS_TABLE_FLAG),
+ #define XLAT_VAL_4 ((unsigned) (DM_STATUS_TABLE_FLAG))
+ #define XLAT_STR_4 STRINGIFY(DM_STATUS_TABLE_FLAG)
  XLAT(DM_ACTIVE_PRESENT_FLAG),
+ #define XLAT_VAL_5 ((unsigned) (DM_ACTIVE_PRESENT_FLAG))
+ #define XLAT_STR_5 STRINGIFY(DM_ACTIVE_PRESENT_FLAG)
  XLAT(DM_INACTIVE_PRESENT_FLAG),
+ #define XLAT_VAL_6 ((unsigned) (DM_INACTIVE_PRESENT_FLAG))
+ #define XLAT_STR_6 STRINGIFY(DM_INACTIVE_PRESENT_FLAG)
  XLAT(DM_BUFFER_FULL_FLAG),
+ #define XLAT_VAL_7 ((unsigned) (DM_BUFFER_FULL_FLAG))
+ #define XLAT_STR_7 STRINGIFY(DM_BUFFER_FULL_FLAG)
  XLAT(DM_SKIP_BDGET_FLAG),
+ #define XLAT_VAL_8 ((unsigned) (DM_SKIP_BDGET_FLAG))
+ #define XLAT_STR_8 STRINGIFY(DM_SKIP_BDGET_FLAG)
  XLAT(DM_SKIP_LOCKFS_FLAG),
+ #define XLAT_VAL_9 ((unsigned) (DM_SKIP_LOCKFS_FLAG))
+ #define XLAT_STR_9 STRINGIFY(DM_SKIP_LOCKFS_FLAG)
  XLAT(DM_NOFLUSH_FLAG),
+ #define XLAT_VAL_10 ((unsigned) (DM_NOFLUSH_FLAG))
+ #define XLAT_STR_10 STRINGIFY(DM_NOFLUSH_FLAG)
  XLAT(DM_QUERY_INACTIVE_TABLE_FLAG),
+ #define XLAT_VAL_11 ((unsigned) (DM_QUERY_INACTIVE_TABLE_FLAG))
+ #define XLAT_STR_11 STRINGIFY(DM_QUERY_INACTIVE_TABLE_FLAG)
  XLAT(DM_UEVENT_GENERATED_FLAG),
+ #define XLAT_VAL_12 ((unsigned) (DM_UEVENT_GENERATED_FLAG))
+ #define XLAT_STR_12 STRINGIFY(DM_UEVENT_GENERATED_FLAG)
  XLAT(DM_UUID_FLAG),
+ #define XLAT_VAL_13 ((unsigned) (DM_UUID_FLAG))
+ #define XLAT_STR_13 STRINGIFY(DM_UUID_FLAG)
  XLAT(DM_SECURE_DATA_FLAG),
+ #define XLAT_VAL_14 ((unsigned) (DM_SECURE_DATA_FLAG))
+ #define XLAT_STR_14 STRINGIFY(DM_SECURE_DATA_FLAG)
  XLAT(DM_DATA_OUT_FLAG),
+ #define XLAT_VAL_15 ((unsigned) (DM_DATA_OUT_FLAG))
+ #define XLAT_STR_15 STRINGIFY(DM_DATA_OUT_FLAG)
  XLAT(DM_DEFERRED_REMOVE),
+ #define XLAT_VAL_16 ((unsigned) (DM_DEFERRED_REMOVE))
+ #define XLAT_STR_16 STRINGIFY(DM_DEFERRED_REMOVE)
  XLAT(DM_INTERNAL_SUSPEND_FLAG),
+ #define XLAT_VAL_17 ((unsigned) (DM_INTERNAL_SUSPEND_FLAG))
+ #define XLAT_STR_17 STRINGIFY(DM_INTERNAL_SUSPEND_FLAG)
 };
 static
 const struct xlat dm_flags[1] = { {
  .data = dm_flags_xdata,
  .size = ARRAY_SIZE(dm_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ebpf_class.h 5.9-0ubuntu2/xlat/ebpf_class.h
--- 5.5-3/xlat/ebpf_class.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ebpf_class.h	2020-09-24 09:18:44.000000000 +0000
@@ -70,21 +70,105 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data ebpf_class_xdata[] = {
  [BPF_LD] = XLAT(BPF_LD),
+ #define XLAT_VAL_0 ((unsigned) (BPF_LD))
+ #define XLAT_STR_0 STRINGIFY(BPF_LD)
  [BPF_LDX] = XLAT(BPF_LDX),
+ #define XLAT_VAL_1 ((unsigned) (BPF_LDX))
+ #define XLAT_STR_1 STRINGIFY(BPF_LDX)
  [BPF_ST] = XLAT(BPF_ST),
+ #define XLAT_VAL_2 ((unsigned) (BPF_ST))
+ #define XLAT_STR_2 STRINGIFY(BPF_ST)
  [BPF_STX] = XLAT(BPF_STX),
+ #define XLAT_VAL_3 ((unsigned) (BPF_STX))
+ #define XLAT_STR_3 STRINGIFY(BPF_STX)
  [BPF_ALU] = XLAT(BPF_ALU),
+ #define XLAT_VAL_4 ((unsigned) (BPF_ALU))
+ #define XLAT_STR_4 STRINGIFY(BPF_ALU)
  [BPF_JMP] = XLAT(BPF_JMP),
+ #define XLAT_VAL_5 ((unsigned) (BPF_JMP))
+ #define XLAT_STR_5 STRINGIFY(BPF_JMP)
  [BPF_JMP32] = XLAT(BPF_JMP32),
+ #define XLAT_VAL_6 ((unsigned) (BPF_JMP32))
+ #define XLAT_STR_6 STRINGIFY(BPF_JMP32)
  [BPF_ALU64] = XLAT(BPF_ALU64),
+ #define XLAT_VAL_7 ((unsigned) (BPF_ALU64))
+ #define XLAT_STR_7 STRINGIFY(BPF_ALU64)
 };
 static
 const struct xlat ebpf_class[1] = { {
  .data = ebpf_class_xdata,
  .size = ARRAY_SIZE(ebpf_class_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ebpf_mode.h 5.9-0ubuntu2/xlat/ebpf_mode.h
--- 5.5-3/xlat/ebpf_mode.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ebpf_mode.h	2020-09-24 09:18:44.000000000 +0000
@@ -49,18 +49,72 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data ebpf_mode_xdata[] = {
  XLAT(BPF_IMM),
+ #define XLAT_VAL_0 ((unsigned) (BPF_IMM))
+ #define XLAT_STR_0 STRINGIFY(BPF_IMM)
  XLAT(BPF_ABS),
+ #define XLAT_VAL_1 ((unsigned) (BPF_ABS))
+ #define XLAT_STR_1 STRINGIFY(BPF_ABS)
  XLAT(BPF_IND),
+ #define XLAT_VAL_2 ((unsigned) (BPF_IND))
+ #define XLAT_STR_2 STRINGIFY(BPF_IND)
  XLAT(BPF_MEM),
+ #define XLAT_VAL_3 ((unsigned) (BPF_MEM))
+ #define XLAT_STR_3 STRINGIFY(BPF_MEM)
  XLAT(BPF_XADD),
+ #define XLAT_VAL_4 ((unsigned) (BPF_XADD))
+ #define XLAT_STR_4 STRINGIFY(BPF_XADD)
 };
 static
 const struct xlat ebpf_mode[1] = { {
  .data = ebpf_mode_xdata,
  .size = ARRAY_SIZE(ebpf_mode_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ebpf_op_alu.h 5.9-0ubuntu2/xlat/ebpf_op_alu.h
--- 5.5-3/xlat/ebpf_op_alu.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ebpf_op_alu.h	2020-09-24 09:18:44.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data ebpf_op_alu_xdata[] = {
  XLAT(BPF_MOV),
+ #define XLAT_VAL_0 ((unsigned) (BPF_MOV))
+ #define XLAT_STR_0 STRINGIFY(BPF_MOV)
  XLAT(BPF_ARSH),
+ #define XLAT_VAL_1 ((unsigned) (BPF_ARSH))
+ #define XLAT_STR_1 STRINGIFY(BPF_ARSH)
  XLAT(BPF_END),
+ #define XLAT_VAL_2 ((unsigned) (BPF_END))
+ #define XLAT_STR_2 STRINGIFY(BPF_END)
 };
 static
 const struct xlat ebpf_op_alu[1] = { {
  .data = ebpf_op_alu_xdata,
  .size = ARRAY_SIZE(ebpf_op_alu_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ebpf_op_jmp.h 5.9-0ubuntu2/xlat/ebpf_op_jmp.h
--- 5.5-3/xlat/ebpf_op_jmp.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ebpf_op_jmp.h	2020-09-24 09:18:44.000000000 +0000
@@ -77,22 +77,116 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data ebpf_op_jmp_xdata[] = {
  XLAT(BPF_JNE),
+ #define XLAT_VAL_0 ((unsigned) (BPF_JNE))
+ #define XLAT_STR_0 STRINGIFY(BPF_JNE)
  XLAT(BPF_JSGT),
+ #define XLAT_VAL_1 ((unsigned) (BPF_JSGT))
+ #define XLAT_STR_1 STRINGIFY(BPF_JSGT)
  XLAT(BPF_JSGE),
+ #define XLAT_VAL_2 ((unsigned) (BPF_JSGE))
+ #define XLAT_STR_2 STRINGIFY(BPF_JSGE)
  XLAT(BPF_CALL),
+ #define XLAT_VAL_3 ((unsigned) (BPF_CALL))
+ #define XLAT_STR_3 STRINGIFY(BPF_CALL)
  XLAT(BPF_EXIT),
+ #define XLAT_VAL_4 ((unsigned) (BPF_EXIT))
+ #define XLAT_STR_4 STRINGIFY(BPF_EXIT)
  XLAT(BPF_JLT),
+ #define XLAT_VAL_5 ((unsigned) (BPF_JLT))
+ #define XLAT_STR_5 STRINGIFY(BPF_JLT)
  XLAT(BPF_JLE),
+ #define XLAT_VAL_6 ((unsigned) (BPF_JLE))
+ #define XLAT_STR_6 STRINGIFY(BPF_JLE)
  XLAT(BPF_JSLT),
+ #define XLAT_VAL_7 ((unsigned) (BPF_JSLT))
+ #define XLAT_STR_7 STRINGIFY(BPF_JSLT)
  XLAT(BPF_JSLE),
+ #define XLAT_VAL_8 ((unsigned) (BPF_JSLE))
+ #define XLAT_STR_8 STRINGIFY(BPF_JSLE)
 };
 static
 const struct xlat ebpf_op_jmp[1] = { {
  .data = ebpf_op_jmp_xdata,
  .size = ARRAY_SIZE(ebpf_op_jmp_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ebpf_regs.h 5.9-0ubuntu2/xlat/ebpf_regs.h
--- 5.5-3/xlat/ebpf_regs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ebpf_regs.h	2020-09-24 09:18:44.000000000 +0000
@@ -91,24 +91,138 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data ebpf_regs_xdata[] = {
  [BPF_REG_0] = XLAT(BPF_REG_0),
+ #define XLAT_VAL_0 ((unsigned) (BPF_REG_0))
+ #define XLAT_STR_0 STRINGIFY(BPF_REG_0)
  [BPF_REG_1] = XLAT(BPF_REG_1),
+ #define XLAT_VAL_1 ((unsigned) (BPF_REG_1))
+ #define XLAT_STR_1 STRINGIFY(BPF_REG_1)
  [BPF_REG_2] = XLAT(BPF_REG_2),
+ #define XLAT_VAL_2 ((unsigned) (BPF_REG_2))
+ #define XLAT_STR_2 STRINGIFY(BPF_REG_2)
  [BPF_REG_3] = XLAT(BPF_REG_3),
+ #define XLAT_VAL_3 ((unsigned) (BPF_REG_3))
+ #define XLAT_STR_3 STRINGIFY(BPF_REG_3)
  [BPF_REG_4] = XLAT(BPF_REG_4),
+ #define XLAT_VAL_4 ((unsigned) (BPF_REG_4))
+ #define XLAT_STR_4 STRINGIFY(BPF_REG_4)
  [BPF_REG_5] = XLAT(BPF_REG_5),
+ #define XLAT_VAL_5 ((unsigned) (BPF_REG_5))
+ #define XLAT_STR_5 STRINGIFY(BPF_REG_5)
  [BPF_REG_6] = XLAT(BPF_REG_6),
+ #define XLAT_VAL_6 ((unsigned) (BPF_REG_6))
+ #define XLAT_STR_6 STRINGIFY(BPF_REG_6)
  [BPF_REG_7] = XLAT(BPF_REG_7),
+ #define XLAT_VAL_7 ((unsigned) (BPF_REG_7))
+ #define XLAT_STR_7 STRINGIFY(BPF_REG_7)
  [BPF_REG_8] = XLAT(BPF_REG_8),
+ #define XLAT_VAL_8 ((unsigned) (BPF_REG_8))
+ #define XLAT_STR_8 STRINGIFY(BPF_REG_8)
  [BPF_REG_9] = XLAT(BPF_REG_9),
+ #define XLAT_VAL_9 ((unsigned) (BPF_REG_9))
+ #define XLAT_STR_9 STRINGIFY(BPF_REG_9)
  [BPF_REG_10] = XLAT(BPF_REG_10),
+ #define XLAT_VAL_10 ((unsigned) (BPF_REG_10))
+ #define XLAT_STR_10 STRINGIFY(BPF_REG_10)
 };
 static
 const struct xlat ebpf_regs[1] = { {
  .data = ebpf_regs_xdata,
  .size = ARRAY_SIZE(ebpf_regs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ebpf_size.h 5.9-0ubuntu2/xlat/ebpf_size.h
--- 5.5-3/xlat/ebpf_size.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ebpf_size.h	2020-09-24 09:18:44.000000000 +0000
@@ -21,14 +21,28 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data ebpf_size_xdata[] = {
  XLAT(BPF_DW),
+ #define XLAT_VAL_0 ((unsigned) (BPF_DW))
+ #define XLAT_STR_0 STRINGIFY(BPF_DW)
 };
 static
 const struct xlat ebpf_size[1] = { {
  .data = ebpf_size_xdata,
  .size = ARRAY_SIZE(ebpf_size_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/efd_flags.h 5.9-0ubuntu2/xlat/efd_flags.h
--- 5.5-3/xlat/efd_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/efd_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -37,18 +37,52 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data efd_flags_xdata[] = {
  XLAT(EFD_SEMAPHORE),
+ #define XLAT_VAL_0 ((unsigned) (EFD_SEMAPHORE))
+ #define XLAT_STR_0 STRINGIFY(EFD_SEMAPHORE)
 #if defined EFD_CLOEXEC || defined O_CLOEXEC
  XLAT(EFD_CLOEXEC),
+ #define XLAT_VAL_1 ((unsigned) (EFD_CLOEXEC))
+ #define XLAT_STR_1 STRINGIFY(EFD_CLOEXEC)
 #endif
  XLAT(EFD_NONBLOCK),
+ #define XLAT_VAL_2 ((unsigned) (EFD_NONBLOCK))
+ #define XLAT_STR_2 STRINGIFY(EFD_NONBLOCK)
 };
 static
 const struct xlat efd_flags[1] = { {
  .data = efd_flags_xdata,
  .size = ARRAY_SIZE(efd_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/elf_em.h 5.9-0ubuntu2/xlat/elf_em.h
--- 5.5-3/xlat/elf_em.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/elf_em.h	2020-09-24 09:18:48.000000000 +0000
@@ -1325,204 +1325,578 @@ static const struct xlat_data elf_em_xda
 
 
  XLAT(EM_NONE),
+ #define XLAT_VAL_0 ((unsigned) (EM_NONE))
+ #define XLAT_STR_0 STRINGIFY(EM_NONE)
  XLAT(EM_M32),
+ #define XLAT_VAL_1 ((unsigned) (EM_M32))
+ #define XLAT_STR_1 STRINGIFY(EM_M32)
  XLAT(EM_SPARC),
+ #define XLAT_VAL_2 ((unsigned) (EM_SPARC))
+ #define XLAT_STR_2 STRINGIFY(EM_SPARC)
  XLAT(EM_386),
+ #define XLAT_VAL_3 ((unsigned) (EM_386))
+ #define XLAT_STR_3 STRINGIFY(EM_386)
  XLAT(EM_68K),
+ #define XLAT_VAL_4 ((unsigned) (EM_68K))
+ #define XLAT_STR_4 STRINGIFY(EM_68K)
  XLAT(EM_88K),
+ #define XLAT_VAL_5 ((unsigned) (EM_88K))
+ #define XLAT_STR_5 STRINGIFY(EM_88K)
  XLAT(EM_486),
+ #define XLAT_VAL_6 ((unsigned) (EM_486))
+ #define XLAT_STR_6 STRINGIFY(EM_486)
 
  XLAT(EM_860),
+ #define XLAT_VAL_7 ((unsigned) (EM_860))
+ #define XLAT_STR_7 STRINGIFY(EM_860)
  XLAT(EM_MIPS),
+ #define XLAT_VAL_8 ((unsigned) (EM_MIPS))
+ #define XLAT_STR_8 STRINGIFY(EM_MIPS)
  XLAT(EM_S370),
+ #define XLAT_VAL_9 ((unsigned) (EM_S370))
+ #define XLAT_STR_9 STRINGIFY(EM_S370)
  XLAT(EM_MIPS_RS3_LE),
+ #define XLAT_VAL_10 ((unsigned) (EM_MIPS_RS3_LE))
+ #define XLAT_STR_10 STRINGIFY(EM_MIPS_RS3_LE)
 
 
  XLAT(EM_PARISC),
+ #define XLAT_VAL_11 ((unsigned) (EM_PARISC))
+ #define XLAT_STR_11 STRINGIFY(EM_PARISC)
 
  XLAT(EM_VPP500),
+ #define XLAT_VAL_12 ((unsigned) (EM_VPP500))
+ #define XLAT_STR_12 STRINGIFY(EM_VPP500)
  XLAT(EM_SPARC32PLUS),
+ #define XLAT_VAL_13 ((unsigned) (EM_SPARC32PLUS))
+ #define XLAT_STR_13 STRINGIFY(EM_SPARC32PLUS)
  XLAT(EM_960),
+ #define XLAT_VAL_14 ((unsigned) (EM_960))
+ #define XLAT_STR_14 STRINGIFY(EM_960)
  XLAT(EM_PPC),
+ #define XLAT_VAL_15 ((unsigned) (EM_PPC))
+ #define XLAT_STR_15 STRINGIFY(EM_PPC)
  XLAT(EM_PPC64),
+ #define XLAT_VAL_16 ((unsigned) (EM_PPC64))
+ #define XLAT_STR_16 STRINGIFY(EM_PPC64)
  XLAT(EM_S390),
+ #define XLAT_VAL_17 ((unsigned) (EM_S390))
+ #define XLAT_STR_17 STRINGIFY(EM_S390)
  XLAT(EM_SPU),
+ #define XLAT_VAL_18 ((unsigned) (EM_SPU))
+ #define XLAT_STR_18 STRINGIFY(EM_SPU)
 
  XLAT(EM_V800),
+ #define XLAT_VAL_19 ((unsigned) (EM_V800))
+ #define XLAT_STR_19 STRINGIFY(EM_V800)
  XLAT(EM_FR20),
+ #define XLAT_VAL_20 ((unsigned) (EM_FR20))
+ #define XLAT_STR_20 STRINGIFY(EM_FR20)
  XLAT(EM_RH32),
+ #define XLAT_VAL_21 ((unsigned) (EM_RH32))
+ #define XLAT_STR_21 STRINGIFY(EM_RH32)
  XLAT(EM_RCE),
+ #define XLAT_VAL_22 ((unsigned) (EM_RCE))
+ #define XLAT_STR_22 STRINGIFY(EM_RCE)
  XLAT(EM_ARM),
+ #define XLAT_VAL_23 ((unsigned) (EM_ARM))
+ #define XLAT_STR_23 STRINGIFY(EM_ARM)
 
  XLAT(EM_SH),
+ #define XLAT_VAL_24 ((unsigned) (EM_SH))
+ #define XLAT_STR_24 STRINGIFY(EM_SH)
  XLAT(EM_SPARCV9),
+ #define XLAT_VAL_25 ((unsigned) (EM_SPARCV9))
+ #define XLAT_STR_25 STRINGIFY(EM_SPARCV9)
  XLAT(EM_TRICORE),
+ #define XLAT_VAL_26 ((unsigned) (EM_TRICORE))
+ #define XLAT_STR_26 STRINGIFY(EM_TRICORE)
  XLAT(EM_ARC),
+ #define XLAT_VAL_27 ((unsigned) (EM_ARC))
+ #define XLAT_STR_27 STRINGIFY(EM_ARC)
  XLAT(EM_H8_300),
+ #define XLAT_VAL_28 ((unsigned) (EM_H8_300))
+ #define XLAT_STR_28 STRINGIFY(EM_H8_300)
  XLAT(EM_H8_300H),
+ #define XLAT_VAL_29 ((unsigned) (EM_H8_300H))
+ #define XLAT_STR_29 STRINGIFY(EM_H8_300H)
  XLAT(EM_H8S),
+ #define XLAT_VAL_30 ((unsigned) (EM_H8S))
+ #define XLAT_STR_30 STRINGIFY(EM_H8S)
  XLAT(EM_H8_500),
+ #define XLAT_VAL_31 ((unsigned) (EM_H8_500))
+ #define XLAT_STR_31 STRINGIFY(EM_H8_500)
  XLAT(EM_IA_64),
+ #define XLAT_VAL_32 ((unsigned) (EM_IA_64))
+ #define XLAT_STR_32 STRINGIFY(EM_IA_64)
  XLAT(EM_MIPS_X),
+ #define XLAT_VAL_33 ((unsigned) (EM_MIPS_X))
+ #define XLAT_STR_33 STRINGIFY(EM_MIPS_X)
  XLAT(EM_COLDFIRE),
+ #define XLAT_VAL_34 ((unsigned) (EM_COLDFIRE))
+ #define XLAT_STR_34 STRINGIFY(EM_COLDFIRE)
  XLAT(EM_68HC12),
+ #define XLAT_VAL_35 ((unsigned) (EM_68HC12))
+ #define XLAT_STR_35 STRINGIFY(EM_68HC12)
  XLAT(EM_MMA),
+ #define XLAT_VAL_36 ((unsigned) (EM_MMA))
+ #define XLAT_STR_36 STRINGIFY(EM_MMA)
  XLAT(EM_PCP),
+ #define XLAT_VAL_37 ((unsigned) (EM_PCP))
+ #define XLAT_STR_37 STRINGIFY(EM_PCP)
  XLAT(EM_NCPU),
+ #define XLAT_VAL_38 ((unsigned) (EM_NCPU))
+ #define XLAT_STR_38 STRINGIFY(EM_NCPU)
  XLAT(EM_NDR1),
+ #define XLAT_VAL_39 ((unsigned) (EM_NDR1))
+ #define XLAT_STR_39 STRINGIFY(EM_NDR1)
  XLAT(EM_STARCORE),
+ #define XLAT_VAL_40 ((unsigned) (EM_STARCORE))
+ #define XLAT_STR_40 STRINGIFY(EM_STARCORE)
  XLAT(EM_ME16),
+ #define XLAT_VAL_41 ((unsigned) (EM_ME16))
+ #define XLAT_STR_41 STRINGIFY(EM_ME16)
  XLAT(EM_ST100),
+ #define XLAT_VAL_42 ((unsigned) (EM_ST100))
+ #define XLAT_STR_42 STRINGIFY(EM_ST100)
  XLAT(EM_TINYJ),
+ #define XLAT_VAL_43 ((unsigned) (EM_TINYJ))
+ #define XLAT_STR_43 STRINGIFY(EM_TINYJ)
  XLAT(EM_X86_64),
+ #define XLAT_VAL_44 ((unsigned) (EM_X86_64))
+ #define XLAT_STR_44 STRINGIFY(EM_X86_64)
  XLAT(EM_PDSP),
+ #define XLAT_VAL_45 ((unsigned) (EM_PDSP))
+ #define XLAT_STR_45 STRINGIFY(EM_PDSP)
  XLAT(EM_PDP10),
+ #define XLAT_VAL_46 ((unsigned) (EM_PDP10))
+ #define XLAT_STR_46 STRINGIFY(EM_PDP10)
  XLAT(EM_PDP11),
+ #define XLAT_VAL_47 ((unsigned) (EM_PDP11))
+ #define XLAT_STR_47 STRINGIFY(EM_PDP11)
  XLAT(EM_FX66),
+ #define XLAT_VAL_48 ((unsigned) (EM_FX66))
+ #define XLAT_STR_48 STRINGIFY(EM_FX66)
  XLAT(EM_ST9PLUS),
+ #define XLAT_VAL_49 ((unsigned) (EM_ST9PLUS))
+ #define XLAT_STR_49 STRINGIFY(EM_ST9PLUS)
  XLAT(EM_ST7),
+ #define XLAT_VAL_50 ((unsigned) (EM_ST7))
+ #define XLAT_STR_50 STRINGIFY(EM_ST7)
  XLAT(EM_68HC16),
+ #define XLAT_VAL_51 ((unsigned) (EM_68HC16))
+ #define XLAT_STR_51 STRINGIFY(EM_68HC16)
  XLAT(EM_68HC11),
+ #define XLAT_VAL_52 ((unsigned) (EM_68HC11))
+ #define XLAT_STR_52 STRINGIFY(EM_68HC11)
  XLAT(EM_68HC08),
+ #define XLAT_VAL_53 ((unsigned) (EM_68HC08))
+ #define XLAT_STR_53 STRINGIFY(EM_68HC08)
  XLAT(EM_68HC05),
+ #define XLAT_VAL_54 ((unsigned) (EM_68HC05))
+ #define XLAT_STR_54 STRINGIFY(EM_68HC05)
  XLAT(EM_SVX),
+ #define XLAT_VAL_55 ((unsigned) (EM_SVX))
+ #define XLAT_STR_55 STRINGIFY(EM_SVX)
  XLAT(EM_ST19),
+ #define XLAT_VAL_56 ((unsigned) (EM_ST19))
+ #define XLAT_STR_56 STRINGIFY(EM_ST19)
  XLAT(EM_VAX),
+ #define XLAT_VAL_57 ((unsigned) (EM_VAX))
+ #define XLAT_STR_57 STRINGIFY(EM_VAX)
  XLAT(EM_CRIS),
+ #define XLAT_VAL_58 ((unsigned) (EM_CRIS))
+ #define XLAT_STR_58 STRINGIFY(EM_CRIS)
  XLAT(EM_JAVELIN),
+ #define XLAT_VAL_59 ((unsigned) (EM_JAVELIN))
+ #define XLAT_STR_59 STRINGIFY(EM_JAVELIN)
  XLAT(EM_FIREPATH),
+ #define XLAT_VAL_60 ((unsigned) (EM_FIREPATH))
+ #define XLAT_STR_60 STRINGIFY(EM_FIREPATH)
  XLAT(EM_ZSP),
+ #define XLAT_VAL_61 ((unsigned) (EM_ZSP))
+ #define XLAT_STR_61 STRINGIFY(EM_ZSP)
  XLAT(EM_MMIX),
+ #define XLAT_VAL_62 ((unsigned) (EM_MMIX))
+ #define XLAT_STR_62 STRINGIFY(EM_MMIX)
  XLAT(EM_HUANY),
+ #define XLAT_VAL_63 ((unsigned) (EM_HUANY))
+ #define XLAT_STR_63 STRINGIFY(EM_HUANY)
  XLAT(EM_PRISM),
+ #define XLAT_VAL_64 ((unsigned) (EM_PRISM))
+ #define XLAT_STR_64 STRINGIFY(EM_PRISM)
  XLAT(EM_AVR),
+ #define XLAT_VAL_65 ((unsigned) (EM_AVR))
+ #define XLAT_STR_65 STRINGIFY(EM_AVR)
  XLAT(EM_FR30),
+ #define XLAT_VAL_66 ((unsigned) (EM_FR30))
+ #define XLAT_STR_66 STRINGIFY(EM_FR30)
  XLAT(EM_D10V),
+ #define XLAT_VAL_67 ((unsigned) (EM_D10V))
+ #define XLAT_STR_67 STRINGIFY(EM_D10V)
  XLAT(EM_D30V),
+ #define XLAT_VAL_68 ((unsigned) (EM_D30V))
+ #define XLAT_STR_68 STRINGIFY(EM_D30V)
  XLAT(EM_V850),
+ #define XLAT_VAL_69 ((unsigned) (EM_V850))
+ #define XLAT_STR_69 STRINGIFY(EM_V850)
  XLAT(EM_M32R),
+ #define XLAT_VAL_70 ((unsigned) (EM_M32R))
+ #define XLAT_STR_70 STRINGIFY(EM_M32R)
  XLAT(EM_MN10300),
+ #define XLAT_VAL_71 ((unsigned) (EM_MN10300))
+ #define XLAT_STR_71 STRINGIFY(EM_MN10300)
  XLAT(EM_MN10200),
+ #define XLAT_VAL_72 ((unsigned) (EM_MN10200))
+ #define XLAT_STR_72 STRINGIFY(EM_MN10200)
  XLAT(EM_PJ),
+ #define XLAT_VAL_73 ((unsigned) (EM_PJ))
+ #define XLAT_STR_73 STRINGIFY(EM_PJ)
  XLAT(EM_OPENRISC),
+ #define XLAT_VAL_74 ((unsigned) (EM_OPENRISC))
+ #define XLAT_STR_74 STRINGIFY(EM_OPENRISC)
  XLAT(EM_ARCOMPACT),
+ #define XLAT_VAL_75 ((unsigned) (EM_ARCOMPACT))
+ #define XLAT_STR_75 STRINGIFY(EM_ARCOMPACT)
  XLAT(EM_XTENSA),
+ #define XLAT_VAL_76 ((unsigned) (EM_XTENSA))
+ #define XLAT_STR_76 STRINGIFY(EM_XTENSA)
  XLAT(EM_VIDEOCORE),
+ #define XLAT_VAL_77 ((unsigned) (EM_VIDEOCORE))
+ #define XLAT_STR_77 STRINGIFY(EM_VIDEOCORE)
  XLAT(EM_TMM_GPP),
+ #define XLAT_VAL_78 ((unsigned) (EM_TMM_GPP))
+ #define XLAT_STR_78 STRINGIFY(EM_TMM_GPP)
  XLAT(EM_NS32K),
+ #define XLAT_VAL_79 ((unsigned) (EM_NS32K))
+ #define XLAT_STR_79 STRINGIFY(EM_NS32K)
  XLAT(EM_TPC),
+ #define XLAT_VAL_80 ((unsigned) (EM_TPC))
+ #define XLAT_STR_80 STRINGIFY(EM_TPC)
  XLAT(EM_SNP1K),
+ #define XLAT_VAL_81 ((unsigned) (EM_SNP1K))
+ #define XLAT_STR_81 STRINGIFY(EM_SNP1K)
  XLAT(EM_ST200),
+ #define XLAT_VAL_82 ((unsigned) (EM_ST200))
+ #define XLAT_STR_82 STRINGIFY(EM_ST200)
  XLAT(EM_IP2K),
+ #define XLAT_VAL_83 ((unsigned) (EM_IP2K))
+ #define XLAT_STR_83 STRINGIFY(EM_IP2K)
  XLAT(EM_MAX),
+ #define XLAT_VAL_84 ((unsigned) (EM_MAX))
+ #define XLAT_STR_84 STRINGIFY(EM_MAX)
  XLAT(EM_CR),
+ #define XLAT_VAL_85 ((unsigned) (EM_CR))
+ #define XLAT_STR_85 STRINGIFY(EM_CR)
  XLAT(EM_F2MC16),
+ #define XLAT_VAL_86 ((unsigned) (EM_F2MC16))
+ #define XLAT_STR_86 STRINGIFY(EM_F2MC16)
  XLAT(EM_MSP430),
+ #define XLAT_VAL_87 ((unsigned) (EM_MSP430))
+ #define XLAT_STR_87 STRINGIFY(EM_MSP430)
  XLAT(EM_BLACKFIN),
+ #define XLAT_VAL_88 ((unsigned) (EM_BLACKFIN))
+ #define XLAT_STR_88 STRINGIFY(EM_BLACKFIN)
  XLAT(EM_SE_C33),
+ #define XLAT_VAL_89 ((unsigned) (EM_SE_C33))
+ #define XLAT_STR_89 STRINGIFY(EM_SE_C33)
  XLAT(EM_SEP),
+ #define XLAT_VAL_90 ((unsigned) (EM_SEP))
+ #define XLAT_STR_90 STRINGIFY(EM_SEP)
  XLAT(EM_ARCA),
+ #define XLAT_VAL_91 ((unsigned) (EM_ARCA))
+ #define XLAT_STR_91 STRINGIFY(EM_ARCA)
  XLAT(EM_UNICORE),
+ #define XLAT_VAL_92 ((unsigned) (EM_UNICORE))
+ #define XLAT_STR_92 STRINGIFY(EM_UNICORE)
  XLAT(EM_EXCESS),
+ #define XLAT_VAL_93 ((unsigned) (EM_EXCESS))
+ #define XLAT_STR_93 STRINGIFY(EM_EXCESS)
  XLAT(EM_DXP),
+ #define XLAT_VAL_94 ((unsigned) (EM_DXP))
+ #define XLAT_STR_94 STRINGIFY(EM_DXP)
  XLAT(EM_ALTERA_NIOS2),
+ #define XLAT_VAL_95 ((unsigned) (EM_ALTERA_NIOS2))
+ #define XLAT_STR_95 STRINGIFY(EM_ALTERA_NIOS2)
  XLAT(EM_CRX),
+ #define XLAT_VAL_96 ((unsigned) (EM_CRX))
+ #define XLAT_STR_96 STRINGIFY(EM_CRX)
  XLAT(EM_XGATE),
+ #define XLAT_VAL_97 ((unsigned) (EM_XGATE))
+ #define XLAT_STR_97 STRINGIFY(EM_XGATE)
  XLAT(EM_C166),
+ #define XLAT_VAL_98 ((unsigned) (EM_C166))
+ #define XLAT_STR_98 STRINGIFY(EM_C166)
  XLAT(EM_M16C),
+ #define XLAT_VAL_99 ((unsigned) (EM_M16C))
+ #define XLAT_STR_99 STRINGIFY(EM_M16C)
  XLAT(EM_DSPIC30F),
+ #define XLAT_VAL_100 ((unsigned) (EM_DSPIC30F))
+ #define XLAT_STR_100 STRINGIFY(EM_DSPIC30F)
  XLAT(EM_CE),
+ #define XLAT_VAL_101 ((unsigned) (EM_CE))
+ #define XLAT_STR_101 STRINGIFY(EM_CE)
  XLAT(EM_M32C),
+ #define XLAT_VAL_102 ((unsigned) (EM_M32C))
+ #define XLAT_STR_102 STRINGIFY(EM_M32C)
 
  XLAT(EM_TSK3000),
+ #define XLAT_VAL_103 ((unsigned) (EM_TSK3000))
+ #define XLAT_STR_103 STRINGIFY(EM_TSK3000)
  XLAT(EM_RS08),
+ #define XLAT_VAL_104 ((unsigned) (EM_RS08))
+ #define XLAT_STR_104 STRINGIFY(EM_RS08)
  XLAT(EM_SHARC),
+ #define XLAT_VAL_105 ((unsigned) (EM_SHARC))
+ #define XLAT_STR_105 STRINGIFY(EM_SHARC)
  XLAT(EM_ECOG2),
+ #define XLAT_VAL_106 ((unsigned) (EM_ECOG2))
+ #define XLAT_STR_106 STRINGIFY(EM_ECOG2)
  XLAT(EM_SCORE7),
+ #define XLAT_VAL_107 ((unsigned) (EM_SCORE7))
+ #define XLAT_STR_107 STRINGIFY(EM_SCORE7)
  XLAT(EM_DSP24),
+ #define XLAT_VAL_108 ((unsigned) (EM_DSP24))
+ #define XLAT_STR_108 STRINGIFY(EM_DSP24)
  XLAT(EM_VIDEOCORE3),
+ #define XLAT_VAL_109 ((unsigned) (EM_VIDEOCORE3))
+ #define XLAT_STR_109 STRINGIFY(EM_VIDEOCORE3)
  XLAT(EM_LATTICEMICO32),
+ #define XLAT_VAL_110 ((unsigned) (EM_LATTICEMICO32))
+ #define XLAT_STR_110 STRINGIFY(EM_LATTICEMICO32)
  XLAT(EM_SE_C17),
+ #define XLAT_VAL_111 ((unsigned) (EM_SE_C17))
+ #define XLAT_STR_111 STRINGIFY(EM_SE_C17)
  XLAT(EM_TI_C6000),
+ #define XLAT_VAL_112 ((unsigned) (EM_TI_C6000))
+ #define XLAT_STR_112 STRINGIFY(EM_TI_C6000)
  XLAT(EM_TI_C2000),
+ #define XLAT_VAL_113 ((unsigned) (EM_TI_C2000))
+ #define XLAT_STR_113 STRINGIFY(EM_TI_C2000)
  XLAT(EM_TI_C5500),
+ #define XLAT_VAL_114 ((unsigned) (EM_TI_C5500))
+ #define XLAT_STR_114 STRINGIFY(EM_TI_C5500)
  XLAT(EM_TI_ARP32),
+ #define XLAT_VAL_115 ((unsigned) (EM_TI_ARP32))
+ #define XLAT_STR_115 STRINGIFY(EM_TI_ARP32)
  XLAT(EM_TI_PRU),
+ #define XLAT_VAL_116 ((unsigned) (EM_TI_PRU))
+ #define XLAT_STR_116 STRINGIFY(EM_TI_PRU)
 
  XLAT(EM_MMDSP_PLUS),
+ #define XLAT_VAL_117 ((unsigned) (EM_MMDSP_PLUS))
+ #define XLAT_STR_117 STRINGIFY(EM_MMDSP_PLUS)
  XLAT(EM_CYPRESS_M8C),
+ #define XLAT_VAL_118 ((unsigned) (EM_CYPRESS_M8C))
+ #define XLAT_STR_118 STRINGIFY(EM_CYPRESS_M8C)
  XLAT(EM_R32C),
+ #define XLAT_VAL_119 ((unsigned) (EM_R32C))
+ #define XLAT_STR_119 STRINGIFY(EM_R32C)
  XLAT(EM_TRIMEDIA),
+ #define XLAT_VAL_120 ((unsigned) (EM_TRIMEDIA))
+ #define XLAT_STR_120 STRINGIFY(EM_TRIMEDIA)
  XLAT(EM_HEXAGON),
+ #define XLAT_VAL_121 ((unsigned) (EM_HEXAGON))
+ #define XLAT_STR_121 STRINGIFY(EM_HEXAGON)
  XLAT(EM_8051),
+ #define XLAT_VAL_122 ((unsigned) (EM_8051))
+ #define XLAT_STR_122 STRINGIFY(EM_8051)
  XLAT(EM_STXP7X),
+ #define XLAT_VAL_123 ((unsigned) (EM_STXP7X))
+ #define XLAT_STR_123 STRINGIFY(EM_STXP7X)
  XLAT(EM_NDS32),
+ #define XLAT_VAL_124 ((unsigned) (EM_NDS32))
+ #define XLAT_STR_124 STRINGIFY(EM_NDS32)
  XLAT(EM_ECOG1X),
+ #define XLAT_VAL_125 ((unsigned) (EM_ECOG1X))
+ #define XLAT_STR_125 STRINGIFY(EM_ECOG1X)
  XLAT(EM_MAXQ30),
+ #define XLAT_VAL_126 ((unsigned) (EM_MAXQ30))
+ #define XLAT_STR_126 STRINGIFY(EM_MAXQ30)
  XLAT(EM_XIMO16),
+ #define XLAT_VAL_127 ((unsigned) (EM_XIMO16))
+ #define XLAT_STR_127 STRINGIFY(EM_XIMO16)
  XLAT(EM_MANIK),
+ #define XLAT_VAL_128 ((unsigned) (EM_MANIK))
+ #define XLAT_STR_128 STRINGIFY(EM_MANIK)
  XLAT(EM_CRAYNV2),
+ #define XLAT_VAL_129 ((unsigned) (EM_CRAYNV2))
+ #define XLAT_STR_129 STRINGIFY(EM_CRAYNV2)
  XLAT(EM_RX),
+ #define XLAT_VAL_130 ((unsigned) (EM_RX))
+ #define XLAT_STR_130 STRINGIFY(EM_RX)
  XLAT(EM_METAG),
+ #define XLAT_VAL_131 ((unsigned) (EM_METAG))
+ #define XLAT_STR_131 STRINGIFY(EM_METAG)
  XLAT(EM_MCST_ELBRUS),
+ #define XLAT_VAL_132 ((unsigned) (EM_MCST_ELBRUS))
+ #define XLAT_STR_132 STRINGIFY(EM_MCST_ELBRUS)
  XLAT(EM_ECOG16),
+ #define XLAT_VAL_133 ((unsigned) (EM_ECOG16))
+ #define XLAT_STR_133 STRINGIFY(EM_ECOG16)
  XLAT(EM_CR16),
+ #define XLAT_VAL_134 ((unsigned) (EM_CR16))
+ #define XLAT_STR_134 STRINGIFY(EM_CR16)
  XLAT(EM_ETPU),
+ #define XLAT_VAL_135 ((unsigned) (EM_ETPU))
+ #define XLAT_STR_135 STRINGIFY(EM_ETPU)
  XLAT(EM_SLE9X),
+ #define XLAT_VAL_136 ((unsigned) (EM_SLE9X))
+ #define XLAT_STR_136 STRINGIFY(EM_SLE9X)
  XLAT(EM_L10M),
+ #define XLAT_VAL_137 ((unsigned) (EM_L10M))
+ #define XLAT_STR_137 STRINGIFY(EM_L10M)
  XLAT(EM_K10M),
+ #define XLAT_VAL_138 ((unsigned) (EM_K10M))
+ #define XLAT_STR_138 STRINGIFY(EM_K10M)
 
  XLAT(EM_AARCH64),
+ #define XLAT_VAL_139 ((unsigned) (EM_AARCH64))
+ #define XLAT_STR_139 STRINGIFY(EM_AARCH64)
 
 
  XLAT(EM_STM8),
+ #define XLAT_VAL_140 ((unsigned) (EM_STM8))
+ #define XLAT_STR_140 STRINGIFY(EM_STM8)
  XLAT(EM_TILE64),
+ #define XLAT_VAL_141 ((unsigned) (EM_TILE64))
+ #define XLAT_STR_141 STRINGIFY(EM_TILE64)
  XLAT(EM_TILEPRO),
+ #define XLAT_VAL_142 ((unsigned) (EM_TILEPRO))
+ #define XLAT_STR_142 STRINGIFY(EM_TILEPRO)
  XLAT(EM_MICROBLAZE),
+ #define XLAT_VAL_143 ((unsigned) (EM_MICROBLAZE))
+ #define XLAT_STR_143 STRINGIFY(EM_MICROBLAZE)
  XLAT(EM_CUDA),
+ #define XLAT_VAL_144 ((unsigned) (EM_CUDA))
+ #define XLAT_STR_144 STRINGIFY(EM_CUDA)
  XLAT(EM_TILEGX),
+ #define XLAT_VAL_145 ((unsigned) (EM_TILEGX))
+ #define XLAT_STR_145 STRINGIFY(EM_TILEGX)
  XLAT(EM_CLOUDSHIELD),
+ #define XLAT_VAL_146 ((unsigned) (EM_CLOUDSHIELD))
+ #define XLAT_STR_146 STRINGIFY(EM_CLOUDSHIELD)
  XLAT(EM_COREA_1ST),
+ #define XLAT_VAL_147 ((unsigned) (EM_COREA_1ST))
+ #define XLAT_STR_147 STRINGIFY(EM_COREA_1ST)
  XLAT(EM_COREA_2ND),
+ #define XLAT_VAL_148 ((unsigned) (EM_COREA_2ND))
+ #define XLAT_STR_148 STRINGIFY(EM_COREA_2ND)
  XLAT(EM_ARCV2),
+ #define XLAT_VAL_149 ((unsigned) (EM_ARCV2))
+ #define XLAT_STR_149 STRINGIFY(EM_ARCV2)
  XLAT(EM_OPEN8),
+ #define XLAT_VAL_150 ((unsigned) (EM_OPEN8))
+ #define XLAT_STR_150 STRINGIFY(EM_OPEN8)
  XLAT(EM_RL78),
+ #define XLAT_VAL_151 ((unsigned) (EM_RL78))
+ #define XLAT_STR_151 STRINGIFY(EM_RL78)
  XLAT(EM_VIDEOCORE5),
+ #define XLAT_VAL_152 ((unsigned) (EM_VIDEOCORE5))
+ #define XLAT_STR_152 STRINGIFY(EM_VIDEOCORE5)
  XLAT(EM_78KOR),
+ #define XLAT_VAL_153 ((unsigned) (EM_78KOR))
+ #define XLAT_STR_153 STRINGIFY(EM_78KOR)
  XLAT(EM_56800EX),
+ #define XLAT_VAL_154 ((unsigned) (EM_56800EX))
+ #define XLAT_STR_154 STRINGIFY(EM_56800EX)
  XLAT(EM_BA1),
+ #define XLAT_VAL_155 ((unsigned) (EM_BA1))
+ #define XLAT_STR_155 STRINGIFY(EM_BA1)
  XLAT(EM_BA2),
+ #define XLAT_VAL_156 ((unsigned) (EM_BA2))
+ #define XLAT_STR_156 STRINGIFY(EM_BA2)
  XLAT(EM_XCORE),
+ #define XLAT_VAL_157 ((unsigned) (EM_XCORE))
+ #define XLAT_STR_157 STRINGIFY(EM_XCORE)
  XLAT(EM_MCHP_PIC),
+ #define XLAT_VAL_158 ((unsigned) (EM_MCHP_PIC))
+ #define XLAT_STR_158 STRINGIFY(EM_MCHP_PIC)
 
  XLAT(EM_KM32),
+ #define XLAT_VAL_159 ((unsigned) (EM_KM32))
+ #define XLAT_STR_159 STRINGIFY(EM_KM32)
  XLAT(EM_KMX32),
+ #define XLAT_VAL_160 ((unsigned) (EM_KMX32))
+ #define XLAT_STR_160 STRINGIFY(EM_KMX32)
  XLAT(EM_KMX16),
+ #define XLAT_VAL_161 ((unsigned) (EM_KMX16))
+ #define XLAT_STR_161 STRINGIFY(EM_KMX16)
  XLAT(EM_KMX8),
+ #define XLAT_VAL_162 ((unsigned) (EM_KMX8))
+ #define XLAT_STR_162 STRINGIFY(EM_KMX8)
  XLAT(EM_KVARC),
+ #define XLAT_VAL_163 ((unsigned) (EM_KVARC))
+ #define XLAT_STR_163 STRINGIFY(EM_KVARC)
  XLAT(EM_CDP),
+ #define XLAT_VAL_164 ((unsigned) (EM_CDP))
+ #define XLAT_STR_164 STRINGIFY(EM_CDP)
  XLAT(EM_COGE),
+ #define XLAT_VAL_165 ((unsigned) (EM_COGE))
+ #define XLAT_STR_165 STRINGIFY(EM_COGE)
  XLAT(EM_COOL),
+ #define XLAT_VAL_166 ((unsigned) (EM_COOL))
+ #define XLAT_STR_166 STRINGIFY(EM_COOL)
  XLAT(EM_NORC),
+ #define XLAT_VAL_167 ((unsigned) (EM_NORC))
+ #define XLAT_STR_167 STRINGIFY(EM_NORC)
  XLAT(EM_CSR_KALIMBA),
+ #define XLAT_VAL_168 ((unsigned) (EM_CSR_KALIMBA))
+ #define XLAT_STR_168 STRINGIFY(EM_CSR_KALIMBA)
  XLAT(EM_Z80),
+ #define XLAT_VAL_169 ((unsigned) (EM_Z80))
+ #define XLAT_STR_169 STRINGIFY(EM_Z80)
  XLAT(EM_VISIUM),
+ #define XLAT_VAL_170 ((unsigned) (EM_VISIUM))
+ #define XLAT_STR_170 STRINGIFY(EM_VISIUM)
  XLAT(EM_FT32),
+ #define XLAT_VAL_171 ((unsigned) (EM_FT32))
+ #define XLAT_STR_171 STRINGIFY(EM_FT32)
  XLAT(EM_MOXIE),
+ #define XLAT_VAL_172 ((unsigned) (EM_MOXIE))
+ #define XLAT_STR_172 STRINGIFY(EM_MOXIE)
  XLAT(EM_AMDGPU),
+ #define XLAT_VAL_173 ((unsigned) (EM_AMDGPU))
+ #define XLAT_STR_173 STRINGIFY(EM_AMDGPU)
  XLAT(EM_RISCV),
+ #define XLAT_VAL_174 ((unsigned) (EM_RISCV))
+ #define XLAT_STR_174 STRINGIFY(EM_RISCV)
  XLAT(EM_BPF),
+ #define XLAT_VAL_175 ((unsigned) (EM_BPF))
+ #define XLAT_STR_175 STRINGIFY(EM_BPF)
  XLAT(EM_CSKY),
+ #define XLAT_VAL_176 ((unsigned) (EM_CSKY))
+ #define XLAT_STR_176 STRINGIFY(EM_CSKY)
  XLAT(EM_AVR32),
+ #define XLAT_VAL_177 ((unsigned) (EM_AVR32))
+ #define XLAT_STR_177 STRINGIFY(EM_AVR32)
  XLAT(EM_FRV),
+ #define XLAT_VAL_178 ((unsigned) (EM_FRV))
+ #define XLAT_STR_178 STRINGIFY(EM_FRV)
  XLAT(EM_OR32),
+ #define XLAT_VAL_179 ((unsigned) (EM_OR32))
+ #define XLAT_STR_179 STRINGIFY(EM_OR32)
  XLAT(EM_ALPHA),
+ #define XLAT_VAL_180 ((unsigned) (EM_ALPHA))
+ #define XLAT_STR_180 STRINGIFY(EM_ALPHA)
  XLAT(EM_CYGNUS_V850),
+ #define XLAT_VAL_181 ((unsigned) (EM_CYGNUS_V850))
+ #define XLAT_STR_181 STRINGIFY(EM_CYGNUS_V850)
  XLAT(EM_CYGNUS_M32R),
+ #define XLAT_VAL_182 ((unsigned) (EM_CYGNUS_M32R))
+ #define XLAT_STR_182 STRINGIFY(EM_CYGNUS_M32R)
  XLAT(EM_S390_OLD),
+ #define XLAT_VAL_183 ((unsigned) (EM_S390_OLD))
+ #define XLAT_STR_183 STRINGIFY(EM_S390_OLD)
  XLAT(EM_XTENSA_OLD),
+ #define XLAT_VAL_184 ((unsigned) (EM_XTENSA_OLD))
+ #define XLAT_STR_184 STRINGIFY(EM_XTENSA_OLD)
  XLAT(EM_MICROBLAZE_OLD),
+ #define XLAT_VAL_185 ((unsigned) (EM_MICROBLAZE_OLD))
+ #define XLAT_STR_185 STRINGIFY(EM_MICROBLAZE_OLD)
  XLAT(EM_CYGNUS_MN10300),
+ #define XLAT_VAL_186 ((unsigned) (EM_CYGNUS_MN10300))
+ #define XLAT_STR_186 STRINGIFY(EM_CYGNUS_MN10300)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -1531,8 +1905,1508 @@ const struct xlat elf_em[1] = { {
  .data = elf_em_xdata,
  .size = ARRAY_SIZE(elf_em_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+#  ifdef XLAT_VAL_47
+  | XLAT_VAL_47
+#  endif
+#  ifdef XLAT_VAL_48
+  | XLAT_VAL_48
+#  endif
+#  ifdef XLAT_VAL_49
+  | XLAT_VAL_49
+#  endif
+#  ifdef XLAT_VAL_50
+  | XLAT_VAL_50
+#  endif
+#  ifdef XLAT_VAL_51
+  | XLAT_VAL_51
+#  endif
+#  ifdef XLAT_VAL_52
+  | XLAT_VAL_52
+#  endif
+#  ifdef XLAT_VAL_53
+  | XLAT_VAL_53
+#  endif
+#  ifdef XLAT_VAL_54
+  | XLAT_VAL_54
+#  endif
+#  ifdef XLAT_VAL_55
+  | XLAT_VAL_55
+#  endif
+#  ifdef XLAT_VAL_56
+  | XLAT_VAL_56
+#  endif
+#  ifdef XLAT_VAL_57
+  | XLAT_VAL_57
+#  endif
+#  ifdef XLAT_VAL_58
+  | XLAT_VAL_58
+#  endif
+#  ifdef XLAT_VAL_59
+  | XLAT_VAL_59
+#  endif
+#  ifdef XLAT_VAL_60
+  | XLAT_VAL_60
+#  endif
+#  ifdef XLAT_VAL_61
+  | XLAT_VAL_61
+#  endif
+#  ifdef XLAT_VAL_62
+  | XLAT_VAL_62
+#  endif
+#  ifdef XLAT_VAL_63
+  | XLAT_VAL_63
+#  endif
+#  ifdef XLAT_VAL_64
+  | XLAT_VAL_64
+#  endif
+#  ifdef XLAT_VAL_65
+  | XLAT_VAL_65
+#  endif
+#  ifdef XLAT_VAL_66
+  | XLAT_VAL_66
+#  endif
+#  ifdef XLAT_VAL_67
+  | XLAT_VAL_67
+#  endif
+#  ifdef XLAT_VAL_68
+  | XLAT_VAL_68
+#  endif
+#  ifdef XLAT_VAL_69
+  | XLAT_VAL_69
+#  endif
+#  ifdef XLAT_VAL_70
+  | XLAT_VAL_70
+#  endif
+#  ifdef XLAT_VAL_71
+  | XLAT_VAL_71
+#  endif
+#  ifdef XLAT_VAL_72
+  | XLAT_VAL_72
+#  endif
+#  ifdef XLAT_VAL_73
+  | XLAT_VAL_73
+#  endif
+#  ifdef XLAT_VAL_74
+  | XLAT_VAL_74
+#  endif
+#  ifdef XLAT_VAL_75
+  | XLAT_VAL_75
+#  endif
+#  ifdef XLAT_VAL_76
+  | XLAT_VAL_76
+#  endif
+#  ifdef XLAT_VAL_77
+  | XLAT_VAL_77
+#  endif
+#  ifdef XLAT_VAL_78
+  | XLAT_VAL_78
+#  endif
+#  ifdef XLAT_VAL_79
+  | XLAT_VAL_79
+#  endif
+#  ifdef XLAT_VAL_80
+  | XLAT_VAL_80
+#  endif
+#  ifdef XLAT_VAL_81
+  | XLAT_VAL_81
+#  endif
+#  ifdef XLAT_VAL_82
+  | XLAT_VAL_82
+#  endif
+#  ifdef XLAT_VAL_83
+  | XLAT_VAL_83
+#  endif
+#  ifdef XLAT_VAL_84
+  | XLAT_VAL_84
+#  endif
+#  ifdef XLAT_VAL_85
+  | XLAT_VAL_85
+#  endif
+#  ifdef XLAT_VAL_86
+  | XLAT_VAL_86
+#  endif
+#  ifdef XLAT_VAL_87
+  | XLAT_VAL_87
+#  endif
+#  ifdef XLAT_VAL_88
+  | XLAT_VAL_88
+#  endif
+#  ifdef XLAT_VAL_89
+  | XLAT_VAL_89
+#  endif
+#  ifdef XLAT_VAL_90
+  | XLAT_VAL_90
+#  endif
+#  ifdef XLAT_VAL_91
+  | XLAT_VAL_91
+#  endif
+#  ifdef XLAT_VAL_92
+  | XLAT_VAL_92
+#  endif
+#  ifdef XLAT_VAL_93
+  | XLAT_VAL_93
+#  endif
+#  ifdef XLAT_VAL_94
+  | XLAT_VAL_94
+#  endif
+#  ifdef XLAT_VAL_95
+  | XLAT_VAL_95
+#  endif
+#  ifdef XLAT_VAL_96
+  | XLAT_VAL_96
+#  endif
+#  ifdef XLAT_VAL_97
+  | XLAT_VAL_97
+#  endif
+#  ifdef XLAT_VAL_98
+  | XLAT_VAL_98
+#  endif
+#  ifdef XLAT_VAL_99
+  | XLAT_VAL_99
+#  endif
+#  ifdef XLAT_VAL_100
+  | XLAT_VAL_100
+#  endif
+#  ifdef XLAT_VAL_101
+  | XLAT_VAL_101
+#  endif
+#  ifdef XLAT_VAL_102
+  | XLAT_VAL_102
+#  endif
+#  ifdef XLAT_VAL_103
+  | XLAT_VAL_103
+#  endif
+#  ifdef XLAT_VAL_104
+  | XLAT_VAL_104
+#  endif
+#  ifdef XLAT_VAL_105
+  | XLAT_VAL_105
+#  endif
+#  ifdef XLAT_VAL_106
+  | XLAT_VAL_106
+#  endif
+#  ifdef XLAT_VAL_107
+  | XLAT_VAL_107
+#  endif
+#  ifdef XLAT_VAL_108
+  | XLAT_VAL_108
+#  endif
+#  ifdef XLAT_VAL_109
+  | XLAT_VAL_109
+#  endif
+#  ifdef XLAT_VAL_110
+  | XLAT_VAL_110
+#  endif
+#  ifdef XLAT_VAL_111
+  | XLAT_VAL_111
+#  endif
+#  ifdef XLAT_VAL_112
+  | XLAT_VAL_112
+#  endif
+#  ifdef XLAT_VAL_113
+  | XLAT_VAL_113
+#  endif
+#  ifdef XLAT_VAL_114
+  | XLAT_VAL_114
+#  endif
+#  ifdef XLAT_VAL_115
+  | XLAT_VAL_115
+#  endif
+#  ifdef XLAT_VAL_116
+  | XLAT_VAL_116
+#  endif
+#  ifdef XLAT_VAL_117
+  | XLAT_VAL_117
+#  endif
+#  ifdef XLAT_VAL_118
+  | XLAT_VAL_118
+#  endif
+#  ifdef XLAT_VAL_119
+  | XLAT_VAL_119
+#  endif
+#  ifdef XLAT_VAL_120
+  | XLAT_VAL_120
+#  endif
+#  ifdef XLAT_VAL_121
+  | XLAT_VAL_121
+#  endif
+#  ifdef XLAT_VAL_122
+  | XLAT_VAL_122
+#  endif
+#  ifdef XLAT_VAL_123
+  | XLAT_VAL_123
+#  endif
+#  ifdef XLAT_VAL_124
+  | XLAT_VAL_124
+#  endif
+#  ifdef XLAT_VAL_125
+  | XLAT_VAL_125
+#  endif
+#  ifdef XLAT_VAL_126
+  | XLAT_VAL_126
+#  endif
+#  ifdef XLAT_VAL_127
+  | XLAT_VAL_127
+#  endif
+#  ifdef XLAT_VAL_128
+  | XLAT_VAL_128
+#  endif
+#  ifdef XLAT_VAL_129
+  | XLAT_VAL_129
+#  endif
+#  ifdef XLAT_VAL_130
+  | XLAT_VAL_130
+#  endif
+#  ifdef XLAT_VAL_131
+  | XLAT_VAL_131
+#  endif
+#  ifdef XLAT_VAL_132
+  | XLAT_VAL_132
+#  endif
+#  ifdef XLAT_VAL_133
+  | XLAT_VAL_133
+#  endif
+#  ifdef XLAT_VAL_134
+  | XLAT_VAL_134
+#  endif
+#  ifdef XLAT_VAL_135
+  | XLAT_VAL_135
+#  endif
+#  ifdef XLAT_VAL_136
+  | XLAT_VAL_136
+#  endif
+#  ifdef XLAT_VAL_137
+  | XLAT_VAL_137
+#  endif
+#  ifdef XLAT_VAL_138
+  | XLAT_VAL_138
+#  endif
+#  ifdef XLAT_VAL_139
+  | XLAT_VAL_139
+#  endif
+#  ifdef XLAT_VAL_140
+  | XLAT_VAL_140
+#  endif
+#  ifdef XLAT_VAL_141
+  | XLAT_VAL_141
+#  endif
+#  ifdef XLAT_VAL_142
+  | XLAT_VAL_142
+#  endif
+#  ifdef XLAT_VAL_143
+  | XLAT_VAL_143
+#  endif
+#  ifdef XLAT_VAL_144
+  | XLAT_VAL_144
+#  endif
+#  ifdef XLAT_VAL_145
+  | XLAT_VAL_145
+#  endif
+#  ifdef XLAT_VAL_146
+  | XLAT_VAL_146
+#  endif
+#  ifdef XLAT_VAL_147
+  | XLAT_VAL_147
+#  endif
+#  ifdef XLAT_VAL_148
+  | XLAT_VAL_148
+#  endif
+#  ifdef XLAT_VAL_149
+  | XLAT_VAL_149
+#  endif
+#  ifdef XLAT_VAL_150
+  | XLAT_VAL_150
+#  endif
+#  ifdef XLAT_VAL_151
+  | XLAT_VAL_151
+#  endif
+#  ifdef XLAT_VAL_152
+  | XLAT_VAL_152
+#  endif
+#  ifdef XLAT_VAL_153
+  | XLAT_VAL_153
+#  endif
+#  ifdef XLAT_VAL_154
+  | XLAT_VAL_154
+#  endif
+#  ifdef XLAT_VAL_155
+  | XLAT_VAL_155
+#  endif
+#  ifdef XLAT_VAL_156
+  | XLAT_VAL_156
+#  endif
+#  ifdef XLAT_VAL_157
+  | XLAT_VAL_157
+#  endif
+#  ifdef XLAT_VAL_158
+  | XLAT_VAL_158
+#  endif
+#  ifdef XLAT_VAL_159
+  | XLAT_VAL_159
+#  endif
+#  ifdef XLAT_VAL_160
+  | XLAT_VAL_160
+#  endif
+#  ifdef XLAT_VAL_161
+  | XLAT_VAL_161
+#  endif
+#  ifdef XLAT_VAL_162
+  | XLAT_VAL_162
+#  endif
+#  ifdef XLAT_VAL_163
+  | XLAT_VAL_163
+#  endif
+#  ifdef XLAT_VAL_164
+  | XLAT_VAL_164
+#  endif
+#  ifdef XLAT_VAL_165
+  | XLAT_VAL_165
+#  endif
+#  ifdef XLAT_VAL_166
+  | XLAT_VAL_166
+#  endif
+#  ifdef XLAT_VAL_167
+  | XLAT_VAL_167
+#  endif
+#  ifdef XLAT_VAL_168
+  | XLAT_VAL_168
+#  endif
+#  ifdef XLAT_VAL_169
+  | XLAT_VAL_169
+#  endif
+#  ifdef XLAT_VAL_170
+  | XLAT_VAL_170
+#  endif
+#  ifdef XLAT_VAL_171
+  | XLAT_VAL_171
+#  endif
+#  ifdef XLAT_VAL_172
+  | XLAT_VAL_172
+#  endif
+#  ifdef XLAT_VAL_173
+  | XLAT_VAL_173
+#  endif
+#  ifdef XLAT_VAL_174
+  | XLAT_VAL_174
+#  endif
+#  ifdef XLAT_VAL_175
+  | XLAT_VAL_175
+#  endif
+#  ifdef XLAT_VAL_176
+  | XLAT_VAL_176
+#  endif
+#  ifdef XLAT_VAL_177
+  | XLAT_VAL_177
+#  endif
+#  ifdef XLAT_VAL_178
+  | XLAT_VAL_178
+#  endif
+#  ifdef XLAT_VAL_179
+  | XLAT_VAL_179
+#  endif
+#  ifdef XLAT_VAL_180
+  | XLAT_VAL_180
+#  endif
+#  ifdef XLAT_VAL_181
+  | XLAT_VAL_181
+#  endif
+#  ifdef XLAT_VAL_182
+  | XLAT_VAL_182
+#  endif
+#  ifdef XLAT_VAL_183
+  | XLAT_VAL_183
+#  endif
+#  ifdef XLAT_VAL_184
+  | XLAT_VAL_184
+#  endif
+#  ifdef XLAT_VAL_185
+  | XLAT_VAL_185
+#  endif
+#  ifdef XLAT_VAL_186
+  | XLAT_VAL_186
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+#  ifdef XLAT_STR_47
+  + sizeof(XLAT_STR_47)
+#  endif
+#  ifdef XLAT_STR_48
+  + sizeof(XLAT_STR_48)
+#  endif
+#  ifdef XLAT_STR_49
+  + sizeof(XLAT_STR_49)
+#  endif
+#  ifdef XLAT_STR_50
+  + sizeof(XLAT_STR_50)
+#  endif
+#  ifdef XLAT_STR_51
+  + sizeof(XLAT_STR_51)
+#  endif
+#  ifdef XLAT_STR_52
+  + sizeof(XLAT_STR_52)
+#  endif
+#  ifdef XLAT_STR_53
+  + sizeof(XLAT_STR_53)
+#  endif
+#  ifdef XLAT_STR_54
+  + sizeof(XLAT_STR_54)
+#  endif
+#  ifdef XLAT_STR_55
+  + sizeof(XLAT_STR_55)
+#  endif
+#  ifdef XLAT_STR_56
+  + sizeof(XLAT_STR_56)
+#  endif
+#  ifdef XLAT_STR_57
+  + sizeof(XLAT_STR_57)
+#  endif
+#  ifdef XLAT_STR_58
+  + sizeof(XLAT_STR_58)
+#  endif
+#  ifdef XLAT_STR_59
+  + sizeof(XLAT_STR_59)
+#  endif
+#  ifdef XLAT_STR_60
+  + sizeof(XLAT_STR_60)
+#  endif
+#  ifdef XLAT_STR_61
+  + sizeof(XLAT_STR_61)
+#  endif
+#  ifdef XLAT_STR_62
+  + sizeof(XLAT_STR_62)
+#  endif
+#  ifdef XLAT_STR_63
+  + sizeof(XLAT_STR_63)
+#  endif
+#  ifdef XLAT_STR_64
+  + sizeof(XLAT_STR_64)
+#  endif
+#  ifdef XLAT_STR_65
+  + sizeof(XLAT_STR_65)
+#  endif
+#  ifdef XLAT_STR_66
+  + sizeof(XLAT_STR_66)
+#  endif
+#  ifdef XLAT_STR_67
+  + sizeof(XLAT_STR_67)
+#  endif
+#  ifdef XLAT_STR_68
+  + sizeof(XLAT_STR_68)
+#  endif
+#  ifdef XLAT_STR_69
+  + sizeof(XLAT_STR_69)
+#  endif
+#  ifdef XLAT_STR_70
+  + sizeof(XLAT_STR_70)
+#  endif
+#  ifdef XLAT_STR_71
+  + sizeof(XLAT_STR_71)
+#  endif
+#  ifdef XLAT_STR_72
+  + sizeof(XLAT_STR_72)
+#  endif
+#  ifdef XLAT_STR_73
+  + sizeof(XLAT_STR_73)
+#  endif
+#  ifdef XLAT_STR_74
+  + sizeof(XLAT_STR_74)
+#  endif
+#  ifdef XLAT_STR_75
+  + sizeof(XLAT_STR_75)
+#  endif
+#  ifdef XLAT_STR_76
+  + sizeof(XLAT_STR_76)
+#  endif
+#  ifdef XLAT_STR_77
+  + sizeof(XLAT_STR_77)
+#  endif
+#  ifdef XLAT_STR_78
+  + sizeof(XLAT_STR_78)
+#  endif
+#  ifdef XLAT_STR_79
+  + sizeof(XLAT_STR_79)
+#  endif
+#  ifdef XLAT_STR_80
+  + sizeof(XLAT_STR_80)
+#  endif
+#  ifdef XLAT_STR_81
+  + sizeof(XLAT_STR_81)
+#  endif
+#  ifdef XLAT_STR_82
+  + sizeof(XLAT_STR_82)
+#  endif
+#  ifdef XLAT_STR_83
+  + sizeof(XLAT_STR_83)
+#  endif
+#  ifdef XLAT_STR_84
+  + sizeof(XLAT_STR_84)
+#  endif
+#  ifdef XLAT_STR_85
+  + sizeof(XLAT_STR_85)
+#  endif
+#  ifdef XLAT_STR_86
+  + sizeof(XLAT_STR_86)
+#  endif
+#  ifdef XLAT_STR_87
+  + sizeof(XLAT_STR_87)
+#  endif
+#  ifdef XLAT_STR_88
+  + sizeof(XLAT_STR_88)
+#  endif
+#  ifdef XLAT_STR_89
+  + sizeof(XLAT_STR_89)
+#  endif
+#  ifdef XLAT_STR_90
+  + sizeof(XLAT_STR_90)
+#  endif
+#  ifdef XLAT_STR_91
+  + sizeof(XLAT_STR_91)
+#  endif
+#  ifdef XLAT_STR_92
+  + sizeof(XLAT_STR_92)
+#  endif
+#  ifdef XLAT_STR_93
+  + sizeof(XLAT_STR_93)
+#  endif
+#  ifdef XLAT_STR_94
+  + sizeof(XLAT_STR_94)
+#  endif
+#  ifdef XLAT_STR_95
+  + sizeof(XLAT_STR_95)
+#  endif
+#  ifdef XLAT_STR_96
+  + sizeof(XLAT_STR_96)
+#  endif
+#  ifdef XLAT_STR_97
+  + sizeof(XLAT_STR_97)
+#  endif
+#  ifdef XLAT_STR_98
+  + sizeof(XLAT_STR_98)
+#  endif
+#  ifdef XLAT_STR_99
+  + sizeof(XLAT_STR_99)
+#  endif
+#  ifdef XLAT_STR_100
+  + sizeof(XLAT_STR_100)
+#  endif
+#  ifdef XLAT_STR_101
+  + sizeof(XLAT_STR_101)
+#  endif
+#  ifdef XLAT_STR_102
+  + sizeof(XLAT_STR_102)
+#  endif
+#  ifdef XLAT_STR_103
+  + sizeof(XLAT_STR_103)
+#  endif
+#  ifdef XLAT_STR_104
+  + sizeof(XLAT_STR_104)
+#  endif
+#  ifdef XLAT_STR_105
+  + sizeof(XLAT_STR_105)
+#  endif
+#  ifdef XLAT_STR_106
+  + sizeof(XLAT_STR_106)
+#  endif
+#  ifdef XLAT_STR_107
+  + sizeof(XLAT_STR_107)
+#  endif
+#  ifdef XLAT_STR_108
+  + sizeof(XLAT_STR_108)
+#  endif
+#  ifdef XLAT_STR_109
+  + sizeof(XLAT_STR_109)
+#  endif
+#  ifdef XLAT_STR_110
+  + sizeof(XLAT_STR_110)
+#  endif
+#  ifdef XLAT_STR_111
+  + sizeof(XLAT_STR_111)
+#  endif
+#  ifdef XLAT_STR_112
+  + sizeof(XLAT_STR_112)
+#  endif
+#  ifdef XLAT_STR_113
+  + sizeof(XLAT_STR_113)
+#  endif
+#  ifdef XLAT_STR_114
+  + sizeof(XLAT_STR_114)
+#  endif
+#  ifdef XLAT_STR_115
+  + sizeof(XLAT_STR_115)
+#  endif
+#  ifdef XLAT_STR_116
+  + sizeof(XLAT_STR_116)
+#  endif
+#  ifdef XLAT_STR_117
+  + sizeof(XLAT_STR_117)
+#  endif
+#  ifdef XLAT_STR_118
+  + sizeof(XLAT_STR_118)
+#  endif
+#  ifdef XLAT_STR_119
+  + sizeof(XLAT_STR_119)
+#  endif
+#  ifdef XLAT_STR_120
+  + sizeof(XLAT_STR_120)
+#  endif
+#  ifdef XLAT_STR_121
+  + sizeof(XLAT_STR_121)
+#  endif
+#  ifdef XLAT_STR_122
+  + sizeof(XLAT_STR_122)
+#  endif
+#  ifdef XLAT_STR_123
+  + sizeof(XLAT_STR_123)
+#  endif
+#  ifdef XLAT_STR_124
+  + sizeof(XLAT_STR_124)
+#  endif
+#  ifdef XLAT_STR_125
+  + sizeof(XLAT_STR_125)
+#  endif
+#  ifdef XLAT_STR_126
+  + sizeof(XLAT_STR_126)
+#  endif
+#  ifdef XLAT_STR_127
+  + sizeof(XLAT_STR_127)
+#  endif
+#  ifdef XLAT_STR_128
+  + sizeof(XLAT_STR_128)
+#  endif
+#  ifdef XLAT_STR_129
+  + sizeof(XLAT_STR_129)
+#  endif
+#  ifdef XLAT_STR_130
+  + sizeof(XLAT_STR_130)
+#  endif
+#  ifdef XLAT_STR_131
+  + sizeof(XLAT_STR_131)
+#  endif
+#  ifdef XLAT_STR_132
+  + sizeof(XLAT_STR_132)
+#  endif
+#  ifdef XLAT_STR_133
+  + sizeof(XLAT_STR_133)
+#  endif
+#  ifdef XLAT_STR_134
+  + sizeof(XLAT_STR_134)
+#  endif
+#  ifdef XLAT_STR_135
+  + sizeof(XLAT_STR_135)
+#  endif
+#  ifdef XLAT_STR_136
+  + sizeof(XLAT_STR_136)
+#  endif
+#  ifdef XLAT_STR_137
+  + sizeof(XLAT_STR_137)
+#  endif
+#  ifdef XLAT_STR_138
+  + sizeof(XLAT_STR_138)
+#  endif
+#  ifdef XLAT_STR_139
+  + sizeof(XLAT_STR_139)
+#  endif
+#  ifdef XLAT_STR_140
+  + sizeof(XLAT_STR_140)
+#  endif
+#  ifdef XLAT_STR_141
+  + sizeof(XLAT_STR_141)
+#  endif
+#  ifdef XLAT_STR_142
+  + sizeof(XLAT_STR_142)
+#  endif
+#  ifdef XLAT_STR_143
+  + sizeof(XLAT_STR_143)
+#  endif
+#  ifdef XLAT_STR_144
+  + sizeof(XLAT_STR_144)
+#  endif
+#  ifdef XLAT_STR_145
+  + sizeof(XLAT_STR_145)
+#  endif
+#  ifdef XLAT_STR_146
+  + sizeof(XLAT_STR_146)
+#  endif
+#  ifdef XLAT_STR_147
+  + sizeof(XLAT_STR_147)
+#  endif
+#  ifdef XLAT_STR_148
+  + sizeof(XLAT_STR_148)
+#  endif
+#  ifdef XLAT_STR_149
+  + sizeof(XLAT_STR_149)
+#  endif
+#  ifdef XLAT_STR_150
+  + sizeof(XLAT_STR_150)
+#  endif
+#  ifdef XLAT_STR_151
+  + sizeof(XLAT_STR_151)
+#  endif
+#  ifdef XLAT_STR_152
+  + sizeof(XLAT_STR_152)
+#  endif
+#  ifdef XLAT_STR_153
+  + sizeof(XLAT_STR_153)
+#  endif
+#  ifdef XLAT_STR_154
+  + sizeof(XLAT_STR_154)
+#  endif
+#  ifdef XLAT_STR_155
+  + sizeof(XLAT_STR_155)
+#  endif
+#  ifdef XLAT_STR_156
+  + sizeof(XLAT_STR_156)
+#  endif
+#  ifdef XLAT_STR_157
+  + sizeof(XLAT_STR_157)
+#  endif
+#  ifdef XLAT_STR_158
+  + sizeof(XLAT_STR_158)
+#  endif
+#  ifdef XLAT_STR_159
+  + sizeof(XLAT_STR_159)
+#  endif
+#  ifdef XLAT_STR_160
+  + sizeof(XLAT_STR_160)
+#  endif
+#  ifdef XLAT_STR_161
+  + sizeof(XLAT_STR_161)
+#  endif
+#  ifdef XLAT_STR_162
+  + sizeof(XLAT_STR_162)
+#  endif
+#  ifdef XLAT_STR_163
+  + sizeof(XLAT_STR_163)
+#  endif
+#  ifdef XLAT_STR_164
+  + sizeof(XLAT_STR_164)
+#  endif
+#  ifdef XLAT_STR_165
+  + sizeof(XLAT_STR_165)
+#  endif
+#  ifdef XLAT_STR_166
+  + sizeof(XLAT_STR_166)
+#  endif
+#  ifdef XLAT_STR_167
+  + sizeof(XLAT_STR_167)
+#  endif
+#  ifdef XLAT_STR_168
+  + sizeof(XLAT_STR_168)
+#  endif
+#  ifdef XLAT_STR_169
+  + sizeof(XLAT_STR_169)
+#  endif
+#  ifdef XLAT_STR_170
+  + sizeof(XLAT_STR_170)
+#  endif
+#  ifdef XLAT_STR_171
+  + sizeof(XLAT_STR_171)
+#  endif
+#  ifdef XLAT_STR_172
+  + sizeof(XLAT_STR_172)
+#  endif
+#  ifdef XLAT_STR_173
+  + sizeof(XLAT_STR_173)
+#  endif
+#  ifdef XLAT_STR_174
+  + sizeof(XLAT_STR_174)
+#  endif
+#  ifdef XLAT_STR_175
+  + sizeof(XLAT_STR_175)
+#  endif
+#  ifdef XLAT_STR_176
+  + sizeof(XLAT_STR_176)
+#  endif
+#  ifdef XLAT_STR_177
+  + sizeof(XLAT_STR_177)
+#  endif
+#  ifdef XLAT_STR_178
+  + sizeof(XLAT_STR_178)
+#  endif
+#  ifdef XLAT_STR_179
+  + sizeof(XLAT_STR_179)
+#  endif
+#  ifdef XLAT_STR_180
+  + sizeof(XLAT_STR_180)
+#  endif
+#  ifdef XLAT_STR_181
+  + sizeof(XLAT_STR_181)
+#  endif
+#  ifdef XLAT_STR_182
+  + sizeof(XLAT_STR_182)
+#  endif
+#  ifdef XLAT_STR_183
+  + sizeof(XLAT_STR_183)
+#  endif
+#  ifdef XLAT_STR_184
+  + sizeof(XLAT_STR_184)
+#  endif
+#  ifdef XLAT_STR_185
+  + sizeof(XLAT_STR_185)
+#  endif
+#  ifdef XLAT_STR_186
+  + sizeof(XLAT_STR_186)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
+#  undef XLAT_STR_47
+#  undef XLAT_VAL_47
+#  undef XLAT_STR_48
+#  undef XLAT_VAL_48
+#  undef XLAT_STR_49
+#  undef XLAT_VAL_49
+#  undef XLAT_STR_50
+#  undef XLAT_VAL_50
+#  undef XLAT_STR_51
+#  undef XLAT_VAL_51
+#  undef XLAT_STR_52
+#  undef XLAT_VAL_52
+#  undef XLAT_STR_53
+#  undef XLAT_VAL_53
+#  undef XLAT_STR_54
+#  undef XLAT_VAL_54
+#  undef XLAT_STR_55
+#  undef XLAT_VAL_55
+#  undef XLAT_STR_56
+#  undef XLAT_VAL_56
+#  undef XLAT_STR_57
+#  undef XLAT_VAL_57
+#  undef XLAT_STR_58
+#  undef XLAT_VAL_58
+#  undef XLAT_STR_59
+#  undef XLAT_VAL_59
+#  undef XLAT_STR_60
+#  undef XLAT_VAL_60
+#  undef XLAT_STR_61
+#  undef XLAT_VAL_61
+#  undef XLAT_STR_62
+#  undef XLAT_VAL_62
+#  undef XLAT_STR_63
+#  undef XLAT_VAL_63
+#  undef XLAT_STR_64
+#  undef XLAT_VAL_64
+#  undef XLAT_STR_65
+#  undef XLAT_VAL_65
+#  undef XLAT_STR_66
+#  undef XLAT_VAL_66
+#  undef XLAT_STR_67
+#  undef XLAT_VAL_67
+#  undef XLAT_STR_68
+#  undef XLAT_VAL_68
+#  undef XLAT_STR_69
+#  undef XLAT_VAL_69
+#  undef XLAT_STR_70
+#  undef XLAT_VAL_70
+#  undef XLAT_STR_71
+#  undef XLAT_VAL_71
+#  undef XLAT_STR_72
+#  undef XLAT_VAL_72
+#  undef XLAT_STR_73
+#  undef XLAT_VAL_73
+#  undef XLAT_STR_74
+#  undef XLAT_VAL_74
+#  undef XLAT_STR_75
+#  undef XLAT_VAL_75
+#  undef XLAT_STR_76
+#  undef XLAT_VAL_76
+#  undef XLAT_STR_77
+#  undef XLAT_VAL_77
+#  undef XLAT_STR_78
+#  undef XLAT_VAL_78
+#  undef XLAT_STR_79
+#  undef XLAT_VAL_79
+#  undef XLAT_STR_80
+#  undef XLAT_VAL_80
+#  undef XLAT_STR_81
+#  undef XLAT_VAL_81
+#  undef XLAT_STR_82
+#  undef XLAT_VAL_82
+#  undef XLAT_STR_83
+#  undef XLAT_VAL_83
+#  undef XLAT_STR_84
+#  undef XLAT_VAL_84
+#  undef XLAT_STR_85
+#  undef XLAT_VAL_85
+#  undef XLAT_STR_86
+#  undef XLAT_VAL_86
+#  undef XLAT_STR_87
+#  undef XLAT_VAL_87
+#  undef XLAT_STR_88
+#  undef XLAT_VAL_88
+#  undef XLAT_STR_89
+#  undef XLAT_VAL_89
+#  undef XLAT_STR_90
+#  undef XLAT_VAL_90
+#  undef XLAT_STR_91
+#  undef XLAT_VAL_91
+#  undef XLAT_STR_92
+#  undef XLAT_VAL_92
+#  undef XLAT_STR_93
+#  undef XLAT_VAL_93
+#  undef XLAT_STR_94
+#  undef XLAT_VAL_94
+#  undef XLAT_STR_95
+#  undef XLAT_VAL_95
+#  undef XLAT_STR_96
+#  undef XLAT_VAL_96
+#  undef XLAT_STR_97
+#  undef XLAT_VAL_97
+#  undef XLAT_STR_98
+#  undef XLAT_VAL_98
+#  undef XLAT_STR_99
+#  undef XLAT_VAL_99
+#  undef XLAT_STR_100
+#  undef XLAT_VAL_100
+#  undef XLAT_STR_101
+#  undef XLAT_VAL_101
+#  undef XLAT_STR_102
+#  undef XLAT_VAL_102
+#  undef XLAT_STR_103
+#  undef XLAT_VAL_103
+#  undef XLAT_STR_104
+#  undef XLAT_VAL_104
+#  undef XLAT_STR_105
+#  undef XLAT_VAL_105
+#  undef XLAT_STR_106
+#  undef XLAT_VAL_106
+#  undef XLAT_STR_107
+#  undef XLAT_VAL_107
+#  undef XLAT_STR_108
+#  undef XLAT_VAL_108
+#  undef XLAT_STR_109
+#  undef XLAT_VAL_109
+#  undef XLAT_STR_110
+#  undef XLAT_VAL_110
+#  undef XLAT_STR_111
+#  undef XLAT_VAL_111
+#  undef XLAT_STR_112
+#  undef XLAT_VAL_112
+#  undef XLAT_STR_113
+#  undef XLAT_VAL_113
+#  undef XLAT_STR_114
+#  undef XLAT_VAL_114
+#  undef XLAT_STR_115
+#  undef XLAT_VAL_115
+#  undef XLAT_STR_116
+#  undef XLAT_VAL_116
+#  undef XLAT_STR_117
+#  undef XLAT_VAL_117
+#  undef XLAT_STR_118
+#  undef XLAT_VAL_118
+#  undef XLAT_STR_119
+#  undef XLAT_VAL_119
+#  undef XLAT_STR_120
+#  undef XLAT_VAL_120
+#  undef XLAT_STR_121
+#  undef XLAT_VAL_121
+#  undef XLAT_STR_122
+#  undef XLAT_VAL_122
+#  undef XLAT_STR_123
+#  undef XLAT_VAL_123
+#  undef XLAT_STR_124
+#  undef XLAT_VAL_124
+#  undef XLAT_STR_125
+#  undef XLAT_VAL_125
+#  undef XLAT_STR_126
+#  undef XLAT_VAL_126
+#  undef XLAT_STR_127
+#  undef XLAT_VAL_127
+#  undef XLAT_STR_128
+#  undef XLAT_VAL_128
+#  undef XLAT_STR_129
+#  undef XLAT_VAL_129
+#  undef XLAT_STR_130
+#  undef XLAT_VAL_130
+#  undef XLAT_STR_131
+#  undef XLAT_VAL_131
+#  undef XLAT_STR_132
+#  undef XLAT_VAL_132
+#  undef XLAT_STR_133
+#  undef XLAT_VAL_133
+#  undef XLAT_STR_134
+#  undef XLAT_VAL_134
+#  undef XLAT_STR_135
+#  undef XLAT_VAL_135
+#  undef XLAT_STR_136
+#  undef XLAT_VAL_136
+#  undef XLAT_STR_137
+#  undef XLAT_VAL_137
+#  undef XLAT_STR_138
+#  undef XLAT_VAL_138
+#  undef XLAT_STR_139
+#  undef XLAT_VAL_139
+#  undef XLAT_STR_140
+#  undef XLAT_VAL_140
+#  undef XLAT_STR_141
+#  undef XLAT_VAL_141
+#  undef XLAT_STR_142
+#  undef XLAT_VAL_142
+#  undef XLAT_STR_143
+#  undef XLAT_VAL_143
+#  undef XLAT_STR_144
+#  undef XLAT_VAL_144
+#  undef XLAT_STR_145
+#  undef XLAT_VAL_145
+#  undef XLAT_STR_146
+#  undef XLAT_VAL_146
+#  undef XLAT_STR_147
+#  undef XLAT_VAL_147
+#  undef XLAT_STR_148
+#  undef XLAT_VAL_148
+#  undef XLAT_STR_149
+#  undef XLAT_VAL_149
+#  undef XLAT_STR_150
+#  undef XLAT_VAL_150
+#  undef XLAT_STR_151
+#  undef XLAT_VAL_151
+#  undef XLAT_STR_152
+#  undef XLAT_VAL_152
+#  undef XLAT_STR_153
+#  undef XLAT_VAL_153
+#  undef XLAT_STR_154
+#  undef XLAT_VAL_154
+#  undef XLAT_STR_155
+#  undef XLAT_VAL_155
+#  undef XLAT_STR_156
+#  undef XLAT_VAL_156
+#  undef XLAT_STR_157
+#  undef XLAT_VAL_157
+#  undef XLAT_STR_158
+#  undef XLAT_VAL_158
+#  undef XLAT_STR_159
+#  undef XLAT_VAL_159
+#  undef XLAT_STR_160
+#  undef XLAT_VAL_160
+#  undef XLAT_STR_161
+#  undef XLAT_VAL_161
+#  undef XLAT_STR_162
+#  undef XLAT_VAL_162
+#  undef XLAT_STR_163
+#  undef XLAT_VAL_163
+#  undef XLAT_STR_164
+#  undef XLAT_VAL_164
+#  undef XLAT_STR_165
+#  undef XLAT_VAL_165
+#  undef XLAT_STR_166
+#  undef XLAT_VAL_166
+#  undef XLAT_STR_167
+#  undef XLAT_VAL_167
+#  undef XLAT_STR_168
+#  undef XLAT_VAL_168
+#  undef XLAT_STR_169
+#  undef XLAT_VAL_169
+#  undef XLAT_STR_170
+#  undef XLAT_VAL_170
+#  undef XLAT_STR_171
+#  undef XLAT_VAL_171
+#  undef XLAT_STR_172
+#  undef XLAT_VAL_172
+#  undef XLAT_STR_173
+#  undef XLAT_VAL_173
+#  undef XLAT_STR_174
+#  undef XLAT_VAL_174
+#  undef XLAT_STR_175
+#  undef XLAT_VAL_175
+#  undef XLAT_STR_176
+#  undef XLAT_VAL_176
+#  undef XLAT_STR_177
+#  undef XLAT_VAL_177
+#  undef XLAT_STR_178
+#  undef XLAT_VAL_178
+#  undef XLAT_STR_179
+#  undef XLAT_VAL_179
+#  undef XLAT_STR_180
+#  undef XLAT_VAL_180
+#  undef XLAT_STR_181
+#  undef XLAT_VAL_181
+#  undef XLAT_STR_182
+#  undef XLAT_VAL_182
+#  undef XLAT_STR_183
+#  undef XLAT_VAL_183
+#  undef XLAT_STR_184
+#  undef XLAT_VAL_184
+#  undef XLAT_STR_185
+#  undef XLAT_VAL_185
+#  undef XLAT_STR_186
+#  undef XLAT_VAL_186
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/epollctls.h 5.9-0ubuntu2/xlat/epollctls.h
--- 5.5-3/xlat/epollctls.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/epollctls.h	2020-09-24 09:18:44.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data epollctls_xdata[] = {
  [EPOLL_CTL_ADD] = XLAT(EPOLL_CTL_ADD),
+ #define XLAT_VAL_0 ((unsigned) (EPOLL_CTL_ADD))
+ #define XLAT_STR_0 STRINGIFY(EPOLL_CTL_ADD)
  [EPOLL_CTL_DEL] = XLAT(EPOLL_CTL_DEL),
+ #define XLAT_VAL_1 ((unsigned) (EPOLL_CTL_DEL))
+ #define XLAT_STR_1 STRINGIFY(EPOLL_CTL_DEL)
  [EPOLL_CTL_MOD] = XLAT(EPOLL_CTL_MOD),
+ #define XLAT_VAL_2 ((unsigned) (EPOLL_CTL_MOD))
+ #define XLAT_STR_2 STRINGIFY(EPOLL_CTL_MOD)
 };
 static
 const struct xlat epollctls[1] = { {
  .data = epollctls_xdata,
  .size = ARRAY_SIZE(epollctls_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/epollevents.h 5.9-0ubuntu2/xlat/epollevents.h
--- 5.5-3/xlat/epollevents.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/epollevents.h	2020-09-24 09:18:44.000000000 +0000
@@ -126,29 +126,193 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data epollevents_xdata[] = {
  XLAT(EPOLLIN),
+ #define XLAT_VAL_0 ((unsigned) (EPOLLIN))
+ #define XLAT_STR_0 STRINGIFY(EPOLLIN)
  XLAT(EPOLLPRI),
+ #define XLAT_VAL_1 ((unsigned) (EPOLLPRI))
+ #define XLAT_STR_1 STRINGIFY(EPOLLPRI)
  XLAT(EPOLLOUT),
+ #define XLAT_VAL_2 ((unsigned) (EPOLLOUT))
+ #define XLAT_STR_2 STRINGIFY(EPOLLOUT)
  XLAT(EPOLLERR),
+ #define XLAT_VAL_3 ((unsigned) (EPOLLERR))
+ #define XLAT_STR_3 STRINGIFY(EPOLLERR)
  XLAT(EPOLLHUP),
+ #define XLAT_VAL_4 ((unsigned) (EPOLLHUP))
+ #define XLAT_STR_4 STRINGIFY(EPOLLHUP)
  XLAT(EPOLLNVAL),
+ #define XLAT_VAL_5 ((unsigned) (EPOLLNVAL))
+ #define XLAT_STR_5 STRINGIFY(EPOLLNVAL)
  XLAT(EPOLLRDNORM),
+ #define XLAT_VAL_6 ((unsigned) (EPOLLRDNORM))
+ #define XLAT_STR_6 STRINGIFY(EPOLLRDNORM)
  XLAT(EPOLLRDBAND),
+ #define XLAT_VAL_7 ((unsigned) (EPOLLRDBAND))
+ #define XLAT_STR_7 STRINGIFY(EPOLLRDBAND)
  XLAT(EPOLLWRNORM),
+ #define XLAT_VAL_8 ((unsigned) (EPOLLWRNORM))
+ #define XLAT_STR_8 STRINGIFY(EPOLLWRNORM)
  XLAT(EPOLLWRBAND),
+ #define XLAT_VAL_9 ((unsigned) (EPOLLWRBAND))
+ #define XLAT_STR_9 STRINGIFY(EPOLLWRBAND)
  XLAT(EPOLLMSG),
+ #define XLAT_VAL_10 ((unsigned) (EPOLLMSG))
+ #define XLAT_STR_10 STRINGIFY(EPOLLMSG)
  XLAT(EPOLLRDHUP),
+ #define XLAT_VAL_11 ((unsigned) (EPOLLRDHUP))
+ #define XLAT_STR_11 STRINGIFY(EPOLLRDHUP)
  XLAT(EPOLLEXCLUSIVE),
+ #define XLAT_VAL_12 ((unsigned) (EPOLLEXCLUSIVE))
+ #define XLAT_STR_12 STRINGIFY(EPOLLEXCLUSIVE)
  XLAT(EPOLLWAKEUP),
+ #define XLAT_VAL_13 ((unsigned) (EPOLLWAKEUP))
+ #define XLAT_STR_13 STRINGIFY(EPOLLWAKEUP)
  XLAT(EPOLLONESHOT),
+ #define XLAT_VAL_14 ((unsigned) (EPOLLONESHOT))
+ #define XLAT_STR_14 STRINGIFY(EPOLLONESHOT)
  XLAT(EPOLLET),
+ #define XLAT_VAL_15 ((unsigned) (EPOLLET))
+ #define XLAT_STR_15 STRINGIFY(EPOLLET)
 };
 static
 const struct xlat epollevents[1] = { {
  .data = epollevents_xdata,
  .size = ARRAY_SIZE(epollevents_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/epollflags.h 5.9-0ubuntu2/xlat/epollflags.h
--- 5.5-3/xlat/epollflags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/epollflags.h	2020-09-24 09:18:44.000000000 +0000
@@ -24,6 +24,8 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 static const struct xlat_data epollflags_xdata[] = {
 #if defined EPOLL_CLOEXEC || defined O_CLOEXEC
  XLAT(EPOLL_CLOEXEC),
+ #define XLAT_VAL_0 ((unsigned) (EPOLL_CLOEXEC))
+ #define XLAT_STR_0 STRINGIFY(EPOLL_CLOEXEC)
 #endif
 };
 static
@@ -31,8 +33,20 @@ const struct xlat epollflags[1] = { {
  .data = epollflags_xdata,
  .size = ARRAY_SIZE(epollflags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ethernet_protocols.h 5.9-0ubuntu2/xlat/ethernet_protocols.h
--- 5.5-3/xlat/ethernet_protocols.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ethernet_protocols.h	2020-09-24 09:18:47.000000000 +0000
@@ -507,6 +507,13 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define ETH_P_LLDP 0x88CC
 #endif
+#if defined(ETH_P_MRP) || (defined(HAVE_DECL_ETH_P_MRP) && HAVE_DECL_ETH_P_MRP)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ETH_P_MRP) == (0x88E3), "ETH_P_MRP != 0x88E3");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ETH_P_MRP 0x88E3
+#endif
 #if defined(ETH_P_MACSEC) || (defined(HAVE_DECL_ETH_P_MACSEC) && HAVE_DECL_ETH_P_MACSEC)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
 static_assert((ETH_P_MACSEC) == (0x88E5), "ETH_P_MACSEC != 0x88E5");
@@ -661,105 +668,1050 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data ethernet_protocols_xdata[] = {
  XLAT(ETH_P_802_3),
+ #define XLAT_VAL_0 ((unsigned) (ETH_P_802_3))
+ #define XLAT_STR_0 STRINGIFY(ETH_P_802_3)
  XLAT(ETH_P_AX25),
+ #define XLAT_VAL_1 ((unsigned) (ETH_P_AX25))
+ #define XLAT_STR_1 STRINGIFY(ETH_P_AX25)
  XLAT(ETH_P_ALL),
+ #define XLAT_VAL_2 ((unsigned) (ETH_P_ALL))
+ #define XLAT_STR_2 STRINGIFY(ETH_P_ALL)
  XLAT(ETH_P_802_2),
+ #define XLAT_VAL_3 ((unsigned) (ETH_P_802_2))
+ #define XLAT_STR_3 STRINGIFY(ETH_P_802_2)
  XLAT(ETH_P_SNAP),
+ #define XLAT_VAL_4 ((unsigned) (ETH_P_SNAP))
+ #define XLAT_STR_4 STRINGIFY(ETH_P_SNAP)
  XLAT(ETH_P_DDCMP),
+ #define XLAT_VAL_5 ((unsigned) (ETH_P_DDCMP))
+ #define XLAT_STR_5 STRINGIFY(ETH_P_DDCMP)
  XLAT(ETH_P_WAN_PPP),
+ #define XLAT_VAL_6 ((unsigned) (ETH_P_WAN_PPP))
+ #define XLAT_STR_6 STRINGIFY(ETH_P_WAN_PPP)
  XLAT(ETH_P_PPP_MP),
+ #define XLAT_VAL_7 ((unsigned) (ETH_P_PPP_MP))
+ #define XLAT_STR_7 STRINGIFY(ETH_P_PPP_MP)
  XLAT(ETH_P_LOCALTALK),
+ #define XLAT_VAL_8 ((unsigned) (ETH_P_LOCALTALK))
+ #define XLAT_STR_8 STRINGIFY(ETH_P_LOCALTALK)
  XLAT(ETH_P_CAN),
+ #define XLAT_VAL_9 ((unsigned) (ETH_P_CAN))
+ #define XLAT_STR_9 STRINGIFY(ETH_P_CAN)
  XLAT(ETH_P_CANFD),
+ #define XLAT_VAL_10 ((unsigned) (ETH_P_CANFD))
+ #define XLAT_STR_10 STRINGIFY(ETH_P_CANFD)
  XLAT(ETH_P_PPPTALK),
+ #define XLAT_VAL_11 ((unsigned) (ETH_P_PPPTALK))
+ #define XLAT_STR_11 STRINGIFY(ETH_P_PPPTALK)
  XLAT(ETH_P_TR_802_2),
+ #define XLAT_VAL_12 ((unsigned) (ETH_P_TR_802_2))
+ #define XLAT_STR_12 STRINGIFY(ETH_P_TR_802_2)
  XLAT(ETH_P_MOBITEX),
+ #define XLAT_VAL_13 ((unsigned) (ETH_P_MOBITEX))
+ #define XLAT_STR_13 STRINGIFY(ETH_P_MOBITEX)
  XLAT(ETH_P_CONTROL),
+ #define XLAT_VAL_14 ((unsigned) (ETH_P_CONTROL))
+ #define XLAT_STR_14 STRINGIFY(ETH_P_CONTROL)
  XLAT(ETH_P_IRDA),
+ #define XLAT_VAL_15 ((unsigned) (ETH_P_IRDA))
+ #define XLAT_STR_15 STRINGIFY(ETH_P_IRDA)
  XLAT(ETH_P_ECONET),
+ #define XLAT_VAL_16 ((unsigned) (ETH_P_ECONET))
+ #define XLAT_STR_16 STRINGIFY(ETH_P_ECONET)
  XLAT(ETH_P_HDLC),
+ #define XLAT_VAL_17 ((unsigned) (ETH_P_HDLC))
+ #define XLAT_STR_17 STRINGIFY(ETH_P_HDLC)
  XLAT(ETH_P_ARCNET),
+ #define XLAT_VAL_18 ((unsigned) (ETH_P_ARCNET))
+ #define XLAT_STR_18 STRINGIFY(ETH_P_ARCNET)
  XLAT(ETH_P_DSA),
+ #define XLAT_VAL_19 ((unsigned) (ETH_P_DSA))
+ #define XLAT_STR_19 STRINGIFY(ETH_P_DSA)
  XLAT(ETH_P_TRAILER),
+ #define XLAT_VAL_20 ((unsigned) (ETH_P_TRAILER))
+ #define XLAT_STR_20 STRINGIFY(ETH_P_TRAILER)
  XLAT(ETH_P_LOOP),
+ #define XLAT_VAL_21 ((unsigned) (ETH_P_LOOP))
+ #define XLAT_STR_21 STRINGIFY(ETH_P_LOOP)
  XLAT(ETH_P_PHONET),
+ #define XLAT_VAL_22 ((unsigned) (ETH_P_PHONET))
+ #define XLAT_STR_22 STRINGIFY(ETH_P_PHONET)
  XLAT(ETH_P_IEEE802154),
+ #define XLAT_VAL_23 ((unsigned) (ETH_P_IEEE802154))
+ #define XLAT_STR_23 STRINGIFY(ETH_P_IEEE802154)
  XLAT(ETH_P_CAIF),
+ #define XLAT_VAL_24 ((unsigned) (ETH_P_CAIF))
+ #define XLAT_STR_24 STRINGIFY(ETH_P_CAIF)
  XLAT(ETH_P_XDSA),
+ #define XLAT_VAL_25 ((unsigned) (ETH_P_XDSA))
+ #define XLAT_STR_25 STRINGIFY(ETH_P_XDSA)
  XLAT(ETH_P_MAP),
+ #define XLAT_VAL_26 ((unsigned) (ETH_P_MAP))
+ #define XLAT_STR_26 STRINGIFY(ETH_P_MAP)
  XLAT(ETH_P_PUP),
+ #define XLAT_VAL_27 ((unsigned) (ETH_P_PUP))
+ #define XLAT_STR_27 STRINGIFY(ETH_P_PUP)
  XLAT(ETH_P_PUPAT),
+ #define XLAT_VAL_28 ((unsigned) (ETH_P_PUPAT))
+ #define XLAT_STR_28 STRINGIFY(ETH_P_PUPAT)
  XLAT(ETH_P_802_3_MIN),
+ #define XLAT_VAL_29 ((unsigned) (ETH_P_802_3_MIN))
+ #define XLAT_STR_29 STRINGIFY(ETH_P_802_3_MIN)
  XLAT(ETH_P_IP),
+ #define XLAT_VAL_30 ((unsigned) (ETH_P_IP))
+ #define XLAT_STR_30 STRINGIFY(ETH_P_IP)
  XLAT(ETH_P_X25),
+ #define XLAT_VAL_31 ((unsigned) (ETH_P_X25))
+ #define XLAT_STR_31 STRINGIFY(ETH_P_X25)
  XLAT(ETH_P_ARP),
+ #define XLAT_VAL_32 ((unsigned) (ETH_P_ARP))
+ #define XLAT_STR_32 STRINGIFY(ETH_P_ARP)
  XLAT(ETH_P_BPQ),
+ #define XLAT_VAL_33 ((unsigned) (ETH_P_BPQ))
+ #define XLAT_STR_33 STRINGIFY(ETH_P_BPQ)
  XLAT(ETH_P_IEEEPUP),
+ #define XLAT_VAL_34 ((unsigned) (ETH_P_IEEEPUP))
+ #define XLAT_STR_34 STRINGIFY(ETH_P_IEEEPUP)
  XLAT(ETH_P_IEEEPUPAT),
+ #define XLAT_VAL_35 ((unsigned) (ETH_P_IEEEPUPAT))
+ #define XLAT_STR_35 STRINGIFY(ETH_P_IEEEPUPAT)
  XLAT(ETH_P_ERSPAN2),
+ #define XLAT_VAL_36 ((unsigned) (ETH_P_ERSPAN2))
+ #define XLAT_STR_36 STRINGIFY(ETH_P_ERSPAN2)
  XLAT(ETH_P_TSN),
+ #define XLAT_VAL_37 ((unsigned) (ETH_P_TSN))
+ #define XLAT_STR_37 STRINGIFY(ETH_P_TSN)
  XLAT(ETH_P_BATMAN),
+ #define XLAT_VAL_38 ((unsigned) (ETH_P_BATMAN))
+ #define XLAT_STR_38 STRINGIFY(ETH_P_BATMAN)
  XLAT(ETH_P_DEC),
+ #define XLAT_VAL_39 ((unsigned) (ETH_P_DEC))
+ #define XLAT_STR_39 STRINGIFY(ETH_P_DEC)
  XLAT(ETH_P_DNA_DL),
+ #define XLAT_VAL_40 ((unsigned) (ETH_P_DNA_DL))
+ #define XLAT_STR_40 STRINGIFY(ETH_P_DNA_DL)
  XLAT(ETH_P_DNA_RC),
+ #define XLAT_VAL_41 ((unsigned) (ETH_P_DNA_RC))
+ #define XLAT_STR_41 STRINGIFY(ETH_P_DNA_RC)
  XLAT(ETH_P_DNA_RT),
+ #define XLAT_VAL_42 ((unsigned) (ETH_P_DNA_RT))
+ #define XLAT_STR_42 STRINGIFY(ETH_P_DNA_RT)
  XLAT(ETH_P_LAT),
+ #define XLAT_VAL_43 ((unsigned) (ETH_P_LAT))
+ #define XLAT_STR_43 STRINGIFY(ETH_P_LAT)
  XLAT(ETH_P_DIAG),
+ #define XLAT_VAL_44 ((unsigned) (ETH_P_DIAG))
+ #define XLAT_STR_44 STRINGIFY(ETH_P_DIAG)
  XLAT(ETH_P_CUST),
+ #define XLAT_VAL_45 ((unsigned) (ETH_P_CUST))
+ #define XLAT_STR_45 STRINGIFY(ETH_P_CUST)
  XLAT(ETH_P_SCA),
+ #define XLAT_VAL_46 ((unsigned) (ETH_P_SCA))
+ #define XLAT_STR_46 STRINGIFY(ETH_P_SCA)
  XLAT(ETH_P_TEB),
+ #define XLAT_VAL_47 ((unsigned) (ETH_P_TEB))
+ #define XLAT_STR_47 STRINGIFY(ETH_P_TEB)
  XLAT(ETH_P_RARP),
+ #define XLAT_VAL_48 ((unsigned) (ETH_P_RARP))
+ #define XLAT_STR_48 STRINGIFY(ETH_P_RARP)
  XLAT(ETH_P_ATALK),
+ #define XLAT_VAL_49 ((unsigned) (ETH_P_ATALK))
+ #define XLAT_STR_49 STRINGIFY(ETH_P_ATALK)
  XLAT(ETH_P_AARP),
+ #define XLAT_VAL_50 ((unsigned) (ETH_P_AARP))
+ #define XLAT_STR_50 STRINGIFY(ETH_P_AARP)
  XLAT(ETH_P_8021Q),
+ #define XLAT_VAL_51 ((unsigned) (ETH_P_8021Q))
+ #define XLAT_STR_51 STRINGIFY(ETH_P_8021Q)
  XLAT(ETH_P_IPX),
+ #define XLAT_VAL_52 ((unsigned) (ETH_P_IPX))
+ #define XLAT_STR_52 STRINGIFY(ETH_P_IPX)
  XLAT(ETH_P_IPV6),
+ #define XLAT_VAL_53 ((unsigned) (ETH_P_IPV6))
+ #define XLAT_STR_53 STRINGIFY(ETH_P_IPV6)
  XLAT(ETH_P_PAUSE),
+ #define XLAT_VAL_54 ((unsigned) (ETH_P_PAUSE))
+ #define XLAT_STR_54 STRINGIFY(ETH_P_PAUSE)
  XLAT(ETH_P_SLOW),
+ #define XLAT_VAL_55 ((unsigned) (ETH_P_SLOW))
+ #define XLAT_STR_55 STRINGIFY(ETH_P_SLOW)
  XLAT(ETH_P_WCCP),
+ #define XLAT_VAL_56 ((unsigned) (ETH_P_WCCP))
+ #define XLAT_STR_56 STRINGIFY(ETH_P_WCCP)
  XLAT(ETH_P_MPLS_UC),
+ #define XLAT_VAL_57 ((unsigned) (ETH_P_MPLS_UC))
+ #define XLAT_STR_57 STRINGIFY(ETH_P_MPLS_UC)
  XLAT(ETH_P_MPLS_MC),
+ #define XLAT_VAL_58 ((unsigned) (ETH_P_MPLS_MC))
+ #define XLAT_STR_58 STRINGIFY(ETH_P_MPLS_MC)
  XLAT(ETH_P_ATMMPOA),
+ #define XLAT_VAL_59 ((unsigned) (ETH_P_ATMMPOA))
+ #define XLAT_STR_59 STRINGIFY(ETH_P_ATMMPOA)
  XLAT(ETH_P_PPP_DISC),
+ #define XLAT_VAL_60 ((unsigned) (ETH_P_PPP_DISC))
+ #define XLAT_STR_60 STRINGIFY(ETH_P_PPP_DISC)
  XLAT(ETH_P_PPP_SES),
+ #define XLAT_VAL_61 ((unsigned) (ETH_P_PPP_SES))
+ #define XLAT_STR_61 STRINGIFY(ETH_P_PPP_SES)
  XLAT(ETH_P_LINK_CTL),
+ #define XLAT_VAL_62 ((unsigned) (ETH_P_LINK_CTL))
+ #define XLAT_STR_62 STRINGIFY(ETH_P_LINK_CTL)
  XLAT(ETH_P_ATMFATE),
+ #define XLAT_VAL_63 ((unsigned) (ETH_P_ATMFATE))
+ #define XLAT_STR_63 STRINGIFY(ETH_P_ATMFATE)
  XLAT(ETH_P_PAE),
+ #define XLAT_VAL_64 ((unsigned) (ETH_P_PAE))
+ #define XLAT_STR_64 STRINGIFY(ETH_P_PAE)
  XLAT(ETH_P_AOE),
+ #define XLAT_VAL_65 ((unsigned) (ETH_P_AOE))
+ #define XLAT_STR_65 STRINGIFY(ETH_P_AOE)
  XLAT(ETH_P_8021AD),
+ #define XLAT_VAL_66 ((unsigned) (ETH_P_8021AD))
+ #define XLAT_STR_66 STRINGIFY(ETH_P_8021AD)
  XLAT(ETH_P_802_EX1),
+ #define XLAT_VAL_67 ((unsigned) (ETH_P_802_EX1))
+ #define XLAT_STR_67 STRINGIFY(ETH_P_802_EX1)
  XLAT(ETH_P_ERSPAN),
+ #define XLAT_VAL_68 ((unsigned) (ETH_P_ERSPAN))
+ #define XLAT_STR_68 STRINGIFY(ETH_P_ERSPAN)
  XLAT(ETH_P_PREAUTH),
+ #define XLAT_VAL_69 ((unsigned) (ETH_P_PREAUTH))
+ #define XLAT_STR_69 STRINGIFY(ETH_P_PREAUTH)
  XLAT(ETH_P_TIPC),
+ #define XLAT_VAL_70 ((unsigned) (ETH_P_TIPC))
+ #define XLAT_STR_70 STRINGIFY(ETH_P_TIPC)
  XLAT(ETH_P_LLDP),
+ #define XLAT_VAL_71 ((unsigned) (ETH_P_LLDP))
+ #define XLAT_STR_71 STRINGIFY(ETH_P_LLDP)
+ XLAT(ETH_P_MRP),
+ #define XLAT_VAL_72 ((unsigned) (ETH_P_MRP))
+ #define XLAT_STR_72 STRINGIFY(ETH_P_MRP)
  XLAT(ETH_P_MACSEC),
+ #define XLAT_VAL_73 ((unsigned) (ETH_P_MACSEC))
+ #define XLAT_STR_73 STRINGIFY(ETH_P_MACSEC)
  XLAT(ETH_P_8021AH),
+ #define XLAT_VAL_74 ((unsigned) (ETH_P_8021AH))
+ #define XLAT_STR_74 STRINGIFY(ETH_P_8021AH)
  XLAT(ETH_P_MVRP),
+ #define XLAT_VAL_75 ((unsigned) (ETH_P_MVRP))
+ #define XLAT_STR_75 STRINGIFY(ETH_P_MVRP)
  XLAT(ETH_P_1588),
+ #define XLAT_VAL_76 ((unsigned) (ETH_P_1588))
+ #define XLAT_STR_76 STRINGIFY(ETH_P_1588)
  XLAT(ETH_P_NCSI),
+ #define XLAT_VAL_77 ((unsigned) (ETH_P_NCSI))
+ #define XLAT_STR_77 STRINGIFY(ETH_P_NCSI)
  XLAT(ETH_P_PRP),
+ #define XLAT_VAL_78 ((unsigned) (ETH_P_PRP))
+ #define XLAT_STR_78 STRINGIFY(ETH_P_PRP)
  XLAT(ETH_P_FCOE),
+ #define XLAT_VAL_79 ((unsigned) (ETH_P_FCOE))
+ #define XLAT_STR_79 STRINGIFY(ETH_P_FCOE)
  XLAT(ETH_P_TDLS),
+ #define XLAT_VAL_80 ((unsigned) (ETH_P_TDLS))
+ #define XLAT_STR_80 STRINGIFY(ETH_P_TDLS)
  XLAT(ETH_P_FIP),
+ #define XLAT_VAL_81 ((unsigned) (ETH_P_FIP))
+ #define XLAT_STR_81 STRINGIFY(ETH_P_FIP)
  XLAT(ETH_P_IBOE),
+ #define XLAT_VAL_82 ((unsigned) (ETH_P_IBOE))
+ #define XLAT_STR_82 STRINGIFY(ETH_P_IBOE)
  XLAT(ETH_P_80221),
+ #define XLAT_VAL_83 ((unsigned) (ETH_P_80221))
+ #define XLAT_STR_83 STRINGIFY(ETH_P_80221)
  XLAT(ETH_P_HSR),
+ #define XLAT_VAL_84 ((unsigned) (ETH_P_HSR))
+ #define XLAT_STR_84 STRINGIFY(ETH_P_HSR)
  XLAT(ETH_P_NSH),
+ #define XLAT_VAL_85 ((unsigned) (ETH_P_NSH))
+ #define XLAT_STR_85 STRINGIFY(ETH_P_NSH)
  XLAT(ETH_P_LOOPBACK),
+ #define XLAT_VAL_86 ((unsigned) (ETH_P_LOOPBACK))
+ #define XLAT_STR_86 STRINGIFY(ETH_P_LOOPBACK)
  XLAT(ETH_P_QINQ1),
+ #define XLAT_VAL_87 ((unsigned) (ETH_P_QINQ1))
+ #define XLAT_STR_87 STRINGIFY(ETH_P_QINQ1)
  XLAT(ETH_P_QINQ2),
+ #define XLAT_VAL_88 ((unsigned) (ETH_P_QINQ2))
+ #define XLAT_STR_88 STRINGIFY(ETH_P_QINQ2)
  XLAT(ETH_P_QINQ3),
+ #define XLAT_VAL_89 ((unsigned) (ETH_P_QINQ3))
+ #define XLAT_STR_89 STRINGIFY(ETH_P_QINQ3)
  XLAT(ETH_P_EDSA),
+ #define XLAT_VAL_90 ((unsigned) (ETH_P_EDSA))
+ #define XLAT_STR_90 STRINGIFY(ETH_P_EDSA)
  XLAT(ETH_P_DSA_8021Q),
+ #define XLAT_VAL_91 ((unsigned) (ETH_P_DSA_8021Q))
+ #define XLAT_STR_91 STRINGIFY(ETH_P_DSA_8021Q)
  XLAT(ETH_P_IFE),
+ #define XLAT_VAL_92 ((unsigned) (ETH_P_IFE))
+ #define XLAT_STR_92 STRINGIFY(ETH_P_IFE)
  XLAT(ETH_P_AF_IUCV),
+ #define XLAT_VAL_93 ((unsigned) (ETH_P_AF_IUCV))
+ #define XLAT_STR_93 STRINGIFY(ETH_P_AF_IUCV)
 };
 const struct xlat ethernet_protocols[1] = { {
  .data = ethernet_protocols_xdata,
  .size = ARRAY_SIZE(ethernet_protocols_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+#  ifdef XLAT_VAL_47
+  | XLAT_VAL_47
+#  endif
+#  ifdef XLAT_VAL_48
+  | XLAT_VAL_48
+#  endif
+#  ifdef XLAT_VAL_49
+  | XLAT_VAL_49
+#  endif
+#  ifdef XLAT_VAL_50
+  | XLAT_VAL_50
+#  endif
+#  ifdef XLAT_VAL_51
+  | XLAT_VAL_51
+#  endif
+#  ifdef XLAT_VAL_52
+  | XLAT_VAL_52
+#  endif
+#  ifdef XLAT_VAL_53
+  | XLAT_VAL_53
+#  endif
+#  ifdef XLAT_VAL_54
+  | XLAT_VAL_54
+#  endif
+#  ifdef XLAT_VAL_55
+  | XLAT_VAL_55
+#  endif
+#  ifdef XLAT_VAL_56
+  | XLAT_VAL_56
+#  endif
+#  ifdef XLAT_VAL_57
+  | XLAT_VAL_57
+#  endif
+#  ifdef XLAT_VAL_58
+  | XLAT_VAL_58
+#  endif
+#  ifdef XLAT_VAL_59
+  | XLAT_VAL_59
+#  endif
+#  ifdef XLAT_VAL_60
+  | XLAT_VAL_60
+#  endif
+#  ifdef XLAT_VAL_61
+  | XLAT_VAL_61
+#  endif
+#  ifdef XLAT_VAL_62
+  | XLAT_VAL_62
+#  endif
+#  ifdef XLAT_VAL_63
+  | XLAT_VAL_63
+#  endif
+#  ifdef XLAT_VAL_64
+  | XLAT_VAL_64
+#  endif
+#  ifdef XLAT_VAL_65
+  | XLAT_VAL_65
+#  endif
+#  ifdef XLAT_VAL_66
+  | XLAT_VAL_66
+#  endif
+#  ifdef XLAT_VAL_67
+  | XLAT_VAL_67
+#  endif
+#  ifdef XLAT_VAL_68
+  | XLAT_VAL_68
+#  endif
+#  ifdef XLAT_VAL_69
+  | XLAT_VAL_69
+#  endif
+#  ifdef XLAT_VAL_70
+  | XLAT_VAL_70
+#  endif
+#  ifdef XLAT_VAL_71
+  | XLAT_VAL_71
+#  endif
+#  ifdef XLAT_VAL_72
+  | XLAT_VAL_72
+#  endif
+#  ifdef XLAT_VAL_73
+  | XLAT_VAL_73
+#  endif
+#  ifdef XLAT_VAL_74
+  | XLAT_VAL_74
+#  endif
+#  ifdef XLAT_VAL_75
+  | XLAT_VAL_75
+#  endif
+#  ifdef XLAT_VAL_76
+  | XLAT_VAL_76
+#  endif
+#  ifdef XLAT_VAL_77
+  | XLAT_VAL_77
+#  endif
+#  ifdef XLAT_VAL_78
+  | XLAT_VAL_78
+#  endif
+#  ifdef XLAT_VAL_79
+  | XLAT_VAL_79
+#  endif
+#  ifdef XLAT_VAL_80
+  | XLAT_VAL_80
+#  endif
+#  ifdef XLAT_VAL_81
+  | XLAT_VAL_81
+#  endif
+#  ifdef XLAT_VAL_82
+  | XLAT_VAL_82
+#  endif
+#  ifdef XLAT_VAL_83
+  | XLAT_VAL_83
+#  endif
+#  ifdef XLAT_VAL_84
+  | XLAT_VAL_84
+#  endif
+#  ifdef XLAT_VAL_85
+  | XLAT_VAL_85
+#  endif
+#  ifdef XLAT_VAL_86
+  | XLAT_VAL_86
+#  endif
+#  ifdef XLAT_VAL_87
+  | XLAT_VAL_87
+#  endif
+#  ifdef XLAT_VAL_88
+  | XLAT_VAL_88
+#  endif
+#  ifdef XLAT_VAL_89
+  | XLAT_VAL_89
+#  endif
+#  ifdef XLAT_VAL_90
+  | XLAT_VAL_90
+#  endif
+#  ifdef XLAT_VAL_91
+  | XLAT_VAL_91
+#  endif
+#  ifdef XLAT_VAL_92
+  | XLAT_VAL_92
+#  endif
+#  ifdef XLAT_VAL_93
+  | XLAT_VAL_93
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+#  ifdef XLAT_STR_47
+  + sizeof(XLAT_STR_47)
+#  endif
+#  ifdef XLAT_STR_48
+  + sizeof(XLAT_STR_48)
+#  endif
+#  ifdef XLAT_STR_49
+  + sizeof(XLAT_STR_49)
+#  endif
+#  ifdef XLAT_STR_50
+  + sizeof(XLAT_STR_50)
+#  endif
+#  ifdef XLAT_STR_51
+  + sizeof(XLAT_STR_51)
+#  endif
+#  ifdef XLAT_STR_52
+  + sizeof(XLAT_STR_52)
+#  endif
+#  ifdef XLAT_STR_53
+  + sizeof(XLAT_STR_53)
+#  endif
+#  ifdef XLAT_STR_54
+  + sizeof(XLAT_STR_54)
+#  endif
+#  ifdef XLAT_STR_55
+  + sizeof(XLAT_STR_55)
+#  endif
+#  ifdef XLAT_STR_56
+  + sizeof(XLAT_STR_56)
+#  endif
+#  ifdef XLAT_STR_57
+  + sizeof(XLAT_STR_57)
+#  endif
+#  ifdef XLAT_STR_58
+  + sizeof(XLAT_STR_58)
+#  endif
+#  ifdef XLAT_STR_59
+  + sizeof(XLAT_STR_59)
+#  endif
+#  ifdef XLAT_STR_60
+  + sizeof(XLAT_STR_60)
+#  endif
+#  ifdef XLAT_STR_61
+  + sizeof(XLAT_STR_61)
+#  endif
+#  ifdef XLAT_STR_62
+  + sizeof(XLAT_STR_62)
+#  endif
+#  ifdef XLAT_STR_63
+  + sizeof(XLAT_STR_63)
+#  endif
+#  ifdef XLAT_STR_64
+  + sizeof(XLAT_STR_64)
+#  endif
+#  ifdef XLAT_STR_65
+  + sizeof(XLAT_STR_65)
+#  endif
+#  ifdef XLAT_STR_66
+  + sizeof(XLAT_STR_66)
+#  endif
+#  ifdef XLAT_STR_67
+  + sizeof(XLAT_STR_67)
+#  endif
+#  ifdef XLAT_STR_68
+  + sizeof(XLAT_STR_68)
+#  endif
+#  ifdef XLAT_STR_69
+  + sizeof(XLAT_STR_69)
+#  endif
+#  ifdef XLAT_STR_70
+  + sizeof(XLAT_STR_70)
+#  endif
+#  ifdef XLAT_STR_71
+  + sizeof(XLAT_STR_71)
+#  endif
+#  ifdef XLAT_STR_72
+  + sizeof(XLAT_STR_72)
+#  endif
+#  ifdef XLAT_STR_73
+  + sizeof(XLAT_STR_73)
+#  endif
+#  ifdef XLAT_STR_74
+  + sizeof(XLAT_STR_74)
+#  endif
+#  ifdef XLAT_STR_75
+  + sizeof(XLAT_STR_75)
+#  endif
+#  ifdef XLAT_STR_76
+  + sizeof(XLAT_STR_76)
+#  endif
+#  ifdef XLAT_STR_77
+  + sizeof(XLAT_STR_77)
+#  endif
+#  ifdef XLAT_STR_78
+  + sizeof(XLAT_STR_78)
+#  endif
+#  ifdef XLAT_STR_79
+  + sizeof(XLAT_STR_79)
+#  endif
+#  ifdef XLAT_STR_80
+  + sizeof(XLAT_STR_80)
+#  endif
+#  ifdef XLAT_STR_81
+  + sizeof(XLAT_STR_81)
+#  endif
+#  ifdef XLAT_STR_82
+  + sizeof(XLAT_STR_82)
+#  endif
+#  ifdef XLAT_STR_83
+  + sizeof(XLAT_STR_83)
+#  endif
+#  ifdef XLAT_STR_84
+  + sizeof(XLAT_STR_84)
+#  endif
+#  ifdef XLAT_STR_85
+  + sizeof(XLAT_STR_85)
+#  endif
+#  ifdef XLAT_STR_86
+  + sizeof(XLAT_STR_86)
+#  endif
+#  ifdef XLAT_STR_87
+  + sizeof(XLAT_STR_87)
+#  endif
+#  ifdef XLAT_STR_88
+  + sizeof(XLAT_STR_88)
+#  endif
+#  ifdef XLAT_STR_89
+  + sizeof(XLAT_STR_89)
+#  endif
+#  ifdef XLAT_STR_90
+  + sizeof(XLAT_STR_90)
+#  endif
+#  ifdef XLAT_STR_91
+  + sizeof(XLAT_STR_91)
+#  endif
+#  ifdef XLAT_STR_92
+  + sizeof(XLAT_STR_92)
+#  endif
+#  ifdef XLAT_STR_93
+  + sizeof(XLAT_STR_93)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
+#  undef XLAT_STR_47
+#  undef XLAT_VAL_47
+#  undef XLAT_STR_48
+#  undef XLAT_VAL_48
+#  undef XLAT_STR_49
+#  undef XLAT_VAL_49
+#  undef XLAT_STR_50
+#  undef XLAT_VAL_50
+#  undef XLAT_STR_51
+#  undef XLAT_VAL_51
+#  undef XLAT_STR_52
+#  undef XLAT_VAL_52
+#  undef XLAT_STR_53
+#  undef XLAT_VAL_53
+#  undef XLAT_STR_54
+#  undef XLAT_VAL_54
+#  undef XLAT_STR_55
+#  undef XLAT_VAL_55
+#  undef XLAT_STR_56
+#  undef XLAT_VAL_56
+#  undef XLAT_STR_57
+#  undef XLAT_VAL_57
+#  undef XLAT_STR_58
+#  undef XLAT_VAL_58
+#  undef XLAT_STR_59
+#  undef XLAT_VAL_59
+#  undef XLAT_STR_60
+#  undef XLAT_VAL_60
+#  undef XLAT_STR_61
+#  undef XLAT_VAL_61
+#  undef XLAT_STR_62
+#  undef XLAT_VAL_62
+#  undef XLAT_STR_63
+#  undef XLAT_VAL_63
+#  undef XLAT_STR_64
+#  undef XLAT_VAL_64
+#  undef XLAT_STR_65
+#  undef XLAT_VAL_65
+#  undef XLAT_STR_66
+#  undef XLAT_VAL_66
+#  undef XLAT_STR_67
+#  undef XLAT_VAL_67
+#  undef XLAT_STR_68
+#  undef XLAT_VAL_68
+#  undef XLAT_STR_69
+#  undef XLAT_VAL_69
+#  undef XLAT_STR_70
+#  undef XLAT_VAL_70
+#  undef XLAT_STR_71
+#  undef XLAT_VAL_71
+#  undef XLAT_STR_72
+#  undef XLAT_VAL_72
+#  undef XLAT_STR_73
+#  undef XLAT_VAL_73
+#  undef XLAT_STR_74
+#  undef XLAT_VAL_74
+#  undef XLAT_STR_75
+#  undef XLAT_VAL_75
+#  undef XLAT_STR_76
+#  undef XLAT_VAL_76
+#  undef XLAT_STR_77
+#  undef XLAT_VAL_77
+#  undef XLAT_STR_78
+#  undef XLAT_VAL_78
+#  undef XLAT_STR_79
+#  undef XLAT_VAL_79
+#  undef XLAT_STR_80
+#  undef XLAT_VAL_80
+#  undef XLAT_STR_81
+#  undef XLAT_VAL_81
+#  undef XLAT_STR_82
+#  undef XLAT_VAL_82
+#  undef XLAT_STR_83
+#  undef XLAT_VAL_83
+#  undef XLAT_STR_84
+#  undef XLAT_VAL_84
+#  undef XLAT_STR_85
+#  undef XLAT_VAL_85
+#  undef XLAT_STR_86
+#  undef XLAT_VAL_86
+#  undef XLAT_STR_87
+#  undef XLAT_VAL_87
+#  undef XLAT_STR_88
+#  undef XLAT_VAL_88
+#  undef XLAT_STR_89
+#  undef XLAT_VAL_89
+#  undef XLAT_STR_90
+#  undef XLAT_VAL_90
+#  undef XLAT_STR_91
+#  undef XLAT_VAL_91
+#  undef XLAT_STR_92
+#  undef XLAT_VAL_92
+#  undef XLAT_STR_93
+#  undef XLAT_VAL_93
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ethernet_protocols.in 5.9-0ubuntu2/xlat/ethernet_protocols.in
--- 5.5-3/xlat/ethernet_protocols.in	2019-08-13 11:06:57.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ethernet_protocols.in	2020-06-28 08:00:00.000000000 +0000
@@ -71,6 +71,7 @@ ETH_P_ERSPAN	0x88BE		/* ERSPAN type II
 ETH_P_PREAUTH	0x88C7		/* 802.11 Preauthentication	*/
 ETH_P_TIPC	0x88CA		/* TIPC				*/
 ETH_P_LLDP	0x88CC		/* Link Layer Discovery Protocol */
+ETH_P_MRP	0x88E3		/* Media Redundancy Protocol	*/
 ETH_P_MACSEC	0x88E5		/* 802.1ae MACsec */
 ETH_P_8021AH	0x88E7          /* 802.1ah Backbone Service Tag */
 ETH_P_MVRP	0x88F5          /* 802.1Q MVRP                  */
diff -pruN 5.5-3/xlat/evdev_abs.h 5.9-0ubuntu2/xlat/evdev_abs.h
--- 5.5-3/xlat/evdev_abs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/evdev_abs.h	2020-09-24 09:18:45.000000000 +0000
@@ -304,54 +304,478 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data evdev_abs_xdata[] = {
  [ABS_X] = XLAT(ABS_X),
+ #define XLAT_VAL_0 ((unsigned) (ABS_X))
+ #define XLAT_STR_0 STRINGIFY(ABS_X)
  [ABS_Y] = XLAT(ABS_Y),
+ #define XLAT_VAL_1 ((unsigned) (ABS_Y))
+ #define XLAT_STR_1 STRINGIFY(ABS_Y)
  [ABS_Z] = XLAT(ABS_Z),
+ #define XLAT_VAL_2 ((unsigned) (ABS_Z))
+ #define XLAT_STR_2 STRINGIFY(ABS_Z)
  [ABS_RX] = XLAT(ABS_RX),
+ #define XLAT_VAL_3 ((unsigned) (ABS_RX))
+ #define XLAT_STR_3 STRINGIFY(ABS_RX)
  [ABS_RY] = XLAT(ABS_RY),
+ #define XLAT_VAL_4 ((unsigned) (ABS_RY))
+ #define XLAT_STR_4 STRINGIFY(ABS_RY)
  [ABS_RZ] = XLAT(ABS_RZ),
+ #define XLAT_VAL_5 ((unsigned) (ABS_RZ))
+ #define XLAT_STR_5 STRINGIFY(ABS_RZ)
  [ABS_THROTTLE] = XLAT(ABS_THROTTLE),
+ #define XLAT_VAL_6 ((unsigned) (ABS_THROTTLE))
+ #define XLAT_STR_6 STRINGIFY(ABS_THROTTLE)
  [ABS_RUDDER] = XLAT(ABS_RUDDER),
+ #define XLAT_VAL_7 ((unsigned) (ABS_RUDDER))
+ #define XLAT_STR_7 STRINGIFY(ABS_RUDDER)
  [ABS_WHEEL] = XLAT(ABS_WHEEL),
+ #define XLAT_VAL_8 ((unsigned) (ABS_WHEEL))
+ #define XLAT_STR_8 STRINGIFY(ABS_WHEEL)
  [ABS_GAS] = XLAT(ABS_GAS),
+ #define XLAT_VAL_9 ((unsigned) (ABS_GAS))
+ #define XLAT_STR_9 STRINGIFY(ABS_GAS)
  [ABS_BRAKE] = XLAT(ABS_BRAKE),
+ #define XLAT_VAL_10 ((unsigned) (ABS_BRAKE))
+ #define XLAT_STR_10 STRINGIFY(ABS_BRAKE)
  [ABS_HAT0X] = XLAT(ABS_HAT0X),
+ #define XLAT_VAL_11 ((unsigned) (ABS_HAT0X))
+ #define XLAT_STR_11 STRINGIFY(ABS_HAT0X)
  [ABS_HAT0Y] = XLAT(ABS_HAT0Y),
+ #define XLAT_VAL_12 ((unsigned) (ABS_HAT0Y))
+ #define XLAT_STR_12 STRINGIFY(ABS_HAT0Y)
  [ABS_HAT1X] = XLAT(ABS_HAT1X),
+ #define XLAT_VAL_13 ((unsigned) (ABS_HAT1X))
+ #define XLAT_STR_13 STRINGIFY(ABS_HAT1X)
  [ABS_HAT1Y] = XLAT(ABS_HAT1Y),
+ #define XLAT_VAL_14 ((unsigned) (ABS_HAT1Y))
+ #define XLAT_STR_14 STRINGIFY(ABS_HAT1Y)
  [ABS_HAT2X] = XLAT(ABS_HAT2X),
+ #define XLAT_VAL_15 ((unsigned) (ABS_HAT2X))
+ #define XLAT_STR_15 STRINGIFY(ABS_HAT2X)
  [ABS_HAT2Y] = XLAT(ABS_HAT2Y),
+ #define XLAT_VAL_16 ((unsigned) (ABS_HAT2Y))
+ #define XLAT_STR_16 STRINGIFY(ABS_HAT2Y)
  [ABS_HAT3X] = XLAT(ABS_HAT3X),
+ #define XLAT_VAL_17 ((unsigned) (ABS_HAT3X))
+ #define XLAT_STR_17 STRINGIFY(ABS_HAT3X)
  [ABS_HAT3Y] = XLAT(ABS_HAT3Y),
+ #define XLAT_VAL_18 ((unsigned) (ABS_HAT3Y))
+ #define XLAT_STR_18 STRINGIFY(ABS_HAT3Y)
  [ABS_PRESSURE] = XLAT(ABS_PRESSURE),
+ #define XLAT_VAL_19 ((unsigned) (ABS_PRESSURE))
+ #define XLAT_STR_19 STRINGIFY(ABS_PRESSURE)
  [ABS_DISTANCE] = XLAT(ABS_DISTANCE),
+ #define XLAT_VAL_20 ((unsigned) (ABS_DISTANCE))
+ #define XLAT_STR_20 STRINGIFY(ABS_DISTANCE)
  [ABS_TILT_X] = XLAT(ABS_TILT_X),
+ #define XLAT_VAL_21 ((unsigned) (ABS_TILT_X))
+ #define XLAT_STR_21 STRINGIFY(ABS_TILT_X)
  [ABS_TILT_Y] = XLAT(ABS_TILT_Y),
+ #define XLAT_VAL_22 ((unsigned) (ABS_TILT_Y))
+ #define XLAT_STR_22 STRINGIFY(ABS_TILT_Y)
  [ABS_TOOL_WIDTH] = XLAT(ABS_TOOL_WIDTH),
+ #define XLAT_VAL_23 ((unsigned) (ABS_TOOL_WIDTH))
+ #define XLAT_STR_23 STRINGIFY(ABS_TOOL_WIDTH)
  [ABS_VOLUME] = XLAT(ABS_VOLUME),
+ #define XLAT_VAL_24 ((unsigned) (ABS_VOLUME))
+ #define XLAT_STR_24 STRINGIFY(ABS_VOLUME)
  [ABS_MISC] = XLAT(ABS_MISC),
+ #define XLAT_VAL_25 ((unsigned) (ABS_MISC))
+ #define XLAT_STR_25 STRINGIFY(ABS_MISC)
  [ABS_RESERVED] = XLAT(ABS_RESERVED),
+ #define XLAT_VAL_26 ((unsigned) (ABS_RESERVED))
+ #define XLAT_STR_26 STRINGIFY(ABS_RESERVED)
  [ABS_MT_SLOT] = XLAT(ABS_MT_SLOT),
+ #define XLAT_VAL_27 ((unsigned) (ABS_MT_SLOT))
+ #define XLAT_STR_27 STRINGIFY(ABS_MT_SLOT)
  [ABS_MT_TOUCH_MAJOR] = XLAT(ABS_MT_TOUCH_MAJOR),
+ #define XLAT_VAL_28 ((unsigned) (ABS_MT_TOUCH_MAJOR))
+ #define XLAT_STR_28 STRINGIFY(ABS_MT_TOUCH_MAJOR)
  [ABS_MT_TOUCH_MINOR] = XLAT(ABS_MT_TOUCH_MINOR),
+ #define XLAT_VAL_29 ((unsigned) (ABS_MT_TOUCH_MINOR))
+ #define XLAT_STR_29 STRINGIFY(ABS_MT_TOUCH_MINOR)
  [ABS_MT_WIDTH_MAJOR] = XLAT(ABS_MT_WIDTH_MAJOR),
+ #define XLAT_VAL_30 ((unsigned) (ABS_MT_WIDTH_MAJOR))
+ #define XLAT_STR_30 STRINGIFY(ABS_MT_WIDTH_MAJOR)
  [ABS_MT_WIDTH_MINOR] = XLAT(ABS_MT_WIDTH_MINOR),
+ #define XLAT_VAL_31 ((unsigned) (ABS_MT_WIDTH_MINOR))
+ #define XLAT_STR_31 STRINGIFY(ABS_MT_WIDTH_MINOR)
  [ABS_MT_ORIENTATION] = XLAT(ABS_MT_ORIENTATION),
+ #define XLAT_VAL_32 ((unsigned) (ABS_MT_ORIENTATION))
+ #define XLAT_STR_32 STRINGIFY(ABS_MT_ORIENTATION)
  [ABS_MT_POSITION_X] = XLAT(ABS_MT_POSITION_X),
+ #define XLAT_VAL_33 ((unsigned) (ABS_MT_POSITION_X))
+ #define XLAT_STR_33 STRINGIFY(ABS_MT_POSITION_X)
  [ABS_MT_POSITION_Y] = XLAT(ABS_MT_POSITION_Y),
+ #define XLAT_VAL_34 ((unsigned) (ABS_MT_POSITION_Y))
+ #define XLAT_STR_34 STRINGIFY(ABS_MT_POSITION_Y)
  [ABS_MT_TOOL_TYPE] = XLAT(ABS_MT_TOOL_TYPE),
+ #define XLAT_VAL_35 ((unsigned) (ABS_MT_TOOL_TYPE))
+ #define XLAT_STR_35 STRINGIFY(ABS_MT_TOOL_TYPE)
  [ABS_MT_BLOB_ID] = XLAT(ABS_MT_BLOB_ID),
+ #define XLAT_VAL_36 ((unsigned) (ABS_MT_BLOB_ID))
+ #define XLAT_STR_36 STRINGIFY(ABS_MT_BLOB_ID)
  [ABS_MT_TRACKING_ID] = XLAT(ABS_MT_TRACKING_ID),
+ #define XLAT_VAL_37 ((unsigned) (ABS_MT_TRACKING_ID))
+ #define XLAT_STR_37 STRINGIFY(ABS_MT_TRACKING_ID)
  [ABS_MT_PRESSURE] = XLAT(ABS_MT_PRESSURE),
+ #define XLAT_VAL_38 ((unsigned) (ABS_MT_PRESSURE))
+ #define XLAT_STR_38 STRINGIFY(ABS_MT_PRESSURE)
  [ABS_MT_DISTANCE] = XLAT(ABS_MT_DISTANCE),
+ #define XLAT_VAL_39 ((unsigned) (ABS_MT_DISTANCE))
+ #define XLAT_STR_39 STRINGIFY(ABS_MT_DISTANCE)
  [ABS_MT_TOOL_X] = XLAT(ABS_MT_TOOL_X),
+ #define XLAT_VAL_40 ((unsigned) (ABS_MT_TOOL_X))
+ #define XLAT_STR_40 STRINGIFY(ABS_MT_TOOL_X)
  [ABS_MT_TOOL_Y] = XLAT(ABS_MT_TOOL_Y),
+ #define XLAT_VAL_41 ((unsigned) (ABS_MT_TOOL_Y))
+ #define XLAT_STR_41 STRINGIFY(ABS_MT_TOOL_Y)
 };
 const struct xlat evdev_abs[1] = { {
  .data = evdev_abs_xdata,
  .size = ARRAY_SIZE(evdev_abs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/evdev_autorepeat.h 5.9-0ubuntu2/xlat/evdev_autorepeat.h
--- 5.5-3/xlat/evdev_autorepeat.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/evdev_autorepeat.h	2020-09-24 09:18:44.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data evdev_autorepeat_xdata[] = {
  [REP_DELAY] = XLAT(REP_DELAY),
+ #define XLAT_VAL_0 ((unsigned) (REP_DELAY))
+ #define XLAT_STR_0 STRINGIFY(REP_DELAY)
  [REP_PERIOD] = XLAT(REP_PERIOD),
+ #define XLAT_VAL_1 ((unsigned) (REP_PERIOD))
+ #define XLAT_STR_1 STRINGIFY(REP_PERIOD)
 };
 static
 const struct xlat evdev_autorepeat[1] = { {
  .data = evdev_autorepeat_xdata,
  .size = ARRAY_SIZE(evdev_autorepeat_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/evdev_ev.h 5.9-0ubuntu2/xlat/evdev_ev.h
--- 5.5-3/xlat/evdev_ev.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/evdev_ev.h	2020-09-24 09:18:44.000000000 +0000
@@ -94,24 +94,148 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data evdev_ev_xdata[] = {
  XLAT(EV_SYN),
+ #define XLAT_VAL_0 ((unsigned) (EV_SYN))
+ #define XLAT_STR_0 STRINGIFY(EV_SYN)
  XLAT(EV_KEY),
+ #define XLAT_VAL_1 ((unsigned) (EV_KEY))
+ #define XLAT_STR_1 STRINGIFY(EV_KEY)
  XLAT(EV_REL),
+ #define XLAT_VAL_2 ((unsigned) (EV_REL))
+ #define XLAT_STR_2 STRINGIFY(EV_REL)
  XLAT(EV_ABS),
+ #define XLAT_VAL_3 ((unsigned) (EV_ABS))
+ #define XLAT_STR_3 STRINGIFY(EV_ABS)
  XLAT(EV_MSC),
+ #define XLAT_VAL_4 ((unsigned) (EV_MSC))
+ #define XLAT_STR_4 STRINGIFY(EV_MSC)
  XLAT(EV_SW),
+ #define XLAT_VAL_5 ((unsigned) (EV_SW))
+ #define XLAT_STR_5 STRINGIFY(EV_SW)
  XLAT(EV_LED),
+ #define XLAT_VAL_6 ((unsigned) (EV_LED))
+ #define XLAT_STR_6 STRINGIFY(EV_LED)
  XLAT(EV_SND),
+ #define XLAT_VAL_7 ((unsigned) (EV_SND))
+ #define XLAT_STR_7 STRINGIFY(EV_SND)
  XLAT(EV_REP),
+ #define XLAT_VAL_8 ((unsigned) (EV_REP))
+ #define XLAT_STR_8 STRINGIFY(EV_REP)
  XLAT(EV_FF),
+ #define XLAT_VAL_9 ((unsigned) (EV_FF))
+ #define XLAT_STR_9 STRINGIFY(EV_FF)
  XLAT(EV_PWR),
+ #define XLAT_VAL_10 ((unsigned) (EV_PWR))
+ #define XLAT_STR_10 STRINGIFY(EV_PWR)
  XLAT(EV_FF_STATUS),
+ #define XLAT_VAL_11 ((unsigned) (EV_FF_STATUS))
+ #define XLAT_STR_11 STRINGIFY(EV_FF_STATUS)
 };
 const struct xlat evdev_ev[1] = { {
  .data = evdev_ev_xdata,
  .size = ARRAY_SIZE(evdev_ev_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/evdev_ff_status.h 5.9-0ubuntu2/xlat/evdev_ff_status.h
--- 5.5-3/xlat/evdev_ff_status.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/evdev_ff_status.h	2020-09-24 09:18:44.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data evdev_ff_status_xdata[] = {
  [FF_STATUS_STOPPED] = XLAT(FF_STATUS_STOPPED),
+ #define XLAT_VAL_0 ((unsigned) (FF_STATUS_STOPPED))
+ #define XLAT_STR_0 STRINGIFY(FF_STATUS_STOPPED)
  [FF_STATUS_PLAYING] = XLAT(FF_STATUS_PLAYING),
+ #define XLAT_VAL_1 ((unsigned) (FF_STATUS_PLAYING))
+ #define XLAT_STR_1 STRINGIFY(FF_STATUS_PLAYING)
 };
 static
 const struct xlat evdev_ff_status[1] = { {
  .data = evdev_ff_status_xdata,
  .size = ARRAY_SIZE(evdev_ff_status_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/evdev_ff_types.h 5.9-0ubuntu2/xlat/evdev_ff_types.h
--- 5.5-3/xlat/evdev_ff_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/evdev_ff_types.h	2020-09-24 09:18:44.000000000 +0000
@@ -126,29 +126,193 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data evdev_ff_types_xdata[] = {
  XLAT(FF_RUMBLE),
+ #define XLAT_VAL_0 ((unsigned) (FF_RUMBLE))
+ #define XLAT_STR_0 STRINGIFY(FF_RUMBLE)
  XLAT(FF_PERIODIC),
+ #define XLAT_VAL_1 ((unsigned) (FF_PERIODIC))
+ #define XLAT_STR_1 STRINGIFY(FF_PERIODIC)
  XLAT(FF_CONSTANT),
+ #define XLAT_VAL_2 ((unsigned) (FF_CONSTANT))
+ #define XLAT_STR_2 STRINGIFY(FF_CONSTANT)
  XLAT(FF_SPRING),
+ #define XLAT_VAL_3 ((unsigned) (FF_SPRING))
+ #define XLAT_STR_3 STRINGIFY(FF_SPRING)
  XLAT(FF_FRICTION),
+ #define XLAT_VAL_4 ((unsigned) (FF_FRICTION))
+ #define XLAT_STR_4 STRINGIFY(FF_FRICTION)
  XLAT(FF_DAMPER),
+ #define XLAT_VAL_5 ((unsigned) (FF_DAMPER))
+ #define XLAT_STR_5 STRINGIFY(FF_DAMPER)
  XLAT(FF_INERTIA),
+ #define XLAT_VAL_6 ((unsigned) (FF_INERTIA))
+ #define XLAT_STR_6 STRINGIFY(FF_INERTIA)
  XLAT(FF_RAMP),
+ #define XLAT_VAL_7 ((unsigned) (FF_RAMP))
+ #define XLAT_STR_7 STRINGIFY(FF_RAMP)
  XLAT(FF_SQUARE),
+ #define XLAT_VAL_8 ((unsigned) (FF_SQUARE))
+ #define XLAT_STR_8 STRINGIFY(FF_SQUARE)
  XLAT(FF_TRIANGLE),
+ #define XLAT_VAL_9 ((unsigned) (FF_TRIANGLE))
+ #define XLAT_STR_9 STRINGIFY(FF_TRIANGLE)
  XLAT(FF_SINE),
+ #define XLAT_VAL_10 ((unsigned) (FF_SINE))
+ #define XLAT_STR_10 STRINGIFY(FF_SINE)
  XLAT(FF_SAW_UP),
+ #define XLAT_VAL_11 ((unsigned) (FF_SAW_UP))
+ #define XLAT_STR_11 STRINGIFY(FF_SAW_UP)
  XLAT(FF_SAW_DOWN),
+ #define XLAT_VAL_12 ((unsigned) (FF_SAW_DOWN))
+ #define XLAT_STR_12 STRINGIFY(FF_SAW_DOWN)
  XLAT(FF_CUSTOM),
+ #define XLAT_VAL_13 ((unsigned) (FF_CUSTOM))
+ #define XLAT_STR_13 STRINGIFY(FF_CUSTOM)
  XLAT(FF_GAIN),
+ #define XLAT_VAL_14 ((unsigned) (FF_GAIN))
+ #define XLAT_STR_14 STRINGIFY(FF_GAIN)
  XLAT(FF_AUTOCENTER),
+ #define XLAT_VAL_15 ((unsigned) (FF_AUTOCENTER))
+ #define XLAT_STR_15 STRINGIFY(FF_AUTOCENTER)
 };
 static
 const struct xlat evdev_ff_types[1] = { {
  .data = evdev_ff_types_xdata,
  .size = ARRAY_SIZE(evdev_ff_types_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/evdev_ioctl_cmds.h 5.9-0ubuntu2/xlat/evdev_ioctl_cmds.h
--- 5.5-3/xlat/evdev_ioctl_cmds.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/evdev_ioctl_cmds.h	2020-09-24 09:18:44.000000000 +0000
@@ -119,30 +119,184 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data evdev_ioctl_cmds_xdata[] = {
  XLAT(EVIOCGVERSION),
+ #define XLAT_VAL_0 ((unsigned) (EVIOCGVERSION))
+ #define XLAT_STR_0 STRINGIFY(EVIOCGVERSION)
  XLAT(EVIOCGID),
+ #define XLAT_VAL_1 ((unsigned) (EVIOCGID))
+ #define XLAT_STR_1 STRINGIFY(EVIOCGID)
  XLAT(EVIOCGREP),
+ #define XLAT_VAL_2 ((unsigned) (EVIOCGREP))
+ #define XLAT_STR_2 STRINGIFY(EVIOCGREP)
  XLAT(EVIOCSREP),
+ #define XLAT_VAL_3 ((unsigned) (EVIOCSREP))
+ #define XLAT_STR_3 STRINGIFY(EVIOCSREP)
  XLAT(EVIOCGKEYCODE),
+ #define XLAT_VAL_4 ((unsigned) (EVIOCGKEYCODE))
+ #define XLAT_STR_4 STRINGIFY(EVIOCGKEYCODE)
  XLAT(EVIOCGKEYCODE_V2),
+ #define XLAT_VAL_5 ((unsigned) (EVIOCGKEYCODE_V2))
+ #define XLAT_STR_5 STRINGIFY(EVIOCGKEYCODE_V2)
  XLAT(EVIOCSKEYCODE),
+ #define XLAT_VAL_6 ((unsigned) (EVIOCSKEYCODE))
+ #define XLAT_STR_6 STRINGIFY(EVIOCSKEYCODE)
  XLAT(EVIOCSKEYCODE_V2),
+ #define XLAT_VAL_7 ((unsigned) (EVIOCSKEYCODE_V2))
+ #define XLAT_STR_7 STRINGIFY(EVIOCSKEYCODE_V2)
 
 
  XLAT(EVIOCRMFF),
+ #define XLAT_VAL_8 ((unsigned) (EVIOCRMFF))
+ #define XLAT_STR_8 STRINGIFY(EVIOCRMFF)
  XLAT(EVIOCGEFFECTS),
+ #define XLAT_VAL_9 ((unsigned) (EVIOCGEFFECTS))
+ #define XLAT_STR_9 STRINGIFY(EVIOCGEFFECTS)
  XLAT(EVIOCGRAB),
+ #define XLAT_VAL_10 ((unsigned) (EVIOCGRAB))
+ #define XLAT_STR_10 STRINGIFY(EVIOCGRAB)
  XLAT(EVIOCREVOKE),
+ #define XLAT_VAL_11 ((unsigned) (EVIOCREVOKE))
+ #define XLAT_STR_11 STRINGIFY(EVIOCREVOKE)
  XLAT(EVIOCGMASK),
+ #define XLAT_VAL_12 ((unsigned) (EVIOCGMASK))
+ #define XLAT_STR_12 STRINGIFY(EVIOCGMASK)
  XLAT(EVIOCSMASK),
+ #define XLAT_VAL_13 ((unsigned) (EVIOCSMASK))
+ #define XLAT_STR_13 STRINGIFY(EVIOCSMASK)
  XLAT(EVIOCSCLOCKID),
+ #define XLAT_VAL_14 ((unsigned) (EVIOCSCLOCKID))
+ #define XLAT_STR_14 STRINGIFY(EVIOCSCLOCKID)
 };
 static
 const struct xlat evdev_ioctl_cmds[1] = { {
  .data = evdev_ioctl_cmds_xdata,
  .size = ARRAY_SIZE(evdev_ioctl_cmds_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/evdev_keycode.h 5.9-0ubuntu2/xlat/evdev_keycode.h
--- 5.5-3/xlat/evdev_keycode.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/evdev_keycode.h	2020-09-24 09:18:49.000000000 +0000
@@ -3564,6 +3564,13 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define KEY_PRIVACY_SCREEN_TOGGLE 0x279
 #endif
+#if defined(KEY_SELECTIVE_SCREENSHOT) || (defined(HAVE_DECL_KEY_SELECTIVE_SCREENSHOT) && HAVE_DECL_KEY_SELECTIVE_SCREENSHOT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((KEY_SELECTIVE_SCREENSHOT) == (0x27a), "KEY_SELECTIVE_SCREENSHOT != 0x27a");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define KEY_SELECTIVE_SCREENSHOT 0x27a
+#endif
 #if defined(KEY_MACRO1) || (defined(HAVE_DECL_KEY_MACRO1) && HAVE_DECL_KEY_MACRO1)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
 static_assert((KEY_MACRO1) == (0x290), "KEY_MACRO1 != 0x290");
@@ -4143,259 +4150,741 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 static const struct xlat_data evdev_keycode_xdata[] = {
 
  [KEY_RESERVED] = XLAT(KEY_RESERVED),
+ #define XLAT_VAL_0 ((unsigned) (KEY_RESERVED))
+ #define XLAT_STR_0 STRINGIFY(KEY_RESERVED)
  [KEY_ESC] = XLAT(KEY_ESC),
+ #define XLAT_VAL_1 ((unsigned) (KEY_ESC))
+ #define XLAT_STR_1 STRINGIFY(KEY_ESC)
  [KEY_1] = XLAT(KEY_1),
+ #define XLAT_VAL_2 ((unsigned) (KEY_1))
+ #define XLAT_STR_2 STRINGIFY(KEY_1)
  [KEY_2] = XLAT(KEY_2),
+ #define XLAT_VAL_3 ((unsigned) (KEY_2))
+ #define XLAT_STR_3 STRINGIFY(KEY_2)
  [KEY_3] = XLAT(KEY_3),
+ #define XLAT_VAL_4 ((unsigned) (KEY_3))
+ #define XLAT_STR_4 STRINGIFY(KEY_3)
  [KEY_4] = XLAT(KEY_4),
+ #define XLAT_VAL_5 ((unsigned) (KEY_4))
+ #define XLAT_STR_5 STRINGIFY(KEY_4)
  [KEY_5] = XLAT(KEY_5),
+ #define XLAT_VAL_6 ((unsigned) (KEY_5))
+ #define XLAT_STR_6 STRINGIFY(KEY_5)
  [KEY_6] = XLAT(KEY_6),
+ #define XLAT_VAL_7 ((unsigned) (KEY_6))
+ #define XLAT_STR_7 STRINGIFY(KEY_6)
  [KEY_7] = XLAT(KEY_7),
+ #define XLAT_VAL_8 ((unsigned) (KEY_7))
+ #define XLAT_STR_8 STRINGIFY(KEY_7)
  [KEY_8] = XLAT(KEY_8),
+ #define XLAT_VAL_9 ((unsigned) (KEY_8))
+ #define XLAT_STR_9 STRINGIFY(KEY_8)
  [KEY_9] = XLAT(KEY_9),
+ #define XLAT_VAL_10 ((unsigned) (KEY_9))
+ #define XLAT_STR_10 STRINGIFY(KEY_9)
  [KEY_0] = XLAT(KEY_0),
+ #define XLAT_VAL_11 ((unsigned) (KEY_0))
+ #define XLAT_STR_11 STRINGIFY(KEY_0)
  [KEY_MINUS] = XLAT(KEY_MINUS),
+ #define XLAT_VAL_12 ((unsigned) (KEY_MINUS))
+ #define XLAT_STR_12 STRINGIFY(KEY_MINUS)
  [KEY_EQUAL] = XLAT(KEY_EQUAL),
+ #define XLAT_VAL_13 ((unsigned) (KEY_EQUAL))
+ #define XLAT_STR_13 STRINGIFY(KEY_EQUAL)
  [KEY_BACKSPACE] = XLAT(KEY_BACKSPACE),
+ #define XLAT_VAL_14 ((unsigned) (KEY_BACKSPACE))
+ #define XLAT_STR_14 STRINGIFY(KEY_BACKSPACE)
  [KEY_TAB] = XLAT(KEY_TAB),
+ #define XLAT_VAL_15 ((unsigned) (KEY_TAB))
+ #define XLAT_STR_15 STRINGIFY(KEY_TAB)
  [KEY_Q] = XLAT(KEY_Q),
+ #define XLAT_VAL_16 ((unsigned) (KEY_Q))
+ #define XLAT_STR_16 STRINGIFY(KEY_Q)
  [KEY_W] = XLAT(KEY_W),
+ #define XLAT_VAL_17 ((unsigned) (KEY_W))
+ #define XLAT_STR_17 STRINGIFY(KEY_W)
  [KEY_E] = XLAT(KEY_E),
+ #define XLAT_VAL_18 ((unsigned) (KEY_E))
+ #define XLAT_STR_18 STRINGIFY(KEY_E)
  [KEY_R] = XLAT(KEY_R),
+ #define XLAT_VAL_19 ((unsigned) (KEY_R))
+ #define XLAT_STR_19 STRINGIFY(KEY_R)
  [KEY_T] = XLAT(KEY_T),
+ #define XLAT_VAL_20 ((unsigned) (KEY_T))
+ #define XLAT_STR_20 STRINGIFY(KEY_T)
  [KEY_Y] = XLAT(KEY_Y),
+ #define XLAT_VAL_21 ((unsigned) (KEY_Y))
+ #define XLAT_STR_21 STRINGIFY(KEY_Y)
  [KEY_U] = XLAT(KEY_U),
+ #define XLAT_VAL_22 ((unsigned) (KEY_U))
+ #define XLAT_STR_22 STRINGIFY(KEY_U)
  [KEY_I] = XLAT(KEY_I),
+ #define XLAT_VAL_23 ((unsigned) (KEY_I))
+ #define XLAT_STR_23 STRINGIFY(KEY_I)
  [KEY_O] = XLAT(KEY_O),
+ #define XLAT_VAL_24 ((unsigned) (KEY_O))
+ #define XLAT_STR_24 STRINGIFY(KEY_O)
  [KEY_P] = XLAT(KEY_P),
+ #define XLAT_VAL_25 ((unsigned) (KEY_P))
+ #define XLAT_STR_25 STRINGIFY(KEY_P)
  [KEY_LEFTBRACE] = XLAT(KEY_LEFTBRACE),
+ #define XLAT_VAL_26 ((unsigned) (KEY_LEFTBRACE))
+ #define XLAT_STR_26 STRINGIFY(KEY_LEFTBRACE)
  [KEY_RIGHTBRACE] = XLAT(KEY_RIGHTBRACE),
+ #define XLAT_VAL_27 ((unsigned) (KEY_RIGHTBRACE))
+ #define XLAT_STR_27 STRINGIFY(KEY_RIGHTBRACE)
  [KEY_ENTER] = XLAT(KEY_ENTER),
+ #define XLAT_VAL_28 ((unsigned) (KEY_ENTER))
+ #define XLAT_STR_28 STRINGIFY(KEY_ENTER)
  [KEY_LEFTCTRL] = XLAT(KEY_LEFTCTRL),
+ #define XLAT_VAL_29 ((unsigned) (KEY_LEFTCTRL))
+ #define XLAT_STR_29 STRINGIFY(KEY_LEFTCTRL)
  [KEY_A] = XLAT(KEY_A),
+ #define XLAT_VAL_30 ((unsigned) (KEY_A))
+ #define XLAT_STR_30 STRINGIFY(KEY_A)
  [KEY_S] = XLAT(KEY_S),
+ #define XLAT_VAL_31 ((unsigned) (KEY_S))
+ #define XLAT_STR_31 STRINGIFY(KEY_S)
  [KEY_D] = XLAT(KEY_D),
+ #define XLAT_VAL_32 ((unsigned) (KEY_D))
+ #define XLAT_STR_32 STRINGIFY(KEY_D)
  [KEY_F] = XLAT(KEY_F),
+ #define XLAT_VAL_33 ((unsigned) (KEY_F))
+ #define XLAT_STR_33 STRINGIFY(KEY_F)
  [KEY_G] = XLAT(KEY_G),
+ #define XLAT_VAL_34 ((unsigned) (KEY_G))
+ #define XLAT_STR_34 STRINGIFY(KEY_G)
  [KEY_H] = XLAT(KEY_H),
+ #define XLAT_VAL_35 ((unsigned) (KEY_H))
+ #define XLAT_STR_35 STRINGIFY(KEY_H)
  [KEY_J] = XLAT(KEY_J),
+ #define XLAT_VAL_36 ((unsigned) (KEY_J))
+ #define XLAT_STR_36 STRINGIFY(KEY_J)
  [KEY_K] = XLAT(KEY_K),
+ #define XLAT_VAL_37 ((unsigned) (KEY_K))
+ #define XLAT_STR_37 STRINGIFY(KEY_K)
  [KEY_L] = XLAT(KEY_L),
+ #define XLAT_VAL_38 ((unsigned) (KEY_L))
+ #define XLAT_STR_38 STRINGIFY(KEY_L)
  [KEY_SEMICOLON] = XLAT(KEY_SEMICOLON),
+ #define XLAT_VAL_39 ((unsigned) (KEY_SEMICOLON))
+ #define XLAT_STR_39 STRINGIFY(KEY_SEMICOLON)
  [KEY_APOSTROPHE] = XLAT(KEY_APOSTROPHE),
+ #define XLAT_VAL_40 ((unsigned) (KEY_APOSTROPHE))
+ #define XLAT_STR_40 STRINGIFY(KEY_APOSTROPHE)
  [KEY_GRAVE] = XLAT(KEY_GRAVE),
+ #define XLAT_VAL_41 ((unsigned) (KEY_GRAVE))
+ #define XLAT_STR_41 STRINGIFY(KEY_GRAVE)
  [KEY_LEFTSHIFT] = XLAT(KEY_LEFTSHIFT),
+ #define XLAT_VAL_42 ((unsigned) (KEY_LEFTSHIFT))
+ #define XLAT_STR_42 STRINGIFY(KEY_LEFTSHIFT)
  [KEY_BACKSLASH] = XLAT(KEY_BACKSLASH),
+ #define XLAT_VAL_43 ((unsigned) (KEY_BACKSLASH))
+ #define XLAT_STR_43 STRINGIFY(KEY_BACKSLASH)
  [KEY_Z] = XLAT(KEY_Z),
+ #define XLAT_VAL_44 ((unsigned) (KEY_Z))
+ #define XLAT_STR_44 STRINGIFY(KEY_Z)
  [KEY_X] = XLAT(KEY_X),
+ #define XLAT_VAL_45 ((unsigned) (KEY_X))
+ #define XLAT_STR_45 STRINGIFY(KEY_X)
  [KEY_C] = XLAT(KEY_C),
+ #define XLAT_VAL_46 ((unsigned) (KEY_C))
+ #define XLAT_STR_46 STRINGIFY(KEY_C)
  [KEY_V] = XLAT(KEY_V),
+ #define XLAT_VAL_47 ((unsigned) (KEY_V))
+ #define XLAT_STR_47 STRINGIFY(KEY_V)
  [KEY_B] = XLAT(KEY_B),
+ #define XLAT_VAL_48 ((unsigned) (KEY_B))
+ #define XLAT_STR_48 STRINGIFY(KEY_B)
  [KEY_N] = XLAT(KEY_N),
+ #define XLAT_VAL_49 ((unsigned) (KEY_N))
+ #define XLAT_STR_49 STRINGIFY(KEY_N)
  [KEY_M] = XLAT(KEY_M),
+ #define XLAT_VAL_50 ((unsigned) (KEY_M))
+ #define XLAT_STR_50 STRINGIFY(KEY_M)
  [KEY_COMMA] = XLAT(KEY_COMMA),
+ #define XLAT_VAL_51 ((unsigned) (KEY_COMMA))
+ #define XLAT_STR_51 STRINGIFY(KEY_COMMA)
  [KEY_DOT] = XLAT(KEY_DOT),
+ #define XLAT_VAL_52 ((unsigned) (KEY_DOT))
+ #define XLAT_STR_52 STRINGIFY(KEY_DOT)
  [KEY_SLASH] = XLAT(KEY_SLASH),
+ #define XLAT_VAL_53 ((unsigned) (KEY_SLASH))
+ #define XLAT_STR_53 STRINGIFY(KEY_SLASH)
  [KEY_RIGHTSHIFT] = XLAT(KEY_RIGHTSHIFT),
+ #define XLAT_VAL_54 ((unsigned) (KEY_RIGHTSHIFT))
+ #define XLAT_STR_54 STRINGIFY(KEY_RIGHTSHIFT)
  [KEY_KPASTERISK] = XLAT(KEY_KPASTERISK),
+ #define XLAT_VAL_55 ((unsigned) (KEY_KPASTERISK))
+ #define XLAT_STR_55 STRINGIFY(KEY_KPASTERISK)
  [KEY_LEFTALT] = XLAT(KEY_LEFTALT),
+ #define XLAT_VAL_56 ((unsigned) (KEY_LEFTALT))
+ #define XLAT_STR_56 STRINGIFY(KEY_LEFTALT)
  [KEY_SPACE] = XLAT(KEY_SPACE),
+ #define XLAT_VAL_57 ((unsigned) (KEY_SPACE))
+ #define XLAT_STR_57 STRINGIFY(KEY_SPACE)
  [KEY_CAPSLOCK] = XLAT(KEY_CAPSLOCK),
+ #define XLAT_VAL_58 ((unsigned) (KEY_CAPSLOCK))
+ #define XLAT_STR_58 STRINGIFY(KEY_CAPSLOCK)
  [KEY_F1] = XLAT(KEY_F1),
+ #define XLAT_VAL_59 ((unsigned) (KEY_F1))
+ #define XLAT_STR_59 STRINGIFY(KEY_F1)
  [KEY_F2] = XLAT(KEY_F2),
+ #define XLAT_VAL_60 ((unsigned) (KEY_F2))
+ #define XLAT_STR_60 STRINGIFY(KEY_F2)
  [KEY_F3] = XLAT(KEY_F3),
+ #define XLAT_VAL_61 ((unsigned) (KEY_F3))
+ #define XLAT_STR_61 STRINGIFY(KEY_F3)
  [KEY_F4] = XLAT(KEY_F4),
+ #define XLAT_VAL_62 ((unsigned) (KEY_F4))
+ #define XLAT_STR_62 STRINGIFY(KEY_F4)
  [KEY_F5] = XLAT(KEY_F5),
+ #define XLAT_VAL_63 ((unsigned) (KEY_F5))
+ #define XLAT_STR_63 STRINGIFY(KEY_F5)
  [KEY_F6] = XLAT(KEY_F6),
+ #define XLAT_VAL_64 ((unsigned) (KEY_F6))
+ #define XLAT_STR_64 STRINGIFY(KEY_F6)
  [KEY_F7] = XLAT(KEY_F7),
+ #define XLAT_VAL_65 ((unsigned) (KEY_F7))
+ #define XLAT_STR_65 STRINGIFY(KEY_F7)
  [KEY_F8] = XLAT(KEY_F8),
+ #define XLAT_VAL_66 ((unsigned) (KEY_F8))
+ #define XLAT_STR_66 STRINGIFY(KEY_F8)
  [KEY_F9] = XLAT(KEY_F9),
+ #define XLAT_VAL_67 ((unsigned) (KEY_F9))
+ #define XLAT_STR_67 STRINGIFY(KEY_F9)
  [KEY_F10] = XLAT(KEY_F10),
+ #define XLAT_VAL_68 ((unsigned) (KEY_F10))
+ #define XLAT_STR_68 STRINGIFY(KEY_F10)
  [KEY_NUMLOCK] = XLAT(KEY_NUMLOCK),
+ #define XLAT_VAL_69 ((unsigned) (KEY_NUMLOCK))
+ #define XLAT_STR_69 STRINGIFY(KEY_NUMLOCK)
  [KEY_SCROLLLOCK] = XLAT(KEY_SCROLLLOCK),
+ #define XLAT_VAL_70 ((unsigned) (KEY_SCROLLLOCK))
+ #define XLAT_STR_70 STRINGIFY(KEY_SCROLLLOCK)
  [KEY_KP7] = XLAT(KEY_KP7),
+ #define XLAT_VAL_71 ((unsigned) (KEY_KP7))
+ #define XLAT_STR_71 STRINGIFY(KEY_KP7)
  [KEY_KP8] = XLAT(KEY_KP8),
+ #define XLAT_VAL_72 ((unsigned) (KEY_KP8))
+ #define XLAT_STR_72 STRINGIFY(KEY_KP8)
  [KEY_KP9] = XLAT(KEY_KP9),
+ #define XLAT_VAL_73 ((unsigned) (KEY_KP9))
+ #define XLAT_STR_73 STRINGIFY(KEY_KP9)
  [KEY_KPMINUS] = XLAT(KEY_KPMINUS),
+ #define XLAT_VAL_74 ((unsigned) (KEY_KPMINUS))
+ #define XLAT_STR_74 STRINGIFY(KEY_KPMINUS)
  [KEY_KP4] = XLAT(KEY_KP4),
+ #define XLAT_VAL_75 ((unsigned) (KEY_KP4))
+ #define XLAT_STR_75 STRINGIFY(KEY_KP4)
  [KEY_KP5] = XLAT(KEY_KP5),
+ #define XLAT_VAL_76 ((unsigned) (KEY_KP5))
+ #define XLAT_STR_76 STRINGIFY(KEY_KP5)
  [KEY_KP6] = XLAT(KEY_KP6),
+ #define XLAT_VAL_77 ((unsigned) (KEY_KP6))
+ #define XLAT_STR_77 STRINGIFY(KEY_KP6)
  [KEY_KPPLUS] = XLAT(KEY_KPPLUS),
+ #define XLAT_VAL_78 ((unsigned) (KEY_KPPLUS))
+ #define XLAT_STR_78 STRINGIFY(KEY_KPPLUS)
  [KEY_KP1] = XLAT(KEY_KP1),
+ #define XLAT_VAL_79 ((unsigned) (KEY_KP1))
+ #define XLAT_STR_79 STRINGIFY(KEY_KP1)
  [KEY_KP2] = XLAT(KEY_KP2),
+ #define XLAT_VAL_80 ((unsigned) (KEY_KP2))
+ #define XLAT_STR_80 STRINGIFY(KEY_KP2)
  [KEY_KP3] = XLAT(KEY_KP3),
+ #define XLAT_VAL_81 ((unsigned) (KEY_KP3))
+ #define XLAT_STR_81 STRINGIFY(KEY_KP3)
  [KEY_KP0] = XLAT(KEY_KP0),
+ #define XLAT_VAL_82 ((unsigned) (KEY_KP0))
+ #define XLAT_STR_82 STRINGIFY(KEY_KP0)
  [KEY_KPDOT] = XLAT(KEY_KPDOT),
+ #define XLAT_VAL_83 ((unsigned) (KEY_KPDOT))
+ #define XLAT_STR_83 STRINGIFY(KEY_KPDOT)
 
  [KEY_ZENKAKUHANKAKU] = XLAT(KEY_ZENKAKUHANKAKU),
+ #define XLAT_VAL_84 ((unsigned) (KEY_ZENKAKUHANKAKU))
+ #define XLAT_STR_84 STRINGIFY(KEY_ZENKAKUHANKAKU)
  [KEY_102ND] = XLAT(KEY_102ND),
+ #define XLAT_VAL_85 ((unsigned) (KEY_102ND))
+ #define XLAT_STR_85 STRINGIFY(KEY_102ND)
  [KEY_F11] = XLAT(KEY_F11),
+ #define XLAT_VAL_86 ((unsigned) (KEY_F11))
+ #define XLAT_STR_86 STRINGIFY(KEY_F11)
  [KEY_F12] = XLAT(KEY_F12),
+ #define XLAT_VAL_87 ((unsigned) (KEY_F12))
+ #define XLAT_STR_87 STRINGIFY(KEY_F12)
  [KEY_RO] = XLAT(KEY_RO),
+ #define XLAT_VAL_88 ((unsigned) (KEY_RO))
+ #define XLAT_STR_88 STRINGIFY(KEY_RO)
  [KEY_KATAKANA] = XLAT(KEY_KATAKANA),
+ #define XLAT_VAL_89 ((unsigned) (KEY_KATAKANA))
+ #define XLAT_STR_89 STRINGIFY(KEY_KATAKANA)
  [KEY_HIRAGANA] = XLAT(KEY_HIRAGANA),
+ #define XLAT_VAL_90 ((unsigned) (KEY_HIRAGANA))
+ #define XLAT_STR_90 STRINGIFY(KEY_HIRAGANA)
  [KEY_HENKAN] = XLAT(KEY_HENKAN),
+ #define XLAT_VAL_91 ((unsigned) (KEY_HENKAN))
+ #define XLAT_STR_91 STRINGIFY(KEY_HENKAN)
  [KEY_KATAKANAHIRAGANA] = XLAT(KEY_KATAKANAHIRAGANA),
+ #define XLAT_VAL_92 ((unsigned) (KEY_KATAKANAHIRAGANA))
+ #define XLAT_STR_92 STRINGIFY(KEY_KATAKANAHIRAGANA)
  [KEY_MUHENKAN] = XLAT(KEY_MUHENKAN),
+ #define XLAT_VAL_93 ((unsigned) (KEY_MUHENKAN))
+ #define XLAT_STR_93 STRINGIFY(KEY_MUHENKAN)
  [KEY_KPJPCOMMA] = XLAT(KEY_KPJPCOMMA),
+ #define XLAT_VAL_94 ((unsigned) (KEY_KPJPCOMMA))
+ #define XLAT_STR_94 STRINGIFY(KEY_KPJPCOMMA)
  [KEY_KPENTER] = XLAT(KEY_KPENTER),
+ #define XLAT_VAL_95 ((unsigned) (KEY_KPENTER))
+ #define XLAT_STR_95 STRINGIFY(KEY_KPENTER)
  [KEY_RIGHTCTRL] = XLAT(KEY_RIGHTCTRL),
+ #define XLAT_VAL_96 ((unsigned) (KEY_RIGHTCTRL))
+ #define XLAT_STR_96 STRINGIFY(KEY_RIGHTCTRL)
  [KEY_KPSLASH] = XLAT(KEY_KPSLASH),
+ #define XLAT_VAL_97 ((unsigned) (KEY_KPSLASH))
+ #define XLAT_STR_97 STRINGIFY(KEY_KPSLASH)
  [KEY_SYSRQ] = XLAT(KEY_SYSRQ),
+ #define XLAT_VAL_98 ((unsigned) (KEY_SYSRQ))
+ #define XLAT_STR_98 STRINGIFY(KEY_SYSRQ)
  [KEY_RIGHTALT] = XLAT(KEY_RIGHTALT),
+ #define XLAT_VAL_99 ((unsigned) (KEY_RIGHTALT))
+ #define XLAT_STR_99 STRINGIFY(KEY_RIGHTALT)
  [KEY_LINEFEED] = XLAT(KEY_LINEFEED),
+ #define XLAT_VAL_100 ((unsigned) (KEY_LINEFEED))
+ #define XLAT_STR_100 STRINGIFY(KEY_LINEFEED)
  [KEY_HOME] = XLAT(KEY_HOME),
+ #define XLAT_VAL_101 ((unsigned) (KEY_HOME))
+ #define XLAT_STR_101 STRINGIFY(KEY_HOME)
  [KEY_UP] = XLAT(KEY_UP),
+ #define XLAT_VAL_102 ((unsigned) (KEY_UP))
+ #define XLAT_STR_102 STRINGIFY(KEY_UP)
  [KEY_PAGEUP] = XLAT(KEY_PAGEUP),
+ #define XLAT_VAL_103 ((unsigned) (KEY_PAGEUP))
+ #define XLAT_STR_103 STRINGIFY(KEY_PAGEUP)
  [KEY_LEFT] = XLAT(KEY_LEFT),
+ #define XLAT_VAL_104 ((unsigned) (KEY_LEFT))
+ #define XLAT_STR_104 STRINGIFY(KEY_LEFT)
  [KEY_RIGHT] = XLAT(KEY_RIGHT),
+ #define XLAT_VAL_105 ((unsigned) (KEY_RIGHT))
+ #define XLAT_STR_105 STRINGIFY(KEY_RIGHT)
  [KEY_END] = XLAT(KEY_END),
+ #define XLAT_VAL_106 ((unsigned) (KEY_END))
+ #define XLAT_STR_106 STRINGIFY(KEY_END)
  [KEY_DOWN] = XLAT(KEY_DOWN),
+ #define XLAT_VAL_107 ((unsigned) (KEY_DOWN))
+ #define XLAT_STR_107 STRINGIFY(KEY_DOWN)
  [KEY_PAGEDOWN] = XLAT(KEY_PAGEDOWN),
+ #define XLAT_VAL_108 ((unsigned) (KEY_PAGEDOWN))
+ #define XLAT_STR_108 STRINGIFY(KEY_PAGEDOWN)
  [KEY_INSERT] = XLAT(KEY_INSERT),
+ #define XLAT_VAL_109 ((unsigned) (KEY_INSERT))
+ #define XLAT_STR_109 STRINGIFY(KEY_INSERT)
  [KEY_DELETE] = XLAT(KEY_DELETE),
+ #define XLAT_VAL_110 ((unsigned) (KEY_DELETE))
+ #define XLAT_STR_110 STRINGIFY(KEY_DELETE)
  [KEY_MACRO] = XLAT(KEY_MACRO),
+ #define XLAT_VAL_111 ((unsigned) (KEY_MACRO))
+ #define XLAT_STR_111 STRINGIFY(KEY_MACRO)
  [KEY_MUTE] = XLAT(KEY_MUTE),
+ #define XLAT_VAL_112 ((unsigned) (KEY_MUTE))
+ #define XLAT_STR_112 STRINGIFY(KEY_MUTE)
  [KEY_VOLUMEDOWN] = XLAT(KEY_VOLUMEDOWN),
+ #define XLAT_VAL_113 ((unsigned) (KEY_VOLUMEDOWN))
+ #define XLAT_STR_113 STRINGIFY(KEY_VOLUMEDOWN)
  [KEY_VOLUMEUP] = XLAT(KEY_VOLUMEUP),
+ #define XLAT_VAL_114 ((unsigned) (KEY_VOLUMEUP))
+ #define XLAT_STR_114 STRINGIFY(KEY_VOLUMEUP)
  [KEY_POWER] = XLAT(KEY_POWER),
+ #define XLAT_VAL_115 ((unsigned) (KEY_POWER))
+ #define XLAT_STR_115 STRINGIFY(KEY_POWER)
  [KEY_KPEQUAL] = XLAT(KEY_KPEQUAL),
+ #define XLAT_VAL_116 ((unsigned) (KEY_KPEQUAL))
+ #define XLAT_STR_116 STRINGIFY(KEY_KPEQUAL)
  [KEY_KPPLUSMINUS] = XLAT(KEY_KPPLUSMINUS),
+ #define XLAT_VAL_117 ((unsigned) (KEY_KPPLUSMINUS))
+ #define XLAT_STR_117 STRINGIFY(KEY_KPPLUSMINUS)
  [KEY_PAUSE] = XLAT(KEY_PAUSE),
+ #define XLAT_VAL_118 ((unsigned) (KEY_PAUSE))
+ #define XLAT_STR_118 STRINGIFY(KEY_PAUSE)
  [KEY_SCALE] = XLAT(KEY_SCALE),
+ #define XLAT_VAL_119 ((unsigned) (KEY_SCALE))
+ #define XLAT_STR_119 STRINGIFY(KEY_SCALE)
 
  [KEY_KPCOMMA] = XLAT(KEY_KPCOMMA),
+ #define XLAT_VAL_120 ((unsigned) (KEY_KPCOMMA))
+ #define XLAT_STR_120 STRINGIFY(KEY_KPCOMMA)
  [KEY_HANGEUL] = XLAT(KEY_HANGEUL),
+ #define XLAT_VAL_121 ((unsigned) (KEY_HANGEUL))
+ #define XLAT_STR_121 STRINGIFY(KEY_HANGEUL)
  [KEY_HANJA] = XLAT(KEY_HANJA),
+ #define XLAT_VAL_122 ((unsigned) (KEY_HANJA))
+ #define XLAT_STR_122 STRINGIFY(KEY_HANJA)
  [KEY_YEN] = XLAT(KEY_YEN),
+ #define XLAT_VAL_123 ((unsigned) (KEY_YEN))
+ #define XLAT_STR_123 STRINGIFY(KEY_YEN)
  [KEY_LEFTMETA] = XLAT(KEY_LEFTMETA),
+ #define XLAT_VAL_124 ((unsigned) (KEY_LEFTMETA))
+ #define XLAT_STR_124 STRINGIFY(KEY_LEFTMETA)
  [KEY_RIGHTMETA] = XLAT(KEY_RIGHTMETA),
+ #define XLAT_VAL_125 ((unsigned) (KEY_RIGHTMETA))
+ #define XLAT_STR_125 STRINGIFY(KEY_RIGHTMETA)
  [KEY_COMPOSE] = XLAT(KEY_COMPOSE),
+ #define XLAT_VAL_126 ((unsigned) (KEY_COMPOSE))
+ #define XLAT_STR_126 STRINGIFY(KEY_COMPOSE)
 
  [KEY_STOP] = XLAT(KEY_STOP),
+ #define XLAT_VAL_127 ((unsigned) (KEY_STOP))
+ #define XLAT_STR_127 STRINGIFY(KEY_STOP)
  [KEY_AGAIN] = XLAT(KEY_AGAIN),
+ #define XLAT_VAL_128 ((unsigned) (KEY_AGAIN))
+ #define XLAT_STR_128 STRINGIFY(KEY_AGAIN)
  [KEY_PROPS] = XLAT(KEY_PROPS),
+ #define XLAT_VAL_129 ((unsigned) (KEY_PROPS))
+ #define XLAT_STR_129 STRINGIFY(KEY_PROPS)
  [KEY_UNDO] = XLAT(KEY_UNDO),
+ #define XLAT_VAL_130 ((unsigned) (KEY_UNDO))
+ #define XLAT_STR_130 STRINGIFY(KEY_UNDO)
  [KEY_FRONT] = XLAT(KEY_FRONT),
+ #define XLAT_VAL_131 ((unsigned) (KEY_FRONT))
+ #define XLAT_STR_131 STRINGIFY(KEY_FRONT)
  [KEY_COPY] = XLAT(KEY_COPY),
+ #define XLAT_VAL_132 ((unsigned) (KEY_COPY))
+ #define XLAT_STR_132 STRINGIFY(KEY_COPY)
  [KEY_OPEN] = XLAT(KEY_OPEN),
+ #define XLAT_VAL_133 ((unsigned) (KEY_OPEN))
+ #define XLAT_STR_133 STRINGIFY(KEY_OPEN)
  [KEY_PASTE] = XLAT(KEY_PASTE),
+ #define XLAT_VAL_134 ((unsigned) (KEY_PASTE))
+ #define XLAT_STR_134 STRINGIFY(KEY_PASTE)
  [KEY_FIND] = XLAT(KEY_FIND),
+ #define XLAT_VAL_135 ((unsigned) (KEY_FIND))
+ #define XLAT_STR_135 STRINGIFY(KEY_FIND)
  [KEY_CUT] = XLAT(KEY_CUT),
+ #define XLAT_VAL_136 ((unsigned) (KEY_CUT))
+ #define XLAT_STR_136 STRINGIFY(KEY_CUT)
  [KEY_HELP] = XLAT(KEY_HELP),
+ #define XLAT_VAL_137 ((unsigned) (KEY_HELP))
+ #define XLAT_STR_137 STRINGIFY(KEY_HELP)
  [KEY_MENU] = XLAT(KEY_MENU),
+ #define XLAT_VAL_138 ((unsigned) (KEY_MENU))
+ #define XLAT_STR_138 STRINGIFY(KEY_MENU)
  [KEY_CALC] = XLAT(KEY_CALC),
+ #define XLAT_VAL_139 ((unsigned) (KEY_CALC))
+ #define XLAT_STR_139 STRINGIFY(KEY_CALC)
  [KEY_SETUP] = XLAT(KEY_SETUP),
+ #define XLAT_VAL_140 ((unsigned) (KEY_SETUP))
+ #define XLAT_STR_140 STRINGIFY(KEY_SETUP)
  [KEY_SLEEP] = XLAT(KEY_SLEEP),
+ #define XLAT_VAL_141 ((unsigned) (KEY_SLEEP))
+ #define XLAT_STR_141 STRINGIFY(KEY_SLEEP)
  [KEY_WAKEUP] = XLAT(KEY_WAKEUP),
+ #define XLAT_VAL_142 ((unsigned) (KEY_WAKEUP))
+ #define XLAT_STR_142 STRINGIFY(KEY_WAKEUP)
  [KEY_FILE] = XLAT(KEY_FILE),
+ #define XLAT_VAL_143 ((unsigned) (KEY_FILE))
+ #define XLAT_STR_143 STRINGIFY(KEY_FILE)
  [KEY_SENDFILE] = XLAT(KEY_SENDFILE),
+ #define XLAT_VAL_144 ((unsigned) (KEY_SENDFILE))
+ #define XLAT_STR_144 STRINGIFY(KEY_SENDFILE)
  [KEY_DELETEFILE] = XLAT(KEY_DELETEFILE),
+ #define XLAT_VAL_145 ((unsigned) (KEY_DELETEFILE))
+ #define XLAT_STR_145 STRINGIFY(KEY_DELETEFILE)
  [KEY_XFER] = XLAT(KEY_XFER),
+ #define XLAT_VAL_146 ((unsigned) (KEY_XFER))
+ #define XLAT_STR_146 STRINGIFY(KEY_XFER)
  [KEY_PROG1] = XLAT(KEY_PROG1),
+ #define XLAT_VAL_147 ((unsigned) (KEY_PROG1))
+ #define XLAT_STR_147 STRINGIFY(KEY_PROG1)
  [KEY_PROG2] = XLAT(KEY_PROG2),
+ #define XLAT_VAL_148 ((unsigned) (KEY_PROG2))
+ #define XLAT_STR_148 STRINGIFY(KEY_PROG2)
  [KEY_WWW] = XLAT(KEY_WWW),
+ #define XLAT_VAL_149 ((unsigned) (KEY_WWW))
+ #define XLAT_STR_149 STRINGIFY(KEY_WWW)
  [KEY_MSDOS] = XLAT(KEY_MSDOS),
+ #define XLAT_VAL_150 ((unsigned) (KEY_MSDOS))
+ #define XLAT_STR_150 STRINGIFY(KEY_MSDOS)
  [KEY_COFFEE] = XLAT(KEY_COFFEE),
+ #define XLAT_VAL_151 ((unsigned) (KEY_COFFEE))
+ #define XLAT_STR_151 STRINGIFY(KEY_COFFEE)
  [KEY_ROTATE_DISPLAY] = XLAT(KEY_ROTATE_DISPLAY),
+ #define XLAT_VAL_152 ((unsigned) (KEY_ROTATE_DISPLAY))
+ #define XLAT_STR_152 STRINGIFY(KEY_ROTATE_DISPLAY)
  [KEY_CYCLEWINDOWS] = XLAT(KEY_CYCLEWINDOWS),
+ #define XLAT_VAL_153 ((unsigned) (KEY_CYCLEWINDOWS))
+ #define XLAT_STR_153 STRINGIFY(KEY_CYCLEWINDOWS)
  [KEY_MAIL] = XLAT(KEY_MAIL),
+ #define XLAT_VAL_154 ((unsigned) (KEY_MAIL))
+ #define XLAT_STR_154 STRINGIFY(KEY_MAIL)
  [KEY_BOOKMARKS] = XLAT(KEY_BOOKMARKS),
+ #define XLAT_VAL_155 ((unsigned) (KEY_BOOKMARKS))
+ #define XLAT_STR_155 STRINGIFY(KEY_BOOKMARKS)
  [KEY_COMPUTER] = XLAT(KEY_COMPUTER),
+ #define XLAT_VAL_156 ((unsigned) (KEY_COMPUTER))
+ #define XLAT_STR_156 STRINGIFY(KEY_COMPUTER)
  [KEY_BACK] = XLAT(KEY_BACK),
+ #define XLAT_VAL_157 ((unsigned) (KEY_BACK))
+ #define XLAT_STR_157 STRINGIFY(KEY_BACK)
  [KEY_FORWARD] = XLAT(KEY_FORWARD),
+ #define XLAT_VAL_158 ((unsigned) (KEY_FORWARD))
+ #define XLAT_STR_158 STRINGIFY(KEY_FORWARD)
  [KEY_CLOSECD] = XLAT(KEY_CLOSECD),
+ #define XLAT_VAL_159 ((unsigned) (KEY_CLOSECD))
+ #define XLAT_STR_159 STRINGIFY(KEY_CLOSECD)
  [KEY_EJECTCD] = XLAT(KEY_EJECTCD),
+ #define XLAT_VAL_160 ((unsigned) (KEY_EJECTCD))
+ #define XLAT_STR_160 STRINGIFY(KEY_EJECTCD)
  [KEY_EJECTCLOSECD] = XLAT(KEY_EJECTCLOSECD),
+ #define XLAT_VAL_161 ((unsigned) (KEY_EJECTCLOSECD))
+ #define XLAT_STR_161 STRINGIFY(KEY_EJECTCLOSECD)
  [KEY_NEXTSONG] = XLAT(KEY_NEXTSONG),
+ #define XLAT_VAL_162 ((unsigned) (KEY_NEXTSONG))
+ #define XLAT_STR_162 STRINGIFY(KEY_NEXTSONG)
  [KEY_PLAYPAUSE] = XLAT(KEY_PLAYPAUSE),
+ #define XLAT_VAL_163 ((unsigned) (KEY_PLAYPAUSE))
+ #define XLAT_STR_163 STRINGIFY(KEY_PLAYPAUSE)
  [KEY_PREVIOUSSONG] = XLAT(KEY_PREVIOUSSONG),
+ #define XLAT_VAL_164 ((unsigned) (KEY_PREVIOUSSONG))
+ #define XLAT_STR_164 STRINGIFY(KEY_PREVIOUSSONG)
  [KEY_STOPCD] = XLAT(KEY_STOPCD),
+ #define XLAT_VAL_165 ((unsigned) (KEY_STOPCD))
+ #define XLAT_STR_165 STRINGIFY(KEY_STOPCD)
  [KEY_RECORD] = XLAT(KEY_RECORD),
+ #define XLAT_VAL_166 ((unsigned) (KEY_RECORD))
+ #define XLAT_STR_166 STRINGIFY(KEY_RECORD)
  [KEY_REWIND] = XLAT(KEY_REWIND),
+ #define XLAT_VAL_167 ((unsigned) (KEY_REWIND))
+ #define XLAT_STR_167 STRINGIFY(KEY_REWIND)
  [KEY_PHONE] = XLAT(KEY_PHONE),
+ #define XLAT_VAL_168 ((unsigned) (KEY_PHONE))
+ #define XLAT_STR_168 STRINGIFY(KEY_PHONE)
  [KEY_ISO] = XLAT(KEY_ISO),
+ #define XLAT_VAL_169 ((unsigned) (KEY_ISO))
+ #define XLAT_STR_169 STRINGIFY(KEY_ISO)
  [KEY_CONFIG] = XLAT(KEY_CONFIG),
+ #define XLAT_VAL_170 ((unsigned) (KEY_CONFIG))
+ #define XLAT_STR_170 STRINGIFY(KEY_CONFIG)
  [KEY_HOMEPAGE] = XLAT(KEY_HOMEPAGE),
+ #define XLAT_VAL_171 ((unsigned) (KEY_HOMEPAGE))
+ #define XLAT_STR_171 STRINGIFY(KEY_HOMEPAGE)
  [KEY_REFRESH] = XLAT(KEY_REFRESH),
+ #define XLAT_VAL_172 ((unsigned) (KEY_REFRESH))
+ #define XLAT_STR_172 STRINGIFY(KEY_REFRESH)
  [KEY_EXIT] = XLAT(KEY_EXIT),
+ #define XLAT_VAL_173 ((unsigned) (KEY_EXIT))
+ #define XLAT_STR_173 STRINGIFY(KEY_EXIT)
  [KEY_MOVE] = XLAT(KEY_MOVE),
+ #define XLAT_VAL_174 ((unsigned) (KEY_MOVE))
+ #define XLAT_STR_174 STRINGIFY(KEY_MOVE)
  [KEY_EDIT] = XLAT(KEY_EDIT),
+ #define XLAT_VAL_175 ((unsigned) (KEY_EDIT))
+ #define XLAT_STR_175 STRINGIFY(KEY_EDIT)
  [KEY_SCROLLUP] = XLAT(KEY_SCROLLUP),
+ #define XLAT_VAL_176 ((unsigned) (KEY_SCROLLUP))
+ #define XLAT_STR_176 STRINGIFY(KEY_SCROLLUP)
  [KEY_SCROLLDOWN] = XLAT(KEY_SCROLLDOWN),
+ #define XLAT_VAL_177 ((unsigned) (KEY_SCROLLDOWN))
+ #define XLAT_STR_177 STRINGIFY(KEY_SCROLLDOWN)
  [KEY_KPLEFTPAREN] = XLAT(KEY_KPLEFTPAREN),
+ #define XLAT_VAL_178 ((unsigned) (KEY_KPLEFTPAREN))
+ #define XLAT_STR_178 STRINGIFY(KEY_KPLEFTPAREN)
  [KEY_KPRIGHTPAREN] = XLAT(KEY_KPRIGHTPAREN),
+ #define XLAT_VAL_179 ((unsigned) (KEY_KPRIGHTPAREN))
+ #define XLAT_STR_179 STRINGIFY(KEY_KPRIGHTPAREN)
  [KEY_NEW] = XLAT(KEY_NEW),
+ #define XLAT_VAL_180 ((unsigned) (KEY_NEW))
+ #define XLAT_STR_180 STRINGIFY(KEY_NEW)
  [KEY_REDO] = XLAT(KEY_REDO),
+ #define XLAT_VAL_181 ((unsigned) (KEY_REDO))
+ #define XLAT_STR_181 STRINGIFY(KEY_REDO)
 
  [KEY_F13] = XLAT(KEY_F13),
+ #define XLAT_VAL_182 ((unsigned) (KEY_F13))
+ #define XLAT_STR_182 STRINGIFY(KEY_F13)
  [KEY_F14] = XLAT(KEY_F14),
+ #define XLAT_VAL_183 ((unsigned) (KEY_F14))
+ #define XLAT_STR_183 STRINGIFY(KEY_F14)
  [KEY_F15] = XLAT(KEY_F15),
+ #define XLAT_VAL_184 ((unsigned) (KEY_F15))
+ #define XLAT_STR_184 STRINGIFY(KEY_F15)
  [KEY_F16] = XLAT(KEY_F16),
+ #define XLAT_VAL_185 ((unsigned) (KEY_F16))
+ #define XLAT_STR_185 STRINGIFY(KEY_F16)
  [KEY_F17] = XLAT(KEY_F17),
+ #define XLAT_VAL_186 ((unsigned) (KEY_F17))
+ #define XLAT_STR_186 STRINGIFY(KEY_F17)
  [KEY_F18] = XLAT(KEY_F18),
+ #define XLAT_VAL_187 ((unsigned) (KEY_F18))
+ #define XLAT_STR_187 STRINGIFY(KEY_F18)
  [KEY_F19] = XLAT(KEY_F19),
+ #define XLAT_VAL_188 ((unsigned) (KEY_F19))
+ #define XLAT_STR_188 STRINGIFY(KEY_F19)
  [KEY_F20] = XLAT(KEY_F20),
+ #define XLAT_VAL_189 ((unsigned) (KEY_F20))
+ #define XLAT_STR_189 STRINGIFY(KEY_F20)
  [KEY_F21] = XLAT(KEY_F21),
+ #define XLAT_VAL_190 ((unsigned) (KEY_F21))
+ #define XLAT_STR_190 STRINGIFY(KEY_F21)
  [KEY_F22] = XLAT(KEY_F22),
+ #define XLAT_VAL_191 ((unsigned) (KEY_F22))
+ #define XLAT_STR_191 STRINGIFY(KEY_F22)
  [KEY_F23] = XLAT(KEY_F23),
+ #define XLAT_VAL_192 ((unsigned) (KEY_F23))
+ #define XLAT_STR_192 STRINGIFY(KEY_F23)
  [KEY_F24] = XLAT(KEY_F24),
+ #define XLAT_VAL_193 ((unsigned) (KEY_F24))
+ #define XLAT_STR_193 STRINGIFY(KEY_F24)
 
  [KEY_PLAYCD] = XLAT(KEY_PLAYCD),
+ #define XLAT_VAL_194 ((unsigned) (KEY_PLAYCD))
+ #define XLAT_STR_194 STRINGIFY(KEY_PLAYCD)
  [KEY_PAUSECD] = XLAT(KEY_PAUSECD),
+ #define XLAT_VAL_195 ((unsigned) (KEY_PAUSECD))
+ #define XLAT_STR_195 STRINGIFY(KEY_PAUSECD)
  [KEY_PROG3] = XLAT(KEY_PROG3),
+ #define XLAT_VAL_196 ((unsigned) (KEY_PROG3))
+ #define XLAT_STR_196 STRINGIFY(KEY_PROG3)
  [KEY_PROG4] = XLAT(KEY_PROG4),
+ #define XLAT_VAL_197 ((unsigned) (KEY_PROG4))
+ #define XLAT_STR_197 STRINGIFY(KEY_PROG4)
  [KEY_DASHBOARD] = XLAT(KEY_DASHBOARD),
+ #define XLAT_VAL_198 ((unsigned) (KEY_DASHBOARD))
+ #define XLAT_STR_198 STRINGIFY(KEY_DASHBOARD)
  [KEY_SUSPEND] = XLAT(KEY_SUSPEND),
+ #define XLAT_VAL_199 ((unsigned) (KEY_SUSPEND))
+ #define XLAT_STR_199 STRINGIFY(KEY_SUSPEND)
  [KEY_CLOSE] = XLAT(KEY_CLOSE),
+ #define XLAT_VAL_200 ((unsigned) (KEY_CLOSE))
+ #define XLAT_STR_200 STRINGIFY(KEY_CLOSE)
  [KEY_PLAY] = XLAT(KEY_PLAY),
+ #define XLAT_VAL_201 ((unsigned) (KEY_PLAY))
+ #define XLAT_STR_201 STRINGIFY(KEY_PLAY)
  [KEY_FASTFORWARD] = XLAT(KEY_FASTFORWARD),
+ #define XLAT_VAL_202 ((unsigned) (KEY_FASTFORWARD))
+ #define XLAT_STR_202 STRINGIFY(KEY_FASTFORWARD)
  [KEY_BASSBOOST] = XLAT(KEY_BASSBOOST),
+ #define XLAT_VAL_203 ((unsigned) (KEY_BASSBOOST))
+ #define XLAT_STR_203 STRINGIFY(KEY_BASSBOOST)
  [KEY_PRINT] = XLAT(KEY_PRINT),
+ #define XLAT_VAL_204 ((unsigned) (KEY_PRINT))
+ #define XLAT_STR_204 STRINGIFY(KEY_PRINT)
  [KEY_HP] = XLAT(KEY_HP),
+ #define XLAT_VAL_205 ((unsigned) (KEY_HP))
+ #define XLAT_STR_205 STRINGIFY(KEY_HP)
  [KEY_CAMERA] = XLAT(KEY_CAMERA),
+ #define XLAT_VAL_206 ((unsigned) (KEY_CAMERA))
+ #define XLAT_STR_206 STRINGIFY(KEY_CAMERA)
  [KEY_SOUND] = XLAT(KEY_SOUND),
+ #define XLAT_VAL_207 ((unsigned) (KEY_SOUND))
+ #define XLAT_STR_207 STRINGIFY(KEY_SOUND)
  [KEY_QUESTION] = XLAT(KEY_QUESTION),
+ #define XLAT_VAL_208 ((unsigned) (KEY_QUESTION))
+ #define XLAT_STR_208 STRINGIFY(KEY_QUESTION)
  [KEY_EMAIL] = XLAT(KEY_EMAIL),
+ #define XLAT_VAL_209 ((unsigned) (KEY_EMAIL))
+ #define XLAT_STR_209 STRINGIFY(KEY_EMAIL)
  [KEY_CHAT] = XLAT(KEY_CHAT),
+ #define XLAT_VAL_210 ((unsigned) (KEY_CHAT))
+ #define XLAT_STR_210 STRINGIFY(KEY_CHAT)
  [KEY_SEARCH] = XLAT(KEY_SEARCH),
+ #define XLAT_VAL_211 ((unsigned) (KEY_SEARCH))
+ #define XLAT_STR_211 STRINGIFY(KEY_SEARCH)
  [KEY_CONNECT] = XLAT(KEY_CONNECT),
+ #define XLAT_VAL_212 ((unsigned) (KEY_CONNECT))
+ #define XLAT_STR_212 STRINGIFY(KEY_CONNECT)
  [KEY_FINANCE] = XLAT(KEY_FINANCE),
+ #define XLAT_VAL_213 ((unsigned) (KEY_FINANCE))
+ #define XLAT_STR_213 STRINGIFY(KEY_FINANCE)
  [KEY_SPORT] = XLAT(KEY_SPORT),
+ #define XLAT_VAL_214 ((unsigned) (KEY_SPORT))
+ #define XLAT_STR_214 STRINGIFY(KEY_SPORT)
  [KEY_SHOP] = XLAT(KEY_SHOP),
+ #define XLAT_VAL_215 ((unsigned) (KEY_SHOP))
+ #define XLAT_STR_215 STRINGIFY(KEY_SHOP)
  [KEY_ALTERASE] = XLAT(KEY_ALTERASE),
+ #define XLAT_VAL_216 ((unsigned) (KEY_ALTERASE))
+ #define XLAT_STR_216 STRINGIFY(KEY_ALTERASE)
  [KEY_CANCEL] = XLAT(KEY_CANCEL),
+ #define XLAT_VAL_217 ((unsigned) (KEY_CANCEL))
+ #define XLAT_STR_217 STRINGIFY(KEY_CANCEL)
  [KEY_BRIGHTNESSDOWN] = XLAT(KEY_BRIGHTNESSDOWN),
+ #define XLAT_VAL_218 ((unsigned) (KEY_BRIGHTNESSDOWN))
+ #define XLAT_STR_218 STRINGIFY(KEY_BRIGHTNESSDOWN)
  [KEY_BRIGHTNESSUP] = XLAT(KEY_BRIGHTNESSUP),
+ #define XLAT_VAL_219 ((unsigned) (KEY_BRIGHTNESSUP))
+ #define XLAT_STR_219 STRINGIFY(KEY_BRIGHTNESSUP)
  [KEY_MEDIA] = XLAT(KEY_MEDIA),
+ #define XLAT_VAL_220 ((unsigned) (KEY_MEDIA))
+ #define XLAT_STR_220 STRINGIFY(KEY_MEDIA)
 
  [KEY_SWITCHVIDEOMODE] = XLAT(KEY_SWITCHVIDEOMODE),
+ #define XLAT_VAL_221 ((unsigned) (KEY_SWITCHVIDEOMODE))
+ #define XLAT_STR_221 STRINGIFY(KEY_SWITCHVIDEOMODE)
 
  [KEY_KBDILLUMTOGGLE] = XLAT(KEY_KBDILLUMTOGGLE),
+ #define XLAT_VAL_222 ((unsigned) (KEY_KBDILLUMTOGGLE))
+ #define XLAT_STR_222 STRINGIFY(KEY_KBDILLUMTOGGLE)
  [KEY_KBDILLUMDOWN] = XLAT(KEY_KBDILLUMDOWN),
+ #define XLAT_VAL_223 ((unsigned) (KEY_KBDILLUMDOWN))
+ #define XLAT_STR_223 STRINGIFY(KEY_KBDILLUMDOWN)
  [KEY_KBDILLUMUP] = XLAT(KEY_KBDILLUMUP),
+ #define XLAT_VAL_224 ((unsigned) (KEY_KBDILLUMUP))
+ #define XLAT_STR_224 STRINGIFY(KEY_KBDILLUMUP)
 
  [KEY_SEND] = XLAT(KEY_SEND),
+ #define XLAT_VAL_225 ((unsigned) (KEY_SEND))
+ #define XLAT_STR_225 STRINGIFY(KEY_SEND)
  [KEY_REPLY] = XLAT(KEY_REPLY),
+ #define XLAT_VAL_226 ((unsigned) (KEY_REPLY))
+ #define XLAT_STR_226 STRINGIFY(KEY_REPLY)
  [KEY_FORWARDMAIL] = XLAT(KEY_FORWARDMAIL),
+ #define XLAT_VAL_227 ((unsigned) (KEY_FORWARDMAIL))
+ #define XLAT_STR_227 STRINGIFY(KEY_FORWARDMAIL)
  [KEY_SAVE] = XLAT(KEY_SAVE),
+ #define XLAT_VAL_228 ((unsigned) (KEY_SAVE))
+ #define XLAT_STR_228 STRINGIFY(KEY_SAVE)
  [KEY_DOCUMENTS] = XLAT(KEY_DOCUMENTS),
+ #define XLAT_VAL_229 ((unsigned) (KEY_DOCUMENTS))
+ #define XLAT_STR_229 STRINGIFY(KEY_DOCUMENTS)
 
  [KEY_BATTERY] = XLAT(KEY_BATTERY),
+ #define XLAT_VAL_230 ((unsigned) (KEY_BATTERY))
+ #define XLAT_STR_230 STRINGIFY(KEY_BATTERY)
 
  [KEY_BLUETOOTH] = XLAT(KEY_BLUETOOTH),
+ #define XLAT_VAL_231 ((unsigned) (KEY_BLUETOOTH))
+ #define XLAT_STR_231 STRINGIFY(KEY_BLUETOOTH)
  [KEY_WLAN] = XLAT(KEY_WLAN),
+ #define XLAT_VAL_232 ((unsigned) (KEY_WLAN))
+ #define XLAT_STR_232 STRINGIFY(KEY_WLAN)
  [KEY_UWB] = XLAT(KEY_UWB),
+ #define XLAT_VAL_233 ((unsigned) (KEY_UWB))
+ #define XLAT_STR_233 STRINGIFY(KEY_UWB)
 
  [KEY_UNKNOWN] = XLAT(KEY_UNKNOWN),
+ #define XLAT_VAL_234 ((unsigned) (KEY_UNKNOWN))
+ #define XLAT_STR_234 STRINGIFY(KEY_UNKNOWN)
 
  [KEY_VIDEO_NEXT] = XLAT(KEY_VIDEO_NEXT),
+ #define XLAT_VAL_235 ((unsigned) (KEY_VIDEO_NEXT))
+ #define XLAT_STR_235 STRINGIFY(KEY_VIDEO_NEXT)
  [KEY_VIDEO_PREV] = XLAT(KEY_VIDEO_PREV),
+ #define XLAT_VAL_236 ((unsigned) (KEY_VIDEO_PREV))
+ #define XLAT_STR_236 STRINGIFY(KEY_VIDEO_PREV)
  [KEY_BRIGHTNESS_CYCLE] = XLAT(KEY_BRIGHTNESS_CYCLE),
+ #define XLAT_VAL_237 ((unsigned) (KEY_BRIGHTNESS_CYCLE))
+ #define XLAT_STR_237 STRINGIFY(KEY_BRIGHTNESS_CYCLE)
  [KEY_BRIGHTNESS_AUTO] = XLAT(KEY_BRIGHTNESS_AUTO),
+ #define XLAT_VAL_238 ((unsigned) (KEY_BRIGHTNESS_AUTO))
+ #define XLAT_STR_238 STRINGIFY(KEY_BRIGHTNESS_AUTO)
  [KEY_DISPLAY_OFF] = XLAT(KEY_DISPLAY_OFF),
+ #define XLAT_VAL_239 ((unsigned) (KEY_DISPLAY_OFF))
+ #define XLAT_STR_239 STRINGIFY(KEY_DISPLAY_OFF)
 
  [KEY_WWAN] = XLAT(KEY_WWAN),
+ #define XLAT_VAL_240 ((unsigned) (KEY_WWAN))
+ #define XLAT_STR_240 STRINGIFY(KEY_WWAN)
 
 #ifndef STRACE_WORKAROUND_FOR_KEY_RFKILL
 # define STRACE_WORKAROUND_FOR_KEY_RFKILL
@@ -4410,264 +4899,740 @@ static const struct xlat_data evdev_keyc
 # undef KEY_RFKILL
 #endif
  [KEY_RFKILL] = XLAT(KEY_RFKILL),
+ #define XLAT_VAL_241 ((unsigned) (KEY_RFKILL))
+ #define XLAT_STR_241 STRINGIFY(KEY_RFKILL)
 
  [KEY_MICMUTE] = XLAT(KEY_MICMUTE),
+ #define XLAT_VAL_242 ((unsigned) (KEY_MICMUTE))
+ #define XLAT_STR_242 STRINGIFY(KEY_MICMUTE)
 
  [BTN_0] = XLAT(BTN_0),
+ #define XLAT_VAL_243 ((unsigned) (BTN_0))
+ #define XLAT_STR_243 STRINGIFY(BTN_0)
  [BTN_1] = XLAT(BTN_1),
+ #define XLAT_VAL_244 ((unsigned) (BTN_1))
+ #define XLAT_STR_244 STRINGIFY(BTN_1)
  [BTN_2] = XLAT(BTN_2),
+ #define XLAT_VAL_245 ((unsigned) (BTN_2))
+ #define XLAT_STR_245 STRINGIFY(BTN_2)
  [BTN_3] = XLAT(BTN_3),
+ #define XLAT_VAL_246 ((unsigned) (BTN_3))
+ #define XLAT_STR_246 STRINGIFY(BTN_3)
  [BTN_4] = XLAT(BTN_4),
+ #define XLAT_VAL_247 ((unsigned) (BTN_4))
+ #define XLAT_STR_247 STRINGIFY(BTN_4)
  [BTN_5] = XLAT(BTN_5),
+ #define XLAT_VAL_248 ((unsigned) (BTN_5))
+ #define XLAT_STR_248 STRINGIFY(BTN_5)
  [BTN_6] = XLAT(BTN_6),
+ #define XLAT_VAL_249 ((unsigned) (BTN_6))
+ #define XLAT_STR_249 STRINGIFY(BTN_6)
  [BTN_7] = XLAT(BTN_7),
+ #define XLAT_VAL_250 ((unsigned) (BTN_7))
+ #define XLAT_STR_250 STRINGIFY(BTN_7)
  [BTN_8] = XLAT(BTN_8),
+ #define XLAT_VAL_251 ((unsigned) (BTN_8))
+ #define XLAT_STR_251 STRINGIFY(BTN_8)
  [BTN_9] = XLAT(BTN_9),
+ #define XLAT_VAL_252 ((unsigned) (BTN_9))
+ #define XLAT_STR_252 STRINGIFY(BTN_9)
 
  [BTN_LEFT] = XLAT(BTN_LEFT),
+ #define XLAT_VAL_253 ((unsigned) (BTN_LEFT))
+ #define XLAT_STR_253 STRINGIFY(BTN_LEFT)
  [BTN_RIGHT] = XLAT(BTN_RIGHT),
+ #define XLAT_VAL_254 ((unsigned) (BTN_RIGHT))
+ #define XLAT_STR_254 STRINGIFY(BTN_RIGHT)
  [BTN_MIDDLE] = XLAT(BTN_MIDDLE),
+ #define XLAT_VAL_255 ((unsigned) (BTN_MIDDLE))
+ #define XLAT_STR_255 STRINGIFY(BTN_MIDDLE)
  [BTN_SIDE] = XLAT(BTN_SIDE),
+ #define XLAT_VAL_256 ((unsigned) (BTN_SIDE))
+ #define XLAT_STR_256 STRINGIFY(BTN_SIDE)
  [BTN_EXTRA] = XLAT(BTN_EXTRA),
+ #define XLAT_VAL_257 ((unsigned) (BTN_EXTRA))
+ #define XLAT_STR_257 STRINGIFY(BTN_EXTRA)
  [BTN_FORWARD] = XLAT(BTN_FORWARD),
+ #define XLAT_VAL_258 ((unsigned) (BTN_FORWARD))
+ #define XLAT_STR_258 STRINGIFY(BTN_FORWARD)
  [BTN_BACK] = XLAT(BTN_BACK),
+ #define XLAT_VAL_259 ((unsigned) (BTN_BACK))
+ #define XLAT_STR_259 STRINGIFY(BTN_BACK)
  [BTN_TASK] = XLAT(BTN_TASK),
+ #define XLAT_VAL_260 ((unsigned) (BTN_TASK))
+ #define XLAT_STR_260 STRINGIFY(BTN_TASK)
 
  [BTN_TRIGGER] = XLAT(BTN_TRIGGER),
+ #define XLAT_VAL_261 ((unsigned) (BTN_TRIGGER))
+ #define XLAT_STR_261 STRINGIFY(BTN_TRIGGER)
  [BTN_THUMB] = XLAT(BTN_THUMB),
+ #define XLAT_VAL_262 ((unsigned) (BTN_THUMB))
+ #define XLAT_STR_262 STRINGIFY(BTN_THUMB)
  [BTN_THUMB2] = XLAT(BTN_THUMB2),
+ #define XLAT_VAL_263 ((unsigned) (BTN_THUMB2))
+ #define XLAT_STR_263 STRINGIFY(BTN_THUMB2)
  [BTN_TOP] = XLAT(BTN_TOP),
+ #define XLAT_VAL_264 ((unsigned) (BTN_TOP))
+ #define XLAT_STR_264 STRINGIFY(BTN_TOP)
  [BTN_TOP2] = XLAT(BTN_TOP2),
+ #define XLAT_VAL_265 ((unsigned) (BTN_TOP2))
+ #define XLAT_STR_265 STRINGIFY(BTN_TOP2)
  [BTN_PINKIE] = XLAT(BTN_PINKIE),
+ #define XLAT_VAL_266 ((unsigned) (BTN_PINKIE))
+ #define XLAT_STR_266 STRINGIFY(BTN_PINKIE)
  [BTN_BASE] = XLAT(BTN_BASE),
+ #define XLAT_VAL_267 ((unsigned) (BTN_BASE))
+ #define XLAT_STR_267 STRINGIFY(BTN_BASE)
  [BTN_BASE2] = XLAT(BTN_BASE2),
+ #define XLAT_VAL_268 ((unsigned) (BTN_BASE2))
+ #define XLAT_STR_268 STRINGIFY(BTN_BASE2)
  [BTN_BASE3] = XLAT(BTN_BASE3),
+ #define XLAT_VAL_269 ((unsigned) (BTN_BASE3))
+ #define XLAT_STR_269 STRINGIFY(BTN_BASE3)
  [BTN_BASE4] = XLAT(BTN_BASE4),
+ #define XLAT_VAL_270 ((unsigned) (BTN_BASE4))
+ #define XLAT_STR_270 STRINGIFY(BTN_BASE4)
  [BTN_BASE5] = XLAT(BTN_BASE5),
+ #define XLAT_VAL_271 ((unsigned) (BTN_BASE5))
+ #define XLAT_STR_271 STRINGIFY(BTN_BASE5)
  [BTN_BASE6] = XLAT(BTN_BASE6),
+ #define XLAT_VAL_272 ((unsigned) (BTN_BASE6))
+ #define XLAT_STR_272 STRINGIFY(BTN_BASE6)
  [BTN_DEAD] = XLAT(BTN_DEAD),
+ #define XLAT_VAL_273 ((unsigned) (BTN_DEAD))
+ #define XLAT_STR_273 STRINGIFY(BTN_DEAD)
 
  [BTN_SOUTH] = XLAT(BTN_SOUTH),
+ #define XLAT_VAL_274 ((unsigned) (BTN_SOUTH))
+ #define XLAT_STR_274 STRINGIFY(BTN_SOUTH)
  [BTN_EAST] = XLAT(BTN_EAST),
+ #define XLAT_VAL_275 ((unsigned) (BTN_EAST))
+ #define XLAT_STR_275 STRINGIFY(BTN_EAST)
  [BTN_C] = XLAT(BTN_C),
+ #define XLAT_VAL_276 ((unsigned) (BTN_C))
+ #define XLAT_STR_276 STRINGIFY(BTN_C)
  [BTN_NORTH] = XLAT(BTN_NORTH),
+ #define XLAT_VAL_277 ((unsigned) (BTN_NORTH))
+ #define XLAT_STR_277 STRINGIFY(BTN_NORTH)
  [BTN_WEST] = XLAT(BTN_WEST),
+ #define XLAT_VAL_278 ((unsigned) (BTN_WEST))
+ #define XLAT_STR_278 STRINGIFY(BTN_WEST)
  [BTN_Z] = XLAT(BTN_Z),
+ #define XLAT_VAL_279 ((unsigned) (BTN_Z))
+ #define XLAT_STR_279 STRINGIFY(BTN_Z)
  [BTN_TL] = XLAT(BTN_TL),
+ #define XLAT_VAL_280 ((unsigned) (BTN_TL))
+ #define XLAT_STR_280 STRINGIFY(BTN_TL)
  [BTN_TR] = XLAT(BTN_TR),
+ #define XLAT_VAL_281 ((unsigned) (BTN_TR))
+ #define XLAT_STR_281 STRINGIFY(BTN_TR)
  [BTN_TL2] = XLAT(BTN_TL2),
+ #define XLAT_VAL_282 ((unsigned) (BTN_TL2))
+ #define XLAT_STR_282 STRINGIFY(BTN_TL2)
  [BTN_TR2] = XLAT(BTN_TR2),
+ #define XLAT_VAL_283 ((unsigned) (BTN_TR2))
+ #define XLAT_STR_283 STRINGIFY(BTN_TR2)
  [BTN_SELECT] = XLAT(BTN_SELECT),
+ #define XLAT_VAL_284 ((unsigned) (BTN_SELECT))
+ #define XLAT_STR_284 STRINGIFY(BTN_SELECT)
  [BTN_START] = XLAT(BTN_START),
+ #define XLAT_VAL_285 ((unsigned) (BTN_START))
+ #define XLAT_STR_285 STRINGIFY(BTN_START)
  [BTN_MODE] = XLAT(BTN_MODE),
+ #define XLAT_VAL_286 ((unsigned) (BTN_MODE))
+ #define XLAT_STR_286 STRINGIFY(BTN_MODE)
  [BTN_THUMBL] = XLAT(BTN_THUMBL),
+ #define XLAT_VAL_287 ((unsigned) (BTN_THUMBL))
+ #define XLAT_STR_287 STRINGIFY(BTN_THUMBL)
  [BTN_THUMBR] = XLAT(BTN_THUMBR),
+ #define XLAT_VAL_288 ((unsigned) (BTN_THUMBR))
+ #define XLAT_STR_288 STRINGIFY(BTN_THUMBR)
 
  [BTN_TOOL_PEN] = XLAT(BTN_TOOL_PEN),
+ #define XLAT_VAL_289 ((unsigned) (BTN_TOOL_PEN))
+ #define XLAT_STR_289 STRINGIFY(BTN_TOOL_PEN)
  [BTN_TOOL_RUBBER] = XLAT(BTN_TOOL_RUBBER),
+ #define XLAT_VAL_290 ((unsigned) (BTN_TOOL_RUBBER))
+ #define XLAT_STR_290 STRINGIFY(BTN_TOOL_RUBBER)
  [BTN_TOOL_BRUSH] = XLAT(BTN_TOOL_BRUSH),
+ #define XLAT_VAL_291 ((unsigned) (BTN_TOOL_BRUSH))
+ #define XLAT_STR_291 STRINGIFY(BTN_TOOL_BRUSH)
  [BTN_TOOL_PENCIL] = XLAT(BTN_TOOL_PENCIL),
+ #define XLAT_VAL_292 ((unsigned) (BTN_TOOL_PENCIL))
+ #define XLAT_STR_292 STRINGIFY(BTN_TOOL_PENCIL)
  [BTN_TOOL_AIRBRUSH] = XLAT(BTN_TOOL_AIRBRUSH),
+ #define XLAT_VAL_293 ((unsigned) (BTN_TOOL_AIRBRUSH))
+ #define XLAT_STR_293 STRINGIFY(BTN_TOOL_AIRBRUSH)
  [BTN_TOOL_FINGER] = XLAT(BTN_TOOL_FINGER),
+ #define XLAT_VAL_294 ((unsigned) (BTN_TOOL_FINGER))
+ #define XLAT_STR_294 STRINGIFY(BTN_TOOL_FINGER)
  [BTN_TOOL_MOUSE] = XLAT(BTN_TOOL_MOUSE),
+ #define XLAT_VAL_295 ((unsigned) (BTN_TOOL_MOUSE))
+ #define XLAT_STR_295 STRINGIFY(BTN_TOOL_MOUSE)
  [BTN_TOOL_LENS] = XLAT(BTN_TOOL_LENS),
+ #define XLAT_VAL_296 ((unsigned) (BTN_TOOL_LENS))
+ #define XLAT_STR_296 STRINGIFY(BTN_TOOL_LENS)
  [BTN_TOOL_QUINTTAP] = XLAT(BTN_TOOL_QUINTTAP),
+ #define XLAT_VAL_297 ((unsigned) (BTN_TOOL_QUINTTAP))
+ #define XLAT_STR_297 STRINGIFY(BTN_TOOL_QUINTTAP)
  [BTN_STYLUS3] = XLAT(BTN_STYLUS3),
+ #define XLAT_VAL_298 ((unsigned) (BTN_STYLUS3))
+ #define XLAT_STR_298 STRINGIFY(BTN_STYLUS3)
  [BTN_TOUCH] = XLAT(BTN_TOUCH),
+ #define XLAT_VAL_299 ((unsigned) (BTN_TOUCH))
+ #define XLAT_STR_299 STRINGIFY(BTN_TOUCH)
  [BTN_STYLUS] = XLAT(BTN_STYLUS),
+ #define XLAT_VAL_300 ((unsigned) (BTN_STYLUS))
+ #define XLAT_STR_300 STRINGIFY(BTN_STYLUS)
  [BTN_STYLUS2] = XLAT(BTN_STYLUS2),
+ #define XLAT_VAL_301 ((unsigned) (BTN_STYLUS2))
+ #define XLAT_STR_301 STRINGIFY(BTN_STYLUS2)
  [BTN_TOOL_DOUBLETAP] = XLAT(BTN_TOOL_DOUBLETAP),
+ #define XLAT_VAL_302 ((unsigned) (BTN_TOOL_DOUBLETAP))
+ #define XLAT_STR_302 STRINGIFY(BTN_TOOL_DOUBLETAP)
  [BTN_TOOL_TRIPLETAP] = XLAT(BTN_TOOL_TRIPLETAP),
+ #define XLAT_VAL_303 ((unsigned) (BTN_TOOL_TRIPLETAP))
+ #define XLAT_STR_303 STRINGIFY(BTN_TOOL_TRIPLETAP)
  [BTN_TOOL_QUADTAP] = XLAT(BTN_TOOL_QUADTAP),
+ #define XLAT_VAL_304 ((unsigned) (BTN_TOOL_QUADTAP))
+ #define XLAT_STR_304 STRINGIFY(BTN_TOOL_QUADTAP)
 
  [BTN_GEAR_DOWN] = XLAT(BTN_GEAR_DOWN),
+ #define XLAT_VAL_305 ((unsigned) (BTN_GEAR_DOWN))
+ #define XLAT_STR_305 STRINGIFY(BTN_GEAR_DOWN)
  [BTN_GEAR_UP] = XLAT(BTN_GEAR_UP),
+ #define XLAT_VAL_306 ((unsigned) (BTN_GEAR_UP))
+ #define XLAT_STR_306 STRINGIFY(BTN_GEAR_UP)
 
  [KEY_OK] = XLAT(KEY_OK),
+ #define XLAT_VAL_307 ((unsigned) (KEY_OK))
+ #define XLAT_STR_307 STRINGIFY(KEY_OK)
  [KEY_SELECT] = XLAT(KEY_SELECT),
+ #define XLAT_VAL_308 ((unsigned) (KEY_SELECT))
+ #define XLAT_STR_308 STRINGIFY(KEY_SELECT)
  [KEY_GOTO] = XLAT(KEY_GOTO),
+ #define XLAT_VAL_309 ((unsigned) (KEY_GOTO))
+ #define XLAT_STR_309 STRINGIFY(KEY_GOTO)
  [KEY_CLEAR] = XLAT(KEY_CLEAR),
+ #define XLAT_VAL_310 ((unsigned) (KEY_CLEAR))
+ #define XLAT_STR_310 STRINGIFY(KEY_CLEAR)
  [KEY_POWER2] = XLAT(KEY_POWER2),
+ #define XLAT_VAL_311 ((unsigned) (KEY_POWER2))
+ #define XLAT_STR_311 STRINGIFY(KEY_POWER2)
  [KEY_OPTION] = XLAT(KEY_OPTION),
+ #define XLAT_VAL_312 ((unsigned) (KEY_OPTION))
+ #define XLAT_STR_312 STRINGIFY(KEY_OPTION)
  [KEY_INFO] = XLAT(KEY_INFO),
+ #define XLAT_VAL_313 ((unsigned) (KEY_INFO))
+ #define XLAT_STR_313 STRINGIFY(KEY_INFO)
  [KEY_TIME] = XLAT(KEY_TIME),
+ #define XLAT_VAL_314 ((unsigned) (KEY_TIME))
+ #define XLAT_STR_314 STRINGIFY(KEY_TIME)
  [KEY_VENDOR] = XLAT(KEY_VENDOR),
+ #define XLAT_VAL_315 ((unsigned) (KEY_VENDOR))
+ #define XLAT_STR_315 STRINGIFY(KEY_VENDOR)
  [KEY_ARCHIVE] = XLAT(KEY_ARCHIVE),
+ #define XLAT_VAL_316 ((unsigned) (KEY_ARCHIVE))
+ #define XLAT_STR_316 STRINGIFY(KEY_ARCHIVE)
  [KEY_PROGRAM] = XLAT(KEY_PROGRAM),
+ #define XLAT_VAL_317 ((unsigned) (KEY_PROGRAM))
+ #define XLAT_STR_317 STRINGIFY(KEY_PROGRAM)
  [KEY_CHANNEL] = XLAT(KEY_CHANNEL),
+ #define XLAT_VAL_318 ((unsigned) (KEY_CHANNEL))
+ #define XLAT_STR_318 STRINGIFY(KEY_CHANNEL)
  [KEY_FAVORITES] = XLAT(KEY_FAVORITES),
+ #define XLAT_VAL_319 ((unsigned) (KEY_FAVORITES))
+ #define XLAT_STR_319 STRINGIFY(KEY_FAVORITES)
  [KEY_EPG] = XLAT(KEY_EPG),
+ #define XLAT_VAL_320 ((unsigned) (KEY_EPG))
+ #define XLAT_STR_320 STRINGIFY(KEY_EPG)
  [KEY_PVR] = XLAT(KEY_PVR),
+ #define XLAT_VAL_321 ((unsigned) (KEY_PVR))
+ #define XLAT_STR_321 STRINGIFY(KEY_PVR)
  [KEY_MHP] = XLAT(KEY_MHP),
+ #define XLAT_VAL_322 ((unsigned) (KEY_MHP))
+ #define XLAT_STR_322 STRINGIFY(KEY_MHP)
  [KEY_LANGUAGE] = XLAT(KEY_LANGUAGE),
+ #define XLAT_VAL_323 ((unsigned) (KEY_LANGUAGE))
+ #define XLAT_STR_323 STRINGIFY(KEY_LANGUAGE)
  [KEY_TITLE] = XLAT(KEY_TITLE),
+ #define XLAT_VAL_324 ((unsigned) (KEY_TITLE))
+ #define XLAT_STR_324 STRINGIFY(KEY_TITLE)
  [KEY_SUBTITLE] = XLAT(KEY_SUBTITLE),
+ #define XLAT_VAL_325 ((unsigned) (KEY_SUBTITLE))
+ #define XLAT_STR_325 STRINGIFY(KEY_SUBTITLE)
  [KEY_ANGLE] = XLAT(KEY_ANGLE),
+ #define XLAT_VAL_326 ((unsigned) (KEY_ANGLE))
+ #define XLAT_STR_326 STRINGIFY(KEY_ANGLE)
  [KEY_ZOOM] = XLAT(KEY_ZOOM),
+ #define XLAT_VAL_327 ((unsigned) (KEY_ZOOM))
+ #define XLAT_STR_327 STRINGIFY(KEY_ZOOM)
  [KEY_MODE] = XLAT(KEY_MODE),
+ #define XLAT_VAL_328 ((unsigned) (KEY_MODE))
+ #define XLAT_STR_328 STRINGIFY(KEY_MODE)
  [KEY_KEYBOARD] = XLAT(KEY_KEYBOARD),
+ #define XLAT_VAL_329 ((unsigned) (KEY_KEYBOARD))
+ #define XLAT_STR_329 STRINGIFY(KEY_KEYBOARD)
  [KEY_SCREEN] = XLAT(KEY_SCREEN),
+ #define XLAT_VAL_330 ((unsigned) (KEY_SCREEN))
+ #define XLAT_STR_330 STRINGIFY(KEY_SCREEN)
  [KEY_PC] = XLAT(KEY_PC),
+ #define XLAT_VAL_331 ((unsigned) (KEY_PC))
+ #define XLAT_STR_331 STRINGIFY(KEY_PC)
  [KEY_TV] = XLAT(KEY_TV),
+ #define XLAT_VAL_332 ((unsigned) (KEY_TV))
+ #define XLAT_STR_332 STRINGIFY(KEY_TV)
  [KEY_TV2] = XLAT(KEY_TV2),
+ #define XLAT_VAL_333 ((unsigned) (KEY_TV2))
+ #define XLAT_STR_333 STRINGIFY(KEY_TV2)
  [KEY_VCR] = XLAT(KEY_VCR),
+ #define XLAT_VAL_334 ((unsigned) (KEY_VCR))
+ #define XLAT_STR_334 STRINGIFY(KEY_VCR)
  [KEY_VCR2] = XLAT(KEY_VCR2),
+ #define XLAT_VAL_335 ((unsigned) (KEY_VCR2))
+ #define XLAT_STR_335 STRINGIFY(KEY_VCR2)
  [KEY_SAT] = XLAT(KEY_SAT),
+ #define XLAT_VAL_336 ((unsigned) (KEY_SAT))
+ #define XLAT_STR_336 STRINGIFY(KEY_SAT)
  [KEY_SAT2] = XLAT(KEY_SAT2),
+ #define XLAT_VAL_337 ((unsigned) (KEY_SAT2))
+ #define XLAT_STR_337 STRINGIFY(KEY_SAT2)
  [KEY_CD] = XLAT(KEY_CD),
+ #define XLAT_VAL_338 ((unsigned) (KEY_CD))
+ #define XLAT_STR_338 STRINGIFY(KEY_CD)
  [KEY_TAPE] = XLAT(KEY_TAPE),
+ #define XLAT_VAL_339 ((unsigned) (KEY_TAPE))
+ #define XLAT_STR_339 STRINGIFY(KEY_TAPE)
  [KEY_RADIO] = XLAT(KEY_RADIO),
+ #define XLAT_VAL_340 ((unsigned) (KEY_RADIO))
+ #define XLAT_STR_340 STRINGIFY(KEY_RADIO)
  [KEY_TUNER] = XLAT(KEY_TUNER),
+ #define XLAT_VAL_341 ((unsigned) (KEY_TUNER))
+ #define XLAT_STR_341 STRINGIFY(KEY_TUNER)
  [KEY_PLAYER] = XLAT(KEY_PLAYER),
+ #define XLAT_VAL_342 ((unsigned) (KEY_PLAYER))
+ #define XLAT_STR_342 STRINGIFY(KEY_PLAYER)
  [KEY_TEXT] = XLAT(KEY_TEXT),
+ #define XLAT_VAL_343 ((unsigned) (KEY_TEXT))
+ #define XLAT_STR_343 STRINGIFY(KEY_TEXT)
  [KEY_DVD] = XLAT(KEY_DVD),
+ #define XLAT_VAL_344 ((unsigned) (KEY_DVD))
+ #define XLAT_STR_344 STRINGIFY(KEY_DVD)
  [KEY_AUX] = XLAT(KEY_AUX),
+ #define XLAT_VAL_345 ((unsigned) (KEY_AUX))
+ #define XLAT_STR_345 STRINGIFY(KEY_AUX)
  [KEY_MP3] = XLAT(KEY_MP3),
+ #define XLAT_VAL_346 ((unsigned) (KEY_MP3))
+ #define XLAT_STR_346 STRINGIFY(KEY_MP3)
  [KEY_AUDIO] = XLAT(KEY_AUDIO),
+ #define XLAT_VAL_347 ((unsigned) (KEY_AUDIO))
+ #define XLAT_STR_347 STRINGIFY(KEY_AUDIO)
  [KEY_VIDEO] = XLAT(KEY_VIDEO),
+ #define XLAT_VAL_348 ((unsigned) (KEY_VIDEO))
+ #define XLAT_STR_348 STRINGIFY(KEY_VIDEO)
  [KEY_DIRECTORY] = XLAT(KEY_DIRECTORY),
+ #define XLAT_VAL_349 ((unsigned) (KEY_DIRECTORY))
+ #define XLAT_STR_349 STRINGIFY(KEY_DIRECTORY)
  [KEY_LIST] = XLAT(KEY_LIST),
+ #define XLAT_VAL_350 ((unsigned) (KEY_LIST))
+ #define XLAT_STR_350 STRINGIFY(KEY_LIST)
  [KEY_MEMO] = XLAT(KEY_MEMO),
+ #define XLAT_VAL_351 ((unsigned) (KEY_MEMO))
+ #define XLAT_STR_351 STRINGIFY(KEY_MEMO)
  [KEY_CALENDAR] = XLAT(KEY_CALENDAR),
+ #define XLAT_VAL_352 ((unsigned) (KEY_CALENDAR))
+ #define XLAT_STR_352 STRINGIFY(KEY_CALENDAR)
  [KEY_RED] = XLAT(KEY_RED),
+ #define XLAT_VAL_353 ((unsigned) (KEY_RED))
+ #define XLAT_STR_353 STRINGIFY(KEY_RED)
  [KEY_GREEN] = XLAT(KEY_GREEN),
+ #define XLAT_VAL_354 ((unsigned) (KEY_GREEN))
+ #define XLAT_STR_354 STRINGIFY(KEY_GREEN)
  [KEY_YELLOW] = XLAT(KEY_YELLOW),
+ #define XLAT_VAL_355 ((unsigned) (KEY_YELLOW))
+ #define XLAT_STR_355 STRINGIFY(KEY_YELLOW)
  [KEY_BLUE] = XLAT(KEY_BLUE),
+ #define XLAT_VAL_356 ((unsigned) (KEY_BLUE))
+ #define XLAT_STR_356 STRINGIFY(KEY_BLUE)
  [KEY_CHANNELUP] = XLAT(KEY_CHANNELUP),
+ #define XLAT_VAL_357 ((unsigned) (KEY_CHANNELUP))
+ #define XLAT_STR_357 STRINGIFY(KEY_CHANNELUP)
  [KEY_CHANNELDOWN] = XLAT(KEY_CHANNELDOWN),
+ #define XLAT_VAL_358 ((unsigned) (KEY_CHANNELDOWN))
+ #define XLAT_STR_358 STRINGIFY(KEY_CHANNELDOWN)
  [KEY_FIRST] = XLAT(KEY_FIRST),
+ #define XLAT_VAL_359 ((unsigned) (KEY_FIRST))
+ #define XLAT_STR_359 STRINGIFY(KEY_FIRST)
  [KEY_LAST] = XLAT(KEY_LAST),
+ #define XLAT_VAL_360 ((unsigned) (KEY_LAST))
+ #define XLAT_STR_360 STRINGIFY(KEY_LAST)
  [KEY_AB] = XLAT(KEY_AB),
+ #define XLAT_VAL_361 ((unsigned) (KEY_AB))
+ #define XLAT_STR_361 STRINGIFY(KEY_AB)
  [KEY_NEXT] = XLAT(KEY_NEXT),
+ #define XLAT_VAL_362 ((unsigned) (KEY_NEXT))
+ #define XLAT_STR_362 STRINGIFY(KEY_NEXT)
  [KEY_RESTART] = XLAT(KEY_RESTART),
+ #define XLAT_VAL_363 ((unsigned) (KEY_RESTART))
+ #define XLAT_STR_363 STRINGIFY(KEY_RESTART)
  [KEY_SLOW] = XLAT(KEY_SLOW),
+ #define XLAT_VAL_364 ((unsigned) (KEY_SLOW))
+ #define XLAT_STR_364 STRINGIFY(KEY_SLOW)
  [KEY_SHUFFLE] = XLAT(KEY_SHUFFLE),
+ #define XLAT_VAL_365 ((unsigned) (KEY_SHUFFLE))
+ #define XLAT_STR_365 STRINGIFY(KEY_SHUFFLE)
  [KEY_BREAK] = XLAT(KEY_BREAK),
+ #define XLAT_VAL_366 ((unsigned) (KEY_BREAK))
+ #define XLAT_STR_366 STRINGIFY(KEY_BREAK)
  [KEY_PREVIOUS] = XLAT(KEY_PREVIOUS),
+ #define XLAT_VAL_367 ((unsigned) (KEY_PREVIOUS))
+ #define XLAT_STR_367 STRINGIFY(KEY_PREVIOUS)
  [KEY_DIGITS] = XLAT(KEY_DIGITS),
+ #define XLAT_VAL_368 ((unsigned) (KEY_DIGITS))
+ #define XLAT_STR_368 STRINGIFY(KEY_DIGITS)
  [KEY_TEEN] = XLAT(KEY_TEEN),
+ #define XLAT_VAL_369 ((unsigned) (KEY_TEEN))
+ #define XLAT_STR_369 STRINGIFY(KEY_TEEN)
  [KEY_TWEN] = XLAT(KEY_TWEN),
+ #define XLAT_VAL_370 ((unsigned) (KEY_TWEN))
+ #define XLAT_STR_370 STRINGIFY(KEY_TWEN)
  [KEY_VIDEOPHONE] = XLAT(KEY_VIDEOPHONE),
+ #define XLAT_VAL_371 ((unsigned) (KEY_VIDEOPHONE))
+ #define XLAT_STR_371 STRINGIFY(KEY_VIDEOPHONE)
  [KEY_GAMES] = XLAT(KEY_GAMES),
+ #define XLAT_VAL_372 ((unsigned) (KEY_GAMES))
+ #define XLAT_STR_372 STRINGIFY(KEY_GAMES)
  [KEY_ZOOMIN] = XLAT(KEY_ZOOMIN),
+ #define XLAT_VAL_373 ((unsigned) (KEY_ZOOMIN))
+ #define XLAT_STR_373 STRINGIFY(KEY_ZOOMIN)
  [KEY_ZOOMOUT] = XLAT(KEY_ZOOMOUT),
+ #define XLAT_VAL_374 ((unsigned) (KEY_ZOOMOUT))
+ #define XLAT_STR_374 STRINGIFY(KEY_ZOOMOUT)
  [KEY_ZOOMRESET] = XLAT(KEY_ZOOMRESET),
+ #define XLAT_VAL_375 ((unsigned) (KEY_ZOOMRESET))
+ #define XLAT_STR_375 STRINGIFY(KEY_ZOOMRESET)
  [KEY_WORDPROCESSOR] = XLAT(KEY_WORDPROCESSOR),
+ #define XLAT_VAL_376 ((unsigned) (KEY_WORDPROCESSOR))
+ #define XLAT_STR_376 STRINGIFY(KEY_WORDPROCESSOR)
  [KEY_EDITOR] = XLAT(KEY_EDITOR),
+ #define XLAT_VAL_377 ((unsigned) (KEY_EDITOR))
+ #define XLAT_STR_377 STRINGIFY(KEY_EDITOR)
  [KEY_SPREADSHEET] = XLAT(KEY_SPREADSHEET),
+ #define XLAT_VAL_378 ((unsigned) (KEY_SPREADSHEET))
+ #define XLAT_STR_378 STRINGIFY(KEY_SPREADSHEET)
  [KEY_GRAPHICSEDITOR] = XLAT(KEY_GRAPHICSEDITOR),
+ #define XLAT_VAL_379 ((unsigned) (KEY_GRAPHICSEDITOR))
+ #define XLAT_STR_379 STRINGIFY(KEY_GRAPHICSEDITOR)
  [KEY_PRESENTATION] = XLAT(KEY_PRESENTATION),
+ #define XLAT_VAL_380 ((unsigned) (KEY_PRESENTATION))
+ #define XLAT_STR_380 STRINGIFY(KEY_PRESENTATION)
  [KEY_DATABASE] = XLAT(KEY_DATABASE),
+ #define XLAT_VAL_381 ((unsigned) (KEY_DATABASE))
+ #define XLAT_STR_381 STRINGIFY(KEY_DATABASE)
  [KEY_NEWS] = XLAT(KEY_NEWS),
+ #define XLAT_VAL_382 ((unsigned) (KEY_NEWS))
+ #define XLAT_STR_382 STRINGIFY(KEY_NEWS)
  [KEY_VOICEMAIL] = XLAT(KEY_VOICEMAIL),
+ #define XLAT_VAL_383 ((unsigned) (KEY_VOICEMAIL))
+ #define XLAT_STR_383 STRINGIFY(KEY_VOICEMAIL)
  [KEY_ADDRESSBOOK] = XLAT(KEY_ADDRESSBOOK),
+ #define XLAT_VAL_384 ((unsigned) (KEY_ADDRESSBOOK))
+ #define XLAT_STR_384 STRINGIFY(KEY_ADDRESSBOOK)
  [KEY_MESSENGER] = XLAT(KEY_MESSENGER),
+ #define XLAT_VAL_385 ((unsigned) (KEY_MESSENGER))
+ #define XLAT_STR_385 STRINGIFY(KEY_MESSENGER)
  [KEY_DISPLAYTOGGLE] = XLAT(KEY_DISPLAYTOGGLE),
+ #define XLAT_VAL_386 ((unsigned) (KEY_DISPLAYTOGGLE))
+ #define XLAT_STR_386 STRINGIFY(KEY_DISPLAYTOGGLE)
  [KEY_SPELLCHECK] = XLAT(KEY_SPELLCHECK),
+ #define XLAT_VAL_387 ((unsigned) (KEY_SPELLCHECK))
+ #define XLAT_STR_387 STRINGIFY(KEY_SPELLCHECK)
  [KEY_LOGOFF] = XLAT(KEY_LOGOFF),
+ #define XLAT_VAL_388 ((unsigned) (KEY_LOGOFF))
+ #define XLAT_STR_388 STRINGIFY(KEY_LOGOFF)
 
  [KEY_DOLLAR] = XLAT(KEY_DOLLAR),
+ #define XLAT_VAL_389 ((unsigned) (KEY_DOLLAR))
+ #define XLAT_STR_389 STRINGIFY(KEY_DOLLAR)
  [KEY_EURO] = XLAT(KEY_EURO),
+ #define XLAT_VAL_390 ((unsigned) (KEY_EURO))
+ #define XLAT_STR_390 STRINGIFY(KEY_EURO)
 
  [KEY_FRAMEBACK] = XLAT(KEY_FRAMEBACK),
+ #define XLAT_VAL_391 ((unsigned) (KEY_FRAMEBACK))
+ #define XLAT_STR_391 STRINGIFY(KEY_FRAMEBACK)
  [KEY_FRAMEFORWARD] = XLAT(KEY_FRAMEFORWARD),
+ #define XLAT_VAL_392 ((unsigned) (KEY_FRAMEFORWARD))
+ #define XLAT_STR_392 STRINGIFY(KEY_FRAMEFORWARD)
  [KEY_CONTEXT_MENU] = XLAT(KEY_CONTEXT_MENU),
+ #define XLAT_VAL_393 ((unsigned) (KEY_CONTEXT_MENU))
+ #define XLAT_STR_393 STRINGIFY(KEY_CONTEXT_MENU)
  [KEY_MEDIA_REPEAT] = XLAT(KEY_MEDIA_REPEAT),
+ #define XLAT_VAL_394 ((unsigned) (KEY_MEDIA_REPEAT))
+ #define XLAT_STR_394 STRINGIFY(KEY_MEDIA_REPEAT)
  [KEY_10CHANNELSUP] = XLAT(KEY_10CHANNELSUP),
+ #define XLAT_VAL_395 ((unsigned) (KEY_10CHANNELSUP))
+ #define XLAT_STR_395 STRINGIFY(KEY_10CHANNELSUP)
  [KEY_10CHANNELSDOWN] = XLAT(KEY_10CHANNELSDOWN),
+ #define XLAT_VAL_396 ((unsigned) (KEY_10CHANNELSDOWN))
+ #define XLAT_STR_396 STRINGIFY(KEY_10CHANNELSDOWN)
  [KEY_IMAGES] = XLAT(KEY_IMAGES),
+ #define XLAT_VAL_397 ((unsigned) (KEY_IMAGES))
+ #define XLAT_STR_397 STRINGIFY(KEY_IMAGES)
 
  [KEY_DEL_EOL] = XLAT(KEY_DEL_EOL),
+ #define XLAT_VAL_398 ((unsigned) (KEY_DEL_EOL))
+ #define XLAT_STR_398 STRINGIFY(KEY_DEL_EOL)
  [KEY_DEL_EOS] = XLAT(KEY_DEL_EOS),
+ #define XLAT_VAL_399 ((unsigned) (KEY_DEL_EOS))
+ #define XLAT_STR_399 STRINGIFY(KEY_DEL_EOS)
  [KEY_INS_LINE] = XLAT(KEY_INS_LINE),
+ #define XLAT_VAL_400 ((unsigned) (KEY_INS_LINE))
+ #define XLAT_STR_400 STRINGIFY(KEY_INS_LINE)
  [KEY_DEL_LINE] = XLAT(KEY_DEL_LINE),
+ #define XLAT_VAL_401 ((unsigned) (KEY_DEL_LINE))
+ #define XLAT_STR_401 STRINGIFY(KEY_DEL_LINE)
 
  [KEY_FN] = XLAT(KEY_FN),
+ #define XLAT_VAL_402 ((unsigned) (KEY_FN))
+ #define XLAT_STR_402 STRINGIFY(KEY_FN)
  [KEY_FN_ESC] = XLAT(KEY_FN_ESC),
+ #define XLAT_VAL_403 ((unsigned) (KEY_FN_ESC))
+ #define XLAT_STR_403 STRINGIFY(KEY_FN_ESC)
  [KEY_FN_F1] = XLAT(KEY_FN_F1),
+ #define XLAT_VAL_404 ((unsigned) (KEY_FN_F1))
+ #define XLAT_STR_404 STRINGIFY(KEY_FN_F1)
  [KEY_FN_F2] = XLAT(KEY_FN_F2),
+ #define XLAT_VAL_405 ((unsigned) (KEY_FN_F2))
+ #define XLAT_STR_405 STRINGIFY(KEY_FN_F2)
  [KEY_FN_F3] = XLAT(KEY_FN_F3),
+ #define XLAT_VAL_406 ((unsigned) (KEY_FN_F3))
+ #define XLAT_STR_406 STRINGIFY(KEY_FN_F3)
  [KEY_FN_F4] = XLAT(KEY_FN_F4),
+ #define XLAT_VAL_407 ((unsigned) (KEY_FN_F4))
+ #define XLAT_STR_407 STRINGIFY(KEY_FN_F4)
  [KEY_FN_F5] = XLAT(KEY_FN_F5),
+ #define XLAT_VAL_408 ((unsigned) (KEY_FN_F5))
+ #define XLAT_STR_408 STRINGIFY(KEY_FN_F5)
  [KEY_FN_F6] = XLAT(KEY_FN_F6),
+ #define XLAT_VAL_409 ((unsigned) (KEY_FN_F6))
+ #define XLAT_STR_409 STRINGIFY(KEY_FN_F6)
  [KEY_FN_F7] = XLAT(KEY_FN_F7),
+ #define XLAT_VAL_410 ((unsigned) (KEY_FN_F7))
+ #define XLAT_STR_410 STRINGIFY(KEY_FN_F7)
  [KEY_FN_F8] = XLAT(KEY_FN_F8),
+ #define XLAT_VAL_411 ((unsigned) (KEY_FN_F8))
+ #define XLAT_STR_411 STRINGIFY(KEY_FN_F8)
  [KEY_FN_F9] = XLAT(KEY_FN_F9),
+ #define XLAT_VAL_412 ((unsigned) (KEY_FN_F9))
+ #define XLAT_STR_412 STRINGIFY(KEY_FN_F9)
  [KEY_FN_F10] = XLAT(KEY_FN_F10),
+ #define XLAT_VAL_413 ((unsigned) (KEY_FN_F10))
+ #define XLAT_STR_413 STRINGIFY(KEY_FN_F10)
  [KEY_FN_F11] = XLAT(KEY_FN_F11),
+ #define XLAT_VAL_414 ((unsigned) (KEY_FN_F11))
+ #define XLAT_STR_414 STRINGIFY(KEY_FN_F11)
  [KEY_FN_F12] = XLAT(KEY_FN_F12),
+ #define XLAT_VAL_415 ((unsigned) (KEY_FN_F12))
+ #define XLAT_STR_415 STRINGIFY(KEY_FN_F12)
  [KEY_FN_1] = XLAT(KEY_FN_1),
+ #define XLAT_VAL_416 ((unsigned) (KEY_FN_1))
+ #define XLAT_STR_416 STRINGIFY(KEY_FN_1)
  [KEY_FN_2] = XLAT(KEY_FN_2),
+ #define XLAT_VAL_417 ((unsigned) (KEY_FN_2))
+ #define XLAT_STR_417 STRINGIFY(KEY_FN_2)
  [KEY_FN_D] = XLAT(KEY_FN_D),
+ #define XLAT_VAL_418 ((unsigned) (KEY_FN_D))
+ #define XLAT_STR_418 STRINGIFY(KEY_FN_D)
  [KEY_FN_E] = XLAT(KEY_FN_E),
+ #define XLAT_VAL_419 ((unsigned) (KEY_FN_E))
+ #define XLAT_STR_419 STRINGIFY(KEY_FN_E)
  [KEY_FN_F] = XLAT(KEY_FN_F),
+ #define XLAT_VAL_420 ((unsigned) (KEY_FN_F))
+ #define XLAT_STR_420 STRINGIFY(KEY_FN_F)
  [KEY_FN_S] = XLAT(KEY_FN_S),
+ #define XLAT_VAL_421 ((unsigned) (KEY_FN_S))
+ #define XLAT_STR_421 STRINGIFY(KEY_FN_S)
  [KEY_FN_B] = XLAT(KEY_FN_B),
+ #define XLAT_VAL_422 ((unsigned) (KEY_FN_B))
+ #define XLAT_STR_422 STRINGIFY(KEY_FN_B)
 
  [KEY_BRL_DOT1] = XLAT(KEY_BRL_DOT1),
+ #define XLAT_VAL_423 ((unsigned) (KEY_BRL_DOT1))
+ #define XLAT_STR_423 STRINGIFY(KEY_BRL_DOT1)
  [KEY_BRL_DOT2] = XLAT(KEY_BRL_DOT2),
+ #define XLAT_VAL_424 ((unsigned) (KEY_BRL_DOT2))
+ #define XLAT_STR_424 STRINGIFY(KEY_BRL_DOT2)
  [KEY_BRL_DOT3] = XLAT(KEY_BRL_DOT3),
+ #define XLAT_VAL_425 ((unsigned) (KEY_BRL_DOT3))
+ #define XLAT_STR_425 STRINGIFY(KEY_BRL_DOT3)
  [KEY_BRL_DOT4] = XLAT(KEY_BRL_DOT4),
+ #define XLAT_VAL_426 ((unsigned) (KEY_BRL_DOT4))
+ #define XLAT_STR_426 STRINGIFY(KEY_BRL_DOT4)
  [KEY_BRL_DOT5] = XLAT(KEY_BRL_DOT5),
+ #define XLAT_VAL_427 ((unsigned) (KEY_BRL_DOT5))
+ #define XLAT_STR_427 STRINGIFY(KEY_BRL_DOT5)
  [KEY_BRL_DOT6] = XLAT(KEY_BRL_DOT6),
+ #define XLAT_VAL_428 ((unsigned) (KEY_BRL_DOT6))
+ #define XLAT_STR_428 STRINGIFY(KEY_BRL_DOT6)
  [KEY_BRL_DOT7] = XLAT(KEY_BRL_DOT7),
+ #define XLAT_VAL_429 ((unsigned) (KEY_BRL_DOT7))
+ #define XLAT_STR_429 STRINGIFY(KEY_BRL_DOT7)
  [KEY_BRL_DOT8] = XLAT(KEY_BRL_DOT8),
+ #define XLAT_VAL_430 ((unsigned) (KEY_BRL_DOT8))
+ #define XLAT_STR_430 STRINGIFY(KEY_BRL_DOT8)
  [KEY_BRL_DOT9] = XLAT(KEY_BRL_DOT9),
+ #define XLAT_VAL_431 ((unsigned) (KEY_BRL_DOT9))
+ #define XLAT_STR_431 STRINGIFY(KEY_BRL_DOT9)
  [KEY_BRL_DOT10] = XLAT(KEY_BRL_DOT10),
+ #define XLAT_VAL_432 ((unsigned) (KEY_BRL_DOT10))
+ #define XLAT_STR_432 STRINGIFY(KEY_BRL_DOT10)
 
  [KEY_NUMERIC_0] = XLAT(KEY_NUMERIC_0),
+ #define XLAT_VAL_433 ((unsigned) (KEY_NUMERIC_0))
+ #define XLAT_STR_433 STRINGIFY(KEY_NUMERIC_0)
  [KEY_NUMERIC_1] = XLAT(KEY_NUMERIC_1),
+ #define XLAT_VAL_434 ((unsigned) (KEY_NUMERIC_1))
+ #define XLAT_STR_434 STRINGIFY(KEY_NUMERIC_1)
  [KEY_NUMERIC_2] = XLAT(KEY_NUMERIC_2),
+ #define XLAT_VAL_435 ((unsigned) (KEY_NUMERIC_2))
+ #define XLAT_STR_435 STRINGIFY(KEY_NUMERIC_2)
  [KEY_NUMERIC_3] = XLAT(KEY_NUMERIC_3),
+ #define XLAT_VAL_436 ((unsigned) (KEY_NUMERIC_3))
+ #define XLAT_STR_436 STRINGIFY(KEY_NUMERIC_3)
  [KEY_NUMERIC_4] = XLAT(KEY_NUMERIC_4),
+ #define XLAT_VAL_437 ((unsigned) (KEY_NUMERIC_4))
+ #define XLAT_STR_437 STRINGIFY(KEY_NUMERIC_4)
  [KEY_NUMERIC_5] = XLAT(KEY_NUMERIC_5),
+ #define XLAT_VAL_438 ((unsigned) (KEY_NUMERIC_5))
+ #define XLAT_STR_438 STRINGIFY(KEY_NUMERIC_5)
  [KEY_NUMERIC_6] = XLAT(KEY_NUMERIC_6),
+ #define XLAT_VAL_439 ((unsigned) (KEY_NUMERIC_6))
+ #define XLAT_STR_439 STRINGIFY(KEY_NUMERIC_6)
  [KEY_NUMERIC_7] = XLAT(KEY_NUMERIC_7),
+ #define XLAT_VAL_440 ((unsigned) (KEY_NUMERIC_7))
+ #define XLAT_STR_440 STRINGIFY(KEY_NUMERIC_7)
  [KEY_NUMERIC_8] = XLAT(KEY_NUMERIC_8),
+ #define XLAT_VAL_441 ((unsigned) (KEY_NUMERIC_8))
+ #define XLAT_STR_441 STRINGIFY(KEY_NUMERIC_8)
  [KEY_NUMERIC_9] = XLAT(KEY_NUMERIC_9),
+ #define XLAT_VAL_442 ((unsigned) (KEY_NUMERIC_9))
+ #define XLAT_STR_442 STRINGIFY(KEY_NUMERIC_9)
  [KEY_NUMERIC_STAR] = XLAT(KEY_NUMERIC_STAR),
+ #define XLAT_VAL_443 ((unsigned) (KEY_NUMERIC_STAR))
+ #define XLAT_STR_443 STRINGIFY(KEY_NUMERIC_STAR)
  [KEY_NUMERIC_POUND] = XLAT(KEY_NUMERIC_POUND),
+ #define XLAT_VAL_444 ((unsigned) (KEY_NUMERIC_POUND))
+ #define XLAT_STR_444 STRINGIFY(KEY_NUMERIC_POUND)
  [KEY_NUMERIC_A] = XLAT(KEY_NUMERIC_A),
+ #define XLAT_VAL_445 ((unsigned) (KEY_NUMERIC_A))
+ #define XLAT_STR_445 STRINGIFY(KEY_NUMERIC_A)
  [KEY_NUMERIC_B] = XLAT(KEY_NUMERIC_B),
+ #define XLAT_VAL_446 ((unsigned) (KEY_NUMERIC_B))
+ #define XLAT_STR_446 STRINGIFY(KEY_NUMERIC_B)
  [KEY_NUMERIC_C] = XLAT(KEY_NUMERIC_C),
+ #define XLAT_VAL_447 ((unsigned) (KEY_NUMERIC_C))
+ #define XLAT_STR_447 STRINGIFY(KEY_NUMERIC_C)
  [KEY_NUMERIC_D] = XLAT(KEY_NUMERIC_D),
+ #define XLAT_VAL_448 ((unsigned) (KEY_NUMERIC_D))
+ #define XLAT_STR_448 STRINGIFY(KEY_NUMERIC_D)
 
  [KEY_CAMERA_FOCUS] = XLAT(KEY_CAMERA_FOCUS),
+ #define XLAT_VAL_449 ((unsigned) (KEY_CAMERA_FOCUS))
+ #define XLAT_STR_449 STRINGIFY(KEY_CAMERA_FOCUS)
  [KEY_WPS_BUTTON] = XLAT(KEY_WPS_BUTTON),
+ #define XLAT_VAL_450 ((unsigned) (KEY_WPS_BUTTON))
+ #define XLAT_STR_450 STRINGIFY(KEY_WPS_BUTTON)
 
  [KEY_TOUCHPAD_TOGGLE] = XLAT(KEY_TOUCHPAD_TOGGLE),
+ #define XLAT_VAL_451 ((unsigned) (KEY_TOUCHPAD_TOGGLE))
+ #define XLAT_STR_451 STRINGIFY(KEY_TOUCHPAD_TOGGLE)
  [KEY_TOUCHPAD_ON] = XLAT(KEY_TOUCHPAD_ON),
+ #define XLAT_VAL_452 ((unsigned) (KEY_TOUCHPAD_ON))
+ #define XLAT_STR_452 STRINGIFY(KEY_TOUCHPAD_ON)
  [KEY_TOUCHPAD_OFF] = XLAT(KEY_TOUCHPAD_OFF),
+ #define XLAT_VAL_453 ((unsigned) (KEY_TOUCHPAD_OFF))
+ #define XLAT_STR_453 STRINGIFY(KEY_TOUCHPAD_OFF)
 
  [KEY_CAMERA_ZOOMIN] = XLAT(KEY_CAMERA_ZOOMIN),
+ #define XLAT_VAL_454 ((unsigned) (KEY_CAMERA_ZOOMIN))
+ #define XLAT_STR_454 STRINGIFY(KEY_CAMERA_ZOOMIN)
  [KEY_CAMERA_ZOOMOUT] = XLAT(KEY_CAMERA_ZOOMOUT),
+ #define XLAT_VAL_455 ((unsigned) (KEY_CAMERA_ZOOMOUT))
+ #define XLAT_STR_455 STRINGIFY(KEY_CAMERA_ZOOMOUT)
  [KEY_CAMERA_UP] = XLAT(KEY_CAMERA_UP),
+ #define XLAT_VAL_456 ((unsigned) (KEY_CAMERA_UP))
+ #define XLAT_STR_456 STRINGIFY(KEY_CAMERA_UP)
  [KEY_CAMERA_DOWN] = XLAT(KEY_CAMERA_DOWN),
+ #define XLAT_VAL_457 ((unsigned) (KEY_CAMERA_DOWN))
+ #define XLAT_STR_457 STRINGIFY(KEY_CAMERA_DOWN)
  [KEY_CAMERA_LEFT] = XLAT(KEY_CAMERA_LEFT),
+ #define XLAT_VAL_458 ((unsigned) (KEY_CAMERA_LEFT))
+ #define XLAT_STR_458 STRINGIFY(KEY_CAMERA_LEFT)
  [KEY_CAMERA_RIGHT] = XLAT(KEY_CAMERA_RIGHT),
+ #define XLAT_VAL_459 ((unsigned) (KEY_CAMERA_RIGHT))
+ #define XLAT_STR_459 STRINGIFY(KEY_CAMERA_RIGHT)
 
  [KEY_ATTENDANT_ON] = XLAT(KEY_ATTENDANT_ON),
+ #define XLAT_VAL_460 ((unsigned) (KEY_ATTENDANT_ON))
+ #define XLAT_STR_460 STRINGIFY(KEY_ATTENDANT_ON)
  [KEY_ATTENDANT_OFF] = XLAT(KEY_ATTENDANT_OFF),
+ #define XLAT_VAL_461 ((unsigned) (KEY_ATTENDANT_OFF))
+ #define XLAT_STR_461 STRINGIFY(KEY_ATTENDANT_OFF)
  [KEY_ATTENDANT_TOGGLE] = XLAT(KEY_ATTENDANT_TOGGLE),
+ #define XLAT_VAL_462 ((unsigned) (KEY_ATTENDANT_TOGGLE))
+ #define XLAT_STR_462 STRINGIFY(KEY_ATTENDANT_TOGGLE)
  [KEY_LIGHTS_TOGGLE] = XLAT(KEY_LIGHTS_TOGGLE),
+ #define XLAT_VAL_463 ((unsigned) (KEY_LIGHTS_TOGGLE))
+ #define XLAT_STR_463 STRINGIFY(KEY_LIGHTS_TOGGLE)
 
  [BTN_DPAD_UP] = XLAT(BTN_DPAD_UP),
+ #define XLAT_VAL_464 ((unsigned) (BTN_DPAD_UP))
+ #define XLAT_STR_464 STRINGIFY(BTN_DPAD_UP)
  [BTN_DPAD_DOWN] = XLAT(BTN_DPAD_DOWN),
+ #define XLAT_VAL_465 ((unsigned) (BTN_DPAD_DOWN))
+ #define XLAT_STR_465 STRINGIFY(BTN_DPAD_DOWN)
  [BTN_DPAD_LEFT] = XLAT(BTN_DPAD_LEFT),
+ #define XLAT_VAL_466 ((unsigned) (BTN_DPAD_LEFT))
+ #define XLAT_STR_466 STRINGIFY(BTN_DPAD_LEFT)
  [BTN_DPAD_RIGHT] = XLAT(BTN_DPAD_RIGHT),
+ #define XLAT_VAL_467 ((unsigned) (BTN_DPAD_RIGHT))
+ #define XLAT_STR_467 STRINGIFY(BTN_DPAD_RIGHT)
 
  [KEY_ALS_TOGGLE] = XLAT(KEY_ALS_TOGGLE),
+ #define XLAT_VAL_468 ((unsigned) (KEY_ALS_TOGGLE))
+ #define XLAT_STR_468 STRINGIFY(KEY_ALS_TOGGLE)
  [KEY_ROTATE_LOCK_TOGGLE] = XLAT(KEY_ROTATE_LOCK_TOGGLE),
+ #define XLAT_VAL_469 ((unsigned) (KEY_ROTATE_LOCK_TOGGLE))
+ #define XLAT_STR_469 STRINGIFY(KEY_ROTATE_LOCK_TOGGLE)
 
  [KEY_BUTTONCONFIG] = XLAT(KEY_BUTTONCONFIG),
+ #define XLAT_VAL_470 ((unsigned) (KEY_BUTTONCONFIG))
+ #define XLAT_STR_470 STRINGIFY(KEY_BUTTONCONFIG)
  [KEY_TASKMANAGER] = XLAT(KEY_TASKMANAGER),
+ #define XLAT_VAL_471 ((unsigned) (KEY_TASKMANAGER))
+ #define XLAT_STR_471 STRINGIFY(KEY_TASKMANAGER)
  [KEY_JOURNAL] = XLAT(KEY_JOURNAL),
+ #define XLAT_VAL_472 ((unsigned) (KEY_JOURNAL))
+ #define XLAT_STR_472 STRINGIFY(KEY_JOURNAL)
  [KEY_CONTROLPANEL] = XLAT(KEY_CONTROLPANEL),
+ #define XLAT_VAL_473 ((unsigned) (KEY_CONTROLPANEL))
+ #define XLAT_STR_473 STRINGIFY(KEY_CONTROLPANEL)
  [KEY_APPSELECT] = XLAT(KEY_APPSELECT),
+ #define XLAT_VAL_474 ((unsigned) (KEY_APPSELECT))
+ #define XLAT_STR_474 STRINGIFY(KEY_APPSELECT)
  [KEY_SCREENSAVER] = XLAT(KEY_SCREENSAVER),
+ #define XLAT_VAL_475 ((unsigned) (KEY_SCREENSAVER))
+ #define XLAT_STR_475 STRINGIFY(KEY_SCREENSAVER)
  [KEY_VOICECOMMAND] = XLAT(KEY_VOICECOMMAND),
+ #define XLAT_VAL_476 ((unsigned) (KEY_VOICECOMMAND))
+ #define XLAT_STR_476 STRINGIFY(KEY_VOICECOMMAND)
  [KEY_ASSISTANT] = XLAT(KEY_ASSISTANT),
+ #define XLAT_VAL_477 ((unsigned) (KEY_ASSISTANT))
+ #define XLAT_STR_477 STRINGIFY(KEY_ASSISTANT)
  [KEY_KBD_LAYOUT_NEXT] = XLAT(KEY_KBD_LAYOUT_NEXT),
+ #define XLAT_VAL_478 ((unsigned) (KEY_KBD_LAYOUT_NEXT))
+ #define XLAT_STR_478 STRINGIFY(KEY_KBD_LAYOUT_NEXT)
 
 #ifndef STRACE_WORKAROUND_FOR_KEY_BRIGHTNESS_MIN
 # define STRACE_WORKAROUND_FOR_KEY_BRIGHTNESS_MIN
@@ -4682,35 +5647,85 @@ static const struct xlat_data evdev_keyc
 # undef KEY_BRIGHTNESS_MIN
 #endif
  [KEY_BRIGHTNESS_MIN] = XLAT(KEY_BRIGHTNESS_MIN),
+ #define XLAT_VAL_479 ((unsigned) (KEY_BRIGHTNESS_MIN))
+ #define XLAT_STR_479 STRINGIFY(KEY_BRIGHTNESS_MIN)
 
  [KEY_BRIGHTNESS_MAX] = XLAT(KEY_BRIGHTNESS_MAX),
+ #define XLAT_VAL_480 ((unsigned) (KEY_BRIGHTNESS_MAX))
+ #define XLAT_STR_480 STRINGIFY(KEY_BRIGHTNESS_MAX)
 
  [KEY_KBDINPUTASSIST_PREV] = XLAT(KEY_KBDINPUTASSIST_PREV),
+ #define XLAT_VAL_481 ((unsigned) (KEY_KBDINPUTASSIST_PREV))
+ #define XLAT_STR_481 STRINGIFY(KEY_KBDINPUTASSIST_PREV)
  [KEY_KBDINPUTASSIST_NEXT] = XLAT(KEY_KBDINPUTASSIST_NEXT),
+ #define XLAT_VAL_482 ((unsigned) (KEY_KBDINPUTASSIST_NEXT))
+ #define XLAT_STR_482 STRINGIFY(KEY_KBDINPUTASSIST_NEXT)
  [KEY_KBDINPUTASSIST_PREVGROUP] = XLAT(KEY_KBDINPUTASSIST_PREVGROUP),
+ #define XLAT_VAL_483 ((unsigned) (KEY_KBDINPUTASSIST_PREVGROUP))
+ #define XLAT_STR_483 STRINGIFY(KEY_KBDINPUTASSIST_PREVGROUP)
  [KEY_KBDINPUTASSIST_NEXTGROUP] = XLAT(KEY_KBDINPUTASSIST_NEXTGROUP),
+ #define XLAT_VAL_484 ((unsigned) (KEY_KBDINPUTASSIST_NEXTGROUP))
+ #define XLAT_STR_484 STRINGIFY(KEY_KBDINPUTASSIST_NEXTGROUP)
  [KEY_KBDINPUTASSIST_ACCEPT] = XLAT(KEY_KBDINPUTASSIST_ACCEPT),
+ #define XLAT_VAL_485 ((unsigned) (KEY_KBDINPUTASSIST_ACCEPT))
+ #define XLAT_STR_485 STRINGIFY(KEY_KBDINPUTASSIST_ACCEPT)
  [KEY_KBDINPUTASSIST_CANCEL] = XLAT(KEY_KBDINPUTASSIST_CANCEL),
+ #define XLAT_VAL_486 ((unsigned) (KEY_KBDINPUTASSIST_CANCEL))
+ #define XLAT_STR_486 STRINGIFY(KEY_KBDINPUTASSIST_CANCEL)
 
  [KEY_RIGHT_UP] = XLAT(KEY_RIGHT_UP),
+ #define XLAT_VAL_487 ((unsigned) (KEY_RIGHT_UP))
+ #define XLAT_STR_487 STRINGIFY(KEY_RIGHT_UP)
  [KEY_RIGHT_DOWN] = XLAT(KEY_RIGHT_DOWN),
+ #define XLAT_VAL_488 ((unsigned) (KEY_RIGHT_DOWN))
+ #define XLAT_STR_488 STRINGIFY(KEY_RIGHT_DOWN)
  [KEY_LEFT_UP] = XLAT(KEY_LEFT_UP),
+ #define XLAT_VAL_489 ((unsigned) (KEY_LEFT_UP))
+ #define XLAT_STR_489 STRINGIFY(KEY_LEFT_UP)
  [KEY_LEFT_DOWN] = XLAT(KEY_LEFT_DOWN),
+ #define XLAT_VAL_490 ((unsigned) (KEY_LEFT_DOWN))
+ #define XLAT_STR_490 STRINGIFY(KEY_LEFT_DOWN)
 
  [KEY_ROOT_MENU] = XLAT(KEY_ROOT_MENU),
+ #define XLAT_VAL_491 ((unsigned) (KEY_ROOT_MENU))
+ #define XLAT_STR_491 STRINGIFY(KEY_ROOT_MENU)
  [KEY_MEDIA_TOP_MENU] = XLAT(KEY_MEDIA_TOP_MENU),
+ #define XLAT_VAL_492 ((unsigned) (KEY_MEDIA_TOP_MENU))
+ #define XLAT_STR_492 STRINGIFY(KEY_MEDIA_TOP_MENU)
  [KEY_NUMERIC_11] = XLAT(KEY_NUMERIC_11),
+ #define XLAT_VAL_493 ((unsigned) (KEY_NUMERIC_11))
+ #define XLAT_STR_493 STRINGIFY(KEY_NUMERIC_11)
  [KEY_NUMERIC_12] = XLAT(KEY_NUMERIC_12),
+ #define XLAT_VAL_494 ((unsigned) (KEY_NUMERIC_12))
+ #define XLAT_STR_494 STRINGIFY(KEY_NUMERIC_12)
 
  [KEY_AUDIO_DESC] = XLAT(KEY_AUDIO_DESC),
+ #define XLAT_VAL_495 ((unsigned) (KEY_AUDIO_DESC))
+ #define XLAT_STR_495 STRINGIFY(KEY_AUDIO_DESC)
  [KEY_3D_MODE] = XLAT(KEY_3D_MODE),
+ #define XLAT_VAL_496 ((unsigned) (KEY_3D_MODE))
+ #define XLAT_STR_496 STRINGIFY(KEY_3D_MODE)
  [KEY_NEXT_FAVORITE] = XLAT(KEY_NEXT_FAVORITE),
+ #define XLAT_VAL_497 ((unsigned) (KEY_NEXT_FAVORITE))
+ #define XLAT_STR_497 STRINGIFY(KEY_NEXT_FAVORITE)
  [KEY_STOP_RECORD] = XLAT(KEY_STOP_RECORD),
+ #define XLAT_VAL_498 ((unsigned) (KEY_STOP_RECORD))
+ #define XLAT_STR_498 STRINGIFY(KEY_STOP_RECORD)
  [KEY_PAUSE_RECORD] = XLAT(KEY_PAUSE_RECORD),
+ #define XLAT_VAL_499 ((unsigned) (KEY_PAUSE_RECORD))
+ #define XLAT_STR_499 STRINGIFY(KEY_PAUSE_RECORD)
  [KEY_VOD] = XLAT(KEY_VOD),
+ #define XLAT_VAL_500 ((unsigned) (KEY_VOD))
+ #define XLAT_STR_500 STRINGIFY(KEY_VOD)
  [KEY_UNMUTE] = XLAT(KEY_UNMUTE),
+ #define XLAT_VAL_501 ((unsigned) (KEY_UNMUTE))
+ #define XLAT_STR_501 STRINGIFY(KEY_UNMUTE)
  [KEY_FASTREVERSE] = XLAT(KEY_FASTREVERSE),
+ #define XLAT_VAL_502 ((unsigned) (KEY_FASTREVERSE))
+ #define XLAT_STR_502 STRINGIFY(KEY_FASTREVERSE)
  [KEY_SLOWREVERSE] = XLAT(KEY_SLOWREVERSE),
+ #define XLAT_VAL_503 ((unsigned) (KEY_SLOWREVERSE))
+ #define XLAT_STR_503 STRINGIFY(KEY_SLOWREVERSE)
 
 #ifndef STRACE_WORKAROUND_FOR_KEY_DATA
 # define STRACE_WORKAROUND_FOR_KEY_DATA
@@ -4724,102 +5739,4990 @@ static const struct xlat_data evdev_keyc
 # undef KEY_DATA
 #endif
  [KEY_DATA] = XLAT(KEY_DATA),
+ #define XLAT_VAL_504 ((unsigned) (KEY_DATA))
+ #define XLAT_STR_504 STRINGIFY(KEY_DATA)
 
  [KEY_ONSCREEN_KEYBOARD] = XLAT(KEY_ONSCREEN_KEYBOARD),
+ #define XLAT_VAL_505 ((unsigned) (KEY_ONSCREEN_KEYBOARD))
+ #define XLAT_STR_505 STRINGIFY(KEY_ONSCREEN_KEYBOARD)
  [KEY_PRIVACY_SCREEN_TOGGLE] = XLAT(KEY_PRIVACY_SCREEN_TOGGLE),
+ #define XLAT_VAL_506 ((unsigned) (KEY_PRIVACY_SCREEN_TOGGLE))
+ #define XLAT_STR_506 STRINGIFY(KEY_PRIVACY_SCREEN_TOGGLE)
+
+ [KEY_SELECTIVE_SCREENSHOT] = XLAT(KEY_SELECTIVE_SCREENSHOT),
+ #define XLAT_VAL_507 ((unsigned) (KEY_SELECTIVE_SCREENSHOT))
+ #define XLAT_STR_507 STRINGIFY(KEY_SELECTIVE_SCREENSHOT)
 
  [KEY_MACRO1] = XLAT(KEY_MACRO1),
+ #define XLAT_VAL_508 ((unsigned) (KEY_MACRO1))
+ #define XLAT_STR_508 STRINGIFY(KEY_MACRO1)
  [KEY_MACRO2] = XLAT(KEY_MACRO2),
+ #define XLAT_VAL_509 ((unsigned) (KEY_MACRO2))
+ #define XLAT_STR_509 STRINGIFY(KEY_MACRO2)
  [KEY_MACRO3] = XLAT(KEY_MACRO3),
+ #define XLAT_VAL_510 ((unsigned) (KEY_MACRO3))
+ #define XLAT_STR_510 STRINGIFY(KEY_MACRO3)
  [KEY_MACRO4] = XLAT(KEY_MACRO4),
+ #define XLAT_VAL_511 ((unsigned) (KEY_MACRO4))
+ #define XLAT_STR_511 STRINGIFY(KEY_MACRO4)
  [KEY_MACRO5] = XLAT(KEY_MACRO5),
+ #define XLAT_VAL_512 ((unsigned) (KEY_MACRO5))
+ #define XLAT_STR_512 STRINGIFY(KEY_MACRO5)
  [KEY_MACRO6] = XLAT(KEY_MACRO6),
+ #define XLAT_VAL_513 ((unsigned) (KEY_MACRO6))
+ #define XLAT_STR_513 STRINGIFY(KEY_MACRO6)
  [KEY_MACRO7] = XLAT(KEY_MACRO7),
+ #define XLAT_VAL_514 ((unsigned) (KEY_MACRO7))
+ #define XLAT_STR_514 STRINGIFY(KEY_MACRO7)
  [KEY_MACRO8] = XLAT(KEY_MACRO8),
+ #define XLAT_VAL_515 ((unsigned) (KEY_MACRO8))
+ #define XLAT_STR_515 STRINGIFY(KEY_MACRO8)
  [KEY_MACRO9] = XLAT(KEY_MACRO9),
+ #define XLAT_VAL_516 ((unsigned) (KEY_MACRO9))
+ #define XLAT_STR_516 STRINGIFY(KEY_MACRO9)
  [KEY_MACRO10] = XLAT(KEY_MACRO10),
+ #define XLAT_VAL_517 ((unsigned) (KEY_MACRO10))
+ #define XLAT_STR_517 STRINGIFY(KEY_MACRO10)
  [KEY_MACRO11] = XLAT(KEY_MACRO11),
+ #define XLAT_VAL_518 ((unsigned) (KEY_MACRO11))
+ #define XLAT_STR_518 STRINGIFY(KEY_MACRO11)
  [KEY_MACRO12] = XLAT(KEY_MACRO12),
+ #define XLAT_VAL_519 ((unsigned) (KEY_MACRO12))
+ #define XLAT_STR_519 STRINGIFY(KEY_MACRO12)
  [KEY_MACRO13] = XLAT(KEY_MACRO13),
+ #define XLAT_VAL_520 ((unsigned) (KEY_MACRO13))
+ #define XLAT_STR_520 STRINGIFY(KEY_MACRO13)
  [KEY_MACRO14] = XLAT(KEY_MACRO14),
+ #define XLAT_VAL_521 ((unsigned) (KEY_MACRO14))
+ #define XLAT_STR_521 STRINGIFY(KEY_MACRO14)
  [KEY_MACRO15] = XLAT(KEY_MACRO15),
+ #define XLAT_VAL_522 ((unsigned) (KEY_MACRO15))
+ #define XLAT_STR_522 STRINGIFY(KEY_MACRO15)
  [KEY_MACRO16] = XLAT(KEY_MACRO16),
+ #define XLAT_VAL_523 ((unsigned) (KEY_MACRO16))
+ #define XLAT_STR_523 STRINGIFY(KEY_MACRO16)
  [KEY_MACRO17] = XLAT(KEY_MACRO17),
+ #define XLAT_VAL_524 ((unsigned) (KEY_MACRO17))
+ #define XLAT_STR_524 STRINGIFY(KEY_MACRO17)
  [KEY_MACRO18] = XLAT(KEY_MACRO18),
+ #define XLAT_VAL_525 ((unsigned) (KEY_MACRO18))
+ #define XLAT_STR_525 STRINGIFY(KEY_MACRO18)
  [KEY_MACRO19] = XLAT(KEY_MACRO19),
+ #define XLAT_VAL_526 ((unsigned) (KEY_MACRO19))
+ #define XLAT_STR_526 STRINGIFY(KEY_MACRO19)
  [KEY_MACRO20] = XLAT(KEY_MACRO20),
+ #define XLAT_VAL_527 ((unsigned) (KEY_MACRO20))
+ #define XLAT_STR_527 STRINGIFY(KEY_MACRO20)
  [KEY_MACRO21] = XLAT(KEY_MACRO21),
+ #define XLAT_VAL_528 ((unsigned) (KEY_MACRO21))
+ #define XLAT_STR_528 STRINGIFY(KEY_MACRO21)
  [KEY_MACRO22] = XLAT(KEY_MACRO22),
+ #define XLAT_VAL_529 ((unsigned) (KEY_MACRO22))
+ #define XLAT_STR_529 STRINGIFY(KEY_MACRO22)
  [KEY_MACRO23] = XLAT(KEY_MACRO23),
+ #define XLAT_VAL_530 ((unsigned) (KEY_MACRO23))
+ #define XLAT_STR_530 STRINGIFY(KEY_MACRO23)
  [KEY_MACRO24] = XLAT(KEY_MACRO24),
+ #define XLAT_VAL_531 ((unsigned) (KEY_MACRO24))
+ #define XLAT_STR_531 STRINGIFY(KEY_MACRO24)
  [KEY_MACRO25] = XLAT(KEY_MACRO25),
+ #define XLAT_VAL_532 ((unsigned) (KEY_MACRO25))
+ #define XLAT_STR_532 STRINGIFY(KEY_MACRO25)
  [KEY_MACRO26] = XLAT(KEY_MACRO26),
+ #define XLAT_VAL_533 ((unsigned) (KEY_MACRO26))
+ #define XLAT_STR_533 STRINGIFY(KEY_MACRO26)
  [KEY_MACRO27] = XLAT(KEY_MACRO27),
+ #define XLAT_VAL_534 ((unsigned) (KEY_MACRO27))
+ #define XLAT_STR_534 STRINGIFY(KEY_MACRO27)
  [KEY_MACRO28] = XLAT(KEY_MACRO28),
+ #define XLAT_VAL_535 ((unsigned) (KEY_MACRO28))
+ #define XLAT_STR_535 STRINGIFY(KEY_MACRO28)
  [KEY_MACRO29] = XLAT(KEY_MACRO29),
+ #define XLAT_VAL_536 ((unsigned) (KEY_MACRO29))
+ #define XLAT_STR_536 STRINGIFY(KEY_MACRO29)
  [KEY_MACRO30] = XLAT(KEY_MACRO30),
+ #define XLAT_VAL_537 ((unsigned) (KEY_MACRO30))
+ #define XLAT_STR_537 STRINGIFY(KEY_MACRO30)
 
  [KEY_MACRO_RECORD_START] = XLAT(KEY_MACRO_RECORD_START),
+ #define XLAT_VAL_538 ((unsigned) (KEY_MACRO_RECORD_START))
+ #define XLAT_STR_538 STRINGIFY(KEY_MACRO_RECORD_START)
  [KEY_MACRO_RECORD_STOP] = XLAT(KEY_MACRO_RECORD_STOP),
+ #define XLAT_VAL_539 ((unsigned) (KEY_MACRO_RECORD_STOP))
+ #define XLAT_STR_539 STRINGIFY(KEY_MACRO_RECORD_STOP)
  [KEY_MACRO_PRESET_CYCLE] = XLAT(KEY_MACRO_PRESET_CYCLE),
+ #define XLAT_VAL_540 ((unsigned) (KEY_MACRO_PRESET_CYCLE))
+ #define XLAT_STR_540 STRINGIFY(KEY_MACRO_PRESET_CYCLE)
  [KEY_MACRO_PRESET1] = XLAT(KEY_MACRO_PRESET1),
+ #define XLAT_VAL_541 ((unsigned) (KEY_MACRO_PRESET1))
+ #define XLAT_STR_541 STRINGIFY(KEY_MACRO_PRESET1)
  [KEY_MACRO_PRESET2] = XLAT(KEY_MACRO_PRESET2),
+ #define XLAT_VAL_542 ((unsigned) (KEY_MACRO_PRESET2))
+ #define XLAT_STR_542 STRINGIFY(KEY_MACRO_PRESET2)
  [KEY_MACRO_PRESET3] = XLAT(KEY_MACRO_PRESET3),
+ #define XLAT_VAL_543 ((unsigned) (KEY_MACRO_PRESET3))
+ #define XLAT_STR_543 STRINGIFY(KEY_MACRO_PRESET3)
 
  [KEY_KBD_LCD_MENU1] = XLAT(KEY_KBD_LCD_MENU1),
+ #define XLAT_VAL_544 ((unsigned) (KEY_KBD_LCD_MENU1))
+ #define XLAT_STR_544 STRINGIFY(KEY_KBD_LCD_MENU1)
  [KEY_KBD_LCD_MENU2] = XLAT(KEY_KBD_LCD_MENU2),
+ #define XLAT_VAL_545 ((unsigned) (KEY_KBD_LCD_MENU2))
+ #define XLAT_STR_545 STRINGIFY(KEY_KBD_LCD_MENU2)
  [KEY_KBD_LCD_MENU3] = XLAT(KEY_KBD_LCD_MENU3),
+ #define XLAT_VAL_546 ((unsigned) (KEY_KBD_LCD_MENU3))
+ #define XLAT_STR_546 STRINGIFY(KEY_KBD_LCD_MENU3)
  [KEY_KBD_LCD_MENU4] = XLAT(KEY_KBD_LCD_MENU4),
+ #define XLAT_VAL_547 ((unsigned) (KEY_KBD_LCD_MENU4))
+ #define XLAT_STR_547 STRINGIFY(KEY_KBD_LCD_MENU4)
  [KEY_KBD_LCD_MENU5] = XLAT(KEY_KBD_LCD_MENU5),
+ #define XLAT_VAL_548 ((unsigned) (KEY_KBD_LCD_MENU5))
+ #define XLAT_STR_548 STRINGIFY(KEY_KBD_LCD_MENU5)
 
  [BTN_TRIGGER_HAPPY1] = XLAT(BTN_TRIGGER_HAPPY1),
+ #define XLAT_VAL_549 ((unsigned) (BTN_TRIGGER_HAPPY1))
+ #define XLAT_STR_549 STRINGIFY(BTN_TRIGGER_HAPPY1)
  [BTN_TRIGGER_HAPPY2] = XLAT(BTN_TRIGGER_HAPPY2),
+ #define XLAT_VAL_550 ((unsigned) (BTN_TRIGGER_HAPPY2))
+ #define XLAT_STR_550 STRINGIFY(BTN_TRIGGER_HAPPY2)
  [BTN_TRIGGER_HAPPY3] = XLAT(BTN_TRIGGER_HAPPY3),
+ #define XLAT_VAL_551 ((unsigned) (BTN_TRIGGER_HAPPY3))
+ #define XLAT_STR_551 STRINGIFY(BTN_TRIGGER_HAPPY3)
  [BTN_TRIGGER_HAPPY4] = XLAT(BTN_TRIGGER_HAPPY4),
+ #define XLAT_VAL_552 ((unsigned) (BTN_TRIGGER_HAPPY4))
+ #define XLAT_STR_552 STRINGIFY(BTN_TRIGGER_HAPPY4)
  [BTN_TRIGGER_HAPPY5] = XLAT(BTN_TRIGGER_HAPPY5),
+ #define XLAT_VAL_553 ((unsigned) (BTN_TRIGGER_HAPPY5))
+ #define XLAT_STR_553 STRINGIFY(BTN_TRIGGER_HAPPY5)
  [BTN_TRIGGER_HAPPY6] = XLAT(BTN_TRIGGER_HAPPY6),
+ #define XLAT_VAL_554 ((unsigned) (BTN_TRIGGER_HAPPY6))
+ #define XLAT_STR_554 STRINGIFY(BTN_TRIGGER_HAPPY6)
  [BTN_TRIGGER_HAPPY7] = XLAT(BTN_TRIGGER_HAPPY7),
+ #define XLAT_VAL_555 ((unsigned) (BTN_TRIGGER_HAPPY7))
+ #define XLAT_STR_555 STRINGIFY(BTN_TRIGGER_HAPPY7)
  [BTN_TRIGGER_HAPPY8] = XLAT(BTN_TRIGGER_HAPPY8),
+ #define XLAT_VAL_556 ((unsigned) (BTN_TRIGGER_HAPPY8))
+ #define XLAT_STR_556 STRINGIFY(BTN_TRIGGER_HAPPY8)
  [BTN_TRIGGER_HAPPY9] = XLAT(BTN_TRIGGER_HAPPY9),
+ #define XLAT_VAL_557 ((unsigned) (BTN_TRIGGER_HAPPY9))
+ #define XLAT_STR_557 STRINGIFY(BTN_TRIGGER_HAPPY9)
  [BTN_TRIGGER_HAPPY10] = XLAT(BTN_TRIGGER_HAPPY10),
+ #define XLAT_VAL_558 ((unsigned) (BTN_TRIGGER_HAPPY10))
+ #define XLAT_STR_558 STRINGIFY(BTN_TRIGGER_HAPPY10)
  [BTN_TRIGGER_HAPPY11] = XLAT(BTN_TRIGGER_HAPPY11),
+ #define XLAT_VAL_559 ((unsigned) (BTN_TRIGGER_HAPPY11))
+ #define XLAT_STR_559 STRINGIFY(BTN_TRIGGER_HAPPY11)
  [BTN_TRIGGER_HAPPY12] = XLAT(BTN_TRIGGER_HAPPY12),
+ #define XLAT_VAL_560 ((unsigned) (BTN_TRIGGER_HAPPY12))
+ #define XLAT_STR_560 STRINGIFY(BTN_TRIGGER_HAPPY12)
  [BTN_TRIGGER_HAPPY13] = XLAT(BTN_TRIGGER_HAPPY13),
+ #define XLAT_VAL_561 ((unsigned) (BTN_TRIGGER_HAPPY13))
+ #define XLAT_STR_561 STRINGIFY(BTN_TRIGGER_HAPPY13)
  [BTN_TRIGGER_HAPPY14] = XLAT(BTN_TRIGGER_HAPPY14),
+ #define XLAT_VAL_562 ((unsigned) (BTN_TRIGGER_HAPPY14))
+ #define XLAT_STR_562 STRINGIFY(BTN_TRIGGER_HAPPY14)
  [BTN_TRIGGER_HAPPY15] = XLAT(BTN_TRIGGER_HAPPY15),
+ #define XLAT_VAL_563 ((unsigned) (BTN_TRIGGER_HAPPY15))
+ #define XLAT_STR_563 STRINGIFY(BTN_TRIGGER_HAPPY15)
  [BTN_TRIGGER_HAPPY16] = XLAT(BTN_TRIGGER_HAPPY16),
+ #define XLAT_VAL_564 ((unsigned) (BTN_TRIGGER_HAPPY16))
+ #define XLAT_STR_564 STRINGIFY(BTN_TRIGGER_HAPPY16)
  [BTN_TRIGGER_HAPPY17] = XLAT(BTN_TRIGGER_HAPPY17),
+ #define XLAT_VAL_565 ((unsigned) (BTN_TRIGGER_HAPPY17))
+ #define XLAT_STR_565 STRINGIFY(BTN_TRIGGER_HAPPY17)
  [BTN_TRIGGER_HAPPY18] = XLAT(BTN_TRIGGER_HAPPY18),
+ #define XLAT_VAL_566 ((unsigned) (BTN_TRIGGER_HAPPY18))
+ #define XLAT_STR_566 STRINGIFY(BTN_TRIGGER_HAPPY18)
  [BTN_TRIGGER_HAPPY19] = XLAT(BTN_TRIGGER_HAPPY19),
+ #define XLAT_VAL_567 ((unsigned) (BTN_TRIGGER_HAPPY19))
+ #define XLAT_STR_567 STRINGIFY(BTN_TRIGGER_HAPPY19)
  [BTN_TRIGGER_HAPPY20] = XLAT(BTN_TRIGGER_HAPPY20),
+ #define XLAT_VAL_568 ((unsigned) (BTN_TRIGGER_HAPPY20))
+ #define XLAT_STR_568 STRINGIFY(BTN_TRIGGER_HAPPY20)
  [BTN_TRIGGER_HAPPY21] = XLAT(BTN_TRIGGER_HAPPY21),
+ #define XLAT_VAL_569 ((unsigned) (BTN_TRIGGER_HAPPY21))
+ #define XLAT_STR_569 STRINGIFY(BTN_TRIGGER_HAPPY21)
  [BTN_TRIGGER_HAPPY22] = XLAT(BTN_TRIGGER_HAPPY22),
+ #define XLAT_VAL_570 ((unsigned) (BTN_TRIGGER_HAPPY22))
+ #define XLAT_STR_570 STRINGIFY(BTN_TRIGGER_HAPPY22)
  [BTN_TRIGGER_HAPPY23] = XLAT(BTN_TRIGGER_HAPPY23),
+ #define XLAT_VAL_571 ((unsigned) (BTN_TRIGGER_HAPPY23))
+ #define XLAT_STR_571 STRINGIFY(BTN_TRIGGER_HAPPY23)
  [BTN_TRIGGER_HAPPY24] = XLAT(BTN_TRIGGER_HAPPY24),
+ #define XLAT_VAL_572 ((unsigned) (BTN_TRIGGER_HAPPY24))
+ #define XLAT_STR_572 STRINGIFY(BTN_TRIGGER_HAPPY24)
  [BTN_TRIGGER_HAPPY25] = XLAT(BTN_TRIGGER_HAPPY25),
+ #define XLAT_VAL_573 ((unsigned) (BTN_TRIGGER_HAPPY25))
+ #define XLAT_STR_573 STRINGIFY(BTN_TRIGGER_HAPPY25)
  [BTN_TRIGGER_HAPPY26] = XLAT(BTN_TRIGGER_HAPPY26),
+ #define XLAT_VAL_574 ((unsigned) (BTN_TRIGGER_HAPPY26))
+ #define XLAT_STR_574 STRINGIFY(BTN_TRIGGER_HAPPY26)
  [BTN_TRIGGER_HAPPY27] = XLAT(BTN_TRIGGER_HAPPY27),
+ #define XLAT_VAL_575 ((unsigned) (BTN_TRIGGER_HAPPY27))
+ #define XLAT_STR_575 STRINGIFY(BTN_TRIGGER_HAPPY27)
  [BTN_TRIGGER_HAPPY28] = XLAT(BTN_TRIGGER_HAPPY28),
+ #define XLAT_VAL_576 ((unsigned) (BTN_TRIGGER_HAPPY28))
+ #define XLAT_STR_576 STRINGIFY(BTN_TRIGGER_HAPPY28)
  [BTN_TRIGGER_HAPPY29] = XLAT(BTN_TRIGGER_HAPPY29),
+ #define XLAT_VAL_577 ((unsigned) (BTN_TRIGGER_HAPPY29))
+ #define XLAT_STR_577 STRINGIFY(BTN_TRIGGER_HAPPY29)
  [BTN_TRIGGER_HAPPY30] = XLAT(BTN_TRIGGER_HAPPY30),
+ #define XLAT_VAL_578 ((unsigned) (BTN_TRIGGER_HAPPY30))
+ #define XLAT_STR_578 STRINGIFY(BTN_TRIGGER_HAPPY30)
  [BTN_TRIGGER_HAPPY31] = XLAT(BTN_TRIGGER_HAPPY31),
+ #define XLAT_VAL_579 ((unsigned) (BTN_TRIGGER_HAPPY31))
+ #define XLAT_STR_579 STRINGIFY(BTN_TRIGGER_HAPPY31)
  [BTN_TRIGGER_HAPPY32] = XLAT(BTN_TRIGGER_HAPPY32),
+ #define XLAT_VAL_580 ((unsigned) (BTN_TRIGGER_HAPPY32))
+ #define XLAT_STR_580 STRINGIFY(BTN_TRIGGER_HAPPY32)
  [BTN_TRIGGER_HAPPY33] = XLAT(BTN_TRIGGER_HAPPY33),
+ #define XLAT_VAL_581 ((unsigned) (BTN_TRIGGER_HAPPY33))
+ #define XLAT_STR_581 STRINGIFY(BTN_TRIGGER_HAPPY33)
  [BTN_TRIGGER_HAPPY34] = XLAT(BTN_TRIGGER_HAPPY34),
+ #define XLAT_VAL_582 ((unsigned) (BTN_TRIGGER_HAPPY34))
+ #define XLAT_STR_582 STRINGIFY(BTN_TRIGGER_HAPPY34)
  [BTN_TRIGGER_HAPPY35] = XLAT(BTN_TRIGGER_HAPPY35),
+ #define XLAT_VAL_583 ((unsigned) (BTN_TRIGGER_HAPPY35))
+ #define XLAT_STR_583 STRINGIFY(BTN_TRIGGER_HAPPY35)
  [BTN_TRIGGER_HAPPY36] = XLAT(BTN_TRIGGER_HAPPY36),
+ #define XLAT_VAL_584 ((unsigned) (BTN_TRIGGER_HAPPY36))
+ #define XLAT_STR_584 STRINGIFY(BTN_TRIGGER_HAPPY36)
  [BTN_TRIGGER_HAPPY37] = XLAT(BTN_TRIGGER_HAPPY37),
+ #define XLAT_VAL_585 ((unsigned) (BTN_TRIGGER_HAPPY37))
+ #define XLAT_STR_585 STRINGIFY(BTN_TRIGGER_HAPPY37)
  [BTN_TRIGGER_HAPPY38] = XLAT(BTN_TRIGGER_HAPPY38),
+ #define XLAT_VAL_586 ((unsigned) (BTN_TRIGGER_HAPPY38))
+ #define XLAT_STR_586 STRINGIFY(BTN_TRIGGER_HAPPY38)
  [BTN_TRIGGER_HAPPY39] = XLAT(BTN_TRIGGER_HAPPY39),
+ #define XLAT_VAL_587 ((unsigned) (BTN_TRIGGER_HAPPY39))
+ #define XLAT_STR_587 STRINGIFY(BTN_TRIGGER_HAPPY39)
  [BTN_TRIGGER_HAPPY40] = XLAT(BTN_TRIGGER_HAPPY40),
+ #define XLAT_VAL_588 ((unsigned) (BTN_TRIGGER_HAPPY40))
+ #define XLAT_STR_588 STRINGIFY(BTN_TRIGGER_HAPPY40)
 };
 static
 const struct xlat evdev_keycode[1] = { {
  .data = evdev_keycode_xdata,
  .size = ARRAY_SIZE(evdev_keycode_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+#  ifdef XLAT_VAL_47
+  | XLAT_VAL_47
+#  endif
+#  ifdef XLAT_VAL_48
+  | XLAT_VAL_48
+#  endif
+#  ifdef XLAT_VAL_49
+  | XLAT_VAL_49
+#  endif
+#  ifdef XLAT_VAL_50
+  | XLAT_VAL_50
+#  endif
+#  ifdef XLAT_VAL_51
+  | XLAT_VAL_51
+#  endif
+#  ifdef XLAT_VAL_52
+  | XLAT_VAL_52
+#  endif
+#  ifdef XLAT_VAL_53
+  | XLAT_VAL_53
+#  endif
+#  ifdef XLAT_VAL_54
+  | XLAT_VAL_54
+#  endif
+#  ifdef XLAT_VAL_55
+  | XLAT_VAL_55
+#  endif
+#  ifdef XLAT_VAL_56
+  | XLAT_VAL_56
+#  endif
+#  ifdef XLAT_VAL_57
+  | XLAT_VAL_57
+#  endif
+#  ifdef XLAT_VAL_58
+  | XLAT_VAL_58
+#  endif
+#  ifdef XLAT_VAL_59
+  | XLAT_VAL_59
+#  endif
+#  ifdef XLAT_VAL_60
+  | XLAT_VAL_60
+#  endif
+#  ifdef XLAT_VAL_61
+  | XLAT_VAL_61
+#  endif
+#  ifdef XLAT_VAL_62
+  | XLAT_VAL_62
+#  endif
+#  ifdef XLAT_VAL_63
+  | XLAT_VAL_63
+#  endif
+#  ifdef XLAT_VAL_64
+  | XLAT_VAL_64
+#  endif
+#  ifdef XLAT_VAL_65
+  | XLAT_VAL_65
+#  endif
+#  ifdef XLAT_VAL_66
+  | XLAT_VAL_66
+#  endif
+#  ifdef XLAT_VAL_67
+  | XLAT_VAL_67
+#  endif
+#  ifdef XLAT_VAL_68
+  | XLAT_VAL_68
+#  endif
+#  ifdef XLAT_VAL_69
+  | XLAT_VAL_69
+#  endif
+#  ifdef XLAT_VAL_70
+  | XLAT_VAL_70
+#  endif
+#  ifdef XLAT_VAL_71
+  | XLAT_VAL_71
+#  endif
+#  ifdef XLAT_VAL_72
+  | XLAT_VAL_72
+#  endif
+#  ifdef XLAT_VAL_73
+  | XLAT_VAL_73
+#  endif
+#  ifdef XLAT_VAL_74
+  | XLAT_VAL_74
+#  endif
+#  ifdef XLAT_VAL_75
+  | XLAT_VAL_75
+#  endif
+#  ifdef XLAT_VAL_76
+  | XLAT_VAL_76
+#  endif
+#  ifdef XLAT_VAL_77
+  | XLAT_VAL_77
+#  endif
+#  ifdef XLAT_VAL_78
+  | XLAT_VAL_78
+#  endif
+#  ifdef XLAT_VAL_79
+  | XLAT_VAL_79
+#  endif
+#  ifdef XLAT_VAL_80
+  | XLAT_VAL_80
+#  endif
+#  ifdef XLAT_VAL_81
+  | XLAT_VAL_81
+#  endif
+#  ifdef XLAT_VAL_82
+  | XLAT_VAL_82
+#  endif
+#  ifdef XLAT_VAL_83
+  | XLAT_VAL_83
+#  endif
+#  ifdef XLAT_VAL_84
+  | XLAT_VAL_84
+#  endif
+#  ifdef XLAT_VAL_85
+  | XLAT_VAL_85
+#  endif
+#  ifdef XLAT_VAL_86
+  | XLAT_VAL_86
+#  endif
+#  ifdef XLAT_VAL_87
+  | XLAT_VAL_87
+#  endif
+#  ifdef XLAT_VAL_88
+  | XLAT_VAL_88
+#  endif
+#  ifdef XLAT_VAL_89
+  | XLAT_VAL_89
+#  endif
+#  ifdef XLAT_VAL_90
+  | XLAT_VAL_90
+#  endif
+#  ifdef XLAT_VAL_91
+  | XLAT_VAL_91
+#  endif
+#  ifdef XLAT_VAL_92
+  | XLAT_VAL_92
+#  endif
+#  ifdef XLAT_VAL_93
+  | XLAT_VAL_93
+#  endif
+#  ifdef XLAT_VAL_94
+  | XLAT_VAL_94
+#  endif
+#  ifdef XLAT_VAL_95
+  | XLAT_VAL_95
+#  endif
+#  ifdef XLAT_VAL_96
+  | XLAT_VAL_96
+#  endif
+#  ifdef XLAT_VAL_97
+  | XLAT_VAL_97
+#  endif
+#  ifdef XLAT_VAL_98
+  | XLAT_VAL_98
+#  endif
+#  ifdef XLAT_VAL_99
+  | XLAT_VAL_99
+#  endif
+#  ifdef XLAT_VAL_100
+  | XLAT_VAL_100
+#  endif
+#  ifdef XLAT_VAL_101
+  | XLAT_VAL_101
+#  endif
+#  ifdef XLAT_VAL_102
+  | XLAT_VAL_102
+#  endif
+#  ifdef XLAT_VAL_103
+  | XLAT_VAL_103
+#  endif
+#  ifdef XLAT_VAL_104
+  | XLAT_VAL_104
+#  endif
+#  ifdef XLAT_VAL_105
+  | XLAT_VAL_105
+#  endif
+#  ifdef XLAT_VAL_106
+  | XLAT_VAL_106
+#  endif
+#  ifdef XLAT_VAL_107
+  | XLAT_VAL_107
+#  endif
+#  ifdef XLAT_VAL_108
+  | XLAT_VAL_108
+#  endif
+#  ifdef XLAT_VAL_109
+  | XLAT_VAL_109
+#  endif
+#  ifdef XLAT_VAL_110
+  | XLAT_VAL_110
+#  endif
+#  ifdef XLAT_VAL_111
+  | XLAT_VAL_111
+#  endif
+#  ifdef XLAT_VAL_112
+  | XLAT_VAL_112
+#  endif
+#  ifdef XLAT_VAL_113
+  | XLAT_VAL_113
+#  endif
+#  ifdef XLAT_VAL_114
+  | XLAT_VAL_114
+#  endif
+#  ifdef XLAT_VAL_115
+  | XLAT_VAL_115
+#  endif
+#  ifdef XLAT_VAL_116
+  | XLAT_VAL_116
+#  endif
+#  ifdef XLAT_VAL_117
+  | XLAT_VAL_117
+#  endif
+#  ifdef XLAT_VAL_118
+  | XLAT_VAL_118
+#  endif
+#  ifdef XLAT_VAL_119
+  | XLAT_VAL_119
+#  endif
+#  ifdef XLAT_VAL_120
+  | XLAT_VAL_120
+#  endif
+#  ifdef XLAT_VAL_121
+  | XLAT_VAL_121
+#  endif
+#  ifdef XLAT_VAL_122
+  | XLAT_VAL_122
+#  endif
+#  ifdef XLAT_VAL_123
+  | XLAT_VAL_123
+#  endif
+#  ifdef XLAT_VAL_124
+  | XLAT_VAL_124
+#  endif
+#  ifdef XLAT_VAL_125
+  | XLAT_VAL_125
+#  endif
+#  ifdef XLAT_VAL_126
+  | XLAT_VAL_126
+#  endif
+#  ifdef XLAT_VAL_127
+  | XLAT_VAL_127
+#  endif
+#  ifdef XLAT_VAL_128
+  | XLAT_VAL_128
+#  endif
+#  ifdef XLAT_VAL_129
+  | XLAT_VAL_129
+#  endif
+#  ifdef XLAT_VAL_130
+  | XLAT_VAL_130
+#  endif
+#  ifdef XLAT_VAL_131
+  | XLAT_VAL_131
+#  endif
+#  ifdef XLAT_VAL_132
+  | XLAT_VAL_132
+#  endif
+#  ifdef XLAT_VAL_133
+  | XLAT_VAL_133
+#  endif
+#  ifdef XLAT_VAL_134
+  | XLAT_VAL_134
+#  endif
+#  ifdef XLAT_VAL_135
+  | XLAT_VAL_135
+#  endif
+#  ifdef XLAT_VAL_136
+  | XLAT_VAL_136
+#  endif
+#  ifdef XLAT_VAL_137
+  | XLAT_VAL_137
+#  endif
+#  ifdef XLAT_VAL_138
+  | XLAT_VAL_138
+#  endif
+#  ifdef XLAT_VAL_139
+  | XLAT_VAL_139
+#  endif
+#  ifdef XLAT_VAL_140
+  | XLAT_VAL_140
+#  endif
+#  ifdef XLAT_VAL_141
+  | XLAT_VAL_141
+#  endif
+#  ifdef XLAT_VAL_142
+  | XLAT_VAL_142
+#  endif
+#  ifdef XLAT_VAL_143
+  | XLAT_VAL_143
+#  endif
+#  ifdef XLAT_VAL_144
+  | XLAT_VAL_144
+#  endif
+#  ifdef XLAT_VAL_145
+  | XLAT_VAL_145
+#  endif
+#  ifdef XLAT_VAL_146
+  | XLAT_VAL_146
+#  endif
+#  ifdef XLAT_VAL_147
+  | XLAT_VAL_147
+#  endif
+#  ifdef XLAT_VAL_148
+  | XLAT_VAL_148
+#  endif
+#  ifdef XLAT_VAL_149
+  | XLAT_VAL_149
+#  endif
+#  ifdef XLAT_VAL_150
+  | XLAT_VAL_150
+#  endif
+#  ifdef XLAT_VAL_151
+  | XLAT_VAL_151
+#  endif
+#  ifdef XLAT_VAL_152
+  | XLAT_VAL_152
+#  endif
+#  ifdef XLAT_VAL_153
+  | XLAT_VAL_153
+#  endif
+#  ifdef XLAT_VAL_154
+  | XLAT_VAL_154
+#  endif
+#  ifdef XLAT_VAL_155
+  | XLAT_VAL_155
+#  endif
+#  ifdef XLAT_VAL_156
+  | XLAT_VAL_156
+#  endif
+#  ifdef XLAT_VAL_157
+  | XLAT_VAL_157
+#  endif
+#  ifdef XLAT_VAL_158
+  | XLAT_VAL_158
+#  endif
+#  ifdef XLAT_VAL_159
+  | XLAT_VAL_159
+#  endif
+#  ifdef XLAT_VAL_160
+  | XLAT_VAL_160
+#  endif
+#  ifdef XLAT_VAL_161
+  | XLAT_VAL_161
+#  endif
+#  ifdef XLAT_VAL_162
+  | XLAT_VAL_162
+#  endif
+#  ifdef XLAT_VAL_163
+  | XLAT_VAL_163
+#  endif
+#  ifdef XLAT_VAL_164
+  | XLAT_VAL_164
+#  endif
+#  ifdef XLAT_VAL_165
+  | XLAT_VAL_165
+#  endif
+#  ifdef XLAT_VAL_166
+  | XLAT_VAL_166
+#  endif
+#  ifdef XLAT_VAL_167
+  | XLAT_VAL_167
+#  endif
+#  ifdef XLAT_VAL_168
+  | XLAT_VAL_168
+#  endif
+#  ifdef XLAT_VAL_169
+  | XLAT_VAL_169
+#  endif
+#  ifdef XLAT_VAL_170
+  | XLAT_VAL_170
+#  endif
+#  ifdef XLAT_VAL_171
+  | XLAT_VAL_171
+#  endif
+#  ifdef XLAT_VAL_172
+  | XLAT_VAL_172
+#  endif
+#  ifdef XLAT_VAL_173
+  | XLAT_VAL_173
+#  endif
+#  ifdef XLAT_VAL_174
+  | XLAT_VAL_174
+#  endif
+#  ifdef XLAT_VAL_175
+  | XLAT_VAL_175
+#  endif
+#  ifdef XLAT_VAL_176
+  | XLAT_VAL_176
+#  endif
+#  ifdef XLAT_VAL_177
+  | XLAT_VAL_177
+#  endif
+#  ifdef XLAT_VAL_178
+  | XLAT_VAL_178
+#  endif
+#  ifdef XLAT_VAL_179
+  | XLAT_VAL_179
+#  endif
+#  ifdef XLAT_VAL_180
+  | XLAT_VAL_180
+#  endif
+#  ifdef XLAT_VAL_181
+  | XLAT_VAL_181
+#  endif
+#  ifdef XLAT_VAL_182
+  | XLAT_VAL_182
+#  endif
+#  ifdef XLAT_VAL_183
+  | XLAT_VAL_183
+#  endif
+#  ifdef XLAT_VAL_184
+  | XLAT_VAL_184
+#  endif
+#  ifdef XLAT_VAL_185
+  | XLAT_VAL_185
+#  endif
+#  ifdef XLAT_VAL_186
+  | XLAT_VAL_186
+#  endif
+#  ifdef XLAT_VAL_187
+  | XLAT_VAL_187
+#  endif
+#  ifdef XLAT_VAL_188
+  | XLAT_VAL_188
+#  endif
+#  ifdef XLAT_VAL_189
+  | XLAT_VAL_189
+#  endif
+#  ifdef XLAT_VAL_190
+  | XLAT_VAL_190
+#  endif
+#  ifdef XLAT_VAL_191
+  | XLAT_VAL_191
+#  endif
+#  ifdef XLAT_VAL_192
+  | XLAT_VAL_192
+#  endif
+#  ifdef XLAT_VAL_193
+  | XLAT_VAL_193
+#  endif
+#  ifdef XLAT_VAL_194
+  | XLAT_VAL_194
+#  endif
+#  ifdef XLAT_VAL_195
+  | XLAT_VAL_195
+#  endif
+#  ifdef XLAT_VAL_196
+  | XLAT_VAL_196
+#  endif
+#  ifdef XLAT_VAL_197
+  | XLAT_VAL_197
+#  endif
+#  ifdef XLAT_VAL_198
+  | XLAT_VAL_198
+#  endif
+#  ifdef XLAT_VAL_199
+  | XLAT_VAL_199
+#  endif
+#  ifdef XLAT_VAL_200
+  | XLAT_VAL_200
+#  endif
+#  ifdef XLAT_VAL_201
+  | XLAT_VAL_201
+#  endif
+#  ifdef XLAT_VAL_202
+  | XLAT_VAL_202
+#  endif
+#  ifdef XLAT_VAL_203
+  | XLAT_VAL_203
+#  endif
+#  ifdef XLAT_VAL_204
+  | XLAT_VAL_204
+#  endif
+#  ifdef XLAT_VAL_205
+  | XLAT_VAL_205
+#  endif
+#  ifdef XLAT_VAL_206
+  | XLAT_VAL_206
+#  endif
+#  ifdef XLAT_VAL_207
+  | XLAT_VAL_207
+#  endif
+#  ifdef XLAT_VAL_208
+  | XLAT_VAL_208
+#  endif
+#  ifdef XLAT_VAL_209
+  | XLAT_VAL_209
+#  endif
+#  ifdef XLAT_VAL_210
+  | XLAT_VAL_210
+#  endif
+#  ifdef XLAT_VAL_211
+  | XLAT_VAL_211
+#  endif
+#  ifdef XLAT_VAL_212
+  | XLAT_VAL_212
+#  endif
+#  ifdef XLAT_VAL_213
+  | XLAT_VAL_213
+#  endif
+#  ifdef XLAT_VAL_214
+  | XLAT_VAL_214
+#  endif
+#  ifdef XLAT_VAL_215
+  | XLAT_VAL_215
+#  endif
+#  ifdef XLAT_VAL_216
+  | XLAT_VAL_216
+#  endif
+#  ifdef XLAT_VAL_217
+  | XLAT_VAL_217
+#  endif
+#  ifdef XLAT_VAL_218
+  | XLAT_VAL_218
+#  endif
+#  ifdef XLAT_VAL_219
+  | XLAT_VAL_219
+#  endif
+#  ifdef XLAT_VAL_220
+  | XLAT_VAL_220
+#  endif
+#  ifdef XLAT_VAL_221
+  | XLAT_VAL_221
+#  endif
+#  ifdef XLAT_VAL_222
+  | XLAT_VAL_222
+#  endif
+#  ifdef XLAT_VAL_223
+  | XLAT_VAL_223
+#  endif
+#  ifdef XLAT_VAL_224
+  | XLAT_VAL_224
+#  endif
+#  ifdef XLAT_VAL_225
+  | XLAT_VAL_225
+#  endif
+#  ifdef XLAT_VAL_226
+  | XLAT_VAL_226
+#  endif
+#  ifdef XLAT_VAL_227
+  | XLAT_VAL_227
+#  endif
+#  ifdef XLAT_VAL_228
+  | XLAT_VAL_228
+#  endif
+#  ifdef XLAT_VAL_229
+  | XLAT_VAL_229
+#  endif
+#  ifdef XLAT_VAL_230
+  | XLAT_VAL_230
+#  endif
+#  ifdef XLAT_VAL_231
+  | XLAT_VAL_231
+#  endif
+#  ifdef XLAT_VAL_232
+  | XLAT_VAL_232
+#  endif
+#  ifdef XLAT_VAL_233
+  | XLAT_VAL_233
+#  endif
+#  ifdef XLAT_VAL_234
+  | XLAT_VAL_234
+#  endif
+#  ifdef XLAT_VAL_235
+  | XLAT_VAL_235
+#  endif
+#  ifdef XLAT_VAL_236
+  | XLAT_VAL_236
+#  endif
+#  ifdef XLAT_VAL_237
+  | XLAT_VAL_237
+#  endif
+#  ifdef XLAT_VAL_238
+  | XLAT_VAL_238
+#  endif
+#  ifdef XLAT_VAL_239
+  | XLAT_VAL_239
+#  endif
+#  ifdef XLAT_VAL_240
+  | XLAT_VAL_240
+#  endif
+#  ifdef XLAT_VAL_241
+  | XLAT_VAL_241
+#  endif
+#  ifdef XLAT_VAL_242
+  | XLAT_VAL_242
+#  endif
+#  ifdef XLAT_VAL_243
+  | XLAT_VAL_243
+#  endif
+#  ifdef XLAT_VAL_244
+  | XLAT_VAL_244
+#  endif
+#  ifdef XLAT_VAL_245
+  | XLAT_VAL_245
+#  endif
+#  ifdef XLAT_VAL_246
+  | XLAT_VAL_246
+#  endif
+#  ifdef XLAT_VAL_247
+  | XLAT_VAL_247
+#  endif
+#  ifdef XLAT_VAL_248
+  | XLAT_VAL_248
+#  endif
+#  ifdef XLAT_VAL_249
+  | XLAT_VAL_249
+#  endif
+#  ifdef XLAT_VAL_250
+  | XLAT_VAL_250
+#  endif
+#  ifdef XLAT_VAL_251
+  | XLAT_VAL_251
+#  endif
+#  ifdef XLAT_VAL_252
+  | XLAT_VAL_252
+#  endif
+#  ifdef XLAT_VAL_253
+  | XLAT_VAL_253
+#  endif
+#  ifdef XLAT_VAL_254
+  | XLAT_VAL_254
+#  endif
+#  ifdef XLAT_VAL_255
+  | XLAT_VAL_255
+#  endif
+#  ifdef XLAT_VAL_256
+  | XLAT_VAL_256
+#  endif
+#  ifdef XLAT_VAL_257
+  | XLAT_VAL_257
+#  endif
+#  ifdef XLAT_VAL_258
+  | XLAT_VAL_258
+#  endif
+#  ifdef XLAT_VAL_259
+  | XLAT_VAL_259
+#  endif
+#  ifdef XLAT_VAL_260
+  | XLAT_VAL_260
+#  endif
+#  ifdef XLAT_VAL_261
+  | XLAT_VAL_261
+#  endif
+#  ifdef XLAT_VAL_262
+  | XLAT_VAL_262
+#  endif
+#  ifdef XLAT_VAL_263
+  | XLAT_VAL_263
+#  endif
+#  ifdef XLAT_VAL_264
+  | XLAT_VAL_264
+#  endif
+#  ifdef XLAT_VAL_265
+  | XLAT_VAL_265
+#  endif
+#  ifdef XLAT_VAL_266
+  | XLAT_VAL_266
+#  endif
+#  ifdef XLAT_VAL_267
+  | XLAT_VAL_267
+#  endif
+#  ifdef XLAT_VAL_268
+  | XLAT_VAL_268
+#  endif
+#  ifdef XLAT_VAL_269
+  | XLAT_VAL_269
+#  endif
+#  ifdef XLAT_VAL_270
+  | XLAT_VAL_270
+#  endif
+#  ifdef XLAT_VAL_271
+  | XLAT_VAL_271
+#  endif
+#  ifdef XLAT_VAL_272
+  | XLAT_VAL_272
+#  endif
+#  ifdef XLAT_VAL_273
+  | XLAT_VAL_273
+#  endif
+#  ifdef XLAT_VAL_274
+  | XLAT_VAL_274
+#  endif
+#  ifdef XLAT_VAL_275
+  | XLAT_VAL_275
+#  endif
+#  ifdef XLAT_VAL_276
+  | XLAT_VAL_276
+#  endif
+#  ifdef XLAT_VAL_277
+  | XLAT_VAL_277
+#  endif
+#  ifdef XLAT_VAL_278
+  | XLAT_VAL_278
+#  endif
+#  ifdef XLAT_VAL_279
+  | XLAT_VAL_279
+#  endif
+#  ifdef XLAT_VAL_280
+  | XLAT_VAL_280
+#  endif
+#  ifdef XLAT_VAL_281
+  | XLAT_VAL_281
+#  endif
+#  ifdef XLAT_VAL_282
+  | XLAT_VAL_282
+#  endif
+#  ifdef XLAT_VAL_283
+  | XLAT_VAL_283
+#  endif
+#  ifdef XLAT_VAL_284
+  | XLAT_VAL_284
+#  endif
+#  ifdef XLAT_VAL_285
+  | XLAT_VAL_285
+#  endif
+#  ifdef XLAT_VAL_286
+  | XLAT_VAL_286
+#  endif
+#  ifdef XLAT_VAL_287
+  | XLAT_VAL_287
+#  endif
+#  ifdef XLAT_VAL_288
+  | XLAT_VAL_288
+#  endif
+#  ifdef XLAT_VAL_289
+  | XLAT_VAL_289
+#  endif
+#  ifdef XLAT_VAL_290
+  | XLAT_VAL_290
+#  endif
+#  ifdef XLAT_VAL_291
+  | XLAT_VAL_291
+#  endif
+#  ifdef XLAT_VAL_292
+  | XLAT_VAL_292
+#  endif
+#  ifdef XLAT_VAL_293
+  | XLAT_VAL_293
+#  endif
+#  ifdef XLAT_VAL_294
+  | XLAT_VAL_294
+#  endif
+#  ifdef XLAT_VAL_295
+  | XLAT_VAL_295
+#  endif
+#  ifdef XLAT_VAL_296
+  | XLAT_VAL_296
+#  endif
+#  ifdef XLAT_VAL_297
+  | XLAT_VAL_297
+#  endif
+#  ifdef XLAT_VAL_298
+  | XLAT_VAL_298
+#  endif
+#  ifdef XLAT_VAL_299
+  | XLAT_VAL_299
+#  endif
+#  ifdef XLAT_VAL_300
+  | XLAT_VAL_300
+#  endif
+#  ifdef XLAT_VAL_301
+  | XLAT_VAL_301
+#  endif
+#  ifdef XLAT_VAL_302
+  | XLAT_VAL_302
+#  endif
+#  ifdef XLAT_VAL_303
+  | XLAT_VAL_303
+#  endif
+#  ifdef XLAT_VAL_304
+  | XLAT_VAL_304
+#  endif
+#  ifdef XLAT_VAL_305
+  | XLAT_VAL_305
+#  endif
+#  ifdef XLAT_VAL_306
+  | XLAT_VAL_306
+#  endif
+#  ifdef XLAT_VAL_307
+  | XLAT_VAL_307
+#  endif
+#  ifdef XLAT_VAL_308
+  | XLAT_VAL_308
+#  endif
+#  ifdef XLAT_VAL_309
+  | XLAT_VAL_309
+#  endif
+#  ifdef XLAT_VAL_310
+  | XLAT_VAL_310
+#  endif
+#  ifdef XLAT_VAL_311
+  | XLAT_VAL_311
+#  endif
+#  ifdef XLAT_VAL_312
+  | XLAT_VAL_312
+#  endif
+#  ifdef XLAT_VAL_313
+  | XLAT_VAL_313
+#  endif
+#  ifdef XLAT_VAL_314
+  | XLAT_VAL_314
+#  endif
+#  ifdef XLAT_VAL_315
+  | XLAT_VAL_315
+#  endif
+#  ifdef XLAT_VAL_316
+  | XLAT_VAL_316
+#  endif
+#  ifdef XLAT_VAL_317
+  | XLAT_VAL_317
+#  endif
+#  ifdef XLAT_VAL_318
+  | XLAT_VAL_318
+#  endif
+#  ifdef XLAT_VAL_319
+  | XLAT_VAL_319
+#  endif
+#  ifdef XLAT_VAL_320
+  | XLAT_VAL_320
+#  endif
+#  ifdef XLAT_VAL_321
+  | XLAT_VAL_321
+#  endif
+#  ifdef XLAT_VAL_322
+  | XLAT_VAL_322
+#  endif
+#  ifdef XLAT_VAL_323
+  | XLAT_VAL_323
+#  endif
+#  ifdef XLAT_VAL_324
+  | XLAT_VAL_324
+#  endif
+#  ifdef XLAT_VAL_325
+  | XLAT_VAL_325
+#  endif
+#  ifdef XLAT_VAL_326
+  | XLAT_VAL_326
+#  endif
+#  ifdef XLAT_VAL_327
+  | XLAT_VAL_327
+#  endif
+#  ifdef XLAT_VAL_328
+  | XLAT_VAL_328
+#  endif
+#  ifdef XLAT_VAL_329
+  | XLAT_VAL_329
+#  endif
+#  ifdef XLAT_VAL_330
+  | XLAT_VAL_330
+#  endif
+#  ifdef XLAT_VAL_331
+  | XLAT_VAL_331
+#  endif
+#  ifdef XLAT_VAL_332
+  | XLAT_VAL_332
+#  endif
+#  ifdef XLAT_VAL_333
+  | XLAT_VAL_333
+#  endif
+#  ifdef XLAT_VAL_334
+  | XLAT_VAL_334
+#  endif
+#  ifdef XLAT_VAL_335
+  | XLAT_VAL_335
+#  endif
+#  ifdef XLAT_VAL_336
+  | XLAT_VAL_336
+#  endif
+#  ifdef XLAT_VAL_337
+  | XLAT_VAL_337
+#  endif
+#  ifdef XLAT_VAL_338
+  | XLAT_VAL_338
+#  endif
+#  ifdef XLAT_VAL_339
+  | XLAT_VAL_339
+#  endif
+#  ifdef XLAT_VAL_340
+  | XLAT_VAL_340
+#  endif
+#  ifdef XLAT_VAL_341
+  | XLAT_VAL_341
+#  endif
+#  ifdef XLAT_VAL_342
+  | XLAT_VAL_342
+#  endif
+#  ifdef XLAT_VAL_343
+  | XLAT_VAL_343
+#  endif
+#  ifdef XLAT_VAL_344
+  | XLAT_VAL_344
+#  endif
+#  ifdef XLAT_VAL_345
+  | XLAT_VAL_345
+#  endif
+#  ifdef XLAT_VAL_346
+  | XLAT_VAL_346
+#  endif
+#  ifdef XLAT_VAL_347
+  | XLAT_VAL_347
+#  endif
+#  ifdef XLAT_VAL_348
+  | XLAT_VAL_348
+#  endif
+#  ifdef XLAT_VAL_349
+  | XLAT_VAL_349
+#  endif
+#  ifdef XLAT_VAL_350
+  | XLAT_VAL_350
+#  endif
+#  ifdef XLAT_VAL_351
+  | XLAT_VAL_351
+#  endif
+#  ifdef XLAT_VAL_352
+  | XLAT_VAL_352
+#  endif
+#  ifdef XLAT_VAL_353
+  | XLAT_VAL_353
+#  endif
+#  ifdef XLAT_VAL_354
+  | XLAT_VAL_354
+#  endif
+#  ifdef XLAT_VAL_355
+  | XLAT_VAL_355
+#  endif
+#  ifdef XLAT_VAL_356
+  | XLAT_VAL_356
+#  endif
+#  ifdef XLAT_VAL_357
+  | XLAT_VAL_357
+#  endif
+#  ifdef XLAT_VAL_358
+  | XLAT_VAL_358
+#  endif
+#  ifdef XLAT_VAL_359
+  | XLAT_VAL_359
+#  endif
+#  ifdef XLAT_VAL_360
+  | XLAT_VAL_360
+#  endif
+#  ifdef XLAT_VAL_361
+  | XLAT_VAL_361
+#  endif
+#  ifdef XLAT_VAL_362
+  | XLAT_VAL_362
+#  endif
+#  ifdef XLAT_VAL_363
+  | XLAT_VAL_363
+#  endif
+#  ifdef XLAT_VAL_364
+  | XLAT_VAL_364
+#  endif
+#  ifdef XLAT_VAL_365
+  | XLAT_VAL_365
+#  endif
+#  ifdef XLAT_VAL_366
+  | XLAT_VAL_366
+#  endif
+#  ifdef XLAT_VAL_367
+  | XLAT_VAL_367
+#  endif
+#  ifdef XLAT_VAL_368
+  | XLAT_VAL_368
+#  endif
+#  ifdef XLAT_VAL_369
+  | XLAT_VAL_369
+#  endif
+#  ifdef XLAT_VAL_370
+  | XLAT_VAL_370
+#  endif
+#  ifdef XLAT_VAL_371
+  | XLAT_VAL_371
+#  endif
+#  ifdef XLAT_VAL_372
+  | XLAT_VAL_372
+#  endif
+#  ifdef XLAT_VAL_373
+  | XLAT_VAL_373
+#  endif
+#  ifdef XLAT_VAL_374
+  | XLAT_VAL_374
+#  endif
+#  ifdef XLAT_VAL_375
+  | XLAT_VAL_375
+#  endif
+#  ifdef XLAT_VAL_376
+  | XLAT_VAL_376
+#  endif
+#  ifdef XLAT_VAL_377
+  | XLAT_VAL_377
+#  endif
+#  ifdef XLAT_VAL_378
+  | XLAT_VAL_378
+#  endif
+#  ifdef XLAT_VAL_379
+  | XLAT_VAL_379
+#  endif
+#  ifdef XLAT_VAL_380
+  | XLAT_VAL_380
+#  endif
+#  ifdef XLAT_VAL_381
+  | XLAT_VAL_381
+#  endif
+#  ifdef XLAT_VAL_382
+  | XLAT_VAL_382
+#  endif
+#  ifdef XLAT_VAL_383
+  | XLAT_VAL_383
+#  endif
+#  ifdef XLAT_VAL_384
+  | XLAT_VAL_384
+#  endif
+#  ifdef XLAT_VAL_385
+  | XLAT_VAL_385
+#  endif
+#  ifdef XLAT_VAL_386
+  | XLAT_VAL_386
+#  endif
+#  ifdef XLAT_VAL_387
+  | XLAT_VAL_387
+#  endif
+#  ifdef XLAT_VAL_388
+  | XLAT_VAL_388
+#  endif
+#  ifdef XLAT_VAL_389
+  | XLAT_VAL_389
+#  endif
+#  ifdef XLAT_VAL_390
+  | XLAT_VAL_390
+#  endif
+#  ifdef XLAT_VAL_391
+  | XLAT_VAL_391
+#  endif
+#  ifdef XLAT_VAL_392
+  | XLAT_VAL_392
+#  endif
+#  ifdef XLAT_VAL_393
+  | XLAT_VAL_393
+#  endif
+#  ifdef XLAT_VAL_394
+  | XLAT_VAL_394
+#  endif
+#  ifdef XLAT_VAL_395
+  | XLAT_VAL_395
+#  endif
+#  ifdef XLAT_VAL_396
+  | XLAT_VAL_396
+#  endif
+#  ifdef XLAT_VAL_397
+  | XLAT_VAL_397
+#  endif
+#  ifdef XLAT_VAL_398
+  | XLAT_VAL_398
+#  endif
+#  ifdef XLAT_VAL_399
+  | XLAT_VAL_399
+#  endif
+#  ifdef XLAT_VAL_400
+  | XLAT_VAL_400
+#  endif
+#  ifdef XLAT_VAL_401
+  | XLAT_VAL_401
+#  endif
+#  ifdef XLAT_VAL_402
+  | XLAT_VAL_402
+#  endif
+#  ifdef XLAT_VAL_403
+  | XLAT_VAL_403
+#  endif
+#  ifdef XLAT_VAL_404
+  | XLAT_VAL_404
+#  endif
+#  ifdef XLAT_VAL_405
+  | XLAT_VAL_405
+#  endif
+#  ifdef XLAT_VAL_406
+  | XLAT_VAL_406
+#  endif
+#  ifdef XLAT_VAL_407
+  | XLAT_VAL_407
+#  endif
+#  ifdef XLAT_VAL_408
+  | XLAT_VAL_408
+#  endif
+#  ifdef XLAT_VAL_409
+  | XLAT_VAL_409
+#  endif
+#  ifdef XLAT_VAL_410
+  | XLAT_VAL_410
+#  endif
+#  ifdef XLAT_VAL_411
+  | XLAT_VAL_411
+#  endif
+#  ifdef XLAT_VAL_412
+  | XLAT_VAL_412
+#  endif
+#  ifdef XLAT_VAL_413
+  | XLAT_VAL_413
+#  endif
+#  ifdef XLAT_VAL_414
+  | XLAT_VAL_414
+#  endif
+#  ifdef XLAT_VAL_415
+  | XLAT_VAL_415
+#  endif
+#  ifdef XLAT_VAL_416
+  | XLAT_VAL_416
+#  endif
+#  ifdef XLAT_VAL_417
+  | XLAT_VAL_417
+#  endif
+#  ifdef XLAT_VAL_418
+  | XLAT_VAL_418
+#  endif
+#  ifdef XLAT_VAL_419
+  | XLAT_VAL_419
+#  endif
+#  ifdef XLAT_VAL_420
+  | XLAT_VAL_420
+#  endif
+#  ifdef XLAT_VAL_421
+  | XLAT_VAL_421
+#  endif
+#  ifdef XLAT_VAL_422
+  | XLAT_VAL_422
+#  endif
+#  ifdef XLAT_VAL_423
+  | XLAT_VAL_423
+#  endif
+#  ifdef XLAT_VAL_424
+  | XLAT_VAL_424
+#  endif
+#  ifdef XLAT_VAL_425
+  | XLAT_VAL_425
+#  endif
+#  ifdef XLAT_VAL_426
+  | XLAT_VAL_426
+#  endif
+#  ifdef XLAT_VAL_427
+  | XLAT_VAL_427
+#  endif
+#  ifdef XLAT_VAL_428
+  | XLAT_VAL_428
+#  endif
+#  ifdef XLAT_VAL_429
+  | XLAT_VAL_429
+#  endif
+#  ifdef XLAT_VAL_430
+  | XLAT_VAL_430
+#  endif
+#  ifdef XLAT_VAL_431
+  | XLAT_VAL_431
+#  endif
+#  ifdef XLAT_VAL_432
+  | XLAT_VAL_432
+#  endif
+#  ifdef XLAT_VAL_433
+  | XLAT_VAL_433
+#  endif
+#  ifdef XLAT_VAL_434
+  | XLAT_VAL_434
+#  endif
+#  ifdef XLAT_VAL_435
+  | XLAT_VAL_435
+#  endif
+#  ifdef XLAT_VAL_436
+  | XLAT_VAL_436
+#  endif
+#  ifdef XLAT_VAL_437
+  | XLAT_VAL_437
+#  endif
+#  ifdef XLAT_VAL_438
+  | XLAT_VAL_438
+#  endif
+#  ifdef XLAT_VAL_439
+  | XLAT_VAL_439
+#  endif
+#  ifdef XLAT_VAL_440
+  | XLAT_VAL_440
+#  endif
+#  ifdef XLAT_VAL_441
+  | XLAT_VAL_441
+#  endif
+#  ifdef XLAT_VAL_442
+  | XLAT_VAL_442
+#  endif
+#  ifdef XLAT_VAL_443
+  | XLAT_VAL_443
+#  endif
+#  ifdef XLAT_VAL_444
+  | XLAT_VAL_444
+#  endif
+#  ifdef XLAT_VAL_445
+  | XLAT_VAL_445
+#  endif
+#  ifdef XLAT_VAL_446
+  | XLAT_VAL_446
+#  endif
+#  ifdef XLAT_VAL_447
+  | XLAT_VAL_447
+#  endif
+#  ifdef XLAT_VAL_448
+  | XLAT_VAL_448
+#  endif
+#  ifdef XLAT_VAL_449
+  | XLAT_VAL_449
+#  endif
+#  ifdef XLAT_VAL_450
+  | XLAT_VAL_450
+#  endif
+#  ifdef XLAT_VAL_451
+  | XLAT_VAL_451
+#  endif
+#  ifdef XLAT_VAL_452
+  | XLAT_VAL_452
+#  endif
+#  ifdef XLAT_VAL_453
+  | XLAT_VAL_453
+#  endif
+#  ifdef XLAT_VAL_454
+  | XLAT_VAL_454
+#  endif
+#  ifdef XLAT_VAL_455
+  | XLAT_VAL_455
+#  endif
+#  ifdef XLAT_VAL_456
+  | XLAT_VAL_456
+#  endif
+#  ifdef XLAT_VAL_457
+  | XLAT_VAL_457
+#  endif
+#  ifdef XLAT_VAL_458
+  | XLAT_VAL_458
+#  endif
+#  ifdef XLAT_VAL_459
+  | XLAT_VAL_459
+#  endif
+#  ifdef XLAT_VAL_460
+  | XLAT_VAL_460
+#  endif
+#  ifdef XLAT_VAL_461
+  | XLAT_VAL_461
+#  endif
+#  ifdef XLAT_VAL_462
+  | XLAT_VAL_462
+#  endif
+#  ifdef XLAT_VAL_463
+  | XLAT_VAL_463
+#  endif
+#  ifdef XLAT_VAL_464
+  | XLAT_VAL_464
+#  endif
+#  ifdef XLAT_VAL_465
+  | XLAT_VAL_465
+#  endif
+#  ifdef XLAT_VAL_466
+  | XLAT_VAL_466
+#  endif
+#  ifdef XLAT_VAL_467
+  | XLAT_VAL_467
+#  endif
+#  ifdef XLAT_VAL_468
+  | XLAT_VAL_468
+#  endif
+#  ifdef XLAT_VAL_469
+  | XLAT_VAL_469
+#  endif
+#  ifdef XLAT_VAL_470
+  | XLAT_VAL_470
+#  endif
+#  ifdef XLAT_VAL_471
+  | XLAT_VAL_471
+#  endif
+#  ifdef XLAT_VAL_472
+  | XLAT_VAL_472
+#  endif
+#  ifdef XLAT_VAL_473
+  | XLAT_VAL_473
+#  endif
+#  ifdef XLAT_VAL_474
+  | XLAT_VAL_474
+#  endif
+#  ifdef XLAT_VAL_475
+  | XLAT_VAL_475
+#  endif
+#  ifdef XLAT_VAL_476
+  | XLAT_VAL_476
+#  endif
+#  ifdef XLAT_VAL_477
+  | XLAT_VAL_477
+#  endif
+#  ifdef XLAT_VAL_478
+  | XLAT_VAL_478
+#  endif
+#  ifdef XLAT_VAL_479
+  | XLAT_VAL_479
+#  endif
+#  ifdef XLAT_VAL_480
+  | XLAT_VAL_480
+#  endif
+#  ifdef XLAT_VAL_481
+  | XLAT_VAL_481
+#  endif
+#  ifdef XLAT_VAL_482
+  | XLAT_VAL_482
+#  endif
+#  ifdef XLAT_VAL_483
+  | XLAT_VAL_483
+#  endif
+#  ifdef XLAT_VAL_484
+  | XLAT_VAL_484
+#  endif
+#  ifdef XLAT_VAL_485
+  | XLAT_VAL_485
+#  endif
+#  ifdef XLAT_VAL_486
+  | XLAT_VAL_486
+#  endif
+#  ifdef XLAT_VAL_487
+  | XLAT_VAL_487
+#  endif
+#  ifdef XLAT_VAL_488
+  | XLAT_VAL_488
+#  endif
+#  ifdef XLAT_VAL_489
+  | XLAT_VAL_489
+#  endif
+#  ifdef XLAT_VAL_490
+  | XLAT_VAL_490
+#  endif
+#  ifdef XLAT_VAL_491
+  | XLAT_VAL_491
+#  endif
+#  ifdef XLAT_VAL_492
+  | XLAT_VAL_492
+#  endif
+#  ifdef XLAT_VAL_493
+  | XLAT_VAL_493
+#  endif
+#  ifdef XLAT_VAL_494
+  | XLAT_VAL_494
+#  endif
+#  ifdef XLAT_VAL_495
+  | XLAT_VAL_495
+#  endif
+#  ifdef XLAT_VAL_496
+  | XLAT_VAL_496
+#  endif
+#  ifdef XLAT_VAL_497
+  | XLAT_VAL_497
+#  endif
+#  ifdef XLAT_VAL_498
+  | XLAT_VAL_498
+#  endif
+#  ifdef XLAT_VAL_499
+  | XLAT_VAL_499
+#  endif
+#  ifdef XLAT_VAL_500
+  | XLAT_VAL_500
+#  endif
+#  ifdef XLAT_VAL_501
+  | XLAT_VAL_501
+#  endif
+#  ifdef XLAT_VAL_502
+  | XLAT_VAL_502
+#  endif
+#  ifdef XLAT_VAL_503
+  | XLAT_VAL_503
+#  endif
+#  ifdef XLAT_VAL_504
+  | XLAT_VAL_504
+#  endif
+#  ifdef XLAT_VAL_505
+  | XLAT_VAL_505
+#  endif
+#  ifdef XLAT_VAL_506
+  | XLAT_VAL_506
+#  endif
+#  ifdef XLAT_VAL_507
+  | XLAT_VAL_507
+#  endif
+#  ifdef XLAT_VAL_508
+  | XLAT_VAL_508
+#  endif
+#  ifdef XLAT_VAL_509
+  | XLAT_VAL_509
+#  endif
+#  ifdef XLAT_VAL_510
+  | XLAT_VAL_510
+#  endif
+#  ifdef XLAT_VAL_511
+  | XLAT_VAL_511
+#  endif
+#  ifdef XLAT_VAL_512
+  | XLAT_VAL_512
+#  endif
+#  ifdef XLAT_VAL_513
+  | XLAT_VAL_513
+#  endif
+#  ifdef XLAT_VAL_514
+  | XLAT_VAL_514
+#  endif
+#  ifdef XLAT_VAL_515
+  | XLAT_VAL_515
+#  endif
+#  ifdef XLAT_VAL_516
+  | XLAT_VAL_516
+#  endif
+#  ifdef XLAT_VAL_517
+  | XLAT_VAL_517
+#  endif
+#  ifdef XLAT_VAL_518
+  | XLAT_VAL_518
+#  endif
+#  ifdef XLAT_VAL_519
+  | XLAT_VAL_519
+#  endif
+#  ifdef XLAT_VAL_520
+  | XLAT_VAL_520
+#  endif
+#  ifdef XLAT_VAL_521
+  | XLAT_VAL_521
+#  endif
+#  ifdef XLAT_VAL_522
+  | XLAT_VAL_522
+#  endif
+#  ifdef XLAT_VAL_523
+  | XLAT_VAL_523
+#  endif
+#  ifdef XLAT_VAL_524
+  | XLAT_VAL_524
+#  endif
+#  ifdef XLAT_VAL_525
+  | XLAT_VAL_525
+#  endif
+#  ifdef XLAT_VAL_526
+  | XLAT_VAL_526
+#  endif
+#  ifdef XLAT_VAL_527
+  | XLAT_VAL_527
+#  endif
+#  ifdef XLAT_VAL_528
+  | XLAT_VAL_528
+#  endif
+#  ifdef XLAT_VAL_529
+  | XLAT_VAL_529
+#  endif
+#  ifdef XLAT_VAL_530
+  | XLAT_VAL_530
+#  endif
+#  ifdef XLAT_VAL_531
+  | XLAT_VAL_531
+#  endif
+#  ifdef XLAT_VAL_532
+  | XLAT_VAL_532
+#  endif
+#  ifdef XLAT_VAL_533
+  | XLAT_VAL_533
+#  endif
+#  ifdef XLAT_VAL_534
+  | XLAT_VAL_534
+#  endif
+#  ifdef XLAT_VAL_535
+  | XLAT_VAL_535
+#  endif
+#  ifdef XLAT_VAL_536
+  | XLAT_VAL_536
+#  endif
+#  ifdef XLAT_VAL_537
+  | XLAT_VAL_537
+#  endif
+#  ifdef XLAT_VAL_538
+  | XLAT_VAL_538
+#  endif
+#  ifdef XLAT_VAL_539
+  | XLAT_VAL_539
+#  endif
+#  ifdef XLAT_VAL_540
+  | XLAT_VAL_540
+#  endif
+#  ifdef XLAT_VAL_541
+  | XLAT_VAL_541
+#  endif
+#  ifdef XLAT_VAL_542
+  | XLAT_VAL_542
+#  endif
+#  ifdef XLAT_VAL_543
+  | XLAT_VAL_543
+#  endif
+#  ifdef XLAT_VAL_544
+  | XLAT_VAL_544
+#  endif
+#  ifdef XLAT_VAL_545
+  | XLAT_VAL_545
+#  endif
+#  ifdef XLAT_VAL_546
+  | XLAT_VAL_546
+#  endif
+#  ifdef XLAT_VAL_547
+  | XLAT_VAL_547
+#  endif
+#  ifdef XLAT_VAL_548
+  | XLAT_VAL_548
+#  endif
+#  ifdef XLAT_VAL_549
+  | XLAT_VAL_549
+#  endif
+#  ifdef XLAT_VAL_550
+  | XLAT_VAL_550
+#  endif
+#  ifdef XLAT_VAL_551
+  | XLAT_VAL_551
+#  endif
+#  ifdef XLAT_VAL_552
+  | XLAT_VAL_552
+#  endif
+#  ifdef XLAT_VAL_553
+  | XLAT_VAL_553
+#  endif
+#  ifdef XLAT_VAL_554
+  | XLAT_VAL_554
+#  endif
+#  ifdef XLAT_VAL_555
+  | XLAT_VAL_555
+#  endif
+#  ifdef XLAT_VAL_556
+  | XLAT_VAL_556
+#  endif
+#  ifdef XLAT_VAL_557
+  | XLAT_VAL_557
+#  endif
+#  ifdef XLAT_VAL_558
+  | XLAT_VAL_558
+#  endif
+#  ifdef XLAT_VAL_559
+  | XLAT_VAL_559
+#  endif
+#  ifdef XLAT_VAL_560
+  | XLAT_VAL_560
+#  endif
+#  ifdef XLAT_VAL_561
+  | XLAT_VAL_561
+#  endif
+#  ifdef XLAT_VAL_562
+  | XLAT_VAL_562
+#  endif
+#  ifdef XLAT_VAL_563
+  | XLAT_VAL_563
+#  endif
+#  ifdef XLAT_VAL_564
+  | XLAT_VAL_564
+#  endif
+#  ifdef XLAT_VAL_565
+  | XLAT_VAL_565
+#  endif
+#  ifdef XLAT_VAL_566
+  | XLAT_VAL_566
+#  endif
+#  ifdef XLAT_VAL_567
+  | XLAT_VAL_567
+#  endif
+#  ifdef XLAT_VAL_568
+  | XLAT_VAL_568
+#  endif
+#  ifdef XLAT_VAL_569
+  | XLAT_VAL_569
+#  endif
+#  ifdef XLAT_VAL_570
+  | XLAT_VAL_570
+#  endif
+#  ifdef XLAT_VAL_571
+  | XLAT_VAL_571
+#  endif
+#  ifdef XLAT_VAL_572
+  | XLAT_VAL_572
+#  endif
+#  ifdef XLAT_VAL_573
+  | XLAT_VAL_573
+#  endif
+#  ifdef XLAT_VAL_574
+  | XLAT_VAL_574
+#  endif
+#  ifdef XLAT_VAL_575
+  | XLAT_VAL_575
+#  endif
+#  ifdef XLAT_VAL_576
+  | XLAT_VAL_576
+#  endif
+#  ifdef XLAT_VAL_577
+  | XLAT_VAL_577
+#  endif
+#  ifdef XLAT_VAL_578
+  | XLAT_VAL_578
+#  endif
+#  ifdef XLAT_VAL_579
+  | XLAT_VAL_579
+#  endif
+#  ifdef XLAT_VAL_580
+  | XLAT_VAL_580
+#  endif
+#  ifdef XLAT_VAL_581
+  | XLAT_VAL_581
+#  endif
+#  ifdef XLAT_VAL_582
+  | XLAT_VAL_582
+#  endif
+#  ifdef XLAT_VAL_583
+  | XLAT_VAL_583
+#  endif
+#  ifdef XLAT_VAL_584
+  | XLAT_VAL_584
+#  endif
+#  ifdef XLAT_VAL_585
+  | XLAT_VAL_585
+#  endif
+#  ifdef XLAT_VAL_586
+  | XLAT_VAL_586
+#  endif
+#  ifdef XLAT_VAL_587
+  | XLAT_VAL_587
+#  endif
+#  ifdef XLAT_VAL_588
+  | XLAT_VAL_588
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+#  ifdef XLAT_STR_47
+  + sizeof(XLAT_STR_47)
+#  endif
+#  ifdef XLAT_STR_48
+  + sizeof(XLAT_STR_48)
+#  endif
+#  ifdef XLAT_STR_49
+  + sizeof(XLAT_STR_49)
+#  endif
+#  ifdef XLAT_STR_50
+  + sizeof(XLAT_STR_50)
+#  endif
+#  ifdef XLAT_STR_51
+  + sizeof(XLAT_STR_51)
+#  endif
+#  ifdef XLAT_STR_52
+  + sizeof(XLAT_STR_52)
+#  endif
+#  ifdef XLAT_STR_53
+  + sizeof(XLAT_STR_53)
+#  endif
+#  ifdef XLAT_STR_54
+  + sizeof(XLAT_STR_54)
+#  endif
+#  ifdef XLAT_STR_55
+  + sizeof(XLAT_STR_55)
+#  endif
+#  ifdef XLAT_STR_56
+  + sizeof(XLAT_STR_56)
+#  endif
+#  ifdef XLAT_STR_57
+  + sizeof(XLAT_STR_57)
+#  endif
+#  ifdef XLAT_STR_58
+  + sizeof(XLAT_STR_58)
+#  endif
+#  ifdef XLAT_STR_59
+  + sizeof(XLAT_STR_59)
+#  endif
+#  ifdef XLAT_STR_60
+  + sizeof(XLAT_STR_60)
+#  endif
+#  ifdef XLAT_STR_61
+  + sizeof(XLAT_STR_61)
+#  endif
+#  ifdef XLAT_STR_62
+  + sizeof(XLAT_STR_62)
+#  endif
+#  ifdef XLAT_STR_63
+  + sizeof(XLAT_STR_63)
+#  endif
+#  ifdef XLAT_STR_64
+  + sizeof(XLAT_STR_64)
+#  endif
+#  ifdef XLAT_STR_65
+  + sizeof(XLAT_STR_65)
+#  endif
+#  ifdef XLAT_STR_66
+  + sizeof(XLAT_STR_66)
+#  endif
+#  ifdef XLAT_STR_67
+  + sizeof(XLAT_STR_67)
+#  endif
+#  ifdef XLAT_STR_68
+  + sizeof(XLAT_STR_68)
+#  endif
+#  ifdef XLAT_STR_69
+  + sizeof(XLAT_STR_69)
+#  endif
+#  ifdef XLAT_STR_70
+  + sizeof(XLAT_STR_70)
+#  endif
+#  ifdef XLAT_STR_71
+  + sizeof(XLAT_STR_71)
+#  endif
+#  ifdef XLAT_STR_72
+  + sizeof(XLAT_STR_72)
+#  endif
+#  ifdef XLAT_STR_73
+  + sizeof(XLAT_STR_73)
+#  endif
+#  ifdef XLAT_STR_74
+  + sizeof(XLAT_STR_74)
+#  endif
+#  ifdef XLAT_STR_75
+  + sizeof(XLAT_STR_75)
+#  endif
+#  ifdef XLAT_STR_76
+  + sizeof(XLAT_STR_76)
+#  endif
+#  ifdef XLAT_STR_77
+  + sizeof(XLAT_STR_77)
+#  endif
+#  ifdef XLAT_STR_78
+  + sizeof(XLAT_STR_78)
+#  endif
+#  ifdef XLAT_STR_79
+  + sizeof(XLAT_STR_79)
+#  endif
+#  ifdef XLAT_STR_80
+  + sizeof(XLAT_STR_80)
+#  endif
+#  ifdef XLAT_STR_81
+  + sizeof(XLAT_STR_81)
+#  endif
+#  ifdef XLAT_STR_82
+  + sizeof(XLAT_STR_82)
+#  endif
+#  ifdef XLAT_STR_83
+  + sizeof(XLAT_STR_83)
+#  endif
+#  ifdef XLAT_STR_84
+  + sizeof(XLAT_STR_84)
+#  endif
+#  ifdef XLAT_STR_85
+  + sizeof(XLAT_STR_85)
+#  endif
+#  ifdef XLAT_STR_86
+  + sizeof(XLAT_STR_86)
+#  endif
+#  ifdef XLAT_STR_87
+  + sizeof(XLAT_STR_87)
+#  endif
+#  ifdef XLAT_STR_88
+  + sizeof(XLAT_STR_88)
+#  endif
+#  ifdef XLAT_STR_89
+  + sizeof(XLAT_STR_89)
+#  endif
+#  ifdef XLAT_STR_90
+  + sizeof(XLAT_STR_90)
+#  endif
+#  ifdef XLAT_STR_91
+  + sizeof(XLAT_STR_91)
+#  endif
+#  ifdef XLAT_STR_92
+  + sizeof(XLAT_STR_92)
+#  endif
+#  ifdef XLAT_STR_93
+  + sizeof(XLAT_STR_93)
+#  endif
+#  ifdef XLAT_STR_94
+  + sizeof(XLAT_STR_94)
+#  endif
+#  ifdef XLAT_STR_95
+  + sizeof(XLAT_STR_95)
+#  endif
+#  ifdef XLAT_STR_96
+  + sizeof(XLAT_STR_96)
+#  endif
+#  ifdef XLAT_STR_97
+  + sizeof(XLAT_STR_97)
+#  endif
+#  ifdef XLAT_STR_98
+  + sizeof(XLAT_STR_98)
+#  endif
+#  ifdef XLAT_STR_99
+  + sizeof(XLAT_STR_99)
+#  endif
+#  ifdef XLAT_STR_100
+  + sizeof(XLAT_STR_100)
+#  endif
+#  ifdef XLAT_STR_101
+  + sizeof(XLAT_STR_101)
+#  endif
+#  ifdef XLAT_STR_102
+  + sizeof(XLAT_STR_102)
+#  endif
+#  ifdef XLAT_STR_103
+  + sizeof(XLAT_STR_103)
+#  endif
+#  ifdef XLAT_STR_104
+  + sizeof(XLAT_STR_104)
+#  endif
+#  ifdef XLAT_STR_105
+  + sizeof(XLAT_STR_105)
+#  endif
+#  ifdef XLAT_STR_106
+  + sizeof(XLAT_STR_106)
+#  endif
+#  ifdef XLAT_STR_107
+  + sizeof(XLAT_STR_107)
+#  endif
+#  ifdef XLAT_STR_108
+  + sizeof(XLAT_STR_108)
+#  endif
+#  ifdef XLAT_STR_109
+  + sizeof(XLAT_STR_109)
+#  endif
+#  ifdef XLAT_STR_110
+  + sizeof(XLAT_STR_110)
+#  endif
+#  ifdef XLAT_STR_111
+  + sizeof(XLAT_STR_111)
+#  endif
+#  ifdef XLAT_STR_112
+  + sizeof(XLAT_STR_112)
+#  endif
+#  ifdef XLAT_STR_113
+  + sizeof(XLAT_STR_113)
+#  endif
+#  ifdef XLAT_STR_114
+  + sizeof(XLAT_STR_114)
+#  endif
+#  ifdef XLAT_STR_115
+  + sizeof(XLAT_STR_115)
+#  endif
+#  ifdef XLAT_STR_116
+  + sizeof(XLAT_STR_116)
+#  endif
+#  ifdef XLAT_STR_117
+  + sizeof(XLAT_STR_117)
+#  endif
+#  ifdef XLAT_STR_118
+  + sizeof(XLAT_STR_118)
+#  endif
+#  ifdef XLAT_STR_119
+  + sizeof(XLAT_STR_119)
+#  endif
+#  ifdef XLAT_STR_120
+  + sizeof(XLAT_STR_120)
+#  endif
+#  ifdef XLAT_STR_121
+  + sizeof(XLAT_STR_121)
+#  endif
+#  ifdef XLAT_STR_122
+  + sizeof(XLAT_STR_122)
+#  endif
+#  ifdef XLAT_STR_123
+  + sizeof(XLAT_STR_123)
+#  endif
+#  ifdef XLAT_STR_124
+  + sizeof(XLAT_STR_124)
+#  endif
+#  ifdef XLAT_STR_125
+  + sizeof(XLAT_STR_125)
+#  endif
+#  ifdef XLAT_STR_126
+  + sizeof(XLAT_STR_126)
+#  endif
+#  ifdef XLAT_STR_127
+  + sizeof(XLAT_STR_127)
+#  endif
+#  ifdef XLAT_STR_128
+  + sizeof(XLAT_STR_128)
+#  endif
+#  ifdef XLAT_STR_129
+  + sizeof(XLAT_STR_129)
+#  endif
+#  ifdef XLAT_STR_130
+  + sizeof(XLAT_STR_130)
+#  endif
+#  ifdef XLAT_STR_131
+  + sizeof(XLAT_STR_131)
+#  endif
+#  ifdef XLAT_STR_132
+  + sizeof(XLAT_STR_132)
+#  endif
+#  ifdef XLAT_STR_133
+  + sizeof(XLAT_STR_133)
+#  endif
+#  ifdef XLAT_STR_134
+  + sizeof(XLAT_STR_134)
+#  endif
+#  ifdef XLAT_STR_135
+  + sizeof(XLAT_STR_135)
+#  endif
+#  ifdef XLAT_STR_136
+  + sizeof(XLAT_STR_136)
+#  endif
+#  ifdef XLAT_STR_137
+  + sizeof(XLAT_STR_137)
+#  endif
+#  ifdef XLAT_STR_138
+  + sizeof(XLAT_STR_138)
+#  endif
+#  ifdef XLAT_STR_139
+  + sizeof(XLAT_STR_139)
+#  endif
+#  ifdef XLAT_STR_140
+  + sizeof(XLAT_STR_140)
+#  endif
+#  ifdef XLAT_STR_141
+  + sizeof(XLAT_STR_141)
+#  endif
+#  ifdef XLAT_STR_142
+  + sizeof(XLAT_STR_142)
+#  endif
+#  ifdef XLAT_STR_143
+  + sizeof(XLAT_STR_143)
+#  endif
+#  ifdef XLAT_STR_144
+  + sizeof(XLAT_STR_144)
+#  endif
+#  ifdef XLAT_STR_145
+  + sizeof(XLAT_STR_145)
+#  endif
+#  ifdef XLAT_STR_146
+  + sizeof(XLAT_STR_146)
+#  endif
+#  ifdef XLAT_STR_147
+  + sizeof(XLAT_STR_147)
+#  endif
+#  ifdef XLAT_STR_148
+  + sizeof(XLAT_STR_148)
+#  endif
+#  ifdef XLAT_STR_149
+  + sizeof(XLAT_STR_149)
+#  endif
+#  ifdef XLAT_STR_150
+  + sizeof(XLAT_STR_150)
+#  endif
+#  ifdef XLAT_STR_151
+  + sizeof(XLAT_STR_151)
+#  endif
+#  ifdef XLAT_STR_152
+  + sizeof(XLAT_STR_152)
+#  endif
+#  ifdef XLAT_STR_153
+  + sizeof(XLAT_STR_153)
+#  endif
+#  ifdef XLAT_STR_154
+  + sizeof(XLAT_STR_154)
+#  endif
+#  ifdef XLAT_STR_155
+  + sizeof(XLAT_STR_155)
+#  endif
+#  ifdef XLAT_STR_156
+  + sizeof(XLAT_STR_156)
+#  endif
+#  ifdef XLAT_STR_157
+  + sizeof(XLAT_STR_157)
+#  endif
+#  ifdef XLAT_STR_158
+  + sizeof(XLAT_STR_158)
+#  endif
+#  ifdef XLAT_STR_159
+  + sizeof(XLAT_STR_159)
+#  endif
+#  ifdef XLAT_STR_160
+  + sizeof(XLAT_STR_160)
+#  endif
+#  ifdef XLAT_STR_161
+  + sizeof(XLAT_STR_161)
+#  endif
+#  ifdef XLAT_STR_162
+  + sizeof(XLAT_STR_162)
+#  endif
+#  ifdef XLAT_STR_163
+  + sizeof(XLAT_STR_163)
+#  endif
+#  ifdef XLAT_STR_164
+  + sizeof(XLAT_STR_164)
+#  endif
+#  ifdef XLAT_STR_165
+  + sizeof(XLAT_STR_165)
+#  endif
+#  ifdef XLAT_STR_166
+  + sizeof(XLAT_STR_166)
+#  endif
+#  ifdef XLAT_STR_167
+  + sizeof(XLAT_STR_167)
+#  endif
+#  ifdef XLAT_STR_168
+  + sizeof(XLAT_STR_168)
+#  endif
+#  ifdef XLAT_STR_169
+  + sizeof(XLAT_STR_169)
+#  endif
+#  ifdef XLAT_STR_170
+  + sizeof(XLAT_STR_170)
+#  endif
+#  ifdef XLAT_STR_171
+  + sizeof(XLAT_STR_171)
+#  endif
+#  ifdef XLAT_STR_172
+  + sizeof(XLAT_STR_172)
+#  endif
+#  ifdef XLAT_STR_173
+  + sizeof(XLAT_STR_173)
+#  endif
+#  ifdef XLAT_STR_174
+  + sizeof(XLAT_STR_174)
+#  endif
+#  ifdef XLAT_STR_175
+  + sizeof(XLAT_STR_175)
+#  endif
+#  ifdef XLAT_STR_176
+  + sizeof(XLAT_STR_176)
+#  endif
+#  ifdef XLAT_STR_177
+  + sizeof(XLAT_STR_177)
+#  endif
+#  ifdef XLAT_STR_178
+  + sizeof(XLAT_STR_178)
+#  endif
+#  ifdef XLAT_STR_179
+  + sizeof(XLAT_STR_179)
+#  endif
+#  ifdef XLAT_STR_180
+  + sizeof(XLAT_STR_180)
+#  endif
+#  ifdef XLAT_STR_181
+  + sizeof(XLAT_STR_181)
+#  endif
+#  ifdef XLAT_STR_182
+  + sizeof(XLAT_STR_182)
+#  endif
+#  ifdef XLAT_STR_183
+  + sizeof(XLAT_STR_183)
+#  endif
+#  ifdef XLAT_STR_184
+  + sizeof(XLAT_STR_184)
+#  endif
+#  ifdef XLAT_STR_185
+  + sizeof(XLAT_STR_185)
+#  endif
+#  ifdef XLAT_STR_186
+  + sizeof(XLAT_STR_186)
+#  endif
+#  ifdef XLAT_STR_187
+  + sizeof(XLAT_STR_187)
+#  endif
+#  ifdef XLAT_STR_188
+  + sizeof(XLAT_STR_188)
+#  endif
+#  ifdef XLAT_STR_189
+  + sizeof(XLAT_STR_189)
+#  endif
+#  ifdef XLAT_STR_190
+  + sizeof(XLAT_STR_190)
+#  endif
+#  ifdef XLAT_STR_191
+  + sizeof(XLAT_STR_191)
+#  endif
+#  ifdef XLAT_STR_192
+  + sizeof(XLAT_STR_192)
+#  endif
+#  ifdef XLAT_STR_193
+  + sizeof(XLAT_STR_193)
+#  endif
+#  ifdef XLAT_STR_194
+  + sizeof(XLAT_STR_194)
+#  endif
+#  ifdef XLAT_STR_195
+  + sizeof(XLAT_STR_195)
+#  endif
+#  ifdef XLAT_STR_196
+  + sizeof(XLAT_STR_196)
+#  endif
+#  ifdef XLAT_STR_197
+  + sizeof(XLAT_STR_197)
+#  endif
+#  ifdef XLAT_STR_198
+  + sizeof(XLAT_STR_198)
+#  endif
+#  ifdef XLAT_STR_199
+  + sizeof(XLAT_STR_199)
+#  endif
+#  ifdef XLAT_STR_200
+  + sizeof(XLAT_STR_200)
+#  endif
+#  ifdef XLAT_STR_201
+  + sizeof(XLAT_STR_201)
+#  endif
+#  ifdef XLAT_STR_202
+  + sizeof(XLAT_STR_202)
+#  endif
+#  ifdef XLAT_STR_203
+  + sizeof(XLAT_STR_203)
+#  endif
+#  ifdef XLAT_STR_204
+  + sizeof(XLAT_STR_204)
+#  endif
+#  ifdef XLAT_STR_205
+  + sizeof(XLAT_STR_205)
+#  endif
+#  ifdef XLAT_STR_206
+  + sizeof(XLAT_STR_206)
+#  endif
+#  ifdef XLAT_STR_207
+  + sizeof(XLAT_STR_207)
+#  endif
+#  ifdef XLAT_STR_208
+  + sizeof(XLAT_STR_208)
+#  endif
+#  ifdef XLAT_STR_209
+  + sizeof(XLAT_STR_209)
+#  endif
+#  ifdef XLAT_STR_210
+  + sizeof(XLAT_STR_210)
+#  endif
+#  ifdef XLAT_STR_211
+  + sizeof(XLAT_STR_211)
+#  endif
+#  ifdef XLAT_STR_212
+  + sizeof(XLAT_STR_212)
+#  endif
+#  ifdef XLAT_STR_213
+  + sizeof(XLAT_STR_213)
+#  endif
+#  ifdef XLAT_STR_214
+  + sizeof(XLAT_STR_214)
+#  endif
+#  ifdef XLAT_STR_215
+  + sizeof(XLAT_STR_215)
+#  endif
+#  ifdef XLAT_STR_216
+  + sizeof(XLAT_STR_216)
+#  endif
+#  ifdef XLAT_STR_217
+  + sizeof(XLAT_STR_217)
+#  endif
+#  ifdef XLAT_STR_218
+  + sizeof(XLAT_STR_218)
+#  endif
+#  ifdef XLAT_STR_219
+  + sizeof(XLAT_STR_219)
+#  endif
+#  ifdef XLAT_STR_220
+  + sizeof(XLAT_STR_220)
+#  endif
+#  ifdef XLAT_STR_221
+  + sizeof(XLAT_STR_221)
+#  endif
+#  ifdef XLAT_STR_222
+  + sizeof(XLAT_STR_222)
+#  endif
+#  ifdef XLAT_STR_223
+  + sizeof(XLAT_STR_223)
+#  endif
+#  ifdef XLAT_STR_224
+  + sizeof(XLAT_STR_224)
+#  endif
+#  ifdef XLAT_STR_225
+  + sizeof(XLAT_STR_225)
+#  endif
+#  ifdef XLAT_STR_226
+  + sizeof(XLAT_STR_226)
+#  endif
+#  ifdef XLAT_STR_227
+  + sizeof(XLAT_STR_227)
+#  endif
+#  ifdef XLAT_STR_228
+  + sizeof(XLAT_STR_228)
+#  endif
+#  ifdef XLAT_STR_229
+  + sizeof(XLAT_STR_229)
+#  endif
+#  ifdef XLAT_STR_230
+  + sizeof(XLAT_STR_230)
+#  endif
+#  ifdef XLAT_STR_231
+  + sizeof(XLAT_STR_231)
+#  endif
+#  ifdef XLAT_STR_232
+  + sizeof(XLAT_STR_232)
+#  endif
+#  ifdef XLAT_STR_233
+  + sizeof(XLAT_STR_233)
+#  endif
+#  ifdef XLAT_STR_234
+  + sizeof(XLAT_STR_234)
+#  endif
+#  ifdef XLAT_STR_235
+  + sizeof(XLAT_STR_235)
+#  endif
+#  ifdef XLAT_STR_236
+  + sizeof(XLAT_STR_236)
+#  endif
+#  ifdef XLAT_STR_237
+  + sizeof(XLAT_STR_237)
+#  endif
+#  ifdef XLAT_STR_238
+  + sizeof(XLAT_STR_238)
+#  endif
+#  ifdef XLAT_STR_239
+  + sizeof(XLAT_STR_239)
+#  endif
+#  ifdef XLAT_STR_240
+  + sizeof(XLAT_STR_240)
+#  endif
+#  ifdef XLAT_STR_241
+  + sizeof(XLAT_STR_241)
+#  endif
+#  ifdef XLAT_STR_242
+  + sizeof(XLAT_STR_242)
+#  endif
+#  ifdef XLAT_STR_243
+  + sizeof(XLAT_STR_243)
+#  endif
+#  ifdef XLAT_STR_244
+  + sizeof(XLAT_STR_244)
+#  endif
+#  ifdef XLAT_STR_245
+  + sizeof(XLAT_STR_245)
+#  endif
+#  ifdef XLAT_STR_246
+  + sizeof(XLAT_STR_246)
+#  endif
+#  ifdef XLAT_STR_247
+  + sizeof(XLAT_STR_247)
+#  endif
+#  ifdef XLAT_STR_248
+  + sizeof(XLAT_STR_248)
+#  endif
+#  ifdef XLAT_STR_249
+  + sizeof(XLAT_STR_249)
+#  endif
+#  ifdef XLAT_STR_250
+  + sizeof(XLAT_STR_250)
+#  endif
+#  ifdef XLAT_STR_251
+  + sizeof(XLAT_STR_251)
+#  endif
+#  ifdef XLAT_STR_252
+  + sizeof(XLAT_STR_252)
+#  endif
+#  ifdef XLAT_STR_253
+  + sizeof(XLAT_STR_253)
+#  endif
+#  ifdef XLAT_STR_254
+  + sizeof(XLAT_STR_254)
+#  endif
+#  ifdef XLAT_STR_255
+  + sizeof(XLAT_STR_255)
+#  endif
+#  ifdef XLAT_STR_256
+  + sizeof(XLAT_STR_256)
+#  endif
+#  ifdef XLAT_STR_257
+  + sizeof(XLAT_STR_257)
+#  endif
+#  ifdef XLAT_STR_258
+  + sizeof(XLAT_STR_258)
+#  endif
+#  ifdef XLAT_STR_259
+  + sizeof(XLAT_STR_259)
+#  endif
+#  ifdef XLAT_STR_260
+  + sizeof(XLAT_STR_260)
+#  endif
+#  ifdef XLAT_STR_261
+  + sizeof(XLAT_STR_261)
+#  endif
+#  ifdef XLAT_STR_262
+  + sizeof(XLAT_STR_262)
+#  endif
+#  ifdef XLAT_STR_263
+  + sizeof(XLAT_STR_263)
+#  endif
+#  ifdef XLAT_STR_264
+  + sizeof(XLAT_STR_264)
+#  endif
+#  ifdef XLAT_STR_265
+  + sizeof(XLAT_STR_265)
+#  endif
+#  ifdef XLAT_STR_266
+  + sizeof(XLAT_STR_266)
+#  endif
+#  ifdef XLAT_STR_267
+  + sizeof(XLAT_STR_267)
+#  endif
+#  ifdef XLAT_STR_268
+  + sizeof(XLAT_STR_268)
+#  endif
+#  ifdef XLAT_STR_269
+  + sizeof(XLAT_STR_269)
+#  endif
+#  ifdef XLAT_STR_270
+  + sizeof(XLAT_STR_270)
+#  endif
+#  ifdef XLAT_STR_271
+  + sizeof(XLAT_STR_271)
+#  endif
+#  ifdef XLAT_STR_272
+  + sizeof(XLAT_STR_272)
+#  endif
+#  ifdef XLAT_STR_273
+  + sizeof(XLAT_STR_273)
+#  endif
+#  ifdef XLAT_STR_274
+  + sizeof(XLAT_STR_274)
+#  endif
+#  ifdef XLAT_STR_275
+  + sizeof(XLAT_STR_275)
+#  endif
+#  ifdef XLAT_STR_276
+  + sizeof(XLAT_STR_276)
+#  endif
+#  ifdef XLAT_STR_277
+  + sizeof(XLAT_STR_277)
+#  endif
+#  ifdef XLAT_STR_278
+  + sizeof(XLAT_STR_278)
+#  endif
+#  ifdef XLAT_STR_279
+  + sizeof(XLAT_STR_279)
+#  endif
+#  ifdef XLAT_STR_280
+  + sizeof(XLAT_STR_280)
+#  endif
+#  ifdef XLAT_STR_281
+  + sizeof(XLAT_STR_281)
+#  endif
+#  ifdef XLAT_STR_282
+  + sizeof(XLAT_STR_282)
+#  endif
+#  ifdef XLAT_STR_283
+  + sizeof(XLAT_STR_283)
+#  endif
+#  ifdef XLAT_STR_284
+  + sizeof(XLAT_STR_284)
+#  endif
+#  ifdef XLAT_STR_285
+  + sizeof(XLAT_STR_285)
+#  endif
+#  ifdef XLAT_STR_286
+  + sizeof(XLAT_STR_286)
+#  endif
+#  ifdef XLAT_STR_287
+  + sizeof(XLAT_STR_287)
+#  endif
+#  ifdef XLAT_STR_288
+  + sizeof(XLAT_STR_288)
+#  endif
+#  ifdef XLAT_STR_289
+  + sizeof(XLAT_STR_289)
+#  endif
+#  ifdef XLAT_STR_290
+  + sizeof(XLAT_STR_290)
+#  endif
+#  ifdef XLAT_STR_291
+  + sizeof(XLAT_STR_291)
+#  endif
+#  ifdef XLAT_STR_292
+  + sizeof(XLAT_STR_292)
+#  endif
+#  ifdef XLAT_STR_293
+  + sizeof(XLAT_STR_293)
+#  endif
+#  ifdef XLAT_STR_294
+  + sizeof(XLAT_STR_294)
+#  endif
+#  ifdef XLAT_STR_295
+  + sizeof(XLAT_STR_295)
+#  endif
+#  ifdef XLAT_STR_296
+  + sizeof(XLAT_STR_296)
+#  endif
+#  ifdef XLAT_STR_297
+  + sizeof(XLAT_STR_297)
+#  endif
+#  ifdef XLAT_STR_298
+  + sizeof(XLAT_STR_298)
+#  endif
+#  ifdef XLAT_STR_299
+  + sizeof(XLAT_STR_299)
+#  endif
+#  ifdef XLAT_STR_300
+  + sizeof(XLAT_STR_300)
+#  endif
+#  ifdef XLAT_STR_301
+  + sizeof(XLAT_STR_301)
+#  endif
+#  ifdef XLAT_STR_302
+  + sizeof(XLAT_STR_302)
+#  endif
+#  ifdef XLAT_STR_303
+  + sizeof(XLAT_STR_303)
+#  endif
+#  ifdef XLAT_STR_304
+  + sizeof(XLAT_STR_304)
+#  endif
+#  ifdef XLAT_STR_305
+  + sizeof(XLAT_STR_305)
+#  endif
+#  ifdef XLAT_STR_306
+  + sizeof(XLAT_STR_306)
+#  endif
+#  ifdef XLAT_STR_307
+  + sizeof(XLAT_STR_307)
+#  endif
+#  ifdef XLAT_STR_308
+  + sizeof(XLAT_STR_308)
+#  endif
+#  ifdef XLAT_STR_309
+  + sizeof(XLAT_STR_309)
+#  endif
+#  ifdef XLAT_STR_310
+  + sizeof(XLAT_STR_310)
+#  endif
+#  ifdef XLAT_STR_311
+  + sizeof(XLAT_STR_311)
+#  endif
+#  ifdef XLAT_STR_312
+  + sizeof(XLAT_STR_312)
+#  endif
+#  ifdef XLAT_STR_313
+  + sizeof(XLAT_STR_313)
+#  endif
+#  ifdef XLAT_STR_314
+  + sizeof(XLAT_STR_314)
+#  endif
+#  ifdef XLAT_STR_315
+  + sizeof(XLAT_STR_315)
+#  endif
+#  ifdef XLAT_STR_316
+  + sizeof(XLAT_STR_316)
+#  endif
+#  ifdef XLAT_STR_317
+  + sizeof(XLAT_STR_317)
+#  endif
+#  ifdef XLAT_STR_318
+  + sizeof(XLAT_STR_318)
+#  endif
+#  ifdef XLAT_STR_319
+  + sizeof(XLAT_STR_319)
+#  endif
+#  ifdef XLAT_STR_320
+  + sizeof(XLAT_STR_320)
+#  endif
+#  ifdef XLAT_STR_321
+  + sizeof(XLAT_STR_321)
+#  endif
+#  ifdef XLAT_STR_322
+  + sizeof(XLAT_STR_322)
+#  endif
+#  ifdef XLAT_STR_323
+  + sizeof(XLAT_STR_323)
+#  endif
+#  ifdef XLAT_STR_324
+  + sizeof(XLAT_STR_324)
+#  endif
+#  ifdef XLAT_STR_325
+  + sizeof(XLAT_STR_325)
+#  endif
+#  ifdef XLAT_STR_326
+  + sizeof(XLAT_STR_326)
+#  endif
+#  ifdef XLAT_STR_327
+  + sizeof(XLAT_STR_327)
+#  endif
+#  ifdef XLAT_STR_328
+  + sizeof(XLAT_STR_328)
+#  endif
+#  ifdef XLAT_STR_329
+  + sizeof(XLAT_STR_329)
+#  endif
+#  ifdef XLAT_STR_330
+  + sizeof(XLAT_STR_330)
+#  endif
+#  ifdef XLAT_STR_331
+  + sizeof(XLAT_STR_331)
+#  endif
+#  ifdef XLAT_STR_332
+  + sizeof(XLAT_STR_332)
+#  endif
+#  ifdef XLAT_STR_333
+  + sizeof(XLAT_STR_333)
+#  endif
+#  ifdef XLAT_STR_334
+  + sizeof(XLAT_STR_334)
+#  endif
+#  ifdef XLAT_STR_335
+  + sizeof(XLAT_STR_335)
+#  endif
+#  ifdef XLAT_STR_336
+  + sizeof(XLAT_STR_336)
+#  endif
+#  ifdef XLAT_STR_337
+  + sizeof(XLAT_STR_337)
+#  endif
+#  ifdef XLAT_STR_338
+  + sizeof(XLAT_STR_338)
+#  endif
+#  ifdef XLAT_STR_339
+  + sizeof(XLAT_STR_339)
+#  endif
+#  ifdef XLAT_STR_340
+  + sizeof(XLAT_STR_340)
+#  endif
+#  ifdef XLAT_STR_341
+  + sizeof(XLAT_STR_341)
+#  endif
+#  ifdef XLAT_STR_342
+  + sizeof(XLAT_STR_342)
+#  endif
+#  ifdef XLAT_STR_343
+  + sizeof(XLAT_STR_343)
+#  endif
+#  ifdef XLAT_STR_344
+  + sizeof(XLAT_STR_344)
+#  endif
+#  ifdef XLAT_STR_345
+  + sizeof(XLAT_STR_345)
+#  endif
+#  ifdef XLAT_STR_346
+  + sizeof(XLAT_STR_346)
+#  endif
+#  ifdef XLAT_STR_347
+  + sizeof(XLAT_STR_347)
+#  endif
+#  ifdef XLAT_STR_348
+  + sizeof(XLAT_STR_348)
+#  endif
+#  ifdef XLAT_STR_349
+  + sizeof(XLAT_STR_349)
+#  endif
+#  ifdef XLAT_STR_350
+  + sizeof(XLAT_STR_350)
+#  endif
+#  ifdef XLAT_STR_351
+  + sizeof(XLAT_STR_351)
+#  endif
+#  ifdef XLAT_STR_352
+  + sizeof(XLAT_STR_352)
+#  endif
+#  ifdef XLAT_STR_353
+  + sizeof(XLAT_STR_353)
+#  endif
+#  ifdef XLAT_STR_354
+  + sizeof(XLAT_STR_354)
+#  endif
+#  ifdef XLAT_STR_355
+  + sizeof(XLAT_STR_355)
+#  endif
+#  ifdef XLAT_STR_356
+  + sizeof(XLAT_STR_356)
+#  endif
+#  ifdef XLAT_STR_357
+  + sizeof(XLAT_STR_357)
+#  endif
+#  ifdef XLAT_STR_358
+  + sizeof(XLAT_STR_358)
+#  endif
+#  ifdef XLAT_STR_359
+  + sizeof(XLAT_STR_359)
+#  endif
+#  ifdef XLAT_STR_360
+  + sizeof(XLAT_STR_360)
+#  endif
+#  ifdef XLAT_STR_361
+  + sizeof(XLAT_STR_361)
+#  endif
+#  ifdef XLAT_STR_362
+  + sizeof(XLAT_STR_362)
+#  endif
+#  ifdef XLAT_STR_363
+  + sizeof(XLAT_STR_363)
+#  endif
+#  ifdef XLAT_STR_364
+  + sizeof(XLAT_STR_364)
+#  endif
+#  ifdef XLAT_STR_365
+  + sizeof(XLAT_STR_365)
+#  endif
+#  ifdef XLAT_STR_366
+  + sizeof(XLAT_STR_366)
+#  endif
+#  ifdef XLAT_STR_367
+  + sizeof(XLAT_STR_367)
+#  endif
+#  ifdef XLAT_STR_368
+  + sizeof(XLAT_STR_368)
+#  endif
+#  ifdef XLAT_STR_369
+  + sizeof(XLAT_STR_369)
+#  endif
+#  ifdef XLAT_STR_370
+  + sizeof(XLAT_STR_370)
+#  endif
+#  ifdef XLAT_STR_371
+  + sizeof(XLAT_STR_371)
+#  endif
+#  ifdef XLAT_STR_372
+  + sizeof(XLAT_STR_372)
+#  endif
+#  ifdef XLAT_STR_373
+  + sizeof(XLAT_STR_373)
+#  endif
+#  ifdef XLAT_STR_374
+  + sizeof(XLAT_STR_374)
+#  endif
+#  ifdef XLAT_STR_375
+  + sizeof(XLAT_STR_375)
+#  endif
+#  ifdef XLAT_STR_376
+  + sizeof(XLAT_STR_376)
+#  endif
+#  ifdef XLAT_STR_377
+  + sizeof(XLAT_STR_377)
+#  endif
+#  ifdef XLAT_STR_378
+  + sizeof(XLAT_STR_378)
+#  endif
+#  ifdef XLAT_STR_379
+  + sizeof(XLAT_STR_379)
+#  endif
+#  ifdef XLAT_STR_380
+  + sizeof(XLAT_STR_380)
+#  endif
+#  ifdef XLAT_STR_381
+  + sizeof(XLAT_STR_381)
+#  endif
+#  ifdef XLAT_STR_382
+  + sizeof(XLAT_STR_382)
+#  endif
+#  ifdef XLAT_STR_383
+  + sizeof(XLAT_STR_383)
+#  endif
+#  ifdef XLAT_STR_384
+  + sizeof(XLAT_STR_384)
+#  endif
+#  ifdef XLAT_STR_385
+  + sizeof(XLAT_STR_385)
+#  endif
+#  ifdef XLAT_STR_386
+  + sizeof(XLAT_STR_386)
+#  endif
+#  ifdef XLAT_STR_387
+  + sizeof(XLAT_STR_387)
+#  endif
+#  ifdef XLAT_STR_388
+  + sizeof(XLAT_STR_388)
+#  endif
+#  ifdef XLAT_STR_389
+  + sizeof(XLAT_STR_389)
+#  endif
+#  ifdef XLAT_STR_390
+  + sizeof(XLAT_STR_390)
+#  endif
+#  ifdef XLAT_STR_391
+  + sizeof(XLAT_STR_391)
+#  endif
+#  ifdef XLAT_STR_392
+  + sizeof(XLAT_STR_392)
+#  endif
+#  ifdef XLAT_STR_393
+  + sizeof(XLAT_STR_393)
+#  endif
+#  ifdef XLAT_STR_394
+  + sizeof(XLAT_STR_394)
+#  endif
+#  ifdef XLAT_STR_395
+  + sizeof(XLAT_STR_395)
+#  endif
+#  ifdef XLAT_STR_396
+  + sizeof(XLAT_STR_396)
+#  endif
+#  ifdef XLAT_STR_397
+  + sizeof(XLAT_STR_397)
+#  endif
+#  ifdef XLAT_STR_398
+  + sizeof(XLAT_STR_398)
+#  endif
+#  ifdef XLAT_STR_399
+  + sizeof(XLAT_STR_399)
+#  endif
+#  ifdef XLAT_STR_400
+  + sizeof(XLAT_STR_400)
+#  endif
+#  ifdef XLAT_STR_401
+  + sizeof(XLAT_STR_401)
+#  endif
+#  ifdef XLAT_STR_402
+  + sizeof(XLAT_STR_402)
+#  endif
+#  ifdef XLAT_STR_403
+  + sizeof(XLAT_STR_403)
+#  endif
+#  ifdef XLAT_STR_404
+  + sizeof(XLAT_STR_404)
+#  endif
+#  ifdef XLAT_STR_405
+  + sizeof(XLAT_STR_405)
+#  endif
+#  ifdef XLAT_STR_406
+  + sizeof(XLAT_STR_406)
+#  endif
+#  ifdef XLAT_STR_407
+  + sizeof(XLAT_STR_407)
+#  endif
+#  ifdef XLAT_STR_408
+  + sizeof(XLAT_STR_408)
+#  endif
+#  ifdef XLAT_STR_409
+  + sizeof(XLAT_STR_409)
+#  endif
+#  ifdef XLAT_STR_410
+  + sizeof(XLAT_STR_410)
+#  endif
+#  ifdef XLAT_STR_411
+  + sizeof(XLAT_STR_411)
+#  endif
+#  ifdef XLAT_STR_412
+  + sizeof(XLAT_STR_412)
+#  endif
+#  ifdef XLAT_STR_413
+  + sizeof(XLAT_STR_413)
+#  endif
+#  ifdef XLAT_STR_414
+  + sizeof(XLAT_STR_414)
+#  endif
+#  ifdef XLAT_STR_415
+  + sizeof(XLAT_STR_415)
+#  endif
+#  ifdef XLAT_STR_416
+  + sizeof(XLAT_STR_416)
+#  endif
+#  ifdef XLAT_STR_417
+  + sizeof(XLAT_STR_417)
+#  endif
+#  ifdef XLAT_STR_418
+  + sizeof(XLAT_STR_418)
+#  endif
+#  ifdef XLAT_STR_419
+  + sizeof(XLAT_STR_419)
+#  endif
+#  ifdef XLAT_STR_420
+  + sizeof(XLAT_STR_420)
+#  endif
+#  ifdef XLAT_STR_421
+  + sizeof(XLAT_STR_421)
+#  endif
+#  ifdef XLAT_STR_422
+  + sizeof(XLAT_STR_422)
+#  endif
+#  ifdef XLAT_STR_423
+  + sizeof(XLAT_STR_423)
+#  endif
+#  ifdef XLAT_STR_424
+  + sizeof(XLAT_STR_424)
+#  endif
+#  ifdef XLAT_STR_425
+  + sizeof(XLAT_STR_425)
+#  endif
+#  ifdef XLAT_STR_426
+  + sizeof(XLAT_STR_426)
+#  endif
+#  ifdef XLAT_STR_427
+  + sizeof(XLAT_STR_427)
+#  endif
+#  ifdef XLAT_STR_428
+  + sizeof(XLAT_STR_428)
+#  endif
+#  ifdef XLAT_STR_429
+  + sizeof(XLAT_STR_429)
+#  endif
+#  ifdef XLAT_STR_430
+  + sizeof(XLAT_STR_430)
+#  endif
+#  ifdef XLAT_STR_431
+  + sizeof(XLAT_STR_431)
+#  endif
+#  ifdef XLAT_STR_432
+  + sizeof(XLAT_STR_432)
+#  endif
+#  ifdef XLAT_STR_433
+  + sizeof(XLAT_STR_433)
+#  endif
+#  ifdef XLAT_STR_434
+  + sizeof(XLAT_STR_434)
+#  endif
+#  ifdef XLAT_STR_435
+  + sizeof(XLAT_STR_435)
+#  endif
+#  ifdef XLAT_STR_436
+  + sizeof(XLAT_STR_436)
+#  endif
+#  ifdef XLAT_STR_437
+  + sizeof(XLAT_STR_437)
+#  endif
+#  ifdef XLAT_STR_438
+  + sizeof(XLAT_STR_438)
+#  endif
+#  ifdef XLAT_STR_439
+  + sizeof(XLAT_STR_439)
+#  endif
+#  ifdef XLAT_STR_440
+  + sizeof(XLAT_STR_440)
+#  endif
+#  ifdef XLAT_STR_441
+  + sizeof(XLAT_STR_441)
+#  endif
+#  ifdef XLAT_STR_442
+  + sizeof(XLAT_STR_442)
+#  endif
+#  ifdef XLAT_STR_443
+  + sizeof(XLAT_STR_443)
+#  endif
+#  ifdef XLAT_STR_444
+  + sizeof(XLAT_STR_444)
+#  endif
+#  ifdef XLAT_STR_445
+  + sizeof(XLAT_STR_445)
+#  endif
+#  ifdef XLAT_STR_446
+  + sizeof(XLAT_STR_446)
+#  endif
+#  ifdef XLAT_STR_447
+  + sizeof(XLAT_STR_447)
+#  endif
+#  ifdef XLAT_STR_448
+  + sizeof(XLAT_STR_448)
+#  endif
+#  ifdef XLAT_STR_449
+  + sizeof(XLAT_STR_449)
+#  endif
+#  ifdef XLAT_STR_450
+  + sizeof(XLAT_STR_450)
+#  endif
+#  ifdef XLAT_STR_451
+  + sizeof(XLAT_STR_451)
+#  endif
+#  ifdef XLAT_STR_452
+  + sizeof(XLAT_STR_452)
+#  endif
+#  ifdef XLAT_STR_453
+  + sizeof(XLAT_STR_453)
+#  endif
+#  ifdef XLAT_STR_454
+  + sizeof(XLAT_STR_454)
+#  endif
+#  ifdef XLAT_STR_455
+  + sizeof(XLAT_STR_455)
+#  endif
+#  ifdef XLAT_STR_456
+  + sizeof(XLAT_STR_456)
+#  endif
+#  ifdef XLAT_STR_457
+  + sizeof(XLAT_STR_457)
+#  endif
+#  ifdef XLAT_STR_458
+  + sizeof(XLAT_STR_458)
+#  endif
+#  ifdef XLAT_STR_459
+  + sizeof(XLAT_STR_459)
+#  endif
+#  ifdef XLAT_STR_460
+  + sizeof(XLAT_STR_460)
+#  endif
+#  ifdef XLAT_STR_461
+  + sizeof(XLAT_STR_461)
+#  endif
+#  ifdef XLAT_STR_462
+  + sizeof(XLAT_STR_462)
+#  endif
+#  ifdef XLAT_STR_463
+  + sizeof(XLAT_STR_463)
+#  endif
+#  ifdef XLAT_STR_464
+  + sizeof(XLAT_STR_464)
+#  endif
+#  ifdef XLAT_STR_465
+  + sizeof(XLAT_STR_465)
+#  endif
+#  ifdef XLAT_STR_466
+  + sizeof(XLAT_STR_466)
+#  endif
+#  ifdef XLAT_STR_467
+  + sizeof(XLAT_STR_467)
+#  endif
+#  ifdef XLAT_STR_468
+  + sizeof(XLAT_STR_468)
+#  endif
+#  ifdef XLAT_STR_469
+  + sizeof(XLAT_STR_469)
+#  endif
+#  ifdef XLAT_STR_470
+  + sizeof(XLAT_STR_470)
+#  endif
+#  ifdef XLAT_STR_471
+  + sizeof(XLAT_STR_471)
+#  endif
+#  ifdef XLAT_STR_472
+  + sizeof(XLAT_STR_472)
+#  endif
+#  ifdef XLAT_STR_473
+  + sizeof(XLAT_STR_473)
+#  endif
+#  ifdef XLAT_STR_474
+  + sizeof(XLAT_STR_474)
+#  endif
+#  ifdef XLAT_STR_475
+  + sizeof(XLAT_STR_475)
+#  endif
+#  ifdef XLAT_STR_476
+  + sizeof(XLAT_STR_476)
+#  endif
+#  ifdef XLAT_STR_477
+  + sizeof(XLAT_STR_477)
+#  endif
+#  ifdef XLAT_STR_478
+  + sizeof(XLAT_STR_478)
+#  endif
+#  ifdef XLAT_STR_479
+  + sizeof(XLAT_STR_479)
+#  endif
+#  ifdef XLAT_STR_480
+  + sizeof(XLAT_STR_480)
+#  endif
+#  ifdef XLAT_STR_481
+  + sizeof(XLAT_STR_481)
+#  endif
+#  ifdef XLAT_STR_482
+  + sizeof(XLAT_STR_482)
+#  endif
+#  ifdef XLAT_STR_483
+  + sizeof(XLAT_STR_483)
+#  endif
+#  ifdef XLAT_STR_484
+  + sizeof(XLAT_STR_484)
+#  endif
+#  ifdef XLAT_STR_485
+  + sizeof(XLAT_STR_485)
+#  endif
+#  ifdef XLAT_STR_486
+  + sizeof(XLAT_STR_486)
+#  endif
+#  ifdef XLAT_STR_487
+  + sizeof(XLAT_STR_487)
+#  endif
+#  ifdef XLAT_STR_488
+  + sizeof(XLAT_STR_488)
+#  endif
+#  ifdef XLAT_STR_489
+  + sizeof(XLAT_STR_489)
+#  endif
+#  ifdef XLAT_STR_490
+  + sizeof(XLAT_STR_490)
+#  endif
+#  ifdef XLAT_STR_491
+  + sizeof(XLAT_STR_491)
+#  endif
+#  ifdef XLAT_STR_492
+  + sizeof(XLAT_STR_492)
+#  endif
+#  ifdef XLAT_STR_493
+  + sizeof(XLAT_STR_493)
+#  endif
+#  ifdef XLAT_STR_494
+  + sizeof(XLAT_STR_494)
+#  endif
+#  ifdef XLAT_STR_495
+  + sizeof(XLAT_STR_495)
+#  endif
+#  ifdef XLAT_STR_496
+  + sizeof(XLAT_STR_496)
+#  endif
+#  ifdef XLAT_STR_497
+  + sizeof(XLAT_STR_497)
+#  endif
+#  ifdef XLAT_STR_498
+  + sizeof(XLAT_STR_498)
+#  endif
+#  ifdef XLAT_STR_499
+  + sizeof(XLAT_STR_499)
+#  endif
+#  ifdef XLAT_STR_500
+  + sizeof(XLAT_STR_500)
+#  endif
+#  ifdef XLAT_STR_501
+  + sizeof(XLAT_STR_501)
+#  endif
+#  ifdef XLAT_STR_502
+  + sizeof(XLAT_STR_502)
+#  endif
+#  ifdef XLAT_STR_503
+  + sizeof(XLAT_STR_503)
+#  endif
+#  ifdef XLAT_STR_504
+  + sizeof(XLAT_STR_504)
+#  endif
+#  ifdef XLAT_STR_505
+  + sizeof(XLAT_STR_505)
+#  endif
+#  ifdef XLAT_STR_506
+  + sizeof(XLAT_STR_506)
+#  endif
+#  ifdef XLAT_STR_507
+  + sizeof(XLAT_STR_507)
+#  endif
+#  ifdef XLAT_STR_508
+  + sizeof(XLAT_STR_508)
+#  endif
+#  ifdef XLAT_STR_509
+  + sizeof(XLAT_STR_509)
+#  endif
+#  ifdef XLAT_STR_510
+  + sizeof(XLAT_STR_510)
+#  endif
+#  ifdef XLAT_STR_511
+  + sizeof(XLAT_STR_511)
+#  endif
+#  ifdef XLAT_STR_512
+  + sizeof(XLAT_STR_512)
+#  endif
+#  ifdef XLAT_STR_513
+  + sizeof(XLAT_STR_513)
+#  endif
+#  ifdef XLAT_STR_514
+  + sizeof(XLAT_STR_514)
+#  endif
+#  ifdef XLAT_STR_515
+  + sizeof(XLAT_STR_515)
+#  endif
+#  ifdef XLAT_STR_516
+  + sizeof(XLAT_STR_516)
+#  endif
+#  ifdef XLAT_STR_517
+  + sizeof(XLAT_STR_517)
+#  endif
+#  ifdef XLAT_STR_518
+  + sizeof(XLAT_STR_518)
+#  endif
+#  ifdef XLAT_STR_519
+  + sizeof(XLAT_STR_519)
+#  endif
+#  ifdef XLAT_STR_520
+  + sizeof(XLAT_STR_520)
+#  endif
+#  ifdef XLAT_STR_521
+  + sizeof(XLAT_STR_521)
+#  endif
+#  ifdef XLAT_STR_522
+  + sizeof(XLAT_STR_522)
+#  endif
+#  ifdef XLAT_STR_523
+  + sizeof(XLAT_STR_523)
+#  endif
+#  ifdef XLAT_STR_524
+  + sizeof(XLAT_STR_524)
+#  endif
+#  ifdef XLAT_STR_525
+  + sizeof(XLAT_STR_525)
+#  endif
+#  ifdef XLAT_STR_526
+  + sizeof(XLAT_STR_526)
+#  endif
+#  ifdef XLAT_STR_527
+  + sizeof(XLAT_STR_527)
+#  endif
+#  ifdef XLAT_STR_528
+  + sizeof(XLAT_STR_528)
+#  endif
+#  ifdef XLAT_STR_529
+  + sizeof(XLAT_STR_529)
+#  endif
+#  ifdef XLAT_STR_530
+  + sizeof(XLAT_STR_530)
+#  endif
+#  ifdef XLAT_STR_531
+  + sizeof(XLAT_STR_531)
+#  endif
+#  ifdef XLAT_STR_532
+  + sizeof(XLAT_STR_532)
+#  endif
+#  ifdef XLAT_STR_533
+  + sizeof(XLAT_STR_533)
+#  endif
+#  ifdef XLAT_STR_534
+  + sizeof(XLAT_STR_534)
+#  endif
+#  ifdef XLAT_STR_535
+  + sizeof(XLAT_STR_535)
+#  endif
+#  ifdef XLAT_STR_536
+  + sizeof(XLAT_STR_536)
+#  endif
+#  ifdef XLAT_STR_537
+  + sizeof(XLAT_STR_537)
+#  endif
+#  ifdef XLAT_STR_538
+  + sizeof(XLAT_STR_538)
+#  endif
+#  ifdef XLAT_STR_539
+  + sizeof(XLAT_STR_539)
+#  endif
+#  ifdef XLAT_STR_540
+  + sizeof(XLAT_STR_540)
+#  endif
+#  ifdef XLAT_STR_541
+  + sizeof(XLAT_STR_541)
+#  endif
+#  ifdef XLAT_STR_542
+  + sizeof(XLAT_STR_542)
+#  endif
+#  ifdef XLAT_STR_543
+  + sizeof(XLAT_STR_543)
+#  endif
+#  ifdef XLAT_STR_544
+  + sizeof(XLAT_STR_544)
+#  endif
+#  ifdef XLAT_STR_545
+  + sizeof(XLAT_STR_545)
+#  endif
+#  ifdef XLAT_STR_546
+  + sizeof(XLAT_STR_546)
+#  endif
+#  ifdef XLAT_STR_547
+  + sizeof(XLAT_STR_547)
+#  endif
+#  ifdef XLAT_STR_548
+  + sizeof(XLAT_STR_548)
+#  endif
+#  ifdef XLAT_STR_549
+  + sizeof(XLAT_STR_549)
+#  endif
+#  ifdef XLAT_STR_550
+  + sizeof(XLAT_STR_550)
+#  endif
+#  ifdef XLAT_STR_551
+  + sizeof(XLAT_STR_551)
+#  endif
+#  ifdef XLAT_STR_552
+  + sizeof(XLAT_STR_552)
+#  endif
+#  ifdef XLAT_STR_553
+  + sizeof(XLAT_STR_553)
+#  endif
+#  ifdef XLAT_STR_554
+  + sizeof(XLAT_STR_554)
+#  endif
+#  ifdef XLAT_STR_555
+  + sizeof(XLAT_STR_555)
+#  endif
+#  ifdef XLAT_STR_556
+  + sizeof(XLAT_STR_556)
+#  endif
+#  ifdef XLAT_STR_557
+  + sizeof(XLAT_STR_557)
+#  endif
+#  ifdef XLAT_STR_558
+  + sizeof(XLAT_STR_558)
+#  endif
+#  ifdef XLAT_STR_559
+  + sizeof(XLAT_STR_559)
+#  endif
+#  ifdef XLAT_STR_560
+  + sizeof(XLAT_STR_560)
+#  endif
+#  ifdef XLAT_STR_561
+  + sizeof(XLAT_STR_561)
+#  endif
+#  ifdef XLAT_STR_562
+  + sizeof(XLAT_STR_562)
+#  endif
+#  ifdef XLAT_STR_563
+  + sizeof(XLAT_STR_563)
+#  endif
+#  ifdef XLAT_STR_564
+  + sizeof(XLAT_STR_564)
+#  endif
+#  ifdef XLAT_STR_565
+  + sizeof(XLAT_STR_565)
+#  endif
+#  ifdef XLAT_STR_566
+  + sizeof(XLAT_STR_566)
+#  endif
+#  ifdef XLAT_STR_567
+  + sizeof(XLAT_STR_567)
+#  endif
+#  ifdef XLAT_STR_568
+  + sizeof(XLAT_STR_568)
+#  endif
+#  ifdef XLAT_STR_569
+  + sizeof(XLAT_STR_569)
+#  endif
+#  ifdef XLAT_STR_570
+  + sizeof(XLAT_STR_570)
+#  endif
+#  ifdef XLAT_STR_571
+  + sizeof(XLAT_STR_571)
+#  endif
+#  ifdef XLAT_STR_572
+  + sizeof(XLAT_STR_572)
+#  endif
+#  ifdef XLAT_STR_573
+  + sizeof(XLAT_STR_573)
+#  endif
+#  ifdef XLAT_STR_574
+  + sizeof(XLAT_STR_574)
+#  endif
+#  ifdef XLAT_STR_575
+  + sizeof(XLAT_STR_575)
+#  endif
+#  ifdef XLAT_STR_576
+  + sizeof(XLAT_STR_576)
+#  endif
+#  ifdef XLAT_STR_577
+  + sizeof(XLAT_STR_577)
+#  endif
+#  ifdef XLAT_STR_578
+  + sizeof(XLAT_STR_578)
+#  endif
+#  ifdef XLAT_STR_579
+  + sizeof(XLAT_STR_579)
+#  endif
+#  ifdef XLAT_STR_580
+  + sizeof(XLAT_STR_580)
+#  endif
+#  ifdef XLAT_STR_581
+  + sizeof(XLAT_STR_581)
+#  endif
+#  ifdef XLAT_STR_582
+  + sizeof(XLAT_STR_582)
+#  endif
+#  ifdef XLAT_STR_583
+  + sizeof(XLAT_STR_583)
+#  endif
+#  ifdef XLAT_STR_584
+  + sizeof(XLAT_STR_584)
+#  endif
+#  ifdef XLAT_STR_585
+  + sizeof(XLAT_STR_585)
+#  endif
+#  ifdef XLAT_STR_586
+  + sizeof(XLAT_STR_586)
+#  endif
+#  ifdef XLAT_STR_587
+  + sizeof(XLAT_STR_587)
+#  endif
+#  ifdef XLAT_STR_588
+  + sizeof(XLAT_STR_588)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
+#  undef XLAT_STR_47
+#  undef XLAT_VAL_47
+#  undef XLAT_STR_48
+#  undef XLAT_VAL_48
+#  undef XLAT_STR_49
+#  undef XLAT_VAL_49
+#  undef XLAT_STR_50
+#  undef XLAT_VAL_50
+#  undef XLAT_STR_51
+#  undef XLAT_VAL_51
+#  undef XLAT_STR_52
+#  undef XLAT_VAL_52
+#  undef XLAT_STR_53
+#  undef XLAT_VAL_53
+#  undef XLAT_STR_54
+#  undef XLAT_VAL_54
+#  undef XLAT_STR_55
+#  undef XLAT_VAL_55
+#  undef XLAT_STR_56
+#  undef XLAT_VAL_56
+#  undef XLAT_STR_57
+#  undef XLAT_VAL_57
+#  undef XLAT_STR_58
+#  undef XLAT_VAL_58
+#  undef XLAT_STR_59
+#  undef XLAT_VAL_59
+#  undef XLAT_STR_60
+#  undef XLAT_VAL_60
+#  undef XLAT_STR_61
+#  undef XLAT_VAL_61
+#  undef XLAT_STR_62
+#  undef XLAT_VAL_62
+#  undef XLAT_STR_63
+#  undef XLAT_VAL_63
+#  undef XLAT_STR_64
+#  undef XLAT_VAL_64
+#  undef XLAT_STR_65
+#  undef XLAT_VAL_65
+#  undef XLAT_STR_66
+#  undef XLAT_VAL_66
+#  undef XLAT_STR_67
+#  undef XLAT_VAL_67
+#  undef XLAT_STR_68
+#  undef XLAT_VAL_68
+#  undef XLAT_STR_69
+#  undef XLAT_VAL_69
+#  undef XLAT_STR_70
+#  undef XLAT_VAL_70
+#  undef XLAT_STR_71
+#  undef XLAT_VAL_71
+#  undef XLAT_STR_72
+#  undef XLAT_VAL_72
+#  undef XLAT_STR_73
+#  undef XLAT_VAL_73
+#  undef XLAT_STR_74
+#  undef XLAT_VAL_74
+#  undef XLAT_STR_75
+#  undef XLAT_VAL_75
+#  undef XLAT_STR_76
+#  undef XLAT_VAL_76
+#  undef XLAT_STR_77
+#  undef XLAT_VAL_77
+#  undef XLAT_STR_78
+#  undef XLAT_VAL_78
+#  undef XLAT_STR_79
+#  undef XLAT_VAL_79
+#  undef XLAT_STR_80
+#  undef XLAT_VAL_80
+#  undef XLAT_STR_81
+#  undef XLAT_VAL_81
+#  undef XLAT_STR_82
+#  undef XLAT_VAL_82
+#  undef XLAT_STR_83
+#  undef XLAT_VAL_83
+#  undef XLAT_STR_84
+#  undef XLAT_VAL_84
+#  undef XLAT_STR_85
+#  undef XLAT_VAL_85
+#  undef XLAT_STR_86
+#  undef XLAT_VAL_86
+#  undef XLAT_STR_87
+#  undef XLAT_VAL_87
+#  undef XLAT_STR_88
+#  undef XLAT_VAL_88
+#  undef XLAT_STR_89
+#  undef XLAT_VAL_89
+#  undef XLAT_STR_90
+#  undef XLAT_VAL_90
+#  undef XLAT_STR_91
+#  undef XLAT_VAL_91
+#  undef XLAT_STR_92
+#  undef XLAT_VAL_92
+#  undef XLAT_STR_93
+#  undef XLAT_VAL_93
+#  undef XLAT_STR_94
+#  undef XLAT_VAL_94
+#  undef XLAT_STR_95
+#  undef XLAT_VAL_95
+#  undef XLAT_STR_96
+#  undef XLAT_VAL_96
+#  undef XLAT_STR_97
+#  undef XLAT_VAL_97
+#  undef XLAT_STR_98
+#  undef XLAT_VAL_98
+#  undef XLAT_STR_99
+#  undef XLAT_VAL_99
+#  undef XLAT_STR_100
+#  undef XLAT_VAL_100
+#  undef XLAT_STR_101
+#  undef XLAT_VAL_101
+#  undef XLAT_STR_102
+#  undef XLAT_VAL_102
+#  undef XLAT_STR_103
+#  undef XLAT_VAL_103
+#  undef XLAT_STR_104
+#  undef XLAT_VAL_104
+#  undef XLAT_STR_105
+#  undef XLAT_VAL_105
+#  undef XLAT_STR_106
+#  undef XLAT_VAL_106
+#  undef XLAT_STR_107
+#  undef XLAT_VAL_107
+#  undef XLAT_STR_108
+#  undef XLAT_VAL_108
+#  undef XLAT_STR_109
+#  undef XLAT_VAL_109
+#  undef XLAT_STR_110
+#  undef XLAT_VAL_110
+#  undef XLAT_STR_111
+#  undef XLAT_VAL_111
+#  undef XLAT_STR_112
+#  undef XLAT_VAL_112
+#  undef XLAT_STR_113
+#  undef XLAT_VAL_113
+#  undef XLAT_STR_114
+#  undef XLAT_VAL_114
+#  undef XLAT_STR_115
+#  undef XLAT_VAL_115
+#  undef XLAT_STR_116
+#  undef XLAT_VAL_116
+#  undef XLAT_STR_117
+#  undef XLAT_VAL_117
+#  undef XLAT_STR_118
+#  undef XLAT_VAL_118
+#  undef XLAT_STR_119
+#  undef XLAT_VAL_119
+#  undef XLAT_STR_120
+#  undef XLAT_VAL_120
+#  undef XLAT_STR_121
+#  undef XLAT_VAL_121
+#  undef XLAT_STR_122
+#  undef XLAT_VAL_122
+#  undef XLAT_STR_123
+#  undef XLAT_VAL_123
+#  undef XLAT_STR_124
+#  undef XLAT_VAL_124
+#  undef XLAT_STR_125
+#  undef XLAT_VAL_125
+#  undef XLAT_STR_126
+#  undef XLAT_VAL_126
+#  undef XLAT_STR_127
+#  undef XLAT_VAL_127
+#  undef XLAT_STR_128
+#  undef XLAT_VAL_128
+#  undef XLAT_STR_129
+#  undef XLAT_VAL_129
+#  undef XLAT_STR_130
+#  undef XLAT_VAL_130
+#  undef XLAT_STR_131
+#  undef XLAT_VAL_131
+#  undef XLAT_STR_132
+#  undef XLAT_VAL_132
+#  undef XLAT_STR_133
+#  undef XLAT_VAL_133
+#  undef XLAT_STR_134
+#  undef XLAT_VAL_134
+#  undef XLAT_STR_135
+#  undef XLAT_VAL_135
+#  undef XLAT_STR_136
+#  undef XLAT_VAL_136
+#  undef XLAT_STR_137
+#  undef XLAT_VAL_137
+#  undef XLAT_STR_138
+#  undef XLAT_VAL_138
+#  undef XLAT_STR_139
+#  undef XLAT_VAL_139
+#  undef XLAT_STR_140
+#  undef XLAT_VAL_140
+#  undef XLAT_STR_141
+#  undef XLAT_VAL_141
+#  undef XLAT_STR_142
+#  undef XLAT_VAL_142
+#  undef XLAT_STR_143
+#  undef XLAT_VAL_143
+#  undef XLAT_STR_144
+#  undef XLAT_VAL_144
+#  undef XLAT_STR_145
+#  undef XLAT_VAL_145
+#  undef XLAT_STR_146
+#  undef XLAT_VAL_146
+#  undef XLAT_STR_147
+#  undef XLAT_VAL_147
+#  undef XLAT_STR_148
+#  undef XLAT_VAL_148
+#  undef XLAT_STR_149
+#  undef XLAT_VAL_149
+#  undef XLAT_STR_150
+#  undef XLAT_VAL_150
+#  undef XLAT_STR_151
+#  undef XLAT_VAL_151
+#  undef XLAT_STR_152
+#  undef XLAT_VAL_152
+#  undef XLAT_STR_153
+#  undef XLAT_VAL_153
+#  undef XLAT_STR_154
+#  undef XLAT_VAL_154
+#  undef XLAT_STR_155
+#  undef XLAT_VAL_155
+#  undef XLAT_STR_156
+#  undef XLAT_VAL_156
+#  undef XLAT_STR_157
+#  undef XLAT_VAL_157
+#  undef XLAT_STR_158
+#  undef XLAT_VAL_158
+#  undef XLAT_STR_159
+#  undef XLAT_VAL_159
+#  undef XLAT_STR_160
+#  undef XLAT_VAL_160
+#  undef XLAT_STR_161
+#  undef XLAT_VAL_161
+#  undef XLAT_STR_162
+#  undef XLAT_VAL_162
+#  undef XLAT_STR_163
+#  undef XLAT_VAL_163
+#  undef XLAT_STR_164
+#  undef XLAT_VAL_164
+#  undef XLAT_STR_165
+#  undef XLAT_VAL_165
+#  undef XLAT_STR_166
+#  undef XLAT_VAL_166
+#  undef XLAT_STR_167
+#  undef XLAT_VAL_167
+#  undef XLAT_STR_168
+#  undef XLAT_VAL_168
+#  undef XLAT_STR_169
+#  undef XLAT_VAL_169
+#  undef XLAT_STR_170
+#  undef XLAT_VAL_170
+#  undef XLAT_STR_171
+#  undef XLAT_VAL_171
+#  undef XLAT_STR_172
+#  undef XLAT_VAL_172
+#  undef XLAT_STR_173
+#  undef XLAT_VAL_173
+#  undef XLAT_STR_174
+#  undef XLAT_VAL_174
+#  undef XLAT_STR_175
+#  undef XLAT_VAL_175
+#  undef XLAT_STR_176
+#  undef XLAT_VAL_176
+#  undef XLAT_STR_177
+#  undef XLAT_VAL_177
+#  undef XLAT_STR_178
+#  undef XLAT_VAL_178
+#  undef XLAT_STR_179
+#  undef XLAT_VAL_179
+#  undef XLAT_STR_180
+#  undef XLAT_VAL_180
+#  undef XLAT_STR_181
+#  undef XLAT_VAL_181
+#  undef XLAT_STR_182
+#  undef XLAT_VAL_182
+#  undef XLAT_STR_183
+#  undef XLAT_VAL_183
+#  undef XLAT_STR_184
+#  undef XLAT_VAL_184
+#  undef XLAT_STR_185
+#  undef XLAT_VAL_185
+#  undef XLAT_STR_186
+#  undef XLAT_VAL_186
+#  undef XLAT_STR_187
+#  undef XLAT_VAL_187
+#  undef XLAT_STR_188
+#  undef XLAT_VAL_188
+#  undef XLAT_STR_189
+#  undef XLAT_VAL_189
+#  undef XLAT_STR_190
+#  undef XLAT_VAL_190
+#  undef XLAT_STR_191
+#  undef XLAT_VAL_191
+#  undef XLAT_STR_192
+#  undef XLAT_VAL_192
+#  undef XLAT_STR_193
+#  undef XLAT_VAL_193
+#  undef XLAT_STR_194
+#  undef XLAT_VAL_194
+#  undef XLAT_STR_195
+#  undef XLAT_VAL_195
+#  undef XLAT_STR_196
+#  undef XLAT_VAL_196
+#  undef XLAT_STR_197
+#  undef XLAT_VAL_197
+#  undef XLAT_STR_198
+#  undef XLAT_VAL_198
+#  undef XLAT_STR_199
+#  undef XLAT_VAL_199
+#  undef XLAT_STR_200
+#  undef XLAT_VAL_200
+#  undef XLAT_STR_201
+#  undef XLAT_VAL_201
+#  undef XLAT_STR_202
+#  undef XLAT_VAL_202
+#  undef XLAT_STR_203
+#  undef XLAT_VAL_203
+#  undef XLAT_STR_204
+#  undef XLAT_VAL_204
+#  undef XLAT_STR_205
+#  undef XLAT_VAL_205
+#  undef XLAT_STR_206
+#  undef XLAT_VAL_206
+#  undef XLAT_STR_207
+#  undef XLAT_VAL_207
+#  undef XLAT_STR_208
+#  undef XLAT_VAL_208
+#  undef XLAT_STR_209
+#  undef XLAT_VAL_209
+#  undef XLAT_STR_210
+#  undef XLAT_VAL_210
+#  undef XLAT_STR_211
+#  undef XLAT_VAL_211
+#  undef XLAT_STR_212
+#  undef XLAT_VAL_212
+#  undef XLAT_STR_213
+#  undef XLAT_VAL_213
+#  undef XLAT_STR_214
+#  undef XLAT_VAL_214
+#  undef XLAT_STR_215
+#  undef XLAT_VAL_215
+#  undef XLAT_STR_216
+#  undef XLAT_VAL_216
+#  undef XLAT_STR_217
+#  undef XLAT_VAL_217
+#  undef XLAT_STR_218
+#  undef XLAT_VAL_218
+#  undef XLAT_STR_219
+#  undef XLAT_VAL_219
+#  undef XLAT_STR_220
+#  undef XLAT_VAL_220
+#  undef XLAT_STR_221
+#  undef XLAT_VAL_221
+#  undef XLAT_STR_222
+#  undef XLAT_VAL_222
+#  undef XLAT_STR_223
+#  undef XLAT_VAL_223
+#  undef XLAT_STR_224
+#  undef XLAT_VAL_224
+#  undef XLAT_STR_225
+#  undef XLAT_VAL_225
+#  undef XLAT_STR_226
+#  undef XLAT_VAL_226
+#  undef XLAT_STR_227
+#  undef XLAT_VAL_227
+#  undef XLAT_STR_228
+#  undef XLAT_VAL_228
+#  undef XLAT_STR_229
+#  undef XLAT_VAL_229
+#  undef XLAT_STR_230
+#  undef XLAT_VAL_230
+#  undef XLAT_STR_231
+#  undef XLAT_VAL_231
+#  undef XLAT_STR_232
+#  undef XLAT_VAL_232
+#  undef XLAT_STR_233
+#  undef XLAT_VAL_233
+#  undef XLAT_STR_234
+#  undef XLAT_VAL_234
+#  undef XLAT_STR_235
+#  undef XLAT_VAL_235
+#  undef XLAT_STR_236
+#  undef XLAT_VAL_236
+#  undef XLAT_STR_237
+#  undef XLAT_VAL_237
+#  undef XLAT_STR_238
+#  undef XLAT_VAL_238
+#  undef XLAT_STR_239
+#  undef XLAT_VAL_239
+#  undef XLAT_STR_240
+#  undef XLAT_VAL_240
+#  undef XLAT_STR_241
+#  undef XLAT_VAL_241
+#  undef XLAT_STR_242
+#  undef XLAT_VAL_242
+#  undef XLAT_STR_243
+#  undef XLAT_VAL_243
+#  undef XLAT_STR_244
+#  undef XLAT_VAL_244
+#  undef XLAT_STR_245
+#  undef XLAT_VAL_245
+#  undef XLAT_STR_246
+#  undef XLAT_VAL_246
+#  undef XLAT_STR_247
+#  undef XLAT_VAL_247
+#  undef XLAT_STR_248
+#  undef XLAT_VAL_248
+#  undef XLAT_STR_249
+#  undef XLAT_VAL_249
+#  undef XLAT_STR_250
+#  undef XLAT_VAL_250
+#  undef XLAT_STR_251
+#  undef XLAT_VAL_251
+#  undef XLAT_STR_252
+#  undef XLAT_VAL_252
+#  undef XLAT_STR_253
+#  undef XLAT_VAL_253
+#  undef XLAT_STR_254
+#  undef XLAT_VAL_254
+#  undef XLAT_STR_255
+#  undef XLAT_VAL_255
+#  undef XLAT_STR_256
+#  undef XLAT_VAL_256
+#  undef XLAT_STR_257
+#  undef XLAT_VAL_257
+#  undef XLAT_STR_258
+#  undef XLAT_VAL_258
+#  undef XLAT_STR_259
+#  undef XLAT_VAL_259
+#  undef XLAT_STR_260
+#  undef XLAT_VAL_260
+#  undef XLAT_STR_261
+#  undef XLAT_VAL_261
+#  undef XLAT_STR_262
+#  undef XLAT_VAL_262
+#  undef XLAT_STR_263
+#  undef XLAT_VAL_263
+#  undef XLAT_STR_264
+#  undef XLAT_VAL_264
+#  undef XLAT_STR_265
+#  undef XLAT_VAL_265
+#  undef XLAT_STR_266
+#  undef XLAT_VAL_266
+#  undef XLAT_STR_267
+#  undef XLAT_VAL_267
+#  undef XLAT_STR_268
+#  undef XLAT_VAL_268
+#  undef XLAT_STR_269
+#  undef XLAT_VAL_269
+#  undef XLAT_STR_270
+#  undef XLAT_VAL_270
+#  undef XLAT_STR_271
+#  undef XLAT_VAL_271
+#  undef XLAT_STR_272
+#  undef XLAT_VAL_272
+#  undef XLAT_STR_273
+#  undef XLAT_VAL_273
+#  undef XLAT_STR_274
+#  undef XLAT_VAL_274
+#  undef XLAT_STR_275
+#  undef XLAT_VAL_275
+#  undef XLAT_STR_276
+#  undef XLAT_VAL_276
+#  undef XLAT_STR_277
+#  undef XLAT_VAL_277
+#  undef XLAT_STR_278
+#  undef XLAT_VAL_278
+#  undef XLAT_STR_279
+#  undef XLAT_VAL_279
+#  undef XLAT_STR_280
+#  undef XLAT_VAL_280
+#  undef XLAT_STR_281
+#  undef XLAT_VAL_281
+#  undef XLAT_STR_282
+#  undef XLAT_VAL_282
+#  undef XLAT_STR_283
+#  undef XLAT_VAL_283
+#  undef XLAT_STR_284
+#  undef XLAT_VAL_284
+#  undef XLAT_STR_285
+#  undef XLAT_VAL_285
+#  undef XLAT_STR_286
+#  undef XLAT_VAL_286
+#  undef XLAT_STR_287
+#  undef XLAT_VAL_287
+#  undef XLAT_STR_288
+#  undef XLAT_VAL_288
+#  undef XLAT_STR_289
+#  undef XLAT_VAL_289
+#  undef XLAT_STR_290
+#  undef XLAT_VAL_290
+#  undef XLAT_STR_291
+#  undef XLAT_VAL_291
+#  undef XLAT_STR_292
+#  undef XLAT_VAL_292
+#  undef XLAT_STR_293
+#  undef XLAT_VAL_293
+#  undef XLAT_STR_294
+#  undef XLAT_VAL_294
+#  undef XLAT_STR_295
+#  undef XLAT_VAL_295
+#  undef XLAT_STR_296
+#  undef XLAT_VAL_296
+#  undef XLAT_STR_297
+#  undef XLAT_VAL_297
+#  undef XLAT_STR_298
+#  undef XLAT_VAL_298
+#  undef XLAT_STR_299
+#  undef XLAT_VAL_299
+#  undef XLAT_STR_300
+#  undef XLAT_VAL_300
+#  undef XLAT_STR_301
+#  undef XLAT_VAL_301
+#  undef XLAT_STR_302
+#  undef XLAT_VAL_302
+#  undef XLAT_STR_303
+#  undef XLAT_VAL_303
+#  undef XLAT_STR_304
+#  undef XLAT_VAL_304
+#  undef XLAT_STR_305
+#  undef XLAT_VAL_305
+#  undef XLAT_STR_306
+#  undef XLAT_VAL_306
+#  undef XLAT_STR_307
+#  undef XLAT_VAL_307
+#  undef XLAT_STR_308
+#  undef XLAT_VAL_308
+#  undef XLAT_STR_309
+#  undef XLAT_VAL_309
+#  undef XLAT_STR_310
+#  undef XLAT_VAL_310
+#  undef XLAT_STR_311
+#  undef XLAT_VAL_311
+#  undef XLAT_STR_312
+#  undef XLAT_VAL_312
+#  undef XLAT_STR_313
+#  undef XLAT_VAL_313
+#  undef XLAT_STR_314
+#  undef XLAT_VAL_314
+#  undef XLAT_STR_315
+#  undef XLAT_VAL_315
+#  undef XLAT_STR_316
+#  undef XLAT_VAL_316
+#  undef XLAT_STR_317
+#  undef XLAT_VAL_317
+#  undef XLAT_STR_318
+#  undef XLAT_VAL_318
+#  undef XLAT_STR_319
+#  undef XLAT_VAL_319
+#  undef XLAT_STR_320
+#  undef XLAT_VAL_320
+#  undef XLAT_STR_321
+#  undef XLAT_VAL_321
+#  undef XLAT_STR_322
+#  undef XLAT_VAL_322
+#  undef XLAT_STR_323
+#  undef XLAT_VAL_323
+#  undef XLAT_STR_324
+#  undef XLAT_VAL_324
+#  undef XLAT_STR_325
+#  undef XLAT_VAL_325
+#  undef XLAT_STR_326
+#  undef XLAT_VAL_326
+#  undef XLAT_STR_327
+#  undef XLAT_VAL_327
+#  undef XLAT_STR_328
+#  undef XLAT_VAL_328
+#  undef XLAT_STR_329
+#  undef XLAT_VAL_329
+#  undef XLAT_STR_330
+#  undef XLAT_VAL_330
+#  undef XLAT_STR_331
+#  undef XLAT_VAL_331
+#  undef XLAT_STR_332
+#  undef XLAT_VAL_332
+#  undef XLAT_STR_333
+#  undef XLAT_VAL_333
+#  undef XLAT_STR_334
+#  undef XLAT_VAL_334
+#  undef XLAT_STR_335
+#  undef XLAT_VAL_335
+#  undef XLAT_STR_336
+#  undef XLAT_VAL_336
+#  undef XLAT_STR_337
+#  undef XLAT_VAL_337
+#  undef XLAT_STR_338
+#  undef XLAT_VAL_338
+#  undef XLAT_STR_339
+#  undef XLAT_VAL_339
+#  undef XLAT_STR_340
+#  undef XLAT_VAL_340
+#  undef XLAT_STR_341
+#  undef XLAT_VAL_341
+#  undef XLAT_STR_342
+#  undef XLAT_VAL_342
+#  undef XLAT_STR_343
+#  undef XLAT_VAL_343
+#  undef XLAT_STR_344
+#  undef XLAT_VAL_344
+#  undef XLAT_STR_345
+#  undef XLAT_VAL_345
+#  undef XLAT_STR_346
+#  undef XLAT_VAL_346
+#  undef XLAT_STR_347
+#  undef XLAT_VAL_347
+#  undef XLAT_STR_348
+#  undef XLAT_VAL_348
+#  undef XLAT_STR_349
+#  undef XLAT_VAL_349
+#  undef XLAT_STR_350
+#  undef XLAT_VAL_350
+#  undef XLAT_STR_351
+#  undef XLAT_VAL_351
+#  undef XLAT_STR_352
+#  undef XLAT_VAL_352
+#  undef XLAT_STR_353
+#  undef XLAT_VAL_353
+#  undef XLAT_STR_354
+#  undef XLAT_VAL_354
+#  undef XLAT_STR_355
+#  undef XLAT_VAL_355
+#  undef XLAT_STR_356
+#  undef XLAT_VAL_356
+#  undef XLAT_STR_357
+#  undef XLAT_VAL_357
+#  undef XLAT_STR_358
+#  undef XLAT_VAL_358
+#  undef XLAT_STR_359
+#  undef XLAT_VAL_359
+#  undef XLAT_STR_360
+#  undef XLAT_VAL_360
+#  undef XLAT_STR_361
+#  undef XLAT_VAL_361
+#  undef XLAT_STR_362
+#  undef XLAT_VAL_362
+#  undef XLAT_STR_363
+#  undef XLAT_VAL_363
+#  undef XLAT_STR_364
+#  undef XLAT_VAL_364
+#  undef XLAT_STR_365
+#  undef XLAT_VAL_365
+#  undef XLAT_STR_366
+#  undef XLAT_VAL_366
+#  undef XLAT_STR_367
+#  undef XLAT_VAL_367
+#  undef XLAT_STR_368
+#  undef XLAT_VAL_368
+#  undef XLAT_STR_369
+#  undef XLAT_VAL_369
+#  undef XLAT_STR_370
+#  undef XLAT_VAL_370
+#  undef XLAT_STR_371
+#  undef XLAT_VAL_371
+#  undef XLAT_STR_372
+#  undef XLAT_VAL_372
+#  undef XLAT_STR_373
+#  undef XLAT_VAL_373
+#  undef XLAT_STR_374
+#  undef XLAT_VAL_374
+#  undef XLAT_STR_375
+#  undef XLAT_VAL_375
+#  undef XLAT_STR_376
+#  undef XLAT_VAL_376
+#  undef XLAT_STR_377
+#  undef XLAT_VAL_377
+#  undef XLAT_STR_378
+#  undef XLAT_VAL_378
+#  undef XLAT_STR_379
+#  undef XLAT_VAL_379
+#  undef XLAT_STR_380
+#  undef XLAT_VAL_380
+#  undef XLAT_STR_381
+#  undef XLAT_VAL_381
+#  undef XLAT_STR_382
+#  undef XLAT_VAL_382
+#  undef XLAT_STR_383
+#  undef XLAT_VAL_383
+#  undef XLAT_STR_384
+#  undef XLAT_VAL_384
+#  undef XLAT_STR_385
+#  undef XLAT_VAL_385
+#  undef XLAT_STR_386
+#  undef XLAT_VAL_386
+#  undef XLAT_STR_387
+#  undef XLAT_VAL_387
+#  undef XLAT_STR_388
+#  undef XLAT_VAL_388
+#  undef XLAT_STR_389
+#  undef XLAT_VAL_389
+#  undef XLAT_STR_390
+#  undef XLAT_VAL_390
+#  undef XLAT_STR_391
+#  undef XLAT_VAL_391
+#  undef XLAT_STR_392
+#  undef XLAT_VAL_392
+#  undef XLAT_STR_393
+#  undef XLAT_VAL_393
+#  undef XLAT_STR_394
+#  undef XLAT_VAL_394
+#  undef XLAT_STR_395
+#  undef XLAT_VAL_395
+#  undef XLAT_STR_396
+#  undef XLAT_VAL_396
+#  undef XLAT_STR_397
+#  undef XLAT_VAL_397
+#  undef XLAT_STR_398
+#  undef XLAT_VAL_398
+#  undef XLAT_STR_399
+#  undef XLAT_VAL_399
+#  undef XLAT_STR_400
+#  undef XLAT_VAL_400
+#  undef XLAT_STR_401
+#  undef XLAT_VAL_401
+#  undef XLAT_STR_402
+#  undef XLAT_VAL_402
+#  undef XLAT_STR_403
+#  undef XLAT_VAL_403
+#  undef XLAT_STR_404
+#  undef XLAT_VAL_404
+#  undef XLAT_STR_405
+#  undef XLAT_VAL_405
+#  undef XLAT_STR_406
+#  undef XLAT_VAL_406
+#  undef XLAT_STR_407
+#  undef XLAT_VAL_407
+#  undef XLAT_STR_408
+#  undef XLAT_VAL_408
+#  undef XLAT_STR_409
+#  undef XLAT_VAL_409
+#  undef XLAT_STR_410
+#  undef XLAT_VAL_410
+#  undef XLAT_STR_411
+#  undef XLAT_VAL_411
+#  undef XLAT_STR_412
+#  undef XLAT_VAL_412
+#  undef XLAT_STR_413
+#  undef XLAT_VAL_413
+#  undef XLAT_STR_414
+#  undef XLAT_VAL_414
+#  undef XLAT_STR_415
+#  undef XLAT_VAL_415
+#  undef XLAT_STR_416
+#  undef XLAT_VAL_416
+#  undef XLAT_STR_417
+#  undef XLAT_VAL_417
+#  undef XLAT_STR_418
+#  undef XLAT_VAL_418
+#  undef XLAT_STR_419
+#  undef XLAT_VAL_419
+#  undef XLAT_STR_420
+#  undef XLAT_VAL_420
+#  undef XLAT_STR_421
+#  undef XLAT_VAL_421
+#  undef XLAT_STR_422
+#  undef XLAT_VAL_422
+#  undef XLAT_STR_423
+#  undef XLAT_VAL_423
+#  undef XLAT_STR_424
+#  undef XLAT_VAL_424
+#  undef XLAT_STR_425
+#  undef XLAT_VAL_425
+#  undef XLAT_STR_426
+#  undef XLAT_VAL_426
+#  undef XLAT_STR_427
+#  undef XLAT_VAL_427
+#  undef XLAT_STR_428
+#  undef XLAT_VAL_428
+#  undef XLAT_STR_429
+#  undef XLAT_VAL_429
+#  undef XLAT_STR_430
+#  undef XLAT_VAL_430
+#  undef XLAT_STR_431
+#  undef XLAT_VAL_431
+#  undef XLAT_STR_432
+#  undef XLAT_VAL_432
+#  undef XLAT_STR_433
+#  undef XLAT_VAL_433
+#  undef XLAT_STR_434
+#  undef XLAT_VAL_434
+#  undef XLAT_STR_435
+#  undef XLAT_VAL_435
+#  undef XLAT_STR_436
+#  undef XLAT_VAL_436
+#  undef XLAT_STR_437
+#  undef XLAT_VAL_437
+#  undef XLAT_STR_438
+#  undef XLAT_VAL_438
+#  undef XLAT_STR_439
+#  undef XLAT_VAL_439
+#  undef XLAT_STR_440
+#  undef XLAT_VAL_440
+#  undef XLAT_STR_441
+#  undef XLAT_VAL_441
+#  undef XLAT_STR_442
+#  undef XLAT_VAL_442
+#  undef XLAT_STR_443
+#  undef XLAT_VAL_443
+#  undef XLAT_STR_444
+#  undef XLAT_VAL_444
+#  undef XLAT_STR_445
+#  undef XLAT_VAL_445
+#  undef XLAT_STR_446
+#  undef XLAT_VAL_446
+#  undef XLAT_STR_447
+#  undef XLAT_VAL_447
+#  undef XLAT_STR_448
+#  undef XLAT_VAL_448
+#  undef XLAT_STR_449
+#  undef XLAT_VAL_449
+#  undef XLAT_STR_450
+#  undef XLAT_VAL_450
+#  undef XLAT_STR_451
+#  undef XLAT_VAL_451
+#  undef XLAT_STR_452
+#  undef XLAT_VAL_452
+#  undef XLAT_STR_453
+#  undef XLAT_VAL_453
+#  undef XLAT_STR_454
+#  undef XLAT_VAL_454
+#  undef XLAT_STR_455
+#  undef XLAT_VAL_455
+#  undef XLAT_STR_456
+#  undef XLAT_VAL_456
+#  undef XLAT_STR_457
+#  undef XLAT_VAL_457
+#  undef XLAT_STR_458
+#  undef XLAT_VAL_458
+#  undef XLAT_STR_459
+#  undef XLAT_VAL_459
+#  undef XLAT_STR_460
+#  undef XLAT_VAL_460
+#  undef XLAT_STR_461
+#  undef XLAT_VAL_461
+#  undef XLAT_STR_462
+#  undef XLAT_VAL_462
+#  undef XLAT_STR_463
+#  undef XLAT_VAL_463
+#  undef XLAT_STR_464
+#  undef XLAT_VAL_464
+#  undef XLAT_STR_465
+#  undef XLAT_VAL_465
+#  undef XLAT_STR_466
+#  undef XLAT_VAL_466
+#  undef XLAT_STR_467
+#  undef XLAT_VAL_467
+#  undef XLAT_STR_468
+#  undef XLAT_VAL_468
+#  undef XLAT_STR_469
+#  undef XLAT_VAL_469
+#  undef XLAT_STR_470
+#  undef XLAT_VAL_470
+#  undef XLAT_STR_471
+#  undef XLAT_VAL_471
+#  undef XLAT_STR_472
+#  undef XLAT_VAL_472
+#  undef XLAT_STR_473
+#  undef XLAT_VAL_473
+#  undef XLAT_STR_474
+#  undef XLAT_VAL_474
+#  undef XLAT_STR_475
+#  undef XLAT_VAL_475
+#  undef XLAT_STR_476
+#  undef XLAT_VAL_476
+#  undef XLAT_STR_477
+#  undef XLAT_VAL_477
+#  undef XLAT_STR_478
+#  undef XLAT_VAL_478
+#  undef XLAT_STR_479
+#  undef XLAT_VAL_479
+#  undef XLAT_STR_480
+#  undef XLAT_VAL_480
+#  undef XLAT_STR_481
+#  undef XLAT_VAL_481
+#  undef XLAT_STR_482
+#  undef XLAT_VAL_482
+#  undef XLAT_STR_483
+#  undef XLAT_VAL_483
+#  undef XLAT_STR_484
+#  undef XLAT_VAL_484
+#  undef XLAT_STR_485
+#  undef XLAT_VAL_485
+#  undef XLAT_STR_486
+#  undef XLAT_VAL_486
+#  undef XLAT_STR_487
+#  undef XLAT_VAL_487
+#  undef XLAT_STR_488
+#  undef XLAT_VAL_488
+#  undef XLAT_STR_489
+#  undef XLAT_VAL_489
+#  undef XLAT_STR_490
+#  undef XLAT_VAL_490
+#  undef XLAT_STR_491
+#  undef XLAT_VAL_491
+#  undef XLAT_STR_492
+#  undef XLAT_VAL_492
+#  undef XLAT_STR_493
+#  undef XLAT_VAL_493
+#  undef XLAT_STR_494
+#  undef XLAT_VAL_494
+#  undef XLAT_STR_495
+#  undef XLAT_VAL_495
+#  undef XLAT_STR_496
+#  undef XLAT_VAL_496
+#  undef XLAT_STR_497
+#  undef XLAT_VAL_497
+#  undef XLAT_STR_498
+#  undef XLAT_VAL_498
+#  undef XLAT_STR_499
+#  undef XLAT_VAL_499
+#  undef XLAT_STR_500
+#  undef XLAT_VAL_500
+#  undef XLAT_STR_501
+#  undef XLAT_VAL_501
+#  undef XLAT_STR_502
+#  undef XLAT_VAL_502
+#  undef XLAT_STR_503
+#  undef XLAT_VAL_503
+#  undef XLAT_STR_504
+#  undef XLAT_VAL_504
+#  undef XLAT_STR_505
+#  undef XLAT_VAL_505
+#  undef XLAT_STR_506
+#  undef XLAT_VAL_506
+#  undef XLAT_STR_507
+#  undef XLAT_VAL_507
+#  undef XLAT_STR_508
+#  undef XLAT_VAL_508
+#  undef XLAT_STR_509
+#  undef XLAT_VAL_509
+#  undef XLAT_STR_510
+#  undef XLAT_VAL_510
+#  undef XLAT_STR_511
+#  undef XLAT_VAL_511
+#  undef XLAT_STR_512
+#  undef XLAT_VAL_512
+#  undef XLAT_STR_513
+#  undef XLAT_VAL_513
+#  undef XLAT_STR_514
+#  undef XLAT_VAL_514
+#  undef XLAT_STR_515
+#  undef XLAT_VAL_515
+#  undef XLAT_STR_516
+#  undef XLAT_VAL_516
+#  undef XLAT_STR_517
+#  undef XLAT_VAL_517
+#  undef XLAT_STR_518
+#  undef XLAT_VAL_518
+#  undef XLAT_STR_519
+#  undef XLAT_VAL_519
+#  undef XLAT_STR_520
+#  undef XLAT_VAL_520
+#  undef XLAT_STR_521
+#  undef XLAT_VAL_521
+#  undef XLAT_STR_522
+#  undef XLAT_VAL_522
+#  undef XLAT_STR_523
+#  undef XLAT_VAL_523
+#  undef XLAT_STR_524
+#  undef XLAT_VAL_524
+#  undef XLAT_STR_525
+#  undef XLAT_VAL_525
+#  undef XLAT_STR_526
+#  undef XLAT_VAL_526
+#  undef XLAT_STR_527
+#  undef XLAT_VAL_527
+#  undef XLAT_STR_528
+#  undef XLAT_VAL_528
+#  undef XLAT_STR_529
+#  undef XLAT_VAL_529
+#  undef XLAT_STR_530
+#  undef XLAT_VAL_530
+#  undef XLAT_STR_531
+#  undef XLAT_VAL_531
+#  undef XLAT_STR_532
+#  undef XLAT_VAL_532
+#  undef XLAT_STR_533
+#  undef XLAT_VAL_533
+#  undef XLAT_STR_534
+#  undef XLAT_VAL_534
+#  undef XLAT_STR_535
+#  undef XLAT_VAL_535
+#  undef XLAT_STR_536
+#  undef XLAT_VAL_536
+#  undef XLAT_STR_537
+#  undef XLAT_VAL_537
+#  undef XLAT_STR_538
+#  undef XLAT_VAL_538
+#  undef XLAT_STR_539
+#  undef XLAT_VAL_539
+#  undef XLAT_STR_540
+#  undef XLAT_VAL_540
+#  undef XLAT_STR_541
+#  undef XLAT_VAL_541
+#  undef XLAT_STR_542
+#  undef XLAT_VAL_542
+#  undef XLAT_STR_543
+#  undef XLAT_VAL_543
+#  undef XLAT_STR_544
+#  undef XLAT_VAL_544
+#  undef XLAT_STR_545
+#  undef XLAT_VAL_545
+#  undef XLAT_STR_546
+#  undef XLAT_VAL_546
+#  undef XLAT_STR_547
+#  undef XLAT_VAL_547
+#  undef XLAT_STR_548
+#  undef XLAT_VAL_548
+#  undef XLAT_STR_549
+#  undef XLAT_VAL_549
+#  undef XLAT_STR_550
+#  undef XLAT_VAL_550
+#  undef XLAT_STR_551
+#  undef XLAT_VAL_551
+#  undef XLAT_STR_552
+#  undef XLAT_VAL_552
+#  undef XLAT_STR_553
+#  undef XLAT_VAL_553
+#  undef XLAT_STR_554
+#  undef XLAT_VAL_554
+#  undef XLAT_STR_555
+#  undef XLAT_VAL_555
+#  undef XLAT_STR_556
+#  undef XLAT_VAL_556
+#  undef XLAT_STR_557
+#  undef XLAT_VAL_557
+#  undef XLAT_STR_558
+#  undef XLAT_VAL_558
+#  undef XLAT_STR_559
+#  undef XLAT_VAL_559
+#  undef XLAT_STR_560
+#  undef XLAT_VAL_560
+#  undef XLAT_STR_561
+#  undef XLAT_VAL_561
+#  undef XLAT_STR_562
+#  undef XLAT_VAL_562
+#  undef XLAT_STR_563
+#  undef XLAT_VAL_563
+#  undef XLAT_STR_564
+#  undef XLAT_VAL_564
+#  undef XLAT_STR_565
+#  undef XLAT_VAL_565
+#  undef XLAT_STR_566
+#  undef XLAT_VAL_566
+#  undef XLAT_STR_567
+#  undef XLAT_VAL_567
+#  undef XLAT_STR_568
+#  undef XLAT_VAL_568
+#  undef XLAT_STR_569
+#  undef XLAT_VAL_569
+#  undef XLAT_STR_570
+#  undef XLAT_VAL_570
+#  undef XLAT_STR_571
+#  undef XLAT_VAL_571
+#  undef XLAT_STR_572
+#  undef XLAT_VAL_572
+#  undef XLAT_STR_573
+#  undef XLAT_VAL_573
+#  undef XLAT_STR_574
+#  undef XLAT_VAL_574
+#  undef XLAT_STR_575
+#  undef XLAT_VAL_575
+#  undef XLAT_STR_576
+#  undef XLAT_VAL_576
+#  undef XLAT_STR_577
+#  undef XLAT_VAL_577
+#  undef XLAT_STR_578
+#  undef XLAT_VAL_578
+#  undef XLAT_STR_579
+#  undef XLAT_VAL_579
+#  undef XLAT_STR_580
+#  undef XLAT_VAL_580
+#  undef XLAT_STR_581
+#  undef XLAT_VAL_581
+#  undef XLAT_STR_582
+#  undef XLAT_VAL_582
+#  undef XLAT_STR_583
+#  undef XLAT_VAL_583
+#  undef XLAT_STR_584
+#  undef XLAT_VAL_584
+#  undef XLAT_STR_585
+#  undef XLAT_VAL_585
+#  undef XLAT_STR_586
+#  undef XLAT_VAL_586
+#  undef XLAT_STR_587
+#  undef XLAT_VAL_587
+#  undef XLAT_STR_588
+#  undef XLAT_VAL_588
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/evdev_keycode.in 5.9-0ubuntu2/xlat/evdev_keycode.in
--- 5.5-3/xlat/evdev_keycode.in	2020-01-21 18:02:38.000000000 +0000
+++ 5.9-0ubuntu2/xlat/evdev_keycode.in	2020-03-29 16:51:45.000000000 +0000
@@ -586,6 +586,8 @@ KEY_DATA			0x277
 KEY_ONSCREEN_KEYBOARD		0x278
 KEY_PRIVACY_SCREEN_TOGGLE	0x279
 
+KEY_SELECTIVE_SCREENSHOT	0x27a
+
 KEY_MACRO1			0x290
 KEY_MACRO2			0x291
 KEY_MACRO3			0x292
diff -pruN 5.5-3/xlat/evdev_leds.h 5.9-0ubuntu2/xlat/evdev_leds.h
--- 5.5-3/xlat/evdev_leds.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/evdev_leds.h	2020-09-24 09:18:44.000000000 +0000
@@ -91,24 +91,138 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data evdev_leds_xdata[] = {
  [LED_NUML] = XLAT(LED_NUML),
+ #define XLAT_VAL_0 ((unsigned) (LED_NUML))
+ #define XLAT_STR_0 STRINGIFY(LED_NUML)
  [LED_CAPSL] = XLAT(LED_CAPSL),
+ #define XLAT_VAL_1 ((unsigned) (LED_CAPSL))
+ #define XLAT_STR_1 STRINGIFY(LED_CAPSL)
  [LED_SCROLLL] = XLAT(LED_SCROLLL),
+ #define XLAT_VAL_2 ((unsigned) (LED_SCROLLL))
+ #define XLAT_STR_2 STRINGIFY(LED_SCROLLL)
  [LED_COMPOSE] = XLAT(LED_COMPOSE),
+ #define XLAT_VAL_3 ((unsigned) (LED_COMPOSE))
+ #define XLAT_STR_3 STRINGIFY(LED_COMPOSE)
  [LED_KANA] = XLAT(LED_KANA),
+ #define XLAT_VAL_4 ((unsigned) (LED_KANA))
+ #define XLAT_STR_4 STRINGIFY(LED_KANA)
  [LED_SLEEP] = XLAT(LED_SLEEP),
+ #define XLAT_VAL_5 ((unsigned) (LED_SLEEP))
+ #define XLAT_STR_5 STRINGIFY(LED_SLEEP)
  [LED_SUSPEND] = XLAT(LED_SUSPEND),
+ #define XLAT_VAL_6 ((unsigned) (LED_SUSPEND))
+ #define XLAT_STR_6 STRINGIFY(LED_SUSPEND)
  [LED_MUTE] = XLAT(LED_MUTE),
+ #define XLAT_VAL_7 ((unsigned) (LED_MUTE))
+ #define XLAT_STR_7 STRINGIFY(LED_MUTE)
  [LED_MISC] = XLAT(LED_MISC),
+ #define XLAT_VAL_8 ((unsigned) (LED_MISC))
+ #define XLAT_STR_8 STRINGIFY(LED_MISC)
  [LED_MAIL] = XLAT(LED_MAIL),
+ #define XLAT_VAL_9 ((unsigned) (LED_MAIL))
+ #define XLAT_STR_9 STRINGIFY(LED_MAIL)
  [LED_CHARGING] = XLAT(LED_CHARGING),
+ #define XLAT_VAL_10 ((unsigned) (LED_CHARGING))
+ #define XLAT_STR_10 STRINGIFY(LED_CHARGING)
 };
 static
 const struct xlat evdev_leds[1] = { {
  .data = evdev_leds_xdata,
  .size = ARRAY_SIZE(evdev_leds_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/evdev_misc.h 5.9-0ubuntu2/xlat/evdev_misc.h
--- 5.5-3/xlat/evdev_misc.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/evdev_misc.h	2020-09-24 09:18:44.000000000 +0000
@@ -56,19 +56,83 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data evdev_misc_xdata[] = {
  [MSC_SERIAL] = XLAT(MSC_SERIAL),
+ #define XLAT_VAL_0 ((unsigned) (MSC_SERIAL))
+ #define XLAT_STR_0 STRINGIFY(MSC_SERIAL)
  [MSC_PULSELED] = XLAT(MSC_PULSELED),
+ #define XLAT_VAL_1 ((unsigned) (MSC_PULSELED))
+ #define XLAT_STR_1 STRINGIFY(MSC_PULSELED)
  [MSC_GESTURE] = XLAT(MSC_GESTURE),
+ #define XLAT_VAL_2 ((unsigned) (MSC_GESTURE))
+ #define XLAT_STR_2 STRINGIFY(MSC_GESTURE)
  [MSC_RAW] = XLAT(MSC_RAW),
+ #define XLAT_VAL_3 ((unsigned) (MSC_RAW))
+ #define XLAT_STR_3 STRINGIFY(MSC_RAW)
  [MSC_SCAN] = XLAT(MSC_SCAN),
+ #define XLAT_VAL_4 ((unsigned) (MSC_SCAN))
+ #define XLAT_STR_4 STRINGIFY(MSC_SCAN)
  [MSC_TIMESTAMP] = XLAT(MSC_TIMESTAMP),
+ #define XLAT_VAL_5 ((unsigned) (MSC_TIMESTAMP))
+ #define XLAT_STR_5 STRINGIFY(MSC_TIMESTAMP)
 };
 static
 const struct xlat evdev_misc[1] = { {
  .data = evdev_misc_xdata,
  .size = ARRAY_SIZE(evdev_misc_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/evdev_mtslots.h 5.9-0ubuntu2/xlat/evdev_mtslots.h
--- 5.5-3/xlat/evdev_mtslots.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/evdev_mtslots.h	2020-09-24 09:18:44.000000000 +0000
@@ -119,28 +119,182 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data evdev_mtslots_xdata[] = {
  XLAT(ABS_MT_SLOT),
+ #define XLAT_VAL_0 ((unsigned) (ABS_MT_SLOT))
+ #define XLAT_STR_0 STRINGIFY(ABS_MT_SLOT)
  XLAT(ABS_MT_TOUCH_MAJOR),
+ #define XLAT_VAL_1 ((unsigned) (ABS_MT_TOUCH_MAJOR))
+ #define XLAT_STR_1 STRINGIFY(ABS_MT_TOUCH_MAJOR)
  XLAT(ABS_MT_TOUCH_MINOR),
+ #define XLAT_VAL_2 ((unsigned) (ABS_MT_TOUCH_MINOR))
+ #define XLAT_STR_2 STRINGIFY(ABS_MT_TOUCH_MINOR)
  XLAT(ABS_MT_WIDTH_MAJOR),
+ #define XLAT_VAL_3 ((unsigned) (ABS_MT_WIDTH_MAJOR))
+ #define XLAT_STR_3 STRINGIFY(ABS_MT_WIDTH_MAJOR)
  XLAT(ABS_MT_WIDTH_MINOR),
+ #define XLAT_VAL_4 ((unsigned) (ABS_MT_WIDTH_MINOR))
+ #define XLAT_STR_4 STRINGIFY(ABS_MT_WIDTH_MINOR)
  XLAT(ABS_MT_ORIENTATION),
+ #define XLAT_VAL_5 ((unsigned) (ABS_MT_ORIENTATION))
+ #define XLAT_STR_5 STRINGIFY(ABS_MT_ORIENTATION)
  XLAT(ABS_MT_POSITION_X),
+ #define XLAT_VAL_6 ((unsigned) (ABS_MT_POSITION_X))
+ #define XLAT_STR_6 STRINGIFY(ABS_MT_POSITION_X)
  XLAT(ABS_MT_POSITION_Y),
+ #define XLAT_VAL_7 ((unsigned) (ABS_MT_POSITION_Y))
+ #define XLAT_STR_7 STRINGIFY(ABS_MT_POSITION_Y)
  XLAT(ABS_MT_TOOL_TYPE),
+ #define XLAT_VAL_8 ((unsigned) (ABS_MT_TOOL_TYPE))
+ #define XLAT_STR_8 STRINGIFY(ABS_MT_TOOL_TYPE)
  XLAT(ABS_MT_BLOB_ID),
+ #define XLAT_VAL_9 ((unsigned) (ABS_MT_BLOB_ID))
+ #define XLAT_STR_9 STRINGIFY(ABS_MT_BLOB_ID)
  XLAT(ABS_MT_TRACKING_ID),
+ #define XLAT_VAL_10 ((unsigned) (ABS_MT_TRACKING_ID))
+ #define XLAT_STR_10 STRINGIFY(ABS_MT_TRACKING_ID)
  XLAT(ABS_MT_PRESSURE),
+ #define XLAT_VAL_11 ((unsigned) (ABS_MT_PRESSURE))
+ #define XLAT_STR_11 STRINGIFY(ABS_MT_PRESSURE)
  XLAT(ABS_MT_DISTANCE),
+ #define XLAT_VAL_12 ((unsigned) (ABS_MT_DISTANCE))
+ #define XLAT_STR_12 STRINGIFY(ABS_MT_DISTANCE)
  XLAT(ABS_MT_TOOL_X),
+ #define XLAT_VAL_13 ((unsigned) (ABS_MT_TOOL_X))
+ #define XLAT_STR_13 STRINGIFY(ABS_MT_TOOL_X)
  XLAT(ABS_MT_TOOL_Y),
+ #define XLAT_VAL_14 ((unsigned) (ABS_MT_TOOL_Y))
+ #define XLAT_STR_14 STRINGIFY(ABS_MT_TOOL_Y)
 };
 static
 const struct xlat evdev_mtslots[1] = { {
  .data = evdev_mtslots_xdata,
  .size = ARRAY_SIZE(evdev_mtslots_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/evdev_prop.h 5.9-0ubuntu2/xlat/evdev_prop.h
--- 5.5-3/xlat/evdev_prop.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/evdev_prop.h	2020-09-24 09:18:44.000000000 +0000
@@ -63,20 +63,94 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data evdev_prop_xdata[] = {
  [INPUT_PROP_POINTER] = XLAT(INPUT_PROP_POINTER),
+ #define XLAT_VAL_0 ((unsigned) (INPUT_PROP_POINTER))
+ #define XLAT_STR_0 STRINGIFY(INPUT_PROP_POINTER)
  [INPUT_PROP_DIRECT] = XLAT(INPUT_PROP_DIRECT),
+ #define XLAT_VAL_1 ((unsigned) (INPUT_PROP_DIRECT))
+ #define XLAT_STR_1 STRINGIFY(INPUT_PROP_DIRECT)
  [INPUT_PROP_BUTTONPAD] = XLAT(INPUT_PROP_BUTTONPAD),
+ #define XLAT_VAL_2 ((unsigned) (INPUT_PROP_BUTTONPAD))
+ #define XLAT_STR_2 STRINGIFY(INPUT_PROP_BUTTONPAD)
  [INPUT_PROP_SEMI_MT] = XLAT(INPUT_PROP_SEMI_MT),
+ #define XLAT_VAL_3 ((unsigned) (INPUT_PROP_SEMI_MT))
+ #define XLAT_STR_3 STRINGIFY(INPUT_PROP_SEMI_MT)
  [INPUT_PROP_TOPBUTTONPAD] = XLAT(INPUT_PROP_TOPBUTTONPAD),
+ #define XLAT_VAL_4 ((unsigned) (INPUT_PROP_TOPBUTTONPAD))
+ #define XLAT_STR_4 STRINGIFY(INPUT_PROP_TOPBUTTONPAD)
  [INPUT_PROP_POINTING_STICK] = XLAT(INPUT_PROP_POINTING_STICK),
+ #define XLAT_VAL_5 ((unsigned) (INPUT_PROP_POINTING_STICK))
+ #define XLAT_STR_5 STRINGIFY(INPUT_PROP_POINTING_STICK)
  [INPUT_PROP_ACCELEROMETER] = XLAT(INPUT_PROP_ACCELEROMETER),
+ #define XLAT_VAL_6 ((unsigned) (INPUT_PROP_ACCELEROMETER))
+ #define XLAT_STR_6 STRINGIFY(INPUT_PROP_ACCELEROMETER)
 };
 static
 const struct xlat evdev_prop[1] = { {
  .data = evdev_prop_xdata,
  .size = ARRAY_SIZE(evdev_prop_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/evdev_relative_axes.h 5.9-0ubuntu2/xlat/evdev_relative_axes.h
--- 5.5-3/xlat/evdev_relative_axes.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/evdev_relative_axes.h	2020-09-24 09:18:44.000000000 +0000
@@ -105,26 +105,160 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data evdev_relative_axes_xdata[] = {
  [REL_X] = XLAT(REL_X),
+ #define XLAT_VAL_0 ((unsigned) (REL_X))
+ #define XLAT_STR_0 STRINGIFY(REL_X)
  [REL_Y] = XLAT(REL_Y),
+ #define XLAT_VAL_1 ((unsigned) (REL_Y))
+ #define XLAT_STR_1 STRINGIFY(REL_Y)
  [REL_Z] = XLAT(REL_Z),
+ #define XLAT_VAL_2 ((unsigned) (REL_Z))
+ #define XLAT_STR_2 STRINGIFY(REL_Z)
  [REL_RX] = XLAT(REL_RX),
+ #define XLAT_VAL_3 ((unsigned) (REL_RX))
+ #define XLAT_STR_3 STRINGIFY(REL_RX)
  [REL_RY] = XLAT(REL_RY),
+ #define XLAT_VAL_4 ((unsigned) (REL_RY))
+ #define XLAT_STR_4 STRINGIFY(REL_RY)
  [REL_RZ] = XLAT(REL_RZ),
+ #define XLAT_VAL_5 ((unsigned) (REL_RZ))
+ #define XLAT_STR_5 STRINGIFY(REL_RZ)
  [REL_HWHEEL] = XLAT(REL_HWHEEL),
+ #define XLAT_VAL_6 ((unsigned) (REL_HWHEEL))
+ #define XLAT_STR_6 STRINGIFY(REL_HWHEEL)
  [REL_DIAL] = XLAT(REL_DIAL),
+ #define XLAT_VAL_7 ((unsigned) (REL_DIAL))
+ #define XLAT_STR_7 STRINGIFY(REL_DIAL)
  [REL_WHEEL] = XLAT(REL_WHEEL),
+ #define XLAT_VAL_8 ((unsigned) (REL_WHEEL))
+ #define XLAT_STR_8 STRINGIFY(REL_WHEEL)
  [REL_MISC] = XLAT(REL_MISC),
+ #define XLAT_VAL_9 ((unsigned) (REL_MISC))
+ #define XLAT_STR_9 STRINGIFY(REL_MISC)
  [REL_RESERVED] = XLAT(REL_RESERVED),
+ #define XLAT_VAL_10 ((unsigned) (REL_RESERVED))
+ #define XLAT_STR_10 STRINGIFY(REL_RESERVED)
  [REL_WHEEL_HI_RES] = XLAT(REL_WHEEL_HI_RES),
+ #define XLAT_VAL_11 ((unsigned) (REL_WHEEL_HI_RES))
+ #define XLAT_STR_11 STRINGIFY(REL_WHEEL_HI_RES)
  [REL_HWHEEL_HI_RES] = XLAT(REL_HWHEEL_HI_RES),
+ #define XLAT_VAL_12 ((unsigned) (REL_HWHEEL_HI_RES))
+ #define XLAT_STR_12 STRINGIFY(REL_HWHEEL_HI_RES)
 };
 static
 const struct xlat evdev_relative_axes[1] = { {
  .data = evdev_relative_axes_xdata,
  .size = ARRAY_SIZE(evdev_relative_axes_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/evdev_snd.h 5.9-0ubuntu2/xlat/evdev_snd.h
--- 5.5-3/xlat/evdev_snd.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/evdev_snd.h	2020-09-24 09:18:44.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data evdev_snd_xdata[] = {
  [SND_CLICK] = XLAT(SND_CLICK),
+ #define XLAT_VAL_0 ((unsigned) (SND_CLICK))
+ #define XLAT_STR_0 STRINGIFY(SND_CLICK)
  [SND_BELL] = XLAT(SND_BELL),
+ #define XLAT_VAL_1 ((unsigned) (SND_BELL))
+ #define XLAT_STR_1 STRINGIFY(SND_BELL)
  [SND_TONE] = XLAT(SND_TONE),
+ #define XLAT_VAL_2 ((unsigned) (SND_TONE))
+ #define XLAT_STR_2 STRINGIFY(SND_TONE)
 };
 static
 const struct xlat evdev_snd[1] = { {
  .data = evdev_snd_xdata,
  .size = ARRAY_SIZE(evdev_snd_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/evdev_switch.h 5.9-0ubuntu2/xlat/evdev_switch.h
--- 5.5-3/xlat/evdev_switch.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/evdev_switch.h	2020-09-24 09:18:45.000000000 +0000
@@ -126,29 +126,193 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data evdev_switch_xdata[] = {
  [SW_LID] = XLAT(SW_LID),
+ #define XLAT_VAL_0 ((unsigned) (SW_LID))
+ #define XLAT_STR_0 STRINGIFY(SW_LID)
  [SW_TABLET_MODE] = XLAT(SW_TABLET_MODE),
+ #define XLAT_VAL_1 ((unsigned) (SW_TABLET_MODE))
+ #define XLAT_STR_1 STRINGIFY(SW_TABLET_MODE)
  [SW_HEADPHONE_INSERT] = XLAT(SW_HEADPHONE_INSERT),
+ #define XLAT_VAL_2 ((unsigned) (SW_HEADPHONE_INSERT))
+ #define XLAT_STR_2 STRINGIFY(SW_HEADPHONE_INSERT)
  [SW_RFKILL_ALL] = XLAT(SW_RFKILL_ALL),
+ #define XLAT_VAL_3 ((unsigned) (SW_RFKILL_ALL))
+ #define XLAT_STR_3 STRINGIFY(SW_RFKILL_ALL)
  [SW_MICROPHONE_INSERT] = XLAT(SW_MICROPHONE_INSERT),
+ #define XLAT_VAL_4 ((unsigned) (SW_MICROPHONE_INSERT))
+ #define XLAT_STR_4 STRINGIFY(SW_MICROPHONE_INSERT)
  [SW_DOCK] = XLAT(SW_DOCK),
+ #define XLAT_VAL_5 ((unsigned) (SW_DOCK))
+ #define XLAT_STR_5 STRINGIFY(SW_DOCK)
  [SW_LINEOUT_INSERT] = XLAT(SW_LINEOUT_INSERT),
+ #define XLAT_VAL_6 ((unsigned) (SW_LINEOUT_INSERT))
+ #define XLAT_STR_6 STRINGIFY(SW_LINEOUT_INSERT)
  [SW_JACK_PHYSICAL_INSERT] = XLAT(SW_JACK_PHYSICAL_INSERT),
+ #define XLAT_VAL_7 ((unsigned) (SW_JACK_PHYSICAL_INSERT))
+ #define XLAT_STR_7 STRINGIFY(SW_JACK_PHYSICAL_INSERT)
  [SW_VIDEOOUT_INSERT] = XLAT(SW_VIDEOOUT_INSERT),
+ #define XLAT_VAL_8 ((unsigned) (SW_VIDEOOUT_INSERT))
+ #define XLAT_STR_8 STRINGIFY(SW_VIDEOOUT_INSERT)
  [SW_CAMERA_LENS_COVER] = XLAT(SW_CAMERA_LENS_COVER),
+ #define XLAT_VAL_9 ((unsigned) (SW_CAMERA_LENS_COVER))
+ #define XLAT_STR_9 STRINGIFY(SW_CAMERA_LENS_COVER)
  [SW_KEYPAD_SLIDE] = XLAT(SW_KEYPAD_SLIDE),
+ #define XLAT_VAL_10 ((unsigned) (SW_KEYPAD_SLIDE))
+ #define XLAT_STR_10 STRINGIFY(SW_KEYPAD_SLIDE)
  [SW_FRONT_PROXIMITY] = XLAT(SW_FRONT_PROXIMITY),
+ #define XLAT_VAL_11 ((unsigned) (SW_FRONT_PROXIMITY))
+ #define XLAT_STR_11 STRINGIFY(SW_FRONT_PROXIMITY)
  [SW_ROTATE_LOCK] = XLAT(SW_ROTATE_LOCK),
+ #define XLAT_VAL_12 ((unsigned) (SW_ROTATE_LOCK))
+ #define XLAT_STR_12 STRINGIFY(SW_ROTATE_LOCK)
  [SW_LINEIN_INSERT] = XLAT(SW_LINEIN_INSERT),
+ #define XLAT_VAL_13 ((unsigned) (SW_LINEIN_INSERT))
+ #define XLAT_STR_13 STRINGIFY(SW_LINEIN_INSERT)
  [SW_MUTE_DEVICE] = XLAT(SW_MUTE_DEVICE),
+ #define XLAT_VAL_14 ((unsigned) (SW_MUTE_DEVICE))
+ #define XLAT_STR_14 STRINGIFY(SW_MUTE_DEVICE)
  [SW_PEN_INSERTED] = XLAT(SW_PEN_INSERTED),
+ #define XLAT_VAL_15 ((unsigned) (SW_PEN_INSERTED))
+ #define XLAT_STR_15 STRINGIFY(SW_PEN_INSERTED)
 };
 static
 const struct xlat evdev_switch[1] = { {
  .data = evdev_switch_xdata,
  .size = ARRAY_SIZE(evdev_switch_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/faccessat_flags.h 5.9-0ubuntu2/xlat/faccessat_flags.h
--- 5.5-3/xlat/faccessat_flags.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/faccessat_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -0,0 +1,84 @@
+/* Generated by ./xlat/gen.sh from ./xlat/faccessat_flags.in; do not edit. */
+
+#include "gcc_compat.h"
+#include "static_assert.h"
+
+#if defined(AT_SYMLINK_NOFOLLOW) || (defined(HAVE_DECL_AT_SYMLINK_NOFOLLOW) && HAVE_DECL_AT_SYMLINK_NOFOLLOW)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((AT_SYMLINK_NOFOLLOW) == (0x100), "AT_SYMLINK_NOFOLLOW != 0x100");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define AT_SYMLINK_NOFOLLOW 0x100
+#endif
+#if defined(AT_EACCESS) || (defined(HAVE_DECL_AT_EACCESS) && HAVE_DECL_AT_EACCESS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((AT_EACCESS) == (0x200), "AT_EACCESS != 0x200");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define AT_EACCESS 0x200
+#endif
+#if defined(AT_EMPTY_PATH) || (defined(HAVE_DECL_AT_EMPTY_PATH) && HAVE_DECL_AT_EMPTY_PATH)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((AT_EMPTY_PATH) == (0x1000), "AT_EMPTY_PATH != 0x1000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define AT_EMPTY_PATH 0x1000
+#endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+#  error static const struct xlat faccessat_flags in mpers mode
+
+# else
+
+static const struct xlat_data faccessat_flags_xdata[] = {
+ XLAT(AT_SYMLINK_NOFOLLOW),
+ #define XLAT_VAL_0 ((unsigned) (AT_SYMLINK_NOFOLLOW))
+ #define XLAT_STR_0 STRINGIFY(AT_SYMLINK_NOFOLLOW)
+ XLAT(AT_EACCESS),
+ #define XLAT_VAL_1 ((unsigned) (AT_EACCESS))
+ #define XLAT_STR_1 STRINGIFY(AT_EACCESS)
+ XLAT(AT_EMPTY_PATH),
+ #define XLAT_VAL_2 ((unsigned) (AT_EMPTY_PATH))
+ #define XLAT_STR_2 STRINGIFY(AT_EMPTY_PATH)
+};
+static
+const struct xlat faccessat_flags[1] = { {
+ .data = faccessat_flags_xdata,
+ .size = ARRAY_SIZE(faccessat_flags_xdata),
+ .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
+} };
+
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+# endif /* !IN_MPERS */
+
+#endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/faccessat_flags.in 5.9-0ubuntu2/xlat/faccessat_flags.in
--- 5.5-3/xlat/faccessat_flags.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/faccessat_flags.in	2020-07-04 08:00:00.000000000 +0000
@@ -0,0 +1,3 @@
+AT_SYMLINK_NOFOLLOW	0x100
+AT_EACCESS		0x200
+AT_EMPTY_PATH		0x1000
diff -pruN 5.5-3/xlat/falloc_flags.h 5.9-0ubuntu2/xlat/falloc_flags.h
--- 5.5-3/xlat/falloc_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/falloc_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -63,20 +63,94 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data falloc_flags_xdata[] = {
  XLAT(FALLOC_FL_KEEP_SIZE),
+ #define XLAT_VAL_0 ((unsigned) (FALLOC_FL_KEEP_SIZE))
+ #define XLAT_STR_0 STRINGIFY(FALLOC_FL_KEEP_SIZE)
  XLAT(FALLOC_FL_PUNCH_HOLE),
+ #define XLAT_VAL_1 ((unsigned) (FALLOC_FL_PUNCH_HOLE))
+ #define XLAT_STR_1 STRINGIFY(FALLOC_FL_PUNCH_HOLE)
  XLAT(FALLOC_FL_NO_HIDE_STALE),
+ #define XLAT_VAL_2 ((unsigned) (FALLOC_FL_NO_HIDE_STALE))
+ #define XLAT_STR_2 STRINGIFY(FALLOC_FL_NO_HIDE_STALE)
  XLAT(FALLOC_FL_COLLAPSE_RANGE),
+ #define XLAT_VAL_3 ((unsigned) (FALLOC_FL_COLLAPSE_RANGE))
+ #define XLAT_STR_3 STRINGIFY(FALLOC_FL_COLLAPSE_RANGE)
  XLAT(FALLOC_FL_ZERO_RANGE),
+ #define XLAT_VAL_4 ((unsigned) (FALLOC_FL_ZERO_RANGE))
+ #define XLAT_STR_4 STRINGIFY(FALLOC_FL_ZERO_RANGE)
  XLAT(FALLOC_FL_INSERT_RANGE),
+ #define XLAT_VAL_5 ((unsigned) (FALLOC_FL_INSERT_RANGE))
+ #define XLAT_STR_5 STRINGIFY(FALLOC_FL_INSERT_RANGE)
  XLAT(FALLOC_FL_UNSHARE_RANGE),
+ #define XLAT_VAL_6 ((unsigned) (FALLOC_FL_UNSHARE_RANGE))
+ #define XLAT_STR_6 STRINGIFY(FALLOC_FL_UNSHARE_RANGE)
 };
 static
 const struct xlat falloc_flags[1] = { {
  .data = falloc_flags_xdata,
  .size = ARRAY_SIZE(falloc_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/fan_classes.h 5.9-0ubuntu2/xlat/fan_classes.h
--- 5.5-3/xlat/fan_classes.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/fan_classes.h	2020-09-24 09:18:44.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data fan_classes_xdata[] = {
  XLAT(FAN_CLASS_NOTIF),
+ #define XLAT_VAL_0 ((unsigned) (FAN_CLASS_NOTIF))
+ #define XLAT_STR_0 STRINGIFY(FAN_CLASS_NOTIF)
  XLAT(FAN_CLASS_CONTENT),
+ #define XLAT_VAL_1 ((unsigned) (FAN_CLASS_CONTENT))
+ #define XLAT_STR_1 STRINGIFY(FAN_CLASS_CONTENT)
  XLAT(FAN_CLASS_PRE_CONTENT),
+ #define XLAT_VAL_2 ((unsigned) (FAN_CLASS_PRE_CONTENT))
+ #define XLAT_STR_2 STRINGIFY(FAN_CLASS_PRE_CONTENT)
 };
 static
 const struct xlat fan_classes[1] = { {
  .data = fan_classes_xdata,
  .size = ARRAY_SIZE(fan_classes_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/fan_event_flags.h 5.9-0ubuntu2/xlat/fan_event_flags.h
--- 5.5-3/xlat/fan_event_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/fan_event_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -122,6 +122,13 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define FAN_OPEN_EXEC_PERM 0x00040000
 #endif
+#if defined(FAN_DIR_MODIFY) || (defined(HAVE_DECL_FAN_DIR_MODIFY) && HAVE_DECL_FAN_DIR_MODIFY)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((FAN_DIR_MODIFY) == (0x00080000), "FAN_DIR_MODIFY != 0x00080000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define FAN_DIR_MODIFY 0x00080000
+#endif
 #if defined(FAN_ONDIR) || (defined(HAVE_DECL_FAN_ONDIR) && HAVE_DECL_FAN_ONDIR)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
 static_assert((FAN_ONDIR) == (0x40000000), "FAN_ONDIR != 0x40000000");
@@ -147,32 +154,237 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data fan_event_flags_xdata[] = {
  XLAT(FAN_ACCESS),
+ #define XLAT_VAL_0 ((unsigned) (FAN_ACCESS))
+ #define XLAT_STR_0 STRINGIFY(FAN_ACCESS)
  XLAT(FAN_MODIFY),
+ #define XLAT_VAL_1 ((unsigned) (FAN_MODIFY))
+ #define XLAT_STR_1 STRINGIFY(FAN_MODIFY)
  XLAT(FAN_ATTRIB),
+ #define XLAT_VAL_2 ((unsigned) (FAN_ATTRIB))
+ #define XLAT_STR_2 STRINGIFY(FAN_ATTRIB)
  XLAT(FAN_CLOSE_WRITE),
+ #define XLAT_VAL_3 ((unsigned) (FAN_CLOSE_WRITE))
+ #define XLAT_STR_3 STRINGIFY(FAN_CLOSE_WRITE)
  XLAT(FAN_CLOSE_NOWRITE),
+ #define XLAT_VAL_4 ((unsigned) (FAN_CLOSE_NOWRITE))
+ #define XLAT_STR_4 STRINGIFY(FAN_CLOSE_NOWRITE)
  XLAT(FAN_OPEN),
+ #define XLAT_VAL_5 ((unsigned) (FAN_OPEN))
+ #define XLAT_STR_5 STRINGIFY(FAN_OPEN)
  XLAT(FAN_MOVED_FROM),
+ #define XLAT_VAL_6 ((unsigned) (FAN_MOVED_FROM))
+ #define XLAT_STR_6 STRINGIFY(FAN_MOVED_FROM)
  XLAT(FAN_MOVED_TO),
+ #define XLAT_VAL_7 ((unsigned) (FAN_MOVED_TO))
+ #define XLAT_STR_7 STRINGIFY(FAN_MOVED_TO)
  XLAT(FAN_CREATE),
+ #define XLAT_VAL_8 ((unsigned) (FAN_CREATE))
+ #define XLAT_STR_8 STRINGIFY(FAN_CREATE)
  XLAT(FAN_DELETE),
+ #define XLAT_VAL_9 ((unsigned) (FAN_DELETE))
+ #define XLAT_STR_9 STRINGIFY(FAN_DELETE)
  XLAT(FAN_DELETE_SELF),
+ #define XLAT_VAL_10 ((unsigned) (FAN_DELETE_SELF))
+ #define XLAT_STR_10 STRINGIFY(FAN_DELETE_SELF)
  XLAT(FAN_MOVE_SELF),
+ #define XLAT_VAL_11 ((unsigned) (FAN_MOVE_SELF))
+ #define XLAT_STR_11 STRINGIFY(FAN_MOVE_SELF)
  XLAT(FAN_OPEN_EXEC),
+ #define XLAT_VAL_12 ((unsigned) (FAN_OPEN_EXEC))
+ #define XLAT_STR_12 STRINGIFY(FAN_OPEN_EXEC)
  XLAT(FAN_Q_OVERFLOW),
+ #define XLAT_VAL_13 ((unsigned) (FAN_Q_OVERFLOW))
+ #define XLAT_STR_13 STRINGIFY(FAN_Q_OVERFLOW)
  XLAT(FAN_OPEN_PERM),
+ #define XLAT_VAL_14 ((unsigned) (FAN_OPEN_PERM))
+ #define XLAT_STR_14 STRINGIFY(FAN_OPEN_PERM)
  XLAT(FAN_ACCESS_PERM),
+ #define XLAT_VAL_15 ((unsigned) (FAN_ACCESS_PERM))
+ #define XLAT_STR_15 STRINGIFY(FAN_ACCESS_PERM)
  XLAT(FAN_OPEN_EXEC_PERM),
+ #define XLAT_VAL_16 ((unsigned) (FAN_OPEN_EXEC_PERM))
+ #define XLAT_STR_16 STRINGIFY(FAN_OPEN_EXEC_PERM)
+ XLAT(FAN_DIR_MODIFY),
+ #define XLAT_VAL_17 ((unsigned) (FAN_DIR_MODIFY))
+ #define XLAT_STR_17 STRINGIFY(FAN_DIR_MODIFY)
  XLAT(FAN_ONDIR),
+ #define XLAT_VAL_18 ((unsigned) (FAN_ONDIR))
+ #define XLAT_STR_18 STRINGIFY(FAN_ONDIR)
  XLAT(FAN_EVENT_ON_CHILD),
+ #define XLAT_VAL_19 ((unsigned) (FAN_EVENT_ON_CHILD))
+ #define XLAT_STR_19 STRINGIFY(FAN_EVENT_ON_CHILD)
 };
 static
 const struct xlat fan_event_flags[1] = { {
  .data = fan_event_flags_xdata,
  .size = ARRAY_SIZE(fan_event_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/fan_event_flags.in 5.9-0ubuntu2/xlat/fan_event_flags.in
--- 5.5-3/xlat/fan_event_flags.in	2019-05-20 22:50:44.000000000 +0000
+++ 5.9-0ubuntu2/xlat/fan_event_flags.in	2020-04-15 13:39:57.000000000 +0000
@@ -15,5 +15,6 @@ FAN_Q_OVERFLOW		0x00004000
 FAN_OPEN_PERM		0x00010000
 FAN_ACCESS_PERM		0x00020000
 FAN_OPEN_EXEC_PERM	0x00040000
+FAN_DIR_MODIFY		0x00080000
 FAN_ONDIR		0x40000000
 FAN_EVENT_ON_CHILD	0x08000000
diff -pruN 5.5-3/xlat/fan_init_flags.h 5.9-0ubuntu2/xlat/fan_init_flags.h
--- 5.5-3/xlat/fan_init_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/fan_init_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -52,6 +52,20 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define FAN_REPORT_FID 0x00000200
 #endif
+#if defined(FAN_REPORT_DIR_FID) || (defined(HAVE_DECL_FAN_REPORT_DIR_FID) && HAVE_DECL_FAN_REPORT_DIR_FID)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((FAN_REPORT_DIR_FID) == (0x00000400), "FAN_REPORT_DIR_FID != 0x00000400");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define FAN_REPORT_DIR_FID 0x00000400
+#endif
+#if defined(FAN_REPORT_NAME) || (defined(HAVE_DECL_FAN_REPORT_NAME) && HAVE_DECL_FAN_REPORT_NAME)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((FAN_REPORT_NAME) == (0x00000800), "FAN_REPORT_NAME != 0x00000800");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define FAN_REPORT_NAME 0x00000800
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -63,20 +77,116 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data fan_init_flags_xdata[] = {
  XLAT(FAN_CLOEXEC),
+ #define XLAT_VAL_0 ((unsigned) (FAN_CLOEXEC))
+ #define XLAT_STR_0 STRINGIFY(FAN_CLOEXEC)
  XLAT(FAN_NONBLOCK),
+ #define XLAT_VAL_1 ((unsigned) (FAN_NONBLOCK))
+ #define XLAT_STR_1 STRINGIFY(FAN_NONBLOCK)
  XLAT(FAN_UNLIMITED_QUEUE),
+ #define XLAT_VAL_2 ((unsigned) (FAN_UNLIMITED_QUEUE))
+ #define XLAT_STR_2 STRINGIFY(FAN_UNLIMITED_QUEUE)
  XLAT(FAN_UNLIMITED_MARKS),
+ #define XLAT_VAL_3 ((unsigned) (FAN_UNLIMITED_MARKS))
+ #define XLAT_STR_3 STRINGIFY(FAN_UNLIMITED_MARKS)
  XLAT(FAN_ENABLE_AUDIT),
+ #define XLAT_VAL_4 ((unsigned) (FAN_ENABLE_AUDIT))
+ #define XLAT_STR_4 STRINGIFY(FAN_ENABLE_AUDIT)
  XLAT(FAN_REPORT_TID),
+ #define XLAT_VAL_5 ((unsigned) (FAN_REPORT_TID))
+ #define XLAT_STR_5 STRINGIFY(FAN_REPORT_TID)
  XLAT(FAN_REPORT_FID),
+ #define XLAT_VAL_6 ((unsigned) (FAN_REPORT_FID))
+ #define XLAT_STR_6 STRINGIFY(FAN_REPORT_FID)
+ XLAT(FAN_REPORT_DIR_FID),
+ #define XLAT_VAL_7 ((unsigned) (FAN_REPORT_DIR_FID))
+ #define XLAT_STR_7 STRINGIFY(FAN_REPORT_DIR_FID)
+ XLAT(FAN_REPORT_NAME),
+ #define XLAT_VAL_8 ((unsigned) (FAN_REPORT_NAME))
+ #define XLAT_STR_8 STRINGIFY(FAN_REPORT_NAME)
 };
 static
 const struct xlat fan_init_flags[1] = { {
  .data = fan_init_flags_xdata,
  .size = ARRAY_SIZE(fan_init_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/fan_init_flags.in 5.9-0ubuntu2/xlat/fan_init_flags.in
--- 5.5-3/xlat/fan_init_flags.in	2019-05-20 22:50:44.000000000 +0000
+++ 5.9-0ubuntu2/xlat/fan_init_flags.in	2020-09-06 08:00:00.000000000 +0000
@@ -5,3 +5,5 @@ FAN_UNLIMITED_MARKS 0x00000020
 FAN_ENABLE_AUDIT 0x00000040
 FAN_REPORT_TID 0x00000100
 FAN_REPORT_FID 0x00000200
+FAN_REPORT_DIR_FID 0x00000400
+FAN_REPORT_NAME 0x00000800
diff -pruN 5.5-3/xlat/fan_mark_flags.h 5.9-0ubuntu2/xlat/fan_mark_flags.h
--- 5.5-3/xlat/fan_mark_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/fan_mark_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -77,22 +77,116 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data fan_mark_flags_xdata[] = {
  XLAT(FAN_MARK_ADD),
+ #define XLAT_VAL_0 ((unsigned) (FAN_MARK_ADD))
+ #define XLAT_STR_0 STRINGIFY(FAN_MARK_ADD)
  XLAT(FAN_MARK_REMOVE),
+ #define XLAT_VAL_1 ((unsigned) (FAN_MARK_REMOVE))
+ #define XLAT_STR_1 STRINGIFY(FAN_MARK_REMOVE)
  XLAT(FAN_MARK_DONT_FOLLOW),
+ #define XLAT_VAL_2 ((unsigned) (FAN_MARK_DONT_FOLLOW))
+ #define XLAT_STR_2 STRINGIFY(FAN_MARK_DONT_FOLLOW)
  XLAT(FAN_MARK_ONLYDIR),
+ #define XLAT_VAL_3 ((unsigned) (FAN_MARK_ONLYDIR))
+ #define XLAT_STR_3 STRINGIFY(FAN_MARK_ONLYDIR)
  XLAT(FAN_MARK_MOUNT),
+ #define XLAT_VAL_4 ((unsigned) (FAN_MARK_MOUNT))
+ #define XLAT_STR_4 STRINGIFY(FAN_MARK_MOUNT)
  XLAT(FAN_MARK_IGNORED_MASK),
+ #define XLAT_VAL_5 ((unsigned) (FAN_MARK_IGNORED_MASK))
+ #define XLAT_STR_5 STRINGIFY(FAN_MARK_IGNORED_MASK)
  XLAT(FAN_MARK_IGNORED_SURV_MODIFY),
+ #define XLAT_VAL_6 ((unsigned) (FAN_MARK_IGNORED_SURV_MODIFY))
+ #define XLAT_STR_6 STRINGIFY(FAN_MARK_IGNORED_SURV_MODIFY)
  XLAT(FAN_MARK_FLUSH),
+ #define XLAT_VAL_7 ((unsigned) (FAN_MARK_FLUSH))
+ #define XLAT_STR_7 STRINGIFY(FAN_MARK_FLUSH)
  XLAT(FAN_MARK_FILESYSTEM),
+ #define XLAT_VAL_8 ((unsigned) (FAN_MARK_FILESYSTEM))
+ #define XLAT_STR_8 STRINGIFY(FAN_MARK_FILESYSTEM)
 };
 static
 const struct xlat fan_mark_flags[1] = { {
  .data = fan_mark_flags_xdata,
  .size = ARRAY_SIZE(fan_mark_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/fcntlcmds.h 5.9-0ubuntu2/xlat/fcntlcmds.h
--- 5.5-3/xlat/fcntlcmds.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/fcntlcmds.h	2020-09-24 09:18:45.000000000 +0000
@@ -396,64 +396,134 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 static const struct xlat_data fcntlcmds_xdata[] = {
 
  XLAT(F_DUPFD),
+ #define XLAT_VAL_0 ((unsigned) (F_DUPFD))
+ #define XLAT_STR_0 STRINGIFY(F_DUPFD)
  XLAT(F_GETFD),
+ #define XLAT_VAL_1 ((unsigned) (F_GETFD))
+ #define XLAT_STR_1 STRINGIFY(F_GETFD)
  XLAT(F_SETFD),
+ #define XLAT_VAL_2 ((unsigned) (F_SETFD))
+ #define XLAT_STR_2 STRINGIFY(F_SETFD)
  XLAT(F_GETFL),
+ #define XLAT_VAL_3 ((unsigned) (F_GETFL))
+ #define XLAT_STR_3 STRINGIFY(F_GETFL)
  XLAT(F_SETFL),
+ #define XLAT_VAL_4 ((unsigned) (F_SETFL))
+ #define XLAT_STR_4 STRINGIFY(F_SETFL)
 
 #if defined __alpha__ || defined __sparc__
  XLAT(F_GETLK),
+ #define XLAT_VAL_5 ((unsigned) (F_GETLK))
+ #define XLAT_STR_5 STRINGIFY(F_GETLK)
 #elif defined __mips__
  XLAT(F_GETLK),
+ #define XLAT_VAL_6 ((unsigned) (F_GETLK))
+ #define XLAT_STR_6 STRINGIFY(F_GETLK)
 #else
  XLAT(F_GETLK),
+ #define XLAT_VAL_7 ((unsigned) (F_GETLK))
+ #define XLAT_STR_7 STRINGIFY(F_GETLK)
 #endif
 
 #if defined __alpha__ || defined __sparc__
  XLAT(F_SETLK),
+ #define XLAT_VAL_8 ((unsigned) (F_SETLK))
+ #define XLAT_STR_8 STRINGIFY(F_SETLK)
  XLAT(F_SETLKW),
+ #define XLAT_VAL_9 ((unsigned) (F_SETLKW))
+ #define XLAT_STR_9 STRINGIFY(F_SETLKW)
 #else
  XLAT(F_SETLK),
+ #define XLAT_VAL_10 ((unsigned) (F_SETLK))
+ #define XLAT_STR_10 STRINGIFY(F_SETLK)
  XLAT(F_SETLKW),
+ #define XLAT_VAL_11 ((unsigned) (F_SETLKW))
+ #define XLAT_STR_11 STRINGIFY(F_SETLKW)
 #endif
 
 #if defined __alpha__
  XLAT(F_SETOWN),
+ #define XLAT_VAL_12 ((unsigned) (F_SETOWN))
+ #define XLAT_STR_12 STRINGIFY(F_SETOWN)
  XLAT(F_GETOWN),
+ #define XLAT_VAL_13 ((unsigned) (F_GETOWN))
+ #define XLAT_STR_13 STRINGIFY(F_GETOWN)
 #elif defined __hppa__
  XLAT(F_GETOWN),
+ #define XLAT_VAL_14 ((unsigned) (F_GETOWN))
+ #define XLAT_STR_14 STRINGIFY(F_GETOWN)
  XLAT(F_SETOWN),
+ #define XLAT_VAL_15 ((unsigned) (F_SETOWN))
+ #define XLAT_STR_15 STRINGIFY(F_SETOWN)
 #elif defined __mips__
  XLAT(F_GETOWN),
+ #define XLAT_VAL_16 ((unsigned) (F_GETOWN))
+ #define XLAT_STR_16 STRINGIFY(F_GETOWN)
  XLAT(F_SETOWN),
+ #define XLAT_VAL_17 ((unsigned) (F_SETOWN))
+ #define XLAT_STR_17 STRINGIFY(F_SETOWN)
 #elif defined __sparc__
  XLAT(F_GETOWN),
+ #define XLAT_VAL_18 ((unsigned) (F_GETOWN))
+ #define XLAT_STR_18 STRINGIFY(F_GETOWN)
  XLAT(F_SETOWN),
+ #define XLAT_VAL_19 ((unsigned) (F_SETOWN))
+ #define XLAT_STR_19 STRINGIFY(F_SETOWN)
 #else
  XLAT(F_SETOWN),
+ #define XLAT_VAL_20 ((unsigned) (F_SETOWN))
+ #define XLAT_STR_20 STRINGIFY(F_SETOWN)
  XLAT(F_GETOWN),
+ #define XLAT_VAL_21 ((unsigned) (F_GETOWN))
+ #define XLAT_STR_21 STRINGIFY(F_GETOWN)
 #endif
 
 #ifdef __hppa__
  XLAT(F_SETSIG),
+ #define XLAT_VAL_22 ((unsigned) (F_SETSIG))
+ #define XLAT_STR_22 STRINGIFY(F_SETSIG)
  XLAT(F_GETSIG),
+ #define XLAT_VAL_23 ((unsigned) (F_GETSIG))
+ #define XLAT_STR_23 STRINGIFY(F_GETSIG)
 #else
  XLAT(F_SETSIG),
+ #define XLAT_VAL_24 ((unsigned) (F_SETSIG))
+ #define XLAT_STR_24 STRINGIFY(F_SETSIG)
  XLAT(F_GETSIG),
+ #define XLAT_VAL_25 ((unsigned) (F_GETSIG))
+ #define XLAT_STR_25 STRINGIFY(F_GETSIG)
 #endif
 
 #if defined __hppa__
  XLAT(F_GETLK64),
+ #define XLAT_VAL_26 ((unsigned) (F_GETLK64))
+ #define XLAT_STR_26 STRINGIFY(F_GETLK64)
  XLAT(F_SETLK64),
+ #define XLAT_VAL_27 ((unsigned) (F_SETLK64))
+ #define XLAT_STR_27 STRINGIFY(F_SETLK64)
  XLAT(F_SETLKW64),
+ #define XLAT_VAL_28 ((unsigned) (F_SETLKW64))
+ #define XLAT_STR_28 STRINGIFY(F_SETLKW64)
 #elif defined __mips__ && !defined __mips64
  XLAT(F_GETLK64),
+ #define XLAT_VAL_29 ((unsigned) (F_GETLK64))
+ #define XLAT_STR_29 STRINGIFY(F_GETLK64)
  XLAT(F_SETLK64),
+ #define XLAT_VAL_30 ((unsigned) (F_SETLK64))
+ #define XLAT_STR_30 STRINGIFY(F_SETLK64)
  XLAT(F_SETLKW64),
+ #define XLAT_VAL_31 ((unsigned) (F_SETLKW64))
+ #define XLAT_STR_31 STRINGIFY(F_SETLKW64)
 #else
  XLAT(F_GETLK64),
+ #define XLAT_VAL_32 ((unsigned) (F_GETLK64))
+ #define XLAT_STR_32 STRINGIFY(F_GETLK64)
  XLAT(F_SETLK64),
+ #define XLAT_VAL_33 ((unsigned) (F_SETLK64))
+ #define XLAT_STR_33 STRINGIFY(F_SETLK64)
  XLAT(F_SETLKW64),
+ #define XLAT_VAL_34 ((unsigned) (F_SETLKW64))
+ #define XLAT_STR_34 STRINGIFY(F_SETLKW64)
 #endif
 
 #ifndef STRACE_WORKAROUND_FOR_F_OWNER_EX
@@ -475,31 +545,465 @@ static const struct xlat_data fcntlcmds_
 # undef F_GETOWN_EX
 #endif
  XLAT(F_SETOWN_EX),
+ #define XLAT_VAL_35 ((unsigned) (F_SETOWN_EX))
+ #define XLAT_STR_35 STRINGIFY(F_SETOWN_EX)
  XLAT(F_GETOWN_EX),
+ #define XLAT_VAL_36 ((unsigned) (F_GETOWN_EX))
+ #define XLAT_STR_36 STRINGIFY(F_GETOWN_EX)
 
  XLAT(F_GETOWNER_UIDS),
+ #define XLAT_VAL_37 ((unsigned) (F_GETOWNER_UIDS))
+ #define XLAT_STR_37 STRINGIFY(F_GETOWNER_UIDS)
  XLAT(F_OFD_GETLK),
+ #define XLAT_VAL_38 ((unsigned) (F_OFD_GETLK))
+ #define XLAT_STR_38 STRINGIFY(F_OFD_GETLK)
  XLAT(F_OFD_SETLK),
+ #define XLAT_VAL_39 ((unsigned) (F_OFD_SETLK))
+ #define XLAT_STR_39 STRINGIFY(F_OFD_SETLK)
  XLAT(F_OFD_SETLKW),
+ #define XLAT_VAL_40 ((unsigned) (F_OFD_SETLKW))
+ #define XLAT_STR_40 STRINGIFY(F_OFD_SETLKW)
 
 
  XLAT(F_SETLEASE),
+ #define XLAT_VAL_41 ((unsigned) (F_SETLEASE))
+ #define XLAT_STR_41 STRINGIFY(F_SETLEASE)
  XLAT(F_GETLEASE),
+ #define XLAT_VAL_42 ((unsigned) (F_GETLEASE))
+ #define XLAT_STR_42 STRINGIFY(F_GETLEASE)
  XLAT(F_NOTIFY),
+ #define XLAT_VAL_43 ((unsigned) (F_NOTIFY))
+ #define XLAT_STR_43 STRINGIFY(F_NOTIFY)
  XLAT(F_CANCELLK),
+ #define XLAT_VAL_44 ((unsigned) (F_CANCELLK))
+ #define XLAT_STR_44 STRINGIFY(F_CANCELLK)
  XLAT(F_DUPFD_CLOEXEC),
+ #define XLAT_VAL_45 ((unsigned) (F_DUPFD_CLOEXEC))
+ #define XLAT_STR_45 STRINGIFY(F_DUPFD_CLOEXEC)
  XLAT(F_SETPIPE_SZ),
+ #define XLAT_VAL_46 ((unsigned) (F_SETPIPE_SZ))
+ #define XLAT_STR_46 STRINGIFY(F_SETPIPE_SZ)
  XLAT(F_GETPIPE_SZ),
+ #define XLAT_VAL_47 ((unsigned) (F_GETPIPE_SZ))
+ #define XLAT_STR_47 STRINGIFY(F_GETPIPE_SZ)
  XLAT(F_ADD_SEALS),
+ #define XLAT_VAL_48 ((unsigned) (F_ADD_SEALS))
+ #define XLAT_STR_48 STRINGIFY(F_ADD_SEALS)
  XLAT(F_GET_SEALS),
+ #define XLAT_VAL_49 ((unsigned) (F_GET_SEALS))
+ #define XLAT_STR_49 STRINGIFY(F_GET_SEALS)
 };
 static
 const struct xlat fcntlcmds[1] = { {
  .data = fcntlcmds_xdata,
  .size = ARRAY_SIZE(fcntlcmds_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+#  ifdef XLAT_VAL_47
+  | XLAT_VAL_47
+#  endif
+#  ifdef XLAT_VAL_48
+  | XLAT_VAL_48
+#  endif
+#  ifdef XLAT_VAL_49
+  | XLAT_VAL_49
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+#  ifdef XLAT_STR_47
+  + sizeof(XLAT_STR_47)
+#  endif
+#  ifdef XLAT_STR_48
+  + sizeof(XLAT_STR_48)
+#  endif
+#  ifdef XLAT_STR_49
+  + sizeof(XLAT_STR_49)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
+#  undef XLAT_STR_47
+#  undef XLAT_VAL_47
+#  undef XLAT_STR_48
+#  undef XLAT_VAL_48
+#  undef XLAT_STR_49
+#  undef XLAT_VAL_49
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/fdflags.h 5.9-0ubuntu2/xlat/fdflags.h
--- 5.5-3/xlat/fdflags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/fdflags.h	2020-09-24 09:18:44.000000000 +0000
@@ -15,6 +15,8 @@
 static const struct xlat_data fdflags_xdata[] = {
 #if defined(FD_CLOEXEC) || (defined(HAVE_DECL_FD_CLOEXEC) && HAVE_DECL_FD_CLOEXEC)
   XLAT(FD_CLOEXEC),
+ #define XLAT_VAL_0 ((unsigned) (FD_CLOEXEC))
+ #define XLAT_STR_0 STRINGIFY(FD_CLOEXEC)
 #endif
 };
 static
@@ -22,8 +24,20 @@ const struct xlat fdflags[1] = { {
  .data = fdflags_xdata,
  .size = ARRAY_SIZE(fdflags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/fib_rule_actions.h 5.9-0ubuntu2/xlat/fib_rule_actions.h
--- 5.5-3/xlat/fib_rule_actions.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/fib_rule_actions.h	2020-09-24 09:18:44.000000000 +0000
@@ -77,22 +77,116 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data fib_rule_actions_xdata[] = {
  [FR_ACT_UNSPEC] = XLAT(FR_ACT_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (FR_ACT_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(FR_ACT_UNSPEC)
  [FR_ACT_TO_TBL] = XLAT(FR_ACT_TO_TBL),
+ #define XLAT_VAL_1 ((unsigned) (FR_ACT_TO_TBL))
+ #define XLAT_STR_1 STRINGIFY(FR_ACT_TO_TBL)
  [FR_ACT_GOTO] = XLAT(FR_ACT_GOTO),
+ #define XLAT_VAL_2 ((unsigned) (FR_ACT_GOTO))
+ #define XLAT_STR_2 STRINGIFY(FR_ACT_GOTO)
  [FR_ACT_NOP] = XLAT(FR_ACT_NOP),
+ #define XLAT_VAL_3 ((unsigned) (FR_ACT_NOP))
+ #define XLAT_STR_3 STRINGIFY(FR_ACT_NOP)
  [FR_ACT_RES3] = XLAT(FR_ACT_RES3),
+ #define XLAT_VAL_4 ((unsigned) (FR_ACT_RES3))
+ #define XLAT_STR_4 STRINGIFY(FR_ACT_RES3)
  [FR_ACT_RES4] = XLAT(FR_ACT_RES4),
+ #define XLAT_VAL_5 ((unsigned) (FR_ACT_RES4))
+ #define XLAT_STR_5 STRINGIFY(FR_ACT_RES4)
  [FR_ACT_BLACKHOLE] = XLAT(FR_ACT_BLACKHOLE),
+ #define XLAT_VAL_6 ((unsigned) (FR_ACT_BLACKHOLE))
+ #define XLAT_STR_6 STRINGIFY(FR_ACT_BLACKHOLE)
  [FR_ACT_UNREACHABLE] = XLAT(FR_ACT_UNREACHABLE),
+ #define XLAT_VAL_7 ((unsigned) (FR_ACT_UNREACHABLE))
+ #define XLAT_STR_7 STRINGIFY(FR_ACT_UNREACHABLE)
  [FR_ACT_PROHIBIT] = XLAT(FR_ACT_PROHIBIT),
+ #define XLAT_VAL_8 ((unsigned) (FR_ACT_PROHIBIT))
+ #define XLAT_STR_8 STRINGIFY(FR_ACT_PROHIBIT)
 };
 static
 const struct xlat fib_rule_actions[1] = { {
  .data = fib_rule_actions_xdata,
  .size = ARRAY_SIZE(fib_rule_actions_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/fib_rule_flags.h 5.9-0ubuntu2/xlat/fib_rule_flags.h
--- 5.5-3/xlat/fib_rule_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/fib_rule_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -56,19 +56,83 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data fib_rule_flags_xdata[] = {
  XLAT(FIB_RULE_PERMANENT),
+ #define XLAT_VAL_0 ((unsigned) (FIB_RULE_PERMANENT))
+ #define XLAT_STR_0 STRINGIFY(FIB_RULE_PERMANENT)
  XLAT(FIB_RULE_INVERT),
+ #define XLAT_VAL_1 ((unsigned) (FIB_RULE_INVERT))
+ #define XLAT_STR_1 STRINGIFY(FIB_RULE_INVERT)
  XLAT(FIB_RULE_UNRESOLVED),
+ #define XLAT_VAL_2 ((unsigned) (FIB_RULE_UNRESOLVED))
+ #define XLAT_STR_2 STRINGIFY(FIB_RULE_UNRESOLVED)
  XLAT(FIB_RULE_IIF_DETACHED),
+ #define XLAT_VAL_3 ((unsigned) (FIB_RULE_IIF_DETACHED))
+ #define XLAT_STR_3 STRINGIFY(FIB_RULE_IIF_DETACHED)
  XLAT(FIB_RULE_OIF_DETACHED),
+ #define XLAT_VAL_4 ((unsigned) (FIB_RULE_OIF_DETACHED))
+ #define XLAT_STR_4 STRINGIFY(FIB_RULE_OIF_DETACHED)
  XLAT(FIB_RULE_FIND_SADDR),
+ #define XLAT_VAL_5 ((unsigned) (FIB_RULE_FIND_SADDR))
+ #define XLAT_STR_5 STRINGIFY(FIB_RULE_FIND_SADDR)
 };
 static
 const struct xlat fib_rule_flags[1] = { {
  .data = fib_rule_flags_xdata,
  .size = ARRAY_SIZE(fib_rule_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/fiemap_extent_flags.h 5.9-0ubuntu2/xlat/fiemap_extent_flags.h
--- 5.5-3/xlat/fiemap_extent_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/fiemap_extent_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -91,24 +91,138 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data fiemap_extent_flags_xdata[] = {
  XLAT(FIEMAP_EXTENT_LAST),
+ #define XLAT_VAL_0 ((unsigned) (FIEMAP_EXTENT_LAST))
+ #define XLAT_STR_0 STRINGIFY(FIEMAP_EXTENT_LAST)
  XLAT(FIEMAP_EXTENT_UNKNOWN),
+ #define XLAT_VAL_1 ((unsigned) (FIEMAP_EXTENT_UNKNOWN))
+ #define XLAT_STR_1 STRINGIFY(FIEMAP_EXTENT_UNKNOWN)
  XLAT(FIEMAP_EXTENT_DELALLOC),
+ #define XLAT_VAL_2 ((unsigned) (FIEMAP_EXTENT_DELALLOC))
+ #define XLAT_STR_2 STRINGIFY(FIEMAP_EXTENT_DELALLOC)
  XLAT(FIEMAP_EXTENT_ENCODED),
+ #define XLAT_VAL_3 ((unsigned) (FIEMAP_EXTENT_ENCODED))
+ #define XLAT_STR_3 STRINGIFY(FIEMAP_EXTENT_ENCODED)
  XLAT(FIEMAP_EXTENT_DATA_ENCRYPTED),
+ #define XLAT_VAL_4 ((unsigned) (FIEMAP_EXTENT_DATA_ENCRYPTED))
+ #define XLAT_STR_4 STRINGIFY(FIEMAP_EXTENT_DATA_ENCRYPTED)
  XLAT(FIEMAP_EXTENT_NOT_ALIGNED),
+ #define XLAT_VAL_5 ((unsigned) (FIEMAP_EXTENT_NOT_ALIGNED))
+ #define XLAT_STR_5 STRINGIFY(FIEMAP_EXTENT_NOT_ALIGNED)
  XLAT(FIEMAP_EXTENT_DATA_INLINE),
+ #define XLAT_VAL_6 ((unsigned) (FIEMAP_EXTENT_DATA_INLINE))
+ #define XLAT_STR_6 STRINGIFY(FIEMAP_EXTENT_DATA_INLINE)
  XLAT(FIEMAP_EXTENT_DATA_TAIL),
+ #define XLAT_VAL_7 ((unsigned) (FIEMAP_EXTENT_DATA_TAIL))
+ #define XLAT_STR_7 STRINGIFY(FIEMAP_EXTENT_DATA_TAIL)
  XLAT(FIEMAP_EXTENT_UNWRITTEN),
+ #define XLAT_VAL_8 ((unsigned) (FIEMAP_EXTENT_UNWRITTEN))
+ #define XLAT_STR_8 STRINGIFY(FIEMAP_EXTENT_UNWRITTEN)
  XLAT(FIEMAP_EXTENT_MERGED),
+ #define XLAT_VAL_9 ((unsigned) (FIEMAP_EXTENT_MERGED))
+ #define XLAT_STR_9 STRINGIFY(FIEMAP_EXTENT_MERGED)
  XLAT(FIEMAP_EXTENT_SHARED),
+ #define XLAT_VAL_10 ((unsigned) (FIEMAP_EXTENT_SHARED))
+ #define XLAT_STR_10 STRINGIFY(FIEMAP_EXTENT_SHARED)
 };
 static
 const struct xlat fiemap_extent_flags[1] = { {
  .data = fiemap_extent_flags_xdata,
  .size = ARRAY_SIZE(fiemap_extent_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/fiemap_flags.h 5.9-0ubuntu2/xlat/fiemap_flags.h
--- 5.5-3/xlat/fiemap_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/fiemap_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data fiemap_flags_xdata[] = {
  XLAT(FIEMAP_FLAG_SYNC),
+ #define XLAT_VAL_0 ((unsigned) (FIEMAP_FLAG_SYNC))
+ #define XLAT_STR_0 STRINGIFY(FIEMAP_FLAG_SYNC)
  XLAT(FIEMAP_FLAG_XATTR),
+ #define XLAT_VAL_1 ((unsigned) (FIEMAP_FLAG_XATTR))
+ #define XLAT_STR_1 STRINGIFY(FIEMAP_FLAG_XATTR)
  XLAT(FIEMAP_FLAG_CACHE),
+ #define XLAT_VAL_2 ((unsigned) (FIEMAP_FLAG_CACHE))
+ #define XLAT_STR_2 STRINGIFY(FIEMAP_FLAG_CACHE)
 };
 static
 const struct xlat fiemap_flags[1] = { {
  .data = fiemap_flags_xdata,
  .size = ARRAY_SIZE(fiemap_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/flockcmds.h 5.9-0ubuntu2/xlat/flockcmds.h
--- 5.5-3/xlat/flockcmds.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/flockcmds.h	2020-09-24 09:18:44.000000000 +0000
@@ -70,21 +70,105 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data flockcmds_xdata[] = {
  XLAT(LOCK_SH),
+ #define XLAT_VAL_0 ((unsigned) (LOCK_SH))
+ #define XLAT_STR_0 STRINGIFY(LOCK_SH)
  XLAT(LOCK_EX),
+ #define XLAT_VAL_1 ((unsigned) (LOCK_EX))
+ #define XLAT_STR_1 STRINGIFY(LOCK_EX)
  XLAT(LOCK_NB),
+ #define XLAT_VAL_2 ((unsigned) (LOCK_NB))
+ #define XLAT_STR_2 STRINGIFY(LOCK_NB)
  XLAT(LOCK_UN),
+ #define XLAT_VAL_3 ((unsigned) (LOCK_UN))
+ #define XLAT_STR_3 STRINGIFY(LOCK_UN)
  XLAT(LOCK_MAND),
+ #define XLAT_VAL_4 ((unsigned) (LOCK_MAND))
+ #define XLAT_STR_4 STRINGIFY(LOCK_MAND)
  XLAT(LOCK_RW),
+ #define XLAT_VAL_5 ((unsigned) (LOCK_RW))
+ #define XLAT_STR_5 STRINGIFY(LOCK_RW)
  XLAT(LOCK_READ),
+ #define XLAT_VAL_6 ((unsigned) (LOCK_READ))
+ #define XLAT_STR_6 STRINGIFY(LOCK_READ)
  XLAT(LOCK_WRITE),
+ #define XLAT_VAL_7 ((unsigned) (LOCK_WRITE))
+ #define XLAT_STR_7 STRINGIFY(LOCK_WRITE)
 };
 static
 const struct xlat flockcmds[1] = { {
  .data = flockcmds_xdata,
  .size = ARRAY_SIZE(flockcmds_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/f_owner_types.h 5.9-0ubuntu2/xlat/f_owner_types.h
--- 5.5-3/xlat/f_owner_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/f_owner_types.h	2020-09-24 09:18:44.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data f_owner_types_xdata[] = {
  [F_OWNER_TID] = XLAT(F_OWNER_TID),
+ #define XLAT_VAL_0 ((unsigned) (F_OWNER_TID))
+ #define XLAT_STR_0 STRINGIFY(F_OWNER_TID)
  [F_OWNER_PID] = XLAT(F_OWNER_PID),
+ #define XLAT_VAL_1 ((unsigned) (F_OWNER_PID))
+ #define XLAT_STR_1 STRINGIFY(F_OWNER_PID)
  [F_OWNER_PGRP] = XLAT(F_OWNER_PGRP),
+ #define XLAT_VAL_2 ((unsigned) (F_OWNER_PGRP))
+ #define XLAT_STR_2 STRINGIFY(F_OWNER_PGRP)
 };
 static
 const struct xlat f_owner_types[1] = { {
  .data = f_owner_types_xdata,
  .size = ARRAY_SIZE(f_owner_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/fsconfig_cmds.h 5.9-0ubuntu2/xlat/fsconfig_cmds.h
--- 5.5-3/xlat/fsconfig_cmds.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/fsconfig_cmds.h	2020-09-24 09:18:44.000000000 +0000
@@ -70,21 +70,105 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data fsconfig_cmds_xdata[] = {
  [FSCONFIG_SET_FLAG] = XLAT(FSCONFIG_SET_FLAG),
+ #define XLAT_VAL_0 ((unsigned) (FSCONFIG_SET_FLAG))
+ #define XLAT_STR_0 STRINGIFY(FSCONFIG_SET_FLAG)
  [FSCONFIG_SET_STRING] = XLAT(FSCONFIG_SET_STRING),
+ #define XLAT_VAL_1 ((unsigned) (FSCONFIG_SET_STRING))
+ #define XLAT_STR_1 STRINGIFY(FSCONFIG_SET_STRING)
  [FSCONFIG_SET_BINARY] = XLAT(FSCONFIG_SET_BINARY),
+ #define XLAT_VAL_2 ((unsigned) (FSCONFIG_SET_BINARY))
+ #define XLAT_STR_2 STRINGIFY(FSCONFIG_SET_BINARY)
  [FSCONFIG_SET_PATH] = XLAT(FSCONFIG_SET_PATH),
+ #define XLAT_VAL_3 ((unsigned) (FSCONFIG_SET_PATH))
+ #define XLAT_STR_3 STRINGIFY(FSCONFIG_SET_PATH)
  [FSCONFIG_SET_PATH_EMPTY] = XLAT(FSCONFIG_SET_PATH_EMPTY),
+ #define XLAT_VAL_4 ((unsigned) (FSCONFIG_SET_PATH_EMPTY))
+ #define XLAT_STR_4 STRINGIFY(FSCONFIG_SET_PATH_EMPTY)
  [FSCONFIG_SET_FD] = XLAT(FSCONFIG_SET_FD),
+ #define XLAT_VAL_5 ((unsigned) (FSCONFIG_SET_FD))
+ #define XLAT_STR_5 STRINGIFY(FSCONFIG_SET_FD)
  [FSCONFIG_CMD_CREATE] = XLAT(FSCONFIG_CMD_CREATE),
+ #define XLAT_VAL_6 ((unsigned) (FSCONFIG_CMD_CREATE))
+ #define XLAT_STR_6 STRINGIFY(FSCONFIG_CMD_CREATE)
  [FSCONFIG_CMD_RECONFIGURE] = XLAT(FSCONFIG_CMD_RECONFIGURE),
+ #define XLAT_VAL_7 ((unsigned) (FSCONFIG_CMD_RECONFIGURE))
+ #define XLAT_STR_7 STRINGIFY(FSCONFIG_CMD_RECONFIGURE)
 };
 static
 const struct xlat fsconfig_cmds[1] = { {
  .data = fsconfig_cmds_xdata,
  .size = ARRAY_SIZE(fsconfig_cmds_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/f_seals.h 5.9-0ubuntu2/xlat/f_seals.h
--- 5.5-3/xlat/f_seals.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/f_seals.h	2020-09-24 09:18:44.000000000 +0000
@@ -49,18 +49,72 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data f_seals_xdata[] = {
  XLAT(F_SEAL_SEAL),
+ #define XLAT_VAL_0 ((unsigned) (F_SEAL_SEAL))
+ #define XLAT_STR_0 STRINGIFY(F_SEAL_SEAL)
  XLAT(F_SEAL_SHRINK),
+ #define XLAT_VAL_1 ((unsigned) (F_SEAL_SHRINK))
+ #define XLAT_STR_1 STRINGIFY(F_SEAL_SHRINK)
  XLAT(F_SEAL_GROW),
+ #define XLAT_VAL_2 ((unsigned) (F_SEAL_GROW))
+ #define XLAT_STR_2 STRINGIFY(F_SEAL_GROW)
  XLAT(F_SEAL_WRITE),
+ #define XLAT_VAL_3 ((unsigned) (F_SEAL_WRITE))
+ #define XLAT_STR_3 STRINGIFY(F_SEAL_WRITE)
  XLAT(F_SEAL_FUTURE_WRITE),
+ #define XLAT_VAL_4 ((unsigned) (F_SEAL_FUTURE_WRITE))
+ #define XLAT_STR_4 STRINGIFY(F_SEAL_FUTURE_WRITE)
 };
 static
 const struct xlat f_seals[1] = { {
  .data = f_seals_xdata,
  .size = ARRAY_SIZE(f_seals_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/fsmagic.h 5.9-0ubuntu2/xlat/fsmagic.h
--- 5.5-3/xlat/fsmagic.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/fsmagic.h	2020-09-24 09:18:46.000000000 +0000
@@ -416,6 +416,13 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define CRAMFS_MAGIC_WEND 0x453dcd28
 #endif
+#if defined(DEVMEM_MAGIC) || (defined(HAVE_DECL_DEVMEM_MAGIC) && HAVE_DECL_DEVMEM_MAGIC)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((DEVMEM_MAGIC) == (0x454d444d), "DEVMEM_MAGIC != 0x454d444d");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define DEVMEM_MAGIC 0x454d444d
+#endif
 #if defined(GPFS_SUPER_MAGIC) || (defined(HAVE_DECL_GPFS_SUPER_MAGIC) && HAVE_DECL_GPFS_SUPER_MAGIC)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
 static_assert((GPFS_SUPER_MAGIC) == (0x47504653), "GPFS_SUPER_MAGIC != 0x47504653");
@@ -500,6 +507,13 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define AAFS_MAGIC 0x5a3c69f0
 #endif
+#if defined(ZONEFS_MAGIC) || (defined(HAVE_DECL_ZONEFS_MAGIC) && HAVE_DECL_ZONEFS_MAGIC)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ZONEFS_MAGIC) == (0x5a4f4653), "ZONEFS_MAGIC != 0x5a4f4653");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ZONEFS_MAGIC 0x5a4f4653
+#endif
 #if defined(PSTOREFS_MAGIC) || (defined(HAVE_DECL_PSTOREFS_MAGIC) && HAVE_DECL_PSTOREFS_MAGIC)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
 static_assert((PSTOREFS_MAGIC) == (0x6165676c), "PSTOREFS_MAGIC != 0x6165676c");
@@ -763,120 +777,1216 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data fsmagic_xdata[] = {
  XLAT(QNX4_SUPER_MAGIC),
+ #define XLAT_VAL_0 ((unsigned) (QNX4_SUPER_MAGIC))
+ #define XLAT_STR_0 STRINGIFY(QNX4_SUPER_MAGIC)
  XLAT(Z3FOLD_MAGIC),
+ #define XLAT_VAL_1 ((unsigned) (Z3FOLD_MAGIC))
+ #define XLAT_STR_1 STRINGIFY(Z3FOLD_MAGIC)
  XLAT(AUTOFS_SUPER_MAGIC),
+ #define XLAT_VAL_2 ((unsigned) (AUTOFS_SUPER_MAGIC))
+ #define XLAT_STR_2 STRINGIFY(AUTOFS_SUPER_MAGIC)
  XLAT(DEVFS_SUPER_MAGIC),
+ #define XLAT_VAL_3 ((unsigned) (DEVFS_SUPER_MAGIC))
+ #define XLAT_STR_3 STRINGIFY(DEVFS_SUPER_MAGIC)
  XLAT(EXT_SUPER_MAGIC),
+ #define XLAT_VAL_4 ((unsigned) (EXT_SUPER_MAGIC))
+ #define XLAT_STR_4 STRINGIFY(EXT_SUPER_MAGIC)
  XLAT(MINIX_SUPER_MAGIC),
+ #define XLAT_VAL_5 ((unsigned) (MINIX_SUPER_MAGIC))
+ #define XLAT_STR_5 STRINGIFY(MINIX_SUPER_MAGIC)
  XLAT(MINIX_SUPER_MAGIC2),
+ #define XLAT_VAL_6 ((unsigned) (MINIX_SUPER_MAGIC2))
+ #define XLAT_STR_6 STRINGIFY(MINIX_SUPER_MAGIC2)
  XLAT(DEVPTS_SUPER_MAGIC),
+ #define XLAT_VAL_7 ((unsigned) (DEVPTS_SUPER_MAGIC))
+ #define XLAT_STR_7 STRINGIFY(DEVPTS_SUPER_MAGIC)
  XLAT(MINIX2_SUPER_MAGIC),
+ #define XLAT_VAL_8 ((unsigned) (MINIX2_SUPER_MAGIC))
+ #define XLAT_STR_8 STRINGIFY(MINIX2_SUPER_MAGIC)
  XLAT(MINIX2_SUPER_MAGIC2),
+ #define XLAT_VAL_9 ((unsigned) (MINIX2_SUPER_MAGIC2))
+ #define XLAT_STR_9 STRINGIFY(MINIX2_SUPER_MAGIC2)
  XLAT(NILFS_SUPER_MAGIC),
+ #define XLAT_VAL_10 ((unsigned) (NILFS_SUPER_MAGIC))
+ #define XLAT_STR_10 STRINGIFY(NILFS_SUPER_MAGIC)
  XLAT(HFS_SUPER_MAGIC),
+ #define XLAT_VAL_11 ((unsigned) (HFS_SUPER_MAGIC))
+ #define XLAT_STR_11 STRINGIFY(HFS_SUPER_MAGIC)
  XLAT(HFSPLUS_SUPER_MAGIC),
+ #define XLAT_VAL_12 ((unsigned) (HFSPLUS_SUPER_MAGIC))
+ #define XLAT_STR_12 STRINGIFY(HFSPLUS_SUPER_MAGIC)
  XLAT(MSDOS_SUPER_MAGIC),
+ #define XLAT_VAL_13 ((unsigned) (MSDOS_SUPER_MAGIC))
+ #define XLAT_STR_13 STRINGIFY(MSDOS_SUPER_MAGIC)
  XLAT(MINIX3_SUPER_MAGIC),
+ #define XLAT_VAL_14 ((unsigned) (MINIX3_SUPER_MAGIC))
+ #define XLAT_STR_14 STRINGIFY(MINIX3_SUPER_MAGIC)
  XLAT(SMB_SUPER_MAGIC),
+ #define XLAT_VAL_15 ((unsigned) (SMB_SUPER_MAGIC))
+ #define XLAT_STR_15 STRINGIFY(SMB_SUPER_MAGIC)
  XLAT(NCP_SUPER_MAGIC),
+ #define XLAT_VAL_16 ((unsigned) (NCP_SUPER_MAGIC))
+ #define XLAT_STR_16 STRINGIFY(NCP_SUPER_MAGIC)
  XLAT(EXOFS_SUPER_MAGIC),
+ #define XLAT_VAL_17 ((unsigned) (EXOFS_SUPER_MAGIC))
+ #define XLAT_STR_17 STRINGIFY(EXOFS_SUPER_MAGIC)
  XLAT(NFS_SUPER_MAGIC),
+ #define XLAT_VAL_18 ((unsigned) (NFS_SUPER_MAGIC))
+ #define XLAT_STR_18 STRINGIFY(NFS_SUPER_MAGIC)
  XLAT(ROMFS_MAGIC),
+ #define XLAT_VAL_19 ((unsigned) (ROMFS_MAGIC))
+ #define XLAT_STR_19 STRINGIFY(ROMFS_MAGIC)
  XLAT(JFFS2_SUPER_MAGIC),
+ #define XLAT_VAL_20 ((unsigned) (JFFS2_SUPER_MAGIC))
+ #define XLAT_STR_20 STRINGIFY(JFFS2_SUPER_MAGIC)
  XLAT(ISOFS_SUPER_MAGIC),
+ #define XLAT_VAL_21 ((unsigned) (ISOFS_SUPER_MAGIC))
+ #define XLAT_STR_21 STRINGIFY(ISOFS_SUPER_MAGIC)
  XLAT(PROC_SUPER_MAGIC),
+ #define XLAT_VAL_22 ((unsigned) (PROC_SUPER_MAGIC))
+ #define XLAT_STR_22 STRINGIFY(PROC_SUPER_MAGIC)
  XLAT(OPENPROM_SUPER_MAGIC),
+ #define XLAT_VAL_23 ((unsigned) (OPENPROM_SUPER_MAGIC))
+ #define XLAT_STR_23 STRINGIFY(OPENPROM_SUPER_MAGIC)
  XLAT(USBDEVICE_SUPER_MAGIC),
+ #define XLAT_VAL_24 ((unsigned) (USBDEVICE_SUPER_MAGIC))
+ #define XLAT_STR_24 STRINGIFY(USBDEVICE_SUPER_MAGIC)
  XLAT(ADFS_SUPER_MAGIC),
+ #define XLAT_VAL_25 ((unsigned) (ADFS_SUPER_MAGIC))
+ #define XLAT_STR_25 STRINGIFY(ADFS_SUPER_MAGIC)
  XLAT(AFFS_SUPER_MAGIC),
+ #define XLAT_VAL_26 ((unsigned) (AFFS_SUPER_MAGIC))
+ #define XLAT_STR_26 STRINGIFY(AFFS_SUPER_MAGIC)
  XLAT(EXT2_OLD_SUPER_MAGIC),
+ #define XLAT_VAL_27 ((unsigned) (EXT2_OLD_SUPER_MAGIC))
+ #define XLAT_STR_27 STRINGIFY(EXT2_OLD_SUPER_MAGIC)
  XLAT(EXT2_SUPER_MAGIC),
+ #define XLAT_VAL_28 ((unsigned) (EXT2_SUPER_MAGIC))
+ #define XLAT_STR_28 STRINGIFY(EXT2_SUPER_MAGIC)
  XLAT(ECRYPTFS_SUPER_MAGIC),
+ #define XLAT_VAL_29 ((unsigned) (ECRYPTFS_SUPER_MAGIC))
+ #define XLAT_STR_29 STRINGIFY(ECRYPTFS_SUPER_MAGIC)
  XLAT(UFS_MAGIC),
+ #define XLAT_VAL_30 ((unsigned) (UFS_MAGIC))
+ #define XLAT_STR_30 STRINGIFY(UFS_MAGIC)
  XLAT(CGROUP_SUPER_MAGIC),
+ #define XLAT_VAL_31 ((unsigned) (CGROUP_SUPER_MAGIC))
+ #define XLAT_STR_31 STRINGIFY(CGROUP_SUPER_MAGIC)
  XLAT(EFS_SUPER_MAGIC),
+ #define XLAT_VAL_32 ((unsigned) (EFS_SUPER_MAGIC))
+ #define XLAT_STR_32 STRINGIFY(EFS_SUPER_MAGIC)
  XLAT(HOSTFS_SUPER_MAGIC),
+ #define XLAT_VAL_33 ((unsigned) (HOSTFS_SUPER_MAGIC))
+ #define XLAT_STR_33 STRINGIFY(HOSTFS_SUPER_MAGIC)
  XLAT(CEPH_SUPER_MAGIC),
+ #define XLAT_VAL_34 ((unsigned) (CEPH_SUPER_MAGIC))
+ #define XLAT_STR_34 STRINGIFY(CEPH_SUPER_MAGIC)
  XLAT(TMPFS_MAGIC),
+ #define XLAT_VAL_35 ((unsigned) (TMPFS_MAGIC))
+ #define XLAT_STR_35 STRINGIFY(TMPFS_MAGIC)
  XLAT(V9FS_MAGIC),
+ #define XLAT_VAL_36 ((unsigned) (V9FS_MAGIC))
+ #define XLAT_STR_36 STRINGIFY(V9FS_MAGIC)
  XLAT(GFS2_MAGIC),
+ #define XLAT_VAL_37 ((unsigned) (GFS2_MAGIC))
+ #define XLAT_STR_37 STRINGIFY(GFS2_MAGIC)
  XLAT(XIAFS_SUPER_MAGIC),
+ #define XLAT_VAL_38 ((unsigned) (XIAFS_SUPER_MAGIC))
+ #define XLAT_STR_38 STRINGIFY(XIAFS_SUPER_MAGIC)
  XLAT(XENIX_SUPER_MAGIC),
+ #define XLAT_VAL_39 ((unsigned) (XENIX_SUPER_MAGIC))
+ #define XLAT_STR_39 STRINGIFY(XENIX_SUPER_MAGIC)
  XLAT(SYSV4_SUPER_MAGIC),
+ #define XLAT_VAL_40 ((unsigned) (SYSV4_SUPER_MAGIC))
+ #define XLAT_STR_40 STRINGIFY(SYSV4_SUPER_MAGIC)
  XLAT(SYSV2_SUPER_MAGIC),
+ #define XLAT_VAL_41 ((unsigned) (SYSV2_SUPER_MAGIC))
+ #define XLAT_STR_41 STRINGIFY(SYSV2_SUPER_MAGIC)
  XLAT(COH_SUPER_MAGIC),
+ #define XLAT_VAL_42 ((unsigned) (COH_SUPER_MAGIC))
+ #define XLAT_STR_42 STRINGIFY(COH_SUPER_MAGIC)
  XLAT(SHMFS_SUPER_MAGIC),
+ #define XLAT_VAL_43 ((unsigned) (SHMFS_SUPER_MAGIC))
+ #define XLAT_STR_43 STRINGIFY(SHMFS_SUPER_MAGIC)
  XLAT(ANON_INODE_FS_MAGIC),
+ #define XLAT_VAL_44 ((unsigned) (ANON_INODE_FS_MAGIC))
+ #define XLAT_STR_44 STRINGIFY(ANON_INODE_FS_MAGIC)
  XLAT(FUTEXFS_SUPER_MAGIC),
+ #define XLAT_VAL_45 ((unsigned) (FUTEXFS_SUPER_MAGIC))
+ #define XLAT_STR_45 STRINGIFY(FUTEXFS_SUPER_MAGIC)
  XLAT(MTD_INODE_FS_MAGIC),
+ #define XLAT_VAL_46 ((unsigned) (MTD_INODE_FS_MAGIC))
+ #define XLAT_STR_46 STRINGIFY(MTD_INODE_FS_MAGIC)
  XLAT(BALLOON_KVM_MAGIC),
+ #define XLAT_VAL_47 ((unsigned) (BALLOON_KVM_MAGIC))
+ #define XLAT_STR_47 STRINGIFY(BALLOON_KVM_MAGIC)
  XLAT(UDF_SUPER_MAGIC),
+ #define XLAT_VAL_48 ((unsigned) (UDF_SUPER_MAGIC))
+ #define XLAT_STR_48 STRINGIFY(UDF_SUPER_MAGIC)
  XLAT(BFS_MAGIC),
+ #define XLAT_VAL_49 ((unsigned) (BFS_MAGIC))
+ #define XLAT_STR_49 STRINGIFY(BFS_MAGIC)
  XLAT(UBIFS_SUPER_MAGIC),
+ #define XLAT_VAL_50 ((unsigned) (UBIFS_SUPER_MAGIC))
+ #define XLAT_STR_50 STRINGIFY(UBIFS_SUPER_MAGIC)
  XLAT(CRAMFS_MAGIC),
+ #define XLAT_VAL_51 ((unsigned) (CRAMFS_MAGIC))
+ #define XLAT_STR_51 STRINGIFY(CRAMFS_MAGIC)
  XLAT(ZFS_SUPER_MAGIC),
+ #define XLAT_VAL_52 ((unsigned) (ZFS_SUPER_MAGIC))
+ #define XLAT_STR_52 STRINGIFY(ZFS_SUPER_MAGIC)
  XLAT(JFS_SUPER_MAGIC),
+ #define XLAT_VAL_53 ((unsigned) (JFS_SUPER_MAGIC))
+ #define XLAT_STR_53 STRINGIFY(JFS_SUPER_MAGIC)
  XLAT(BEFS_SUPER_MAGIC),
+ #define XLAT_VAL_54 ((unsigned) (BEFS_SUPER_MAGIC))
+ #define XLAT_STR_54 STRINGIFY(BEFS_SUPER_MAGIC)
  XLAT(BINFMTFS_MAGIC),
+ #define XLAT_VAL_55 ((unsigned) (BINFMTFS_MAGIC))
+ #define XLAT_STR_55 STRINGIFY(BINFMTFS_MAGIC)
  XLAT(SMACK_MAGIC),
+ #define XLAT_VAL_56 ((unsigned) (SMACK_MAGIC))
+ #define XLAT_STR_56 STRINGIFY(SMACK_MAGIC)
  XLAT(DMA_BUF_MAGIC),
+ #define XLAT_VAL_57 ((unsigned) (DMA_BUF_MAGIC))
+ #define XLAT_STR_57 STRINGIFY(DMA_BUF_MAGIC)
  XLAT(CRAMFS_MAGIC_WEND),
+ #define XLAT_VAL_58 ((unsigned) (CRAMFS_MAGIC_WEND))
+ #define XLAT_STR_58 STRINGIFY(CRAMFS_MAGIC_WEND)
+ XLAT(DEVMEM_MAGIC),
+ #define XLAT_VAL_59 ((unsigned) (DEVMEM_MAGIC))
+ #define XLAT_STR_59 STRINGIFY(DEVMEM_MAGIC)
  XLAT(GPFS_SUPER_MAGIC),
+ #define XLAT_VAL_60 ((unsigned) (GPFS_SUPER_MAGIC))
+ #define XLAT_STR_60 STRINGIFY(GPFS_SUPER_MAGIC)
  XLAT(PIPEFS_MAGIC),
+ #define XLAT_VAL_61 ((unsigned) (PIPEFS_MAGIC))
+ #define XLAT_STR_61 STRINGIFY(PIPEFS_MAGIC)
  XLAT(REISERFS_SUPER_MAGIC),
+ #define XLAT_VAL_62 ((unsigned) (REISERFS_SUPER_MAGIC))
+ #define XLAT_STR_62 STRINGIFY(REISERFS_SUPER_MAGIC)
  XLAT(AFS_SUPER_MAGIC),
+ #define XLAT_VAL_63 ((unsigned) (AFS_SUPER_MAGIC))
+ #define XLAT_STR_63 STRINGIFY(AFS_SUPER_MAGIC)
  XLAT(NTFS_SB_MAGIC),
+ #define XLAT_VAL_64 ((unsigned) (NTFS_SB_MAGIC))
+ #define XLAT_STR_64 STRINGIFY(NTFS_SB_MAGIC)
  XLAT(SOCKFS_MAGIC),
+ #define XLAT_VAL_65 ((unsigned) (SOCKFS_MAGIC))
+ #define XLAT_STR_65 STRINGIFY(SOCKFS_MAGIC)
  XLAT(UFS_CIGAM),
+ #define XLAT_VAL_66 ((unsigned) (UFS_CIGAM))
+ #define XLAT_STR_66 STRINGIFY(UFS_CIGAM)
  XLAT(VZFS_SUPER_MAGIC),
+ #define XLAT_VAL_67 ((unsigned) (VZFS_SUPER_MAGIC))
+ #define XLAT_STR_67 STRINGIFY(VZFS_SUPER_MAGIC)
  XLAT(STACK_END_MAGIC),
+ #define XLAT_VAL_68 ((unsigned) (STACK_END_MAGIC))
+ #define XLAT_STR_68 STRINGIFY(STACK_END_MAGIC)
  XLAT(ZSMALLOC_MAGIC),
+ #define XLAT_VAL_69 ((unsigned) (ZSMALLOC_MAGIC))
+ #define XLAT_STR_69 STRINGIFY(ZSMALLOC_MAGIC)
  XLAT(XFS_SB_MAGIC),
+ #define XLAT_VAL_70 ((unsigned) (XFS_SB_MAGIC))
+ #define XLAT_STR_70 STRINGIFY(XFS_SB_MAGIC)
  XLAT(AAFS_MAGIC),
+ #define XLAT_VAL_71 ((unsigned) (AAFS_MAGIC))
+ #define XLAT_STR_71 STRINGIFY(AAFS_MAGIC)
+ XLAT(ZONEFS_MAGIC),
+ #define XLAT_VAL_72 ((unsigned) (ZONEFS_MAGIC))
+ #define XLAT_STR_72 STRINGIFY(ZONEFS_MAGIC)
  XLAT(PSTOREFS_MAGIC),
+ #define XLAT_VAL_73 ((unsigned) (PSTOREFS_MAGIC))
+ #define XLAT_STR_73 STRINGIFY(PSTOREFS_MAGIC)
  XLAT(AUFS_SUPER_MAGIC),
+ #define XLAT_VAL_74 ((unsigned) (AUFS_SUPER_MAGIC))
+ #define XLAT_STR_74 STRINGIFY(AUFS_SUPER_MAGIC)
  XLAT(BDEVFS_MAGIC),
+ #define XLAT_VAL_75 ((unsigned) (BDEVFS_MAGIC))
+ #define XLAT_STR_75 STRINGIFY(BDEVFS_MAGIC)
  XLAT(CONFIGFS_MAGIC),
+ #define XLAT_VAL_76 ((unsigned) (CONFIGFS_MAGIC))
+ #define XLAT_STR_76 STRINGIFY(CONFIGFS_MAGIC)
  XLAT(SYSFS_MAGIC),
+ #define XLAT_VAL_77 ((unsigned) (SYSFS_MAGIC))
+ #define XLAT_STR_77 STRINGIFY(SYSFS_MAGIC)
  XLAT(CGROUP2_SUPER_MAGIC),
+ #define XLAT_VAL_78 ((unsigned) (CGROUP2_SUPER_MAGIC))
+ #define XLAT_STR_78 STRINGIFY(CGROUP2_SUPER_MAGIC)
  XLAT(DEBUGFS_MAGIC),
+ #define XLAT_VAL_79 ((unsigned) (DEBUGFS_MAGIC))
+ #define XLAT_STR_79 STRINGIFY(DEBUGFS_MAGIC)
  XLAT(DAXFS_MAGIC),
+ #define XLAT_VAL_80 ((unsigned) (DAXFS_MAGIC))
+ #define XLAT_STR_80 STRINGIFY(DAXFS_MAGIC)
  XLAT(FUSE_CTL_SUPER_MAGIC),
+ #define XLAT_VAL_81 ((unsigned) (FUSE_CTL_SUPER_MAGIC))
+ #define XLAT_STR_81 STRINGIFY(FUSE_CTL_SUPER_MAGIC)
  XLAT(FUSE_SUPER_MAGIC),
+ #define XLAT_VAL_82 ((unsigned) (FUSE_SUPER_MAGIC))
+ #define XLAT_STR_82 STRINGIFY(FUSE_SUPER_MAGIC)
  XLAT(QNX6_SUPER_MAGIC),
+ #define XLAT_VAL_83 ((unsigned) (QNX6_SUPER_MAGIC))
+ #define XLAT_STR_83 STRINGIFY(QNX6_SUPER_MAGIC)
  XLAT(AFS_FS_MAGIC),
+ #define XLAT_VAL_84 ((unsigned) (AFS_FS_MAGIC))
+ #define XLAT_STR_84 STRINGIFY(AFS_FS_MAGIC)
  XLAT(BINDERFS_SUPER_MAGIC),
+ #define XLAT_VAL_85 ((unsigned) (BINDERFS_SUPER_MAGIC))
+ #define XLAT_STR_85 STRINGIFY(BINDERFS_SUPER_MAGIC)
  XLAT(NSFS_MAGIC),
+ #define XLAT_VAL_86 ((unsigned) (NSFS_MAGIC))
+ #define XLAT_STR_86 STRINGIFY(NSFS_MAGIC)
  XLAT(SECURITYFS_MAGIC),
+ #define XLAT_VAL_87 ((unsigned) (SECURITYFS_MAGIC))
+ #define XLAT_STR_87 STRINGIFY(SECURITYFS_MAGIC)
  XLAT(SQUASHFS_MAGIC),
+ #define XLAT_VAL_88 ((unsigned) (SQUASHFS_MAGIC))
+ #define XLAT_STR_88 STRINGIFY(SQUASHFS_MAGIC)
  XLAT(BTRFS_TEST_MAGIC),
+ #define XLAT_VAL_89 ((unsigned) (BTRFS_TEST_MAGIC))
+ #define XLAT_STR_89 STRINGIFY(BTRFS_TEST_MAGIC)
  XLAT(CODA_SUPER_MAGIC),
+ #define XLAT_VAL_90 ((unsigned) (CODA_SUPER_MAGIC))
+ #define XLAT_STR_90 STRINGIFY(CODA_SUPER_MAGIC)
  XLAT(OCFS2_SUPER_MAGIC),
+ #define XLAT_VAL_91 ((unsigned) (OCFS2_SUPER_MAGIC))
+ #define XLAT_STR_91 STRINGIFY(OCFS2_SUPER_MAGIC)
  XLAT(TRACEFS_MAGIC),
+ #define XLAT_VAL_92 ((unsigned) (TRACEFS_MAGIC))
+ #define XLAT_STR_92 STRINGIFY(TRACEFS_MAGIC)
  XLAT(OVERLAYFS_SUPER_MAGIC),
+ #define XLAT_VAL_93 ((unsigned) (OVERLAYFS_SUPER_MAGIC))
+ #define XLAT_STR_93 STRINGIFY(OVERLAYFS_SUPER_MAGIC)
  XLAT(RAMFS_MAGIC),
+ #define XLAT_VAL_94 ((unsigned) (RAMFS_MAGIC))
+ #define XLAT_STR_94 STRINGIFY(RAMFS_MAGIC)
  XLAT(BTRFS_SUPER_MAGIC),
+ #define XLAT_VAL_95 ((unsigned) (BTRFS_SUPER_MAGIC))
+ #define XLAT_STR_95 STRINGIFY(BTRFS_SUPER_MAGIC)
  XLAT(HUGETLBFS_MAGIC),
+ #define XLAT_VAL_96 ((unsigned) (HUGETLBFS_MAGIC))
+ #define XLAT_STR_96 STRINGIFY(HUGETLBFS_MAGIC)
  XLAT(VXFS_SUPER_MAGIC),
+ #define XLAT_VAL_97 ((unsigned) (VXFS_SUPER_MAGIC))
+ #define XLAT_STR_97 STRINGIFY(VXFS_SUPER_MAGIC)
  XLAT(XENFS_SUPER_MAGIC),
+ #define XLAT_VAL_98 ((unsigned) (XENFS_SUPER_MAGIC))
+ #define XLAT_STR_98 STRINGIFY(XENFS_SUPER_MAGIC)
  XLAT(PPC_CMM_MAGIC),
+ #define XLAT_VAL_99 ((unsigned) (PPC_CMM_MAGIC))
+ #define XLAT_STR_99 STRINGIFY(PPC_CMM_MAGIC)
  XLAT(LOGFS_MAGIC),
+ #define XLAT_VAL_100 ((unsigned) (LOGFS_MAGIC))
+ #define XLAT_STR_100 STRINGIFY(LOGFS_MAGIC)
  XLAT(BPF_FS_MAGIC),
+ #define XLAT_VAL_101 ((unsigned) (BPF_FS_MAGIC))
+ #define XLAT_STR_101 STRINGIFY(BPF_FS_MAGIC)
  XLAT(EFIVARFS_MAGIC),
+ #define XLAT_VAL_102 ((unsigned) (EFIVARFS_MAGIC))
+ #define XLAT_STR_102 STRINGIFY(EFIVARFS_MAGIC)
  XLAT(EROFS_SUPER_MAGIC_V1),
+ #define XLAT_VAL_103 ((unsigned) (EROFS_SUPER_MAGIC_V1))
+ #define XLAT_STR_103 STRINGIFY(EROFS_SUPER_MAGIC_V1)
  XLAT(F2FS_SUPER_MAGIC),
+ #define XLAT_VAL_104 ((unsigned) (F2FS_SUPER_MAGIC))
+ #define XLAT_STR_104 STRINGIFY(F2FS_SUPER_MAGIC)
  XLAT(SELINUX_MAGIC),
+ #define XLAT_VAL_105 ((unsigned) (SELINUX_MAGIC))
+ #define XLAT_STR_105 STRINGIFY(SELINUX_MAGIC)
  XLAT(HPFS_SUPER_MAGIC),
+ #define XLAT_VAL_106 ((unsigned) (HPFS_SUPER_MAGIC))
+ #define XLAT_STR_106 STRINGIFY(HPFS_SUPER_MAGIC)
  XLAT(SMB2_MAGIC_NUMBER),
+ #define XLAT_VAL_107 ((unsigned) (SMB2_MAGIC_NUMBER))
+ #define XLAT_STR_107 STRINGIFY(SMB2_MAGIC_NUMBER)
  XLAT(CIFS_MAGIC_NUMBER),
+ #define XLAT_VAL_108 ((unsigned) (CIFS_MAGIC_NUMBER))
+ #define XLAT_STR_108 STRINGIFY(CIFS_MAGIC_NUMBER)
 };
 static
 const struct xlat fsmagic[1] = { {
  .data = fsmagic_xdata,
  .size = ARRAY_SIZE(fsmagic_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+#  ifdef XLAT_VAL_47
+  | XLAT_VAL_47
+#  endif
+#  ifdef XLAT_VAL_48
+  | XLAT_VAL_48
+#  endif
+#  ifdef XLAT_VAL_49
+  | XLAT_VAL_49
+#  endif
+#  ifdef XLAT_VAL_50
+  | XLAT_VAL_50
+#  endif
+#  ifdef XLAT_VAL_51
+  | XLAT_VAL_51
+#  endif
+#  ifdef XLAT_VAL_52
+  | XLAT_VAL_52
+#  endif
+#  ifdef XLAT_VAL_53
+  | XLAT_VAL_53
+#  endif
+#  ifdef XLAT_VAL_54
+  | XLAT_VAL_54
+#  endif
+#  ifdef XLAT_VAL_55
+  | XLAT_VAL_55
+#  endif
+#  ifdef XLAT_VAL_56
+  | XLAT_VAL_56
+#  endif
+#  ifdef XLAT_VAL_57
+  | XLAT_VAL_57
+#  endif
+#  ifdef XLAT_VAL_58
+  | XLAT_VAL_58
+#  endif
+#  ifdef XLAT_VAL_59
+  | XLAT_VAL_59
+#  endif
+#  ifdef XLAT_VAL_60
+  | XLAT_VAL_60
+#  endif
+#  ifdef XLAT_VAL_61
+  | XLAT_VAL_61
+#  endif
+#  ifdef XLAT_VAL_62
+  | XLAT_VAL_62
+#  endif
+#  ifdef XLAT_VAL_63
+  | XLAT_VAL_63
+#  endif
+#  ifdef XLAT_VAL_64
+  | XLAT_VAL_64
+#  endif
+#  ifdef XLAT_VAL_65
+  | XLAT_VAL_65
+#  endif
+#  ifdef XLAT_VAL_66
+  | XLAT_VAL_66
+#  endif
+#  ifdef XLAT_VAL_67
+  | XLAT_VAL_67
+#  endif
+#  ifdef XLAT_VAL_68
+  | XLAT_VAL_68
+#  endif
+#  ifdef XLAT_VAL_69
+  | XLAT_VAL_69
+#  endif
+#  ifdef XLAT_VAL_70
+  | XLAT_VAL_70
+#  endif
+#  ifdef XLAT_VAL_71
+  | XLAT_VAL_71
+#  endif
+#  ifdef XLAT_VAL_72
+  | XLAT_VAL_72
+#  endif
+#  ifdef XLAT_VAL_73
+  | XLAT_VAL_73
+#  endif
+#  ifdef XLAT_VAL_74
+  | XLAT_VAL_74
+#  endif
+#  ifdef XLAT_VAL_75
+  | XLAT_VAL_75
+#  endif
+#  ifdef XLAT_VAL_76
+  | XLAT_VAL_76
+#  endif
+#  ifdef XLAT_VAL_77
+  | XLAT_VAL_77
+#  endif
+#  ifdef XLAT_VAL_78
+  | XLAT_VAL_78
+#  endif
+#  ifdef XLAT_VAL_79
+  | XLAT_VAL_79
+#  endif
+#  ifdef XLAT_VAL_80
+  | XLAT_VAL_80
+#  endif
+#  ifdef XLAT_VAL_81
+  | XLAT_VAL_81
+#  endif
+#  ifdef XLAT_VAL_82
+  | XLAT_VAL_82
+#  endif
+#  ifdef XLAT_VAL_83
+  | XLAT_VAL_83
+#  endif
+#  ifdef XLAT_VAL_84
+  | XLAT_VAL_84
+#  endif
+#  ifdef XLAT_VAL_85
+  | XLAT_VAL_85
+#  endif
+#  ifdef XLAT_VAL_86
+  | XLAT_VAL_86
+#  endif
+#  ifdef XLAT_VAL_87
+  | XLAT_VAL_87
+#  endif
+#  ifdef XLAT_VAL_88
+  | XLAT_VAL_88
+#  endif
+#  ifdef XLAT_VAL_89
+  | XLAT_VAL_89
+#  endif
+#  ifdef XLAT_VAL_90
+  | XLAT_VAL_90
+#  endif
+#  ifdef XLAT_VAL_91
+  | XLAT_VAL_91
+#  endif
+#  ifdef XLAT_VAL_92
+  | XLAT_VAL_92
+#  endif
+#  ifdef XLAT_VAL_93
+  | XLAT_VAL_93
+#  endif
+#  ifdef XLAT_VAL_94
+  | XLAT_VAL_94
+#  endif
+#  ifdef XLAT_VAL_95
+  | XLAT_VAL_95
+#  endif
+#  ifdef XLAT_VAL_96
+  | XLAT_VAL_96
+#  endif
+#  ifdef XLAT_VAL_97
+  | XLAT_VAL_97
+#  endif
+#  ifdef XLAT_VAL_98
+  | XLAT_VAL_98
+#  endif
+#  ifdef XLAT_VAL_99
+  | XLAT_VAL_99
+#  endif
+#  ifdef XLAT_VAL_100
+  | XLAT_VAL_100
+#  endif
+#  ifdef XLAT_VAL_101
+  | XLAT_VAL_101
+#  endif
+#  ifdef XLAT_VAL_102
+  | XLAT_VAL_102
+#  endif
+#  ifdef XLAT_VAL_103
+  | XLAT_VAL_103
+#  endif
+#  ifdef XLAT_VAL_104
+  | XLAT_VAL_104
+#  endif
+#  ifdef XLAT_VAL_105
+  | XLAT_VAL_105
+#  endif
+#  ifdef XLAT_VAL_106
+  | XLAT_VAL_106
+#  endif
+#  ifdef XLAT_VAL_107
+  | XLAT_VAL_107
+#  endif
+#  ifdef XLAT_VAL_108
+  | XLAT_VAL_108
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+#  ifdef XLAT_STR_47
+  + sizeof(XLAT_STR_47)
+#  endif
+#  ifdef XLAT_STR_48
+  + sizeof(XLAT_STR_48)
+#  endif
+#  ifdef XLAT_STR_49
+  + sizeof(XLAT_STR_49)
+#  endif
+#  ifdef XLAT_STR_50
+  + sizeof(XLAT_STR_50)
+#  endif
+#  ifdef XLAT_STR_51
+  + sizeof(XLAT_STR_51)
+#  endif
+#  ifdef XLAT_STR_52
+  + sizeof(XLAT_STR_52)
+#  endif
+#  ifdef XLAT_STR_53
+  + sizeof(XLAT_STR_53)
+#  endif
+#  ifdef XLAT_STR_54
+  + sizeof(XLAT_STR_54)
+#  endif
+#  ifdef XLAT_STR_55
+  + sizeof(XLAT_STR_55)
+#  endif
+#  ifdef XLAT_STR_56
+  + sizeof(XLAT_STR_56)
+#  endif
+#  ifdef XLAT_STR_57
+  + sizeof(XLAT_STR_57)
+#  endif
+#  ifdef XLAT_STR_58
+  + sizeof(XLAT_STR_58)
+#  endif
+#  ifdef XLAT_STR_59
+  + sizeof(XLAT_STR_59)
+#  endif
+#  ifdef XLAT_STR_60
+  + sizeof(XLAT_STR_60)
+#  endif
+#  ifdef XLAT_STR_61
+  + sizeof(XLAT_STR_61)
+#  endif
+#  ifdef XLAT_STR_62
+  + sizeof(XLAT_STR_62)
+#  endif
+#  ifdef XLAT_STR_63
+  + sizeof(XLAT_STR_63)
+#  endif
+#  ifdef XLAT_STR_64
+  + sizeof(XLAT_STR_64)
+#  endif
+#  ifdef XLAT_STR_65
+  + sizeof(XLAT_STR_65)
+#  endif
+#  ifdef XLAT_STR_66
+  + sizeof(XLAT_STR_66)
+#  endif
+#  ifdef XLAT_STR_67
+  + sizeof(XLAT_STR_67)
+#  endif
+#  ifdef XLAT_STR_68
+  + sizeof(XLAT_STR_68)
+#  endif
+#  ifdef XLAT_STR_69
+  + sizeof(XLAT_STR_69)
+#  endif
+#  ifdef XLAT_STR_70
+  + sizeof(XLAT_STR_70)
+#  endif
+#  ifdef XLAT_STR_71
+  + sizeof(XLAT_STR_71)
+#  endif
+#  ifdef XLAT_STR_72
+  + sizeof(XLAT_STR_72)
+#  endif
+#  ifdef XLAT_STR_73
+  + sizeof(XLAT_STR_73)
+#  endif
+#  ifdef XLAT_STR_74
+  + sizeof(XLAT_STR_74)
+#  endif
+#  ifdef XLAT_STR_75
+  + sizeof(XLAT_STR_75)
+#  endif
+#  ifdef XLAT_STR_76
+  + sizeof(XLAT_STR_76)
+#  endif
+#  ifdef XLAT_STR_77
+  + sizeof(XLAT_STR_77)
+#  endif
+#  ifdef XLAT_STR_78
+  + sizeof(XLAT_STR_78)
+#  endif
+#  ifdef XLAT_STR_79
+  + sizeof(XLAT_STR_79)
+#  endif
+#  ifdef XLAT_STR_80
+  + sizeof(XLAT_STR_80)
+#  endif
+#  ifdef XLAT_STR_81
+  + sizeof(XLAT_STR_81)
+#  endif
+#  ifdef XLAT_STR_82
+  + sizeof(XLAT_STR_82)
+#  endif
+#  ifdef XLAT_STR_83
+  + sizeof(XLAT_STR_83)
+#  endif
+#  ifdef XLAT_STR_84
+  + sizeof(XLAT_STR_84)
+#  endif
+#  ifdef XLAT_STR_85
+  + sizeof(XLAT_STR_85)
+#  endif
+#  ifdef XLAT_STR_86
+  + sizeof(XLAT_STR_86)
+#  endif
+#  ifdef XLAT_STR_87
+  + sizeof(XLAT_STR_87)
+#  endif
+#  ifdef XLAT_STR_88
+  + sizeof(XLAT_STR_88)
+#  endif
+#  ifdef XLAT_STR_89
+  + sizeof(XLAT_STR_89)
+#  endif
+#  ifdef XLAT_STR_90
+  + sizeof(XLAT_STR_90)
+#  endif
+#  ifdef XLAT_STR_91
+  + sizeof(XLAT_STR_91)
+#  endif
+#  ifdef XLAT_STR_92
+  + sizeof(XLAT_STR_92)
+#  endif
+#  ifdef XLAT_STR_93
+  + sizeof(XLAT_STR_93)
+#  endif
+#  ifdef XLAT_STR_94
+  + sizeof(XLAT_STR_94)
+#  endif
+#  ifdef XLAT_STR_95
+  + sizeof(XLAT_STR_95)
+#  endif
+#  ifdef XLAT_STR_96
+  + sizeof(XLAT_STR_96)
+#  endif
+#  ifdef XLAT_STR_97
+  + sizeof(XLAT_STR_97)
+#  endif
+#  ifdef XLAT_STR_98
+  + sizeof(XLAT_STR_98)
+#  endif
+#  ifdef XLAT_STR_99
+  + sizeof(XLAT_STR_99)
+#  endif
+#  ifdef XLAT_STR_100
+  + sizeof(XLAT_STR_100)
+#  endif
+#  ifdef XLAT_STR_101
+  + sizeof(XLAT_STR_101)
+#  endif
+#  ifdef XLAT_STR_102
+  + sizeof(XLAT_STR_102)
+#  endif
+#  ifdef XLAT_STR_103
+  + sizeof(XLAT_STR_103)
+#  endif
+#  ifdef XLAT_STR_104
+  + sizeof(XLAT_STR_104)
+#  endif
+#  ifdef XLAT_STR_105
+  + sizeof(XLAT_STR_105)
+#  endif
+#  ifdef XLAT_STR_106
+  + sizeof(XLAT_STR_106)
+#  endif
+#  ifdef XLAT_STR_107
+  + sizeof(XLAT_STR_107)
+#  endif
+#  ifdef XLAT_STR_108
+  + sizeof(XLAT_STR_108)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
+#  undef XLAT_STR_47
+#  undef XLAT_VAL_47
+#  undef XLAT_STR_48
+#  undef XLAT_VAL_48
+#  undef XLAT_STR_49
+#  undef XLAT_VAL_49
+#  undef XLAT_STR_50
+#  undef XLAT_VAL_50
+#  undef XLAT_STR_51
+#  undef XLAT_VAL_51
+#  undef XLAT_STR_52
+#  undef XLAT_VAL_52
+#  undef XLAT_STR_53
+#  undef XLAT_VAL_53
+#  undef XLAT_STR_54
+#  undef XLAT_VAL_54
+#  undef XLAT_STR_55
+#  undef XLAT_VAL_55
+#  undef XLAT_STR_56
+#  undef XLAT_VAL_56
+#  undef XLAT_STR_57
+#  undef XLAT_VAL_57
+#  undef XLAT_STR_58
+#  undef XLAT_VAL_58
+#  undef XLAT_STR_59
+#  undef XLAT_VAL_59
+#  undef XLAT_STR_60
+#  undef XLAT_VAL_60
+#  undef XLAT_STR_61
+#  undef XLAT_VAL_61
+#  undef XLAT_STR_62
+#  undef XLAT_VAL_62
+#  undef XLAT_STR_63
+#  undef XLAT_VAL_63
+#  undef XLAT_STR_64
+#  undef XLAT_VAL_64
+#  undef XLAT_STR_65
+#  undef XLAT_VAL_65
+#  undef XLAT_STR_66
+#  undef XLAT_VAL_66
+#  undef XLAT_STR_67
+#  undef XLAT_VAL_67
+#  undef XLAT_STR_68
+#  undef XLAT_VAL_68
+#  undef XLAT_STR_69
+#  undef XLAT_VAL_69
+#  undef XLAT_STR_70
+#  undef XLAT_VAL_70
+#  undef XLAT_STR_71
+#  undef XLAT_VAL_71
+#  undef XLAT_STR_72
+#  undef XLAT_VAL_72
+#  undef XLAT_STR_73
+#  undef XLAT_VAL_73
+#  undef XLAT_STR_74
+#  undef XLAT_VAL_74
+#  undef XLAT_STR_75
+#  undef XLAT_VAL_75
+#  undef XLAT_STR_76
+#  undef XLAT_VAL_76
+#  undef XLAT_STR_77
+#  undef XLAT_VAL_77
+#  undef XLAT_STR_78
+#  undef XLAT_VAL_78
+#  undef XLAT_STR_79
+#  undef XLAT_VAL_79
+#  undef XLAT_STR_80
+#  undef XLAT_VAL_80
+#  undef XLAT_STR_81
+#  undef XLAT_VAL_81
+#  undef XLAT_STR_82
+#  undef XLAT_VAL_82
+#  undef XLAT_STR_83
+#  undef XLAT_VAL_83
+#  undef XLAT_STR_84
+#  undef XLAT_VAL_84
+#  undef XLAT_STR_85
+#  undef XLAT_VAL_85
+#  undef XLAT_STR_86
+#  undef XLAT_VAL_86
+#  undef XLAT_STR_87
+#  undef XLAT_VAL_87
+#  undef XLAT_STR_88
+#  undef XLAT_VAL_88
+#  undef XLAT_STR_89
+#  undef XLAT_VAL_89
+#  undef XLAT_STR_90
+#  undef XLAT_VAL_90
+#  undef XLAT_STR_91
+#  undef XLAT_VAL_91
+#  undef XLAT_STR_92
+#  undef XLAT_VAL_92
+#  undef XLAT_STR_93
+#  undef XLAT_VAL_93
+#  undef XLAT_STR_94
+#  undef XLAT_VAL_94
+#  undef XLAT_STR_95
+#  undef XLAT_VAL_95
+#  undef XLAT_STR_96
+#  undef XLAT_VAL_96
+#  undef XLAT_STR_97
+#  undef XLAT_VAL_97
+#  undef XLAT_STR_98
+#  undef XLAT_VAL_98
+#  undef XLAT_STR_99
+#  undef XLAT_VAL_99
+#  undef XLAT_STR_100
+#  undef XLAT_VAL_100
+#  undef XLAT_STR_101
+#  undef XLAT_VAL_101
+#  undef XLAT_STR_102
+#  undef XLAT_VAL_102
+#  undef XLAT_STR_103
+#  undef XLAT_VAL_103
+#  undef XLAT_STR_104
+#  undef XLAT_VAL_104
+#  undef XLAT_STR_105
+#  undef XLAT_VAL_105
+#  undef XLAT_STR_106
+#  undef XLAT_VAL_106
+#  undef XLAT_STR_107
+#  undef XLAT_VAL_107
+#  undef XLAT_STR_108
+#  undef XLAT_VAL_108
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/fsmagic.in 5.9-0ubuntu2/xlat/fsmagic.in
--- 5.5-3/xlat/fsmagic.in	2020-01-21 18:02:38.000000000 +0000
+++ 5.9-0ubuntu2/xlat/fsmagic.in	2020-06-28 08:00:00.000000000 +0000
@@ -58,6 +58,7 @@ BINFMTFS_MAGIC		0x42494e4d
 SMACK_MAGIC		0x43415d53
 DMA_BUF_MAGIC		0x444d4142
 CRAMFS_MAGIC_WEND	0x453dcd28
+DEVMEM_MAGIC		0x454d444d
 GPFS_SUPER_MAGIC	0x47504653
 PIPEFS_MAGIC		0x50495045
 REISERFS_SUPER_MAGIC	0x52654973
@@ -70,6 +71,7 @@ STACK_END_MAGIC		0x57ac6e9d
 ZSMALLOC_MAGIC		0x58295829
 XFS_SB_MAGIC		0x58465342
 AAFS_MAGIC		0x5a3c69f0
+ZONEFS_MAGIC		0x5a4f4653
 PSTOREFS_MAGIC		0x6165676c
 AUFS_SUPER_MAGIC	0x61756673
 BDEVFS_MAGIC		0x62646576
diff -pruN 5.5-3/xlat/fsmount_flags.h 5.9-0ubuntu2/xlat/fsmount_flags.h
--- 5.5-3/xlat/fsmount_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/fsmount_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -21,14 +21,28 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data fsmount_flags_xdata[] = {
  XLAT(FSMOUNT_CLOEXEC),
+ #define XLAT_VAL_0 ((unsigned) (FSMOUNT_CLOEXEC))
+ #define XLAT_STR_0 STRINGIFY(FSMOUNT_CLOEXEC)
 };
 static
 const struct xlat fsmount_flags[1] = { {
  .data = fsmount_flags_xdata,
  .size = ARRAY_SIZE(fsmount_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/fsopen_flags.h 5.9-0ubuntu2/xlat/fsopen_flags.h
--- 5.5-3/xlat/fsopen_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/fsopen_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -21,14 +21,28 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data fsopen_flags_xdata[] = {
  XLAT(FSOPEN_CLOEXEC),
+ #define XLAT_VAL_0 ((unsigned) (FSOPEN_CLOEXEC))
+ #define XLAT_STR_0 STRINGIFY(FSOPEN_CLOEXEC)
 };
 static
 const struct xlat fsopen_flags[1] = { {
  .data = fsopen_flags_xdata,
  .size = ARRAY_SIZE(fsopen_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/fspick_flags.h 5.9-0ubuntu2/xlat/fspick_flags.h
--- 5.5-3/xlat/fspick_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/fspick_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data fspick_flags_xdata[] = {
  XLAT(FSPICK_CLOEXEC),
+ #define XLAT_VAL_0 ((unsigned) (FSPICK_CLOEXEC))
+ #define XLAT_STR_0 STRINGIFY(FSPICK_CLOEXEC)
  XLAT(FSPICK_SYMLINK_NOFOLLOW),
+ #define XLAT_VAL_1 ((unsigned) (FSPICK_SYMLINK_NOFOLLOW))
+ #define XLAT_STR_1 STRINGIFY(FSPICK_SYMLINK_NOFOLLOW)
  XLAT(FSPICK_NO_AUTOMOUNT),
+ #define XLAT_VAL_2 ((unsigned) (FSPICK_NO_AUTOMOUNT))
+ #define XLAT_STR_2 STRINGIFY(FSPICK_NO_AUTOMOUNT)
  XLAT(FSPICK_EMPTY_PATH),
+ #define XLAT_VAL_3 ((unsigned) (FSPICK_EMPTY_PATH))
+ #define XLAT_STR_3 STRINGIFY(FSPICK_EMPTY_PATH)
 };
 static
 const struct xlat fspick_flags[1] = { {
  .data = fspick_flags_xdata,
  .size = ARRAY_SIZE(fspick_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/futexbitset.h 5.9-0ubuntu2/xlat/futexbitset.h
--- 5.5-3/xlat/futexbitset.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/futexbitset.h	2020-09-24 09:18:44.000000000 +0000
@@ -21,14 +21,28 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data futexbitset_xdata[] = {
  XLAT(FUTEX_BITSET_MATCH_ANY),
+ #define XLAT_VAL_0 ((unsigned) (FUTEX_BITSET_MATCH_ANY))
+ #define XLAT_STR_0 STRINGIFY(FUTEX_BITSET_MATCH_ANY)
 };
 static
 const struct xlat futexbitset[1] = { {
  .data = futexbitset_xdata,
  .size = ARRAY_SIZE(futexbitset_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/futexops.h 5.9-0ubuntu2/xlat/futexops.h
--- 5.5-3/xlat/futexops.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/futexops.h	2020-09-24 09:18:45.000000000 +0000
@@ -189,50 +189,114 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data futexops_xdata[] = {
  XLAT(FUTEX_WAIT),
+ #define XLAT_VAL_0 ((unsigned) (FUTEX_WAIT))
+ #define XLAT_STR_0 STRINGIFY(FUTEX_WAIT)
  XLAT(FUTEX_WAKE),
+ #define XLAT_VAL_1 ((unsigned) (FUTEX_WAKE))
+ #define XLAT_STR_1 STRINGIFY(FUTEX_WAKE)
  XLAT(FUTEX_FD),
+ #define XLAT_VAL_2 ((unsigned) (FUTEX_FD))
+ #define XLAT_STR_2 STRINGIFY(FUTEX_FD)
  XLAT(FUTEX_REQUEUE),
+ #define XLAT_VAL_3 ((unsigned) (FUTEX_REQUEUE))
+ #define XLAT_STR_3 STRINGIFY(FUTEX_REQUEUE)
  XLAT(FUTEX_CMP_REQUEUE),
+ #define XLAT_VAL_4 ((unsigned) (FUTEX_CMP_REQUEUE))
+ #define XLAT_STR_4 STRINGIFY(FUTEX_CMP_REQUEUE)
  XLAT(FUTEX_WAKE_OP),
+ #define XLAT_VAL_5 ((unsigned) (FUTEX_WAKE_OP))
+ #define XLAT_STR_5 STRINGIFY(FUTEX_WAKE_OP)
  XLAT(FUTEX_LOCK_PI),
+ #define XLAT_VAL_6 ((unsigned) (FUTEX_LOCK_PI))
+ #define XLAT_STR_6 STRINGIFY(FUTEX_LOCK_PI)
  XLAT(FUTEX_UNLOCK_PI),
+ #define XLAT_VAL_7 ((unsigned) (FUTEX_UNLOCK_PI))
+ #define XLAT_STR_7 STRINGIFY(FUTEX_UNLOCK_PI)
  XLAT(FUTEX_TRYLOCK_PI),
+ #define XLAT_VAL_8 ((unsigned) (FUTEX_TRYLOCK_PI))
+ #define XLAT_STR_8 STRINGIFY(FUTEX_TRYLOCK_PI)
  XLAT(FUTEX_WAIT_BITSET),
+ #define XLAT_VAL_9 ((unsigned) (FUTEX_WAIT_BITSET))
+ #define XLAT_STR_9 STRINGIFY(FUTEX_WAIT_BITSET)
  XLAT(FUTEX_WAKE_BITSET),
+ #define XLAT_VAL_10 ((unsigned) (FUTEX_WAKE_BITSET))
+ #define XLAT_STR_10 STRINGIFY(FUTEX_WAKE_BITSET)
  XLAT(FUTEX_WAIT_REQUEUE_PI),
+ #define XLAT_VAL_11 ((unsigned) (FUTEX_WAIT_REQUEUE_PI))
+ #define XLAT_STR_11 STRINGIFY(FUTEX_WAIT_REQUEUE_PI)
  XLAT(FUTEX_CMP_REQUEUE_PI),
+ #define XLAT_VAL_12 ((unsigned) (FUTEX_CMP_REQUEUE_PI))
+ #define XLAT_STR_12 STRINGIFY(FUTEX_CMP_REQUEUE_PI)
  XLAT(FUTEX_WAIT_PRIVATE),
+ #define XLAT_VAL_13 ((unsigned) (FUTEX_WAIT_PRIVATE))
+ #define XLAT_STR_13 STRINGIFY(FUTEX_WAIT_PRIVATE)
  XLAT(FUTEX_WAKE_PRIVATE),
+ #define XLAT_VAL_14 ((unsigned) (FUTEX_WAKE_PRIVATE))
+ #define XLAT_STR_14 STRINGIFY(FUTEX_WAKE_PRIVATE)
 #if defined(FUTEX_FD) || (defined(HAVE_DECL_FUTEX_FD) && HAVE_DECL_FUTEX_FD)
   XLAT(FUTEX_FD|FUTEX_PRIVATE_FLAG),
+ #define XLAT_VAL_15 ((unsigned) (FUTEX_FD|FUTEX_PRIVATE_FLAG))
+ #define XLAT_STR_15 STRINGIFY(FUTEX_FD|FUTEX_PRIVATE_FLAG)
 #endif
  XLAT(FUTEX_REQUEUE_PRIVATE),
+ #define XLAT_VAL_16 ((unsigned) (FUTEX_REQUEUE_PRIVATE))
+ #define XLAT_STR_16 STRINGIFY(FUTEX_REQUEUE_PRIVATE)
  XLAT(FUTEX_CMP_REQUEUE_PRIVATE),
+ #define XLAT_VAL_17 ((unsigned) (FUTEX_CMP_REQUEUE_PRIVATE))
+ #define XLAT_STR_17 STRINGIFY(FUTEX_CMP_REQUEUE_PRIVATE)
  XLAT(FUTEX_WAKE_OP_PRIVATE),
+ #define XLAT_VAL_18 ((unsigned) (FUTEX_WAKE_OP_PRIVATE))
+ #define XLAT_STR_18 STRINGIFY(FUTEX_WAKE_OP_PRIVATE)
  XLAT(FUTEX_LOCK_PI_PRIVATE),
+ #define XLAT_VAL_19 ((unsigned) (FUTEX_LOCK_PI_PRIVATE))
+ #define XLAT_STR_19 STRINGIFY(FUTEX_LOCK_PI_PRIVATE)
  XLAT(FUTEX_UNLOCK_PI_PRIVATE),
+ #define XLAT_VAL_20 ((unsigned) (FUTEX_UNLOCK_PI_PRIVATE))
+ #define XLAT_STR_20 STRINGIFY(FUTEX_UNLOCK_PI_PRIVATE)
  XLAT(FUTEX_TRYLOCK_PI_PRIVATE),
+ #define XLAT_VAL_21 ((unsigned) (FUTEX_TRYLOCK_PI_PRIVATE))
+ #define XLAT_STR_21 STRINGIFY(FUTEX_TRYLOCK_PI_PRIVATE)
  XLAT(FUTEX_WAIT_BITSET_PRIVATE),
+ #define XLAT_VAL_22 ((unsigned) (FUTEX_WAIT_BITSET_PRIVATE))
+ #define XLAT_STR_22 STRINGIFY(FUTEX_WAIT_BITSET_PRIVATE)
  XLAT(FUTEX_WAKE_BITSET_PRIVATE),
+ #define XLAT_VAL_23 ((unsigned) (FUTEX_WAKE_BITSET_PRIVATE))
+ #define XLAT_STR_23 STRINGIFY(FUTEX_WAKE_BITSET_PRIVATE)
  XLAT(FUTEX_WAIT_REQUEUE_PI_PRIVATE),
+ #define XLAT_VAL_24 ((unsigned) (FUTEX_WAIT_REQUEUE_PI_PRIVATE))
+ #define XLAT_STR_24 STRINGIFY(FUTEX_WAIT_REQUEUE_PI_PRIVATE)
  XLAT(FUTEX_CMP_REQUEUE_PI_PRIVATE),
+ #define XLAT_VAL_25 ((unsigned) (FUTEX_CMP_REQUEUE_PI_PRIVATE))
+ #define XLAT_STR_25 STRINGIFY(FUTEX_CMP_REQUEUE_PI_PRIVATE)
 #if defined(FUTEX_WAIT) || (defined(HAVE_DECL_FUTEX_WAIT) && HAVE_DECL_FUTEX_WAIT)
   XLAT(FUTEX_WAIT|FUTEX_CLOCK_REALTIME),
+ #define XLAT_VAL_26 ((unsigned) (FUTEX_WAIT|FUTEX_CLOCK_REALTIME))
+ #define XLAT_STR_26 STRINGIFY(FUTEX_WAIT|FUTEX_CLOCK_REALTIME)
 #endif
 #if defined(FUTEX_WAIT_PRIVATE) || (defined(HAVE_DECL_FUTEX_WAIT_PRIVATE) && HAVE_DECL_FUTEX_WAIT_PRIVATE)
   XLAT(FUTEX_WAIT_PRIVATE|FUTEX_CLOCK_REALTIME),
+ #define XLAT_VAL_27 ((unsigned) (FUTEX_WAIT_PRIVATE|FUTEX_CLOCK_REALTIME))
+ #define XLAT_STR_27 STRINGIFY(FUTEX_WAIT_PRIVATE|FUTEX_CLOCK_REALTIME)
 #endif
 #if defined(FUTEX_WAIT_BITSET) || (defined(HAVE_DECL_FUTEX_WAIT_BITSET) && HAVE_DECL_FUTEX_WAIT_BITSET)
   XLAT(FUTEX_WAIT_BITSET|FUTEX_CLOCK_REALTIME),
+ #define XLAT_VAL_28 ((unsigned) (FUTEX_WAIT_BITSET|FUTEX_CLOCK_REALTIME))
+ #define XLAT_STR_28 STRINGIFY(FUTEX_WAIT_BITSET|FUTEX_CLOCK_REALTIME)
 #endif
 #if defined(FUTEX_WAIT_BITSET_PRIVATE) || (defined(HAVE_DECL_FUTEX_WAIT_BITSET_PRIVATE) && HAVE_DECL_FUTEX_WAIT_BITSET_PRIVATE)
   XLAT(FUTEX_WAIT_BITSET_PRIVATE|FUTEX_CLOCK_REALTIME),
+ #define XLAT_VAL_29 ((unsigned) (FUTEX_WAIT_BITSET_PRIVATE|FUTEX_CLOCK_REALTIME))
+ #define XLAT_STR_29 STRINGIFY(FUTEX_WAIT_BITSET_PRIVATE|FUTEX_CLOCK_REALTIME)
 #endif
 #if defined(FUTEX_WAIT_REQUEUE_PI) || (defined(HAVE_DECL_FUTEX_WAIT_REQUEUE_PI) && HAVE_DECL_FUTEX_WAIT_REQUEUE_PI)
   XLAT(FUTEX_WAIT_REQUEUE_PI|FUTEX_CLOCK_REALTIME),
+ #define XLAT_VAL_30 ((unsigned) (FUTEX_WAIT_REQUEUE_PI|FUTEX_CLOCK_REALTIME))
+ #define XLAT_STR_30 STRINGIFY(FUTEX_WAIT_REQUEUE_PI|FUTEX_CLOCK_REALTIME)
 #endif
 #if defined(FUTEX_WAIT_REQUEUE_PI_PRIVATE) || (defined(HAVE_DECL_FUTEX_WAIT_REQUEUE_PI_PRIVATE) && HAVE_DECL_FUTEX_WAIT_REQUEUE_PI_PRIVATE)
   XLAT(FUTEX_WAIT_REQUEUE_PI_PRIVATE|FUTEX_CLOCK_REALTIME),
+ #define XLAT_VAL_31 ((unsigned) (FUTEX_WAIT_REQUEUE_PI_PRIVATE|FUTEX_CLOCK_REALTIME))
+ #define XLAT_STR_31 STRINGIFY(FUTEX_WAIT_REQUEUE_PI_PRIVATE|FUTEX_CLOCK_REALTIME)
 #endif
 };
 static
@@ -240,8 +304,268 @@ const struct xlat futexops[1] = { {
  .data = futexops_xdata,
  .size = ARRAY_SIZE(futexops_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/futexwakecmps.h 5.9-0ubuntu2/xlat/futexwakecmps.h
--- 5.5-3/xlat/futexwakecmps.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/futexwakecmps.h	2020-09-24 09:18:44.000000000 +0000
@@ -56,19 +56,83 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data futexwakecmps_xdata[] = {
  [FUTEX_OP_CMP_EQ] = XLAT(FUTEX_OP_CMP_EQ),
+ #define XLAT_VAL_0 ((unsigned) (FUTEX_OP_CMP_EQ))
+ #define XLAT_STR_0 STRINGIFY(FUTEX_OP_CMP_EQ)
  [FUTEX_OP_CMP_NE] = XLAT(FUTEX_OP_CMP_NE),
+ #define XLAT_VAL_1 ((unsigned) (FUTEX_OP_CMP_NE))
+ #define XLAT_STR_1 STRINGIFY(FUTEX_OP_CMP_NE)
  [FUTEX_OP_CMP_LT] = XLAT(FUTEX_OP_CMP_LT),
+ #define XLAT_VAL_2 ((unsigned) (FUTEX_OP_CMP_LT))
+ #define XLAT_STR_2 STRINGIFY(FUTEX_OP_CMP_LT)
  [FUTEX_OP_CMP_LE] = XLAT(FUTEX_OP_CMP_LE),
+ #define XLAT_VAL_3 ((unsigned) (FUTEX_OP_CMP_LE))
+ #define XLAT_STR_3 STRINGIFY(FUTEX_OP_CMP_LE)
  [FUTEX_OP_CMP_GT] = XLAT(FUTEX_OP_CMP_GT),
+ #define XLAT_VAL_4 ((unsigned) (FUTEX_OP_CMP_GT))
+ #define XLAT_STR_4 STRINGIFY(FUTEX_OP_CMP_GT)
  [FUTEX_OP_CMP_GE] = XLAT(FUTEX_OP_CMP_GE),
+ #define XLAT_VAL_5 ((unsigned) (FUTEX_OP_CMP_GE))
+ #define XLAT_STR_5 STRINGIFY(FUTEX_OP_CMP_GE)
 };
 static
 const struct xlat futexwakecmps[1] = { {
  .data = futexwakecmps_xdata,
  .size = ARRAY_SIZE(futexwakecmps_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/futexwakeops.h 5.9-0ubuntu2/xlat/futexwakeops.h
--- 5.5-3/xlat/futexwakeops.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/futexwakeops.h	2020-09-24 09:18:44.000000000 +0000
@@ -49,18 +49,72 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data futexwakeops_xdata[] = {
  [FUTEX_OP_SET] = XLAT(FUTEX_OP_SET),
+ #define XLAT_VAL_0 ((unsigned) (FUTEX_OP_SET))
+ #define XLAT_STR_0 STRINGIFY(FUTEX_OP_SET)
  [FUTEX_OP_ADD] = XLAT(FUTEX_OP_ADD),
+ #define XLAT_VAL_1 ((unsigned) (FUTEX_OP_ADD))
+ #define XLAT_STR_1 STRINGIFY(FUTEX_OP_ADD)
  [FUTEX_OP_OR] = XLAT(FUTEX_OP_OR),
+ #define XLAT_VAL_2 ((unsigned) (FUTEX_OP_OR))
+ #define XLAT_STR_2 STRINGIFY(FUTEX_OP_OR)
  [FUTEX_OP_ANDN] = XLAT(FUTEX_OP_ANDN),
+ #define XLAT_VAL_3 ((unsigned) (FUTEX_OP_ANDN))
+ #define XLAT_STR_3 STRINGIFY(FUTEX_OP_ANDN)
  [FUTEX_OP_XOR] = XLAT(FUTEX_OP_XOR),
+ #define XLAT_VAL_4 ((unsigned) (FUTEX_OP_XOR))
+ #define XLAT_STR_4 STRINGIFY(FUTEX_OP_XOR)
 };
 static
 const struct xlat futexwakeops[1] = { {
  .data = futexwakeops_xdata,
  .size = ARRAY_SIZE(futexwakeops_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/gen.sh 5.9-0ubuntu2/xlat/gen.sh
--- 5.5-3/xlat/gen.sh	2019-08-14 19:05:08.000000000 +0000
+++ 5.9-0ubuntu2/xlat/gen.sh	2020-09-18 17:52:40.000000000 +0000
@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2014-2015 Mike Frysinger <vapier@gentoo.org>
 # Copyright (c) 2014-2015 Dmitry V. Levin <ldv@altlinux.org>
-# Copyright (c) 2014-2019 The strace developers.
+# Copyright (c) 2014-2020 The strace developers.
 # All rights reserved.
 #
 # SPDX-License-Identifier: LGPL-2.1-or-later
@@ -20,6 +20,22 @@ EOF
 	exit 1
 }
 
+print_m4_record()
+{
+	local val output
+	val="$1"; shift
+	output="$1"; shift
+	[ -n "$output" ] || return 0
+
+	if [ "$first_enum" = 1 ]; then
+		printf '%s' "$val"
+	else
+		printf ',\n%s' "$val"
+	fi >> "$output"
+
+	first_enum=0
+}
+
 cond_def()
 {
 	local line
@@ -60,13 +76,20 @@ print_xlat()
 	else
 		echo " XLAT_TYPE(${val_type}, ${val}),"
 	fi
+
+	echo " #define XLAT_VAL_$xlat_flag_cnt ((${val_type:-unsigned}) (${val}))"
+	echo " #define XLAT_STR_$xlat_flag_cnt STRINGIFY(${val})"
+	xlat_flag_cnt=$((xlat_flag_cnt + 1))
+
+	[ -z "$enum" ] || print_m4_record "$val" "$output_m4"
 }
 
 print_xlat_pair()
 {
-	local val str
+	local val str macro
 	val="$1"; shift
 	str="$1"; shift
+	macro="$1"; shift
 
 	[ 1 = "$value_indexed" ] && printf " [%s] =" "${val}"
 	if [ -z "${val_type-}" ]; then
@@ -74,6 +97,12 @@ print_xlat_pair()
 	else
 		echo " XLAT_TYPE_PAIR(${val_type}, ${val}, \"${str}\"),"
 	fi
+
+	echo " #define XLAT_VAL_$xlat_flag_cnt ((${val_type:-unsigned}) (${val}))"
+	echo " #define XLAT_STR_$xlat_flag_cnt \"${str}\""
+	xlat_flag_cnt=$((xlat_flag_cnt + 1))
+
+	[ -z "$enum" ] || print_m4_record "$macro" "$output_m4"
 }
 
 cond_xlat()
@@ -88,8 +117,8 @@ cond_xlat()
 		if [ "${m}" = "${m#1<<}" ]; then
 			xlat="$(print_xlat "${val}")"
 		else
-			xlat="$(print_xlat_pair "1ULL<<${val#1<<}" "${val}")"
 			m="${m#1<<}"
+			xlat="$(print_xlat_pair "1ULL<<${val#1<<}" "${val}" "$m")"
 		fi
 
 		if [ -z "${def}" ]; then
@@ -101,20 +130,31 @@ cond_xlat()
 			echo "$xlat"
 		fi
 	}
+
+	# Since we're calling print_xlat/print_xlat_pair in subprocess
+	xlat_flag_cnt=$((xlat_flag_cnt + 1))
+	first_enum=0
 }
 
 gen_header()
 {
-	local input="$1" output="$2" name="$3"
-	echo "generating ${output}"
+	local input="$1" output="$2" name="$3" output_m4="$4"
+
+	exec 3>&1
+
+	echo "generating ${output}" >&2
 	(
 	local defs="${0%/*}/../defs.h"
 	local mpers="${0%/*}/../mpers_xlat.h"
 	local decl="extern const struct xlat ${name}[];"
 	local in_defs= in_mpers=
 	local xlat_type="XT_NORMAL"
+	local includes=""
+	local enum=""
 
+	first_enum=1
 	value_indexed=0
+	xlat_flag_cnt=0
 
 	if grep -F -q -x "$decl" "$defs"; then
 		in_defs=1
@@ -157,6 +197,12 @@ gen_header()
 			value_indexed=1
 			xlat_type="XT_INDEXED"
 			;;
+		'#enum')
+			[ -z "$output_m4" ] || enum=1
+			;;
+		'#include '*)
+			includes="${includes} ${line###include }"
+			;;
 		'#'*)
 			echo "${line}"
 			;;
@@ -173,6 +219,14 @@ gen_header()
 
 	EOF
 
+	[ "$enum" != 1 ] || (
+		echo "generating ${output_m4}" >&2
+		printf 'dnl Generated by %s from %s; do not edit.\n' \
+			"$0" "$input"
+		printf 'AC_DEFUN([st_CHECK_ENUMS_%s],[\n' "$name"
+		printf 'AC_CHECK_DECLS(m4_normalize([\n'
+	) > "${output_m4}"
+
 	if [ -n "$in_defs" ]; then
 		cat <<-EOF
 			# ifndef IN_MPERS
@@ -221,6 +275,10 @@ gen_header()
 			;;
 		'#value_indexed')
 			;;
+		'#enum')
+			;;
+		'#include '*)
+			;;
 		'#val_type '*)
 			val_type="${line#\#val_type }"
 			;;
@@ -233,7 +291,7 @@ gen_header()
 			;;
 		'1<<'[A-Z_]*)	# symbolic constants with shift
 			if [ -n "${unconditional}" ]; then
-				print_xlat_pair "1ULL<<${line#1<<}" "${line}"
+				print_xlat_pair "1ULL<<${line#1<<}" "${line}" "${line#1<<}"
 			else
 				cond_xlat "${line}"
 			fi
@@ -248,6 +306,15 @@ gen_header()
 	done < "${input}"
 	echo '};'
 
+	[ "$enum" != 1 ] || (
+		printf '\n]),,, [\n'
+		[ -z "$includes" ] || printf '#include %s\n' $includes
+		printf '])])])\n'
+
+		# Providing macro name to main
+		echo "st_CHECK_ENUMS_${name}" >&3
+	) >> "${output_m4}"
+
 	if [ -n "$in_defs" ]; then
 		:
 	elif [ -n "$in_mpers" ]; then
@@ -267,13 +334,48 @@ gen_header()
 			 .data = ${name}_xdata,
 			 .size = ARRAY_SIZE(${name}_xdata),
 			 .type = ${xlat_type},
+	EOF
+
+	echo " .flags_mask = 0"
+	for i in $(seq 0 "$((xlat_flag_cnt - 1))"); do
+		cat <<-EOF
+			#  ifdef XLAT_VAL_${i}
+			  | XLAT_VAL_${i}
+			#  endif
+		EOF
+	done
+	echo "  ,"
+
+	echo " .flags_strsz = 0"
+	for i in $(seq 0 "$((xlat_flag_cnt - 1))"); do
+		cat <<-EOF
+			#  ifdef XLAT_STR_${i}
+			  + sizeof(XLAT_STR_${i})
+			#  endif
+		EOF
+	done
+	echo "  ,"
+
+	cat <<-EOF
 		} };
 
+	EOF
+
+	for i in $(seq 0 "$((xlat_flag_cnt - 1))"); do
+		cat <<-EOF
+			#  undef XLAT_STR_${i}
+			#  undef XLAT_VAL_${i}
+		EOF
+	done
+
+	cat <<-EOF
 		# endif /* !IN_MPERS */
 
 		#endif /* !XLAT_MACROS_ONLY */
 	EOF
 	) >"${output}"
+
+	exec 3>&-
 }
 
 gen_make()
@@ -281,7 +383,7 @@ gen_make()
 	local output="$1"
 	local name
 	shift
-	echo "generating ${output}"
+	echo "generating ${output}" >&2
 	(
 		printf "XLAT_INPUT_FILES = "
 		printf 'xlat/%s.in ' "$@"
@@ -301,23 +403,41 @@ gen_git()
 {
 	local output="$1"
 	shift
-	echo "generating ${output}"
+	echo "generating ${output}" >&2
 	(
-		printf '/%s\n' .gitignore Makemodule.am
+		printf '/%s\n' .gitignore Makemodule.am st_check_enums.m4
 		printf '/%s.h\n' "$@"
+		printf '/%s.m4\n' "$@"
 	) >"${output}"
 }
 
+gen_m4_entry()
+{
+	local output
+	output="$1"; shift
+
+	echo "generating $output" >&2
+	{
+		printf 'AC_DEFUN([st_CHECK_ENUMS],[\n'
+		while read fun; do
+			printf '\t%s\n' "$fun"
+		done
+		printf '])\n'
+	} >"$output"
+}
+
 main()
 {
 	case $# in
 	0) set -- "${0%/*}" "${0%/*}" ;;
 	2) ;;
+	3) ;;
 	*) usage ;;
 	esac
 
 	local input="$1"
 	local output="$2"
+	local output_m4="${3:-}"
 	local name
 	local jobs=0
 	local ncpus="$(getconf _NPROCESSORS_ONLN)"
@@ -326,6 +446,7 @@ main()
 		ncpus=1
 
 	if [ -d "${input}" ]; then
+		(
 		local f names=
 		set +f
 		set -- "${input}"/*.in
@@ -334,7 +455,8 @@ main()
 			[ -f "${f}" ] || continue
 			name=${f##*/}
 			name=${name%.in}
-			gen_header "${f}" "${output}/${name}.h" "${name}" &
+			gen_header "${f}" "${output}/${name}.h" "${name}" \
+				"${output}/${name}.m4" &
 			pids="$pids $!"
 			names="${names} ${name}"
 			: $(( jobs += 1 ))
@@ -350,10 +472,12 @@ main()
 		gen_git "${output}/.gitignore" ${names} &
 		gen_make "${output}/Makemodule.am" ${names} &
 		wait
+		) | sort | gen_m4_entry "${output}/st_check_enums.m4"
 	else
 		name=${input##*/}
 		name=${name%.in}
-		gen_header "${input}" "${output}" "${name}"
+		gen_header "${input}" "${output}" "${name}" "${output_m4}" \
+			> /dev/null
 	fi
 }
 
diff -pruN 5.5-3/xlat/get_mempolicy_flags.h 5.9-0ubuntu2/xlat/get_mempolicy_flags.h
--- 5.5-3/xlat/get_mempolicy_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/get_mempolicy_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data get_mempolicy_flags_xdata[] = {
  XLAT(MPOL_F_NODE),
+ #define XLAT_VAL_0 ((unsigned) (MPOL_F_NODE))
+ #define XLAT_STR_0 STRINGIFY(MPOL_F_NODE)
  XLAT(MPOL_F_ADDR),
+ #define XLAT_VAL_1 ((unsigned) (MPOL_F_ADDR))
+ #define XLAT_STR_1 STRINGIFY(MPOL_F_ADDR)
  XLAT(MPOL_F_MEMS_ALLOWED),
+ #define XLAT_VAL_2 ((unsigned) (MPOL_F_MEMS_ALLOWED))
+ #define XLAT_STR_2 STRINGIFY(MPOL_F_MEMS_ALLOWED)
 };
 static
 const struct xlat get_mempolicy_flags[1] = { {
  .data = get_mempolicy_flags_xdata,
  .size = ARRAY_SIZE(get_mempolicy_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/getrandom_flags.h 5.9-0ubuntu2/xlat/getrandom_flags.h
--- 5.5-3/xlat/getrandom_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/getrandom_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -17,6 +17,13 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define GRND_RANDOM 2
 #endif
+#if defined(GRND_INSECURE) || (defined(HAVE_DECL_GRND_INSECURE) && HAVE_DECL_GRND_INSECURE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((GRND_INSECURE) == (4), "GRND_INSECURE != 4");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define GRND_INSECURE 4
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -28,15 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data getrandom_flags_xdata[] = {
  XLAT(GRND_NONBLOCK),
+ #define XLAT_VAL_0 ((unsigned) (GRND_NONBLOCK))
+ #define XLAT_STR_0 STRINGIFY(GRND_NONBLOCK)
  XLAT(GRND_RANDOM),
+ #define XLAT_VAL_1 ((unsigned) (GRND_RANDOM))
+ #define XLAT_STR_1 STRINGIFY(GRND_RANDOM)
+ XLAT(GRND_INSECURE),
+ #define XLAT_VAL_2 ((unsigned) (GRND_INSECURE))
+ #define XLAT_STR_2 STRINGIFY(GRND_INSECURE)
 };
 static
 const struct xlat getrandom_flags[1] = { {
  .data = getrandom_flags_xdata,
  .size = ARRAY_SIZE(getrandom_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/getrandom_flags.in 5.9-0ubuntu2/xlat/getrandom_flags.in
--- 5.5-3/xlat/getrandom_flags.in	2015-11-20 05:44:49.000000000 +0000
+++ 5.9-0ubuntu2/xlat/getrandom_flags.in	2020-03-01 23:25:39.000000000 +0000
@@ -1,2 +1,3 @@
 GRND_NONBLOCK	1
 GRND_RANDOM	2
+GRND_INSECURE	4
diff -pruN 5.5-3/xlat/getsock_ip_options.h 5.9-0ubuntu2/xlat/getsock_ip_options.h
--- 5.5-3/xlat/getsock_ip_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/getsock_ip_options.h	2020-09-24 09:18:44.000000000 +0000
@@ -21,66 +21,106 @@ static const struct xlat_data getsock_ip
 
 #if defined(ARPT_SO_GET_INFO) || (defined(HAVE_DECL_ARPT_SO_GET_INFO) && HAVE_DECL_ARPT_SO_GET_INFO)
   XLAT(ARPT_SO_GET_INFO),
+ #define XLAT_VAL_0 ((unsigned) (ARPT_SO_GET_INFO))
+ #define XLAT_STR_0 STRINGIFY(ARPT_SO_GET_INFO)
 #endif
 #if defined(ARPT_SO_GET_ENTRIES) || (defined(HAVE_DECL_ARPT_SO_GET_ENTRIES) && HAVE_DECL_ARPT_SO_GET_ENTRIES)
   XLAT(ARPT_SO_GET_ENTRIES),
+ #define XLAT_VAL_1 ((unsigned) (ARPT_SO_GET_ENTRIES))
+ #define XLAT_STR_1 STRINGIFY(ARPT_SO_GET_ENTRIES)
 #endif
 #if defined(ARPT_SO_GET_REVISION_MATCH) || (defined(HAVE_DECL_ARPT_SO_GET_REVISION_MATCH) && HAVE_DECL_ARPT_SO_GET_REVISION_MATCH)
   XLAT(ARPT_SO_GET_REVISION_MATCH),
+ #define XLAT_VAL_2 ((unsigned) (ARPT_SO_GET_REVISION_MATCH))
+ #define XLAT_STR_2 STRINGIFY(ARPT_SO_GET_REVISION_MATCH)
 #endif
 #if defined(ARPT_SO_GET_REVISION_TARGET) || (defined(HAVE_DECL_ARPT_SO_GET_REVISION_TARGET) && HAVE_DECL_ARPT_SO_GET_REVISION_TARGET)
   XLAT(ARPT_SO_GET_REVISION_TARGET),
+ #define XLAT_VAL_3 ((unsigned) (ARPT_SO_GET_REVISION_TARGET))
+ #define XLAT_STR_3 STRINGIFY(ARPT_SO_GET_REVISION_TARGET)
 #endif
 
 #if defined(EBT_SO_GET_INFO) || (defined(HAVE_DECL_EBT_SO_GET_INFO) && HAVE_DECL_EBT_SO_GET_INFO)
   XLAT(EBT_SO_GET_INFO),
+ #define XLAT_VAL_4 ((unsigned) (EBT_SO_GET_INFO))
+ #define XLAT_STR_4 STRINGIFY(EBT_SO_GET_INFO)
 #endif
 #if defined(EBT_SO_GET_ENTRIES) || (defined(HAVE_DECL_EBT_SO_GET_ENTRIES) && HAVE_DECL_EBT_SO_GET_ENTRIES)
   XLAT(EBT_SO_GET_ENTRIES),
+ #define XLAT_VAL_5 ((unsigned) (EBT_SO_GET_ENTRIES))
+ #define XLAT_STR_5 STRINGIFY(EBT_SO_GET_ENTRIES)
 #endif
 #if defined(EBT_SO_GET_INIT_INFO) || (defined(HAVE_DECL_EBT_SO_GET_INIT_INFO) && HAVE_DECL_EBT_SO_GET_INIT_INFO)
   XLAT(EBT_SO_GET_INIT_INFO),
+ #define XLAT_VAL_6 ((unsigned) (EBT_SO_GET_INIT_INFO))
+ #define XLAT_STR_6 STRINGIFY(EBT_SO_GET_INIT_INFO)
 #endif
 #if defined(EBT_SO_GET_INIT_ENTRIES) || (defined(HAVE_DECL_EBT_SO_GET_INIT_ENTRIES) && HAVE_DECL_EBT_SO_GET_INIT_ENTRIES)
   XLAT(EBT_SO_GET_INIT_ENTRIES),
+ #define XLAT_VAL_7 ((unsigned) (EBT_SO_GET_INIT_ENTRIES))
+ #define XLAT_STR_7 STRINGIFY(EBT_SO_GET_INIT_ENTRIES)
 #endif
 
 #if defined(IP_VS_SO_GET_VERSION) || (defined(HAVE_DECL_IP_VS_SO_GET_VERSION) && HAVE_DECL_IP_VS_SO_GET_VERSION)
   XLAT(IP_VS_SO_GET_VERSION),
+ #define XLAT_VAL_8 ((unsigned) (IP_VS_SO_GET_VERSION))
+ #define XLAT_STR_8 STRINGIFY(IP_VS_SO_GET_VERSION)
 #endif
 #if defined(IP_VS_SO_GET_INFO) || (defined(HAVE_DECL_IP_VS_SO_GET_INFO) && HAVE_DECL_IP_VS_SO_GET_INFO)
   XLAT(IP_VS_SO_GET_INFO),
+ #define XLAT_VAL_9 ((unsigned) (IP_VS_SO_GET_INFO))
+ #define XLAT_STR_9 STRINGIFY(IP_VS_SO_GET_INFO)
 #endif
 #if defined(IP_VS_SO_GET_SERVICES) || (defined(HAVE_DECL_IP_VS_SO_GET_SERVICES) && HAVE_DECL_IP_VS_SO_GET_SERVICES)
   XLAT(IP_VS_SO_GET_SERVICES),
+ #define XLAT_VAL_10 ((unsigned) (IP_VS_SO_GET_SERVICES))
+ #define XLAT_STR_10 STRINGIFY(IP_VS_SO_GET_SERVICES)
 #endif
 #if defined(IP_VS_SO_GET_SERVICE) || (defined(HAVE_DECL_IP_VS_SO_GET_SERVICE) && HAVE_DECL_IP_VS_SO_GET_SERVICE)
   XLAT(IP_VS_SO_GET_SERVICE),
+ #define XLAT_VAL_11 ((unsigned) (IP_VS_SO_GET_SERVICE))
+ #define XLAT_STR_11 STRINGIFY(IP_VS_SO_GET_SERVICE)
 #endif
 #if defined(IP_VS_SO_GET_DESTS) || (defined(HAVE_DECL_IP_VS_SO_GET_DESTS) && HAVE_DECL_IP_VS_SO_GET_DESTS)
   XLAT(IP_VS_SO_GET_DESTS),
+ #define XLAT_VAL_12 ((unsigned) (IP_VS_SO_GET_DESTS))
+ #define XLAT_STR_12 STRINGIFY(IP_VS_SO_GET_DESTS)
 #endif
 #if defined(IP_VS_SO_GET_DEST) || (defined(HAVE_DECL_IP_VS_SO_GET_DEST) && HAVE_DECL_IP_VS_SO_GET_DEST)
   XLAT(IP_VS_SO_GET_DEST),
+ #define XLAT_VAL_13 ((unsigned) (IP_VS_SO_GET_DEST))
+ #define XLAT_STR_13 STRINGIFY(IP_VS_SO_GET_DEST)
 #endif
 #if defined(IP_VS_SO_GET_TIMEOUT) || (defined(HAVE_DECL_IP_VS_SO_GET_TIMEOUT) && HAVE_DECL_IP_VS_SO_GET_TIMEOUT)
   XLAT(IP_VS_SO_GET_TIMEOUT),
+ #define XLAT_VAL_14 ((unsigned) (IP_VS_SO_GET_TIMEOUT))
+ #define XLAT_STR_14 STRINGIFY(IP_VS_SO_GET_TIMEOUT)
 #endif
 #if defined(IP_VS_SO_GET_DAEMON) || (defined(HAVE_DECL_IP_VS_SO_GET_DAEMON) && HAVE_DECL_IP_VS_SO_GET_DAEMON)
   XLAT(IP_VS_SO_GET_DAEMON),
+ #define XLAT_VAL_15 ((unsigned) (IP_VS_SO_GET_DAEMON))
+ #define XLAT_STR_15 STRINGIFY(IP_VS_SO_GET_DAEMON)
 #endif
 
 #if defined(IPT_SO_GET_INFO) || (defined(HAVE_DECL_IPT_SO_GET_INFO) && HAVE_DECL_IPT_SO_GET_INFO)
   XLAT(IPT_SO_GET_INFO),
+ #define XLAT_VAL_16 ((unsigned) (IPT_SO_GET_INFO))
+ #define XLAT_STR_16 STRINGIFY(IPT_SO_GET_INFO)
 #endif
 #if defined(IPT_SO_GET_ENTRIES) || (defined(HAVE_DECL_IPT_SO_GET_ENTRIES) && HAVE_DECL_IPT_SO_GET_ENTRIES)
   XLAT(IPT_SO_GET_ENTRIES),
+ #define XLAT_VAL_17 ((unsigned) (IPT_SO_GET_ENTRIES))
+ #define XLAT_STR_17 STRINGIFY(IPT_SO_GET_ENTRIES)
 #endif
 #if defined(IPT_SO_GET_REVISION_MATCH) || (defined(HAVE_DECL_IPT_SO_GET_REVISION_MATCH) && HAVE_DECL_IPT_SO_GET_REVISION_MATCH)
   XLAT(IPT_SO_GET_REVISION_MATCH),
+ #define XLAT_VAL_18 ((unsigned) (IPT_SO_GET_REVISION_MATCH))
+ #define XLAT_STR_18 STRINGIFY(IPT_SO_GET_REVISION_MATCH)
 #endif
 #if defined(IPT_SO_GET_REVISION_TARGET) || (defined(HAVE_DECL_IPT_SO_GET_REVISION_TARGET) && HAVE_DECL_IPT_SO_GET_REVISION_TARGET)
   XLAT(IPT_SO_GET_REVISION_TARGET),
+ #define XLAT_VAL_19 ((unsigned) (IPT_SO_GET_REVISION_TARGET))
+ #define XLAT_STR_19 STRINGIFY(IPT_SO_GET_REVISION_TARGET)
 #endif
 };
 static
@@ -88,8 +128,172 @@ const struct xlat getsock_ip_options[1]
  .data = getsock_ip_options_xdata,
  .size = ARRAY_SIZE(getsock_ip_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/getsock_ipv6_options.h 5.9-0ubuntu2/xlat/getsock_ipv6_options.h
--- 5.5-3/xlat/getsock_ipv6_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/getsock_ipv6_options.h	2020-09-24 09:18:44.000000000 +0000
@@ -21,15 +21,23 @@ static const struct xlat_data getsock_ip
 
 #if defined(IP6T_SO_GET_INFO) || (defined(HAVE_DECL_IP6T_SO_GET_INFO) && HAVE_DECL_IP6T_SO_GET_INFO)
   XLAT(IP6T_SO_GET_INFO),
+ #define XLAT_VAL_0 ((unsigned) (IP6T_SO_GET_INFO))
+ #define XLAT_STR_0 STRINGIFY(IP6T_SO_GET_INFO)
 #endif
 #if defined(IP6T_SO_GET_ENTRIES) || (defined(HAVE_DECL_IP6T_SO_GET_ENTRIES) && HAVE_DECL_IP6T_SO_GET_ENTRIES)
   XLAT(IP6T_SO_GET_ENTRIES),
+ #define XLAT_VAL_1 ((unsigned) (IP6T_SO_GET_ENTRIES))
+ #define XLAT_STR_1 STRINGIFY(IP6T_SO_GET_ENTRIES)
 #endif
 #if defined(IP6T_SO_GET_REVISION_MATCH) || (defined(HAVE_DECL_IP6T_SO_GET_REVISION_MATCH) && HAVE_DECL_IP6T_SO_GET_REVISION_MATCH)
   XLAT(IP6T_SO_GET_REVISION_MATCH),
+ #define XLAT_VAL_2 ((unsigned) (IP6T_SO_GET_REVISION_MATCH))
+ #define XLAT_STR_2 STRINGIFY(IP6T_SO_GET_REVISION_MATCH)
 #endif
 #if defined(IP6T_SO_GET_REVISION_TARGET) || (defined(HAVE_DECL_IP6T_SO_GET_REVISION_TARGET) && HAVE_DECL_IP6T_SO_GET_REVISION_TARGET)
   XLAT(IP6T_SO_GET_REVISION_TARGET),
+ #define XLAT_VAL_3 ((unsigned) (IP6T_SO_GET_REVISION_TARGET))
+ #define XLAT_STR_3 STRINGIFY(IP6T_SO_GET_REVISION_TARGET)
 #endif
 };
 static
@@ -37,8 +45,44 @@ const struct xlat getsock_ipv6_options[1
  .data = getsock_ipv6_options_xdata,
  .size = ARRAY_SIZE(getsock_ipv6_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/getsock_options.h 5.9-0ubuntu2/xlat/getsock_options.h
--- 5.5-3/xlat/getsock_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/getsock_options.h	2020-09-24 09:18:44.000000000 +0000
@@ -32,8 +32,12 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 static const struct xlat_data getsock_options_xdata[] = {
 #if defined __hppa__
  XLAT(SO_GET_FILTER),
+ #define XLAT_VAL_0 ((unsigned) (SO_GET_FILTER))
+ #define XLAT_STR_0 STRINGIFY(SO_GET_FILTER)
 #else
  XLAT(SO_GET_FILTER),
+ #define XLAT_VAL_1 ((unsigned) (SO_GET_FILTER))
+ #define XLAT_STR_1 STRINGIFY(SO_GET_FILTER)
 #endif
 };
 static
@@ -41,8 +45,28 @@ const struct xlat getsock_options[1] = {
  .data = getsock_options_xdata,
  .size = ARRAY_SIZE(getsock_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/hci_channels.h 5.9-0ubuntu2/xlat/hci_channels.h
--- 5.5-3/xlat/hci_channels.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/hci_channels.h	2020-09-24 09:18:44.000000000 +0000
@@ -49,18 +49,72 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data hci_channels_xdata[] = {
  [HCI_CHANNEL_RAW] = XLAT(HCI_CHANNEL_RAW),
+ #define XLAT_VAL_0 ((unsigned) (HCI_CHANNEL_RAW))
+ #define XLAT_STR_0 STRINGIFY(HCI_CHANNEL_RAW)
  [HCI_CHANNEL_USER] = XLAT(HCI_CHANNEL_USER),
+ #define XLAT_VAL_1 ((unsigned) (HCI_CHANNEL_USER))
+ #define XLAT_STR_1 STRINGIFY(HCI_CHANNEL_USER)
  [HCI_CHANNEL_MONITOR] = XLAT(HCI_CHANNEL_MONITOR),
+ #define XLAT_VAL_2 ((unsigned) (HCI_CHANNEL_MONITOR))
+ #define XLAT_STR_2 STRINGIFY(HCI_CHANNEL_MONITOR)
  [HCI_CHANNEL_CONTROL] = XLAT(HCI_CHANNEL_CONTROL),
+ #define XLAT_VAL_3 ((unsigned) (HCI_CHANNEL_CONTROL))
+ #define XLAT_STR_3 STRINGIFY(HCI_CHANNEL_CONTROL)
  [HCI_CHANNEL_LOGGING] = XLAT(HCI_CHANNEL_LOGGING),
+ #define XLAT_VAL_4 ((unsigned) (HCI_CHANNEL_LOGGING))
+ #define XLAT_STR_4 STRINGIFY(HCI_CHANNEL_LOGGING)
 };
 static
 const struct xlat hci_channels[1] = { {
  .data = hci_channels_xdata,
  .size = ARRAY_SIZE(hci_channels_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/hdio_drive_cmds.h 5.9-0ubuntu2/xlat/hdio_drive_cmds.h
--- 5.5-3/xlat/hdio_drive_cmds.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/hdio_drive_cmds.h	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,1706 @@
+/* Generated by ./xlat/gen.sh from ./xlat/hdio_drive_cmds.in; do not edit. */
+
+#include "gcc_compat.h"
+#include "static_assert.h"
+
+#if defined(ATA_CMD_NOP) || (defined(HAVE_DECL_ATA_CMD_NOP) && HAVE_DECL_ATA_CMD_NOP)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_NOP) == (0x00), "ATA_CMD_NOP != 0x00");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_NOP 0x00
+#endif
+#if defined(ATA_CMD_CFA_REQ_EXT_ERR) || (defined(HAVE_DECL_ATA_CMD_CFA_REQ_EXT_ERR) && HAVE_DECL_ATA_CMD_CFA_REQ_EXT_ERR)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_CFA_REQ_EXT_ERR) == (0x03), "ATA_CMD_CFA_REQ_EXT_ERR != 0x03");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_CFA_REQ_EXT_ERR 0x03
+#endif
+#if defined(ATA_CMD_DSM) || (defined(HAVE_DECL_ATA_CMD_DSM) && HAVE_DECL_ATA_CMD_DSM)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_DSM) == (0x06), "ATA_CMD_DSM != 0x06");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_DSM 0x06
+#endif
+#if defined(ATA_CMD_DEV_RESET) || (defined(HAVE_DECL_ATA_CMD_DEV_RESET) && HAVE_DECL_ATA_CMD_DEV_RESET)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_DEV_RESET) == (0x08), "ATA_CMD_DEV_RESET != 0x08");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_DEV_RESET 0x08
+#endif
+#if defined(ATA_CMD_REQ_SENSE_DATA) || (defined(HAVE_DECL_ATA_CMD_REQ_SENSE_DATA) && HAVE_DECL_ATA_CMD_REQ_SENSE_DATA)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_REQ_SENSE_DATA) == (0x0B), "ATA_CMD_REQ_SENSE_DATA != 0x0B");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_REQ_SENSE_DATA 0x0B
+#endif
+#if defined(ATA_CMD_RESTORE) || (defined(HAVE_DECL_ATA_CMD_RESTORE) && HAVE_DECL_ATA_CMD_RESTORE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_RESTORE) == (0x10), "ATA_CMD_RESTORE != 0x10");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_RESTORE 0x10
+#endif
+#if defined(ATA_CMD_PIO_READ) || (defined(HAVE_DECL_ATA_CMD_PIO_READ) && HAVE_DECL_ATA_CMD_PIO_READ)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_PIO_READ) == (0x20), "ATA_CMD_PIO_READ != 0x20");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_PIO_READ 0x20
+#endif
+#if defined(ATA_CMD_READ_LONG) || (defined(HAVE_DECL_ATA_CMD_READ_LONG) && HAVE_DECL_ATA_CMD_READ_LONG)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_READ_LONG) == (0x22), "ATA_CMD_READ_LONG != 0x22");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_READ_LONG 0x22
+#endif
+#if defined(ATA_CMD_READ_LONG_ONCE) || (defined(HAVE_DECL_ATA_CMD_READ_LONG_ONCE) && HAVE_DECL_ATA_CMD_READ_LONG_ONCE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_READ_LONG_ONCE) == (0x23), "ATA_CMD_READ_LONG_ONCE != 0x23");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_READ_LONG_ONCE 0x23
+#endif
+#if defined(ATA_CMD_PIO_READ_EXT) || (defined(HAVE_DECL_ATA_CMD_PIO_READ_EXT) && HAVE_DECL_ATA_CMD_PIO_READ_EXT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_PIO_READ_EXT) == (0x24), "ATA_CMD_PIO_READ_EXT != 0x24");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_PIO_READ_EXT 0x24
+#endif
+#if defined(ATA_CMD_READ_EXT) || (defined(HAVE_DECL_ATA_CMD_READ_EXT) && HAVE_DECL_ATA_CMD_READ_EXT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_READ_EXT) == (0x25), "ATA_CMD_READ_EXT != 0x25");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_READ_EXT 0x25
+#endif
+#if defined(ATA_CMD_READ_QUEUED) || (defined(HAVE_DECL_ATA_CMD_READ_QUEUED) && HAVE_DECL_ATA_CMD_READ_QUEUED)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_READ_QUEUED) == (0x26), "ATA_CMD_READ_QUEUED != 0x26");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_READ_QUEUED 0x26
+#endif
+#if defined(ATA_CMD_READ_NATIVE_MAX_EXT) || (defined(HAVE_DECL_ATA_CMD_READ_NATIVE_MAX_EXT) && HAVE_DECL_ATA_CMD_READ_NATIVE_MAX_EXT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_READ_NATIVE_MAX_EXT) == (0x27), "ATA_CMD_READ_NATIVE_MAX_EXT != 0x27");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_READ_NATIVE_MAX_EXT 0x27
+#endif
+#if defined(ATA_CMD_READ_MULTI_EXT) || (defined(HAVE_DECL_ATA_CMD_READ_MULTI_EXT) && HAVE_DECL_ATA_CMD_READ_MULTI_EXT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_READ_MULTI_EXT) == (0x29), "ATA_CMD_READ_MULTI_EXT != 0x29");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_READ_MULTI_EXT 0x29
+#endif
+#if defined(ATA_CMD_READ_STREAM_DMA_EXT) || (defined(HAVE_DECL_ATA_CMD_READ_STREAM_DMA_EXT) && HAVE_DECL_ATA_CMD_READ_STREAM_DMA_EXT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_READ_STREAM_DMA_EXT) == (0x2A), "ATA_CMD_READ_STREAM_DMA_EXT != 0x2A");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_READ_STREAM_DMA_EXT 0x2A
+#endif
+#if defined(ATA_CMD_READ_STREAM_EXT) || (defined(HAVE_DECL_ATA_CMD_READ_STREAM_EXT) && HAVE_DECL_ATA_CMD_READ_STREAM_EXT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_READ_STREAM_EXT) == (0x2B), "ATA_CMD_READ_STREAM_EXT != 0x2B");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_READ_STREAM_EXT 0x2B
+#endif
+#if defined(ATA_CMD_READ_LOG_EXT) || (defined(HAVE_DECL_ATA_CMD_READ_LOG_EXT) && HAVE_DECL_ATA_CMD_READ_LOG_EXT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_READ_LOG_EXT) == (0x2F), "ATA_CMD_READ_LOG_EXT != 0x2F");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_READ_LOG_EXT 0x2F
+#endif
+#if defined(ATA_CMD_PIO_WRITE) || (defined(HAVE_DECL_ATA_CMD_PIO_WRITE) && HAVE_DECL_ATA_CMD_PIO_WRITE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_PIO_WRITE) == (0x30), "ATA_CMD_PIO_WRITE != 0x30");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_PIO_WRITE 0x30
+#endif
+#if defined(ATA_CMD_WRITE_LONG) || (defined(HAVE_DECL_ATA_CMD_WRITE_LONG) && HAVE_DECL_ATA_CMD_WRITE_LONG)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_WRITE_LONG) == (0x32), "ATA_CMD_WRITE_LONG != 0x32");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_WRITE_LONG 0x32
+#endif
+#if defined(ATA_CMD_WRITE_LONG_ONCE) || (defined(HAVE_DECL_ATA_CMD_WRITE_LONG_ONCE) && HAVE_DECL_ATA_CMD_WRITE_LONG_ONCE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_WRITE_LONG_ONCE) == (0x33), "ATA_CMD_WRITE_LONG_ONCE != 0x33");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_WRITE_LONG_ONCE 0x33
+#endif
+#if defined(ATA_CMD_PIO_WRITE_EXT) || (defined(HAVE_DECL_ATA_CMD_PIO_WRITE_EXT) && HAVE_DECL_ATA_CMD_PIO_WRITE_EXT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_PIO_WRITE_EXT) == (0x34), "ATA_CMD_PIO_WRITE_EXT != 0x34");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_PIO_WRITE_EXT 0x34
+#endif
+#if defined(ATA_CMD_WRITE_EXT) || (defined(HAVE_DECL_ATA_CMD_WRITE_EXT) && HAVE_DECL_ATA_CMD_WRITE_EXT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_WRITE_EXT) == (0x35), "ATA_CMD_WRITE_EXT != 0x35");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_WRITE_EXT 0x35
+#endif
+#if defined(ATA_CMD_WRITE_QUEUED) || (defined(HAVE_DECL_ATA_CMD_WRITE_QUEUED) && HAVE_DECL_ATA_CMD_WRITE_QUEUED)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_WRITE_QUEUED) == (0x36), "ATA_CMD_WRITE_QUEUED != 0x36");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_WRITE_QUEUED 0x36
+#endif
+#if defined(ATA_CMD_SET_MAX_EXT) || (defined(HAVE_DECL_ATA_CMD_SET_MAX_EXT) && HAVE_DECL_ATA_CMD_SET_MAX_EXT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_SET_MAX_EXT) == (0x37), "ATA_CMD_SET_MAX_EXT != 0x37");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_SET_MAX_EXT 0x37
+#endif
+#if defined(ATA_CMD_CFA_WRITE_NE) || (defined(HAVE_DECL_ATA_CMD_CFA_WRITE_NE) && HAVE_DECL_ATA_CMD_CFA_WRITE_NE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_CFA_WRITE_NE) == (0x38), "ATA_CMD_CFA_WRITE_NE != 0x38");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_CFA_WRITE_NE 0x38
+#endif
+#if defined(ATA_CMD_WRITE_MULTI_EXT) || (defined(HAVE_DECL_ATA_CMD_WRITE_MULTI_EXT) && HAVE_DECL_ATA_CMD_WRITE_MULTI_EXT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_WRITE_MULTI_EXT) == (0x39), "ATA_CMD_WRITE_MULTI_EXT != 0x39");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_WRITE_MULTI_EXT 0x39
+#endif
+#if defined(ATA_CMD_WRITE_STREAM_DMA_EXT) || (defined(HAVE_DECL_ATA_CMD_WRITE_STREAM_DMA_EXT) && HAVE_DECL_ATA_CMD_WRITE_STREAM_DMA_EXT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_WRITE_STREAM_DMA_EXT) == (0x3A), "ATA_CMD_WRITE_STREAM_DMA_EXT != 0x3A");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_WRITE_STREAM_DMA_EXT 0x3A
+#endif
+#if defined(ATA_CMD_WRITE_STREAM_EXT) || (defined(HAVE_DECL_ATA_CMD_WRITE_STREAM_EXT) && HAVE_DECL_ATA_CMD_WRITE_STREAM_EXT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_WRITE_STREAM_EXT) == (0x3B), "ATA_CMD_WRITE_STREAM_EXT != 0x3B");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_WRITE_STREAM_EXT 0x3B
+#endif
+#if defined(ATA_CMD_WRITE_FUA_EXT) || (defined(HAVE_DECL_ATA_CMD_WRITE_FUA_EXT) && HAVE_DECL_ATA_CMD_WRITE_FUA_EXT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_WRITE_FUA_EXT) == (0x3D), "ATA_CMD_WRITE_FUA_EXT != 0x3D");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_WRITE_FUA_EXT 0x3D
+#endif
+#if defined(ATA_CMD_WRITE_QUEUED_FUA_EXT) || (defined(HAVE_DECL_ATA_CMD_WRITE_QUEUED_FUA_EXT) && HAVE_DECL_ATA_CMD_WRITE_QUEUED_FUA_EXT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_WRITE_QUEUED_FUA_EXT) == (0x3E), "ATA_CMD_WRITE_QUEUED_FUA_EXT != 0x3E");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_WRITE_QUEUED_FUA_EXT 0x3E
+#endif
+#if defined(ATA_CMD_WRITE_LOG_EXT) || (defined(HAVE_DECL_ATA_CMD_WRITE_LOG_EXT) && HAVE_DECL_ATA_CMD_WRITE_LOG_EXT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_WRITE_LOG_EXT) == (0x3F), "ATA_CMD_WRITE_LOG_EXT != 0x3F");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_WRITE_LOG_EXT 0x3F
+#endif
+#if defined(ATA_CMD_VERIFY) || (defined(HAVE_DECL_ATA_CMD_VERIFY) && HAVE_DECL_ATA_CMD_VERIFY)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_VERIFY) == (0x40), "ATA_CMD_VERIFY != 0x40");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_VERIFY 0x40
+#endif
+#if defined(ATA_CMD_VERIFY_EXT) || (defined(HAVE_DECL_ATA_CMD_VERIFY_EXT) && HAVE_DECL_ATA_CMD_VERIFY_EXT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_VERIFY_EXT) == (0x42), "ATA_CMD_VERIFY_EXT != 0x42");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_VERIFY_EXT 0x42
+#endif
+#if defined(ATA_CMD_WRITE_UNCORR_EXT) || (defined(HAVE_DECL_ATA_CMD_WRITE_UNCORR_EXT) && HAVE_DECL_ATA_CMD_WRITE_UNCORR_EXT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_WRITE_UNCORR_EXT) == (0x45), "ATA_CMD_WRITE_UNCORR_EXT != 0x45");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_WRITE_UNCORR_EXT 0x45
+#endif
+#if defined(ATA_CMD_READ_LOG_DMA_EXT) || (defined(HAVE_DECL_ATA_CMD_READ_LOG_DMA_EXT) && HAVE_DECL_ATA_CMD_READ_LOG_DMA_EXT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_READ_LOG_DMA_EXT) == (0x47), "ATA_CMD_READ_LOG_DMA_EXT != 0x47");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_READ_LOG_DMA_EXT 0x47
+#endif
+#if defined(ATA_CMD_ZAC_MGMT_IN) || (defined(HAVE_DECL_ATA_CMD_ZAC_MGMT_IN) && HAVE_DECL_ATA_CMD_ZAC_MGMT_IN)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_ZAC_MGMT_IN) == (0x4A), "ATA_CMD_ZAC_MGMT_IN != 0x4A");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_ZAC_MGMT_IN 0x4A
+#endif
+#if defined(ATA_CMD_CONFIG_STREAM) || (defined(HAVE_DECL_ATA_CMD_CONFIG_STREAM) && HAVE_DECL_ATA_CMD_CONFIG_STREAM)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_CONFIG_STREAM) == (0x51), "ATA_CMD_CONFIG_STREAM != 0x51");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_CONFIG_STREAM 0x51
+#endif
+#if defined(ATA_CMD_WRITE_LOG_DMA_EXT) || (defined(HAVE_DECL_ATA_CMD_WRITE_LOG_DMA_EXT) && HAVE_DECL_ATA_CMD_WRITE_LOG_DMA_EXT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_WRITE_LOG_DMA_EXT) == (0x57), "ATA_CMD_WRITE_LOG_DMA_EXT != 0x57");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_WRITE_LOG_DMA_EXT 0x57
+#endif
+#if defined(ATA_CMD_TRUSTED_NONDATA) || (defined(HAVE_DECL_ATA_CMD_TRUSTED_NONDATA) && HAVE_DECL_ATA_CMD_TRUSTED_NONDATA)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_TRUSTED_NONDATA) == (0x5B), "ATA_CMD_TRUSTED_NONDATA != 0x5B");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_TRUSTED_NONDATA 0x5B
+#endif
+#if defined(ATA_CMD_TRUSTED_RCV) || (defined(HAVE_DECL_ATA_CMD_TRUSTED_RCV) && HAVE_DECL_ATA_CMD_TRUSTED_RCV)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_TRUSTED_RCV) == (0x5C), "ATA_CMD_TRUSTED_RCV != 0x5C");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_TRUSTED_RCV 0x5C
+#endif
+#if defined(ATA_CMD_TRUSTED_RCV_DMA) || (defined(HAVE_DECL_ATA_CMD_TRUSTED_RCV_DMA) && HAVE_DECL_ATA_CMD_TRUSTED_RCV_DMA)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_TRUSTED_RCV_DMA) == (0x5D), "ATA_CMD_TRUSTED_RCV_DMA != 0x5D");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_TRUSTED_RCV_DMA 0x5D
+#endif
+#if defined(ATA_CMD_TRUSTED_SND) || (defined(HAVE_DECL_ATA_CMD_TRUSTED_SND) && HAVE_DECL_ATA_CMD_TRUSTED_SND)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_TRUSTED_SND) == (0x5E), "ATA_CMD_TRUSTED_SND != 0x5E");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_TRUSTED_SND 0x5E
+#endif
+#if defined(ATA_CMD_TRUSTED_SND_DMA) || (defined(HAVE_DECL_ATA_CMD_TRUSTED_SND_DMA) && HAVE_DECL_ATA_CMD_TRUSTED_SND_DMA)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_TRUSTED_SND_DMA) == (0x5F), "ATA_CMD_TRUSTED_SND_DMA != 0x5F");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_TRUSTED_SND_DMA 0x5F
+#endif
+#if defined(ATA_CMD_FPDMA_READ) || (defined(HAVE_DECL_ATA_CMD_FPDMA_READ) && HAVE_DECL_ATA_CMD_FPDMA_READ)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_FPDMA_READ) == (0x60), "ATA_CMD_FPDMA_READ != 0x60");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_FPDMA_READ 0x60
+#endif
+#if defined(ATA_CMD_FPDMA_WRITE) || (defined(HAVE_DECL_ATA_CMD_FPDMA_WRITE) && HAVE_DECL_ATA_CMD_FPDMA_WRITE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_FPDMA_WRITE) == (0x61), "ATA_CMD_FPDMA_WRITE != 0x61");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_FPDMA_WRITE 0x61
+#endif
+#if defined(ATA_CMD_NCQ_NON_DATA) || (defined(HAVE_DECL_ATA_CMD_NCQ_NON_DATA) && HAVE_DECL_ATA_CMD_NCQ_NON_DATA)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_NCQ_NON_DATA) == (0x63), "ATA_CMD_NCQ_NON_DATA != 0x63");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_NCQ_NON_DATA 0x63
+#endif
+#if defined(ATA_CMD_FPDMA_SEND) || (defined(HAVE_DECL_ATA_CMD_FPDMA_SEND) && HAVE_DECL_ATA_CMD_FPDMA_SEND)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_FPDMA_SEND) == (0x64), "ATA_CMD_FPDMA_SEND != 0x64");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_FPDMA_SEND 0x64
+#endif
+#if defined(ATA_CMD_FPDMA_RECV) || (defined(HAVE_DECL_ATA_CMD_FPDMA_RECV) && HAVE_DECL_ATA_CMD_FPDMA_RECV)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_FPDMA_RECV) == (0x65), "ATA_CMD_FPDMA_RECV != 0x65");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_FPDMA_RECV 0x65
+#endif
+#if defined(ATA_CMD_CFA_TRANS_SECT) || (defined(HAVE_DECL_ATA_CMD_CFA_TRANS_SECT) && HAVE_DECL_ATA_CMD_CFA_TRANS_SECT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_CFA_TRANS_SECT) == (0x87), "ATA_CMD_CFA_TRANS_SECT != 0x87");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_CFA_TRANS_SECT 0x87
+#endif
+#if defined(ATA_CMD_EDD) || (defined(HAVE_DECL_ATA_CMD_EDD) && HAVE_DECL_ATA_CMD_EDD)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_EDD) == (0x90), "ATA_CMD_EDD != 0x90");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_EDD 0x90
+#endif
+#if defined(ATA_CMD_INIT_DEV_PARAMS) || (defined(HAVE_DECL_ATA_CMD_INIT_DEV_PARAMS) && HAVE_DECL_ATA_CMD_INIT_DEV_PARAMS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_INIT_DEV_PARAMS) == (0x91), "ATA_CMD_INIT_DEV_PARAMS != 0x91");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_INIT_DEV_PARAMS 0x91
+#endif
+#if defined(ATA_CMD_DOWNLOAD_MICRO) || (defined(HAVE_DECL_ATA_CMD_DOWNLOAD_MICRO) && HAVE_DECL_ATA_CMD_DOWNLOAD_MICRO)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_DOWNLOAD_MICRO) == (0x92), "ATA_CMD_DOWNLOAD_MICRO != 0x92");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_DOWNLOAD_MICRO 0x92
+#endif
+#if defined(ATA_CMD_DOWNLOAD_MICRO_DMA) || (defined(HAVE_DECL_ATA_CMD_DOWNLOAD_MICRO_DMA) && HAVE_DECL_ATA_CMD_DOWNLOAD_MICRO_DMA)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_DOWNLOAD_MICRO_DMA) == (0x93), "ATA_CMD_DOWNLOAD_MICRO_DMA != 0x93");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_DOWNLOAD_MICRO_DMA 0x93
+#endif
+#if defined(ATA_CMD_ZAC_MGMT_OUT) || (defined(HAVE_DECL_ATA_CMD_ZAC_MGMT_OUT) && HAVE_DECL_ATA_CMD_ZAC_MGMT_OUT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_ZAC_MGMT_OUT) == (0x9F), "ATA_CMD_ZAC_MGMT_OUT != 0x9F");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_ZAC_MGMT_OUT 0x9F
+#endif
+#if defined(ATA_CMD_PACKET) || (defined(HAVE_DECL_ATA_CMD_PACKET) && HAVE_DECL_ATA_CMD_PACKET)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_PACKET) == (0xA0), "ATA_CMD_PACKET != 0xA0");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_PACKET 0xA0
+#endif
+#if defined(ATA_CMD_ID_ATAPI) || (defined(HAVE_DECL_ATA_CMD_ID_ATAPI) && HAVE_DECL_ATA_CMD_ID_ATAPI)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_ID_ATAPI) == (0xA1), "ATA_CMD_ID_ATAPI != 0xA1");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_ID_ATAPI 0xA1
+#endif
+#if defined(ATA_CMD_SERVICE) || (defined(HAVE_DECL_ATA_CMD_SERVICE) && HAVE_DECL_ATA_CMD_SERVICE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_SERVICE) == (0xA2), "ATA_CMD_SERVICE != 0xA2");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_SERVICE 0xA2
+#endif
+#if defined(ATA_CMD_SMART) || (defined(HAVE_DECL_ATA_CMD_SMART) && HAVE_DECL_ATA_CMD_SMART)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_SMART) == (0xB0), "ATA_CMD_SMART != 0xB0");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_SMART 0xB0
+#endif
+#if defined(ATA_CMD_CONF_OVERLAY) || (defined(HAVE_DECL_ATA_CMD_CONF_OVERLAY) && HAVE_DECL_ATA_CMD_CONF_OVERLAY)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_CONF_OVERLAY) == (0xB1), "ATA_CMD_CONF_OVERLAY != 0xB1");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_CONF_OVERLAY 0xB1
+#endif
+#if defined(ATA_CMD_SANITIZE_DEVICE) || (defined(HAVE_DECL_ATA_CMD_SANITIZE_DEVICE) && HAVE_DECL_ATA_CMD_SANITIZE_DEVICE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_SANITIZE_DEVICE) == (0xB4), "ATA_CMD_SANITIZE_DEVICE != 0xB4");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_SANITIZE_DEVICE 0xB4
+#endif
+#if defined(ATA_CMD_CFA_ERASE) || (defined(HAVE_DECL_ATA_CMD_CFA_ERASE) && HAVE_DECL_ATA_CMD_CFA_ERASE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_CFA_ERASE) == (0xC0), "ATA_CMD_CFA_ERASE != 0xC0");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_CFA_ERASE 0xC0
+#endif
+#if defined(ATA_CMD_READ_MULTI) || (defined(HAVE_DECL_ATA_CMD_READ_MULTI) && HAVE_DECL_ATA_CMD_READ_MULTI)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_READ_MULTI) == (0xC4), "ATA_CMD_READ_MULTI != 0xC4");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_READ_MULTI 0xC4
+#endif
+#if defined(ATA_CMD_WRITE_MULTI) || (defined(HAVE_DECL_ATA_CMD_WRITE_MULTI) && HAVE_DECL_ATA_CMD_WRITE_MULTI)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_WRITE_MULTI) == (0xC5), "ATA_CMD_WRITE_MULTI != 0xC5");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_WRITE_MULTI 0xC5
+#endif
+#if defined(ATA_CMD_SET_MULTI) || (defined(HAVE_DECL_ATA_CMD_SET_MULTI) && HAVE_DECL_ATA_CMD_SET_MULTI)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_SET_MULTI) == (0xC6), "ATA_CMD_SET_MULTI != 0xC6");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_SET_MULTI 0xC6
+#endif
+#if defined(ATA_CMD_READ) || (defined(HAVE_DECL_ATA_CMD_READ) && HAVE_DECL_ATA_CMD_READ)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_READ) == (0xC8), "ATA_CMD_READ != 0xC8");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_READ 0xC8
+#endif
+#if defined(ATA_CMD_WRITE) || (defined(HAVE_DECL_ATA_CMD_WRITE) && HAVE_DECL_ATA_CMD_WRITE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_WRITE) == (0xCA), "ATA_CMD_WRITE != 0xCA");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_WRITE 0xCA
+#endif
+#if defined(ATA_CMD_CFA_WRITE_MULT_NE) || (defined(HAVE_DECL_ATA_CMD_CFA_WRITE_MULT_NE) && HAVE_DECL_ATA_CMD_CFA_WRITE_MULT_NE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_CFA_WRITE_MULT_NE) == (0xCD), "ATA_CMD_CFA_WRITE_MULT_NE != 0xCD");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_CFA_WRITE_MULT_NE 0xCD
+#endif
+#if defined(ATA_CMD_WRITE_MULTI_FUA_EXT) || (defined(HAVE_DECL_ATA_CMD_WRITE_MULTI_FUA_EXT) && HAVE_DECL_ATA_CMD_WRITE_MULTI_FUA_EXT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_WRITE_MULTI_FUA_EXT) == (0xCE), "ATA_CMD_WRITE_MULTI_FUA_EXT != 0xCE");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_WRITE_MULTI_FUA_EXT 0xCE
+#endif
+#if defined(ATA_CMD_CHK_MED_CRD_TYP) || (defined(HAVE_DECL_ATA_CMD_CHK_MED_CRD_TYP) && HAVE_DECL_ATA_CMD_CHK_MED_CRD_TYP)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_CHK_MED_CRD_TYP) == (0xD1), "ATA_CMD_CHK_MED_CRD_TYP != 0xD1");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_CHK_MED_CRD_TYP 0xD1
+#endif
+#if defined(ATA_CMD_MEDIA_LOCK) || (defined(HAVE_DECL_ATA_CMD_MEDIA_LOCK) && HAVE_DECL_ATA_CMD_MEDIA_LOCK)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_MEDIA_LOCK) == (0xDE), "ATA_CMD_MEDIA_LOCK != 0xDE");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_MEDIA_LOCK 0xDE
+#endif
+#if defined(ATA_CMD_MEDIA_UNLOCK) || (defined(HAVE_DECL_ATA_CMD_MEDIA_UNLOCK) && HAVE_DECL_ATA_CMD_MEDIA_UNLOCK)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_MEDIA_UNLOCK) == (0xDF), "ATA_CMD_MEDIA_UNLOCK != 0xDF");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_MEDIA_UNLOCK 0xDF
+#endif
+#if defined(ATA_CMD_STANDBYNOW1) || (defined(HAVE_DECL_ATA_CMD_STANDBYNOW1) && HAVE_DECL_ATA_CMD_STANDBYNOW1)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_STANDBYNOW1) == (0xE0), "ATA_CMD_STANDBYNOW1 != 0xE0");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_STANDBYNOW1 0xE0
+#endif
+#if defined(ATA_CMD_IDLEIMMEDIATE) || (defined(HAVE_DECL_ATA_CMD_IDLEIMMEDIATE) && HAVE_DECL_ATA_CMD_IDLEIMMEDIATE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_IDLEIMMEDIATE) == (0xE1), "ATA_CMD_IDLEIMMEDIATE != 0xE1");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_IDLEIMMEDIATE 0xE1
+#endif
+#if defined(ATA_CMD_STANDBY) || (defined(HAVE_DECL_ATA_CMD_STANDBY) && HAVE_DECL_ATA_CMD_STANDBY)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_STANDBY) == (0xE2), "ATA_CMD_STANDBY != 0xE2");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_STANDBY 0xE2
+#endif
+#if defined(ATA_CMD_IDLE) || (defined(HAVE_DECL_ATA_CMD_IDLE) && HAVE_DECL_ATA_CMD_IDLE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_IDLE) == (0xE3), "ATA_CMD_IDLE != 0xE3");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_IDLE 0xE3
+#endif
+#if defined(ATA_CMD_PMP_READ) || (defined(HAVE_DECL_ATA_CMD_PMP_READ) && HAVE_DECL_ATA_CMD_PMP_READ)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_PMP_READ) == (0xE4), "ATA_CMD_PMP_READ != 0xE4");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_PMP_READ 0xE4
+#endif
+#if defined(ATA_CMD_CHK_POWER) || (defined(HAVE_DECL_ATA_CMD_CHK_POWER) && HAVE_DECL_ATA_CMD_CHK_POWER)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_CHK_POWER) == (0xE5), "ATA_CMD_CHK_POWER != 0xE5");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_CHK_POWER 0xE5
+#endif
+#if defined(ATA_CMD_SLEEP) || (defined(HAVE_DECL_ATA_CMD_SLEEP) && HAVE_DECL_ATA_CMD_SLEEP)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_SLEEP) == (0xE6), "ATA_CMD_SLEEP != 0xE6");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_SLEEP 0xE6
+#endif
+#if defined(ATA_CMD_FLUSH) || (defined(HAVE_DECL_ATA_CMD_FLUSH) && HAVE_DECL_ATA_CMD_FLUSH)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_FLUSH) == (0xE7), "ATA_CMD_FLUSH != 0xE7");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_FLUSH 0xE7
+#endif
+#if defined(ATA_CMD_PMP_WRITE) || (defined(HAVE_DECL_ATA_CMD_PMP_WRITE) && HAVE_DECL_ATA_CMD_PMP_WRITE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_PMP_WRITE) == (0xE8), "ATA_CMD_PMP_WRITE != 0xE8");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_PMP_WRITE 0xE8
+#endif
+#if defined(ATA_CMD_PMP_READ_DMA) || (defined(HAVE_DECL_ATA_CMD_PMP_READ_DMA) && HAVE_DECL_ATA_CMD_PMP_READ_DMA)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_PMP_READ_DMA) == (0xE9), "ATA_CMD_PMP_READ_DMA != 0xE9");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_PMP_READ_DMA 0xE9
+#endif
+#if defined(ATA_CMD_FLUSH_EXT) || (defined(HAVE_DECL_ATA_CMD_FLUSH_EXT) && HAVE_DECL_ATA_CMD_FLUSH_EXT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_FLUSH_EXT) == (0xEA), "ATA_CMD_FLUSH_EXT != 0xEA");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_FLUSH_EXT 0xEA
+#endif
+#if defined(ATA_CMD_PMP_WRITE_DMA) || (defined(HAVE_DECL_ATA_CMD_PMP_WRITE_DMA) && HAVE_DECL_ATA_CMD_PMP_WRITE_DMA)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_PMP_WRITE_DMA) == (0xEB), "ATA_CMD_PMP_WRITE_DMA != 0xEB");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_PMP_WRITE_DMA 0xEB
+#endif
+#if defined(ATA_CMD_ID_ATA) || (defined(HAVE_DECL_ATA_CMD_ID_ATA) && HAVE_DECL_ATA_CMD_ID_ATA)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_ID_ATA) == (0xEC), "ATA_CMD_ID_ATA != 0xEC");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_ID_ATA 0xEC
+#endif
+#if defined(ATA_CMD_SET_FEATURES) || (defined(HAVE_DECL_ATA_CMD_SET_FEATURES) && HAVE_DECL_ATA_CMD_SET_FEATURES)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_SET_FEATURES) == (0xEF), "ATA_CMD_SET_FEATURES != 0xEF");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_SET_FEATURES 0xEF
+#endif
+#if defined(ATA_CMD_SEC_SET_PASS) || (defined(HAVE_DECL_ATA_CMD_SEC_SET_PASS) && HAVE_DECL_ATA_CMD_SEC_SET_PASS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_SEC_SET_PASS) == (0xF1), "ATA_CMD_SEC_SET_PASS != 0xF1");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_SEC_SET_PASS 0xF1
+#endif
+#if defined(ATA_CMD_SEC_UNLOCK) || (defined(HAVE_DECL_ATA_CMD_SEC_UNLOCK) && HAVE_DECL_ATA_CMD_SEC_UNLOCK)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_SEC_UNLOCK) == (0xF2), "ATA_CMD_SEC_UNLOCK != 0xF2");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_SEC_UNLOCK 0xF2
+#endif
+#if defined(ATA_CMD_SEC_ERASE_PREP) || (defined(HAVE_DECL_ATA_CMD_SEC_ERASE_PREP) && HAVE_DECL_ATA_CMD_SEC_ERASE_PREP)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_SEC_ERASE_PREP) == (0xF3), "ATA_CMD_SEC_ERASE_PREP != 0xF3");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_SEC_ERASE_PREP 0xF3
+#endif
+#if defined(ATA_CMD_SEC_ERASE_UNIT) || (defined(HAVE_DECL_ATA_CMD_SEC_ERASE_UNIT) && HAVE_DECL_ATA_CMD_SEC_ERASE_UNIT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_SEC_ERASE_UNIT) == (0xF4), "ATA_CMD_SEC_ERASE_UNIT != 0xF4");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_SEC_ERASE_UNIT 0xF4
+#endif
+#if defined(ATA_CMD_SEC_FREEZE_LOCK) || (defined(HAVE_DECL_ATA_CMD_SEC_FREEZE_LOCK) && HAVE_DECL_ATA_CMD_SEC_FREEZE_LOCK)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_SEC_FREEZE_LOCK) == (0xF5), "ATA_CMD_SEC_FREEZE_LOCK != 0xF5");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_SEC_FREEZE_LOCK 0xF5
+#endif
+#if defined(ATA_CMD_SEC_DISABLE_PASS) || (defined(HAVE_DECL_ATA_CMD_SEC_DISABLE_PASS) && HAVE_DECL_ATA_CMD_SEC_DISABLE_PASS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_SEC_DISABLE_PASS) == (0xF6), "ATA_CMD_SEC_DISABLE_PASS != 0xF6");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_SEC_DISABLE_PASS 0xF6
+#endif
+#if defined(ATA_CMD_READ_NATIVE_MAX) || (defined(HAVE_DECL_ATA_CMD_READ_NATIVE_MAX) && HAVE_DECL_ATA_CMD_READ_NATIVE_MAX)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_READ_NATIVE_MAX) == (0xF8), "ATA_CMD_READ_NATIVE_MAX != 0xF8");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_READ_NATIVE_MAX 0xF8
+#endif
+#if defined(ATA_CMD_SET_MAX) || (defined(HAVE_DECL_ATA_CMD_SET_MAX) && HAVE_DECL_ATA_CMD_SET_MAX)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((ATA_CMD_SET_MAX) == (0xF9), "ATA_CMD_SET_MAX != 0xF9");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define ATA_CMD_SET_MAX 0xF9
+#endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+extern const struct xlat hdio_drive_cmds[];
+
+# else
+
+static const struct xlat_data hdio_drive_cmds_xdata[] = {
+ XLAT(ATA_CMD_NOP),
+ #define XLAT_VAL_0 ((unsigned) (ATA_CMD_NOP))
+ #define XLAT_STR_0 STRINGIFY(ATA_CMD_NOP)
+ XLAT(ATA_CMD_CFA_REQ_EXT_ERR),
+ #define XLAT_VAL_1 ((unsigned) (ATA_CMD_CFA_REQ_EXT_ERR))
+ #define XLAT_STR_1 STRINGIFY(ATA_CMD_CFA_REQ_EXT_ERR)
+ XLAT(ATA_CMD_DSM),
+ #define XLAT_VAL_2 ((unsigned) (ATA_CMD_DSM))
+ #define XLAT_STR_2 STRINGIFY(ATA_CMD_DSM)
+ XLAT(ATA_CMD_DEV_RESET),
+ #define XLAT_VAL_3 ((unsigned) (ATA_CMD_DEV_RESET))
+ #define XLAT_STR_3 STRINGIFY(ATA_CMD_DEV_RESET)
+ XLAT(ATA_CMD_REQ_SENSE_DATA),
+ #define XLAT_VAL_4 ((unsigned) (ATA_CMD_REQ_SENSE_DATA))
+ #define XLAT_STR_4 STRINGIFY(ATA_CMD_REQ_SENSE_DATA)
+ XLAT(ATA_CMD_RESTORE),
+ #define XLAT_VAL_5 ((unsigned) (ATA_CMD_RESTORE))
+ #define XLAT_STR_5 STRINGIFY(ATA_CMD_RESTORE)
+ XLAT(ATA_CMD_PIO_READ),
+ #define XLAT_VAL_6 ((unsigned) (ATA_CMD_PIO_READ))
+ #define XLAT_STR_6 STRINGIFY(ATA_CMD_PIO_READ)
+ XLAT(ATA_CMD_READ_LONG),
+ #define XLAT_VAL_7 ((unsigned) (ATA_CMD_READ_LONG))
+ #define XLAT_STR_7 STRINGIFY(ATA_CMD_READ_LONG)
+ XLAT(ATA_CMD_READ_LONG_ONCE),
+ #define XLAT_VAL_8 ((unsigned) (ATA_CMD_READ_LONG_ONCE))
+ #define XLAT_STR_8 STRINGIFY(ATA_CMD_READ_LONG_ONCE)
+ XLAT(ATA_CMD_PIO_READ_EXT),
+ #define XLAT_VAL_9 ((unsigned) (ATA_CMD_PIO_READ_EXT))
+ #define XLAT_STR_9 STRINGIFY(ATA_CMD_PIO_READ_EXT)
+ XLAT(ATA_CMD_READ_EXT),
+ #define XLAT_VAL_10 ((unsigned) (ATA_CMD_READ_EXT))
+ #define XLAT_STR_10 STRINGIFY(ATA_CMD_READ_EXT)
+ XLAT(ATA_CMD_READ_QUEUED),
+ #define XLAT_VAL_11 ((unsigned) (ATA_CMD_READ_QUEUED))
+ #define XLAT_STR_11 STRINGIFY(ATA_CMD_READ_QUEUED)
+ XLAT(ATA_CMD_READ_NATIVE_MAX_EXT),
+ #define XLAT_VAL_12 ((unsigned) (ATA_CMD_READ_NATIVE_MAX_EXT))
+ #define XLAT_STR_12 STRINGIFY(ATA_CMD_READ_NATIVE_MAX_EXT)
+ XLAT(ATA_CMD_READ_MULTI_EXT),
+ #define XLAT_VAL_13 ((unsigned) (ATA_CMD_READ_MULTI_EXT))
+ #define XLAT_STR_13 STRINGIFY(ATA_CMD_READ_MULTI_EXT)
+ XLAT(ATA_CMD_READ_STREAM_DMA_EXT),
+ #define XLAT_VAL_14 ((unsigned) (ATA_CMD_READ_STREAM_DMA_EXT))
+ #define XLAT_STR_14 STRINGIFY(ATA_CMD_READ_STREAM_DMA_EXT)
+ XLAT(ATA_CMD_READ_STREAM_EXT),
+ #define XLAT_VAL_15 ((unsigned) (ATA_CMD_READ_STREAM_EXT))
+ #define XLAT_STR_15 STRINGIFY(ATA_CMD_READ_STREAM_EXT)
+ XLAT(ATA_CMD_READ_LOG_EXT),
+ #define XLAT_VAL_16 ((unsigned) (ATA_CMD_READ_LOG_EXT))
+ #define XLAT_STR_16 STRINGIFY(ATA_CMD_READ_LOG_EXT)
+ XLAT(ATA_CMD_PIO_WRITE),
+ #define XLAT_VAL_17 ((unsigned) (ATA_CMD_PIO_WRITE))
+ #define XLAT_STR_17 STRINGIFY(ATA_CMD_PIO_WRITE)
+ XLAT(ATA_CMD_WRITE_LONG),
+ #define XLAT_VAL_18 ((unsigned) (ATA_CMD_WRITE_LONG))
+ #define XLAT_STR_18 STRINGIFY(ATA_CMD_WRITE_LONG)
+ XLAT(ATA_CMD_WRITE_LONG_ONCE),
+ #define XLAT_VAL_19 ((unsigned) (ATA_CMD_WRITE_LONG_ONCE))
+ #define XLAT_STR_19 STRINGIFY(ATA_CMD_WRITE_LONG_ONCE)
+ XLAT(ATA_CMD_PIO_WRITE_EXT),
+ #define XLAT_VAL_20 ((unsigned) (ATA_CMD_PIO_WRITE_EXT))
+ #define XLAT_STR_20 STRINGIFY(ATA_CMD_PIO_WRITE_EXT)
+ XLAT(ATA_CMD_WRITE_EXT),
+ #define XLAT_VAL_21 ((unsigned) (ATA_CMD_WRITE_EXT))
+ #define XLAT_STR_21 STRINGIFY(ATA_CMD_WRITE_EXT)
+ XLAT(ATA_CMD_WRITE_QUEUED),
+ #define XLAT_VAL_22 ((unsigned) (ATA_CMD_WRITE_QUEUED))
+ #define XLAT_STR_22 STRINGIFY(ATA_CMD_WRITE_QUEUED)
+ XLAT(ATA_CMD_SET_MAX_EXT),
+ #define XLAT_VAL_23 ((unsigned) (ATA_CMD_SET_MAX_EXT))
+ #define XLAT_STR_23 STRINGIFY(ATA_CMD_SET_MAX_EXT)
+ XLAT(ATA_CMD_CFA_WRITE_NE),
+ #define XLAT_VAL_24 ((unsigned) (ATA_CMD_CFA_WRITE_NE))
+ #define XLAT_STR_24 STRINGIFY(ATA_CMD_CFA_WRITE_NE)
+ XLAT(ATA_CMD_WRITE_MULTI_EXT),
+ #define XLAT_VAL_25 ((unsigned) (ATA_CMD_WRITE_MULTI_EXT))
+ #define XLAT_STR_25 STRINGIFY(ATA_CMD_WRITE_MULTI_EXT)
+ XLAT(ATA_CMD_WRITE_STREAM_DMA_EXT),
+ #define XLAT_VAL_26 ((unsigned) (ATA_CMD_WRITE_STREAM_DMA_EXT))
+ #define XLAT_STR_26 STRINGIFY(ATA_CMD_WRITE_STREAM_DMA_EXT)
+ XLAT(ATA_CMD_WRITE_STREAM_EXT),
+ #define XLAT_VAL_27 ((unsigned) (ATA_CMD_WRITE_STREAM_EXT))
+ #define XLAT_STR_27 STRINGIFY(ATA_CMD_WRITE_STREAM_EXT)
+ XLAT(ATA_CMD_WRITE_FUA_EXT),
+ #define XLAT_VAL_28 ((unsigned) (ATA_CMD_WRITE_FUA_EXT))
+ #define XLAT_STR_28 STRINGIFY(ATA_CMD_WRITE_FUA_EXT)
+ XLAT(ATA_CMD_WRITE_QUEUED_FUA_EXT),
+ #define XLAT_VAL_29 ((unsigned) (ATA_CMD_WRITE_QUEUED_FUA_EXT))
+ #define XLAT_STR_29 STRINGIFY(ATA_CMD_WRITE_QUEUED_FUA_EXT)
+ XLAT(ATA_CMD_WRITE_LOG_EXT),
+ #define XLAT_VAL_30 ((unsigned) (ATA_CMD_WRITE_LOG_EXT))
+ #define XLAT_STR_30 STRINGIFY(ATA_CMD_WRITE_LOG_EXT)
+ XLAT(ATA_CMD_VERIFY),
+ #define XLAT_VAL_31 ((unsigned) (ATA_CMD_VERIFY))
+ #define XLAT_STR_31 STRINGIFY(ATA_CMD_VERIFY)
+ XLAT(ATA_CMD_VERIFY_EXT),
+ #define XLAT_VAL_32 ((unsigned) (ATA_CMD_VERIFY_EXT))
+ #define XLAT_STR_32 STRINGIFY(ATA_CMD_VERIFY_EXT)
+ XLAT(ATA_CMD_WRITE_UNCORR_EXT),
+ #define XLAT_VAL_33 ((unsigned) (ATA_CMD_WRITE_UNCORR_EXT))
+ #define XLAT_STR_33 STRINGIFY(ATA_CMD_WRITE_UNCORR_EXT)
+ XLAT(ATA_CMD_READ_LOG_DMA_EXT),
+ #define XLAT_VAL_34 ((unsigned) (ATA_CMD_READ_LOG_DMA_EXT))
+ #define XLAT_STR_34 STRINGIFY(ATA_CMD_READ_LOG_DMA_EXT)
+ XLAT(ATA_CMD_ZAC_MGMT_IN),
+ #define XLAT_VAL_35 ((unsigned) (ATA_CMD_ZAC_MGMT_IN))
+ #define XLAT_STR_35 STRINGIFY(ATA_CMD_ZAC_MGMT_IN)
+ XLAT(ATA_CMD_CONFIG_STREAM),
+ #define XLAT_VAL_36 ((unsigned) (ATA_CMD_CONFIG_STREAM))
+ #define XLAT_STR_36 STRINGIFY(ATA_CMD_CONFIG_STREAM)
+ XLAT(ATA_CMD_WRITE_LOG_DMA_EXT),
+ #define XLAT_VAL_37 ((unsigned) (ATA_CMD_WRITE_LOG_DMA_EXT))
+ #define XLAT_STR_37 STRINGIFY(ATA_CMD_WRITE_LOG_DMA_EXT)
+ XLAT(ATA_CMD_TRUSTED_NONDATA),
+ #define XLAT_VAL_38 ((unsigned) (ATA_CMD_TRUSTED_NONDATA))
+ #define XLAT_STR_38 STRINGIFY(ATA_CMD_TRUSTED_NONDATA)
+ XLAT(ATA_CMD_TRUSTED_RCV),
+ #define XLAT_VAL_39 ((unsigned) (ATA_CMD_TRUSTED_RCV))
+ #define XLAT_STR_39 STRINGIFY(ATA_CMD_TRUSTED_RCV)
+ XLAT(ATA_CMD_TRUSTED_RCV_DMA),
+ #define XLAT_VAL_40 ((unsigned) (ATA_CMD_TRUSTED_RCV_DMA))
+ #define XLAT_STR_40 STRINGIFY(ATA_CMD_TRUSTED_RCV_DMA)
+ XLAT(ATA_CMD_TRUSTED_SND),
+ #define XLAT_VAL_41 ((unsigned) (ATA_CMD_TRUSTED_SND))
+ #define XLAT_STR_41 STRINGIFY(ATA_CMD_TRUSTED_SND)
+ XLAT(ATA_CMD_TRUSTED_SND_DMA),
+ #define XLAT_VAL_42 ((unsigned) (ATA_CMD_TRUSTED_SND_DMA))
+ #define XLAT_STR_42 STRINGIFY(ATA_CMD_TRUSTED_SND_DMA)
+ XLAT(ATA_CMD_FPDMA_READ),
+ #define XLAT_VAL_43 ((unsigned) (ATA_CMD_FPDMA_READ))
+ #define XLAT_STR_43 STRINGIFY(ATA_CMD_FPDMA_READ)
+ XLAT(ATA_CMD_FPDMA_WRITE),
+ #define XLAT_VAL_44 ((unsigned) (ATA_CMD_FPDMA_WRITE))
+ #define XLAT_STR_44 STRINGIFY(ATA_CMD_FPDMA_WRITE)
+ XLAT(ATA_CMD_NCQ_NON_DATA),
+ #define XLAT_VAL_45 ((unsigned) (ATA_CMD_NCQ_NON_DATA))
+ #define XLAT_STR_45 STRINGIFY(ATA_CMD_NCQ_NON_DATA)
+ XLAT(ATA_CMD_FPDMA_SEND),
+ #define XLAT_VAL_46 ((unsigned) (ATA_CMD_FPDMA_SEND))
+ #define XLAT_STR_46 STRINGIFY(ATA_CMD_FPDMA_SEND)
+ XLAT(ATA_CMD_FPDMA_RECV),
+ #define XLAT_VAL_47 ((unsigned) (ATA_CMD_FPDMA_RECV))
+ #define XLAT_STR_47 STRINGIFY(ATA_CMD_FPDMA_RECV)
+ XLAT(ATA_CMD_CFA_TRANS_SECT),
+ #define XLAT_VAL_48 ((unsigned) (ATA_CMD_CFA_TRANS_SECT))
+ #define XLAT_STR_48 STRINGIFY(ATA_CMD_CFA_TRANS_SECT)
+ XLAT(ATA_CMD_EDD),
+ #define XLAT_VAL_49 ((unsigned) (ATA_CMD_EDD))
+ #define XLAT_STR_49 STRINGIFY(ATA_CMD_EDD)
+ XLAT(ATA_CMD_INIT_DEV_PARAMS),
+ #define XLAT_VAL_50 ((unsigned) (ATA_CMD_INIT_DEV_PARAMS))
+ #define XLAT_STR_50 STRINGIFY(ATA_CMD_INIT_DEV_PARAMS)
+ XLAT(ATA_CMD_DOWNLOAD_MICRO),
+ #define XLAT_VAL_51 ((unsigned) (ATA_CMD_DOWNLOAD_MICRO))
+ #define XLAT_STR_51 STRINGIFY(ATA_CMD_DOWNLOAD_MICRO)
+ XLAT(ATA_CMD_DOWNLOAD_MICRO_DMA),
+ #define XLAT_VAL_52 ((unsigned) (ATA_CMD_DOWNLOAD_MICRO_DMA))
+ #define XLAT_STR_52 STRINGIFY(ATA_CMD_DOWNLOAD_MICRO_DMA)
+ XLAT(ATA_CMD_ZAC_MGMT_OUT),
+ #define XLAT_VAL_53 ((unsigned) (ATA_CMD_ZAC_MGMT_OUT))
+ #define XLAT_STR_53 STRINGIFY(ATA_CMD_ZAC_MGMT_OUT)
+ XLAT(ATA_CMD_PACKET),
+ #define XLAT_VAL_54 ((unsigned) (ATA_CMD_PACKET))
+ #define XLAT_STR_54 STRINGIFY(ATA_CMD_PACKET)
+ XLAT(ATA_CMD_ID_ATAPI),
+ #define XLAT_VAL_55 ((unsigned) (ATA_CMD_ID_ATAPI))
+ #define XLAT_STR_55 STRINGIFY(ATA_CMD_ID_ATAPI)
+ XLAT(ATA_CMD_SERVICE),
+ #define XLAT_VAL_56 ((unsigned) (ATA_CMD_SERVICE))
+ #define XLAT_STR_56 STRINGIFY(ATA_CMD_SERVICE)
+ XLAT(ATA_CMD_SMART),
+ #define XLAT_VAL_57 ((unsigned) (ATA_CMD_SMART))
+ #define XLAT_STR_57 STRINGIFY(ATA_CMD_SMART)
+ XLAT(ATA_CMD_CONF_OVERLAY),
+ #define XLAT_VAL_58 ((unsigned) (ATA_CMD_CONF_OVERLAY))
+ #define XLAT_STR_58 STRINGIFY(ATA_CMD_CONF_OVERLAY)
+ XLAT(ATA_CMD_SANITIZE_DEVICE),
+ #define XLAT_VAL_59 ((unsigned) (ATA_CMD_SANITIZE_DEVICE))
+ #define XLAT_STR_59 STRINGIFY(ATA_CMD_SANITIZE_DEVICE)
+ XLAT(ATA_CMD_CFA_ERASE),
+ #define XLAT_VAL_60 ((unsigned) (ATA_CMD_CFA_ERASE))
+ #define XLAT_STR_60 STRINGIFY(ATA_CMD_CFA_ERASE)
+ XLAT(ATA_CMD_READ_MULTI),
+ #define XLAT_VAL_61 ((unsigned) (ATA_CMD_READ_MULTI))
+ #define XLAT_STR_61 STRINGIFY(ATA_CMD_READ_MULTI)
+ XLAT(ATA_CMD_WRITE_MULTI),
+ #define XLAT_VAL_62 ((unsigned) (ATA_CMD_WRITE_MULTI))
+ #define XLAT_STR_62 STRINGIFY(ATA_CMD_WRITE_MULTI)
+ XLAT(ATA_CMD_SET_MULTI),
+ #define XLAT_VAL_63 ((unsigned) (ATA_CMD_SET_MULTI))
+ #define XLAT_STR_63 STRINGIFY(ATA_CMD_SET_MULTI)
+ XLAT(ATA_CMD_READ),
+ #define XLAT_VAL_64 ((unsigned) (ATA_CMD_READ))
+ #define XLAT_STR_64 STRINGIFY(ATA_CMD_READ)
+ XLAT(ATA_CMD_WRITE),
+ #define XLAT_VAL_65 ((unsigned) (ATA_CMD_WRITE))
+ #define XLAT_STR_65 STRINGIFY(ATA_CMD_WRITE)
+ XLAT(ATA_CMD_CFA_WRITE_MULT_NE),
+ #define XLAT_VAL_66 ((unsigned) (ATA_CMD_CFA_WRITE_MULT_NE))
+ #define XLAT_STR_66 STRINGIFY(ATA_CMD_CFA_WRITE_MULT_NE)
+ XLAT(ATA_CMD_WRITE_MULTI_FUA_EXT),
+ #define XLAT_VAL_67 ((unsigned) (ATA_CMD_WRITE_MULTI_FUA_EXT))
+ #define XLAT_STR_67 STRINGIFY(ATA_CMD_WRITE_MULTI_FUA_EXT)
+ XLAT(ATA_CMD_CHK_MED_CRD_TYP),
+ #define XLAT_VAL_68 ((unsigned) (ATA_CMD_CHK_MED_CRD_TYP))
+ #define XLAT_STR_68 STRINGIFY(ATA_CMD_CHK_MED_CRD_TYP)
+ XLAT(ATA_CMD_MEDIA_LOCK),
+ #define XLAT_VAL_69 ((unsigned) (ATA_CMD_MEDIA_LOCK))
+ #define XLAT_STR_69 STRINGIFY(ATA_CMD_MEDIA_LOCK)
+ XLAT(ATA_CMD_MEDIA_UNLOCK),
+ #define XLAT_VAL_70 ((unsigned) (ATA_CMD_MEDIA_UNLOCK))
+ #define XLAT_STR_70 STRINGIFY(ATA_CMD_MEDIA_UNLOCK)
+ XLAT(ATA_CMD_STANDBYNOW1),
+ #define XLAT_VAL_71 ((unsigned) (ATA_CMD_STANDBYNOW1))
+ #define XLAT_STR_71 STRINGIFY(ATA_CMD_STANDBYNOW1)
+ XLAT(ATA_CMD_IDLEIMMEDIATE),
+ #define XLAT_VAL_72 ((unsigned) (ATA_CMD_IDLEIMMEDIATE))
+ #define XLAT_STR_72 STRINGIFY(ATA_CMD_IDLEIMMEDIATE)
+ XLAT(ATA_CMD_STANDBY),
+ #define XLAT_VAL_73 ((unsigned) (ATA_CMD_STANDBY))
+ #define XLAT_STR_73 STRINGIFY(ATA_CMD_STANDBY)
+ XLAT(ATA_CMD_IDLE),
+ #define XLAT_VAL_74 ((unsigned) (ATA_CMD_IDLE))
+ #define XLAT_STR_74 STRINGIFY(ATA_CMD_IDLE)
+ XLAT(ATA_CMD_PMP_READ),
+ #define XLAT_VAL_75 ((unsigned) (ATA_CMD_PMP_READ))
+ #define XLAT_STR_75 STRINGIFY(ATA_CMD_PMP_READ)
+ XLAT(ATA_CMD_CHK_POWER),
+ #define XLAT_VAL_76 ((unsigned) (ATA_CMD_CHK_POWER))
+ #define XLAT_STR_76 STRINGIFY(ATA_CMD_CHK_POWER)
+ XLAT(ATA_CMD_SLEEP),
+ #define XLAT_VAL_77 ((unsigned) (ATA_CMD_SLEEP))
+ #define XLAT_STR_77 STRINGIFY(ATA_CMD_SLEEP)
+ XLAT(ATA_CMD_FLUSH),
+ #define XLAT_VAL_78 ((unsigned) (ATA_CMD_FLUSH))
+ #define XLAT_STR_78 STRINGIFY(ATA_CMD_FLUSH)
+ XLAT(ATA_CMD_PMP_WRITE),
+ #define XLAT_VAL_79 ((unsigned) (ATA_CMD_PMP_WRITE))
+ #define XLAT_STR_79 STRINGIFY(ATA_CMD_PMP_WRITE)
+ XLAT(ATA_CMD_PMP_READ_DMA),
+ #define XLAT_VAL_80 ((unsigned) (ATA_CMD_PMP_READ_DMA))
+ #define XLAT_STR_80 STRINGIFY(ATA_CMD_PMP_READ_DMA)
+ XLAT(ATA_CMD_FLUSH_EXT),
+ #define XLAT_VAL_81 ((unsigned) (ATA_CMD_FLUSH_EXT))
+ #define XLAT_STR_81 STRINGIFY(ATA_CMD_FLUSH_EXT)
+ XLAT(ATA_CMD_PMP_WRITE_DMA),
+ #define XLAT_VAL_82 ((unsigned) (ATA_CMD_PMP_WRITE_DMA))
+ #define XLAT_STR_82 STRINGIFY(ATA_CMD_PMP_WRITE_DMA)
+ XLAT(ATA_CMD_ID_ATA),
+ #define XLAT_VAL_83 ((unsigned) (ATA_CMD_ID_ATA))
+ #define XLAT_STR_83 STRINGIFY(ATA_CMD_ID_ATA)
+ XLAT(ATA_CMD_SET_FEATURES),
+ #define XLAT_VAL_84 ((unsigned) (ATA_CMD_SET_FEATURES))
+ #define XLAT_STR_84 STRINGIFY(ATA_CMD_SET_FEATURES)
+ XLAT(ATA_CMD_SEC_SET_PASS),
+ #define XLAT_VAL_85 ((unsigned) (ATA_CMD_SEC_SET_PASS))
+ #define XLAT_STR_85 STRINGIFY(ATA_CMD_SEC_SET_PASS)
+ XLAT(ATA_CMD_SEC_UNLOCK),
+ #define XLAT_VAL_86 ((unsigned) (ATA_CMD_SEC_UNLOCK))
+ #define XLAT_STR_86 STRINGIFY(ATA_CMD_SEC_UNLOCK)
+ XLAT(ATA_CMD_SEC_ERASE_PREP),
+ #define XLAT_VAL_87 ((unsigned) (ATA_CMD_SEC_ERASE_PREP))
+ #define XLAT_STR_87 STRINGIFY(ATA_CMD_SEC_ERASE_PREP)
+ XLAT(ATA_CMD_SEC_ERASE_UNIT),
+ #define XLAT_VAL_88 ((unsigned) (ATA_CMD_SEC_ERASE_UNIT))
+ #define XLAT_STR_88 STRINGIFY(ATA_CMD_SEC_ERASE_UNIT)
+ XLAT(ATA_CMD_SEC_FREEZE_LOCK),
+ #define XLAT_VAL_89 ((unsigned) (ATA_CMD_SEC_FREEZE_LOCK))
+ #define XLAT_STR_89 STRINGIFY(ATA_CMD_SEC_FREEZE_LOCK)
+ XLAT(ATA_CMD_SEC_DISABLE_PASS),
+ #define XLAT_VAL_90 ((unsigned) (ATA_CMD_SEC_DISABLE_PASS))
+ #define XLAT_STR_90 STRINGIFY(ATA_CMD_SEC_DISABLE_PASS)
+ XLAT(ATA_CMD_READ_NATIVE_MAX),
+ #define XLAT_VAL_91 ((unsigned) (ATA_CMD_READ_NATIVE_MAX))
+ #define XLAT_STR_91 STRINGIFY(ATA_CMD_READ_NATIVE_MAX)
+ XLAT(ATA_CMD_SET_MAX),
+ #define XLAT_VAL_92 ((unsigned) (ATA_CMD_SET_MAX))
+ #define XLAT_STR_92 STRINGIFY(ATA_CMD_SET_MAX)
+};
+#  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
+static
+#  endif
+const struct xlat hdio_drive_cmds[1] = { {
+ .data = hdio_drive_cmds_xdata,
+ .size = ARRAY_SIZE(hdio_drive_cmds_xdata),
+ .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+#  ifdef XLAT_VAL_47
+  | XLAT_VAL_47
+#  endif
+#  ifdef XLAT_VAL_48
+  | XLAT_VAL_48
+#  endif
+#  ifdef XLAT_VAL_49
+  | XLAT_VAL_49
+#  endif
+#  ifdef XLAT_VAL_50
+  | XLAT_VAL_50
+#  endif
+#  ifdef XLAT_VAL_51
+  | XLAT_VAL_51
+#  endif
+#  ifdef XLAT_VAL_52
+  | XLAT_VAL_52
+#  endif
+#  ifdef XLAT_VAL_53
+  | XLAT_VAL_53
+#  endif
+#  ifdef XLAT_VAL_54
+  | XLAT_VAL_54
+#  endif
+#  ifdef XLAT_VAL_55
+  | XLAT_VAL_55
+#  endif
+#  ifdef XLAT_VAL_56
+  | XLAT_VAL_56
+#  endif
+#  ifdef XLAT_VAL_57
+  | XLAT_VAL_57
+#  endif
+#  ifdef XLAT_VAL_58
+  | XLAT_VAL_58
+#  endif
+#  ifdef XLAT_VAL_59
+  | XLAT_VAL_59
+#  endif
+#  ifdef XLAT_VAL_60
+  | XLAT_VAL_60
+#  endif
+#  ifdef XLAT_VAL_61
+  | XLAT_VAL_61
+#  endif
+#  ifdef XLAT_VAL_62
+  | XLAT_VAL_62
+#  endif
+#  ifdef XLAT_VAL_63
+  | XLAT_VAL_63
+#  endif
+#  ifdef XLAT_VAL_64
+  | XLAT_VAL_64
+#  endif
+#  ifdef XLAT_VAL_65
+  | XLAT_VAL_65
+#  endif
+#  ifdef XLAT_VAL_66
+  | XLAT_VAL_66
+#  endif
+#  ifdef XLAT_VAL_67
+  | XLAT_VAL_67
+#  endif
+#  ifdef XLAT_VAL_68
+  | XLAT_VAL_68
+#  endif
+#  ifdef XLAT_VAL_69
+  | XLAT_VAL_69
+#  endif
+#  ifdef XLAT_VAL_70
+  | XLAT_VAL_70
+#  endif
+#  ifdef XLAT_VAL_71
+  | XLAT_VAL_71
+#  endif
+#  ifdef XLAT_VAL_72
+  | XLAT_VAL_72
+#  endif
+#  ifdef XLAT_VAL_73
+  | XLAT_VAL_73
+#  endif
+#  ifdef XLAT_VAL_74
+  | XLAT_VAL_74
+#  endif
+#  ifdef XLAT_VAL_75
+  | XLAT_VAL_75
+#  endif
+#  ifdef XLAT_VAL_76
+  | XLAT_VAL_76
+#  endif
+#  ifdef XLAT_VAL_77
+  | XLAT_VAL_77
+#  endif
+#  ifdef XLAT_VAL_78
+  | XLAT_VAL_78
+#  endif
+#  ifdef XLAT_VAL_79
+  | XLAT_VAL_79
+#  endif
+#  ifdef XLAT_VAL_80
+  | XLAT_VAL_80
+#  endif
+#  ifdef XLAT_VAL_81
+  | XLAT_VAL_81
+#  endif
+#  ifdef XLAT_VAL_82
+  | XLAT_VAL_82
+#  endif
+#  ifdef XLAT_VAL_83
+  | XLAT_VAL_83
+#  endif
+#  ifdef XLAT_VAL_84
+  | XLAT_VAL_84
+#  endif
+#  ifdef XLAT_VAL_85
+  | XLAT_VAL_85
+#  endif
+#  ifdef XLAT_VAL_86
+  | XLAT_VAL_86
+#  endif
+#  ifdef XLAT_VAL_87
+  | XLAT_VAL_87
+#  endif
+#  ifdef XLAT_VAL_88
+  | XLAT_VAL_88
+#  endif
+#  ifdef XLAT_VAL_89
+  | XLAT_VAL_89
+#  endif
+#  ifdef XLAT_VAL_90
+  | XLAT_VAL_90
+#  endif
+#  ifdef XLAT_VAL_91
+  | XLAT_VAL_91
+#  endif
+#  ifdef XLAT_VAL_92
+  | XLAT_VAL_92
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+#  ifdef XLAT_STR_47
+  + sizeof(XLAT_STR_47)
+#  endif
+#  ifdef XLAT_STR_48
+  + sizeof(XLAT_STR_48)
+#  endif
+#  ifdef XLAT_STR_49
+  + sizeof(XLAT_STR_49)
+#  endif
+#  ifdef XLAT_STR_50
+  + sizeof(XLAT_STR_50)
+#  endif
+#  ifdef XLAT_STR_51
+  + sizeof(XLAT_STR_51)
+#  endif
+#  ifdef XLAT_STR_52
+  + sizeof(XLAT_STR_52)
+#  endif
+#  ifdef XLAT_STR_53
+  + sizeof(XLAT_STR_53)
+#  endif
+#  ifdef XLAT_STR_54
+  + sizeof(XLAT_STR_54)
+#  endif
+#  ifdef XLAT_STR_55
+  + sizeof(XLAT_STR_55)
+#  endif
+#  ifdef XLAT_STR_56
+  + sizeof(XLAT_STR_56)
+#  endif
+#  ifdef XLAT_STR_57
+  + sizeof(XLAT_STR_57)
+#  endif
+#  ifdef XLAT_STR_58
+  + sizeof(XLAT_STR_58)
+#  endif
+#  ifdef XLAT_STR_59
+  + sizeof(XLAT_STR_59)
+#  endif
+#  ifdef XLAT_STR_60
+  + sizeof(XLAT_STR_60)
+#  endif
+#  ifdef XLAT_STR_61
+  + sizeof(XLAT_STR_61)
+#  endif
+#  ifdef XLAT_STR_62
+  + sizeof(XLAT_STR_62)
+#  endif
+#  ifdef XLAT_STR_63
+  + sizeof(XLAT_STR_63)
+#  endif
+#  ifdef XLAT_STR_64
+  + sizeof(XLAT_STR_64)
+#  endif
+#  ifdef XLAT_STR_65
+  + sizeof(XLAT_STR_65)
+#  endif
+#  ifdef XLAT_STR_66
+  + sizeof(XLAT_STR_66)
+#  endif
+#  ifdef XLAT_STR_67
+  + sizeof(XLAT_STR_67)
+#  endif
+#  ifdef XLAT_STR_68
+  + sizeof(XLAT_STR_68)
+#  endif
+#  ifdef XLAT_STR_69
+  + sizeof(XLAT_STR_69)
+#  endif
+#  ifdef XLAT_STR_70
+  + sizeof(XLAT_STR_70)
+#  endif
+#  ifdef XLAT_STR_71
+  + sizeof(XLAT_STR_71)
+#  endif
+#  ifdef XLAT_STR_72
+  + sizeof(XLAT_STR_72)
+#  endif
+#  ifdef XLAT_STR_73
+  + sizeof(XLAT_STR_73)
+#  endif
+#  ifdef XLAT_STR_74
+  + sizeof(XLAT_STR_74)
+#  endif
+#  ifdef XLAT_STR_75
+  + sizeof(XLAT_STR_75)
+#  endif
+#  ifdef XLAT_STR_76
+  + sizeof(XLAT_STR_76)
+#  endif
+#  ifdef XLAT_STR_77
+  + sizeof(XLAT_STR_77)
+#  endif
+#  ifdef XLAT_STR_78
+  + sizeof(XLAT_STR_78)
+#  endif
+#  ifdef XLAT_STR_79
+  + sizeof(XLAT_STR_79)
+#  endif
+#  ifdef XLAT_STR_80
+  + sizeof(XLAT_STR_80)
+#  endif
+#  ifdef XLAT_STR_81
+  + sizeof(XLAT_STR_81)
+#  endif
+#  ifdef XLAT_STR_82
+  + sizeof(XLAT_STR_82)
+#  endif
+#  ifdef XLAT_STR_83
+  + sizeof(XLAT_STR_83)
+#  endif
+#  ifdef XLAT_STR_84
+  + sizeof(XLAT_STR_84)
+#  endif
+#  ifdef XLAT_STR_85
+  + sizeof(XLAT_STR_85)
+#  endif
+#  ifdef XLAT_STR_86
+  + sizeof(XLAT_STR_86)
+#  endif
+#  ifdef XLAT_STR_87
+  + sizeof(XLAT_STR_87)
+#  endif
+#  ifdef XLAT_STR_88
+  + sizeof(XLAT_STR_88)
+#  endif
+#  ifdef XLAT_STR_89
+  + sizeof(XLAT_STR_89)
+#  endif
+#  ifdef XLAT_STR_90
+  + sizeof(XLAT_STR_90)
+#  endif
+#  ifdef XLAT_STR_91
+  + sizeof(XLAT_STR_91)
+#  endif
+#  ifdef XLAT_STR_92
+  + sizeof(XLAT_STR_92)
+#  endif
+  ,
+} };
+
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
+#  undef XLAT_STR_47
+#  undef XLAT_VAL_47
+#  undef XLAT_STR_48
+#  undef XLAT_VAL_48
+#  undef XLAT_STR_49
+#  undef XLAT_VAL_49
+#  undef XLAT_STR_50
+#  undef XLAT_VAL_50
+#  undef XLAT_STR_51
+#  undef XLAT_VAL_51
+#  undef XLAT_STR_52
+#  undef XLAT_VAL_52
+#  undef XLAT_STR_53
+#  undef XLAT_VAL_53
+#  undef XLAT_STR_54
+#  undef XLAT_VAL_54
+#  undef XLAT_STR_55
+#  undef XLAT_VAL_55
+#  undef XLAT_STR_56
+#  undef XLAT_VAL_56
+#  undef XLAT_STR_57
+#  undef XLAT_VAL_57
+#  undef XLAT_STR_58
+#  undef XLAT_VAL_58
+#  undef XLAT_STR_59
+#  undef XLAT_VAL_59
+#  undef XLAT_STR_60
+#  undef XLAT_VAL_60
+#  undef XLAT_STR_61
+#  undef XLAT_VAL_61
+#  undef XLAT_STR_62
+#  undef XLAT_VAL_62
+#  undef XLAT_STR_63
+#  undef XLAT_VAL_63
+#  undef XLAT_STR_64
+#  undef XLAT_VAL_64
+#  undef XLAT_STR_65
+#  undef XLAT_VAL_65
+#  undef XLAT_STR_66
+#  undef XLAT_VAL_66
+#  undef XLAT_STR_67
+#  undef XLAT_VAL_67
+#  undef XLAT_STR_68
+#  undef XLAT_VAL_68
+#  undef XLAT_STR_69
+#  undef XLAT_VAL_69
+#  undef XLAT_STR_70
+#  undef XLAT_VAL_70
+#  undef XLAT_STR_71
+#  undef XLAT_VAL_71
+#  undef XLAT_STR_72
+#  undef XLAT_VAL_72
+#  undef XLAT_STR_73
+#  undef XLAT_VAL_73
+#  undef XLAT_STR_74
+#  undef XLAT_VAL_74
+#  undef XLAT_STR_75
+#  undef XLAT_VAL_75
+#  undef XLAT_STR_76
+#  undef XLAT_VAL_76
+#  undef XLAT_STR_77
+#  undef XLAT_VAL_77
+#  undef XLAT_STR_78
+#  undef XLAT_VAL_78
+#  undef XLAT_STR_79
+#  undef XLAT_VAL_79
+#  undef XLAT_STR_80
+#  undef XLAT_VAL_80
+#  undef XLAT_STR_81
+#  undef XLAT_VAL_81
+#  undef XLAT_STR_82
+#  undef XLAT_VAL_82
+#  undef XLAT_STR_83
+#  undef XLAT_VAL_83
+#  undef XLAT_STR_84
+#  undef XLAT_VAL_84
+#  undef XLAT_STR_85
+#  undef XLAT_VAL_85
+#  undef XLAT_STR_86
+#  undef XLAT_VAL_86
+#  undef XLAT_STR_87
+#  undef XLAT_VAL_87
+#  undef XLAT_STR_88
+#  undef XLAT_VAL_88
+#  undef XLAT_STR_89
+#  undef XLAT_VAL_89
+#  undef XLAT_STR_90
+#  undef XLAT_VAL_90
+#  undef XLAT_STR_91
+#  undef XLAT_VAL_91
+#  undef XLAT_STR_92
+#  undef XLAT_VAL_92
+# endif /* !IN_MPERS */
+
+#endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/hdio_drive_cmds.in 5.9-0ubuntu2/xlat/hdio_drive_cmds.in
--- 5.5-3/xlat/hdio_drive_cmds.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/hdio_drive_cmds.in	2020-04-02 21:05:45.000000000 +0000
@@ -0,0 +1,94 @@
+#sorted sort -k2,2
+ATA_CMD_NOP			0x00
+ATA_CMD_CFA_REQ_EXT_ERR		0x03
+ATA_CMD_DSM			0x06
+ATA_CMD_DEV_RESET		0x08
+ATA_CMD_REQ_SENSE_DATA		0x0B
+ATA_CMD_RESTORE			0x10
+ATA_CMD_PIO_READ		0x20
+ATA_CMD_READ_LONG		0x22
+ATA_CMD_READ_LONG_ONCE		0x23
+ATA_CMD_PIO_READ_EXT		0x24
+ATA_CMD_READ_EXT		0x25
+ATA_CMD_READ_QUEUED		0x26
+ATA_CMD_READ_NATIVE_MAX_EXT	0x27
+ATA_CMD_READ_MULTI_EXT		0x29
+ATA_CMD_READ_STREAM_DMA_EXT	0x2A
+ATA_CMD_READ_STREAM_EXT		0x2B
+ATA_CMD_READ_LOG_EXT		0x2F
+ATA_CMD_PIO_WRITE		0x30
+ATA_CMD_WRITE_LONG		0x32
+ATA_CMD_WRITE_LONG_ONCE		0x33
+ATA_CMD_PIO_WRITE_EXT		0x34
+ATA_CMD_WRITE_EXT		0x35
+ATA_CMD_WRITE_QUEUED		0x36
+ATA_CMD_SET_MAX_EXT		0x37
+ATA_CMD_CFA_WRITE_NE		0x38
+ATA_CMD_WRITE_MULTI_EXT		0x39
+ATA_CMD_WRITE_STREAM_DMA_EXT	0x3A
+ATA_CMD_WRITE_STREAM_EXT	0x3B
+ATA_CMD_WRITE_FUA_EXT		0x3D
+ATA_CMD_WRITE_QUEUED_FUA_EXT	0x3E
+ATA_CMD_WRITE_LOG_EXT		0x3F
+ATA_CMD_VERIFY			0x40
+ATA_CMD_VERIFY_EXT		0x42
+ATA_CMD_WRITE_UNCORR_EXT	0x45
+ATA_CMD_READ_LOG_DMA_EXT	0x47
+ATA_CMD_ZAC_MGMT_IN		0x4A
+ATA_CMD_CONFIG_STREAM		0x51
+ATA_CMD_WRITE_LOG_DMA_EXT	0x57
+ATA_CMD_TRUSTED_NONDATA		0x5B
+ATA_CMD_TRUSTED_RCV		0x5C
+ATA_CMD_TRUSTED_RCV_DMA		0x5D
+ATA_CMD_TRUSTED_SND		0x5E
+ATA_CMD_TRUSTED_SND_DMA		0x5F
+ATA_CMD_FPDMA_READ		0x60
+ATA_CMD_FPDMA_WRITE		0x61
+ATA_CMD_NCQ_NON_DATA		0x63
+ATA_CMD_FPDMA_SEND		0x64
+ATA_CMD_FPDMA_RECV		0x65
+ATA_CMD_CFA_TRANS_SECT		0x87
+ATA_CMD_EDD			0x90
+ATA_CMD_INIT_DEV_PARAMS		0x91
+ATA_CMD_DOWNLOAD_MICRO		0x92
+ATA_CMD_DOWNLOAD_MICRO_DMA	0x93
+ATA_CMD_ZAC_MGMT_OUT		0x9F
+ATA_CMD_PACKET			0xA0
+ATA_CMD_ID_ATAPI		0xA1
+ATA_CMD_SERVICE			0xA2
+ATA_CMD_SMART			0xB0
+ATA_CMD_CONF_OVERLAY		0xB1
+ATA_CMD_SANITIZE_DEVICE		0xB4
+ATA_CMD_CFA_ERASE		0xC0
+ATA_CMD_READ_MULTI		0xC4
+ATA_CMD_WRITE_MULTI		0xC5
+ATA_CMD_SET_MULTI		0xC6
+ATA_CMD_READ			0xC8
+ATA_CMD_WRITE			0xCA
+ATA_CMD_CFA_WRITE_MULT_NE	0xCD
+ATA_CMD_WRITE_MULTI_FUA_EXT	0xCE
+ATA_CMD_CHK_MED_CRD_TYP		0xD1
+ATA_CMD_MEDIA_LOCK		0xDE
+ATA_CMD_MEDIA_UNLOCK		0xDF
+ATA_CMD_STANDBYNOW1		0xE0
+ATA_CMD_IDLEIMMEDIATE		0xE1
+ATA_CMD_STANDBY			0xE2
+ATA_CMD_IDLE			0xE3
+ATA_CMD_PMP_READ		0xE4
+ATA_CMD_CHK_POWER		0xE5
+ATA_CMD_SLEEP			0xE6
+ATA_CMD_FLUSH			0xE7
+ATA_CMD_PMP_WRITE		0xE8
+ATA_CMD_PMP_READ_DMA		0xE9
+ATA_CMD_FLUSH_EXT		0xEA
+ATA_CMD_PMP_WRITE_DMA		0xEB
+ATA_CMD_ID_ATA			0xEC
+ATA_CMD_SET_FEATURES		0xEF
+ATA_CMD_SEC_SET_PASS		0xF1
+ATA_CMD_SEC_UNLOCK		0xF2
+ATA_CMD_SEC_ERASE_PREP		0xF3
+ATA_CMD_SEC_ERASE_UNIT		0xF4
+ATA_CMD_SEC_FREEZE_LOCK		0xF5
+ATA_CMD_SEC_DISABLE_PASS	0xF6
+ATA_CMD_READ_NATIVE_MAX		0xF8
+ATA_CMD_SET_MAX			0xF9
diff -pruN 5.5-3/xlat/hw_breakpoint_len.h 5.9-0ubuntu2/xlat/hw_breakpoint_len.h
--- 5.5-3/xlat/hw_breakpoint_len.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/hw_breakpoint_len.h	2020-09-24 09:18:44.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data hw_breakpoint_len_xdata[] = {
  XLAT(HW_BREAKPOINT_LEN_1),
+ #define XLAT_VAL_0 ((unsigned) (HW_BREAKPOINT_LEN_1))
+ #define XLAT_STR_0 STRINGIFY(HW_BREAKPOINT_LEN_1)
  XLAT(HW_BREAKPOINT_LEN_2),
+ #define XLAT_VAL_1 ((unsigned) (HW_BREAKPOINT_LEN_2))
+ #define XLAT_STR_1 STRINGIFY(HW_BREAKPOINT_LEN_2)
  XLAT(HW_BREAKPOINT_LEN_4),
+ #define XLAT_VAL_2 ((unsigned) (HW_BREAKPOINT_LEN_4))
+ #define XLAT_STR_2 STRINGIFY(HW_BREAKPOINT_LEN_4)
  XLAT(HW_BREAKPOINT_LEN_8),
+ #define XLAT_VAL_3 ((unsigned) (HW_BREAKPOINT_LEN_8))
+ #define XLAT_STR_3 STRINGIFY(HW_BREAKPOINT_LEN_8)
 };
 static
 const struct xlat hw_breakpoint_len[1] = { {
  .data = hw_breakpoint_len_xdata,
  .size = ARRAY_SIZE(hw_breakpoint_len_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/hw_breakpoint_type.h 5.9-0ubuntu2/xlat/hw_breakpoint_type.h
--- 5.5-3/xlat/hw_breakpoint_type.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/hw_breakpoint_type.h	2020-09-24 09:18:44.000000000 +0000
@@ -49,18 +49,72 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data hw_breakpoint_type_xdata[] = {
  XLAT(HW_BREAKPOINT_EMPTY),
+ #define XLAT_VAL_0 ((unsigned) (HW_BREAKPOINT_EMPTY))
+ #define XLAT_STR_0 STRINGIFY(HW_BREAKPOINT_EMPTY)
  XLAT(HW_BREAKPOINT_R),
+ #define XLAT_VAL_1 ((unsigned) (HW_BREAKPOINT_R))
+ #define XLAT_STR_1 STRINGIFY(HW_BREAKPOINT_R)
  XLAT(HW_BREAKPOINT_W),
+ #define XLAT_VAL_2 ((unsigned) (HW_BREAKPOINT_W))
+ #define XLAT_STR_2 STRINGIFY(HW_BREAKPOINT_W)
  XLAT(HW_BREAKPOINT_RW),
+ #define XLAT_VAL_3 ((unsigned) (HW_BREAKPOINT_RW))
+ #define XLAT_STR_3 STRINGIFY(HW_BREAKPOINT_RW)
  XLAT(HW_BREAKPOINT_X),
+ #define XLAT_VAL_4 ((unsigned) (HW_BREAKPOINT_X))
+ #define XLAT_STR_4 STRINGIFY(HW_BREAKPOINT_X)
 };
 static
 const struct xlat hw_breakpoint_type[1] = { {
  .data = hw_breakpoint_type_xdata,
  .size = ARRAY_SIZE(hw_breakpoint_type_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/icmpfilterflags.h 5.9-0ubuntu2/xlat/icmpfilterflags.h
--- 5.5-3/xlat/icmpfilterflags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/icmpfilterflags.h	2020-09-24 09:18:44.000000000 +0000
@@ -15,42 +15,68 @@
 static const struct xlat_data icmpfilterflags_xdata[] = {
 #if defined(ICMP_ECHOREPLY) || (defined(HAVE_DECL_ICMP_ECHOREPLY) && HAVE_DECL_ICMP_ECHOREPLY)
   XLAT_PAIR(1ULL<<ICMP_ECHOREPLY, "1<<ICMP_ECHOREPLY"),
+ #define XLAT_VAL_0 ((unsigned) (1ULL<<ICMP_ECHOREPLY))
+ #define XLAT_STR_0 "1<<ICMP_ECHOREPLY"
 #endif
 #if defined(ICMP_DEST_UNREACH) || (defined(HAVE_DECL_ICMP_DEST_UNREACH) && HAVE_DECL_ICMP_DEST_UNREACH)
   XLAT_PAIR(1ULL<<ICMP_DEST_UNREACH, "1<<ICMP_DEST_UNREACH"),
+ #define XLAT_VAL_1 ((unsigned) (1ULL<<ICMP_DEST_UNREACH))
+ #define XLAT_STR_1 "1<<ICMP_DEST_UNREACH"
 #endif
 #if defined(ICMP_SOURCE_QUENCH) || (defined(HAVE_DECL_ICMP_SOURCE_QUENCH) && HAVE_DECL_ICMP_SOURCE_QUENCH)
   XLAT_PAIR(1ULL<<ICMP_SOURCE_QUENCH, "1<<ICMP_SOURCE_QUENCH"),
+ #define XLAT_VAL_2 ((unsigned) (1ULL<<ICMP_SOURCE_QUENCH))
+ #define XLAT_STR_2 "1<<ICMP_SOURCE_QUENCH"
 #endif
 #if defined(ICMP_REDIRECT) || (defined(HAVE_DECL_ICMP_REDIRECT) && HAVE_DECL_ICMP_REDIRECT)
   XLAT_PAIR(1ULL<<ICMP_REDIRECT, "1<<ICMP_REDIRECT"),
+ #define XLAT_VAL_3 ((unsigned) (1ULL<<ICMP_REDIRECT))
+ #define XLAT_STR_3 "1<<ICMP_REDIRECT"
 #endif
 #if defined(ICMP_ECHO) || (defined(HAVE_DECL_ICMP_ECHO) && HAVE_DECL_ICMP_ECHO)
   XLAT_PAIR(1ULL<<ICMP_ECHO, "1<<ICMP_ECHO"),
+ #define XLAT_VAL_4 ((unsigned) (1ULL<<ICMP_ECHO))
+ #define XLAT_STR_4 "1<<ICMP_ECHO"
 #endif
 #if defined(ICMP_TIME_EXCEEDED) || (defined(HAVE_DECL_ICMP_TIME_EXCEEDED) && HAVE_DECL_ICMP_TIME_EXCEEDED)
   XLAT_PAIR(1ULL<<ICMP_TIME_EXCEEDED, "1<<ICMP_TIME_EXCEEDED"),
+ #define XLAT_VAL_5 ((unsigned) (1ULL<<ICMP_TIME_EXCEEDED))
+ #define XLAT_STR_5 "1<<ICMP_TIME_EXCEEDED"
 #endif
 #if defined(ICMP_PARAMETERPROB) || (defined(HAVE_DECL_ICMP_PARAMETERPROB) && HAVE_DECL_ICMP_PARAMETERPROB)
   XLAT_PAIR(1ULL<<ICMP_PARAMETERPROB, "1<<ICMP_PARAMETERPROB"),
+ #define XLAT_VAL_6 ((unsigned) (1ULL<<ICMP_PARAMETERPROB))
+ #define XLAT_STR_6 "1<<ICMP_PARAMETERPROB"
 #endif
 #if defined(ICMP_TIMESTAMP) || (defined(HAVE_DECL_ICMP_TIMESTAMP) && HAVE_DECL_ICMP_TIMESTAMP)
   XLAT_PAIR(1ULL<<ICMP_TIMESTAMP, "1<<ICMP_TIMESTAMP"),
+ #define XLAT_VAL_7 ((unsigned) (1ULL<<ICMP_TIMESTAMP))
+ #define XLAT_STR_7 "1<<ICMP_TIMESTAMP"
 #endif
 #if defined(ICMP_TIMESTAMPREPLY) || (defined(HAVE_DECL_ICMP_TIMESTAMPREPLY) && HAVE_DECL_ICMP_TIMESTAMPREPLY)
   XLAT_PAIR(1ULL<<ICMP_TIMESTAMPREPLY, "1<<ICMP_TIMESTAMPREPLY"),
+ #define XLAT_VAL_8 ((unsigned) (1ULL<<ICMP_TIMESTAMPREPLY))
+ #define XLAT_STR_8 "1<<ICMP_TIMESTAMPREPLY"
 #endif
 #if defined(ICMP_INFO_REQUEST) || (defined(HAVE_DECL_ICMP_INFO_REQUEST) && HAVE_DECL_ICMP_INFO_REQUEST)
   XLAT_PAIR(1ULL<<ICMP_INFO_REQUEST, "1<<ICMP_INFO_REQUEST"),
+ #define XLAT_VAL_9 ((unsigned) (1ULL<<ICMP_INFO_REQUEST))
+ #define XLAT_STR_9 "1<<ICMP_INFO_REQUEST"
 #endif
 #if defined(ICMP_INFO_REPLY) || (defined(HAVE_DECL_ICMP_INFO_REPLY) && HAVE_DECL_ICMP_INFO_REPLY)
   XLAT_PAIR(1ULL<<ICMP_INFO_REPLY, "1<<ICMP_INFO_REPLY"),
+ #define XLAT_VAL_10 ((unsigned) (1ULL<<ICMP_INFO_REPLY))
+ #define XLAT_STR_10 "1<<ICMP_INFO_REPLY"
 #endif
 #if defined(ICMP_ADDRESS) || (defined(HAVE_DECL_ICMP_ADDRESS) && HAVE_DECL_ICMP_ADDRESS)
   XLAT_PAIR(1ULL<<ICMP_ADDRESS, "1<<ICMP_ADDRESS"),
+ #define XLAT_VAL_11 ((unsigned) (1ULL<<ICMP_ADDRESS))
+ #define XLAT_STR_11 "1<<ICMP_ADDRESS"
 #endif
 #if defined(ICMP_ADDRESSREPLY) || (defined(HAVE_DECL_ICMP_ADDRESSREPLY) && HAVE_DECL_ICMP_ADDRESSREPLY)
   XLAT_PAIR(1ULL<<ICMP_ADDRESSREPLY, "1<<ICMP_ADDRESSREPLY"),
+ #define XLAT_VAL_12 ((unsigned) (1ULL<<ICMP_ADDRESSREPLY))
+ #define XLAT_STR_12 "1<<ICMP_ADDRESSREPLY"
 #endif
 };
 static
@@ -58,8 +84,116 @@ const struct xlat icmpfilterflags[1] = {
  .data = icmpfilterflags_xdata,
  .size = ARRAY_SIZE(icmpfilterflags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ifaddrflags.h 5.9-0ubuntu2/xlat/ifaddrflags.h
--- 5.5-3/xlat/ifaddrflags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ifaddrflags.h	2020-09-24 09:18:44.000000000 +0000
@@ -15,39 +15,63 @@
 static const struct xlat_data ifaddrflags_xdata[] = {
 #if defined(IFA_F_SECONDARY) || (defined(HAVE_DECL_IFA_F_SECONDARY) && HAVE_DECL_IFA_F_SECONDARY)
   XLAT(IFA_F_SECONDARY),
+ #define XLAT_VAL_0 ((unsigned) (IFA_F_SECONDARY))
+ #define XLAT_STR_0 STRINGIFY(IFA_F_SECONDARY)
 #endif
 #if defined(IFA_F_NODAD) || (defined(HAVE_DECL_IFA_F_NODAD) && HAVE_DECL_IFA_F_NODAD)
   XLAT(IFA_F_NODAD),
+ #define XLAT_VAL_1 ((unsigned) (IFA_F_NODAD))
+ #define XLAT_STR_1 STRINGIFY(IFA_F_NODAD)
 #endif
 #if defined(IFA_F_OPTIMISTIC) || (defined(HAVE_DECL_IFA_F_OPTIMISTIC) && HAVE_DECL_IFA_F_OPTIMISTIC)
   XLAT(IFA_F_OPTIMISTIC),
+ #define XLAT_VAL_2 ((unsigned) (IFA_F_OPTIMISTIC))
+ #define XLAT_STR_2 STRINGIFY(IFA_F_OPTIMISTIC)
 #endif
 #if defined(IFA_F_DADFAILED) || (defined(HAVE_DECL_IFA_F_DADFAILED) && HAVE_DECL_IFA_F_DADFAILED)
   XLAT(IFA_F_DADFAILED),
+ #define XLAT_VAL_3 ((unsigned) (IFA_F_DADFAILED))
+ #define XLAT_STR_3 STRINGIFY(IFA_F_DADFAILED)
 #endif
 #if defined(IFA_F_HOMEADDRESS) || (defined(HAVE_DECL_IFA_F_HOMEADDRESS) && HAVE_DECL_IFA_F_HOMEADDRESS)
   XLAT(IFA_F_HOMEADDRESS),
+ #define XLAT_VAL_4 ((unsigned) (IFA_F_HOMEADDRESS))
+ #define XLAT_STR_4 STRINGIFY(IFA_F_HOMEADDRESS)
 #endif
 #if defined(IFA_F_DEPRECATED) || (defined(HAVE_DECL_IFA_F_DEPRECATED) && HAVE_DECL_IFA_F_DEPRECATED)
   XLAT(IFA_F_DEPRECATED),
+ #define XLAT_VAL_5 ((unsigned) (IFA_F_DEPRECATED))
+ #define XLAT_STR_5 STRINGIFY(IFA_F_DEPRECATED)
 #endif
 #if defined(IFA_F_TENTATIVE) || (defined(HAVE_DECL_IFA_F_TENTATIVE) && HAVE_DECL_IFA_F_TENTATIVE)
   XLAT(IFA_F_TENTATIVE),
+ #define XLAT_VAL_6 ((unsigned) (IFA_F_TENTATIVE))
+ #define XLAT_STR_6 STRINGIFY(IFA_F_TENTATIVE)
 #endif
 #if defined(IFA_F_PERMANENT) || (defined(HAVE_DECL_IFA_F_PERMANENT) && HAVE_DECL_IFA_F_PERMANENT)
   XLAT(IFA_F_PERMANENT),
+ #define XLAT_VAL_7 ((unsigned) (IFA_F_PERMANENT))
+ #define XLAT_STR_7 STRINGIFY(IFA_F_PERMANENT)
 #endif
 #if defined(IFA_F_MANAGETEMPADDR) || (defined(HAVE_DECL_IFA_F_MANAGETEMPADDR) && HAVE_DECL_IFA_F_MANAGETEMPADDR)
   XLAT(IFA_F_MANAGETEMPADDR),
+ #define XLAT_VAL_8 ((unsigned) (IFA_F_MANAGETEMPADDR))
+ #define XLAT_STR_8 STRINGIFY(IFA_F_MANAGETEMPADDR)
 #endif
 #if defined(IFA_F_NOPREFIXROUTE) || (defined(HAVE_DECL_IFA_F_NOPREFIXROUTE) && HAVE_DECL_IFA_F_NOPREFIXROUTE)
   XLAT(IFA_F_NOPREFIXROUTE),
+ #define XLAT_VAL_9 ((unsigned) (IFA_F_NOPREFIXROUTE))
+ #define XLAT_STR_9 STRINGIFY(IFA_F_NOPREFIXROUTE)
 #endif
 #if defined(IFA_F_MCAUTOJOIN) || (defined(HAVE_DECL_IFA_F_MCAUTOJOIN) && HAVE_DECL_IFA_F_MCAUTOJOIN)
   XLAT(IFA_F_MCAUTOJOIN),
+ #define XLAT_VAL_10 ((unsigned) (IFA_F_MCAUTOJOIN))
+ #define XLAT_STR_10 STRINGIFY(IFA_F_MCAUTOJOIN)
 #endif
 #if defined(IFA_F_STABLE_PRIVACY) || (defined(HAVE_DECL_IFA_F_STABLE_PRIVACY) && HAVE_DECL_IFA_F_STABLE_PRIVACY)
   XLAT(IFA_F_STABLE_PRIVACY),
+ #define XLAT_VAL_11 ((unsigned) (IFA_F_STABLE_PRIVACY))
+ #define XLAT_STR_11 STRINGIFY(IFA_F_STABLE_PRIVACY)
 #endif
 };
 static
@@ -55,8 +79,108 @@ const struct xlat ifaddrflags[1] = { {
  .data = ifaddrflags_xdata,
  .size = ARRAY_SIZE(ifaddrflags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/if_dqblk_valid.h 5.9-0ubuntu2/xlat/if_dqblk_valid.h
--- 5.5-3/xlat/if_dqblk_valid.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/if_dqblk_valid.h	2020-09-24 09:18:44.000000000 +0000
@@ -56,19 +56,83 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data if_dqblk_valid_xdata[] = {
  XLAT(QIF_BLIMITS),
+ #define XLAT_VAL_0 ((unsigned) (QIF_BLIMITS))
+ #define XLAT_STR_0 STRINGIFY(QIF_BLIMITS)
  XLAT(QIF_SPACE),
+ #define XLAT_VAL_1 ((unsigned) (QIF_SPACE))
+ #define XLAT_STR_1 STRINGIFY(QIF_SPACE)
  XLAT(QIF_ILIMITS),
+ #define XLAT_VAL_2 ((unsigned) (QIF_ILIMITS))
+ #define XLAT_STR_2 STRINGIFY(QIF_ILIMITS)
  XLAT(QIF_INODES),
+ #define XLAT_VAL_3 ((unsigned) (QIF_INODES))
+ #define XLAT_STR_3 STRINGIFY(QIF_INODES)
  XLAT(QIF_BTIME),
+ #define XLAT_VAL_4 ((unsigned) (QIF_BTIME))
+ #define XLAT_STR_4 STRINGIFY(QIF_BTIME)
  XLAT(QIF_ITIME),
+ #define XLAT_VAL_5 ((unsigned) (QIF_ITIME))
+ #define XLAT_STR_5 STRINGIFY(QIF_ITIME)
 };
 static
 const struct xlat if_dqblk_valid[1] = { {
  .data = if_dqblk_valid_xdata,
  .size = ARRAY_SIZE(if_dqblk_valid_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/if_dqinfo_flags.h 5.9-0ubuntu2/xlat/if_dqinfo_flags.h
--- 5.5-3/xlat/if_dqinfo_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/if_dqinfo_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data if_dqinfo_flags_xdata[] = {
  XLAT(DQF_ROOT_SQUASH),
+ #define XLAT_VAL_0 ((unsigned) (DQF_ROOT_SQUASH))
+ #define XLAT_STR_0 STRINGIFY(DQF_ROOT_SQUASH)
  XLAT(DQF_SYS_FILE),
+ #define XLAT_VAL_1 ((unsigned) (DQF_SYS_FILE))
+ #define XLAT_STR_1 STRINGIFY(DQF_SYS_FILE)
 };
 static
 const struct xlat if_dqinfo_flags[1] = { {
  .data = if_dqinfo_flags_xdata,
  .size = ARRAY_SIZE(if_dqinfo_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/if_dqinfo_valid.h 5.9-0ubuntu2/xlat/if_dqinfo_valid.h
--- 5.5-3/xlat/if_dqinfo_valid.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/if_dqinfo_valid.h	2020-09-24 09:18:44.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data if_dqinfo_valid_xdata[] = {
  XLAT(IIF_BGRACE),
+ #define XLAT_VAL_0 ((unsigned) (IIF_BGRACE))
+ #define XLAT_STR_0 STRINGIFY(IIF_BGRACE)
  XLAT(IIF_IGRACE),
+ #define XLAT_VAL_1 ((unsigned) (IIF_IGRACE))
+ #define XLAT_STR_1 STRINGIFY(IIF_IGRACE)
  XLAT(IIF_FLAGS),
+ #define XLAT_VAL_2 ((unsigned) (IIF_FLAGS))
+ #define XLAT_STR_2 STRINGIFY(IIF_FLAGS)
 };
 static
 const struct xlat if_dqinfo_valid[1] = { {
  .data = if_dqinfo_valid_xdata,
  .size = ARRAY_SIZE(if_dqinfo_valid_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/iffflags.h 5.9-0ubuntu2/xlat/iffflags.h
--- 5.5-3/xlat/iffflags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/iffflags.h	2020-09-24 09:18:45.000000000 +0000
@@ -143,31 +143,225 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data iffflags_xdata[] = {
  XLAT(IFF_UP),
+ #define XLAT_VAL_0 ((unsigned) (IFF_UP))
+ #define XLAT_STR_0 STRINGIFY(IFF_UP)
  XLAT(IFF_BROADCAST),
+ #define XLAT_VAL_1 ((unsigned) (IFF_BROADCAST))
+ #define XLAT_STR_1 STRINGIFY(IFF_BROADCAST)
  XLAT(IFF_DEBUG),
+ #define XLAT_VAL_2 ((unsigned) (IFF_DEBUG))
+ #define XLAT_STR_2 STRINGIFY(IFF_DEBUG)
  XLAT(IFF_LOOPBACK),
+ #define XLAT_VAL_3 ((unsigned) (IFF_LOOPBACK))
+ #define XLAT_STR_3 STRINGIFY(IFF_LOOPBACK)
  XLAT(IFF_POINTOPOINT),
+ #define XLAT_VAL_4 ((unsigned) (IFF_POINTOPOINT))
+ #define XLAT_STR_4 STRINGIFY(IFF_POINTOPOINT)
  XLAT(IFF_NOTRAILERS),
+ #define XLAT_VAL_5 ((unsigned) (IFF_NOTRAILERS))
+ #define XLAT_STR_5 STRINGIFY(IFF_NOTRAILERS)
  XLAT(IFF_RUNNING),
+ #define XLAT_VAL_6 ((unsigned) (IFF_RUNNING))
+ #define XLAT_STR_6 STRINGIFY(IFF_RUNNING)
  XLAT(IFF_NOARP),
+ #define XLAT_VAL_7 ((unsigned) (IFF_NOARP))
+ #define XLAT_STR_7 STRINGIFY(IFF_NOARP)
  XLAT(IFF_PROMISC),
+ #define XLAT_VAL_8 ((unsigned) (IFF_PROMISC))
+ #define XLAT_STR_8 STRINGIFY(IFF_PROMISC)
  XLAT(IFF_ALLMULTI),
+ #define XLAT_VAL_9 ((unsigned) (IFF_ALLMULTI))
+ #define XLAT_STR_9 STRINGIFY(IFF_ALLMULTI)
  XLAT(IFF_MASTER),
+ #define XLAT_VAL_10 ((unsigned) (IFF_MASTER))
+ #define XLAT_STR_10 STRINGIFY(IFF_MASTER)
  XLAT(IFF_SLAVE),
+ #define XLAT_VAL_11 ((unsigned) (IFF_SLAVE))
+ #define XLAT_STR_11 STRINGIFY(IFF_SLAVE)
  XLAT(IFF_MULTICAST),
+ #define XLAT_VAL_12 ((unsigned) (IFF_MULTICAST))
+ #define XLAT_STR_12 STRINGIFY(IFF_MULTICAST)
  XLAT(IFF_PORTSEL),
+ #define XLAT_VAL_13 ((unsigned) (IFF_PORTSEL))
+ #define XLAT_STR_13 STRINGIFY(IFF_PORTSEL)
  XLAT(IFF_AUTOMEDIA),
+ #define XLAT_VAL_14 ((unsigned) (IFF_AUTOMEDIA))
+ #define XLAT_STR_14 STRINGIFY(IFF_AUTOMEDIA)
  XLAT(IFF_DYNAMIC),
+ #define XLAT_VAL_15 ((unsigned) (IFF_DYNAMIC))
+ #define XLAT_STR_15 STRINGIFY(IFF_DYNAMIC)
  XLAT(IFF_LOWER_UP),
+ #define XLAT_VAL_16 ((unsigned) (IFF_LOWER_UP))
+ #define XLAT_STR_16 STRINGIFY(IFF_LOWER_UP)
  XLAT(IFF_DORMANT),
+ #define XLAT_VAL_17 ((unsigned) (IFF_DORMANT))
+ #define XLAT_STR_17 STRINGIFY(IFF_DORMANT)
  XLAT(IFF_ECHO),
+ #define XLAT_VAL_18 ((unsigned) (IFF_ECHO))
+ #define XLAT_STR_18 STRINGIFY(IFF_ECHO)
 };
 const struct xlat iffflags[1] = { {
  .data = iffflags_xdata,
  .size = ARRAY_SIZE(iffflags_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/in6_addr_gen_mode.h 5.9-0ubuntu2/xlat/in6_addr_gen_mode.h
--- 5.5-3/xlat/in6_addr_gen_mode.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/in6_addr_gen_mode.h	2020-09-24 09:18:44.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data in6_addr_gen_mode_xdata[] = {
  [IN6_ADDR_GEN_MODE_EUI64] = XLAT(IN6_ADDR_GEN_MODE_EUI64),
+ #define XLAT_VAL_0 ((unsigned) (IN6_ADDR_GEN_MODE_EUI64))
+ #define XLAT_STR_0 STRINGIFY(IN6_ADDR_GEN_MODE_EUI64)
  [IN6_ADDR_GEN_MODE_NONE] = XLAT(IN6_ADDR_GEN_MODE_NONE),
+ #define XLAT_VAL_1 ((unsigned) (IN6_ADDR_GEN_MODE_NONE))
+ #define XLAT_STR_1 STRINGIFY(IN6_ADDR_GEN_MODE_NONE)
  [IN6_ADDR_GEN_MODE_STABLE_PRIVACY] = XLAT(IN6_ADDR_GEN_MODE_STABLE_PRIVACY),
+ #define XLAT_VAL_2 ((unsigned) (IN6_ADDR_GEN_MODE_STABLE_PRIVACY))
+ #define XLAT_STR_2 STRINGIFY(IN6_ADDR_GEN_MODE_STABLE_PRIVACY)
  [IN6_ADDR_GEN_MODE_RANDOM] = XLAT(IN6_ADDR_GEN_MODE_RANDOM),
+ #define XLAT_VAL_3 ((unsigned) (IN6_ADDR_GEN_MODE_RANDOM))
+ #define XLAT_STR_3 STRINGIFY(IN6_ADDR_GEN_MODE_RANDOM)
 };
 static
 const struct xlat in6_addr_gen_mode[1] = { {
  .data = in6_addr_gen_mode_xdata,
  .size = ARRAY_SIZE(in6_addr_gen_mode_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/inet6_devconf_indices.h 5.9-0ubuntu2/xlat/inet6_devconf_indices.h
--- 5.5-3/xlat/inet6_devconf_indices.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/inet6_devconf_indices.h	2020-09-24 09:18:46.000000000 +0000
@@ -371,64 +371,578 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data inet6_devconf_indices_xdata[] = {
  [DEVCONF_FORWARDING] = XLAT(DEVCONF_FORWARDING),
+ #define XLAT_VAL_0 ((unsigned) (DEVCONF_FORWARDING))
+ #define XLAT_STR_0 STRINGIFY(DEVCONF_FORWARDING)
  [DEVCONF_HOPLIMIT] = XLAT(DEVCONF_HOPLIMIT),
+ #define XLAT_VAL_1 ((unsigned) (DEVCONF_HOPLIMIT))
+ #define XLAT_STR_1 STRINGIFY(DEVCONF_HOPLIMIT)
  [DEVCONF_MTU6] = XLAT(DEVCONF_MTU6),
+ #define XLAT_VAL_2 ((unsigned) (DEVCONF_MTU6))
+ #define XLAT_STR_2 STRINGIFY(DEVCONF_MTU6)
  [DEVCONF_ACCEPT_RA] = XLAT(DEVCONF_ACCEPT_RA),
+ #define XLAT_VAL_3 ((unsigned) (DEVCONF_ACCEPT_RA))
+ #define XLAT_STR_3 STRINGIFY(DEVCONF_ACCEPT_RA)
  [DEVCONF_ACCEPT_REDIRECTS] = XLAT(DEVCONF_ACCEPT_REDIRECTS),
+ #define XLAT_VAL_4 ((unsigned) (DEVCONF_ACCEPT_REDIRECTS))
+ #define XLAT_STR_4 STRINGIFY(DEVCONF_ACCEPT_REDIRECTS)
  [DEVCONF_AUTOCONF] = XLAT(DEVCONF_AUTOCONF),
+ #define XLAT_VAL_5 ((unsigned) (DEVCONF_AUTOCONF))
+ #define XLAT_STR_5 STRINGIFY(DEVCONF_AUTOCONF)
  [DEVCONF_DAD_TRANSMITS] = XLAT(DEVCONF_DAD_TRANSMITS),
+ #define XLAT_VAL_6 ((unsigned) (DEVCONF_DAD_TRANSMITS))
+ #define XLAT_STR_6 STRINGIFY(DEVCONF_DAD_TRANSMITS)
  [DEVCONF_RTR_SOLICITS] = XLAT(DEVCONF_RTR_SOLICITS),
+ #define XLAT_VAL_7 ((unsigned) (DEVCONF_RTR_SOLICITS))
+ #define XLAT_STR_7 STRINGIFY(DEVCONF_RTR_SOLICITS)
  [DEVCONF_RTR_SOLICIT_INTERVAL] = XLAT(DEVCONF_RTR_SOLICIT_INTERVAL),
+ #define XLAT_VAL_8 ((unsigned) (DEVCONF_RTR_SOLICIT_INTERVAL))
+ #define XLAT_STR_8 STRINGIFY(DEVCONF_RTR_SOLICIT_INTERVAL)
  [DEVCONF_RTR_SOLICIT_DELAY] = XLAT(DEVCONF_RTR_SOLICIT_DELAY),
+ #define XLAT_VAL_9 ((unsigned) (DEVCONF_RTR_SOLICIT_DELAY))
+ #define XLAT_STR_9 STRINGIFY(DEVCONF_RTR_SOLICIT_DELAY)
  [DEVCONF_USE_TEMPADDR] = XLAT(DEVCONF_USE_TEMPADDR),
+ #define XLAT_VAL_10 ((unsigned) (DEVCONF_USE_TEMPADDR))
+ #define XLAT_STR_10 STRINGIFY(DEVCONF_USE_TEMPADDR)
  [DEVCONF_TEMP_VALID_LFT] = XLAT(DEVCONF_TEMP_VALID_LFT),
+ #define XLAT_VAL_11 ((unsigned) (DEVCONF_TEMP_VALID_LFT))
+ #define XLAT_STR_11 STRINGIFY(DEVCONF_TEMP_VALID_LFT)
  [DEVCONF_TEMP_PREFERED_LFT] = XLAT(DEVCONF_TEMP_PREFERED_LFT),
+ #define XLAT_VAL_12 ((unsigned) (DEVCONF_TEMP_PREFERED_LFT))
+ #define XLAT_STR_12 STRINGIFY(DEVCONF_TEMP_PREFERED_LFT)
  [DEVCONF_REGEN_MAX_RETRY] = XLAT(DEVCONF_REGEN_MAX_RETRY),
+ #define XLAT_VAL_13 ((unsigned) (DEVCONF_REGEN_MAX_RETRY))
+ #define XLAT_STR_13 STRINGIFY(DEVCONF_REGEN_MAX_RETRY)
  [DEVCONF_MAX_DESYNC_FACTOR] = XLAT(DEVCONF_MAX_DESYNC_FACTOR),
+ #define XLAT_VAL_14 ((unsigned) (DEVCONF_MAX_DESYNC_FACTOR))
+ #define XLAT_STR_14 STRINGIFY(DEVCONF_MAX_DESYNC_FACTOR)
  [DEVCONF_MAX_ADDRESSES] = XLAT(DEVCONF_MAX_ADDRESSES),
+ #define XLAT_VAL_15 ((unsigned) (DEVCONF_MAX_ADDRESSES))
+ #define XLAT_STR_15 STRINGIFY(DEVCONF_MAX_ADDRESSES)
  [DEVCONF_FORCE_MLD_VERSION] = XLAT(DEVCONF_FORCE_MLD_VERSION),
+ #define XLAT_VAL_16 ((unsigned) (DEVCONF_FORCE_MLD_VERSION))
+ #define XLAT_STR_16 STRINGIFY(DEVCONF_FORCE_MLD_VERSION)
  [DEVCONF_ACCEPT_RA_DEFRTR] = XLAT(DEVCONF_ACCEPT_RA_DEFRTR),
+ #define XLAT_VAL_17 ((unsigned) (DEVCONF_ACCEPT_RA_DEFRTR))
+ #define XLAT_STR_17 STRINGIFY(DEVCONF_ACCEPT_RA_DEFRTR)
  [DEVCONF_ACCEPT_RA_PINFO] = XLAT(DEVCONF_ACCEPT_RA_PINFO),
+ #define XLAT_VAL_18 ((unsigned) (DEVCONF_ACCEPT_RA_PINFO))
+ #define XLAT_STR_18 STRINGIFY(DEVCONF_ACCEPT_RA_PINFO)
  [DEVCONF_ACCEPT_RA_RTR_PREF] = XLAT(DEVCONF_ACCEPT_RA_RTR_PREF),
+ #define XLAT_VAL_19 ((unsigned) (DEVCONF_ACCEPT_RA_RTR_PREF))
+ #define XLAT_STR_19 STRINGIFY(DEVCONF_ACCEPT_RA_RTR_PREF)
  [DEVCONF_RTR_PROBE_INTERVAL] = XLAT(DEVCONF_RTR_PROBE_INTERVAL),
+ #define XLAT_VAL_20 ((unsigned) (DEVCONF_RTR_PROBE_INTERVAL))
+ #define XLAT_STR_20 STRINGIFY(DEVCONF_RTR_PROBE_INTERVAL)
  [DEVCONF_ACCEPT_RA_RT_INFO_MAX_PLEN] = XLAT(DEVCONF_ACCEPT_RA_RT_INFO_MAX_PLEN),
+ #define XLAT_VAL_21 ((unsigned) (DEVCONF_ACCEPT_RA_RT_INFO_MAX_PLEN))
+ #define XLAT_STR_21 STRINGIFY(DEVCONF_ACCEPT_RA_RT_INFO_MAX_PLEN)
  [DEVCONF_PROXY_NDP] = XLAT(DEVCONF_PROXY_NDP),
+ #define XLAT_VAL_22 ((unsigned) (DEVCONF_PROXY_NDP))
+ #define XLAT_STR_22 STRINGIFY(DEVCONF_PROXY_NDP)
  [DEVCONF_OPTIMISTIC_DAD] = XLAT(DEVCONF_OPTIMISTIC_DAD),
+ #define XLAT_VAL_23 ((unsigned) (DEVCONF_OPTIMISTIC_DAD))
+ #define XLAT_STR_23 STRINGIFY(DEVCONF_OPTIMISTIC_DAD)
  [DEVCONF_ACCEPT_SOURCE_ROUTE] = XLAT(DEVCONF_ACCEPT_SOURCE_ROUTE),
+ #define XLAT_VAL_24 ((unsigned) (DEVCONF_ACCEPT_SOURCE_ROUTE))
+ #define XLAT_STR_24 STRINGIFY(DEVCONF_ACCEPT_SOURCE_ROUTE)
  [DEVCONF_MC_FORWARDING] = XLAT(DEVCONF_MC_FORWARDING),
+ #define XLAT_VAL_25 ((unsigned) (DEVCONF_MC_FORWARDING))
+ #define XLAT_STR_25 STRINGIFY(DEVCONF_MC_FORWARDING)
  [DEVCONF_DISABLE_IPV6] = XLAT(DEVCONF_DISABLE_IPV6),
+ #define XLAT_VAL_26 ((unsigned) (DEVCONF_DISABLE_IPV6))
+ #define XLAT_STR_26 STRINGIFY(DEVCONF_DISABLE_IPV6)
  [DEVCONF_ACCEPT_DAD] = XLAT(DEVCONF_ACCEPT_DAD),
+ #define XLAT_VAL_27 ((unsigned) (DEVCONF_ACCEPT_DAD))
+ #define XLAT_STR_27 STRINGIFY(DEVCONF_ACCEPT_DAD)
  [DEVCONF_FORCE_TLLAO] = XLAT(DEVCONF_FORCE_TLLAO),
+ #define XLAT_VAL_28 ((unsigned) (DEVCONF_FORCE_TLLAO))
+ #define XLAT_STR_28 STRINGIFY(DEVCONF_FORCE_TLLAO)
  [DEVCONF_NDISC_NOTIFY] = XLAT(DEVCONF_NDISC_NOTIFY),
+ #define XLAT_VAL_29 ((unsigned) (DEVCONF_NDISC_NOTIFY))
+ #define XLAT_STR_29 STRINGIFY(DEVCONF_NDISC_NOTIFY)
  [DEVCONF_MLDV1_UNSOLICITED_REPORT_INTERVAL] = XLAT(DEVCONF_MLDV1_UNSOLICITED_REPORT_INTERVAL),
+ #define XLAT_VAL_30 ((unsigned) (DEVCONF_MLDV1_UNSOLICITED_REPORT_INTERVAL))
+ #define XLAT_STR_30 STRINGIFY(DEVCONF_MLDV1_UNSOLICITED_REPORT_INTERVAL)
  [DEVCONF_MLDV2_UNSOLICITED_REPORT_INTERVAL] = XLAT(DEVCONF_MLDV2_UNSOLICITED_REPORT_INTERVAL),
+ #define XLAT_VAL_31 ((unsigned) (DEVCONF_MLDV2_UNSOLICITED_REPORT_INTERVAL))
+ #define XLAT_STR_31 STRINGIFY(DEVCONF_MLDV2_UNSOLICITED_REPORT_INTERVAL)
  [DEVCONF_SUPPRESS_FRAG_NDISC] = XLAT(DEVCONF_SUPPRESS_FRAG_NDISC),
+ #define XLAT_VAL_32 ((unsigned) (DEVCONF_SUPPRESS_FRAG_NDISC))
+ #define XLAT_STR_32 STRINGIFY(DEVCONF_SUPPRESS_FRAG_NDISC)
  [DEVCONF_ACCEPT_RA_FROM_LOCAL] = XLAT(DEVCONF_ACCEPT_RA_FROM_LOCAL),
+ #define XLAT_VAL_33 ((unsigned) (DEVCONF_ACCEPT_RA_FROM_LOCAL))
+ #define XLAT_STR_33 STRINGIFY(DEVCONF_ACCEPT_RA_FROM_LOCAL)
  [DEVCONF_USE_OPTIMISTIC] = XLAT(DEVCONF_USE_OPTIMISTIC),
+ #define XLAT_VAL_34 ((unsigned) (DEVCONF_USE_OPTIMISTIC))
+ #define XLAT_STR_34 STRINGIFY(DEVCONF_USE_OPTIMISTIC)
  [DEVCONF_ACCEPT_RA_MTU] = XLAT(DEVCONF_ACCEPT_RA_MTU),
+ #define XLAT_VAL_35 ((unsigned) (DEVCONF_ACCEPT_RA_MTU))
+ #define XLAT_STR_35 STRINGIFY(DEVCONF_ACCEPT_RA_MTU)
  [DEVCONF_STABLE_SECRET] = XLAT(DEVCONF_STABLE_SECRET),
+ #define XLAT_VAL_36 ((unsigned) (DEVCONF_STABLE_SECRET))
+ #define XLAT_STR_36 STRINGIFY(DEVCONF_STABLE_SECRET)
  [DEVCONF_USE_OIF_ADDRS_ONLY] = XLAT(DEVCONF_USE_OIF_ADDRS_ONLY),
+ #define XLAT_VAL_37 ((unsigned) (DEVCONF_USE_OIF_ADDRS_ONLY))
+ #define XLAT_STR_37 STRINGIFY(DEVCONF_USE_OIF_ADDRS_ONLY)
  [DEVCONF_ACCEPT_RA_MIN_HOP_LIMIT] = XLAT(DEVCONF_ACCEPT_RA_MIN_HOP_LIMIT),
+ #define XLAT_VAL_38 ((unsigned) (DEVCONF_ACCEPT_RA_MIN_HOP_LIMIT))
+ #define XLAT_STR_38 STRINGIFY(DEVCONF_ACCEPT_RA_MIN_HOP_LIMIT)
  [DEVCONF_IGNORE_ROUTES_WITH_LINKDOWN] = XLAT(DEVCONF_IGNORE_ROUTES_WITH_LINKDOWN),
+ #define XLAT_VAL_39 ((unsigned) (DEVCONF_IGNORE_ROUTES_WITH_LINKDOWN))
+ #define XLAT_STR_39 STRINGIFY(DEVCONF_IGNORE_ROUTES_WITH_LINKDOWN)
  [DEVCONF_DROP_UNICAST_IN_L2_MULTICAST] = XLAT(DEVCONF_DROP_UNICAST_IN_L2_MULTICAST),
+ #define XLAT_VAL_40 ((unsigned) (DEVCONF_DROP_UNICAST_IN_L2_MULTICAST))
+ #define XLAT_STR_40 STRINGIFY(DEVCONF_DROP_UNICAST_IN_L2_MULTICAST)
  [DEVCONF_DROP_UNSOLICITED_NA] = XLAT(DEVCONF_DROP_UNSOLICITED_NA),
+ #define XLAT_VAL_41 ((unsigned) (DEVCONF_DROP_UNSOLICITED_NA))
+ #define XLAT_STR_41 STRINGIFY(DEVCONF_DROP_UNSOLICITED_NA)
  [DEVCONF_KEEP_ADDR_ON_DOWN] = XLAT(DEVCONF_KEEP_ADDR_ON_DOWN),
+ #define XLAT_VAL_42 ((unsigned) (DEVCONF_KEEP_ADDR_ON_DOWN))
+ #define XLAT_STR_42 STRINGIFY(DEVCONF_KEEP_ADDR_ON_DOWN)
  [DEVCONF_RTR_SOLICIT_MAX_INTERVAL] = XLAT(DEVCONF_RTR_SOLICIT_MAX_INTERVAL),
+ #define XLAT_VAL_43 ((unsigned) (DEVCONF_RTR_SOLICIT_MAX_INTERVAL))
+ #define XLAT_STR_43 STRINGIFY(DEVCONF_RTR_SOLICIT_MAX_INTERVAL)
  [DEVCONF_SEG6_ENABLED] = XLAT(DEVCONF_SEG6_ENABLED),
+ #define XLAT_VAL_44 ((unsigned) (DEVCONF_SEG6_ENABLED))
+ #define XLAT_STR_44 STRINGIFY(DEVCONF_SEG6_ENABLED)
  [DEVCONF_SEG6_REQUIRE_HMAC] = XLAT(DEVCONF_SEG6_REQUIRE_HMAC),
+ #define XLAT_VAL_45 ((unsigned) (DEVCONF_SEG6_REQUIRE_HMAC))
+ #define XLAT_STR_45 STRINGIFY(DEVCONF_SEG6_REQUIRE_HMAC)
  [DEVCONF_ENHANCED_DAD] = XLAT(DEVCONF_ENHANCED_DAD),
+ #define XLAT_VAL_46 ((unsigned) (DEVCONF_ENHANCED_DAD))
+ #define XLAT_STR_46 STRINGIFY(DEVCONF_ENHANCED_DAD)
  [DEVCONF_ADDR_GEN_MODE] = XLAT(DEVCONF_ADDR_GEN_MODE),
+ #define XLAT_VAL_47 ((unsigned) (DEVCONF_ADDR_GEN_MODE))
+ #define XLAT_STR_47 STRINGIFY(DEVCONF_ADDR_GEN_MODE)
  [DEVCONF_DISABLE_POLICY] = XLAT(DEVCONF_DISABLE_POLICY),
+ #define XLAT_VAL_48 ((unsigned) (DEVCONF_DISABLE_POLICY))
+ #define XLAT_STR_48 STRINGIFY(DEVCONF_DISABLE_POLICY)
  [DEVCONF_ACCEPT_RA_RT_INFO_MIN_PLEN] = XLAT(DEVCONF_ACCEPT_RA_RT_INFO_MIN_PLEN),
+ #define XLAT_VAL_49 ((unsigned) (DEVCONF_ACCEPT_RA_RT_INFO_MIN_PLEN))
+ #define XLAT_STR_49 STRINGIFY(DEVCONF_ACCEPT_RA_RT_INFO_MIN_PLEN)
  [DEVCONF_NDISC_TCLASS] = XLAT(DEVCONF_NDISC_TCLASS),
+ #define XLAT_VAL_50 ((unsigned) (DEVCONF_NDISC_TCLASS))
+ #define XLAT_STR_50 STRINGIFY(DEVCONF_NDISC_TCLASS)
 };
 static
 const struct xlat inet6_devconf_indices[1] = { {
  .data = inet6_devconf_indices_xdata,
  .size = ARRAY_SIZE(inet6_devconf_indices_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+#  ifdef XLAT_VAL_47
+  | XLAT_VAL_47
+#  endif
+#  ifdef XLAT_VAL_48
+  | XLAT_VAL_48
+#  endif
+#  ifdef XLAT_VAL_49
+  | XLAT_VAL_49
+#  endif
+#  ifdef XLAT_VAL_50
+  | XLAT_VAL_50
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+#  ifdef XLAT_STR_47
+  + sizeof(XLAT_STR_47)
+#  endif
+#  ifdef XLAT_STR_48
+  + sizeof(XLAT_STR_48)
+#  endif
+#  ifdef XLAT_STR_49
+  + sizeof(XLAT_STR_49)
+#  endif
+#  ifdef XLAT_STR_50
+  + sizeof(XLAT_STR_50)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
+#  undef XLAT_STR_47
+#  undef XLAT_VAL_47
+#  undef XLAT_STR_48
+#  undef XLAT_VAL_48
+#  undef XLAT_STR_49
+#  undef XLAT_VAL_49
+#  undef XLAT_STR_50
+#  undef XLAT_VAL_50
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/inet6_if_flags.h 5.9-0ubuntu2/xlat/inet6_if_flags.h
--- 5.5-3/xlat/inet6_if_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/inet6_if_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -49,18 +49,72 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data inet6_if_flags_xdata[] = {
  XLAT(IF_RS_SENT),
+ #define XLAT_VAL_0 ((unsigned) (IF_RS_SENT))
+ #define XLAT_STR_0 STRINGIFY(IF_RS_SENT)
  XLAT(IF_RA_RCVD),
+ #define XLAT_VAL_1 ((unsigned) (IF_RA_RCVD))
+ #define XLAT_STR_1 STRINGIFY(IF_RA_RCVD)
  XLAT(IF_RA_MANAGED),
+ #define XLAT_VAL_2 ((unsigned) (IF_RA_MANAGED))
+ #define XLAT_STR_2 STRINGIFY(IF_RA_MANAGED)
  XLAT(IF_RA_OTHERCONF),
+ #define XLAT_VAL_3 ((unsigned) (IF_RA_OTHERCONF))
+ #define XLAT_STR_3 STRINGIFY(IF_RA_OTHERCONF)
  XLAT(IF_READY),
+ #define XLAT_VAL_4 ((unsigned) (IF_READY))
+ #define XLAT_STR_4 STRINGIFY(IF_READY)
 };
 static
 const struct xlat inet6_if_flags[1] = { {
  .data = inet6_if_flags_xdata,
  .size = ARRAY_SIZE(inet6_if_flags_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/inet_devconf_indices.h 5.9-0ubuntu2/xlat/inet_devconf_indices.h
--- 5.5-3/xlat/inet_devconf_indices.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/inet_devconf_indices.h	2020-09-24 09:18:45.000000000 +0000
@@ -239,45 +239,369 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 static const struct xlat_data inet_devconf_indices_xdata[] = {
 
  [IPV4_DEVCONF_FORWARDING-1] = XLAT(IPV4_DEVCONF_FORWARDING-1),
+ #define XLAT_VAL_0 ((unsigned) (IPV4_DEVCONF_FORWARDING-1))
+ #define XLAT_STR_0 STRINGIFY(IPV4_DEVCONF_FORWARDING-1)
  [IPV4_DEVCONF_MC_FORWARDING-1] = XLAT(IPV4_DEVCONF_MC_FORWARDING-1),
+ #define XLAT_VAL_1 ((unsigned) (IPV4_DEVCONF_MC_FORWARDING-1))
+ #define XLAT_STR_1 STRINGIFY(IPV4_DEVCONF_MC_FORWARDING-1)
  [IPV4_DEVCONF_PROXY_ARP-1] = XLAT(IPV4_DEVCONF_PROXY_ARP-1),
+ #define XLAT_VAL_2 ((unsigned) (IPV4_DEVCONF_PROXY_ARP-1))
+ #define XLAT_STR_2 STRINGIFY(IPV4_DEVCONF_PROXY_ARP-1)
  [IPV4_DEVCONF_ACCEPT_REDIRECTS-1] = XLAT(IPV4_DEVCONF_ACCEPT_REDIRECTS-1),
+ #define XLAT_VAL_3 ((unsigned) (IPV4_DEVCONF_ACCEPT_REDIRECTS-1))
+ #define XLAT_STR_3 STRINGIFY(IPV4_DEVCONF_ACCEPT_REDIRECTS-1)
  [IPV4_DEVCONF_SECURE_REDIRECTS-1] = XLAT(IPV4_DEVCONF_SECURE_REDIRECTS-1),
+ #define XLAT_VAL_4 ((unsigned) (IPV4_DEVCONF_SECURE_REDIRECTS-1))
+ #define XLAT_STR_4 STRINGIFY(IPV4_DEVCONF_SECURE_REDIRECTS-1)
  [IPV4_DEVCONF_SEND_REDIRECTS-1] = XLAT(IPV4_DEVCONF_SEND_REDIRECTS-1),
+ #define XLAT_VAL_5 ((unsigned) (IPV4_DEVCONF_SEND_REDIRECTS-1))
+ #define XLAT_STR_5 STRINGIFY(IPV4_DEVCONF_SEND_REDIRECTS-1)
  [IPV4_DEVCONF_SHARED_MEDIA-1] = XLAT(IPV4_DEVCONF_SHARED_MEDIA-1),
+ #define XLAT_VAL_6 ((unsigned) (IPV4_DEVCONF_SHARED_MEDIA-1))
+ #define XLAT_STR_6 STRINGIFY(IPV4_DEVCONF_SHARED_MEDIA-1)
  [IPV4_DEVCONF_RP_FILTER-1] = XLAT(IPV4_DEVCONF_RP_FILTER-1),
+ #define XLAT_VAL_7 ((unsigned) (IPV4_DEVCONF_RP_FILTER-1))
+ #define XLAT_STR_7 STRINGIFY(IPV4_DEVCONF_RP_FILTER-1)
  [IPV4_DEVCONF_ACCEPT_SOURCE_ROUTE-1] = XLAT(IPV4_DEVCONF_ACCEPT_SOURCE_ROUTE-1),
+ #define XLAT_VAL_8 ((unsigned) (IPV4_DEVCONF_ACCEPT_SOURCE_ROUTE-1))
+ #define XLAT_STR_8 STRINGIFY(IPV4_DEVCONF_ACCEPT_SOURCE_ROUTE-1)
  [IPV4_DEVCONF_BOOTP_RELAY-1] = XLAT(IPV4_DEVCONF_BOOTP_RELAY-1),
+ #define XLAT_VAL_9 ((unsigned) (IPV4_DEVCONF_BOOTP_RELAY-1))
+ #define XLAT_STR_9 STRINGIFY(IPV4_DEVCONF_BOOTP_RELAY-1)
  [IPV4_DEVCONF_LOG_MARTIANS-1] = XLAT(IPV4_DEVCONF_LOG_MARTIANS-1),
+ #define XLAT_VAL_10 ((unsigned) (IPV4_DEVCONF_LOG_MARTIANS-1))
+ #define XLAT_STR_10 STRINGIFY(IPV4_DEVCONF_LOG_MARTIANS-1)
  [IPV4_DEVCONF_TAG-1] = XLAT(IPV4_DEVCONF_TAG-1),
+ #define XLAT_VAL_11 ((unsigned) (IPV4_DEVCONF_TAG-1))
+ #define XLAT_STR_11 STRINGIFY(IPV4_DEVCONF_TAG-1)
  [IPV4_DEVCONF_ARPFILTER-1] = XLAT(IPV4_DEVCONF_ARPFILTER-1),
+ #define XLAT_VAL_12 ((unsigned) (IPV4_DEVCONF_ARPFILTER-1))
+ #define XLAT_STR_12 STRINGIFY(IPV4_DEVCONF_ARPFILTER-1)
  [IPV4_DEVCONF_MEDIUM_ID-1] = XLAT(IPV4_DEVCONF_MEDIUM_ID-1),
+ #define XLAT_VAL_13 ((unsigned) (IPV4_DEVCONF_MEDIUM_ID-1))
+ #define XLAT_STR_13 STRINGIFY(IPV4_DEVCONF_MEDIUM_ID-1)
  [IPV4_DEVCONF_NOXFRM-1] = XLAT(IPV4_DEVCONF_NOXFRM-1),
+ #define XLAT_VAL_14 ((unsigned) (IPV4_DEVCONF_NOXFRM-1))
+ #define XLAT_STR_14 STRINGIFY(IPV4_DEVCONF_NOXFRM-1)
  [IPV4_DEVCONF_NOPOLICY-1] = XLAT(IPV4_DEVCONF_NOPOLICY-1),
+ #define XLAT_VAL_15 ((unsigned) (IPV4_DEVCONF_NOPOLICY-1))
+ #define XLAT_STR_15 STRINGIFY(IPV4_DEVCONF_NOPOLICY-1)
  [IPV4_DEVCONF_FORCE_IGMP_VERSION-1] = XLAT(IPV4_DEVCONF_FORCE_IGMP_VERSION-1),
+ #define XLAT_VAL_16 ((unsigned) (IPV4_DEVCONF_FORCE_IGMP_VERSION-1))
+ #define XLAT_STR_16 STRINGIFY(IPV4_DEVCONF_FORCE_IGMP_VERSION-1)
  [IPV4_DEVCONF_ARP_ANNOUNCE-1] = XLAT(IPV4_DEVCONF_ARP_ANNOUNCE-1),
+ #define XLAT_VAL_17 ((unsigned) (IPV4_DEVCONF_ARP_ANNOUNCE-1))
+ #define XLAT_STR_17 STRINGIFY(IPV4_DEVCONF_ARP_ANNOUNCE-1)
  [IPV4_DEVCONF_ARP_IGNORE-1] = XLAT(IPV4_DEVCONF_ARP_IGNORE-1),
+ #define XLAT_VAL_18 ((unsigned) (IPV4_DEVCONF_ARP_IGNORE-1))
+ #define XLAT_STR_18 STRINGIFY(IPV4_DEVCONF_ARP_IGNORE-1)
  [IPV4_DEVCONF_PROMOTE_SECONDARIES-1] = XLAT(IPV4_DEVCONF_PROMOTE_SECONDARIES-1),
+ #define XLAT_VAL_19 ((unsigned) (IPV4_DEVCONF_PROMOTE_SECONDARIES-1))
+ #define XLAT_STR_19 STRINGIFY(IPV4_DEVCONF_PROMOTE_SECONDARIES-1)
  [IPV4_DEVCONF_ARP_ACCEPT-1] = XLAT(IPV4_DEVCONF_ARP_ACCEPT-1),
+ #define XLAT_VAL_20 ((unsigned) (IPV4_DEVCONF_ARP_ACCEPT-1))
+ #define XLAT_STR_20 STRINGIFY(IPV4_DEVCONF_ARP_ACCEPT-1)
  [IPV4_DEVCONF_ARP_NOTIFY-1] = XLAT(IPV4_DEVCONF_ARP_NOTIFY-1),
+ #define XLAT_VAL_21 ((unsigned) (IPV4_DEVCONF_ARP_NOTIFY-1))
+ #define XLAT_STR_21 STRINGIFY(IPV4_DEVCONF_ARP_NOTIFY-1)
  [IPV4_DEVCONF_ACCEPT_LOCAL-1] = XLAT(IPV4_DEVCONF_ACCEPT_LOCAL-1),
+ #define XLAT_VAL_22 ((unsigned) (IPV4_DEVCONF_ACCEPT_LOCAL-1))
+ #define XLAT_STR_22 STRINGIFY(IPV4_DEVCONF_ACCEPT_LOCAL-1)
  [IPV4_DEVCONF_SRC_VMARK-1] = XLAT(IPV4_DEVCONF_SRC_VMARK-1),
+ #define XLAT_VAL_23 ((unsigned) (IPV4_DEVCONF_SRC_VMARK-1))
+ #define XLAT_STR_23 STRINGIFY(IPV4_DEVCONF_SRC_VMARK-1)
  [IPV4_DEVCONF_PROXY_ARP_PVLAN-1] = XLAT(IPV4_DEVCONF_PROXY_ARP_PVLAN-1),
+ #define XLAT_VAL_24 ((unsigned) (IPV4_DEVCONF_PROXY_ARP_PVLAN-1))
+ #define XLAT_STR_24 STRINGIFY(IPV4_DEVCONF_PROXY_ARP_PVLAN-1)
  [IPV4_DEVCONF_ROUTE_LOCALNET-1] = XLAT(IPV4_DEVCONF_ROUTE_LOCALNET-1),
+ #define XLAT_VAL_25 ((unsigned) (IPV4_DEVCONF_ROUTE_LOCALNET-1))
+ #define XLAT_STR_25 STRINGIFY(IPV4_DEVCONF_ROUTE_LOCALNET-1)
  [IPV4_DEVCONF_IGMPV2_UNSOLICITED_REPORT_INTERVAL-1] = XLAT(IPV4_DEVCONF_IGMPV2_UNSOLICITED_REPORT_INTERVAL-1),
+ #define XLAT_VAL_26 ((unsigned) (IPV4_DEVCONF_IGMPV2_UNSOLICITED_REPORT_INTERVAL-1))
+ #define XLAT_STR_26 STRINGIFY(IPV4_DEVCONF_IGMPV2_UNSOLICITED_REPORT_INTERVAL-1)
  [IPV4_DEVCONF_IGMPV3_UNSOLICITED_REPORT_INTERVAL-1] = XLAT(IPV4_DEVCONF_IGMPV3_UNSOLICITED_REPORT_INTERVAL-1),
+ #define XLAT_VAL_27 ((unsigned) (IPV4_DEVCONF_IGMPV3_UNSOLICITED_REPORT_INTERVAL-1))
+ #define XLAT_STR_27 STRINGIFY(IPV4_DEVCONF_IGMPV3_UNSOLICITED_REPORT_INTERVAL-1)
  [IPV4_DEVCONF_IGNORE_ROUTES_WITH_LINKDOWN-1] = XLAT(IPV4_DEVCONF_IGNORE_ROUTES_WITH_LINKDOWN-1),
+ #define XLAT_VAL_28 ((unsigned) (IPV4_DEVCONF_IGNORE_ROUTES_WITH_LINKDOWN-1))
+ #define XLAT_STR_28 STRINGIFY(IPV4_DEVCONF_IGNORE_ROUTES_WITH_LINKDOWN-1)
  [IPV4_DEVCONF_DROP_UNICAST_IN_L2_MULTICAST-1] = XLAT(IPV4_DEVCONF_DROP_UNICAST_IN_L2_MULTICAST-1),
+ #define XLAT_VAL_29 ((unsigned) (IPV4_DEVCONF_DROP_UNICAST_IN_L2_MULTICAST-1))
+ #define XLAT_STR_29 STRINGIFY(IPV4_DEVCONF_DROP_UNICAST_IN_L2_MULTICAST-1)
  [IPV4_DEVCONF_DROP_GRATUITOUS_ARP-1] = XLAT(IPV4_DEVCONF_DROP_GRATUITOUS_ARP-1),
+ #define XLAT_VAL_30 ((unsigned) (IPV4_DEVCONF_DROP_GRATUITOUS_ARP-1))
+ #define XLAT_STR_30 STRINGIFY(IPV4_DEVCONF_DROP_GRATUITOUS_ARP-1)
  [IPV4_DEVCONF_BC_FORWARDING-1] = XLAT(IPV4_DEVCONF_BC_FORWARDING-1),
+ #define XLAT_VAL_31 ((unsigned) (IPV4_DEVCONF_BC_FORWARDING-1))
+ #define XLAT_STR_31 STRINGIFY(IPV4_DEVCONF_BC_FORWARDING-1)
 };
 static
 const struct xlat inet_devconf_indices[1] = { {
  .data = inet_devconf_indices_xdata,
  .size = ARRAY_SIZE(inet_devconf_indices_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/inet_diag_attrs.h 5.9-0ubuntu2/xlat/inet_diag_attrs.h
--- 5.5-3/xlat/inet_diag_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/inet_diag_attrs.h	2020-09-24 09:18:44.000000000 +0000
@@ -14,31 +14,259 @@
 
 static const struct xlat_data inet_diag_attrs_xdata[] = {
  XLAT(INET_DIAG_NONE),
+ #define XLAT_VAL_0 ((unsigned) (INET_DIAG_NONE))
+ #define XLAT_STR_0 STRINGIFY(INET_DIAG_NONE)
  XLAT(INET_DIAG_MEMINFO),
+ #define XLAT_VAL_1 ((unsigned) (INET_DIAG_MEMINFO))
+ #define XLAT_STR_1 STRINGIFY(INET_DIAG_MEMINFO)
  XLAT(INET_DIAG_INFO),
+ #define XLAT_VAL_2 ((unsigned) (INET_DIAG_INFO))
+ #define XLAT_STR_2 STRINGIFY(INET_DIAG_INFO)
  XLAT(INET_DIAG_VEGASINFO),
+ #define XLAT_VAL_3 ((unsigned) (INET_DIAG_VEGASINFO))
+ #define XLAT_STR_3 STRINGIFY(INET_DIAG_VEGASINFO)
  XLAT(INET_DIAG_CONG),
+ #define XLAT_VAL_4 ((unsigned) (INET_DIAG_CONG))
+ #define XLAT_STR_4 STRINGIFY(INET_DIAG_CONG)
  XLAT(INET_DIAG_TOS),
+ #define XLAT_VAL_5 ((unsigned) (INET_DIAG_TOS))
+ #define XLAT_STR_5 STRINGIFY(INET_DIAG_TOS)
  XLAT(INET_DIAG_TCLASS),
+ #define XLAT_VAL_6 ((unsigned) (INET_DIAG_TCLASS))
+ #define XLAT_STR_6 STRINGIFY(INET_DIAG_TCLASS)
  XLAT(INET_DIAG_SKMEMINFO),
+ #define XLAT_VAL_7 ((unsigned) (INET_DIAG_SKMEMINFO))
+ #define XLAT_STR_7 STRINGIFY(INET_DIAG_SKMEMINFO)
  XLAT(INET_DIAG_SHUTDOWN),
+ #define XLAT_VAL_8 ((unsigned) (INET_DIAG_SHUTDOWN))
+ #define XLAT_STR_8 STRINGIFY(INET_DIAG_SHUTDOWN)
  XLAT(INET_DIAG_DCTCPINFO),
+ #define XLAT_VAL_9 ((unsigned) (INET_DIAG_DCTCPINFO))
+ #define XLAT_STR_9 STRINGIFY(INET_DIAG_DCTCPINFO)
  XLAT(INET_DIAG_PROTOCOL),
+ #define XLAT_VAL_10 ((unsigned) (INET_DIAG_PROTOCOL))
+ #define XLAT_STR_10 STRINGIFY(INET_DIAG_PROTOCOL)
  XLAT(INET_DIAG_SKV6ONLY),
+ #define XLAT_VAL_11 ((unsigned) (INET_DIAG_SKV6ONLY))
+ #define XLAT_STR_11 STRINGIFY(INET_DIAG_SKV6ONLY)
  XLAT(INET_DIAG_LOCALS),
+ #define XLAT_VAL_12 ((unsigned) (INET_DIAG_LOCALS))
+ #define XLAT_STR_12 STRINGIFY(INET_DIAG_LOCALS)
  XLAT(INET_DIAG_PEERS),
+ #define XLAT_VAL_13 ((unsigned) (INET_DIAG_PEERS))
+ #define XLAT_STR_13 STRINGIFY(INET_DIAG_PEERS)
  XLAT(INET_DIAG_PAD),
+ #define XLAT_VAL_14 ((unsigned) (INET_DIAG_PAD))
+ #define XLAT_STR_14 STRINGIFY(INET_DIAG_PAD)
  XLAT(INET_DIAG_MARK),
+ #define XLAT_VAL_15 ((unsigned) (INET_DIAG_MARK))
+ #define XLAT_STR_15 STRINGIFY(INET_DIAG_MARK)
  XLAT(INET_DIAG_BBRINFO),
+ #define XLAT_VAL_16 ((unsigned) (INET_DIAG_BBRINFO))
+ #define XLAT_STR_16 STRINGIFY(INET_DIAG_BBRINFO)
  XLAT(INET_DIAG_CLASS_ID),
+ #define XLAT_VAL_17 ((unsigned) (INET_DIAG_CLASS_ID))
+ #define XLAT_STR_17 STRINGIFY(INET_DIAG_CLASS_ID)
+ XLAT(INET_DIAG_MD5SIG),
+ #define XLAT_VAL_18 ((unsigned) (INET_DIAG_MD5SIG))
+ #define XLAT_STR_18 STRINGIFY(INET_DIAG_MD5SIG)
+ XLAT(INET_DIAG_ULP_INFO),
+ #define XLAT_VAL_19 ((unsigned) (INET_DIAG_ULP_INFO))
+ #define XLAT_STR_19 STRINGIFY(INET_DIAG_ULP_INFO)
+ XLAT(INET_DIAG_SK_BPF_STORAGES),
+ #define XLAT_VAL_20 ((unsigned) (INET_DIAG_SK_BPF_STORAGES))
+ #define XLAT_STR_20 STRINGIFY(INET_DIAG_SK_BPF_STORAGES)
+ XLAT(INET_DIAG_CGROUP_ID),
+ #define XLAT_VAL_21 ((unsigned) (INET_DIAG_CGROUP_ID))
+ #define XLAT_STR_21 STRINGIFY(INET_DIAG_CGROUP_ID)
 };
 static
 const struct xlat inet_diag_attrs[1] = { {
  .data = inet_diag_attrs_xdata,
  .size = ARRAY_SIZE(inet_diag_attrs_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/inet_diag_attrs.in 5.9-0ubuntu2/xlat/inet_diag_attrs.in
--- 5.5-3/xlat/inet_diag_attrs.in	2017-09-17 12:04:11.000000000 +0000
+++ 5.9-0ubuntu2/xlat/inet_diag_attrs.in	2020-06-28 08:00:00.000000000 +0000
@@ -17,3 +17,7 @@ INET_DIAG_PAD
 INET_DIAG_MARK
 INET_DIAG_BBRINFO
 INET_DIAG_CLASS_ID
+INET_DIAG_MD5SIG
+INET_DIAG_ULP_INFO
+INET_DIAG_SK_BPF_STORAGES
+INET_DIAG_CGROUP_ID
diff -pruN 5.5-3/xlat/inet_diag_bytecodes.h 5.9-0ubuntu2/xlat/inet_diag_bytecodes.h
--- 5.5-3/xlat/inet_diag_bytecodes.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/inet_diag_bytecodes.h	2020-09-24 09:18:44.000000000 +0000
@@ -14,26 +14,171 @@
 
 static const struct xlat_data inet_diag_bytecodes_xdata[] = {
  XLAT(INET_DIAG_BC_NOP),
+ #define XLAT_VAL_0 ((unsigned) (INET_DIAG_BC_NOP))
+ #define XLAT_STR_0 STRINGIFY(INET_DIAG_BC_NOP)
  XLAT(INET_DIAG_BC_JMP),
+ #define XLAT_VAL_1 ((unsigned) (INET_DIAG_BC_JMP))
+ #define XLAT_STR_1 STRINGIFY(INET_DIAG_BC_JMP)
  XLAT(INET_DIAG_BC_S_GE),
+ #define XLAT_VAL_2 ((unsigned) (INET_DIAG_BC_S_GE))
+ #define XLAT_STR_2 STRINGIFY(INET_DIAG_BC_S_GE)
  XLAT(INET_DIAG_BC_S_LE),
+ #define XLAT_VAL_3 ((unsigned) (INET_DIAG_BC_S_LE))
+ #define XLAT_STR_3 STRINGIFY(INET_DIAG_BC_S_LE)
  XLAT(INET_DIAG_BC_D_GE),
+ #define XLAT_VAL_4 ((unsigned) (INET_DIAG_BC_D_GE))
+ #define XLAT_STR_4 STRINGIFY(INET_DIAG_BC_D_GE)
  XLAT(INET_DIAG_BC_D_LE),
+ #define XLAT_VAL_5 ((unsigned) (INET_DIAG_BC_D_LE))
+ #define XLAT_STR_5 STRINGIFY(INET_DIAG_BC_D_LE)
  XLAT(INET_DIAG_BC_AUTO),
+ #define XLAT_VAL_6 ((unsigned) (INET_DIAG_BC_AUTO))
+ #define XLAT_STR_6 STRINGIFY(INET_DIAG_BC_AUTO)
  XLAT(INET_DIAG_BC_S_COND),
+ #define XLAT_VAL_7 ((unsigned) (INET_DIAG_BC_S_COND))
+ #define XLAT_STR_7 STRINGIFY(INET_DIAG_BC_S_COND)
  XLAT(INET_DIAG_BC_D_COND),
+ #define XLAT_VAL_8 ((unsigned) (INET_DIAG_BC_D_COND))
+ #define XLAT_STR_8 STRINGIFY(INET_DIAG_BC_D_COND)
  XLAT(INET_DIAG_BC_DEV_COND),
+ #define XLAT_VAL_9 ((unsigned) (INET_DIAG_BC_DEV_COND))
+ #define XLAT_STR_9 STRINGIFY(INET_DIAG_BC_DEV_COND)
  XLAT(INET_DIAG_BC_MARK_COND),
+ #define XLAT_VAL_10 ((unsigned) (INET_DIAG_BC_MARK_COND))
+ #define XLAT_STR_10 STRINGIFY(INET_DIAG_BC_MARK_COND)
  XLAT(INET_DIAG_BC_S_EQ),
+ #define XLAT_VAL_11 ((unsigned) (INET_DIAG_BC_S_EQ))
+ #define XLAT_STR_11 STRINGIFY(INET_DIAG_BC_S_EQ)
  XLAT(INET_DIAG_BC_D_EQ),
+ #define XLAT_VAL_12 ((unsigned) (INET_DIAG_BC_D_EQ))
+ #define XLAT_STR_12 STRINGIFY(INET_DIAG_BC_D_EQ)
+ XLAT(INET_DIAG_BC_CGROUP_COND),
+ #define XLAT_VAL_13 ((unsigned) (INET_DIAG_BC_CGROUP_COND))
+ #define XLAT_STR_13 STRINGIFY(INET_DIAG_BC_CGROUP_COND)
 };
 static
 const struct xlat inet_diag_bytecodes[1] = { {
  .data = inet_diag_bytecodes_xdata,
  .size = ARRAY_SIZE(inet_diag_bytecodes_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/inet_diag_bytecodes.in 5.9-0ubuntu2/xlat/inet_diag_bytecodes.in
--- 5.5-3/xlat/inet_diag_bytecodes.in	2018-02-27 13:14:38.000000000 +0000
+++ 5.9-0ubuntu2/xlat/inet_diag_bytecodes.in	2020-06-28 08:00:00.000000000 +0000
@@ -12,3 +12,4 @@ INET_DIAG_BC_DEV_COND
 INET_DIAG_BC_MARK_COND
 INET_DIAG_BC_S_EQ
 INET_DIAG_BC_D_EQ
+INET_DIAG_BC_CGROUP_COND
diff -pruN 5.5-3/xlat/inet_diag_extended_flags.h 5.9-0ubuntu2/xlat/inet_diag_extended_flags.h
--- 5.5-3/xlat/inet_diag_extended_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/inet_diag_extended_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -14,30 +14,248 @@
 
 static const struct xlat_data inet_diag_extended_flags_xdata[] = {
  XLAT(1<<(INET_DIAG_MEMINFO-1)),
+ #define XLAT_VAL_0 ((unsigned) (1<<(INET_DIAG_MEMINFO-1)))
+ #define XLAT_STR_0 STRINGIFY(1<<(INET_DIAG_MEMINFO-1))
  XLAT(1<<(INET_DIAG_INFO-1)),
+ #define XLAT_VAL_1 ((unsigned) (1<<(INET_DIAG_INFO-1)))
+ #define XLAT_STR_1 STRINGIFY(1<<(INET_DIAG_INFO-1))
  XLAT(1<<(INET_DIAG_VEGASINFO-1)),
+ #define XLAT_VAL_2 ((unsigned) (1<<(INET_DIAG_VEGASINFO-1)))
+ #define XLAT_STR_2 STRINGIFY(1<<(INET_DIAG_VEGASINFO-1))
  XLAT(1<<(INET_DIAG_CONG-1)),
+ #define XLAT_VAL_3 ((unsigned) (1<<(INET_DIAG_CONG-1)))
+ #define XLAT_STR_3 STRINGIFY(1<<(INET_DIAG_CONG-1))
  XLAT(1<<(INET_DIAG_TOS-1)),
+ #define XLAT_VAL_4 ((unsigned) (1<<(INET_DIAG_TOS-1)))
+ #define XLAT_STR_4 STRINGIFY(1<<(INET_DIAG_TOS-1))
  XLAT(1<<(INET_DIAG_TCLASS-1)),
+ #define XLAT_VAL_5 ((unsigned) (1<<(INET_DIAG_TCLASS-1)))
+ #define XLAT_STR_5 STRINGIFY(1<<(INET_DIAG_TCLASS-1))
  XLAT(1<<(INET_DIAG_SKMEMINFO-1)),
+ #define XLAT_VAL_6 ((unsigned) (1<<(INET_DIAG_SKMEMINFO-1)))
+ #define XLAT_STR_6 STRINGIFY(1<<(INET_DIAG_SKMEMINFO-1))
  XLAT(1<<(INET_DIAG_SHUTDOWN-1)),
+ #define XLAT_VAL_7 ((unsigned) (1<<(INET_DIAG_SHUTDOWN-1)))
+ #define XLAT_STR_7 STRINGIFY(1<<(INET_DIAG_SHUTDOWN-1))
  XLAT(1<<(INET_DIAG_DCTCPINFO-1)),
+ #define XLAT_VAL_8 ((unsigned) (1<<(INET_DIAG_DCTCPINFO-1)))
+ #define XLAT_STR_8 STRINGIFY(1<<(INET_DIAG_DCTCPINFO-1))
  XLAT(1<<(INET_DIAG_PROTOCOL-1)),
+ #define XLAT_VAL_9 ((unsigned) (1<<(INET_DIAG_PROTOCOL-1)))
+ #define XLAT_STR_9 STRINGIFY(1<<(INET_DIAG_PROTOCOL-1))
  XLAT(1<<(INET_DIAG_SKV6ONLY-1)),
+ #define XLAT_VAL_10 ((unsigned) (1<<(INET_DIAG_SKV6ONLY-1)))
+ #define XLAT_STR_10 STRINGIFY(1<<(INET_DIAG_SKV6ONLY-1))
  XLAT(1<<(INET_DIAG_LOCALS-1)),
+ #define XLAT_VAL_11 ((unsigned) (1<<(INET_DIAG_LOCALS-1)))
+ #define XLAT_STR_11 STRINGIFY(1<<(INET_DIAG_LOCALS-1))
  XLAT(1<<(INET_DIAG_PEERS-1)),
+ #define XLAT_VAL_12 ((unsigned) (1<<(INET_DIAG_PEERS-1)))
+ #define XLAT_STR_12 STRINGIFY(1<<(INET_DIAG_PEERS-1))
  XLAT(1<<(INET_DIAG_PAD-1)),
+ #define XLAT_VAL_13 ((unsigned) (1<<(INET_DIAG_PAD-1)))
+ #define XLAT_STR_13 STRINGIFY(1<<(INET_DIAG_PAD-1))
  XLAT(1<<(INET_DIAG_MARK-1)),
+ #define XLAT_VAL_14 ((unsigned) (1<<(INET_DIAG_MARK-1)))
+ #define XLAT_STR_14 STRINGIFY(1<<(INET_DIAG_MARK-1))
  XLAT(1<<(INET_DIAG_BBRINFO-1)),
+ #define XLAT_VAL_15 ((unsigned) (1<<(INET_DIAG_BBRINFO-1)))
+ #define XLAT_STR_15 STRINGIFY(1<<(INET_DIAG_BBRINFO-1))
  XLAT(1<<(INET_DIAG_CLASS_ID-1)),
+ #define XLAT_VAL_16 ((unsigned) (1<<(INET_DIAG_CLASS_ID-1)))
+ #define XLAT_STR_16 STRINGIFY(1<<(INET_DIAG_CLASS_ID-1))
+ XLAT(1<<(INET_DIAG_MD5SIG-1)),
+ #define XLAT_VAL_17 ((unsigned) (1<<(INET_DIAG_MD5SIG-1)))
+ #define XLAT_STR_17 STRINGIFY(1<<(INET_DIAG_MD5SIG-1))
+ XLAT(1<<(INET_DIAG_ULP_INFO-1)),
+ #define XLAT_VAL_18 ((unsigned) (1<<(INET_DIAG_ULP_INFO-1)))
+ #define XLAT_STR_18 STRINGIFY(1<<(INET_DIAG_ULP_INFO-1))
+ XLAT(1<<(INET_DIAG_SK_BPF_STORAGES-1)),
+ #define XLAT_VAL_19 ((unsigned) (1<<(INET_DIAG_SK_BPF_STORAGES-1)))
+ #define XLAT_STR_19 STRINGIFY(1<<(INET_DIAG_SK_BPF_STORAGES-1))
+ XLAT(1<<(INET_DIAG_CGROUP_ID-1)),
+ #define XLAT_VAL_20 ((unsigned) (1<<(INET_DIAG_CGROUP_ID-1)))
+ #define XLAT_STR_20 STRINGIFY(1<<(INET_DIAG_CGROUP_ID-1))
 };
 static
 const struct xlat inet_diag_extended_flags[1] = { {
  .data = inet_diag_extended_flags_xdata,
  .size = ARRAY_SIZE(inet_diag_extended_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/inet_diag_extended_flags.in 5.9-0ubuntu2/xlat/inet_diag_extended_flags.in
--- 5.5-3/xlat/inet_diag_extended_flags.in	2017-09-17 12:04:11.000000000 +0000
+++ 5.9-0ubuntu2/xlat/inet_diag_extended_flags.in	2020-06-28 08:00:00.000000000 +0000
@@ -16,3 +16,7 @@
 1<<(INET_DIAG_MARK-1)
 1<<(INET_DIAG_BBRINFO-1)
 1<<(INET_DIAG_CLASS_ID-1)
+1<<(INET_DIAG_MD5SIG-1)
+1<<(INET_DIAG_ULP_INFO-1)
+1<<(INET_DIAG_SK_BPF_STORAGES-1)
+1<<(INET_DIAG_CGROUP_ID-1)
diff -pruN 5.5-3/xlat/inet_diag_req_attrs.h 5.9-0ubuntu2/xlat/inet_diag_req_attrs.h
--- 5.5-3/xlat/inet_diag_req_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/inet_diag_req_attrs.h	2020-09-24 09:18:44.000000000 +0000
@@ -14,15 +14,61 @@
 
 static const struct xlat_data inet_diag_req_attrs_xdata[] = {
  XLAT(INET_DIAG_REQ_NONE),
+ #define XLAT_VAL_0 ((unsigned) (INET_DIAG_REQ_NONE))
+ #define XLAT_STR_0 STRINGIFY(INET_DIAG_REQ_NONE)
  XLAT(INET_DIAG_REQ_BYTECODE),
+ #define XLAT_VAL_1 ((unsigned) (INET_DIAG_REQ_BYTECODE))
+ #define XLAT_STR_1 STRINGIFY(INET_DIAG_REQ_BYTECODE)
+ XLAT(INET_DIAG_REQ_SK_BPF_STORAGES),
+ #define XLAT_VAL_2 ((unsigned) (INET_DIAG_REQ_SK_BPF_STORAGES))
+ #define XLAT_STR_2 STRINGIFY(INET_DIAG_REQ_SK_BPF_STORAGES)
+ XLAT(INET_DIAG_REQ_PROTOCOL),
+ #define XLAT_VAL_3 ((unsigned) (INET_DIAG_REQ_PROTOCOL))
+ #define XLAT_STR_3 STRINGIFY(INET_DIAG_REQ_PROTOCOL)
 };
 static
 const struct xlat inet_diag_req_attrs[1] = { {
  .data = inet_diag_req_attrs_xdata,
  .size = ARRAY_SIZE(inet_diag_req_attrs_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/inet_diag_req_attrs.in 5.9-0ubuntu2/xlat/inet_diag_req_attrs.in
--- 5.5-3/xlat/inet_diag_req_attrs.in	2017-06-30 21:38:49.000000000 +0000
+++ 5.9-0ubuntu2/xlat/inet_diag_req_attrs.in	2020-09-06 08:00:00.000000000 +0000
@@ -1,3 +1,5 @@
 #unconditional
 INET_DIAG_REQ_NONE
 INET_DIAG_REQ_BYTECODE
+INET_DIAG_REQ_SK_BPF_STORAGES
+INET_DIAG_REQ_PROTOCOL
diff -pruN 5.5-3/xlat/inet_protocols.h 5.9-0ubuntu2/xlat/inet_protocols.h
--- 5.5-3/xlat/inet_protocols.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/inet_protocols.h	2020-09-24 09:18:45.000000000 +0000
@@ -220,6 +220,13 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define IPPROTO_MPLS 137
 #endif
+#if defined(IPPROTO_ETHERNET) || (defined(HAVE_DECL_IPPROTO_ETHERNET) && HAVE_DECL_IPPROTO_ETHERNET)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IPPROTO_ETHERNET) == (143), "IPPROTO_ETHERNET != 143");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IPPROTO_ETHERNET 143
+#endif
 #if defined(IPPROTO_RAW) || (defined(HAVE_DECL_IPPROTO_RAW) && HAVE_DECL_IPPROTO_RAW)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
 static_assert((IPPROTO_RAW) == (255), "IPPROTO_RAW != 255");
@@ -234,6 +241,13 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define IPPROTO_MAX 256
 #endif
+#if defined(IPPROTO_MPTCP) || (defined(HAVE_DECL_IPPROTO_MPTCP) && HAVE_DECL_IPPROTO_MPTCP)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IPPROTO_MPTCP) == (262), "IPPROTO_MPTCP != 262");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IPPROTO_MPTCP 262
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -241,45 +255,401 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data inet_protocols_xdata[] = {
  XLAT(IPPROTO_IP),
+ #define XLAT_VAL_0 ((unsigned) (IPPROTO_IP))
+ #define XLAT_STR_0 STRINGIFY(IPPROTO_IP)
  XLAT(IPPROTO_ICMP),
+ #define XLAT_VAL_1 ((unsigned) (IPPROTO_ICMP))
+ #define XLAT_STR_1 STRINGIFY(IPPROTO_ICMP)
  XLAT(IPPROTO_IGMP),
+ #define XLAT_VAL_2 ((unsigned) (IPPROTO_IGMP))
+ #define XLAT_STR_2 STRINGIFY(IPPROTO_IGMP)
  XLAT(IPPROTO_IPIP),
+ #define XLAT_VAL_3 ((unsigned) (IPPROTO_IPIP))
+ #define XLAT_STR_3 STRINGIFY(IPPROTO_IPIP)
  XLAT(IPPROTO_TCP),
+ #define XLAT_VAL_4 ((unsigned) (IPPROTO_TCP))
+ #define XLAT_STR_4 STRINGIFY(IPPROTO_TCP)
  XLAT(IPPROTO_EGP),
+ #define XLAT_VAL_5 ((unsigned) (IPPROTO_EGP))
+ #define XLAT_STR_5 STRINGIFY(IPPROTO_EGP)
  XLAT(IPPROTO_PUP),
+ #define XLAT_VAL_6 ((unsigned) (IPPROTO_PUP))
+ #define XLAT_STR_6 STRINGIFY(IPPROTO_PUP)
  XLAT(IPPROTO_UDP),
+ #define XLAT_VAL_7 ((unsigned) (IPPROTO_UDP))
+ #define XLAT_STR_7 STRINGIFY(IPPROTO_UDP)
  XLAT(IPPROTO_IDP),
+ #define XLAT_VAL_8 ((unsigned) (IPPROTO_IDP))
+ #define XLAT_STR_8 STRINGIFY(IPPROTO_IDP)
  XLAT(IPPROTO_TP),
+ #define XLAT_VAL_9 ((unsigned) (IPPROTO_TP))
+ #define XLAT_STR_9 STRINGIFY(IPPROTO_TP)
  XLAT(IPPROTO_DCCP),
+ #define XLAT_VAL_10 ((unsigned) (IPPROTO_DCCP))
+ #define XLAT_STR_10 STRINGIFY(IPPROTO_DCCP)
  XLAT(IPPROTO_IPV6),
+ #define XLAT_VAL_11 ((unsigned) (IPPROTO_IPV6))
+ #define XLAT_STR_11 STRINGIFY(IPPROTO_IPV6)
  XLAT(IPPROTO_ROUTING),
+ #define XLAT_VAL_12 ((unsigned) (IPPROTO_ROUTING))
+ #define XLAT_STR_12 STRINGIFY(IPPROTO_ROUTING)
  XLAT(IPPROTO_FRAGMENT),
+ #define XLAT_VAL_13 ((unsigned) (IPPROTO_FRAGMENT))
+ #define XLAT_STR_13 STRINGIFY(IPPROTO_FRAGMENT)
  XLAT(IPPROTO_RSVP),
+ #define XLAT_VAL_14 ((unsigned) (IPPROTO_RSVP))
+ #define XLAT_STR_14 STRINGIFY(IPPROTO_RSVP)
  XLAT(IPPROTO_GRE),
+ #define XLAT_VAL_15 ((unsigned) (IPPROTO_GRE))
+ #define XLAT_STR_15 STRINGIFY(IPPROTO_GRE)
  XLAT(IPPROTO_ESP),
+ #define XLAT_VAL_16 ((unsigned) (IPPROTO_ESP))
+ #define XLAT_STR_16 STRINGIFY(IPPROTO_ESP)
  XLAT(IPPROTO_AH),
+ #define XLAT_VAL_17 ((unsigned) (IPPROTO_AH))
+ #define XLAT_STR_17 STRINGIFY(IPPROTO_AH)
  XLAT(IPPROTO_ICMPV6),
+ #define XLAT_VAL_18 ((unsigned) (IPPROTO_ICMPV6))
+ #define XLAT_STR_18 STRINGIFY(IPPROTO_ICMPV6)
  XLAT(IPPROTO_NONE),
+ #define XLAT_VAL_19 ((unsigned) (IPPROTO_NONE))
+ #define XLAT_STR_19 STRINGIFY(IPPROTO_NONE)
  XLAT(IPPROTO_DSTOPTS),
+ #define XLAT_VAL_20 ((unsigned) (IPPROTO_DSTOPTS))
+ #define XLAT_STR_20 STRINGIFY(IPPROTO_DSTOPTS)
  XLAT(IPPROTO_MTP),
+ #define XLAT_VAL_21 ((unsigned) (IPPROTO_MTP))
+ #define XLAT_STR_21 STRINGIFY(IPPROTO_MTP)
  XLAT(IPPROTO_BEETPH),
+ #define XLAT_VAL_22 ((unsigned) (IPPROTO_BEETPH))
+ #define XLAT_STR_22 STRINGIFY(IPPROTO_BEETPH)
  XLAT(IPPROTO_ENCAP),
+ #define XLAT_VAL_23 ((unsigned) (IPPROTO_ENCAP))
+ #define XLAT_STR_23 STRINGIFY(IPPROTO_ENCAP)
  XLAT(IPPROTO_PIM),
+ #define XLAT_VAL_24 ((unsigned) (IPPROTO_PIM))
+ #define XLAT_STR_24 STRINGIFY(IPPROTO_PIM)
  XLAT(IPPROTO_COMP),
+ #define XLAT_VAL_25 ((unsigned) (IPPROTO_COMP))
+ #define XLAT_STR_25 STRINGIFY(IPPROTO_COMP)
  XLAT(IPPROTO_L2TP),
+ #define XLAT_VAL_26 ((unsigned) (IPPROTO_L2TP))
+ #define XLAT_STR_26 STRINGIFY(IPPROTO_L2TP)
  XLAT(IPPROTO_SCTP),
+ #define XLAT_VAL_27 ((unsigned) (IPPROTO_SCTP))
+ #define XLAT_STR_27 STRINGIFY(IPPROTO_SCTP)
  XLAT(IPPROTO_MH),
+ #define XLAT_VAL_28 ((unsigned) (IPPROTO_MH))
+ #define XLAT_STR_28 STRINGIFY(IPPROTO_MH)
  XLAT(IPPROTO_UDPLITE),
+ #define XLAT_VAL_29 ((unsigned) (IPPROTO_UDPLITE))
+ #define XLAT_STR_29 STRINGIFY(IPPROTO_UDPLITE)
  XLAT(IPPROTO_MPLS),
+ #define XLAT_VAL_30 ((unsigned) (IPPROTO_MPLS))
+ #define XLAT_STR_30 STRINGIFY(IPPROTO_MPLS)
+ XLAT(IPPROTO_ETHERNET),
+ #define XLAT_VAL_31 ((unsigned) (IPPROTO_ETHERNET))
+ #define XLAT_STR_31 STRINGIFY(IPPROTO_ETHERNET)
  XLAT(IPPROTO_RAW),
+ #define XLAT_VAL_32 ((unsigned) (IPPROTO_RAW))
+ #define XLAT_STR_32 STRINGIFY(IPPROTO_RAW)
  XLAT(IPPROTO_MAX),
+ #define XLAT_VAL_33 ((unsigned) (IPPROTO_MAX))
+ #define XLAT_STR_33 STRINGIFY(IPPROTO_MAX)
+ XLAT(IPPROTO_MPTCP),
+ #define XLAT_VAL_34 ((unsigned) (IPPROTO_MPTCP))
+ #define XLAT_STR_34 STRINGIFY(IPPROTO_MPTCP)
 };
 const struct xlat inet_protocols[1] = { {
  .data = inet_protocols_xdata,
  .size = ARRAY_SIZE(inet_protocols_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/inet_protocols.in 5.9-0ubuntu2/xlat/inet_protocols.in
--- 5.5-3/xlat/inet_protocols.in	2019-07-24 17:12:18.000000000 +0000
+++ 5.9-0ubuntu2/xlat/inet_protocols.in	2020-03-16 20:40:50.000000000 +0000
@@ -30,5 +30,7 @@ IPPROTO_SCTP		132
 IPPROTO_MH		135
 IPPROTO_UDPLITE		136
 IPPROTO_MPLS		137
+IPPROTO_ETHERNET	143
 IPPROTO_RAW		255
 IPPROTO_MAX		256
+IPPROTO_MPTCP		262
diff -pruN 5.5-3/xlat/inotify_flags.h 5.9-0ubuntu2/xlat/inotify_flags.h
--- 5.5-3/xlat/inotify_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/inotify_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -168,35 +168,259 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data inotify_flags_xdata[] = {
  XLAT(IN_ACCESS),
+ #define XLAT_VAL_0 ((unsigned) (IN_ACCESS))
+ #define XLAT_STR_0 STRINGIFY(IN_ACCESS)
  XLAT(IN_MODIFY),
+ #define XLAT_VAL_1 ((unsigned) (IN_MODIFY))
+ #define XLAT_STR_1 STRINGIFY(IN_MODIFY)
  XLAT(IN_ATTRIB),
+ #define XLAT_VAL_2 ((unsigned) (IN_ATTRIB))
+ #define XLAT_STR_2 STRINGIFY(IN_ATTRIB)
  XLAT(IN_CLOSE_WRITE),
+ #define XLAT_VAL_3 ((unsigned) (IN_CLOSE_WRITE))
+ #define XLAT_STR_3 STRINGIFY(IN_CLOSE_WRITE)
  XLAT(IN_CLOSE_NOWRITE),
+ #define XLAT_VAL_4 ((unsigned) (IN_CLOSE_NOWRITE))
+ #define XLAT_STR_4 STRINGIFY(IN_CLOSE_NOWRITE)
  XLAT(IN_OPEN),
+ #define XLAT_VAL_5 ((unsigned) (IN_OPEN))
+ #define XLAT_STR_5 STRINGIFY(IN_OPEN)
  XLAT(IN_MOVED_FROM),
+ #define XLAT_VAL_6 ((unsigned) (IN_MOVED_FROM))
+ #define XLAT_STR_6 STRINGIFY(IN_MOVED_FROM)
  XLAT(IN_MOVED_TO),
+ #define XLAT_VAL_7 ((unsigned) (IN_MOVED_TO))
+ #define XLAT_STR_7 STRINGIFY(IN_MOVED_TO)
  XLAT(IN_CREATE),
+ #define XLAT_VAL_8 ((unsigned) (IN_CREATE))
+ #define XLAT_STR_8 STRINGIFY(IN_CREATE)
  XLAT(IN_DELETE),
+ #define XLAT_VAL_9 ((unsigned) (IN_DELETE))
+ #define XLAT_STR_9 STRINGIFY(IN_DELETE)
  XLAT(IN_DELETE_SELF),
+ #define XLAT_VAL_10 ((unsigned) (IN_DELETE_SELF))
+ #define XLAT_STR_10 STRINGIFY(IN_DELETE_SELF)
  XLAT(IN_MOVE_SELF),
+ #define XLAT_VAL_11 ((unsigned) (IN_MOVE_SELF))
+ #define XLAT_STR_11 STRINGIFY(IN_MOVE_SELF)
  XLAT(IN_UNMOUNT),
+ #define XLAT_VAL_12 ((unsigned) (IN_UNMOUNT))
+ #define XLAT_STR_12 STRINGIFY(IN_UNMOUNT)
  XLAT(IN_Q_OVERFLOW),
+ #define XLAT_VAL_13 ((unsigned) (IN_Q_OVERFLOW))
+ #define XLAT_STR_13 STRINGIFY(IN_Q_OVERFLOW)
  XLAT(IN_IGNORED),
+ #define XLAT_VAL_14 ((unsigned) (IN_IGNORED))
+ #define XLAT_STR_14 STRINGIFY(IN_IGNORED)
  XLAT(IN_ONLYDIR),
+ #define XLAT_VAL_15 ((unsigned) (IN_ONLYDIR))
+ #define XLAT_STR_15 STRINGIFY(IN_ONLYDIR)
  XLAT(IN_DONT_FOLLOW),
+ #define XLAT_VAL_16 ((unsigned) (IN_DONT_FOLLOW))
+ #define XLAT_STR_16 STRINGIFY(IN_DONT_FOLLOW)
  XLAT(IN_EXCL_UNLINK),
+ #define XLAT_VAL_17 ((unsigned) (IN_EXCL_UNLINK))
+ #define XLAT_STR_17 STRINGIFY(IN_EXCL_UNLINK)
  XLAT(IN_MASK_CREATE),
+ #define XLAT_VAL_18 ((unsigned) (IN_MASK_CREATE))
+ #define XLAT_STR_18 STRINGIFY(IN_MASK_CREATE)
  XLAT(IN_MASK_ADD),
+ #define XLAT_VAL_19 ((unsigned) (IN_MASK_ADD))
+ #define XLAT_STR_19 STRINGIFY(IN_MASK_ADD)
  XLAT(IN_ISDIR),
+ #define XLAT_VAL_20 ((unsigned) (IN_ISDIR))
+ #define XLAT_STR_20 STRINGIFY(IN_ISDIR)
  XLAT(IN_ONESHOT),
+ #define XLAT_VAL_21 ((unsigned) (IN_ONESHOT))
+ #define XLAT_STR_21 STRINGIFY(IN_ONESHOT)
 };
 static
 const struct xlat inotify_flags[1] = { {
  .data = inotify_flags_xdata,
  .size = ARRAY_SIZE(inotify_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/inotify_init_flags.h 5.9-0ubuntu2/xlat/inotify_init_flags.h
--- 5.5-3/xlat/inotify_init_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/inotify_init_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -30,8 +30,12 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data inotify_init_flags_xdata[] = {
  XLAT(IN_NONBLOCK),
+ #define XLAT_VAL_0 ((unsigned) (IN_NONBLOCK))
+ #define XLAT_STR_0 STRINGIFY(IN_NONBLOCK)
 #if defined IN_CLOEXEC || defined O_CLOEXEC
  XLAT(IN_CLOEXEC),
+ #define XLAT_VAL_1 ((unsigned) (IN_CLOEXEC))
+ #define XLAT_STR_1 STRINGIFY(IN_CLOEXEC)
 #endif
 };
 static
@@ -39,8 +43,28 @@ const struct xlat inotify_init_flags[1]
  .data = inotify_init_flags_xdata,
  .size = ARRAY_SIZE(inotify_init_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ioctl_dirs.h 5.9-0ubuntu2/xlat/ioctl_dirs.h
--- 5.5-3/xlat/ioctl_dirs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ioctl_dirs.h	2020-09-24 09:18:44.000000000 +0000
@@ -15,12 +15,18 @@
 static const struct xlat_data ioctl_dirs_xdata[] = {
 #if defined(_IOC_NONE) || (defined(HAVE_DECL__IOC_NONE) && HAVE_DECL__IOC_NONE)
   XLAT(_IOC_NONE),
+ #define XLAT_VAL_0 ((unsigned) (_IOC_NONE))
+ #define XLAT_STR_0 STRINGIFY(_IOC_NONE)
 #endif
 #if defined(_IOC_READ) || (defined(HAVE_DECL__IOC_READ) && HAVE_DECL__IOC_READ)
   XLAT(_IOC_READ),
+ #define XLAT_VAL_1 ((unsigned) (_IOC_READ))
+ #define XLAT_STR_1 STRINGIFY(_IOC_READ)
 #endif
 #if defined(_IOC_WRITE) || (defined(HAVE_DECL__IOC_WRITE) && HAVE_DECL__IOC_WRITE)
   XLAT(_IOC_WRITE),
+ #define XLAT_VAL_2 ((unsigned) (_IOC_WRITE))
+ #define XLAT_STR_2 STRINGIFY(_IOC_WRITE)
 #endif
 };
 static
@@ -28,8 +34,36 @@ const struct xlat ioctl_dirs[1] = { {
  .data = ioctl_dirs_xdata,
  .size = ARRAY_SIZE(ioctl_dirs_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ioprio_class.h 5.9-0ubuntu2/xlat/ioprio_class.h
--- 5.5-3/xlat/ioprio_class.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ioprio_class.h	2020-09-24 09:18:44.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data ioprio_class_xdata[] = {
  [IOPRIO_CLASS_NONE] = XLAT(IOPRIO_CLASS_NONE),
+ #define XLAT_VAL_0 ((unsigned) (IOPRIO_CLASS_NONE))
+ #define XLAT_STR_0 STRINGIFY(IOPRIO_CLASS_NONE)
  [IOPRIO_CLASS_RT] = XLAT(IOPRIO_CLASS_RT),
+ #define XLAT_VAL_1 ((unsigned) (IOPRIO_CLASS_RT))
+ #define XLAT_STR_1 STRINGIFY(IOPRIO_CLASS_RT)
  [IOPRIO_CLASS_BE] = XLAT(IOPRIO_CLASS_BE),
+ #define XLAT_VAL_2 ((unsigned) (IOPRIO_CLASS_BE))
+ #define XLAT_STR_2 STRINGIFY(IOPRIO_CLASS_BE)
  [IOPRIO_CLASS_IDLE] = XLAT(IOPRIO_CLASS_IDLE),
+ #define XLAT_VAL_3 ((unsigned) (IOPRIO_CLASS_IDLE))
+ #define XLAT_STR_3 STRINGIFY(IOPRIO_CLASS_IDLE)
 };
 static
 const struct xlat ioprio_class[1] = { {
  .data = ioprio_class_xdata,
  .size = ARRAY_SIZE(ioprio_class_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ioprio_who.h 5.9-0ubuntu2/xlat/ioprio_who.h
--- 5.5-3/xlat/ioprio_who.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ioprio_who.h	2020-09-24 09:18:44.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data ioprio_who_xdata[] = {
  [IOPRIO_WHO_PROCESS] = XLAT(IOPRIO_WHO_PROCESS),
+ #define XLAT_VAL_0 ((unsigned) (IOPRIO_WHO_PROCESS))
+ #define XLAT_STR_0 STRINGIFY(IOPRIO_WHO_PROCESS)
  [IOPRIO_WHO_PGRP] = XLAT(IOPRIO_WHO_PGRP),
+ #define XLAT_VAL_1 ((unsigned) (IOPRIO_WHO_PGRP))
+ #define XLAT_STR_1 STRINGIFY(IOPRIO_WHO_PGRP)
  [IOPRIO_WHO_USER] = XLAT(IOPRIO_WHO_USER),
+ #define XLAT_VAL_2 ((unsigned) (IOPRIO_WHO_USER))
+ #define XLAT_STR_2 STRINGIFY(IOPRIO_WHO_USER)
 };
 static
 const struct xlat ioprio_who[1] = { {
  .data = ioprio_who_xdata,
  .size = ARRAY_SIZE(ioprio_who_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ipccalls.h 5.9-0ubuntu2/xlat/ipccalls.h
--- 5.5-3/xlat/ipccalls.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ipccalls.h	2020-09-24 09:18:44.000000000 +0000
@@ -98,25 +98,149 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data ipccalls_xdata[] = {
  XLAT(SEMOP),
+ #define XLAT_VAL_0 ((unsigned) (SEMOP))
+ #define XLAT_STR_0 STRINGIFY(SEMOP)
  XLAT(SEMGET),
+ #define XLAT_VAL_1 ((unsigned) (SEMGET))
+ #define XLAT_STR_1 STRINGIFY(SEMGET)
  XLAT(SEMCTL),
+ #define XLAT_VAL_2 ((unsigned) (SEMCTL))
+ #define XLAT_STR_2 STRINGIFY(SEMCTL)
  XLAT(SEMTIMEDOP),
+ #define XLAT_VAL_3 ((unsigned) (SEMTIMEDOP))
+ #define XLAT_STR_3 STRINGIFY(SEMTIMEDOP)
  XLAT(MSGSND),
+ #define XLAT_VAL_4 ((unsigned) (MSGSND))
+ #define XLAT_STR_4 STRINGIFY(MSGSND)
  XLAT(MSGRCV),
+ #define XLAT_VAL_5 ((unsigned) (MSGRCV))
+ #define XLAT_STR_5 STRINGIFY(MSGRCV)
  XLAT(MSGGET),
+ #define XLAT_VAL_6 ((unsigned) (MSGGET))
+ #define XLAT_STR_6 STRINGIFY(MSGGET)
  XLAT(MSGCTL),
+ #define XLAT_VAL_7 ((unsigned) (MSGCTL))
+ #define XLAT_STR_7 STRINGIFY(MSGCTL)
  XLAT(SHMAT),
+ #define XLAT_VAL_8 ((unsigned) (SHMAT))
+ #define XLAT_STR_8 STRINGIFY(SHMAT)
  XLAT(SHMDT),
+ #define XLAT_VAL_9 ((unsigned) (SHMDT))
+ #define XLAT_STR_9 STRINGIFY(SHMDT)
  XLAT(SHMGET),
+ #define XLAT_VAL_10 ((unsigned) (SHMGET))
+ #define XLAT_STR_10 STRINGIFY(SHMGET)
  XLAT(SHMCTL),
+ #define XLAT_VAL_11 ((unsigned) (SHMCTL))
+ #define XLAT_STR_11 STRINGIFY(SHMCTL)
 };
 static
 const struct xlat ipccalls[1] = { {
  .data = ipccalls_xdata,
  .size = ARRAY_SIZE(ipccalls_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ipc_msg_flags.h 5.9-0ubuntu2/xlat/ipc_msg_flags.h
--- 5.5-3/xlat/ipc_msg_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ipc_msg_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data ipc_msg_flags_xdata[] = {
  XLAT(MSG_NOERROR),
+ #define XLAT_VAL_0 ((unsigned) (MSG_NOERROR))
+ #define XLAT_STR_0 STRINGIFY(MSG_NOERROR)
  XLAT(MSG_EXCEPT),
+ #define XLAT_VAL_1 ((unsigned) (MSG_EXCEPT))
+ #define XLAT_STR_1 STRINGIFY(MSG_EXCEPT)
  XLAT(MSG_COPY),
+ #define XLAT_VAL_2 ((unsigned) (MSG_COPY))
+ #define XLAT_STR_2 STRINGIFY(MSG_COPY)
  XLAT(IPC_NOWAIT),
+ #define XLAT_VAL_3 ((unsigned) (IPC_NOWAIT))
+ #define XLAT_STR_3 STRINGIFY(IPC_NOWAIT)
 };
 static
 const struct xlat ipc_msg_flags[1] = { {
  .data = ipc_msg_flags_xdata,
  .size = ARRAY_SIZE(ipc_msg_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ip_cmsg_types.h 5.9-0ubuntu2/xlat/ip_cmsg_types.h
--- 5.5-3/xlat/ip_cmsg_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ip_cmsg_types.h	2020-09-24 09:18:44.000000000 +0000
@@ -70,15 +70,33 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data ip_cmsg_types_xdata[] = {
  XLAT(IP_TOS),
+ #define XLAT_VAL_0 ((unsigned) (IP_TOS))
+ #define XLAT_STR_0 STRINGIFY(IP_TOS)
  XLAT(IP_TTL),
+ #define XLAT_VAL_1 ((unsigned) (IP_TTL))
+ #define XLAT_STR_1 STRINGIFY(IP_TTL)
  XLAT(IP_RECVOPTS),
+ #define XLAT_VAL_2 ((unsigned) (IP_RECVOPTS))
+ #define XLAT_STR_2 STRINGIFY(IP_RECVOPTS)
  XLAT(IP_RETOPTS),
+ #define XLAT_VAL_3 ((unsigned) (IP_RETOPTS))
+ #define XLAT_STR_3 STRINGIFY(IP_RETOPTS)
  XLAT(IP_PKTINFO),
+ #define XLAT_VAL_4 ((unsigned) (IP_PKTINFO))
+ #define XLAT_STR_4 STRINGIFY(IP_PKTINFO)
  XLAT(IP_RECVERR),
+ #define XLAT_VAL_5 ((unsigned) (IP_RECVERR))
+ #define XLAT_STR_5 STRINGIFY(IP_RECVERR)
  XLAT(IP_ORIGDSTADDR),
+ #define XLAT_VAL_6 ((unsigned) (IP_ORIGDSTADDR))
+ #define XLAT_STR_6 STRINGIFY(IP_ORIGDSTADDR)
  XLAT(IP_CHECKSUM),
+ #define XLAT_VAL_7 ((unsigned) (IP_CHECKSUM))
+ #define XLAT_STR_7 STRINGIFY(IP_CHECKSUM)
 #if defined(SCM_SECURITY) || (defined(HAVE_DECL_SCM_SECURITY) && HAVE_DECL_SCM_SECURITY)
   XLAT(SCM_SECURITY),
+ #define XLAT_VAL_8 ((unsigned) (SCM_SECURITY))
+ #define XLAT_STR_8 STRINGIFY(SCM_SECURITY)
 #endif
 };
 static
@@ -86,8 +104,84 @@ const struct xlat ip_cmsg_types[1] = { {
  .data = ip_cmsg_types_xdata,
  .size = ARRAY_SIZE(ip_cmsg_types_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ipc_private.h 5.9-0ubuntu2/xlat/ipc_private.h
--- 5.5-3/xlat/ipc_private.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ipc_private.h	2020-09-24 09:18:44.000000000 +0000
@@ -17,13 +17,27 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data ipc_private_xdata[] = {
  XLAT(IPC_PRIVATE),
+ #define XLAT_VAL_0 ((unsigned) (IPC_PRIVATE))
+ #define XLAT_STR_0 STRINGIFY(IPC_PRIVATE)
 };
 const struct xlat ipc_private[1] = { {
  .data = ipc_private_xdata,
  .size = ARRAY_SIZE(ipc_private_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ip_type_of_services.h 5.9-0ubuntu2/xlat/ip_type_of_services.h
--- 5.5-3/xlat/ip_type_of_services.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ip_type_of_services.h	2020-09-24 09:18:44.000000000 +0000
@@ -11,23 +11,67 @@
 static const struct xlat_data ip_type_of_services_xdata[] = {
 #if defined(IPTOS_LOWDELAY) || (defined(HAVE_DECL_IPTOS_LOWDELAY) && HAVE_DECL_IPTOS_LOWDELAY)
   XLAT(IPTOS_LOWDELAY),
+ #define XLAT_VAL_0 ((unsigned) (IPTOS_LOWDELAY))
+ #define XLAT_STR_0 STRINGIFY(IPTOS_LOWDELAY)
 #endif
 #if defined(IPTOS_THROUGHPUT) || (defined(HAVE_DECL_IPTOS_THROUGHPUT) && HAVE_DECL_IPTOS_THROUGHPUT)
   XLAT(IPTOS_THROUGHPUT),
+ #define XLAT_VAL_1 ((unsigned) (IPTOS_THROUGHPUT))
+ #define XLAT_STR_1 STRINGIFY(IPTOS_THROUGHPUT)
 #endif
 #if defined(IPTOS_RELIABILITY) || (defined(HAVE_DECL_IPTOS_RELIABILITY) && HAVE_DECL_IPTOS_RELIABILITY)
   XLAT(IPTOS_RELIABILITY),
+ #define XLAT_VAL_2 ((unsigned) (IPTOS_RELIABILITY))
+ #define XLAT_STR_2 STRINGIFY(IPTOS_RELIABILITY)
 #endif
 #if defined(IPTOS_MINCOST) || (defined(HAVE_DECL_IPTOS_MINCOST) && HAVE_DECL_IPTOS_MINCOST)
   XLAT(IPTOS_MINCOST),
+ #define XLAT_VAL_3 ((unsigned) (IPTOS_MINCOST))
+ #define XLAT_STR_3 STRINGIFY(IPTOS_MINCOST)
 #endif
 };
 const struct xlat ip_type_of_services[1] = { {
  .data = ip_type_of_services_xdata,
  .size = ARRAY_SIZE(ip_type_of_services_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/irda_protocols.h 5.9-0ubuntu2/xlat/irda_protocols.h
--- 5.5-3/xlat/irda_protocols.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/irda_protocols.h	2020-09-24 09:18:44.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data irda_protocols_xdata[] = {
  [IRDAPROTO_UNITDATA] = XLAT(IRDAPROTO_UNITDATA),
+ #define XLAT_VAL_0 ((unsigned) (IRDAPROTO_UNITDATA))
+ #define XLAT_STR_0 STRINGIFY(IRDAPROTO_UNITDATA)
  [IRDAPROTO_ULTRA] = XLAT(IRDAPROTO_ULTRA),
+ #define XLAT_VAL_1 ((unsigned) (IRDAPROTO_ULTRA))
+ #define XLAT_STR_1 STRINGIFY(IRDAPROTO_ULTRA)
 };
 static
 const struct xlat irda_protocols[1] = { {
  .data = irda_protocols_xdata,
  .size = ARRAY_SIZE(irda_protocols_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/isdn_protocols.h 5.9-0ubuntu2/xlat/isdn_protocols.h
--- 5.5-3/xlat/isdn_protocols.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/isdn_protocols.h	2020-09-24 09:18:44.000000000 +0000
@@ -105,18 +105,44 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data isdn_protocols_xdata[] = {
  XLAT(ISDN_P_BASE),
+ #define XLAT_VAL_0 ((unsigned) (ISDN_P_BASE))
+ #define XLAT_STR_0 STRINGIFY(ISDN_P_BASE)
  XLAT(ISDN_P_TE_S0),
+ #define XLAT_VAL_1 ((unsigned) (ISDN_P_TE_S0))
+ #define XLAT_STR_1 STRINGIFY(ISDN_P_TE_S0)
  XLAT(ISDN_P_NT_S0),
+ #define XLAT_VAL_2 ((unsigned) (ISDN_P_NT_S0))
+ #define XLAT_STR_2 STRINGIFY(ISDN_P_NT_S0)
  XLAT(ISDN_P_TE_E1),
+ #define XLAT_VAL_3 ((unsigned) (ISDN_P_TE_E1))
+ #define XLAT_STR_3 STRINGIFY(ISDN_P_TE_E1)
  XLAT(ISDN_P_NT_E1),
+ #define XLAT_VAL_4 ((unsigned) (ISDN_P_NT_E1))
+ #define XLAT_STR_4 STRINGIFY(ISDN_P_NT_E1)
  XLAT(ISDN_P_LAPD_TE),
+ #define XLAT_VAL_5 ((unsigned) (ISDN_P_LAPD_TE))
+ #define XLAT_STR_5 STRINGIFY(ISDN_P_LAPD_TE)
  XLAT(ISDN_P_LAPD_NT),
+ #define XLAT_VAL_6 ((unsigned) (ISDN_P_LAPD_NT))
+ #define XLAT_STR_6 STRINGIFY(ISDN_P_LAPD_NT)
  XLAT(ISDN_P_B_RAW),
+ #define XLAT_VAL_7 ((unsigned) (ISDN_P_B_RAW))
+ #define XLAT_STR_7 STRINGIFY(ISDN_P_B_RAW)
  XLAT(ISDN_P_B_HDLC),
+ #define XLAT_VAL_8 ((unsigned) (ISDN_P_B_HDLC))
+ #define XLAT_STR_8 STRINGIFY(ISDN_P_B_HDLC)
  XLAT(ISDN_P_B_X75SLP),
+ #define XLAT_VAL_9 ((unsigned) (ISDN_P_B_X75SLP))
+ #define XLAT_STR_9 STRINGIFY(ISDN_P_B_X75SLP)
  XLAT(ISDN_P_B_L2DTMF),
+ #define XLAT_VAL_10 ((unsigned) (ISDN_P_B_L2DTMF))
+ #define XLAT_STR_10 STRINGIFY(ISDN_P_B_L2DTMF)
  XLAT(ISDN_P_B_L2DSP),
+ #define XLAT_VAL_11 ((unsigned) (ISDN_P_B_L2DSP))
+ #define XLAT_STR_11 STRINGIFY(ISDN_P_B_L2DSP)
  XLAT(ISDN_P_B_L2DSPHDLC),
+ #define XLAT_VAL_12 ((unsigned) (ISDN_P_B_L2DSPHDLC))
+ #define XLAT_STR_12 STRINGIFY(ISDN_P_B_L2DSPHDLC)
 /*
 * those two are present in include/linux/mISDNif.h but are not handled during
 * socket creation.
@@ -129,8 +155,116 @@ const struct xlat isdn_protocols[1] = {
  .data = isdn_protocols_xdata,
  .size = ARRAY_SIZE(isdn_protocols_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/itimer_which.h 5.9-0ubuntu2/xlat/itimer_which.h
--- 5.5-3/xlat/itimer_which.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/itimer_which.h	2020-09-24 09:18:44.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data itimer_which_xdata[] = {
  [ITIMER_REAL] = XLAT(ITIMER_REAL),
+ #define XLAT_VAL_0 ((unsigned) (ITIMER_REAL))
+ #define XLAT_STR_0 STRINGIFY(ITIMER_REAL)
  [ITIMER_VIRTUAL] = XLAT(ITIMER_VIRTUAL),
+ #define XLAT_VAL_1 ((unsigned) (ITIMER_VIRTUAL))
+ #define XLAT_STR_1 STRINGIFY(ITIMER_VIRTUAL)
  [ITIMER_PROF] = XLAT(ITIMER_PROF),
+ #define XLAT_VAL_2 ((unsigned) (ITIMER_PROF))
+ #define XLAT_STR_2 STRINGIFY(ITIMER_PROF)
 };
 static
 const struct xlat itimer_which[1] = { {
  .data = itimer_which_xdata,
  .size = ARRAY_SIZE(itimer_which_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/kcm_protocols.h 5.9-0ubuntu2/xlat/kcm_protocols.h
--- 5.5-3/xlat/kcm_protocols.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/kcm_protocols.h	2020-09-24 09:18:44.000000000 +0000
@@ -21,14 +21,28 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data kcm_protocols_xdata[] = {
  [KCMPROTO_CONNECTED] = XLAT(KCMPROTO_CONNECTED),
+ #define XLAT_VAL_0 ((unsigned) (KCMPROTO_CONNECTED))
+ #define XLAT_STR_0 STRINGIFY(KCMPROTO_CONNECTED)
 };
 static
 const struct xlat kcm_protocols[1] = { {
  .data = kcm_protocols_xdata,
  .size = ARRAY_SIZE(kcm_protocols_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/kcmp_types.h 5.9-0ubuntu2/xlat/kcmp_types.h
--- 5.5-3/xlat/kcmp_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/kcmp_types.h	2020-09-24 09:18:44.000000000 +0000
@@ -70,21 +70,105 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data kcmp_types_xdata[] = {
  [KCMP_FILE] = XLAT(KCMP_FILE),
+ #define XLAT_VAL_0 ((unsigned) (KCMP_FILE))
+ #define XLAT_STR_0 STRINGIFY(KCMP_FILE)
  [KCMP_VM] = XLAT(KCMP_VM),
+ #define XLAT_VAL_1 ((unsigned) (KCMP_VM))
+ #define XLAT_STR_1 STRINGIFY(KCMP_VM)
  [KCMP_FILES] = XLAT(KCMP_FILES),
+ #define XLAT_VAL_2 ((unsigned) (KCMP_FILES))
+ #define XLAT_STR_2 STRINGIFY(KCMP_FILES)
  [KCMP_FS] = XLAT(KCMP_FS),
+ #define XLAT_VAL_3 ((unsigned) (KCMP_FS))
+ #define XLAT_STR_3 STRINGIFY(KCMP_FS)
  [KCMP_SIGHAND] = XLAT(KCMP_SIGHAND),
+ #define XLAT_VAL_4 ((unsigned) (KCMP_SIGHAND))
+ #define XLAT_STR_4 STRINGIFY(KCMP_SIGHAND)
  [KCMP_IO] = XLAT(KCMP_IO),
+ #define XLAT_VAL_5 ((unsigned) (KCMP_IO))
+ #define XLAT_STR_5 STRINGIFY(KCMP_IO)
  [KCMP_SYSVSEM] = XLAT(KCMP_SYSVSEM),
+ #define XLAT_VAL_6 ((unsigned) (KCMP_SYSVSEM))
+ #define XLAT_STR_6 STRINGIFY(KCMP_SYSVSEM)
  [KCMP_EPOLL_TFD] = XLAT(KCMP_EPOLL_TFD),
+ #define XLAT_VAL_7 ((unsigned) (KCMP_EPOLL_TFD))
+ #define XLAT_STR_7 STRINGIFY(KCMP_EPOLL_TFD)
 };
 static
 const struct xlat kcmp_types[1] = { {
  .data = kcmp_types_xdata,
  .size = ARRAY_SIZE(kcmp_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/kexec_arch_values.h 5.9-0ubuntu2/xlat/kexec_arch_values.h
--- 5.5-3/xlat/kexec_arch_values.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/kexec_arch_values.h	2020-09-24 09:18:44.000000000 +0000
@@ -112,27 +112,171 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data kexec_arch_values_xdata[] = {
  XLAT(KEXEC_ARCH_DEFAULT),
+ #define XLAT_VAL_0 ((unsigned) (KEXEC_ARCH_DEFAULT))
+ #define XLAT_STR_0 STRINGIFY(KEXEC_ARCH_DEFAULT)
  XLAT(KEXEC_ARCH_386),
+ #define XLAT_VAL_1 ((unsigned) (KEXEC_ARCH_386))
+ #define XLAT_STR_1 STRINGIFY(KEXEC_ARCH_386)
  XLAT(KEXEC_ARCH_68K),
+ #define XLAT_VAL_2 ((unsigned) (KEXEC_ARCH_68K))
+ #define XLAT_STR_2 STRINGIFY(KEXEC_ARCH_68K)
  XLAT(KEXEC_ARCH_PARISC),
+ #define XLAT_VAL_3 ((unsigned) (KEXEC_ARCH_PARISC))
+ #define XLAT_STR_3 STRINGIFY(KEXEC_ARCH_PARISC)
  XLAT(KEXEC_ARCH_X86_64),
+ #define XLAT_VAL_4 ((unsigned) (KEXEC_ARCH_X86_64))
+ #define XLAT_STR_4 STRINGIFY(KEXEC_ARCH_X86_64)
  XLAT(KEXEC_ARCH_PPC),
+ #define XLAT_VAL_5 ((unsigned) (KEXEC_ARCH_PPC))
+ #define XLAT_STR_5 STRINGIFY(KEXEC_ARCH_PPC)
  XLAT(KEXEC_ARCH_PPC64),
+ #define XLAT_VAL_6 ((unsigned) (KEXEC_ARCH_PPC64))
+ #define XLAT_STR_6 STRINGIFY(KEXEC_ARCH_PPC64)
  XLAT(KEXEC_ARCH_IA_64),
+ #define XLAT_VAL_7 ((unsigned) (KEXEC_ARCH_IA_64))
+ #define XLAT_STR_7 STRINGIFY(KEXEC_ARCH_IA_64)
  XLAT(KEXEC_ARCH_ARM),
+ #define XLAT_VAL_8 ((unsigned) (KEXEC_ARCH_ARM))
+ #define XLAT_STR_8 STRINGIFY(KEXEC_ARCH_ARM)
  XLAT(KEXEC_ARCH_S390),
+ #define XLAT_VAL_9 ((unsigned) (KEXEC_ARCH_S390))
+ #define XLAT_STR_9 STRINGIFY(KEXEC_ARCH_S390)
  XLAT(KEXEC_ARCH_SH),
+ #define XLAT_VAL_10 ((unsigned) (KEXEC_ARCH_SH))
+ #define XLAT_STR_10 STRINGIFY(KEXEC_ARCH_SH)
  XLAT(KEXEC_ARCH_MIPS_LE),
+ #define XLAT_VAL_11 ((unsigned) (KEXEC_ARCH_MIPS_LE))
+ #define XLAT_STR_11 STRINGIFY(KEXEC_ARCH_MIPS_LE)
  XLAT(KEXEC_ARCH_MIPS),
+ #define XLAT_VAL_12 ((unsigned) (KEXEC_ARCH_MIPS))
+ #define XLAT_STR_12 STRINGIFY(KEXEC_ARCH_MIPS)
  XLAT(KEXEC_ARCH_AARCH64),
+ #define XLAT_VAL_13 ((unsigned) (KEXEC_ARCH_AARCH64))
+ #define XLAT_STR_13 STRINGIFY(KEXEC_ARCH_AARCH64)
 };
 static
 const struct xlat kexec_arch_values[1] = { {
  .data = kexec_arch_values_xdata,
  .size = ARRAY_SIZE(kexec_arch_values_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/kexec_file_load_flags.h 5.9-0ubuntu2/xlat/kexec_file_load_flags.h
--- 5.5-3/xlat/kexec_file_load_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/kexec_file_load_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data kexec_file_load_flags_xdata[] = {
  XLAT(KEXEC_FILE_UNLOAD),
+ #define XLAT_VAL_0 ((unsigned) (KEXEC_FILE_UNLOAD))
+ #define XLAT_STR_0 STRINGIFY(KEXEC_FILE_UNLOAD)
  XLAT(KEXEC_FILE_ON_CRASH),
+ #define XLAT_VAL_1 ((unsigned) (KEXEC_FILE_ON_CRASH))
+ #define XLAT_STR_1 STRINGIFY(KEXEC_FILE_ON_CRASH)
  XLAT(KEXEC_FILE_NO_INITRAMFS),
+ #define XLAT_VAL_2 ((unsigned) (KEXEC_FILE_NO_INITRAMFS))
+ #define XLAT_STR_2 STRINGIFY(KEXEC_FILE_NO_INITRAMFS)
 };
 static
 const struct xlat kexec_file_load_flags[1] = { {
  .data = kexec_file_load_flags_xdata,
  .size = ARRAY_SIZE(kexec_file_load_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/kexec_load_flags.h 5.9-0ubuntu2/xlat/kexec_load_flags.h
--- 5.5-3/xlat/kexec_load_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/kexec_load_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data kexec_load_flags_xdata[] = {
  XLAT(KEXEC_ON_CRASH),
+ #define XLAT_VAL_0 ((unsigned) (KEXEC_ON_CRASH))
+ #define XLAT_STR_0 STRINGIFY(KEXEC_ON_CRASH)
  XLAT(KEXEC_PRESERVE_CONTEXT),
+ #define XLAT_VAL_1 ((unsigned) (KEXEC_PRESERVE_CONTEXT))
+ #define XLAT_STR_1 STRINGIFY(KEXEC_PRESERVE_CONTEXT)
 };
 static
 const struct xlat kexec_load_flags[1] = { {
  .data = kexec_load_flags_xdata,
  .size = ARRAY_SIZE(kexec_load_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/keyctl_caps0.h 5.9-0ubuntu2/xlat/keyctl_caps0.h
--- 5.5-3/xlat/keyctl_caps0.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/keyctl_caps0.h	2020-09-24 09:18:44.000000000 +0000
@@ -70,21 +70,105 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data keyctl_caps0_xdata[] = {
  XLAT(KEYCTL_CAPS0_CAPABILITIES),
+ #define XLAT_VAL_0 ((unsigned) (KEYCTL_CAPS0_CAPABILITIES))
+ #define XLAT_STR_0 STRINGIFY(KEYCTL_CAPS0_CAPABILITIES)
  XLAT(KEYCTL_CAPS0_PERSISTENT_KEYRINGS),
+ #define XLAT_VAL_1 ((unsigned) (KEYCTL_CAPS0_PERSISTENT_KEYRINGS))
+ #define XLAT_STR_1 STRINGIFY(KEYCTL_CAPS0_PERSISTENT_KEYRINGS)
  XLAT(KEYCTL_CAPS0_DIFFIE_HELLMAN),
+ #define XLAT_VAL_2 ((unsigned) (KEYCTL_CAPS0_DIFFIE_HELLMAN))
+ #define XLAT_STR_2 STRINGIFY(KEYCTL_CAPS0_DIFFIE_HELLMAN)
  XLAT(KEYCTL_CAPS0_PUBLIC_KEY),
+ #define XLAT_VAL_3 ((unsigned) (KEYCTL_CAPS0_PUBLIC_KEY))
+ #define XLAT_STR_3 STRINGIFY(KEYCTL_CAPS0_PUBLIC_KEY)
  XLAT(KEYCTL_CAPS0_BIG_KEY),
+ #define XLAT_VAL_4 ((unsigned) (KEYCTL_CAPS0_BIG_KEY))
+ #define XLAT_STR_4 STRINGIFY(KEYCTL_CAPS0_BIG_KEY)
  XLAT(KEYCTL_CAPS0_INVALIDATE),
+ #define XLAT_VAL_5 ((unsigned) (KEYCTL_CAPS0_INVALIDATE))
+ #define XLAT_STR_5 STRINGIFY(KEYCTL_CAPS0_INVALIDATE)
  XLAT(KEYCTL_CAPS0_RESTRICT_KEYRING),
+ #define XLAT_VAL_6 ((unsigned) (KEYCTL_CAPS0_RESTRICT_KEYRING))
+ #define XLAT_STR_6 STRINGIFY(KEYCTL_CAPS0_RESTRICT_KEYRING)
  XLAT(KEYCTL_CAPS0_MOVE),
+ #define XLAT_VAL_7 ((unsigned) (KEYCTL_CAPS0_MOVE))
+ #define XLAT_STR_7 STRINGIFY(KEYCTL_CAPS0_MOVE)
 };
 static
 const struct xlat keyctl_caps0[1] = { {
  .data = keyctl_caps0_xdata,
  .size = ARRAY_SIZE(keyctl_caps0_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/keyctl_caps1.h 5.9-0ubuntu2/xlat/keyctl_caps1.h
--- 5.5-3/xlat/keyctl_caps1.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/keyctl_caps1.h	2020-09-24 09:18:44.000000000 +0000
@@ -17,6 +17,13 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define KEYCTL_CAPS1_NS_KEY_TAG 0x02
 #endif
+#if defined(KEYCTL_CAPS1_NOTIFICATIONS) || (defined(HAVE_DECL_KEYCTL_CAPS1_NOTIFICATIONS) && HAVE_DECL_KEYCTL_CAPS1_NOTIFICATIONS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((KEYCTL_CAPS1_NOTIFICATIONS) == (0x04), "KEYCTL_CAPS1_NOTIFICATIONS != 0x04");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define KEYCTL_CAPS1_NOTIFICATIONS 0x04
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -28,15 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data keyctl_caps1_xdata[] = {
  XLAT(KEYCTL_CAPS1_NS_KEYRING_NAME),
+ #define XLAT_VAL_0 ((unsigned) (KEYCTL_CAPS1_NS_KEYRING_NAME))
+ #define XLAT_STR_0 STRINGIFY(KEYCTL_CAPS1_NS_KEYRING_NAME)
  XLAT(KEYCTL_CAPS1_NS_KEY_TAG),
+ #define XLAT_VAL_1 ((unsigned) (KEYCTL_CAPS1_NS_KEY_TAG))
+ #define XLAT_STR_1 STRINGIFY(KEYCTL_CAPS1_NS_KEY_TAG)
+ XLAT(KEYCTL_CAPS1_NOTIFICATIONS),
+ #define XLAT_VAL_2 ((unsigned) (KEYCTL_CAPS1_NOTIFICATIONS))
+ #define XLAT_STR_2 STRINGIFY(KEYCTL_CAPS1_NOTIFICATIONS)
 };
 static
 const struct xlat keyctl_caps1[1] = { {
  .data = keyctl_caps1_xdata,
  .size = ARRAY_SIZE(keyctl_caps1_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/keyctl_caps1.in 5.9-0ubuntu2/xlat/keyctl_caps1.in
--- 5.5-3/xlat/keyctl_caps1.in	2020-01-27 13:21:44.000000000 +0000
+++ 5.9-0ubuntu2/xlat/keyctl_caps1.in	2020-06-28 08:00:00.000000000 +0000
@@ -1,2 +1,3 @@
 KEYCTL_CAPS1_NS_KEYRING_NAME	0x01
 KEYCTL_CAPS1_NS_KEY_TAG		0x02
+KEYCTL_CAPS1_NOTIFICATIONS	0x04
diff -pruN 5.5-3/xlat/keyctl_commands.h 5.9-0ubuntu2/xlat/keyctl_commands.h
--- 5.5-3/xlat/keyctl_commands.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/keyctl_commands.h	2020-09-24 09:18:45.000000000 +0000
@@ -227,6 +227,13 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define KEYCTL_CAPABILITIES 31
 #endif
+#if defined(KEYCTL_WATCH_KEY) || (defined(HAVE_DECL_KEYCTL_WATCH_KEY) && HAVE_DECL_KEYCTL_WATCH_KEY)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((KEYCTL_WATCH_KEY) == (32), "KEYCTL_WATCH_KEY != 32");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define KEYCTL_WATCH_KEY 32
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -238,45 +245,380 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data keyctl_commands_xdata[] = {
  [KEYCTL_GET_KEYRING_ID] = XLAT(KEYCTL_GET_KEYRING_ID),
+ #define XLAT_VAL_0 ((unsigned) (KEYCTL_GET_KEYRING_ID))
+ #define XLAT_STR_0 STRINGIFY(KEYCTL_GET_KEYRING_ID)
  [KEYCTL_JOIN_SESSION_KEYRING] = XLAT(KEYCTL_JOIN_SESSION_KEYRING),
+ #define XLAT_VAL_1 ((unsigned) (KEYCTL_JOIN_SESSION_KEYRING))
+ #define XLAT_STR_1 STRINGIFY(KEYCTL_JOIN_SESSION_KEYRING)
  [KEYCTL_UPDATE] = XLAT(KEYCTL_UPDATE),
+ #define XLAT_VAL_2 ((unsigned) (KEYCTL_UPDATE))
+ #define XLAT_STR_2 STRINGIFY(KEYCTL_UPDATE)
  [KEYCTL_REVOKE] = XLAT(KEYCTL_REVOKE),
+ #define XLAT_VAL_3 ((unsigned) (KEYCTL_REVOKE))
+ #define XLAT_STR_3 STRINGIFY(KEYCTL_REVOKE)
  [KEYCTL_CHOWN] = XLAT(KEYCTL_CHOWN),
+ #define XLAT_VAL_4 ((unsigned) (KEYCTL_CHOWN))
+ #define XLAT_STR_4 STRINGIFY(KEYCTL_CHOWN)
  [KEYCTL_SETPERM] = XLAT(KEYCTL_SETPERM),
+ #define XLAT_VAL_5 ((unsigned) (KEYCTL_SETPERM))
+ #define XLAT_STR_5 STRINGIFY(KEYCTL_SETPERM)
  [KEYCTL_DESCRIBE] = XLAT(KEYCTL_DESCRIBE),
+ #define XLAT_VAL_6 ((unsigned) (KEYCTL_DESCRIBE))
+ #define XLAT_STR_6 STRINGIFY(KEYCTL_DESCRIBE)
  [KEYCTL_CLEAR] = XLAT(KEYCTL_CLEAR),
+ #define XLAT_VAL_7 ((unsigned) (KEYCTL_CLEAR))
+ #define XLAT_STR_7 STRINGIFY(KEYCTL_CLEAR)
  [KEYCTL_LINK] = XLAT(KEYCTL_LINK),
+ #define XLAT_VAL_8 ((unsigned) (KEYCTL_LINK))
+ #define XLAT_STR_8 STRINGIFY(KEYCTL_LINK)
  [KEYCTL_UNLINK] = XLAT(KEYCTL_UNLINK),
+ #define XLAT_VAL_9 ((unsigned) (KEYCTL_UNLINK))
+ #define XLAT_STR_9 STRINGIFY(KEYCTL_UNLINK)
  [KEYCTL_SEARCH] = XLAT(KEYCTL_SEARCH),
+ #define XLAT_VAL_10 ((unsigned) (KEYCTL_SEARCH))
+ #define XLAT_STR_10 STRINGIFY(KEYCTL_SEARCH)
  [KEYCTL_READ] = XLAT(KEYCTL_READ),
+ #define XLAT_VAL_11 ((unsigned) (KEYCTL_READ))
+ #define XLAT_STR_11 STRINGIFY(KEYCTL_READ)
  [KEYCTL_INSTANTIATE] = XLAT(KEYCTL_INSTANTIATE),
+ #define XLAT_VAL_12 ((unsigned) (KEYCTL_INSTANTIATE))
+ #define XLAT_STR_12 STRINGIFY(KEYCTL_INSTANTIATE)
  [KEYCTL_NEGATE] = XLAT(KEYCTL_NEGATE),
+ #define XLAT_VAL_13 ((unsigned) (KEYCTL_NEGATE))
+ #define XLAT_STR_13 STRINGIFY(KEYCTL_NEGATE)
  [KEYCTL_SET_REQKEY_KEYRING] = XLAT(KEYCTL_SET_REQKEY_KEYRING),
+ #define XLAT_VAL_14 ((unsigned) (KEYCTL_SET_REQKEY_KEYRING))
+ #define XLAT_STR_14 STRINGIFY(KEYCTL_SET_REQKEY_KEYRING)
  [KEYCTL_SET_TIMEOUT] = XLAT(KEYCTL_SET_TIMEOUT),
+ #define XLAT_VAL_15 ((unsigned) (KEYCTL_SET_TIMEOUT))
+ #define XLAT_STR_15 STRINGIFY(KEYCTL_SET_TIMEOUT)
  [KEYCTL_ASSUME_AUTHORITY] = XLAT(KEYCTL_ASSUME_AUTHORITY),
+ #define XLAT_VAL_16 ((unsigned) (KEYCTL_ASSUME_AUTHORITY))
+ #define XLAT_STR_16 STRINGIFY(KEYCTL_ASSUME_AUTHORITY)
  [KEYCTL_GET_SECURITY] = XLAT(KEYCTL_GET_SECURITY),
+ #define XLAT_VAL_17 ((unsigned) (KEYCTL_GET_SECURITY))
+ #define XLAT_STR_17 STRINGIFY(KEYCTL_GET_SECURITY)
  [KEYCTL_SESSION_TO_PARENT] = XLAT(KEYCTL_SESSION_TO_PARENT),
+ #define XLAT_VAL_18 ((unsigned) (KEYCTL_SESSION_TO_PARENT))
+ #define XLAT_STR_18 STRINGIFY(KEYCTL_SESSION_TO_PARENT)
  [KEYCTL_REJECT] = XLAT(KEYCTL_REJECT),
+ #define XLAT_VAL_19 ((unsigned) (KEYCTL_REJECT))
+ #define XLAT_STR_19 STRINGIFY(KEYCTL_REJECT)
  [KEYCTL_INSTANTIATE_IOV] = XLAT(KEYCTL_INSTANTIATE_IOV),
+ #define XLAT_VAL_20 ((unsigned) (KEYCTL_INSTANTIATE_IOV))
+ #define XLAT_STR_20 STRINGIFY(KEYCTL_INSTANTIATE_IOV)
  [KEYCTL_INVALIDATE] = XLAT(KEYCTL_INVALIDATE),
+ #define XLAT_VAL_21 ((unsigned) (KEYCTL_INVALIDATE))
+ #define XLAT_STR_21 STRINGIFY(KEYCTL_INVALIDATE)
  [KEYCTL_GET_PERSISTENT] = XLAT(KEYCTL_GET_PERSISTENT),
+ #define XLAT_VAL_22 ((unsigned) (KEYCTL_GET_PERSISTENT))
+ #define XLAT_STR_22 STRINGIFY(KEYCTL_GET_PERSISTENT)
  [KEYCTL_DH_COMPUTE] = XLAT(KEYCTL_DH_COMPUTE),
+ #define XLAT_VAL_23 ((unsigned) (KEYCTL_DH_COMPUTE))
+ #define XLAT_STR_23 STRINGIFY(KEYCTL_DH_COMPUTE)
  [KEYCTL_PKEY_QUERY] = XLAT(KEYCTL_PKEY_QUERY),
+ #define XLAT_VAL_24 ((unsigned) (KEYCTL_PKEY_QUERY))
+ #define XLAT_STR_24 STRINGIFY(KEYCTL_PKEY_QUERY)
  [KEYCTL_PKEY_ENCRYPT] = XLAT(KEYCTL_PKEY_ENCRYPT),
+ #define XLAT_VAL_25 ((unsigned) (KEYCTL_PKEY_ENCRYPT))
+ #define XLAT_STR_25 STRINGIFY(KEYCTL_PKEY_ENCRYPT)
  [KEYCTL_PKEY_DECRYPT] = XLAT(KEYCTL_PKEY_DECRYPT),
+ #define XLAT_VAL_26 ((unsigned) (KEYCTL_PKEY_DECRYPT))
+ #define XLAT_STR_26 STRINGIFY(KEYCTL_PKEY_DECRYPT)
  [KEYCTL_PKEY_SIGN] = XLAT(KEYCTL_PKEY_SIGN),
+ #define XLAT_VAL_27 ((unsigned) (KEYCTL_PKEY_SIGN))
+ #define XLAT_STR_27 STRINGIFY(KEYCTL_PKEY_SIGN)
  [KEYCTL_PKEY_VERIFY] = XLAT(KEYCTL_PKEY_VERIFY),
+ #define XLAT_VAL_28 ((unsigned) (KEYCTL_PKEY_VERIFY))
+ #define XLAT_STR_28 STRINGIFY(KEYCTL_PKEY_VERIFY)
  [KEYCTL_RESTRICT_KEYRING] = XLAT(KEYCTL_RESTRICT_KEYRING),
+ #define XLAT_VAL_29 ((unsigned) (KEYCTL_RESTRICT_KEYRING))
+ #define XLAT_STR_29 STRINGIFY(KEYCTL_RESTRICT_KEYRING)
  [KEYCTL_MOVE] = XLAT(KEYCTL_MOVE),
+ #define XLAT_VAL_30 ((unsigned) (KEYCTL_MOVE))
+ #define XLAT_STR_30 STRINGIFY(KEYCTL_MOVE)
  [KEYCTL_CAPABILITIES] = XLAT(KEYCTL_CAPABILITIES),
+ #define XLAT_VAL_31 ((unsigned) (KEYCTL_CAPABILITIES))
+ #define XLAT_STR_31 STRINGIFY(KEYCTL_CAPABILITIES)
+ [KEYCTL_WATCH_KEY] = XLAT(KEYCTL_WATCH_KEY),
+ #define XLAT_VAL_32 ((unsigned) (KEYCTL_WATCH_KEY))
+ #define XLAT_STR_32 STRINGIFY(KEYCTL_WATCH_KEY)
 };
 static
 const struct xlat keyctl_commands[1] = { {
  .data = keyctl_commands_xdata,
  .size = ARRAY_SIZE(keyctl_commands_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/keyctl_commands.in 5.9-0ubuntu2/xlat/keyctl_commands.in
--- 5.5-3/xlat/keyctl_commands.in	2019-08-14 19:05:08.000000000 +0000
+++ 5.9-0ubuntu2/xlat/keyctl_commands.in	2020-06-28 08:00:00.000000000 +0000
@@ -31,3 +31,4 @@ KEYCTL_PKEY_VERIFY 28
 KEYCTL_RESTRICT_KEYRING 29
 KEYCTL_MOVE 30
 KEYCTL_CAPABILITIES 31
+KEYCTL_WATCH_KEY 32
diff -pruN 5.5-3/xlat/keyctl_move_flags.h 5.9-0ubuntu2/xlat/keyctl_move_flags.h
--- 5.5-3/xlat/keyctl_move_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/keyctl_move_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -21,14 +21,28 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data keyctl_move_flags_xdata[] = {
  XLAT(KEYCTL_MOVE_EXCL),
+ #define XLAT_VAL_0 ((unsigned) (KEYCTL_MOVE_EXCL))
+ #define XLAT_STR_0 STRINGIFY(KEYCTL_MOVE_EXCL)
 };
 static
 const struct xlat keyctl_move_flags[1] = { {
  .data = keyctl_move_flags_xdata,
  .size = ARRAY_SIZE(keyctl_move_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/keyctl_pkey_ops.h 5.9-0ubuntu2/xlat/keyctl_pkey_ops.h
--- 5.5-3/xlat/keyctl_pkey_ops.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/keyctl_pkey_ops.h	2020-09-24 09:18:44.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data keyctl_pkey_ops_xdata[] = {
  XLAT(KEYCTL_SUPPORTS_ENCRYPT),
+ #define XLAT_VAL_0 ((unsigned) (KEYCTL_SUPPORTS_ENCRYPT))
+ #define XLAT_STR_0 STRINGIFY(KEYCTL_SUPPORTS_ENCRYPT)
  XLAT(KEYCTL_SUPPORTS_DECRYPT),
+ #define XLAT_VAL_1 ((unsigned) (KEYCTL_SUPPORTS_DECRYPT))
+ #define XLAT_STR_1 STRINGIFY(KEYCTL_SUPPORTS_DECRYPT)
  XLAT(KEYCTL_SUPPORTS_SIGN),
+ #define XLAT_VAL_2 ((unsigned) (KEYCTL_SUPPORTS_SIGN))
+ #define XLAT_STR_2 STRINGIFY(KEYCTL_SUPPORTS_SIGN)
  XLAT(KEYCTL_SUPPORTS_VERIFY),
+ #define XLAT_VAL_3 ((unsigned) (KEYCTL_SUPPORTS_VERIFY))
+ #define XLAT_STR_3 STRINGIFY(KEYCTL_SUPPORTS_VERIFY)
 };
 static
 const struct xlat keyctl_pkey_ops[1] = { {
  .data = keyctl_pkey_ops_xdata,
  .size = ARRAY_SIZE(keyctl_pkey_ops_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/key_perms.h 5.9-0ubuntu2/xlat/key_perms.h
--- 5.5-3/xlat/key_perms.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/key_perms.h	2020-09-24 09:18:45.000000000 +0000
@@ -210,41 +210,325 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data key_perms_xdata[] = {
  XLAT(KEY_POS_VIEW),
+ #define XLAT_VAL_0 ((unsigned) (KEY_POS_VIEW))
+ #define XLAT_STR_0 STRINGIFY(KEY_POS_VIEW)
  XLAT(KEY_POS_READ),
+ #define XLAT_VAL_1 ((unsigned) (KEY_POS_READ))
+ #define XLAT_STR_1 STRINGIFY(KEY_POS_READ)
  XLAT(KEY_POS_WRITE),
+ #define XLAT_VAL_2 ((unsigned) (KEY_POS_WRITE))
+ #define XLAT_STR_2 STRINGIFY(KEY_POS_WRITE)
  XLAT(KEY_POS_SEARCH),
+ #define XLAT_VAL_3 ((unsigned) (KEY_POS_SEARCH))
+ #define XLAT_STR_3 STRINGIFY(KEY_POS_SEARCH)
  XLAT(KEY_POS_LINK),
+ #define XLAT_VAL_4 ((unsigned) (KEY_POS_LINK))
+ #define XLAT_STR_4 STRINGIFY(KEY_POS_LINK)
  XLAT(KEY_POS_SETATTR),
+ #define XLAT_VAL_5 ((unsigned) (KEY_POS_SETATTR))
+ #define XLAT_STR_5 STRINGIFY(KEY_POS_SETATTR)
  XLAT(KEY_POS_ALL),
+ #define XLAT_VAL_6 ((unsigned) (KEY_POS_ALL))
+ #define XLAT_STR_6 STRINGIFY(KEY_POS_ALL)
  XLAT(KEY_USR_VIEW),
+ #define XLAT_VAL_7 ((unsigned) (KEY_USR_VIEW))
+ #define XLAT_STR_7 STRINGIFY(KEY_USR_VIEW)
  XLAT(KEY_USR_READ),
+ #define XLAT_VAL_8 ((unsigned) (KEY_USR_READ))
+ #define XLAT_STR_8 STRINGIFY(KEY_USR_READ)
  XLAT(KEY_USR_WRITE),
+ #define XLAT_VAL_9 ((unsigned) (KEY_USR_WRITE))
+ #define XLAT_STR_9 STRINGIFY(KEY_USR_WRITE)
  XLAT(KEY_USR_SEARCH),
+ #define XLAT_VAL_10 ((unsigned) (KEY_USR_SEARCH))
+ #define XLAT_STR_10 STRINGIFY(KEY_USR_SEARCH)
  XLAT(KEY_USR_LINK),
+ #define XLAT_VAL_11 ((unsigned) (KEY_USR_LINK))
+ #define XLAT_STR_11 STRINGIFY(KEY_USR_LINK)
  XLAT(KEY_USR_SETATTR),
+ #define XLAT_VAL_12 ((unsigned) (KEY_USR_SETATTR))
+ #define XLAT_STR_12 STRINGIFY(KEY_USR_SETATTR)
  XLAT(KEY_USR_ALL),
+ #define XLAT_VAL_13 ((unsigned) (KEY_USR_ALL))
+ #define XLAT_STR_13 STRINGIFY(KEY_USR_ALL)
  XLAT(KEY_GRP_VIEW),
+ #define XLAT_VAL_14 ((unsigned) (KEY_GRP_VIEW))
+ #define XLAT_STR_14 STRINGIFY(KEY_GRP_VIEW)
  XLAT(KEY_GRP_READ),
+ #define XLAT_VAL_15 ((unsigned) (KEY_GRP_READ))
+ #define XLAT_STR_15 STRINGIFY(KEY_GRP_READ)
  XLAT(KEY_GRP_WRITE),
+ #define XLAT_VAL_16 ((unsigned) (KEY_GRP_WRITE))
+ #define XLAT_STR_16 STRINGIFY(KEY_GRP_WRITE)
  XLAT(KEY_GRP_SEARCH),
+ #define XLAT_VAL_17 ((unsigned) (KEY_GRP_SEARCH))
+ #define XLAT_STR_17 STRINGIFY(KEY_GRP_SEARCH)
  XLAT(KEY_GRP_LINK),
+ #define XLAT_VAL_18 ((unsigned) (KEY_GRP_LINK))
+ #define XLAT_STR_18 STRINGIFY(KEY_GRP_LINK)
  XLAT(KEY_GRP_SETATTR),
+ #define XLAT_VAL_19 ((unsigned) (KEY_GRP_SETATTR))
+ #define XLAT_STR_19 STRINGIFY(KEY_GRP_SETATTR)
  XLAT(KEY_GRP_ALL),
+ #define XLAT_VAL_20 ((unsigned) (KEY_GRP_ALL))
+ #define XLAT_STR_20 STRINGIFY(KEY_GRP_ALL)
  XLAT(KEY_OTH_VIEW),
+ #define XLAT_VAL_21 ((unsigned) (KEY_OTH_VIEW))
+ #define XLAT_STR_21 STRINGIFY(KEY_OTH_VIEW)
  XLAT(KEY_OTH_READ),
+ #define XLAT_VAL_22 ((unsigned) (KEY_OTH_READ))
+ #define XLAT_STR_22 STRINGIFY(KEY_OTH_READ)
  XLAT(KEY_OTH_WRITE),
+ #define XLAT_VAL_23 ((unsigned) (KEY_OTH_WRITE))
+ #define XLAT_STR_23 STRINGIFY(KEY_OTH_WRITE)
  XLAT(KEY_OTH_SEARCH),
+ #define XLAT_VAL_24 ((unsigned) (KEY_OTH_SEARCH))
+ #define XLAT_STR_24 STRINGIFY(KEY_OTH_SEARCH)
  XLAT(KEY_OTH_LINK),
+ #define XLAT_VAL_25 ((unsigned) (KEY_OTH_LINK))
+ #define XLAT_STR_25 STRINGIFY(KEY_OTH_LINK)
  XLAT(KEY_OTH_SETATTR),
+ #define XLAT_VAL_26 ((unsigned) (KEY_OTH_SETATTR))
+ #define XLAT_STR_26 STRINGIFY(KEY_OTH_SETATTR)
  XLAT(KEY_OTH_ALL),
+ #define XLAT_VAL_27 ((unsigned) (KEY_OTH_ALL))
+ #define XLAT_STR_27 STRINGIFY(KEY_OTH_ALL)
 };
 static
 const struct xlat key_perms[1] = { {
  .data = key_perms_xdata,
  .size = ARRAY_SIZE(key_perms_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/key_reqkeys.h 5.9-0ubuntu2/xlat/key_reqkeys.h
--- 5.5-3/xlat/key_reqkeys.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/key_reqkeys.h	2020-09-24 09:18:44.000000000 +0000
@@ -77,22 +77,116 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data key_reqkeys_xdata[] = {
  XLAT_TYPE(int, KEY_REQKEY_DEFL_NO_CHANGE),
+ #define XLAT_VAL_0 ((int) (KEY_REQKEY_DEFL_NO_CHANGE))
+ #define XLAT_STR_0 STRINGIFY(KEY_REQKEY_DEFL_NO_CHANGE)
  XLAT_TYPE(int, KEY_REQKEY_DEFL_DEFAULT),
+ #define XLAT_VAL_1 ((int) (KEY_REQKEY_DEFL_DEFAULT))
+ #define XLAT_STR_1 STRINGIFY(KEY_REQKEY_DEFL_DEFAULT)
  XLAT_TYPE(int, KEY_REQKEY_DEFL_THREAD_KEYRING),
+ #define XLAT_VAL_2 ((int) (KEY_REQKEY_DEFL_THREAD_KEYRING))
+ #define XLAT_STR_2 STRINGIFY(KEY_REQKEY_DEFL_THREAD_KEYRING)
  XLAT_TYPE(int, KEY_REQKEY_DEFL_PROCESS_KEYRING),
+ #define XLAT_VAL_3 ((int) (KEY_REQKEY_DEFL_PROCESS_KEYRING))
+ #define XLAT_STR_3 STRINGIFY(KEY_REQKEY_DEFL_PROCESS_KEYRING)
  XLAT_TYPE(int, KEY_REQKEY_DEFL_SESSION_KEYRING),
+ #define XLAT_VAL_4 ((int) (KEY_REQKEY_DEFL_SESSION_KEYRING))
+ #define XLAT_STR_4 STRINGIFY(KEY_REQKEY_DEFL_SESSION_KEYRING)
  XLAT_TYPE(int, KEY_REQKEY_DEFL_USER_KEYRING),
+ #define XLAT_VAL_5 ((int) (KEY_REQKEY_DEFL_USER_KEYRING))
+ #define XLAT_STR_5 STRINGIFY(KEY_REQKEY_DEFL_USER_KEYRING)
  XLAT_TYPE(int, KEY_REQKEY_DEFL_USER_SESSION_KEYRING),
+ #define XLAT_VAL_6 ((int) (KEY_REQKEY_DEFL_USER_SESSION_KEYRING))
+ #define XLAT_STR_6 STRINGIFY(KEY_REQKEY_DEFL_USER_SESSION_KEYRING)
  XLAT_TYPE(int, KEY_REQKEY_DEFL_GROUP_KEYRING),
+ #define XLAT_VAL_7 ((int) (KEY_REQKEY_DEFL_GROUP_KEYRING))
+ #define XLAT_STR_7 STRINGIFY(KEY_REQKEY_DEFL_GROUP_KEYRING)
  XLAT_TYPE(int, KEY_REQKEY_DEFL_REQUESTOR_KEYRING),
+ #define XLAT_VAL_8 ((int) (KEY_REQKEY_DEFL_REQUESTOR_KEYRING))
+ #define XLAT_STR_8 STRINGIFY(KEY_REQKEY_DEFL_REQUESTOR_KEYRING)
 };
 static
 const struct xlat key_reqkeys[1] = { {
  .data = key_reqkeys_xdata,
  .size = ARRAY_SIZE(key_reqkeys_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/key_spec.h 5.9-0ubuntu2/xlat/key_spec.h
--- 5.5-3/xlat/key_spec.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/key_spec.h	2020-09-24 09:18:44.000000000 +0000
@@ -70,21 +70,105 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data key_spec_xdata[] = {
  XLAT_TYPE(int, KEY_SPEC_THREAD_KEYRING),
+ #define XLAT_VAL_0 ((int) (KEY_SPEC_THREAD_KEYRING))
+ #define XLAT_STR_0 STRINGIFY(KEY_SPEC_THREAD_KEYRING)
  XLAT_TYPE(int, KEY_SPEC_PROCESS_KEYRING),
+ #define XLAT_VAL_1 ((int) (KEY_SPEC_PROCESS_KEYRING))
+ #define XLAT_STR_1 STRINGIFY(KEY_SPEC_PROCESS_KEYRING)
  XLAT_TYPE(int, KEY_SPEC_SESSION_KEYRING),
+ #define XLAT_VAL_2 ((int) (KEY_SPEC_SESSION_KEYRING))
+ #define XLAT_STR_2 STRINGIFY(KEY_SPEC_SESSION_KEYRING)
  XLAT_TYPE(int, KEY_SPEC_USER_KEYRING),
+ #define XLAT_VAL_3 ((int) (KEY_SPEC_USER_KEYRING))
+ #define XLAT_STR_3 STRINGIFY(KEY_SPEC_USER_KEYRING)
  XLAT_TYPE(int, KEY_SPEC_USER_SESSION_KEYRING),
+ #define XLAT_VAL_4 ((int) (KEY_SPEC_USER_SESSION_KEYRING))
+ #define XLAT_STR_4 STRINGIFY(KEY_SPEC_USER_SESSION_KEYRING)
  XLAT_TYPE(int, KEY_SPEC_GROUP_KEYRING),
+ #define XLAT_VAL_5 ((int) (KEY_SPEC_GROUP_KEYRING))
+ #define XLAT_STR_5 STRINGIFY(KEY_SPEC_GROUP_KEYRING)
  XLAT_TYPE(int, KEY_SPEC_REQKEY_AUTH_KEY),
+ #define XLAT_VAL_6 ((int) (KEY_SPEC_REQKEY_AUTH_KEY))
+ #define XLAT_STR_6 STRINGIFY(KEY_SPEC_REQKEY_AUTH_KEY)
  XLAT_TYPE(int, KEY_SPEC_REQUESTOR_KEYRING),
+ #define XLAT_VAL_7 ((int) (KEY_SPEC_REQUESTOR_KEYRING))
+ #define XLAT_STR_7 STRINGIFY(KEY_SPEC_REQUESTOR_KEYRING)
 };
 static
 const struct xlat key_spec[1] = { {
  .data = key_spec_xdata,
  .size = ARRAY_SIZE(key_spec_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/kvm_cap.h 5.9-0ubuntu2/xlat/kvm_cap.h
--- 5.5-3/xlat/kvm_cap.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/kvm_cap.h	2020-09-24 09:18:47.000000000 +0000
@@ -1214,6 +1214,69 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define KVM_CAP_ARM_INJECT_EXT_DABT 178
 #endif
+#if defined(KVM_CAP_S390_VCPU_RESETS) || (defined(HAVE_DECL_KVM_CAP_S390_VCPU_RESETS) && HAVE_DECL_KVM_CAP_S390_VCPU_RESETS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((KVM_CAP_S390_VCPU_RESETS) == (179), "KVM_CAP_S390_VCPU_RESETS != 179");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define KVM_CAP_S390_VCPU_RESETS 179
+#endif
+#if defined(KVM_CAP_S390_PROTECTED) || (defined(HAVE_DECL_KVM_CAP_S390_PROTECTED) && HAVE_DECL_KVM_CAP_S390_PROTECTED)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((KVM_CAP_S390_PROTECTED) == (180), "KVM_CAP_S390_PROTECTED != 180");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define KVM_CAP_S390_PROTECTED 180
+#endif
+#if defined(KVM_CAP_PPC_SECURE_GUEST) || (defined(HAVE_DECL_KVM_CAP_PPC_SECURE_GUEST) && HAVE_DECL_KVM_CAP_PPC_SECURE_GUEST)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((KVM_CAP_PPC_SECURE_GUEST) == (181), "KVM_CAP_PPC_SECURE_GUEST != 181");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define KVM_CAP_PPC_SECURE_GUEST 181
+#endif
+#if defined(KVM_CAP_HALT_POLL) || (defined(HAVE_DECL_KVM_CAP_HALT_POLL) && HAVE_DECL_KVM_CAP_HALT_POLL)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((KVM_CAP_HALT_POLL) == (182), "KVM_CAP_HALT_POLL != 182");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define KVM_CAP_HALT_POLL 182
+#endif
+#if defined(KVM_CAP_ASYNC_PF_INT) || (defined(HAVE_DECL_KVM_CAP_ASYNC_PF_INT) && HAVE_DECL_KVM_CAP_ASYNC_PF_INT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((KVM_CAP_ASYNC_PF_INT) == (183), "KVM_CAP_ASYNC_PF_INT != 183");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define KVM_CAP_ASYNC_PF_INT 183
+#endif
+#if defined(KVM_CAP_LAST_CPU) || (defined(HAVE_DECL_KVM_CAP_LAST_CPU) && HAVE_DECL_KVM_CAP_LAST_CPU)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((KVM_CAP_LAST_CPU) == (184), "KVM_CAP_LAST_CPU != 184");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define KVM_CAP_LAST_CPU 184
+#endif
+#if defined(KVM_CAP_SMALLER_MAXPHYADDR) || (defined(HAVE_DECL_KVM_CAP_SMALLER_MAXPHYADDR) && HAVE_DECL_KVM_CAP_SMALLER_MAXPHYADDR)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((KVM_CAP_SMALLER_MAXPHYADDR) == (185), "KVM_CAP_SMALLER_MAXPHYADDR != 185");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define KVM_CAP_SMALLER_MAXPHYADDR 185
+#endif
+#if defined(KVM_CAP_S390_DIAG318) || (defined(HAVE_DECL_KVM_CAP_S390_DIAG318) && HAVE_DECL_KVM_CAP_S390_DIAG318)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((KVM_CAP_S390_DIAG318) == (186), "KVM_CAP_S390_DIAG318 != 186");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define KVM_CAP_S390_DIAG318 186
+#endif
+#if defined(KVM_CAP_STEAL_TIME) || (defined(HAVE_DECL_KVM_CAP_STEAL_TIME) && HAVE_DECL_KVM_CAP_STEAL_TIME)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((KVM_CAP_STEAL_TIME) == (187), "KVM_CAP_STEAL_TIME != 187");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define KVM_CAP_STEAL_TIME 187
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -1225,186 +1288,2019 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data kvm_cap_xdata[] = {
  [KVM_CAP_IRQCHIP] = XLAT(KVM_CAP_IRQCHIP),
+ #define XLAT_VAL_0 ((unsigned) (KVM_CAP_IRQCHIP))
+ #define XLAT_STR_0 STRINGIFY(KVM_CAP_IRQCHIP)
  [KVM_CAP_HLT] = XLAT(KVM_CAP_HLT),
+ #define XLAT_VAL_1 ((unsigned) (KVM_CAP_HLT))
+ #define XLAT_STR_1 STRINGIFY(KVM_CAP_HLT)
  [KVM_CAP_MMU_SHADOW_CACHE_CONTROL] = XLAT(KVM_CAP_MMU_SHADOW_CACHE_CONTROL),
+ #define XLAT_VAL_2 ((unsigned) (KVM_CAP_MMU_SHADOW_CACHE_CONTROL))
+ #define XLAT_STR_2 STRINGIFY(KVM_CAP_MMU_SHADOW_CACHE_CONTROL)
  [KVM_CAP_USER_MEMORY] = XLAT(KVM_CAP_USER_MEMORY),
+ #define XLAT_VAL_3 ((unsigned) (KVM_CAP_USER_MEMORY))
+ #define XLAT_STR_3 STRINGIFY(KVM_CAP_USER_MEMORY)
  [KVM_CAP_SET_TSS_ADDR] = XLAT(KVM_CAP_SET_TSS_ADDR),
+ #define XLAT_VAL_4 ((unsigned) (KVM_CAP_SET_TSS_ADDR))
+ #define XLAT_STR_4 STRINGIFY(KVM_CAP_SET_TSS_ADDR)
  [KVM_CAP_VAPIC] = XLAT(KVM_CAP_VAPIC),
+ #define XLAT_VAL_5 ((unsigned) (KVM_CAP_VAPIC))
+ #define XLAT_STR_5 STRINGIFY(KVM_CAP_VAPIC)
  [KVM_CAP_EXT_CPUID] = XLAT(KVM_CAP_EXT_CPUID),
+ #define XLAT_VAL_6 ((unsigned) (KVM_CAP_EXT_CPUID))
+ #define XLAT_STR_6 STRINGIFY(KVM_CAP_EXT_CPUID)
  [KVM_CAP_CLOCKSOURCE] = XLAT(KVM_CAP_CLOCKSOURCE),
+ #define XLAT_VAL_7 ((unsigned) (KVM_CAP_CLOCKSOURCE))
+ #define XLAT_STR_7 STRINGIFY(KVM_CAP_CLOCKSOURCE)
  [KVM_CAP_NR_VCPUS] = XLAT(KVM_CAP_NR_VCPUS),
+ #define XLAT_VAL_8 ((unsigned) (KVM_CAP_NR_VCPUS))
+ #define XLAT_STR_8 STRINGIFY(KVM_CAP_NR_VCPUS)
  [KVM_CAP_NR_MEMSLOTS] = XLAT(KVM_CAP_NR_MEMSLOTS),
+ #define XLAT_VAL_9 ((unsigned) (KVM_CAP_NR_MEMSLOTS))
+ #define XLAT_STR_9 STRINGIFY(KVM_CAP_NR_MEMSLOTS)
  [KVM_CAP_PIT] = XLAT(KVM_CAP_PIT),
+ #define XLAT_VAL_10 ((unsigned) (KVM_CAP_PIT))
+ #define XLAT_STR_10 STRINGIFY(KVM_CAP_PIT)
  [KVM_CAP_NOP_IO_DELAY] = XLAT(KVM_CAP_NOP_IO_DELAY),
+ #define XLAT_VAL_11 ((unsigned) (KVM_CAP_NOP_IO_DELAY))
+ #define XLAT_STR_11 STRINGIFY(KVM_CAP_NOP_IO_DELAY)
  [KVM_CAP_PV_MMU] = XLAT(KVM_CAP_PV_MMU),
+ #define XLAT_VAL_12 ((unsigned) (KVM_CAP_PV_MMU))
+ #define XLAT_STR_12 STRINGIFY(KVM_CAP_PV_MMU)
  [KVM_CAP_MP_STATE] = XLAT(KVM_CAP_MP_STATE),
+ #define XLAT_VAL_13 ((unsigned) (KVM_CAP_MP_STATE))
+ #define XLAT_STR_13 STRINGIFY(KVM_CAP_MP_STATE)
  [KVM_CAP_COALESCED_MMIO] = XLAT(KVM_CAP_COALESCED_MMIO),
+ #define XLAT_VAL_14 ((unsigned) (KVM_CAP_COALESCED_MMIO))
+ #define XLAT_STR_14 STRINGIFY(KVM_CAP_COALESCED_MMIO)
  [KVM_CAP_SYNC_MMU] = XLAT(KVM_CAP_SYNC_MMU),
+ #define XLAT_VAL_15 ((unsigned) (KVM_CAP_SYNC_MMU))
+ #define XLAT_STR_15 STRINGIFY(KVM_CAP_SYNC_MMU)
  [KVM_CAP_IOMMU] = XLAT(KVM_CAP_IOMMU),
+ #define XLAT_VAL_16 ((unsigned) (KVM_CAP_IOMMU))
+ #define XLAT_STR_16 STRINGIFY(KVM_CAP_IOMMU)
  [KVM_CAP_DESTROY_MEMORY_REGION_WORKS] = XLAT(KVM_CAP_DESTROY_MEMORY_REGION_WORKS),
+ #define XLAT_VAL_17 ((unsigned) (KVM_CAP_DESTROY_MEMORY_REGION_WORKS))
+ #define XLAT_STR_17 STRINGIFY(KVM_CAP_DESTROY_MEMORY_REGION_WORKS)
  [KVM_CAP_USER_NMI] = XLAT(KVM_CAP_USER_NMI),
+ #define XLAT_VAL_18 ((unsigned) (KVM_CAP_USER_NMI))
+ #define XLAT_STR_18 STRINGIFY(KVM_CAP_USER_NMI)
  [KVM_CAP_SET_GUEST_DEBUG] = XLAT(KVM_CAP_SET_GUEST_DEBUG),
+ #define XLAT_VAL_19 ((unsigned) (KVM_CAP_SET_GUEST_DEBUG))
+ #define XLAT_STR_19 STRINGIFY(KVM_CAP_SET_GUEST_DEBUG)
  [KVM_CAP_REINJECT_CONTROL] = XLAT(KVM_CAP_REINJECT_CONTROL),
+ #define XLAT_VAL_20 ((unsigned) (KVM_CAP_REINJECT_CONTROL))
+ #define XLAT_STR_20 STRINGIFY(KVM_CAP_REINJECT_CONTROL)
  [KVM_CAP_IRQ_ROUTING] = XLAT(KVM_CAP_IRQ_ROUTING),
+ #define XLAT_VAL_21 ((unsigned) (KVM_CAP_IRQ_ROUTING))
+ #define XLAT_STR_21 STRINGIFY(KVM_CAP_IRQ_ROUTING)
  [KVM_CAP_IRQ_INJECT_STATUS] = XLAT(KVM_CAP_IRQ_INJECT_STATUS),
+ #define XLAT_VAL_22 ((unsigned) (KVM_CAP_IRQ_INJECT_STATUS))
+ #define XLAT_STR_22 STRINGIFY(KVM_CAP_IRQ_INJECT_STATUS)
  [KVM_CAP_ASSIGN_DEV_IRQ] = XLAT(KVM_CAP_ASSIGN_DEV_IRQ),
+ #define XLAT_VAL_23 ((unsigned) (KVM_CAP_ASSIGN_DEV_IRQ))
+ #define XLAT_STR_23 STRINGIFY(KVM_CAP_ASSIGN_DEV_IRQ)
  [KVM_CAP_JOIN_MEMORY_REGIONS_WORKS] = XLAT(KVM_CAP_JOIN_MEMORY_REGIONS_WORKS),
+ #define XLAT_VAL_24 ((unsigned) (KVM_CAP_JOIN_MEMORY_REGIONS_WORKS))
+ #define XLAT_STR_24 STRINGIFY(KVM_CAP_JOIN_MEMORY_REGIONS_WORKS)
  [KVM_CAP_MCE] = XLAT(KVM_CAP_MCE),
+ #define XLAT_VAL_25 ((unsigned) (KVM_CAP_MCE))
+ #define XLAT_STR_25 STRINGIFY(KVM_CAP_MCE)
  [KVM_CAP_IRQFD] = XLAT(KVM_CAP_IRQFD),
+ #define XLAT_VAL_26 ((unsigned) (KVM_CAP_IRQFD))
+ #define XLAT_STR_26 STRINGIFY(KVM_CAP_IRQFD)
  [KVM_CAP_PIT2] = XLAT(KVM_CAP_PIT2),
+ #define XLAT_VAL_27 ((unsigned) (KVM_CAP_PIT2))
+ #define XLAT_STR_27 STRINGIFY(KVM_CAP_PIT2)
  [KVM_CAP_SET_BOOT_CPU_ID] = XLAT(KVM_CAP_SET_BOOT_CPU_ID),
+ #define XLAT_VAL_28 ((unsigned) (KVM_CAP_SET_BOOT_CPU_ID))
+ #define XLAT_STR_28 STRINGIFY(KVM_CAP_SET_BOOT_CPU_ID)
  [KVM_CAP_PIT_STATE2] = XLAT(KVM_CAP_PIT_STATE2),
+ #define XLAT_VAL_29 ((unsigned) (KVM_CAP_PIT_STATE2))
+ #define XLAT_STR_29 STRINGIFY(KVM_CAP_PIT_STATE2)
  [KVM_CAP_IOEVENTFD] = XLAT(KVM_CAP_IOEVENTFD),
+ #define XLAT_VAL_30 ((unsigned) (KVM_CAP_IOEVENTFD))
+ #define XLAT_STR_30 STRINGIFY(KVM_CAP_IOEVENTFD)
  [KVM_CAP_SET_IDENTITY_MAP_ADDR] = XLAT(KVM_CAP_SET_IDENTITY_MAP_ADDR),
+ #define XLAT_VAL_31 ((unsigned) (KVM_CAP_SET_IDENTITY_MAP_ADDR))
+ #define XLAT_STR_31 STRINGIFY(KVM_CAP_SET_IDENTITY_MAP_ADDR)
  [KVM_CAP_XEN_HVM] = XLAT(KVM_CAP_XEN_HVM),
+ #define XLAT_VAL_32 ((unsigned) (KVM_CAP_XEN_HVM))
+ #define XLAT_STR_32 STRINGIFY(KVM_CAP_XEN_HVM)
  [KVM_CAP_ADJUST_CLOCK] = XLAT(KVM_CAP_ADJUST_CLOCK),
+ #define XLAT_VAL_33 ((unsigned) (KVM_CAP_ADJUST_CLOCK))
+ #define XLAT_STR_33 STRINGIFY(KVM_CAP_ADJUST_CLOCK)
  [KVM_CAP_INTERNAL_ERROR_DATA] = XLAT(KVM_CAP_INTERNAL_ERROR_DATA),
+ #define XLAT_VAL_34 ((unsigned) (KVM_CAP_INTERNAL_ERROR_DATA))
+ #define XLAT_STR_34 STRINGIFY(KVM_CAP_INTERNAL_ERROR_DATA)
  [KVM_CAP_VCPU_EVENTS] = XLAT(KVM_CAP_VCPU_EVENTS),
+ #define XLAT_VAL_35 ((unsigned) (KVM_CAP_VCPU_EVENTS))
+ #define XLAT_STR_35 STRINGIFY(KVM_CAP_VCPU_EVENTS)
  [KVM_CAP_S390_PSW] = XLAT(KVM_CAP_S390_PSW),
+ #define XLAT_VAL_36 ((unsigned) (KVM_CAP_S390_PSW))
+ #define XLAT_STR_36 STRINGIFY(KVM_CAP_S390_PSW)
  [KVM_CAP_PPC_SEGSTATE] = XLAT(KVM_CAP_PPC_SEGSTATE),
+ #define XLAT_VAL_37 ((unsigned) (KVM_CAP_PPC_SEGSTATE))
+ #define XLAT_STR_37 STRINGIFY(KVM_CAP_PPC_SEGSTATE)
  [KVM_CAP_HYPERV] = XLAT(KVM_CAP_HYPERV),
+ #define XLAT_VAL_38 ((unsigned) (KVM_CAP_HYPERV))
+ #define XLAT_STR_38 STRINGIFY(KVM_CAP_HYPERV)
  [KVM_CAP_HYPERV_VAPIC] = XLAT(KVM_CAP_HYPERV_VAPIC),
+ #define XLAT_VAL_39 ((unsigned) (KVM_CAP_HYPERV_VAPIC))
+ #define XLAT_STR_39 STRINGIFY(KVM_CAP_HYPERV_VAPIC)
  [KVM_CAP_HYPERV_SPIN] = XLAT(KVM_CAP_HYPERV_SPIN),
+ #define XLAT_VAL_40 ((unsigned) (KVM_CAP_HYPERV_SPIN))
+ #define XLAT_STR_40 STRINGIFY(KVM_CAP_HYPERV_SPIN)
  [KVM_CAP_PCI_SEGMENT] = XLAT(KVM_CAP_PCI_SEGMENT),
+ #define XLAT_VAL_41 ((unsigned) (KVM_CAP_PCI_SEGMENT))
+ #define XLAT_STR_41 STRINGIFY(KVM_CAP_PCI_SEGMENT)
  [KVM_CAP_PPC_PAIRED_SINGLES] = XLAT(KVM_CAP_PPC_PAIRED_SINGLES),
+ #define XLAT_VAL_42 ((unsigned) (KVM_CAP_PPC_PAIRED_SINGLES))
+ #define XLAT_STR_42 STRINGIFY(KVM_CAP_PPC_PAIRED_SINGLES)
  [KVM_CAP_INTR_SHADOW] = XLAT(KVM_CAP_INTR_SHADOW),
+ #define XLAT_VAL_43 ((unsigned) (KVM_CAP_INTR_SHADOW))
+ #define XLAT_STR_43 STRINGIFY(KVM_CAP_INTR_SHADOW)
  [KVM_CAP_DEBUGREGS] = XLAT(KVM_CAP_DEBUGREGS),
+ #define XLAT_VAL_44 ((unsigned) (KVM_CAP_DEBUGREGS))
+ #define XLAT_STR_44 STRINGIFY(KVM_CAP_DEBUGREGS)
  [KVM_CAP_X86_ROBUST_SINGLESTEP] = XLAT(KVM_CAP_X86_ROBUST_SINGLESTEP),
+ #define XLAT_VAL_45 ((unsigned) (KVM_CAP_X86_ROBUST_SINGLESTEP))
+ #define XLAT_STR_45 STRINGIFY(KVM_CAP_X86_ROBUST_SINGLESTEP)
  [KVM_CAP_PPC_OSI] = XLAT(KVM_CAP_PPC_OSI),
+ #define XLAT_VAL_46 ((unsigned) (KVM_CAP_PPC_OSI))
+ #define XLAT_STR_46 STRINGIFY(KVM_CAP_PPC_OSI)
  [KVM_CAP_PPC_UNSET_IRQ] = XLAT(KVM_CAP_PPC_UNSET_IRQ),
+ #define XLAT_VAL_47 ((unsigned) (KVM_CAP_PPC_UNSET_IRQ))
+ #define XLAT_STR_47 STRINGIFY(KVM_CAP_PPC_UNSET_IRQ)
  [KVM_CAP_ENABLE_CAP] = XLAT(KVM_CAP_ENABLE_CAP),
+ #define XLAT_VAL_48 ((unsigned) (KVM_CAP_ENABLE_CAP))
+ #define XLAT_STR_48 STRINGIFY(KVM_CAP_ENABLE_CAP)
  [KVM_CAP_XSAVE] = XLAT(KVM_CAP_XSAVE),
+ #define XLAT_VAL_49 ((unsigned) (KVM_CAP_XSAVE))
+ #define XLAT_STR_49 STRINGIFY(KVM_CAP_XSAVE)
  [KVM_CAP_XCRS] = XLAT(KVM_CAP_XCRS),
+ #define XLAT_VAL_50 ((unsigned) (KVM_CAP_XCRS))
+ #define XLAT_STR_50 STRINGIFY(KVM_CAP_XCRS)
  [KVM_CAP_PPC_GET_PVINFO] = XLAT(KVM_CAP_PPC_GET_PVINFO),
+ #define XLAT_VAL_51 ((unsigned) (KVM_CAP_PPC_GET_PVINFO))
+ #define XLAT_STR_51 STRINGIFY(KVM_CAP_PPC_GET_PVINFO)
  [KVM_CAP_PPC_IRQ_LEVEL] = XLAT(KVM_CAP_PPC_IRQ_LEVEL),
+ #define XLAT_VAL_52 ((unsigned) (KVM_CAP_PPC_IRQ_LEVEL))
+ #define XLAT_STR_52 STRINGIFY(KVM_CAP_PPC_IRQ_LEVEL)
  [KVM_CAP_ASYNC_PF] = XLAT(KVM_CAP_ASYNC_PF),
+ #define XLAT_VAL_53 ((unsigned) (KVM_CAP_ASYNC_PF))
+ #define XLAT_STR_53 STRINGIFY(KVM_CAP_ASYNC_PF)
  [KVM_CAP_TSC_CONTROL] = XLAT(KVM_CAP_TSC_CONTROL),
+ #define XLAT_VAL_54 ((unsigned) (KVM_CAP_TSC_CONTROL))
+ #define XLAT_STR_54 STRINGIFY(KVM_CAP_TSC_CONTROL)
  [KVM_CAP_GET_TSC_KHZ] = XLAT(KVM_CAP_GET_TSC_KHZ),
+ #define XLAT_VAL_55 ((unsigned) (KVM_CAP_GET_TSC_KHZ))
+ #define XLAT_STR_55 STRINGIFY(KVM_CAP_GET_TSC_KHZ)
  [KVM_CAP_PPC_BOOKE_SREGS] = XLAT(KVM_CAP_PPC_BOOKE_SREGS),
+ #define XLAT_VAL_56 ((unsigned) (KVM_CAP_PPC_BOOKE_SREGS))
+ #define XLAT_STR_56 STRINGIFY(KVM_CAP_PPC_BOOKE_SREGS)
  [KVM_CAP_SPAPR_TCE] = XLAT(KVM_CAP_SPAPR_TCE),
+ #define XLAT_VAL_57 ((unsigned) (KVM_CAP_SPAPR_TCE))
+ #define XLAT_STR_57 STRINGIFY(KVM_CAP_SPAPR_TCE)
  [KVM_CAP_PPC_SMT] = XLAT(KVM_CAP_PPC_SMT),
+ #define XLAT_VAL_58 ((unsigned) (KVM_CAP_PPC_SMT))
+ #define XLAT_STR_58 STRINGIFY(KVM_CAP_PPC_SMT)
  [KVM_CAP_PPC_RMA] = XLAT(KVM_CAP_PPC_RMA),
+ #define XLAT_VAL_59 ((unsigned) (KVM_CAP_PPC_RMA))
+ #define XLAT_STR_59 STRINGIFY(KVM_CAP_PPC_RMA)
  [KVM_CAP_MAX_VCPUS] = XLAT(KVM_CAP_MAX_VCPUS),
+ #define XLAT_VAL_60 ((unsigned) (KVM_CAP_MAX_VCPUS))
+ #define XLAT_STR_60 STRINGIFY(KVM_CAP_MAX_VCPUS)
  [KVM_CAP_PPC_HIOR] = XLAT(KVM_CAP_PPC_HIOR),
+ #define XLAT_VAL_61 ((unsigned) (KVM_CAP_PPC_HIOR))
+ #define XLAT_STR_61 STRINGIFY(KVM_CAP_PPC_HIOR)
  [KVM_CAP_PPC_PAPR] = XLAT(KVM_CAP_PPC_PAPR),
+ #define XLAT_VAL_62 ((unsigned) (KVM_CAP_PPC_PAPR))
+ #define XLAT_STR_62 STRINGIFY(KVM_CAP_PPC_PAPR)
  [KVM_CAP_SW_TLB] = XLAT(KVM_CAP_SW_TLB),
+ #define XLAT_VAL_63 ((unsigned) (KVM_CAP_SW_TLB))
+ #define XLAT_STR_63 STRINGIFY(KVM_CAP_SW_TLB)
  [KVM_CAP_ONE_REG] = XLAT(KVM_CAP_ONE_REG),
+ #define XLAT_VAL_64 ((unsigned) (KVM_CAP_ONE_REG))
+ #define XLAT_STR_64 STRINGIFY(KVM_CAP_ONE_REG)
  [KVM_CAP_S390_GMAP] = XLAT(KVM_CAP_S390_GMAP),
+ #define XLAT_VAL_65 ((unsigned) (KVM_CAP_S390_GMAP))
+ #define XLAT_STR_65 STRINGIFY(KVM_CAP_S390_GMAP)
  [KVM_CAP_TSC_DEADLINE_TIMER] = XLAT(KVM_CAP_TSC_DEADLINE_TIMER),
+ #define XLAT_VAL_66 ((unsigned) (KVM_CAP_TSC_DEADLINE_TIMER))
+ #define XLAT_STR_66 STRINGIFY(KVM_CAP_TSC_DEADLINE_TIMER)
  [KVM_CAP_S390_UCONTROL] = XLAT(KVM_CAP_S390_UCONTROL),
+ #define XLAT_VAL_67 ((unsigned) (KVM_CAP_S390_UCONTROL))
+ #define XLAT_STR_67 STRINGIFY(KVM_CAP_S390_UCONTROL)
  [KVM_CAP_SYNC_REGS] = XLAT(KVM_CAP_SYNC_REGS),
+ #define XLAT_VAL_68 ((unsigned) (KVM_CAP_SYNC_REGS))
+ #define XLAT_STR_68 STRINGIFY(KVM_CAP_SYNC_REGS)
  [KVM_CAP_PCI_2_3] = XLAT(KVM_CAP_PCI_2_3),
+ #define XLAT_VAL_69 ((unsigned) (KVM_CAP_PCI_2_3))
+ #define XLAT_STR_69 STRINGIFY(KVM_CAP_PCI_2_3)
  [KVM_CAP_KVMCLOCK_CTRL] = XLAT(KVM_CAP_KVMCLOCK_CTRL),
+ #define XLAT_VAL_70 ((unsigned) (KVM_CAP_KVMCLOCK_CTRL))
+ #define XLAT_STR_70 STRINGIFY(KVM_CAP_KVMCLOCK_CTRL)
  [KVM_CAP_SIGNAL_MSI] = XLAT(KVM_CAP_SIGNAL_MSI),
+ #define XLAT_VAL_71 ((unsigned) (KVM_CAP_SIGNAL_MSI))
+ #define XLAT_STR_71 STRINGIFY(KVM_CAP_SIGNAL_MSI)
  [KVM_CAP_PPC_GET_SMMU_INFO] = XLAT(KVM_CAP_PPC_GET_SMMU_INFO),
+ #define XLAT_VAL_72 ((unsigned) (KVM_CAP_PPC_GET_SMMU_INFO))
+ #define XLAT_STR_72 STRINGIFY(KVM_CAP_PPC_GET_SMMU_INFO)
  [KVM_CAP_S390_COW] = XLAT(KVM_CAP_S390_COW),
+ #define XLAT_VAL_73 ((unsigned) (KVM_CAP_S390_COW))
+ #define XLAT_STR_73 STRINGIFY(KVM_CAP_S390_COW)
  [KVM_CAP_PPC_ALLOC_HTAB] = XLAT(KVM_CAP_PPC_ALLOC_HTAB),
+ #define XLAT_VAL_74 ((unsigned) (KVM_CAP_PPC_ALLOC_HTAB))
+ #define XLAT_STR_74 STRINGIFY(KVM_CAP_PPC_ALLOC_HTAB)
  [KVM_CAP_READONLY_MEM] = XLAT(KVM_CAP_READONLY_MEM),
+ #define XLAT_VAL_75 ((unsigned) (KVM_CAP_READONLY_MEM))
+ #define XLAT_STR_75 STRINGIFY(KVM_CAP_READONLY_MEM)
  [KVM_CAP_IRQFD_RESAMPLE] = XLAT(KVM_CAP_IRQFD_RESAMPLE),
+ #define XLAT_VAL_76 ((unsigned) (KVM_CAP_IRQFD_RESAMPLE))
+ #define XLAT_STR_76 STRINGIFY(KVM_CAP_IRQFD_RESAMPLE)
  [KVM_CAP_PPC_BOOKE_WATCHDOG] = XLAT(KVM_CAP_PPC_BOOKE_WATCHDOG),
+ #define XLAT_VAL_77 ((unsigned) (KVM_CAP_PPC_BOOKE_WATCHDOG))
+ #define XLAT_STR_77 STRINGIFY(KVM_CAP_PPC_BOOKE_WATCHDOG)
  [KVM_CAP_PPC_HTAB_FD] = XLAT(KVM_CAP_PPC_HTAB_FD),
+ #define XLAT_VAL_78 ((unsigned) (KVM_CAP_PPC_HTAB_FD))
+ #define XLAT_STR_78 STRINGIFY(KVM_CAP_PPC_HTAB_FD)
  [KVM_CAP_S390_CSS_SUPPORT] = XLAT(KVM_CAP_S390_CSS_SUPPORT),
+ #define XLAT_VAL_79 ((unsigned) (KVM_CAP_S390_CSS_SUPPORT))
+ #define XLAT_STR_79 STRINGIFY(KVM_CAP_S390_CSS_SUPPORT)
  [KVM_CAP_PPC_EPR] = XLAT(KVM_CAP_PPC_EPR),
+ #define XLAT_VAL_80 ((unsigned) (KVM_CAP_PPC_EPR))
+ #define XLAT_STR_80 STRINGIFY(KVM_CAP_PPC_EPR)
  [KVM_CAP_ARM_PSCI] = XLAT(KVM_CAP_ARM_PSCI),
+ #define XLAT_VAL_81 ((unsigned) (KVM_CAP_ARM_PSCI))
+ #define XLAT_STR_81 STRINGIFY(KVM_CAP_ARM_PSCI)
  [KVM_CAP_ARM_SET_DEVICE_ADDR] = XLAT(KVM_CAP_ARM_SET_DEVICE_ADDR),
+ #define XLAT_VAL_82 ((unsigned) (KVM_CAP_ARM_SET_DEVICE_ADDR))
+ #define XLAT_STR_82 STRINGIFY(KVM_CAP_ARM_SET_DEVICE_ADDR)
  [KVM_CAP_DEVICE_CTRL] = XLAT(KVM_CAP_DEVICE_CTRL),
+ #define XLAT_VAL_83 ((unsigned) (KVM_CAP_DEVICE_CTRL))
+ #define XLAT_STR_83 STRINGIFY(KVM_CAP_DEVICE_CTRL)
  [KVM_CAP_IRQ_MPIC] = XLAT(KVM_CAP_IRQ_MPIC),
+ #define XLAT_VAL_84 ((unsigned) (KVM_CAP_IRQ_MPIC))
+ #define XLAT_STR_84 STRINGIFY(KVM_CAP_IRQ_MPIC)
  [KVM_CAP_PPC_RTAS] = XLAT(KVM_CAP_PPC_RTAS),
+ #define XLAT_VAL_85 ((unsigned) (KVM_CAP_PPC_RTAS))
+ #define XLAT_STR_85 STRINGIFY(KVM_CAP_PPC_RTAS)
  [KVM_CAP_IRQ_XICS] = XLAT(KVM_CAP_IRQ_XICS),
+ #define XLAT_VAL_86 ((unsigned) (KVM_CAP_IRQ_XICS))
+ #define XLAT_STR_86 STRINGIFY(KVM_CAP_IRQ_XICS)
  [KVM_CAP_ARM_EL1_32BIT] = XLAT(KVM_CAP_ARM_EL1_32BIT),
+ #define XLAT_VAL_87 ((unsigned) (KVM_CAP_ARM_EL1_32BIT))
+ #define XLAT_STR_87 STRINGIFY(KVM_CAP_ARM_EL1_32BIT)
  [KVM_CAP_SPAPR_MULTITCE] = XLAT(KVM_CAP_SPAPR_MULTITCE),
+ #define XLAT_VAL_88 ((unsigned) (KVM_CAP_SPAPR_MULTITCE))
+ #define XLAT_STR_88 STRINGIFY(KVM_CAP_SPAPR_MULTITCE)
  [KVM_CAP_EXT_EMUL_CPUID] = XLAT(KVM_CAP_EXT_EMUL_CPUID),
+ #define XLAT_VAL_89 ((unsigned) (KVM_CAP_EXT_EMUL_CPUID))
+ #define XLAT_STR_89 STRINGIFY(KVM_CAP_EXT_EMUL_CPUID)
  [KVM_CAP_HYPERV_TIME] = XLAT(KVM_CAP_HYPERV_TIME),
+ #define XLAT_VAL_90 ((unsigned) (KVM_CAP_HYPERV_TIME))
+ #define XLAT_STR_90 STRINGIFY(KVM_CAP_HYPERV_TIME)
  [KVM_CAP_IOAPIC_POLARITY_IGNORED] = XLAT(KVM_CAP_IOAPIC_POLARITY_IGNORED),
+ #define XLAT_VAL_91 ((unsigned) (KVM_CAP_IOAPIC_POLARITY_IGNORED))
+ #define XLAT_STR_91 STRINGIFY(KVM_CAP_IOAPIC_POLARITY_IGNORED)
  [KVM_CAP_ENABLE_CAP_VM] = XLAT(KVM_CAP_ENABLE_CAP_VM),
+ #define XLAT_VAL_92 ((unsigned) (KVM_CAP_ENABLE_CAP_VM))
+ #define XLAT_STR_92 STRINGIFY(KVM_CAP_ENABLE_CAP_VM)
  [KVM_CAP_S390_IRQCHIP] = XLAT(KVM_CAP_S390_IRQCHIP),
+ #define XLAT_VAL_93 ((unsigned) (KVM_CAP_S390_IRQCHIP))
+ #define XLAT_STR_93 STRINGIFY(KVM_CAP_S390_IRQCHIP)
  [KVM_CAP_IOEVENTFD_NO_LENGTH] = XLAT(KVM_CAP_IOEVENTFD_NO_LENGTH),
+ #define XLAT_VAL_94 ((unsigned) (KVM_CAP_IOEVENTFD_NO_LENGTH))
+ #define XLAT_STR_94 STRINGIFY(KVM_CAP_IOEVENTFD_NO_LENGTH)
  [KVM_CAP_VM_ATTRIBUTES] = XLAT(KVM_CAP_VM_ATTRIBUTES),
+ #define XLAT_VAL_95 ((unsigned) (KVM_CAP_VM_ATTRIBUTES))
+ #define XLAT_STR_95 STRINGIFY(KVM_CAP_VM_ATTRIBUTES)
  [KVM_CAP_ARM_PSCI_0_2] = XLAT(KVM_CAP_ARM_PSCI_0_2),
+ #define XLAT_VAL_96 ((unsigned) (KVM_CAP_ARM_PSCI_0_2))
+ #define XLAT_STR_96 STRINGIFY(KVM_CAP_ARM_PSCI_0_2)
  [KVM_CAP_PPC_FIXUP_HCALL] = XLAT(KVM_CAP_PPC_FIXUP_HCALL),
+ #define XLAT_VAL_97 ((unsigned) (KVM_CAP_PPC_FIXUP_HCALL))
+ #define XLAT_STR_97 STRINGIFY(KVM_CAP_PPC_FIXUP_HCALL)
  [KVM_CAP_PPC_ENABLE_HCALL] = XLAT(KVM_CAP_PPC_ENABLE_HCALL),
+ #define XLAT_VAL_98 ((unsigned) (KVM_CAP_PPC_ENABLE_HCALL))
+ #define XLAT_STR_98 STRINGIFY(KVM_CAP_PPC_ENABLE_HCALL)
  [KVM_CAP_CHECK_EXTENSION_VM] = XLAT(KVM_CAP_CHECK_EXTENSION_VM),
+ #define XLAT_VAL_99 ((unsigned) (KVM_CAP_CHECK_EXTENSION_VM))
+ #define XLAT_STR_99 STRINGIFY(KVM_CAP_CHECK_EXTENSION_VM)
  [KVM_CAP_S390_USER_SIGP] = XLAT(KVM_CAP_S390_USER_SIGP),
+ #define XLAT_VAL_100 ((unsigned) (KVM_CAP_S390_USER_SIGP))
+ #define XLAT_STR_100 STRINGIFY(KVM_CAP_S390_USER_SIGP)
  [KVM_CAP_S390_VECTOR_REGISTERS] = XLAT(KVM_CAP_S390_VECTOR_REGISTERS),
+ #define XLAT_VAL_101 ((unsigned) (KVM_CAP_S390_VECTOR_REGISTERS))
+ #define XLAT_STR_101 STRINGIFY(KVM_CAP_S390_VECTOR_REGISTERS)
  [KVM_CAP_S390_MEM_OP] = XLAT(KVM_CAP_S390_MEM_OP),
+ #define XLAT_VAL_102 ((unsigned) (KVM_CAP_S390_MEM_OP))
+ #define XLAT_STR_102 STRINGIFY(KVM_CAP_S390_MEM_OP)
  [KVM_CAP_S390_USER_STSI] = XLAT(KVM_CAP_S390_USER_STSI),
+ #define XLAT_VAL_103 ((unsigned) (KVM_CAP_S390_USER_STSI))
+ #define XLAT_STR_103 STRINGIFY(KVM_CAP_S390_USER_STSI)
  [KVM_CAP_S390_SKEYS] = XLAT(KVM_CAP_S390_SKEYS),
+ #define XLAT_VAL_104 ((unsigned) (KVM_CAP_S390_SKEYS))
+ #define XLAT_STR_104 STRINGIFY(KVM_CAP_S390_SKEYS)
  [KVM_CAP_MIPS_FPU] = XLAT(KVM_CAP_MIPS_FPU),
+ #define XLAT_VAL_105 ((unsigned) (KVM_CAP_MIPS_FPU))
+ #define XLAT_STR_105 STRINGIFY(KVM_CAP_MIPS_FPU)
  [KVM_CAP_MIPS_MSA] = XLAT(KVM_CAP_MIPS_MSA),
+ #define XLAT_VAL_106 ((unsigned) (KVM_CAP_MIPS_MSA))
+ #define XLAT_STR_106 STRINGIFY(KVM_CAP_MIPS_MSA)
  [KVM_CAP_S390_INJECT_IRQ] = XLAT(KVM_CAP_S390_INJECT_IRQ),
+ #define XLAT_VAL_107 ((unsigned) (KVM_CAP_S390_INJECT_IRQ))
+ #define XLAT_STR_107 STRINGIFY(KVM_CAP_S390_INJECT_IRQ)
  [KVM_CAP_S390_IRQ_STATE] = XLAT(KVM_CAP_S390_IRQ_STATE),
+ #define XLAT_VAL_108 ((unsigned) (KVM_CAP_S390_IRQ_STATE))
+ #define XLAT_STR_108 STRINGIFY(KVM_CAP_S390_IRQ_STATE)
  [KVM_CAP_PPC_HWRNG] = XLAT(KVM_CAP_PPC_HWRNG),
+ #define XLAT_VAL_109 ((unsigned) (KVM_CAP_PPC_HWRNG))
+ #define XLAT_STR_109 STRINGIFY(KVM_CAP_PPC_HWRNG)
  [KVM_CAP_DISABLE_QUIRKS] = XLAT(KVM_CAP_DISABLE_QUIRKS),
+ #define XLAT_VAL_110 ((unsigned) (KVM_CAP_DISABLE_QUIRKS))
+ #define XLAT_STR_110 STRINGIFY(KVM_CAP_DISABLE_QUIRKS)
  [KVM_CAP_X86_SMM] = XLAT(KVM_CAP_X86_SMM),
+ #define XLAT_VAL_111 ((unsigned) (KVM_CAP_X86_SMM))
+ #define XLAT_STR_111 STRINGIFY(KVM_CAP_X86_SMM)
  [KVM_CAP_MULTI_ADDRESS_SPACE] = XLAT(KVM_CAP_MULTI_ADDRESS_SPACE),
+ #define XLAT_VAL_112 ((unsigned) (KVM_CAP_MULTI_ADDRESS_SPACE))
+ #define XLAT_STR_112 STRINGIFY(KVM_CAP_MULTI_ADDRESS_SPACE)
  [KVM_CAP_GUEST_DEBUG_HW_BPS] = XLAT(KVM_CAP_GUEST_DEBUG_HW_BPS),
+ #define XLAT_VAL_113 ((unsigned) (KVM_CAP_GUEST_DEBUG_HW_BPS))
+ #define XLAT_STR_113 STRINGIFY(KVM_CAP_GUEST_DEBUG_HW_BPS)
  [KVM_CAP_GUEST_DEBUG_HW_WPS] = XLAT(KVM_CAP_GUEST_DEBUG_HW_WPS),
+ #define XLAT_VAL_114 ((unsigned) (KVM_CAP_GUEST_DEBUG_HW_WPS))
+ #define XLAT_STR_114 STRINGIFY(KVM_CAP_GUEST_DEBUG_HW_WPS)
  [KVM_CAP_SPLIT_IRQCHIP] = XLAT(KVM_CAP_SPLIT_IRQCHIP),
+ #define XLAT_VAL_115 ((unsigned) (KVM_CAP_SPLIT_IRQCHIP))
+ #define XLAT_STR_115 STRINGIFY(KVM_CAP_SPLIT_IRQCHIP)
  [KVM_CAP_IOEVENTFD_ANY_LENGTH] = XLAT(KVM_CAP_IOEVENTFD_ANY_LENGTH),
+ #define XLAT_VAL_116 ((unsigned) (KVM_CAP_IOEVENTFD_ANY_LENGTH))
+ #define XLAT_STR_116 STRINGIFY(KVM_CAP_IOEVENTFD_ANY_LENGTH)
  [KVM_CAP_HYPERV_SYNIC] = XLAT(KVM_CAP_HYPERV_SYNIC),
+ #define XLAT_VAL_117 ((unsigned) (KVM_CAP_HYPERV_SYNIC))
+ #define XLAT_STR_117 STRINGIFY(KVM_CAP_HYPERV_SYNIC)
  [KVM_CAP_S390_RI] = XLAT(KVM_CAP_S390_RI),
+ #define XLAT_VAL_118 ((unsigned) (KVM_CAP_S390_RI))
+ #define XLAT_STR_118 STRINGIFY(KVM_CAP_S390_RI)
  [KVM_CAP_SPAPR_TCE_64] = XLAT(KVM_CAP_SPAPR_TCE_64),
+ #define XLAT_VAL_119 ((unsigned) (KVM_CAP_SPAPR_TCE_64))
+ #define XLAT_STR_119 STRINGIFY(KVM_CAP_SPAPR_TCE_64)
  [KVM_CAP_ARM_PMU_V3] = XLAT(KVM_CAP_ARM_PMU_V3),
+ #define XLAT_VAL_120 ((unsigned) (KVM_CAP_ARM_PMU_V3))
+ #define XLAT_STR_120 STRINGIFY(KVM_CAP_ARM_PMU_V3)
  [KVM_CAP_VCPU_ATTRIBUTES] = XLAT(KVM_CAP_VCPU_ATTRIBUTES),
+ #define XLAT_VAL_121 ((unsigned) (KVM_CAP_VCPU_ATTRIBUTES))
+ #define XLAT_STR_121 STRINGIFY(KVM_CAP_VCPU_ATTRIBUTES)
  [KVM_CAP_MAX_VCPU_ID] = XLAT(KVM_CAP_MAX_VCPU_ID),
+ #define XLAT_VAL_122 ((unsigned) (KVM_CAP_MAX_VCPU_ID))
+ #define XLAT_STR_122 STRINGIFY(KVM_CAP_MAX_VCPU_ID)
  [KVM_CAP_X2APIC_API] = XLAT(KVM_CAP_X2APIC_API),
+ #define XLAT_VAL_123 ((unsigned) (KVM_CAP_X2APIC_API))
+ #define XLAT_STR_123 STRINGIFY(KVM_CAP_X2APIC_API)
  [KVM_CAP_S390_USER_INSTR0] = XLAT(KVM_CAP_S390_USER_INSTR0),
+ #define XLAT_VAL_124 ((unsigned) (KVM_CAP_S390_USER_INSTR0))
+ #define XLAT_STR_124 STRINGIFY(KVM_CAP_S390_USER_INSTR0)
  [KVM_CAP_MSI_DEVID] = XLAT(KVM_CAP_MSI_DEVID),
+ #define XLAT_VAL_125 ((unsigned) (KVM_CAP_MSI_DEVID))
+ #define XLAT_STR_125 STRINGIFY(KVM_CAP_MSI_DEVID)
  [KVM_CAP_PPC_HTM] = XLAT(KVM_CAP_PPC_HTM),
+ #define XLAT_VAL_126 ((unsigned) (KVM_CAP_PPC_HTM))
+ #define XLAT_STR_126 STRINGIFY(KVM_CAP_PPC_HTM)
  [KVM_CAP_SPAPR_RESIZE_HPT] = XLAT(KVM_CAP_SPAPR_RESIZE_HPT),
+ #define XLAT_VAL_127 ((unsigned) (KVM_CAP_SPAPR_RESIZE_HPT))
+ #define XLAT_STR_127 STRINGIFY(KVM_CAP_SPAPR_RESIZE_HPT)
  [KVM_CAP_PPC_MMU_RADIX] = XLAT(KVM_CAP_PPC_MMU_RADIX),
+ #define XLAT_VAL_128 ((unsigned) (KVM_CAP_PPC_MMU_RADIX))
+ #define XLAT_STR_128 STRINGIFY(KVM_CAP_PPC_MMU_RADIX)
  [KVM_CAP_PPC_MMU_HASH_V3] = XLAT(KVM_CAP_PPC_MMU_HASH_V3),
+ #define XLAT_VAL_129 ((unsigned) (KVM_CAP_PPC_MMU_HASH_V3))
+ #define XLAT_STR_129 STRINGIFY(KVM_CAP_PPC_MMU_HASH_V3)
  [KVM_CAP_IMMEDIATE_EXIT] = XLAT(KVM_CAP_IMMEDIATE_EXIT),
+ #define XLAT_VAL_130 ((unsigned) (KVM_CAP_IMMEDIATE_EXIT))
+ #define XLAT_STR_130 STRINGIFY(KVM_CAP_IMMEDIATE_EXIT)
  [KVM_CAP_MIPS_VZ] = XLAT(KVM_CAP_MIPS_VZ),
+ #define XLAT_VAL_131 ((unsigned) (KVM_CAP_MIPS_VZ))
+ #define XLAT_STR_131 STRINGIFY(KVM_CAP_MIPS_VZ)
  [KVM_CAP_MIPS_TE] = XLAT(KVM_CAP_MIPS_TE),
+ #define XLAT_VAL_132 ((unsigned) (KVM_CAP_MIPS_TE))
+ #define XLAT_STR_132 STRINGIFY(KVM_CAP_MIPS_TE)
  [KVM_CAP_MIPS_64BIT] = XLAT(KVM_CAP_MIPS_64BIT),
+ #define XLAT_VAL_133 ((unsigned) (KVM_CAP_MIPS_64BIT))
+ #define XLAT_STR_133 STRINGIFY(KVM_CAP_MIPS_64BIT)
  [KVM_CAP_S390_GS] = XLAT(KVM_CAP_S390_GS),
+ #define XLAT_VAL_134 ((unsigned) (KVM_CAP_S390_GS))
+ #define XLAT_STR_134 STRINGIFY(KVM_CAP_S390_GS)
  [KVM_CAP_S390_AIS] = XLAT(KVM_CAP_S390_AIS),
+ #define XLAT_VAL_135 ((unsigned) (KVM_CAP_S390_AIS))
+ #define XLAT_STR_135 STRINGIFY(KVM_CAP_S390_AIS)
  [KVM_CAP_SPAPR_TCE_VFIO] = XLAT(KVM_CAP_SPAPR_TCE_VFIO),
+ #define XLAT_VAL_136 ((unsigned) (KVM_CAP_SPAPR_TCE_VFIO))
+ #define XLAT_STR_136 STRINGIFY(KVM_CAP_SPAPR_TCE_VFIO)
  [KVM_CAP_X86_DISABLE_EXITS] = XLAT(KVM_CAP_X86_DISABLE_EXITS),
+ #define XLAT_VAL_137 ((unsigned) (KVM_CAP_X86_DISABLE_EXITS))
+ #define XLAT_STR_137 STRINGIFY(KVM_CAP_X86_DISABLE_EXITS)
  [KVM_CAP_ARM_USER_IRQ] = XLAT(KVM_CAP_ARM_USER_IRQ),
+ #define XLAT_VAL_138 ((unsigned) (KVM_CAP_ARM_USER_IRQ))
+ #define XLAT_STR_138 STRINGIFY(KVM_CAP_ARM_USER_IRQ)
  [KVM_CAP_S390_CMMA_MIGRATION] = XLAT(KVM_CAP_S390_CMMA_MIGRATION),
+ #define XLAT_VAL_139 ((unsigned) (KVM_CAP_S390_CMMA_MIGRATION))
+ #define XLAT_STR_139 STRINGIFY(KVM_CAP_S390_CMMA_MIGRATION)
  [KVM_CAP_PPC_FWNMI] = XLAT(KVM_CAP_PPC_FWNMI),
+ #define XLAT_VAL_140 ((unsigned) (KVM_CAP_PPC_FWNMI))
+ #define XLAT_STR_140 STRINGIFY(KVM_CAP_PPC_FWNMI)
  [KVM_CAP_PPC_SMT_POSSIBLE] = XLAT(KVM_CAP_PPC_SMT_POSSIBLE),
+ #define XLAT_VAL_141 ((unsigned) (KVM_CAP_PPC_SMT_POSSIBLE))
+ #define XLAT_STR_141 STRINGIFY(KVM_CAP_PPC_SMT_POSSIBLE)
  [KVM_CAP_HYPERV_SYNIC2] = XLAT(KVM_CAP_HYPERV_SYNIC2),
+ #define XLAT_VAL_142 ((unsigned) (KVM_CAP_HYPERV_SYNIC2))
+ #define XLAT_STR_142 STRINGIFY(KVM_CAP_HYPERV_SYNIC2)
  [KVM_CAP_HYPERV_VP_INDEX] = XLAT(KVM_CAP_HYPERV_VP_INDEX),
+ #define XLAT_VAL_143 ((unsigned) (KVM_CAP_HYPERV_VP_INDEX))
+ #define XLAT_STR_143 STRINGIFY(KVM_CAP_HYPERV_VP_INDEX)
  [KVM_CAP_S390_AIS_MIGRATION] = XLAT(KVM_CAP_S390_AIS_MIGRATION),
+ #define XLAT_VAL_144 ((unsigned) (KVM_CAP_S390_AIS_MIGRATION))
+ #define XLAT_STR_144 STRINGIFY(KVM_CAP_S390_AIS_MIGRATION)
  [KVM_CAP_PPC_GET_CPU_CHAR] = XLAT(KVM_CAP_PPC_GET_CPU_CHAR),
+ #define XLAT_VAL_145 ((unsigned) (KVM_CAP_PPC_GET_CPU_CHAR))
+ #define XLAT_STR_145 STRINGIFY(KVM_CAP_PPC_GET_CPU_CHAR)
  [KVM_CAP_S390_BPB] = XLAT(KVM_CAP_S390_BPB),
+ #define XLAT_VAL_146 ((unsigned) (KVM_CAP_S390_BPB))
+ #define XLAT_STR_146 STRINGIFY(KVM_CAP_S390_BPB)
  [KVM_CAP_GET_MSR_FEATURES] = XLAT(KVM_CAP_GET_MSR_FEATURES),
+ #define XLAT_VAL_147 ((unsigned) (KVM_CAP_GET_MSR_FEATURES))
+ #define XLAT_STR_147 STRINGIFY(KVM_CAP_GET_MSR_FEATURES)
  [KVM_CAP_HYPERV_EVENTFD] = XLAT(KVM_CAP_HYPERV_EVENTFD),
+ #define XLAT_VAL_148 ((unsigned) (KVM_CAP_HYPERV_EVENTFD))
+ #define XLAT_STR_148 STRINGIFY(KVM_CAP_HYPERV_EVENTFD)
  [KVM_CAP_HYPERV_TLBFLUSH] = XLAT(KVM_CAP_HYPERV_TLBFLUSH),
+ #define XLAT_VAL_149 ((unsigned) (KVM_CAP_HYPERV_TLBFLUSH))
+ #define XLAT_STR_149 STRINGIFY(KVM_CAP_HYPERV_TLBFLUSH)
  [KVM_CAP_S390_HPAGE_1M] = XLAT(KVM_CAP_S390_HPAGE_1M),
+ #define XLAT_VAL_150 ((unsigned) (KVM_CAP_S390_HPAGE_1M))
+ #define XLAT_STR_150 STRINGIFY(KVM_CAP_S390_HPAGE_1M)
  [KVM_CAP_NESTED_STATE] = XLAT(KVM_CAP_NESTED_STATE),
+ #define XLAT_VAL_151 ((unsigned) (KVM_CAP_NESTED_STATE))
+ #define XLAT_STR_151 STRINGIFY(KVM_CAP_NESTED_STATE)
  [KVM_CAP_ARM_INJECT_SERROR_ESR] = XLAT(KVM_CAP_ARM_INJECT_SERROR_ESR),
+ #define XLAT_VAL_152 ((unsigned) (KVM_CAP_ARM_INJECT_SERROR_ESR))
+ #define XLAT_STR_152 STRINGIFY(KVM_CAP_ARM_INJECT_SERROR_ESR)
  [KVM_CAP_MSR_PLATFORM_INFO] = XLAT(KVM_CAP_MSR_PLATFORM_INFO),
+ #define XLAT_VAL_153 ((unsigned) (KVM_CAP_MSR_PLATFORM_INFO))
+ #define XLAT_STR_153 STRINGIFY(KVM_CAP_MSR_PLATFORM_INFO)
  [KVM_CAP_PPC_NESTED_HV] = XLAT(KVM_CAP_PPC_NESTED_HV),
+ #define XLAT_VAL_154 ((unsigned) (KVM_CAP_PPC_NESTED_HV))
+ #define XLAT_STR_154 STRINGIFY(KVM_CAP_PPC_NESTED_HV)
  [KVM_CAP_HYPERV_SEND_IPI] = XLAT(KVM_CAP_HYPERV_SEND_IPI),
+ #define XLAT_VAL_155 ((unsigned) (KVM_CAP_HYPERV_SEND_IPI))
+ #define XLAT_STR_155 STRINGIFY(KVM_CAP_HYPERV_SEND_IPI)
  [KVM_CAP_COALESCED_PIO] = XLAT(KVM_CAP_COALESCED_PIO),
+ #define XLAT_VAL_156 ((unsigned) (KVM_CAP_COALESCED_PIO))
+ #define XLAT_STR_156 STRINGIFY(KVM_CAP_COALESCED_PIO)
  [KVM_CAP_HYPERV_ENLIGHTENED_VMCS] = XLAT(KVM_CAP_HYPERV_ENLIGHTENED_VMCS),
+ #define XLAT_VAL_157 ((unsigned) (KVM_CAP_HYPERV_ENLIGHTENED_VMCS))
+ #define XLAT_STR_157 STRINGIFY(KVM_CAP_HYPERV_ENLIGHTENED_VMCS)
  [KVM_CAP_EXCEPTION_PAYLOAD] = XLAT(KVM_CAP_EXCEPTION_PAYLOAD),
+ #define XLAT_VAL_158 ((unsigned) (KVM_CAP_EXCEPTION_PAYLOAD))
+ #define XLAT_STR_158 STRINGIFY(KVM_CAP_EXCEPTION_PAYLOAD)
  [KVM_CAP_ARM_VM_IPA_SIZE] = XLAT(KVM_CAP_ARM_VM_IPA_SIZE),
+ #define XLAT_VAL_159 ((unsigned) (KVM_CAP_ARM_VM_IPA_SIZE))
+ #define XLAT_STR_159 STRINGIFY(KVM_CAP_ARM_VM_IPA_SIZE)
  [KVM_CAP_MANUAL_DIRTY_LOG_PROTECT] = XLAT(KVM_CAP_MANUAL_DIRTY_LOG_PROTECT),
+ #define XLAT_VAL_160 ((unsigned) (KVM_CAP_MANUAL_DIRTY_LOG_PROTECT))
+ #define XLAT_STR_160 STRINGIFY(KVM_CAP_MANUAL_DIRTY_LOG_PROTECT)
  [KVM_CAP_HYPERV_CPUID] = XLAT(KVM_CAP_HYPERV_CPUID),
+ #define XLAT_VAL_161 ((unsigned) (KVM_CAP_HYPERV_CPUID))
+ #define XLAT_STR_161 STRINGIFY(KVM_CAP_HYPERV_CPUID)
  [KVM_CAP_MANUAL_DIRTY_LOG_PROTECT2] = XLAT(KVM_CAP_MANUAL_DIRTY_LOG_PROTECT2),
+ #define XLAT_VAL_162 ((unsigned) (KVM_CAP_MANUAL_DIRTY_LOG_PROTECT2))
+ #define XLAT_STR_162 STRINGIFY(KVM_CAP_MANUAL_DIRTY_LOG_PROTECT2)
  [KVM_CAP_PPC_IRQ_XIVE] = XLAT(KVM_CAP_PPC_IRQ_XIVE),
+ #define XLAT_VAL_163 ((unsigned) (KVM_CAP_PPC_IRQ_XIVE))
+ #define XLAT_STR_163 STRINGIFY(KVM_CAP_PPC_IRQ_XIVE)
  [KVM_CAP_ARM_SVE] = XLAT(KVM_CAP_ARM_SVE),
+ #define XLAT_VAL_164 ((unsigned) (KVM_CAP_ARM_SVE))
+ #define XLAT_STR_164 STRINGIFY(KVM_CAP_ARM_SVE)
  [KVM_CAP_ARM_PTRAUTH_ADDRESS] = XLAT(KVM_CAP_ARM_PTRAUTH_ADDRESS),
+ #define XLAT_VAL_165 ((unsigned) (KVM_CAP_ARM_PTRAUTH_ADDRESS))
+ #define XLAT_STR_165 STRINGIFY(KVM_CAP_ARM_PTRAUTH_ADDRESS)
  [KVM_CAP_ARM_PTRAUTH_GENERIC] = XLAT(KVM_CAP_ARM_PTRAUTH_GENERIC),
+ #define XLAT_VAL_166 ((unsigned) (KVM_CAP_ARM_PTRAUTH_GENERIC))
+ #define XLAT_STR_166 STRINGIFY(KVM_CAP_ARM_PTRAUTH_GENERIC)
  [KVM_CAP_PMU_EVENT_FILTER] = XLAT(KVM_CAP_PMU_EVENT_FILTER),
+ #define XLAT_VAL_167 ((unsigned) (KVM_CAP_PMU_EVENT_FILTER))
+ #define XLAT_STR_167 STRINGIFY(KVM_CAP_PMU_EVENT_FILTER)
  [KVM_CAP_ARM_IRQ_LINE_LAYOUT_2] = XLAT(KVM_CAP_ARM_IRQ_LINE_LAYOUT_2),
+ #define XLAT_VAL_168 ((unsigned) (KVM_CAP_ARM_IRQ_LINE_LAYOUT_2))
+ #define XLAT_STR_168 STRINGIFY(KVM_CAP_ARM_IRQ_LINE_LAYOUT_2)
  [KVM_CAP_HYPERV_DIRECT_TLBFLUSH] = XLAT(KVM_CAP_HYPERV_DIRECT_TLBFLUSH),
+ #define XLAT_VAL_169 ((unsigned) (KVM_CAP_HYPERV_DIRECT_TLBFLUSH))
+ #define XLAT_STR_169 STRINGIFY(KVM_CAP_HYPERV_DIRECT_TLBFLUSH)
  [KVM_CAP_PPC_GUEST_DEBUG_SSTEP] = XLAT(KVM_CAP_PPC_GUEST_DEBUG_SSTEP),
+ #define XLAT_VAL_170 ((unsigned) (KVM_CAP_PPC_GUEST_DEBUG_SSTEP))
+ #define XLAT_STR_170 STRINGIFY(KVM_CAP_PPC_GUEST_DEBUG_SSTEP)
  [KVM_CAP_ARM_NISV_TO_USER] = XLAT(KVM_CAP_ARM_NISV_TO_USER),
+ #define XLAT_VAL_171 ((unsigned) (KVM_CAP_ARM_NISV_TO_USER))
+ #define XLAT_STR_171 STRINGIFY(KVM_CAP_ARM_NISV_TO_USER)
  [KVM_CAP_ARM_INJECT_EXT_DABT] = XLAT(KVM_CAP_ARM_INJECT_EXT_DABT),
+ #define XLAT_VAL_172 ((unsigned) (KVM_CAP_ARM_INJECT_EXT_DABT))
+ #define XLAT_STR_172 STRINGIFY(KVM_CAP_ARM_INJECT_EXT_DABT)
+ [KVM_CAP_S390_VCPU_RESETS] = XLAT(KVM_CAP_S390_VCPU_RESETS),
+ #define XLAT_VAL_173 ((unsigned) (KVM_CAP_S390_VCPU_RESETS))
+ #define XLAT_STR_173 STRINGIFY(KVM_CAP_S390_VCPU_RESETS)
+ [KVM_CAP_S390_PROTECTED] = XLAT(KVM_CAP_S390_PROTECTED),
+ #define XLAT_VAL_174 ((unsigned) (KVM_CAP_S390_PROTECTED))
+ #define XLAT_STR_174 STRINGIFY(KVM_CAP_S390_PROTECTED)
+ [KVM_CAP_PPC_SECURE_GUEST] = XLAT(KVM_CAP_PPC_SECURE_GUEST),
+ #define XLAT_VAL_175 ((unsigned) (KVM_CAP_PPC_SECURE_GUEST))
+ #define XLAT_STR_175 STRINGIFY(KVM_CAP_PPC_SECURE_GUEST)
+ [KVM_CAP_HALT_POLL] = XLAT(KVM_CAP_HALT_POLL),
+ #define XLAT_VAL_176 ((unsigned) (KVM_CAP_HALT_POLL))
+ #define XLAT_STR_176 STRINGIFY(KVM_CAP_HALT_POLL)
+ [KVM_CAP_ASYNC_PF_INT] = XLAT(KVM_CAP_ASYNC_PF_INT),
+ #define XLAT_VAL_177 ((unsigned) (KVM_CAP_ASYNC_PF_INT))
+ #define XLAT_STR_177 STRINGIFY(KVM_CAP_ASYNC_PF_INT)
+ [KVM_CAP_LAST_CPU] = XLAT(KVM_CAP_LAST_CPU),
+ #define XLAT_VAL_178 ((unsigned) (KVM_CAP_LAST_CPU))
+ #define XLAT_STR_178 STRINGIFY(KVM_CAP_LAST_CPU)
+ [KVM_CAP_SMALLER_MAXPHYADDR] = XLAT(KVM_CAP_SMALLER_MAXPHYADDR),
+ #define XLAT_VAL_179 ((unsigned) (KVM_CAP_SMALLER_MAXPHYADDR))
+ #define XLAT_STR_179 STRINGIFY(KVM_CAP_SMALLER_MAXPHYADDR)
+ [KVM_CAP_S390_DIAG318] = XLAT(KVM_CAP_S390_DIAG318),
+ #define XLAT_VAL_180 ((unsigned) (KVM_CAP_S390_DIAG318))
+ #define XLAT_STR_180 STRINGIFY(KVM_CAP_S390_DIAG318)
+ [KVM_CAP_STEAL_TIME] = XLAT(KVM_CAP_STEAL_TIME),
+ #define XLAT_VAL_181 ((unsigned) (KVM_CAP_STEAL_TIME))
+ #define XLAT_STR_181 STRINGIFY(KVM_CAP_STEAL_TIME)
 };
 static
 const struct xlat kvm_cap[1] = { {
  .data = kvm_cap_xdata,
  .size = ARRAY_SIZE(kvm_cap_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+#  ifdef XLAT_VAL_47
+  | XLAT_VAL_47
+#  endif
+#  ifdef XLAT_VAL_48
+  | XLAT_VAL_48
+#  endif
+#  ifdef XLAT_VAL_49
+  | XLAT_VAL_49
+#  endif
+#  ifdef XLAT_VAL_50
+  | XLAT_VAL_50
+#  endif
+#  ifdef XLAT_VAL_51
+  | XLAT_VAL_51
+#  endif
+#  ifdef XLAT_VAL_52
+  | XLAT_VAL_52
+#  endif
+#  ifdef XLAT_VAL_53
+  | XLAT_VAL_53
+#  endif
+#  ifdef XLAT_VAL_54
+  | XLAT_VAL_54
+#  endif
+#  ifdef XLAT_VAL_55
+  | XLAT_VAL_55
+#  endif
+#  ifdef XLAT_VAL_56
+  | XLAT_VAL_56
+#  endif
+#  ifdef XLAT_VAL_57
+  | XLAT_VAL_57
+#  endif
+#  ifdef XLAT_VAL_58
+  | XLAT_VAL_58
+#  endif
+#  ifdef XLAT_VAL_59
+  | XLAT_VAL_59
+#  endif
+#  ifdef XLAT_VAL_60
+  | XLAT_VAL_60
+#  endif
+#  ifdef XLAT_VAL_61
+  | XLAT_VAL_61
+#  endif
+#  ifdef XLAT_VAL_62
+  | XLAT_VAL_62
+#  endif
+#  ifdef XLAT_VAL_63
+  | XLAT_VAL_63
+#  endif
+#  ifdef XLAT_VAL_64
+  | XLAT_VAL_64
+#  endif
+#  ifdef XLAT_VAL_65
+  | XLAT_VAL_65
+#  endif
+#  ifdef XLAT_VAL_66
+  | XLAT_VAL_66
+#  endif
+#  ifdef XLAT_VAL_67
+  | XLAT_VAL_67
+#  endif
+#  ifdef XLAT_VAL_68
+  | XLAT_VAL_68
+#  endif
+#  ifdef XLAT_VAL_69
+  | XLAT_VAL_69
+#  endif
+#  ifdef XLAT_VAL_70
+  | XLAT_VAL_70
+#  endif
+#  ifdef XLAT_VAL_71
+  | XLAT_VAL_71
+#  endif
+#  ifdef XLAT_VAL_72
+  | XLAT_VAL_72
+#  endif
+#  ifdef XLAT_VAL_73
+  | XLAT_VAL_73
+#  endif
+#  ifdef XLAT_VAL_74
+  | XLAT_VAL_74
+#  endif
+#  ifdef XLAT_VAL_75
+  | XLAT_VAL_75
+#  endif
+#  ifdef XLAT_VAL_76
+  | XLAT_VAL_76
+#  endif
+#  ifdef XLAT_VAL_77
+  | XLAT_VAL_77
+#  endif
+#  ifdef XLAT_VAL_78
+  | XLAT_VAL_78
+#  endif
+#  ifdef XLAT_VAL_79
+  | XLAT_VAL_79
+#  endif
+#  ifdef XLAT_VAL_80
+  | XLAT_VAL_80
+#  endif
+#  ifdef XLAT_VAL_81
+  | XLAT_VAL_81
+#  endif
+#  ifdef XLAT_VAL_82
+  | XLAT_VAL_82
+#  endif
+#  ifdef XLAT_VAL_83
+  | XLAT_VAL_83
+#  endif
+#  ifdef XLAT_VAL_84
+  | XLAT_VAL_84
+#  endif
+#  ifdef XLAT_VAL_85
+  | XLAT_VAL_85
+#  endif
+#  ifdef XLAT_VAL_86
+  | XLAT_VAL_86
+#  endif
+#  ifdef XLAT_VAL_87
+  | XLAT_VAL_87
+#  endif
+#  ifdef XLAT_VAL_88
+  | XLAT_VAL_88
+#  endif
+#  ifdef XLAT_VAL_89
+  | XLAT_VAL_89
+#  endif
+#  ifdef XLAT_VAL_90
+  | XLAT_VAL_90
+#  endif
+#  ifdef XLAT_VAL_91
+  | XLAT_VAL_91
+#  endif
+#  ifdef XLAT_VAL_92
+  | XLAT_VAL_92
+#  endif
+#  ifdef XLAT_VAL_93
+  | XLAT_VAL_93
+#  endif
+#  ifdef XLAT_VAL_94
+  | XLAT_VAL_94
+#  endif
+#  ifdef XLAT_VAL_95
+  | XLAT_VAL_95
+#  endif
+#  ifdef XLAT_VAL_96
+  | XLAT_VAL_96
+#  endif
+#  ifdef XLAT_VAL_97
+  | XLAT_VAL_97
+#  endif
+#  ifdef XLAT_VAL_98
+  | XLAT_VAL_98
+#  endif
+#  ifdef XLAT_VAL_99
+  | XLAT_VAL_99
+#  endif
+#  ifdef XLAT_VAL_100
+  | XLAT_VAL_100
+#  endif
+#  ifdef XLAT_VAL_101
+  | XLAT_VAL_101
+#  endif
+#  ifdef XLAT_VAL_102
+  | XLAT_VAL_102
+#  endif
+#  ifdef XLAT_VAL_103
+  | XLAT_VAL_103
+#  endif
+#  ifdef XLAT_VAL_104
+  | XLAT_VAL_104
+#  endif
+#  ifdef XLAT_VAL_105
+  | XLAT_VAL_105
+#  endif
+#  ifdef XLAT_VAL_106
+  | XLAT_VAL_106
+#  endif
+#  ifdef XLAT_VAL_107
+  | XLAT_VAL_107
+#  endif
+#  ifdef XLAT_VAL_108
+  | XLAT_VAL_108
+#  endif
+#  ifdef XLAT_VAL_109
+  | XLAT_VAL_109
+#  endif
+#  ifdef XLAT_VAL_110
+  | XLAT_VAL_110
+#  endif
+#  ifdef XLAT_VAL_111
+  | XLAT_VAL_111
+#  endif
+#  ifdef XLAT_VAL_112
+  | XLAT_VAL_112
+#  endif
+#  ifdef XLAT_VAL_113
+  | XLAT_VAL_113
+#  endif
+#  ifdef XLAT_VAL_114
+  | XLAT_VAL_114
+#  endif
+#  ifdef XLAT_VAL_115
+  | XLAT_VAL_115
+#  endif
+#  ifdef XLAT_VAL_116
+  | XLAT_VAL_116
+#  endif
+#  ifdef XLAT_VAL_117
+  | XLAT_VAL_117
+#  endif
+#  ifdef XLAT_VAL_118
+  | XLAT_VAL_118
+#  endif
+#  ifdef XLAT_VAL_119
+  | XLAT_VAL_119
+#  endif
+#  ifdef XLAT_VAL_120
+  | XLAT_VAL_120
+#  endif
+#  ifdef XLAT_VAL_121
+  | XLAT_VAL_121
+#  endif
+#  ifdef XLAT_VAL_122
+  | XLAT_VAL_122
+#  endif
+#  ifdef XLAT_VAL_123
+  | XLAT_VAL_123
+#  endif
+#  ifdef XLAT_VAL_124
+  | XLAT_VAL_124
+#  endif
+#  ifdef XLAT_VAL_125
+  | XLAT_VAL_125
+#  endif
+#  ifdef XLAT_VAL_126
+  | XLAT_VAL_126
+#  endif
+#  ifdef XLAT_VAL_127
+  | XLAT_VAL_127
+#  endif
+#  ifdef XLAT_VAL_128
+  | XLAT_VAL_128
+#  endif
+#  ifdef XLAT_VAL_129
+  | XLAT_VAL_129
+#  endif
+#  ifdef XLAT_VAL_130
+  | XLAT_VAL_130
+#  endif
+#  ifdef XLAT_VAL_131
+  | XLAT_VAL_131
+#  endif
+#  ifdef XLAT_VAL_132
+  | XLAT_VAL_132
+#  endif
+#  ifdef XLAT_VAL_133
+  | XLAT_VAL_133
+#  endif
+#  ifdef XLAT_VAL_134
+  | XLAT_VAL_134
+#  endif
+#  ifdef XLAT_VAL_135
+  | XLAT_VAL_135
+#  endif
+#  ifdef XLAT_VAL_136
+  | XLAT_VAL_136
+#  endif
+#  ifdef XLAT_VAL_137
+  | XLAT_VAL_137
+#  endif
+#  ifdef XLAT_VAL_138
+  | XLAT_VAL_138
+#  endif
+#  ifdef XLAT_VAL_139
+  | XLAT_VAL_139
+#  endif
+#  ifdef XLAT_VAL_140
+  | XLAT_VAL_140
+#  endif
+#  ifdef XLAT_VAL_141
+  | XLAT_VAL_141
+#  endif
+#  ifdef XLAT_VAL_142
+  | XLAT_VAL_142
+#  endif
+#  ifdef XLAT_VAL_143
+  | XLAT_VAL_143
+#  endif
+#  ifdef XLAT_VAL_144
+  | XLAT_VAL_144
+#  endif
+#  ifdef XLAT_VAL_145
+  | XLAT_VAL_145
+#  endif
+#  ifdef XLAT_VAL_146
+  | XLAT_VAL_146
+#  endif
+#  ifdef XLAT_VAL_147
+  | XLAT_VAL_147
+#  endif
+#  ifdef XLAT_VAL_148
+  | XLAT_VAL_148
+#  endif
+#  ifdef XLAT_VAL_149
+  | XLAT_VAL_149
+#  endif
+#  ifdef XLAT_VAL_150
+  | XLAT_VAL_150
+#  endif
+#  ifdef XLAT_VAL_151
+  | XLAT_VAL_151
+#  endif
+#  ifdef XLAT_VAL_152
+  | XLAT_VAL_152
+#  endif
+#  ifdef XLAT_VAL_153
+  | XLAT_VAL_153
+#  endif
+#  ifdef XLAT_VAL_154
+  | XLAT_VAL_154
+#  endif
+#  ifdef XLAT_VAL_155
+  | XLAT_VAL_155
+#  endif
+#  ifdef XLAT_VAL_156
+  | XLAT_VAL_156
+#  endif
+#  ifdef XLAT_VAL_157
+  | XLAT_VAL_157
+#  endif
+#  ifdef XLAT_VAL_158
+  | XLAT_VAL_158
+#  endif
+#  ifdef XLAT_VAL_159
+  | XLAT_VAL_159
+#  endif
+#  ifdef XLAT_VAL_160
+  | XLAT_VAL_160
+#  endif
+#  ifdef XLAT_VAL_161
+  | XLAT_VAL_161
+#  endif
+#  ifdef XLAT_VAL_162
+  | XLAT_VAL_162
+#  endif
+#  ifdef XLAT_VAL_163
+  | XLAT_VAL_163
+#  endif
+#  ifdef XLAT_VAL_164
+  | XLAT_VAL_164
+#  endif
+#  ifdef XLAT_VAL_165
+  | XLAT_VAL_165
+#  endif
+#  ifdef XLAT_VAL_166
+  | XLAT_VAL_166
+#  endif
+#  ifdef XLAT_VAL_167
+  | XLAT_VAL_167
+#  endif
+#  ifdef XLAT_VAL_168
+  | XLAT_VAL_168
+#  endif
+#  ifdef XLAT_VAL_169
+  | XLAT_VAL_169
+#  endif
+#  ifdef XLAT_VAL_170
+  | XLAT_VAL_170
+#  endif
+#  ifdef XLAT_VAL_171
+  | XLAT_VAL_171
+#  endif
+#  ifdef XLAT_VAL_172
+  | XLAT_VAL_172
+#  endif
+#  ifdef XLAT_VAL_173
+  | XLAT_VAL_173
+#  endif
+#  ifdef XLAT_VAL_174
+  | XLAT_VAL_174
+#  endif
+#  ifdef XLAT_VAL_175
+  | XLAT_VAL_175
+#  endif
+#  ifdef XLAT_VAL_176
+  | XLAT_VAL_176
+#  endif
+#  ifdef XLAT_VAL_177
+  | XLAT_VAL_177
+#  endif
+#  ifdef XLAT_VAL_178
+  | XLAT_VAL_178
+#  endif
+#  ifdef XLAT_VAL_179
+  | XLAT_VAL_179
+#  endif
+#  ifdef XLAT_VAL_180
+  | XLAT_VAL_180
+#  endif
+#  ifdef XLAT_VAL_181
+  | XLAT_VAL_181
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+#  ifdef XLAT_STR_47
+  + sizeof(XLAT_STR_47)
+#  endif
+#  ifdef XLAT_STR_48
+  + sizeof(XLAT_STR_48)
+#  endif
+#  ifdef XLAT_STR_49
+  + sizeof(XLAT_STR_49)
+#  endif
+#  ifdef XLAT_STR_50
+  + sizeof(XLAT_STR_50)
+#  endif
+#  ifdef XLAT_STR_51
+  + sizeof(XLAT_STR_51)
+#  endif
+#  ifdef XLAT_STR_52
+  + sizeof(XLAT_STR_52)
+#  endif
+#  ifdef XLAT_STR_53
+  + sizeof(XLAT_STR_53)
+#  endif
+#  ifdef XLAT_STR_54
+  + sizeof(XLAT_STR_54)
+#  endif
+#  ifdef XLAT_STR_55
+  + sizeof(XLAT_STR_55)
+#  endif
+#  ifdef XLAT_STR_56
+  + sizeof(XLAT_STR_56)
+#  endif
+#  ifdef XLAT_STR_57
+  + sizeof(XLAT_STR_57)
+#  endif
+#  ifdef XLAT_STR_58
+  + sizeof(XLAT_STR_58)
+#  endif
+#  ifdef XLAT_STR_59
+  + sizeof(XLAT_STR_59)
+#  endif
+#  ifdef XLAT_STR_60
+  + sizeof(XLAT_STR_60)
+#  endif
+#  ifdef XLAT_STR_61
+  + sizeof(XLAT_STR_61)
+#  endif
+#  ifdef XLAT_STR_62
+  + sizeof(XLAT_STR_62)
+#  endif
+#  ifdef XLAT_STR_63
+  + sizeof(XLAT_STR_63)
+#  endif
+#  ifdef XLAT_STR_64
+  + sizeof(XLAT_STR_64)
+#  endif
+#  ifdef XLAT_STR_65
+  + sizeof(XLAT_STR_65)
+#  endif
+#  ifdef XLAT_STR_66
+  + sizeof(XLAT_STR_66)
+#  endif
+#  ifdef XLAT_STR_67
+  + sizeof(XLAT_STR_67)
+#  endif
+#  ifdef XLAT_STR_68
+  + sizeof(XLAT_STR_68)
+#  endif
+#  ifdef XLAT_STR_69
+  + sizeof(XLAT_STR_69)
+#  endif
+#  ifdef XLAT_STR_70
+  + sizeof(XLAT_STR_70)
+#  endif
+#  ifdef XLAT_STR_71
+  + sizeof(XLAT_STR_71)
+#  endif
+#  ifdef XLAT_STR_72
+  + sizeof(XLAT_STR_72)
+#  endif
+#  ifdef XLAT_STR_73
+  + sizeof(XLAT_STR_73)
+#  endif
+#  ifdef XLAT_STR_74
+  + sizeof(XLAT_STR_74)
+#  endif
+#  ifdef XLAT_STR_75
+  + sizeof(XLAT_STR_75)
+#  endif
+#  ifdef XLAT_STR_76
+  + sizeof(XLAT_STR_76)
+#  endif
+#  ifdef XLAT_STR_77
+  + sizeof(XLAT_STR_77)
+#  endif
+#  ifdef XLAT_STR_78
+  + sizeof(XLAT_STR_78)
+#  endif
+#  ifdef XLAT_STR_79
+  + sizeof(XLAT_STR_79)
+#  endif
+#  ifdef XLAT_STR_80
+  + sizeof(XLAT_STR_80)
+#  endif
+#  ifdef XLAT_STR_81
+  + sizeof(XLAT_STR_81)
+#  endif
+#  ifdef XLAT_STR_82
+  + sizeof(XLAT_STR_82)
+#  endif
+#  ifdef XLAT_STR_83
+  + sizeof(XLAT_STR_83)
+#  endif
+#  ifdef XLAT_STR_84
+  + sizeof(XLAT_STR_84)
+#  endif
+#  ifdef XLAT_STR_85
+  + sizeof(XLAT_STR_85)
+#  endif
+#  ifdef XLAT_STR_86
+  + sizeof(XLAT_STR_86)
+#  endif
+#  ifdef XLAT_STR_87
+  + sizeof(XLAT_STR_87)
+#  endif
+#  ifdef XLAT_STR_88
+  + sizeof(XLAT_STR_88)
+#  endif
+#  ifdef XLAT_STR_89
+  + sizeof(XLAT_STR_89)
+#  endif
+#  ifdef XLAT_STR_90
+  + sizeof(XLAT_STR_90)
+#  endif
+#  ifdef XLAT_STR_91
+  + sizeof(XLAT_STR_91)
+#  endif
+#  ifdef XLAT_STR_92
+  + sizeof(XLAT_STR_92)
+#  endif
+#  ifdef XLAT_STR_93
+  + sizeof(XLAT_STR_93)
+#  endif
+#  ifdef XLAT_STR_94
+  + sizeof(XLAT_STR_94)
+#  endif
+#  ifdef XLAT_STR_95
+  + sizeof(XLAT_STR_95)
+#  endif
+#  ifdef XLAT_STR_96
+  + sizeof(XLAT_STR_96)
+#  endif
+#  ifdef XLAT_STR_97
+  + sizeof(XLAT_STR_97)
+#  endif
+#  ifdef XLAT_STR_98
+  + sizeof(XLAT_STR_98)
+#  endif
+#  ifdef XLAT_STR_99
+  + sizeof(XLAT_STR_99)
+#  endif
+#  ifdef XLAT_STR_100
+  + sizeof(XLAT_STR_100)
+#  endif
+#  ifdef XLAT_STR_101
+  + sizeof(XLAT_STR_101)
+#  endif
+#  ifdef XLAT_STR_102
+  + sizeof(XLAT_STR_102)
+#  endif
+#  ifdef XLAT_STR_103
+  + sizeof(XLAT_STR_103)
+#  endif
+#  ifdef XLAT_STR_104
+  + sizeof(XLAT_STR_104)
+#  endif
+#  ifdef XLAT_STR_105
+  + sizeof(XLAT_STR_105)
+#  endif
+#  ifdef XLAT_STR_106
+  + sizeof(XLAT_STR_106)
+#  endif
+#  ifdef XLAT_STR_107
+  + sizeof(XLAT_STR_107)
+#  endif
+#  ifdef XLAT_STR_108
+  + sizeof(XLAT_STR_108)
+#  endif
+#  ifdef XLAT_STR_109
+  + sizeof(XLAT_STR_109)
+#  endif
+#  ifdef XLAT_STR_110
+  + sizeof(XLAT_STR_110)
+#  endif
+#  ifdef XLAT_STR_111
+  + sizeof(XLAT_STR_111)
+#  endif
+#  ifdef XLAT_STR_112
+  + sizeof(XLAT_STR_112)
+#  endif
+#  ifdef XLAT_STR_113
+  + sizeof(XLAT_STR_113)
+#  endif
+#  ifdef XLAT_STR_114
+  + sizeof(XLAT_STR_114)
+#  endif
+#  ifdef XLAT_STR_115
+  + sizeof(XLAT_STR_115)
+#  endif
+#  ifdef XLAT_STR_116
+  + sizeof(XLAT_STR_116)
+#  endif
+#  ifdef XLAT_STR_117
+  + sizeof(XLAT_STR_117)
+#  endif
+#  ifdef XLAT_STR_118
+  + sizeof(XLAT_STR_118)
+#  endif
+#  ifdef XLAT_STR_119
+  + sizeof(XLAT_STR_119)
+#  endif
+#  ifdef XLAT_STR_120
+  + sizeof(XLAT_STR_120)
+#  endif
+#  ifdef XLAT_STR_121
+  + sizeof(XLAT_STR_121)
+#  endif
+#  ifdef XLAT_STR_122
+  + sizeof(XLAT_STR_122)
+#  endif
+#  ifdef XLAT_STR_123
+  + sizeof(XLAT_STR_123)
+#  endif
+#  ifdef XLAT_STR_124
+  + sizeof(XLAT_STR_124)
+#  endif
+#  ifdef XLAT_STR_125
+  + sizeof(XLAT_STR_125)
+#  endif
+#  ifdef XLAT_STR_126
+  + sizeof(XLAT_STR_126)
+#  endif
+#  ifdef XLAT_STR_127
+  + sizeof(XLAT_STR_127)
+#  endif
+#  ifdef XLAT_STR_128
+  + sizeof(XLAT_STR_128)
+#  endif
+#  ifdef XLAT_STR_129
+  + sizeof(XLAT_STR_129)
+#  endif
+#  ifdef XLAT_STR_130
+  + sizeof(XLAT_STR_130)
+#  endif
+#  ifdef XLAT_STR_131
+  + sizeof(XLAT_STR_131)
+#  endif
+#  ifdef XLAT_STR_132
+  + sizeof(XLAT_STR_132)
+#  endif
+#  ifdef XLAT_STR_133
+  + sizeof(XLAT_STR_133)
+#  endif
+#  ifdef XLAT_STR_134
+  + sizeof(XLAT_STR_134)
+#  endif
+#  ifdef XLAT_STR_135
+  + sizeof(XLAT_STR_135)
+#  endif
+#  ifdef XLAT_STR_136
+  + sizeof(XLAT_STR_136)
+#  endif
+#  ifdef XLAT_STR_137
+  + sizeof(XLAT_STR_137)
+#  endif
+#  ifdef XLAT_STR_138
+  + sizeof(XLAT_STR_138)
+#  endif
+#  ifdef XLAT_STR_139
+  + sizeof(XLAT_STR_139)
+#  endif
+#  ifdef XLAT_STR_140
+  + sizeof(XLAT_STR_140)
+#  endif
+#  ifdef XLAT_STR_141
+  + sizeof(XLAT_STR_141)
+#  endif
+#  ifdef XLAT_STR_142
+  + sizeof(XLAT_STR_142)
+#  endif
+#  ifdef XLAT_STR_143
+  + sizeof(XLAT_STR_143)
+#  endif
+#  ifdef XLAT_STR_144
+  + sizeof(XLAT_STR_144)
+#  endif
+#  ifdef XLAT_STR_145
+  + sizeof(XLAT_STR_145)
+#  endif
+#  ifdef XLAT_STR_146
+  + sizeof(XLAT_STR_146)
+#  endif
+#  ifdef XLAT_STR_147
+  + sizeof(XLAT_STR_147)
+#  endif
+#  ifdef XLAT_STR_148
+  + sizeof(XLAT_STR_148)
+#  endif
+#  ifdef XLAT_STR_149
+  + sizeof(XLAT_STR_149)
+#  endif
+#  ifdef XLAT_STR_150
+  + sizeof(XLAT_STR_150)
+#  endif
+#  ifdef XLAT_STR_151
+  + sizeof(XLAT_STR_151)
+#  endif
+#  ifdef XLAT_STR_152
+  + sizeof(XLAT_STR_152)
+#  endif
+#  ifdef XLAT_STR_153
+  + sizeof(XLAT_STR_153)
+#  endif
+#  ifdef XLAT_STR_154
+  + sizeof(XLAT_STR_154)
+#  endif
+#  ifdef XLAT_STR_155
+  + sizeof(XLAT_STR_155)
+#  endif
+#  ifdef XLAT_STR_156
+  + sizeof(XLAT_STR_156)
+#  endif
+#  ifdef XLAT_STR_157
+  + sizeof(XLAT_STR_157)
+#  endif
+#  ifdef XLAT_STR_158
+  + sizeof(XLAT_STR_158)
+#  endif
+#  ifdef XLAT_STR_159
+  + sizeof(XLAT_STR_159)
+#  endif
+#  ifdef XLAT_STR_160
+  + sizeof(XLAT_STR_160)
+#  endif
+#  ifdef XLAT_STR_161
+  + sizeof(XLAT_STR_161)
+#  endif
+#  ifdef XLAT_STR_162
+  + sizeof(XLAT_STR_162)
+#  endif
+#  ifdef XLAT_STR_163
+  + sizeof(XLAT_STR_163)
+#  endif
+#  ifdef XLAT_STR_164
+  + sizeof(XLAT_STR_164)
+#  endif
+#  ifdef XLAT_STR_165
+  + sizeof(XLAT_STR_165)
+#  endif
+#  ifdef XLAT_STR_166
+  + sizeof(XLAT_STR_166)
+#  endif
+#  ifdef XLAT_STR_167
+  + sizeof(XLAT_STR_167)
+#  endif
+#  ifdef XLAT_STR_168
+  + sizeof(XLAT_STR_168)
+#  endif
+#  ifdef XLAT_STR_169
+  + sizeof(XLAT_STR_169)
+#  endif
+#  ifdef XLAT_STR_170
+  + sizeof(XLAT_STR_170)
+#  endif
+#  ifdef XLAT_STR_171
+  + sizeof(XLAT_STR_171)
+#  endif
+#  ifdef XLAT_STR_172
+  + sizeof(XLAT_STR_172)
+#  endif
+#  ifdef XLAT_STR_173
+  + sizeof(XLAT_STR_173)
+#  endif
+#  ifdef XLAT_STR_174
+  + sizeof(XLAT_STR_174)
+#  endif
+#  ifdef XLAT_STR_175
+  + sizeof(XLAT_STR_175)
+#  endif
+#  ifdef XLAT_STR_176
+  + sizeof(XLAT_STR_176)
+#  endif
+#  ifdef XLAT_STR_177
+  + sizeof(XLAT_STR_177)
+#  endif
+#  ifdef XLAT_STR_178
+  + sizeof(XLAT_STR_178)
+#  endif
+#  ifdef XLAT_STR_179
+  + sizeof(XLAT_STR_179)
+#  endif
+#  ifdef XLAT_STR_180
+  + sizeof(XLAT_STR_180)
+#  endif
+#  ifdef XLAT_STR_181
+  + sizeof(XLAT_STR_181)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
+#  undef XLAT_STR_47
+#  undef XLAT_VAL_47
+#  undef XLAT_STR_48
+#  undef XLAT_VAL_48
+#  undef XLAT_STR_49
+#  undef XLAT_VAL_49
+#  undef XLAT_STR_50
+#  undef XLAT_VAL_50
+#  undef XLAT_STR_51
+#  undef XLAT_VAL_51
+#  undef XLAT_STR_52
+#  undef XLAT_VAL_52
+#  undef XLAT_STR_53
+#  undef XLAT_VAL_53
+#  undef XLAT_STR_54
+#  undef XLAT_VAL_54
+#  undef XLAT_STR_55
+#  undef XLAT_VAL_55
+#  undef XLAT_STR_56
+#  undef XLAT_VAL_56
+#  undef XLAT_STR_57
+#  undef XLAT_VAL_57
+#  undef XLAT_STR_58
+#  undef XLAT_VAL_58
+#  undef XLAT_STR_59
+#  undef XLAT_VAL_59
+#  undef XLAT_STR_60
+#  undef XLAT_VAL_60
+#  undef XLAT_STR_61
+#  undef XLAT_VAL_61
+#  undef XLAT_STR_62
+#  undef XLAT_VAL_62
+#  undef XLAT_STR_63
+#  undef XLAT_VAL_63
+#  undef XLAT_STR_64
+#  undef XLAT_VAL_64
+#  undef XLAT_STR_65
+#  undef XLAT_VAL_65
+#  undef XLAT_STR_66
+#  undef XLAT_VAL_66
+#  undef XLAT_STR_67
+#  undef XLAT_VAL_67
+#  undef XLAT_STR_68
+#  undef XLAT_VAL_68
+#  undef XLAT_STR_69
+#  undef XLAT_VAL_69
+#  undef XLAT_STR_70
+#  undef XLAT_VAL_70
+#  undef XLAT_STR_71
+#  undef XLAT_VAL_71
+#  undef XLAT_STR_72
+#  undef XLAT_VAL_72
+#  undef XLAT_STR_73
+#  undef XLAT_VAL_73
+#  undef XLAT_STR_74
+#  undef XLAT_VAL_74
+#  undef XLAT_STR_75
+#  undef XLAT_VAL_75
+#  undef XLAT_STR_76
+#  undef XLAT_VAL_76
+#  undef XLAT_STR_77
+#  undef XLAT_VAL_77
+#  undef XLAT_STR_78
+#  undef XLAT_VAL_78
+#  undef XLAT_STR_79
+#  undef XLAT_VAL_79
+#  undef XLAT_STR_80
+#  undef XLAT_VAL_80
+#  undef XLAT_STR_81
+#  undef XLAT_VAL_81
+#  undef XLAT_STR_82
+#  undef XLAT_VAL_82
+#  undef XLAT_STR_83
+#  undef XLAT_VAL_83
+#  undef XLAT_STR_84
+#  undef XLAT_VAL_84
+#  undef XLAT_STR_85
+#  undef XLAT_VAL_85
+#  undef XLAT_STR_86
+#  undef XLAT_VAL_86
+#  undef XLAT_STR_87
+#  undef XLAT_VAL_87
+#  undef XLAT_STR_88
+#  undef XLAT_VAL_88
+#  undef XLAT_STR_89
+#  undef XLAT_VAL_89
+#  undef XLAT_STR_90
+#  undef XLAT_VAL_90
+#  undef XLAT_STR_91
+#  undef XLAT_VAL_91
+#  undef XLAT_STR_92
+#  undef XLAT_VAL_92
+#  undef XLAT_STR_93
+#  undef XLAT_VAL_93
+#  undef XLAT_STR_94
+#  undef XLAT_VAL_94
+#  undef XLAT_STR_95
+#  undef XLAT_VAL_95
+#  undef XLAT_STR_96
+#  undef XLAT_VAL_96
+#  undef XLAT_STR_97
+#  undef XLAT_VAL_97
+#  undef XLAT_STR_98
+#  undef XLAT_VAL_98
+#  undef XLAT_STR_99
+#  undef XLAT_VAL_99
+#  undef XLAT_STR_100
+#  undef XLAT_VAL_100
+#  undef XLAT_STR_101
+#  undef XLAT_VAL_101
+#  undef XLAT_STR_102
+#  undef XLAT_VAL_102
+#  undef XLAT_STR_103
+#  undef XLAT_VAL_103
+#  undef XLAT_STR_104
+#  undef XLAT_VAL_104
+#  undef XLAT_STR_105
+#  undef XLAT_VAL_105
+#  undef XLAT_STR_106
+#  undef XLAT_VAL_106
+#  undef XLAT_STR_107
+#  undef XLAT_VAL_107
+#  undef XLAT_STR_108
+#  undef XLAT_VAL_108
+#  undef XLAT_STR_109
+#  undef XLAT_VAL_109
+#  undef XLAT_STR_110
+#  undef XLAT_VAL_110
+#  undef XLAT_STR_111
+#  undef XLAT_VAL_111
+#  undef XLAT_STR_112
+#  undef XLAT_VAL_112
+#  undef XLAT_STR_113
+#  undef XLAT_VAL_113
+#  undef XLAT_STR_114
+#  undef XLAT_VAL_114
+#  undef XLAT_STR_115
+#  undef XLAT_VAL_115
+#  undef XLAT_STR_116
+#  undef XLAT_VAL_116
+#  undef XLAT_STR_117
+#  undef XLAT_VAL_117
+#  undef XLAT_STR_118
+#  undef XLAT_VAL_118
+#  undef XLAT_STR_119
+#  undef XLAT_VAL_119
+#  undef XLAT_STR_120
+#  undef XLAT_VAL_120
+#  undef XLAT_STR_121
+#  undef XLAT_VAL_121
+#  undef XLAT_STR_122
+#  undef XLAT_VAL_122
+#  undef XLAT_STR_123
+#  undef XLAT_VAL_123
+#  undef XLAT_STR_124
+#  undef XLAT_VAL_124
+#  undef XLAT_STR_125
+#  undef XLAT_VAL_125
+#  undef XLAT_STR_126
+#  undef XLAT_VAL_126
+#  undef XLAT_STR_127
+#  undef XLAT_VAL_127
+#  undef XLAT_STR_128
+#  undef XLAT_VAL_128
+#  undef XLAT_STR_129
+#  undef XLAT_VAL_129
+#  undef XLAT_STR_130
+#  undef XLAT_VAL_130
+#  undef XLAT_STR_131
+#  undef XLAT_VAL_131
+#  undef XLAT_STR_132
+#  undef XLAT_VAL_132
+#  undef XLAT_STR_133
+#  undef XLAT_VAL_133
+#  undef XLAT_STR_134
+#  undef XLAT_VAL_134
+#  undef XLAT_STR_135
+#  undef XLAT_VAL_135
+#  undef XLAT_STR_136
+#  undef XLAT_VAL_136
+#  undef XLAT_STR_137
+#  undef XLAT_VAL_137
+#  undef XLAT_STR_138
+#  undef XLAT_VAL_138
+#  undef XLAT_STR_139
+#  undef XLAT_VAL_139
+#  undef XLAT_STR_140
+#  undef XLAT_VAL_140
+#  undef XLAT_STR_141
+#  undef XLAT_VAL_141
+#  undef XLAT_STR_142
+#  undef XLAT_VAL_142
+#  undef XLAT_STR_143
+#  undef XLAT_VAL_143
+#  undef XLAT_STR_144
+#  undef XLAT_VAL_144
+#  undef XLAT_STR_145
+#  undef XLAT_VAL_145
+#  undef XLAT_STR_146
+#  undef XLAT_VAL_146
+#  undef XLAT_STR_147
+#  undef XLAT_VAL_147
+#  undef XLAT_STR_148
+#  undef XLAT_VAL_148
+#  undef XLAT_STR_149
+#  undef XLAT_VAL_149
+#  undef XLAT_STR_150
+#  undef XLAT_VAL_150
+#  undef XLAT_STR_151
+#  undef XLAT_VAL_151
+#  undef XLAT_STR_152
+#  undef XLAT_VAL_152
+#  undef XLAT_STR_153
+#  undef XLAT_VAL_153
+#  undef XLAT_STR_154
+#  undef XLAT_VAL_154
+#  undef XLAT_STR_155
+#  undef XLAT_VAL_155
+#  undef XLAT_STR_156
+#  undef XLAT_VAL_156
+#  undef XLAT_STR_157
+#  undef XLAT_VAL_157
+#  undef XLAT_STR_158
+#  undef XLAT_VAL_158
+#  undef XLAT_STR_159
+#  undef XLAT_VAL_159
+#  undef XLAT_STR_160
+#  undef XLAT_VAL_160
+#  undef XLAT_STR_161
+#  undef XLAT_VAL_161
+#  undef XLAT_STR_162
+#  undef XLAT_VAL_162
+#  undef XLAT_STR_163
+#  undef XLAT_VAL_163
+#  undef XLAT_STR_164
+#  undef XLAT_VAL_164
+#  undef XLAT_STR_165
+#  undef XLAT_VAL_165
+#  undef XLAT_STR_166
+#  undef XLAT_VAL_166
+#  undef XLAT_STR_167
+#  undef XLAT_VAL_167
+#  undef XLAT_STR_168
+#  undef XLAT_VAL_168
+#  undef XLAT_STR_169
+#  undef XLAT_VAL_169
+#  undef XLAT_STR_170
+#  undef XLAT_VAL_170
+#  undef XLAT_STR_171
+#  undef XLAT_VAL_171
+#  undef XLAT_STR_172
+#  undef XLAT_VAL_172
+#  undef XLAT_STR_173
+#  undef XLAT_VAL_173
+#  undef XLAT_STR_174
+#  undef XLAT_VAL_174
+#  undef XLAT_STR_175
+#  undef XLAT_VAL_175
+#  undef XLAT_STR_176
+#  undef XLAT_VAL_176
+#  undef XLAT_STR_177
+#  undef XLAT_VAL_177
+#  undef XLAT_STR_178
+#  undef XLAT_VAL_178
+#  undef XLAT_STR_179
+#  undef XLAT_VAL_179
+#  undef XLAT_STR_180
+#  undef XLAT_VAL_180
+#  undef XLAT_STR_181
+#  undef XLAT_VAL_181
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/kvm_cap.in 5.9-0ubuntu2/xlat/kvm_cap.in
--- 5.5-3/xlat/kvm_cap.in	2020-01-07 23:31:49.000000000 +0000
+++ 5.9-0ubuntu2/xlat/kvm_cap.in	2020-09-20 08:00:00.000000000 +0000
@@ -172,3 +172,12 @@ KVM_CAP_HYPERV_DIRECT_TLBFLUSH		175
 KVM_CAP_PPC_GUEST_DEBUG_SSTEP		176
 KVM_CAP_ARM_NISV_TO_USER		177
 KVM_CAP_ARM_INJECT_EXT_DABT		178
+KVM_CAP_S390_VCPU_RESETS		179
+KVM_CAP_S390_PROTECTED			180
+KVM_CAP_PPC_SECURE_GUEST		181
+KVM_CAP_HALT_POLL			182
+KVM_CAP_ASYNC_PF_INT			183
+KVM_CAP_LAST_CPU			184
+KVM_CAP_SMALLER_MAXPHYADDR		185
+KVM_CAP_S390_DIAG318			186
+KVM_CAP_STEAL_TIME			187
diff -pruN 5.5-3/xlat/kvm_cpuid_flags.h 5.9-0ubuntu2/xlat/kvm_cpuid_flags.h
--- 5.5-3/xlat/kvm_cpuid_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/kvm_cpuid_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -45,16 +45,50 @@ static const struct xlat_data kvm_cpuid_
 #endif
 
  XLAT(KVM_CPUID_FLAG_SIGNIFCANT_INDEX),
+ #define XLAT_VAL_0 ((unsigned) (KVM_CPUID_FLAG_SIGNIFCANT_INDEX))
+ #define XLAT_STR_0 STRINGIFY(KVM_CPUID_FLAG_SIGNIFCANT_INDEX)
  XLAT(KVM_CPUID_FLAG_STATEFUL_FUNC),
+ #define XLAT_VAL_1 ((unsigned) (KVM_CPUID_FLAG_STATEFUL_FUNC))
+ #define XLAT_STR_1 STRINGIFY(KVM_CPUID_FLAG_STATEFUL_FUNC)
  XLAT(KVM_CPUID_FLAG_STATE_READ_NEXT),
+ #define XLAT_VAL_2 ((unsigned) (KVM_CPUID_FLAG_STATE_READ_NEXT))
+ #define XLAT_STR_2 STRINGIFY(KVM_CPUID_FLAG_STATE_READ_NEXT)
 };
 static
 const struct xlat kvm_cpuid_flags[1] = { {
  .data = kvm_cpuid_flags_xdata,
  .size = ARRAY_SIZE(kvm_cpuid_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/kvm_exit_reason.h 5.9-0ubuntu2/xlat/kvm_exit_reason.h
--- 5.5-3/xlat/kvm_exit_reason.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/kvm_exit_reason.h	2020-09-24 09:18:45.000000000 +0000
@@ -217,43 +217,337 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data kvm_exit_reason_xdata[] = {
  [KVM_EXIT_UNKNOWN] = XLAT(KVM_EXIT_UNKNOWN),
+ #define XLAT_VAL_0 ((unsigned) (KVM_EXIT_UNKNOWN))
+ #define XLAT_STR_0 STRINGIFY(KVM_EXIT_UNKNOWN)
  [KVM_EXIT_EXCEPTION] = XLAT(KVM_EXIT_EXCEPTION),
+ #define XLAT_VAL_1 ((unsigned) (KVM_EXIT_EXCEPTION))
+ #define XLAT_STR_1 STRINGIFY(KVM_EXIT_EXCEPTION)
  [KVM_EXIT_IO] = XLAT(KVM_EXIT_IO),
+ #define XLAT_VAL_2 ((unsigned) (KVM_EXIT_IO))
+ #define XLAT_STR_2 STRINGIFY(KVM_EXIT_IO)
  [KVM_EXIT_HYPERCALL] = XLAT(KVM_EXIT_HYPERCALL),
+ #define XLAT_VAL_3 ((unsigned) (KVM_EXIT_HYPERCALL))
+ #define XLAT_STR_3 STRINGIFY(KVM_EXIT_HYPERCALL)
  [KVM_EXIT_DEBUG] = XLAT(KVM_EXIT_DEBUG),
+ #define XLAT_VAL_4 ((unsigned) (KVM_EXIT_DEBUG))
+ #define XLAT_STR_4 STRINGIFY(KVM_EXIT_DEBUG)
  [KVM_EXIT_HLT] = XLAT(KVM_EXIT_HLT),
+ #define XLAT_VAL_5 ((unsigned) (KVM_EXIT_HLT))
+ #define XLAT_STR_5 STRINGIFY(KVM_EXIT_HLT)
  [KVM_EXIT_MMIO] = XLAT(KVM_EXIT_MMIO),
+ #define XLAT_VAL_6 ((unsigned) (KVM_EXIT_MMIO))
+ #define XLAT_STR_6 STRINGIFY(KVM_EXIT_MMIO)
  [KVM_EXIT_IRQ_WINDOW_OPEN] = XLAT(KVM_EXIT_IRQ_WINDOW_OPEN),
+ #define XLAT_VAL_7 ((unsigned) (KVM_EXIT_IRQ_WINDOW_OPEN))
+ #define XLAT_STR_7 STRINGIFY(KVM_EXIT_IRQ_WINDOW_OPEN)
  [KVM_EXIT_SHUTDOWN] = XLAT(KVM_EXIT_SHUTDOWN),
+ #define XLAT_VAL_8 ((unsigned) (KVM_EXIT_SHUTDOWN))
+ #define XLAT_STR_8 STRINGIFY(KVM_EXIT_SHUTDOWN)
  [KVM_EXIT_FAIL_ENTRY] = XLAT(KVM_EXIT_FAIL_ENTRY),
+ #define XLAT_VAL_9 ((unsigned) (KVM_EXIT_FAIL_ENTRY))
+ #define XLAT_STR_9 STRINGIFY(KVM_EXIT_FAIL_ENTRY)
  [KVM_EXIT_INTR] = XLAT(KVM_EXIT_INTR),
+ #define XLAT_VAL_10 ((unsigned) (KVM_EXIT_INTR))
+ #define XLAT_STR_10 STRINGIFY(KVM_EXIT_INTR)
  [KVM_EXIT_SET_TPR] = XLAT(KVM_EXIT_SET_TPR),
+ #define XLAT_VAL_11 ((unsigned) (KVM_EXIT_SET_TPR))
+ #define XLAT_STR_11 STRINGIFY(KVM_EXIT_SET_TPR)
  [KVM_EXIT_TPR_ACCESS] = XLAT(KVM_EXIT_TPR_ACCESS),
+ #define XLAT_VAL_12 ((unsigned) (KVM_EXIT_TPR_ACCESS))
+ #define XLAT_STR_12 STRINGIFY(KVM_EXIT_TPR_ACCESS)
  [KVM_EXIT_S390_SIEIC] = XLAT(KVM_EXIT_S390_SIEIC),
+ #define XLAT_VAL_13 ((unsigned) (KVM_EXIT_S390_SIEIC))
+ #define XLAT_STR_13 STRINGIFY(KVM_EXIT_S390_SIEIC)
  [KVM_EXIT_S390_RESET] = XLAT(KVM_EXIT_S390_RESET),
+ #define XLAT_VAL_14 ((unsigned) (KVM_EXIT_S390_RESET))
+ #define XLAT_STR_14 STRINGIFY(KVM_EXIT_S390_RESET)
 
  [KVM_EXIT_DCR] = XLAT(KVM_EXIT_DCR),
+ #define XLAT_VAL_15 ((unsigned) (KVM_EXIT_DCR))
+ #define XLAT_STR_15 STRINGIFY(KVM_EXIT_DCR)
  [KVM_EXIT_NMI] = XLAT(KVM_EXIT_NMI),
+ #define XLAT_VAL_16 ((unsigned) (KVM_EXIT_NMI))
+ #define XLAT_STR_16 STRINGIFY(KVM_EXIT_NMI)
  [KVM_EXIT_INTERNAL_ERROR] = XLAT(KVM_EXIT_INTERNAL_ERROR),
+ #define XLAT_VAL_17 ((unsigned) (KVM_EXIT_INTERNAL_ERROR))
+ #define XLAT_STR_17 STRINGIFY(KVM_EXIT_INTERNAL_ERROR)
  [KVM_EXIT_OSI] = XLAT(KVM_EXIT_OSI),
+ #define XLAT_VAL_18 ((unsigned) (KVM_EXIT_OSI))
+ #define XLAT_STR_18 STRINGIFY(KVM_EXIT_OSI)
  [KVM_EXIT_PAPR_HCALL] = XLAT(KVM_EXIT_PAPR_HCALL),
+ #define XLAT_VAL_19 ((unsigned) (KVM_EXIT_PAPR_HCALL))
+ #define XLAT_STR_19 STRINGIFY(KVM_EXIT_PAPR_HCALL)
  [KVM_EXIT_S390_UCONTROL] = XLAT(KVM_EXIT_S390_UCONTROL),
+ #define XLAT_VAL_20 ((unsigned) (KVM_EXIT_S390_UCONTROL))
+ #define XLAT_STR_20 STRINGIFY(KVM_EXIT_S390_UCONTROL)
  [KVM_EXIT_WATCHDOG] = XLAT(KVM_EXIT_WATCHDOG),
+ #define XLAT_VAL_21 ((unsigned) (KVM_EXIT_WATCHDOG))
+ #define XLAT_STR_21 STRINGIFY(KVM_EXIT_WATCHDOG)
  [KVM_EXIT_S390_TSCH] = XLAT(KVM_EXIT_S390_TSCH),
+ #define XLAT_VAL_22 ((unsigned) (KVM_EXIT_S390_TSCH))
+ #define XLAT_STR_22 STRINGIFY(KVM_EXIT_S390_TSCH)
  [KVM_EXIT_EPR] = XLAT(KVM_EXIT_EPR),
+ #define XLAT_VAL_23 ((unsigned) (KVM_EXIT_EPR))
+ #define XLAT_STR_23 STRINGIFY(KVM_EXIT_EPR)
  [KVM_EXIT_SYSTEM_EVENT] = XLAT(KVM_EXIT_SYSTEM_EVENT),
+ #define XLAT_VAL_24 ((unsigned) (KVM_EXIT_SYSTEM_EVENT))
+ #define XLAT_STR_24 STRINGIFY(KVM_EXIT_SYSTEM_EVENT)
  [KVM_EXIT_S390_STSI] = XLAT(KVM_EXIT_S390_STSI),
+ #define XLAT_VAL_25 ((unsigned) (KVM_EXIT_S390_STSI))
+ #define XLAT_STR_25 STRINGIFY(KVM_EXIT_S390_STSI)
  [KVM_EXIT_IOAPIC_EOI] = XLAT(KVM_EXIT_IOAPIC_EOI),
+ #define XLAT_VAL_26 ((unsigned) (KVM_EXIT_IOAPIC_EOI))
+ #define XLAT_STR_26 STRINGIFY(KVM_EXIT_IOAPIC_EOI)
  [KVM_EXIT_HYPERV] = XLAT(KVM_EXIT_HYPERV),
+ #define XLAT_VAL_27 ((unsigned) (KVM_EXIT_HYPERV))
+ #define XLAT_STR_27 STRINGIFY(KVM_EXIT_HYPERV)
  [KVM_EXIT_ARM_NISV] = XLAT(KVM_EXIT_ARM_NISV),
+ #define XLAT_VAL_28 ((unsigned) (KVM_EXIT_ARM_NISV))
+ #define XLAT_STR_28 STRINGIFY(KVM_EXIT_ARM_NISV)
 };
 static
 const struct xlat kvm_exit_reason[1] = { {
  .data = kvm_exit_reason_xdata,
  .size = ARRAY_SIZE(kvm_exit_reason_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/kvm_mem_flags.h 5.9-0ubuntu2/xlat/kvm_mem_flags.h
--- 5.5-3/xlat/kvm_mem_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/kvm_mem_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data kvm_mem_flags_xdata[] = {
  XLAT(KVM_MEM_LOG_DIRTY_PAGES),
+ #define XLAT_VAL_0 ((unsigned) (KVM_MEM_LOG_DIRTY_PAGES))
+ #define XLAT_STR_0 STRINGIFY(KVM_MEM_LOG_DIRTY_PAGES)
  XLAT(KVM_MEM_READONLY),
+ #define XLAT_VAL_1 ((unsigned) (KVM_MEM_READONLY))
+ #define XLAT_STR_1 STRINGIFY(KVM_MEM_READONLY)
 };
 static
 const struct xlat kvm_mem_flags[1] = { {
  .data = kvm_mem_flags_xdata,
  .size = ARRAY_SIZE(kvm_mem_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/lockfcmds.h 5.9-0ubuntu2/xlat/lockfcmds.h
--- 5.5-3/xlat/lockfcmds.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/lockfcmds.h	2020-09-24 09:18:44.000000000 +0000
@@ -15,18 +15,28 @@
 static const struct xlat_data lockfcmds_xdata[] = {
 #if defined(F_RDLCK) || (defined(HAVE_DECL_F_RDLCK) && HAVE_DECL_F_RDLCK)
   XLAT(F_RDLCK),
+ #define XLAT_VAL_0 ((unsigned) (F_RDLCK))
+ #define XLAT_STR_0 STRINGIFY(F_RDLCK)
 #endif
 #if defined(F_WRLCK) || (defined(HAVE_DECL_F_WRLCK) && HAVE_DECL_F_WRLCK)
   XLAT(F_WRLCK),
+ #define XLAT_VAL_1 ((unsigned) (F_WRLCK))
+ #define XLAT_STR_1 STRINGIFY(F_WRLCK)
 #endif
 #if defined(F_UNLCK) || (defined(HAVE_DECL_F_UNLCK) && HAVE_DECL_F_UNLCK)
   XLAT(F_UNLCK),
+ #define XLAT_VAL_2 ((unsigned) (F_UNLCK))
+ #define XLAT_STR_2 STRINGIFY(F_UNLCK)
 #endif
 #if defined(F_EXLCK) || (defined(HAVE_DECL_F_EXLCK) && HAVE_DECL_F_EXLCK)
   XLAT(F_EXLCK),
+ #define XLAT_VAL_3 ((unsigned) (F_EXLCK))
+ #define XLAT_STR_3 STRINGIFY(F_EXLCK)
 #endif
 #if defined(F_SHLCK) || (defined(HAVE_DECL_F_SHLCK) && HAVE_DECL_F_SHLCK)
   XLAT(F_SHLCK),
+ #define XLAT_VAL_4 ((unsigned) (F_SHLCK))
+ #define XLAT_STR_4 STRINGIFY(F_SHLCK)
 #endif
 };
 static
@@ -34,8 +44,52 @@ const struct xlat lockfcmds[1] = { {
  .data = lockfcmds_xdata,
  .size = ARRAY_SIZE(lockfcmds_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/loop_cmds.h 5.9-0ubuntu2/xlat/loop_cmds.h
--- 5.5-3/xlat/loop_cmds.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/loop_cmds.h	2020-09-24 09:18:45.000000000 +0000
@@ -73,6 +73,13 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define LOOP_SET_BLOCK_SIZE 0x4C09
 #endif
+#if defined(LOOP_CONFIGURE) || (defined(HAVE_DECL_LOOP_CONFIGURE) && HAVE_DECL_LOOP_CONFIGURE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((LOOP_CONFIGURE) == (0x4C0A), "LOOP_CONFIGURE != 0x4C0A");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define LOOP_CONFIGURE 0x4C0A
+#endif
 #if defined(LOOP_CTL_ADD) || (defined(HAVE_DECL_LOOP_CTL_ADD) && HAVE_DECL_LOOP_CTL_ADD)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
 static_assert((LOOP_CTL_ADD) == (0x4C80), "LOOP_CTL_ADD != 0x4C80");
@@ -105,18 +112,47 @@ extern const struct xlat loop_cmds[];
 
 static const struct xlat_data loop_cmds_xdata[] = {
  XLAT(LOOP_SET_FD),
+ #define XLAT_VAL_0 ((unsigned) (LOOP_SET_FD))
+ #define XLAT_STR_0 STRINGIFY(LOOP_SET_FD)
  XLAT(LOOP_CLR_FD),
+ #define XLAT_VAL_1 ((unsigned) (LOOP_CLR_FD))
+ #define XLAT_STR_1 STRINGIFY(LOOP_CLR_FD)
  XLAT(LOOP_SET_STATUS),
+ #define XLAT_VAL_2 ((unsigned) (LOOP_SET_STATUS))
+ #define XLAT_STR_2 STRINGIFY(LOOP_SET_STATUS)
  XLAT(LOOP_GET_STATUS),
+ #define XLAT_VAL_3 ((unsigned) (LOOP_GET_STATUS))
+ #define XLAT_STR_3 STRINGIFY(LOOP_GET_STATUS)
  XLAT(LOOP_SET_STATUS64),
+ #define XLAT_VAL_4 ((unsigned) (LOOP_SET_STATUS64))
+ #define XLAT_STR_4 STRINGIFY(LOOP_SET_STATUS64)
  XLAT(LOOP_GET_STATUS64),
+ #define XLAT_VAL_5 ((unsigned) (LOOP_GET_STATUS64))
+ #define XLAT_STR_5 STRINGIFY(LOOP_GET_STATUS64)
  XLAT(LOOP_CHANGE_FD),
+ #define XLAT_VAL_6 ((unsigned) (LOOP_CHANGE_FD))
+ #define XLAT_STR_6 STRINGIFY(LOOP_CHANGE_FD)
  XLAT(LOOP_SET_CAPACITY),
+ #define XLAT_VAL_7 ((unsigned) (LOOP_SET_CAPACITY))
+ #define XLAT_STR_7 STRINGIFY(LOOP_SET_CAPACITY)
  XLAT(LOOP_SET_DIRECT_IO),
+ #define XLAT_VAL_8 ((unsigned) (LOOP_SET_DIRECT_IO))
+ #define XLAT_STR_8 STRINGIFY(LOOP_SET_DIRECT_IO)
  XLAT(LOOP_SET_BLOCK_SIZE),
+ #define XLAT_VAL_9 ((unsigned) (LOOP_SET_BLOCK_SIZE))
+ #define XLAT_STR_9 STRINGIFY(LOOP_SET_BLOCK_SIZE)
+ XLAT(LOOP_CONFIGURE),
+ #define XLAT_VAL_10 ((unsigned) (LOOP_CONFIGURE))
+ #define XLAT_STR_10 STRINGIFY(LOOP_CONFIGURE)
  XLAT(LOOP_CTL_ADD),
+ #define XLAT_VAL_11 ((unsigned) (LOOP_CTL_ADD))
+ #define XLAT_STR_11 STRINGIFY(LOOP_CTL_ADD)
  XLAT(LOOP_CTL_REMOVE),
+ #define XLAT_VAL_12 ((unsigned) (LOOP_CTL_REMOVE))
+ #define XLAT_STR_12 STRINGIFY(LOOP_CTL_REMOVE)
  XLAT(LOOP_CTL_GET_FREE),
+ #define XLAT_VAL_13 ((unsigned) (LOOP_CTL_GET_FREE))
+ #define XLAT_STR_13 STRINGIFY(LOOP_CTL_GET_FREE)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -125,8 +161,124 @@ const struct xlat loop_cmds[1] = { {
  .data = loop_cmds_xdata,
  .size = ARRAY_SIZE(loop_cmds_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/loop_cmds.in 5.9-0ubuntu2/xlat/loop_cmds.in
--- 5.5-3/xlat/loop_cmds.in	2018-12-26 01:59:38.000000000 +0000
+++ 5.9-0ubuntu2/xlat/loop_cmds.in	2020-06-28 08:00:00.000000000 +0000
@@ -8,6 +8,7 @@ LOOP_CHANGE_FD		0x4C06
 LOOP_SET_CAPACITY	0x4C07
 LOOP_SET_DIRECT_IO	0x4C08
 LOOP_SET_BLOCK_SIZE	0x4C09
+LOOP_CONFIGURE		0x4C0A
 LOOP_CTL_ADD		0x4C80
 LOOP_CTL_REMOVE		0x4C81
 LOOP_CTL_GET_FREE	0x4C82
diff -pruN 5.5-3/xlat/loop_crypt_type_options.h 5.9-0ubuntu2/xlat/loop_crypt_type_options.h
--- 5.5-3/xlat/loop_crypt_type_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/loop_crypt_type_options.h	2020-09-24 09:18:44.000000000 +0000
@@ -15,33 +15,53 @@ extern const struct xlat loop_crypt_type
 static const struct xlat_data loop_crypt_type_options_xdata[] = {
 #if defined(LO_CRYPT_NONE) || (defined(HAVE_DECL_LO_CRYPT_NONE) && HAVE_DECL_LO_CRYPT_NONE)
   XLAT(LO_CRYPT_NONE),
+ #define XLAT_VAL_0 ((unsigned) (LO_CRYPT_NONE))
+ #define XLAT_STR_0 STRINGIFY(LO_CRYPT_NONE)
 #endif
 #if defined(LO_CRYPT_XOR) || (defined(HAVE_DECL_LO_CRYPT_XOR) && HAVE_DECL_LO_CRYPT_XOR)
   XLAT(LO_CRYPT_XOR),
+ #define XLAT_VAL_1 ((unsigned) (LO_CRYPT_XOR))
+ #define XLAT_STR_1 STRINGIFY(LO_CRYPT_XOR)
 #endif
 #if defined(LO_CRYPT_DES) || (defined(HAVE_DECL_LO_CRYPT_DES) && HAVE_DECL_LO_CRYPT_DES)
   XLAT(LO_CRYPT_DES),
+ #define XLAT_VAL_2 ((unsigned) (LO_CRYPT_DES))
+ #define XLAT_STR_2 STRINGIFY(LO_CRYPT_DES)
 #endif
 #if defined(LO_CRYPT_FISH2) || (defined(HAVE_DECL_LO_CRYPT_FISH2) && HAVE_DECL_LO_CRYPT_FISH2)
   XLAT(LO_CRYPT_FISH2),
+ #define XLAT_VAL_3 ((unsigned) (LO_CRYPT_FISH2))
+ #define XLAT_STR_3 STRINGIFY(LO_CRYPT_FISH2)
 #endif
 #if defined(LO_CRYPT_BLOW) || (defined(HAVE_DECL_LO_CRYPT_BLOW) && HAVE_DECL_LO_CRYPT_BLOW)
   XLAT(LO_CRYPT_BLOW),
+ #define XLAT_VAL_4 ((unsigned) (LO_CRYPT_BLOW))
+ #define XLAT_STR_4 STRINGIFY(LO_CRYPT_BLOW)
 #endif
 #if defined(LO_CRYPT_CAST128) || (defined(HAVE_DECL_LO_CRYPT_CAST128) && HAVE_DECL_LO_CRYPT_CAST128)
   XLAT(LO_CRYPT_CAST128),
+ #define XLAT_VAL_5 ((unsigned) (LO_CRYPT_CAST128))
+ #define XLAT_STR_5 STRINGIFY(LO_CRYPT_CAST128)
 #endif
 #if defined(LO_CRYPT_IDEA) || (defined(HAVE_DECL_LO_CRYPT_IDEA) && HAVE_DECL_LO_CRYPT_IDEA)
   XLAT(LO_CRYPT_IDEA),
+ #define XLAT_VAL_6 ((unsigned) (LO_CRYPT_IDEA))
+ #define XLAT_STR_6 STRINGIFY(LO_CRYPT_IDEA)
 #endif
 #if defined(LO_CRYPT_DUMMY) || (defined(HAVE_DECL_LO_CRYPT_DUMMY) && HAVE_DECL_LO_CRYPT_DUMMY)
   XLAT(LO_CRYPT_DUMMY),
+ #define XLAT_VAL_7 ((unsigned) (LO_CRYPT_DUMMY))
+ #define XLAT_STR_7 STRINGIFY(LO_CRYPT_DUMMY)
 #endif
 #if defined(LO_CRYPT_SKIPJACK) || (defined(HAVE_DECL_LO_CRYPT_SKIPJACK) && HAVE_DECL_LO_CRYPT_SKIPJACK)
   XLAT(LO_CRYPT_SKIPJACK),
+ #define XLAT_VAL_8 ((unsigned) (LO_CRYPT_SKIPJACK))
+ #define XLAT_STR_8 STRINGIFY(LO_CRYPT_SKIPJACK)
 #endif
 #if defined(LO_CRYPT_CRYPTOAPI) || (defined(HAVE_DECL_LO_CRYPT_CRYPTOAPI) && HAVE_DECL_LO_CRYPT_CRYPTOAPI)
   XLAT(LO_CRYPT_CRYPTOAPI),
+ #define XLAT_VAL_9 ((unsigned) (LO_CRYPT_CRYPTOAPI))
+ #define XLAT_STR_9 STRINGIFY(LO_CRYPT_CRYPTOAPI)
 #endif
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
@@ -51,8 +71,92 @@ const struct xlat loop_crypt_type_option
  .data = loop_crypt_type_options_xdata,
  .size = ARRAY_SIZE(loop_crypt_type_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/loop_flags_options.h 5.9-0ubuntu2/xlat/loop_flags_options.h
--- 5.5-3/xlat/loop_flags_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/loop_flags_options.h	2020-09-24 09:18:44.000000000 +0000
@@ -49,14 +49,24 @@ extern const struct xlat loop_flags_opti
 
 static const struct xlat_data loop_flags_options_xdata[] = {
  XLAT(LO_FLAGS_READ_ONLY),
+ #define XLAT_VAL_0 ((unsigned) (LO_FLAGS_READ_ONLY))
+ #define XLAT_STR_0 STRINGIFY(LO_FLAGS_READ_ONLY)
 
  XLAT(LO_FLAGS_USE_AOPS),
+ #define XLAT_VAL_1 ((unsigned) (LO_FLAGS_USE_AOPS))
+ #define XLAT_STR_1 STRINGIFY(LO_FLAGS_USE_AOPS)
 
  XLAT(LO_FLAGS_AUTOCLEAR),
+ #define XLAT_VAL_2 ((unsigned) (LO_FLAGS_AUTOCLEAR))
+ #define XLAT_STR_2 STRINGIFY(LO_FLAGS_AUTOCLEAR)
 
  XLAT(LO_FLAGS_PARTSCAN),
+ #define XLAT_VAL_3 ((unsigned) (LO_FLAGS_PARTSCAN))
+ #define XLAT_STR_3 STRINGIFY(LO_FLAGS_PARTSCAN)
 
  XLAT(LO_FLAGS_DIRECT_IO),
+ #define XLAT_VAL_4 ((unsigned) (LO_FLAGS_DIRECT_IO))
+ #define XLAT_STR_4 STRINGIFY(LO_FLAGS_DIRECT_IO)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -65,8 +75,52 @@ const struct xlat loop_flags_options[1]
  .data = loop_flags_options_xdata,
  .size = ARRAY_SIZE(loop_flags_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/loop_flags_options.in 5.9-0ubuntu2/xlat/loop_flags_options.in
--- 5.5-3/xlat/loop_flags_options.in	2016-12-29 02:07:34.000000000 +0000
+++ 5.9-0ubuntu2/xlat/loop_flags_options.in	2020-05-30 08:00:00.000000000 +0000
@@ -1,3 +1,5 @@
+#enum
+#include <linux/loop.h>
 LO_FLAGS_READ_ONLY	1
 /* Added in v2.6.11-732-gf3f28e4, Removed in v3.2-rc1~49^2~5^2~3 */
 LO_FLAGS_USE_AOPS	2
diff -pruN 5.5-3/xlat/loop_flags_options.m4 5.9-0ubuntu2/xlat/loop_flags_options.m4
--- 5.5-3/xlat/loop_flags_options.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/loop_flags_options.m4	2020-09-24 09:18:44.000000000 +0000
@@ -0,0 +1,11 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/loop_flags_options.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_loop_flags_options],[
+AC_CHECK_DECLS(m4_normalize([
+LO_FLAGS_READ_ONLY,
+LO_FLAGS_USE_AOPS,
+LO_FLAGS_AUTOCLEAR,
+LO_FLAGS_PARTSCAN,
+LO_FLAGS_DIRECT_IO
+]),,, [
+#include <linux/loop.h>
+])])])
diff -pruN 5.5-3/xlat/lwtunnel_encap_types.h 5.9-0ubuntu2/xlat/lwtunnel_encap_types.h
--- 5.5-3/xlat/lwtunnel_encap_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/lwtunnel_encap_types.h	2020-09-24 09:18:44.000000000 +0000
@@ -52,6 +52,20 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define LWTUNNEL_ENCAP_BPF 6
 #endif
+#if defined(LWTUNNEL_ENCAP_SEG6_LOCAL) || (defined(HAVE_DECL_LWTUNNEL_ENCAP_SEG6_LOCAL) && HAVE_DECL_LWTUNNEL_ENCAP_SEG6_LOCAL)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((LWTUNNEL_ENCAP_SEG6_LOCAL) == (7), "LWTUNNEL_ENCAP_SEG6_LOCAL != 7");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define LWTUNNEL_ENCAP_SEG6_LOCAL 7
+#endif
+#if defined(LWTUNNEL_ENCAP_RPL) || (defined(HAVE_DECL_LWTUNNEL_ENCAP_RPL) && HAVE_DECL_LWTUNNEL_ENCAP_RPL)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((LWTUNNEL_ENCAP_RPL) == (8), "LWTUNNEL_ENCAP_RPL != 8");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define LWTUNNEL_ENCAP_RPL 8
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -63,20 +77,116 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data lwtunnel_encap_types_xdata[] = {
  [LWTUNNEL_ENCAP_NONE] = XLAT(LWTUNNEL_ENCAP_NONE),
+ #define XLAT_VAL_0 ((unsigned) (LWTUNNEL_ENCAP_NONE))
+ #define XLAT_STR_0 STRINGIFY(LWTUNNEL_ENCAP_NONE)
  [LWTUNNEL_ENCAP_MPLS] = XLAT(LWTUNNEL_ENCAP_MPLS),
+ #define XLAT_VAL_1 ((unsigned) (LWTUNNEL_ENCAP_MPLS))
+ #define XLAT_STR_1 STRINGIFY(LWTUNNEL_ENCAP_MPLS)
  [LWTUNNEL_ENCAP_IP] = XLAT(LWTUNNEL_ENCAP_IP),
+ #define XLAT_VAL_2 ((unsigned) (LWTUNNEL_ENCAP_IP))
+ #define XLAT_STR_2 STRINGIFY(LWTUNNEL_ENCAP_IP)
  [LWTUNNEL_ENCAP_ILA] = XLAT(LWTUNNEL_ENCAP_ILA),
+ #define XLAT_VAL_3 ((unsigned) (LWTUNNEL_ENCAP_ILA))
+ #define XLAT_STR_3 STRINGIFY(LWTUNNEL_ENCAP_ILA)
  [LWTUNNEL_ENCAP_IP6] = XLAT(LWTUNNEL_ENCAP_IP6),
+ #define XLAT_VAL_4 ((unsigned) (LWTUNNEL_ENCAP_IP6))
+ #define XLAT_STR_4 STRINGIFY(LWTUNNEL_ENCAP_IP6)
  [LWTUNNEL_ENCAP_SEG6] = XLAT(LWTUNNEL_ENCAP_SEG6),
+ #define XLAT_VAL_5 ((unsigned) (LWTUNNEL_ENCAP_SEG6))
+ #define XLAT_STR_5 STRINGIFY(LWTUNNEL_ENCAP_SEG6)
  [LWTUNNEL_ENCAP_BPF] = XLAT(LWTUNNEL_ENCAP_BPF),
+ #define XLAT_VAL_6 ((unsigned) (LWTUNNEL_ENCAP_BPF))
+ #define XLAT_STR_6 STRINGIFY(LWTUNNEL_ENCAP_BPF)
+ [LWTUNNEL_ENCAP_SEG6_LOCAL] = XLAT(LWTUNNEL_ENCAP_SEG6_LOCAL),
+ #define XLAT_VAL_7 ((unsigned) (LWTUNNEL_ENCAP_SEG6_LOCAL))
+ #define XLAT_STR_7 STRINGIFY(LWTUNNEL_ENCAP_SEG6_LOCAL)
+ [LWTUNNEL_ENCAP_RPL] = XLAT(LWTUNNEL_ENCAP_RPL),
+ #define XLAT_VAL_8 ((unsigned) (LWTUNNEL_ENCAP_RPL))
+ #define XLAT_STR_8 STRINGIFY(LWTUNNEL_ENCAP_RPL)
 };
 static
 const struct xlat lwtunnel_encap_types[1] = { {
  .data = lwtunnel_encap_types_xdata,
  .size = ARRAY_SIZE(lwtunnel_encap_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/lwtunnel_encap_types.in 5.9-0ubuntu2/xlat/lwtunnel_encap_types.in
--- 5.5-3/xlat/lwtunnel_encap_types.in	2019-08-14 19:05:08.000000000 +0000
+++ 5.9-0ubuntu2/xlat/lwtunnel_encap_types.in	2020-04-15 13:39:57.000000000 +0000
@@ -1,8 +1,10 @@
 #value_indexed
-LWTUNNEL_ENCAP_NONE	0
-LWTUNNEL_ENCAP_MPLS	1
-LWTUNNEL_ENCAP_IP	2
-LWTUNNEL_ENCAP_ILA	3
-LWTUNNEL_ENCAP_IP6	4
-LWTUNNEL_ENCAP_SEG6	5
-LWTUNNEL_ENCAP_BPF	6
+LWTUNNEL_ENCAP_NONE		0
+LWTUNNEL_ENCAP_MPLS		1
+LWTUNNEL_ENCAP_IP		2
+LWTUNNEL_ENCAP_ILA		3
+LWTUNNEL_ENCAP_IP6		4
+LWTUNNEL_ENCAP_SEG6		5
+LWTUNNEL_ENCAP_BPF		6
+LWTUNNEL_ENCAP_SEG6_LOCAL	7
+LWTUNNEL_ENCAP_RPL		8
diff -pruN 5.5-3/xlat/madvise_cmds.h 5.9-0ubuntu2/xlat/madvise_cmds.h
--- 5.5-3/xlat/madvise_cmds.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/madvise_cmds.h	2020-09-24 09:18:45.000000000 +0000
@@ -253,90 +253,394 @@ static const struct xlat_data madvise_cm
 
 
  XLAT(MADV_NORMAL),
+ #define XLAT_VAL_0 ((unsigned) (MADV_NORMAL))
+ #define XLAT_STR_0 STRINGIFY(MADV_NORMAL)
 
  XLAT(MADV_RANDOM),
+ #define XLAT_VAL_1 ((unsigned) (MADV_RANDOM))
+ #define XLAT_STR_1 STRINGIFY(MADV_RANDOM)
 
  XLAT(MADV_SEQUENTIAL),
+ #define XLAT_VAL_2 ((unsigned) (MADV_SEQUENTIAL))
+ #define XLAT_STR_2 STRINGIFY(MADV_SEQUENTIAL)
 
  XLAT(MADV_WILLNEED),
+ #define XLAT_VAL_3 ((unsigned) (MADV_WILLNEED))
+ #define XLAT_STR_3 STRINGIFY(MADV_WILLNEED)
 
 #if defined __alpha__
  XLAT(MADV_DONTNEED),
+ #define XLAT_VAL_4 ((unsigned) (MADV_DONTNEED))
+ #define XLAT_STR_4 STRINGIFY(MADV_DONTNEED)
 #else
  XLAT(MADV_DONTNEED),
+ #define XLAT_VAL_5 ((unsigned) (MADV_DONTNEED))
+ #define XLAT_STR_5 STRINGIFY(MADV_DONTNEED)
 #endif
 
  XLAT(MADV_FREE),
+ #define XLAT_VAL_6 ((unsigned) (MADV_FREE))
+ #define XLAT_STR_6 STRINGIFY(MADV_FREE)
 
  XLAT(MADV_REMOVE),
+ #define XLAT_VAL_7 ((unsigned) (MADV_REMOVE))
+ #define XLAT_STR_7 STRINGIFY(MADV_REMOVE)
 
  XLAT(MADV_DONTFORK),
+ #define XLAT_VAL_8 ((unsigned) (MADV_DONTFORK))
+ #define XLAT_STR_8 STRINGIFY(MADV_DONTFORK)
 
  XLAT(MADV_DOFORK),
+ #define XLAT_VAL_9 ((unsigned) (MADV_DOFORK))
+ #define XLAT_STR_9 STRINGIFY(MADV_DOFORK)
 
 #if defined __hppa__
  XLAT(MADV_MERGEABLE),
+ #define XLAT_VAL_10 ((unsigned) (MADV_MERGEABLE))
+ #define XLAT_STR_10 STRINGIFY(MADV_MERGEABLE)
 #else
  XLAT(MADV_MERGEABLE),
+ #define XLAT_VAL_11 ((unsigned) (MADV_MERGEABLE))
+ #define XLAT_STR_11 STRINGIFY(MADV_MERGEABLE)
 #endif
 
 #if defined __hppa__
  XLAT(MADV_UNMERGEABLE),
+ #define XLAT_VAL_12 ((unsigned) (MADV_UNMERGEABLE))
+ #define XLAT_STR_12 STRINGIFY(MADV_UNMERGEABLE)
 #else
  XLAT(MADV_UNMERGEABLE),
+ #define XLAT_VAL_13 ((unsigned) (MADV_UNMERGEABLE))
+ #define XLAT_STR_13 STRINGIFY(MADV_UNMERGEABLE)
 #endif
 
 #if defined __hppa__
  XLAT(MADV_HUGEPAGE),
+ #define XLAT_VAL_14 ((unsigned) (MADV_HUGEPAGE))
+ #define XLAT_STR_14 STRINGIFY(MADV_HUGEPAGE)
 #else
  XLAT(MADV_HUGEPAGE),
+ #define XLAT_VAL_15 ((unsigned) (MADV_HUGEPAGE))
+ #define XLAT_STR_15 STRINGIFY(MADV_HUGEPAGE)
 #endif
 
 #if defined __hppa__
  XLAT(MADV_NOHUGEPAGE),
+ #define XLAT_VAL_16 ((unsigned) (MADV_NOHUGEPAGE))
+ #define XLAT_STR_16 STRINGIFY(MADV_NOHUGEPAGE)
 #else
  XLAT(MADV_NOHUGEPAGE),
+ #define XLAT_VAL_17 ((unsigned) (MADV_NOHUGEPAGE))
+ #define XLAT_STR_17 STRINGIFY(MADV_NOHUGEPAGE)
 #endif
 
 #if defined __hppa__
  XLAT(MADV_DONTDUMP),
+ #define XLAT_VAL_18 ((unsigned) (MADV_DONTDUMP))
+ #define XLAT_STR_18 STRINGIFY(MADV_DONTDUMP)
 #else
  XLAT(MADV_DONTDUMP),
+ #define XLAT_VAL_19 ((unsigned) (MADV_DONTDUMP))
+ #define XLAT_STR_19 STRINGIFY(MADV_DONTDUMP)
 #endif
 
 #if defined __hppa__
  XLAT(MADV_DODUMP),
+ #define XLAT_VAL_20 ((unsigned) (MADV_DODUMP))
+ #define XLAT_STR_20 STRINGIFY(MADV_DODUMP)
 #else
  XLAT(MADV_DODUMP),
+ #define XLAT_VAL_21 ((unsigned) (MADV_DODUMP))
+ #define XLAT_STR_21 STRINGIFY(MADV_DODUMP)
 #endif
 
 #if defined __hppa__
  XLAT(MADV_WIPEONFORK),
+ #define XLAT_VAL_22 ((unsigned) (MADV_WIPEONFORK))
+ #define XLAT_STR_22 STRINGIFY(MADV_WIPEONFORK)
 #else
  XLAT(MADV_WIPEONFORK),
+ #define XLAT_VAL_23 ((unsigned) (MADV_WIPEONFORK))
+ #define XLAT_STR_23 STRINGIFY(MADV_WIPEONFORK)
 #endif
 
 #if defined __hppa__
  XLAT(MADV_KEEPONFORK),
+ #define XLAT_VAL_24 ((unsigned) (MADV_KEEPONFORK))
+ #define XLAT_STR_24 STRINGIFY(MADV_KEEPONFORK)
 #else
  XLAT(MADV_KEEPONFORK),
+ #define XLAT_VAL_25 ((unsigned) (MADV_KEEPONFORK))
+ #define XLAT_STR_25 STRINGIFY(MADV_KEEPONFORK)
 #endif
 
  XLAT(MADV_COLD),
+ #define XLAT_VAL_26 ((unsigned) (MADV_COLD))
+ #define XLAT_STR_26 STRINGIFY(MADV_COLD)
 
  XLAT(MADV_PAGEOUT),
+ #define XLAT_VAL_27 ((unsigned) (MADV_PAGEOUT))
+ #define XLAT_STR_27 STRINGIFY(MADV_PAGEOUT)
 
  XLAT(MADV_HWPOISON),
+ #define XLAT_VAL_28 ((unsigned) (MADV_HWPOISON))
+ #define XLAT_STR_28 STRINGIFY(MADV_HWPOISON)
 
  XLAT(MADV_SOFT_OFFLINE),
+ #define XLAT_VAL_29 ((unsigned) (MADV_SOFT_OFFLINE))
+ #define XLAT_STR_29 STRINGIFY(MADV_SOFT_OFFLINE)
 };
 static
 const struct xlat madvise_cmds[1] = { {
  .data = madvise_cmds_xdata,
  .size = ARRAY_SIZE(madvise_cmds_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/Makemodule.am 5.9-0ubuntu2/xlat/Makemodule.am
--- 5.5-3/xlat/Makemodule.am	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/Makemodule.am	2020-09-24 09:18:46.000000000 +0000
@@ -1,6 +1,6 @@
-XLAT_INPUT_FILES = xlat/access_flags.in xlat/addrfams.in xlat/adjtimex_modes.in xlat/adjtimex_state.in xlat/adjtimex_status.in xlat/advise.in xlat/af_packet_types.in xlat/af_packet_versions.in xlat/aio_cmds.in xlat/aio_iocb_flags.in xlat/archvals.in xlat/arp_hardware_types.in xlat/at_flags.in xlat/at_statx_sync_types.in xlat/atomic_ops.in xlat/audit_arch.in xlat/ax25_protocols.in xlat/baud_options.in xlat/bdaddr_types.in xlat/blkpg_ops.in xlat/block_ioctl_cmds.in xlat/bluetooth_l2_cid.in xlat/bluetooth_l2_psm.in xlat/bootflags1.in xlat/bootflags2.in xlat/bootflags3.in xlat/bpf_attach_flags.in xlat/bpf_attach_type.in xlat/bpf_class.in xlat/bpf_commands.in xlat/bpf_file_mode_flags.in xlat/bpf_map_flags.in xlat/bpf_map_lookup_elem_flags.in xlat/bpf_map_types.in xlat/bpf_map_update_elem_flags.in xlat/bpf_miscop.in xlat/bpf_mode.in xlat/bpf_op_alu.in xlat/bpf_op_jmp.in xlat/bpf_prog_flags.in xlat/bpf_prog_types.in xlat/bpf_query_flags.in xlat/bpf_rval.in xlat/bpf_size.in xlat/bpf_src.in xlat/bpf_task_fd_type.in xlat/bsg_flags.in xlat/bsg_protocol.in xlat/bsg_subprotocol.in xlat/bt_protocols.in xlat/btrfs_balance_args.in xlat/btrfs_balance_ctl_cmds.in xlat/btrfs_balance_flags.in xlat/btrfs_balance_state.in xlat/btrfs_compress_types.in xlat/btrfs_cont_reading_from_srcdev_mode.in xlat/btrfs_defrag_flags.in xlat/btrfs_dev_replace_cmds.in xlat/btrfs_dev_replace_results.in xlat/btrfs_dev_replace_state.in xlat/btrfs_dev_stats_flags.in xlat/btrfs_dev_stats_values.in xlat/btrfs_features_compat.in xlat/btrfs_features_compat_ro.in xlat/btrfs_features_incompat.in xlat/btrfs_key_types.in xlat/btrfs_logical_ino_args_flags.in xlat/btrfs_qgroup_ctl_cmds.in xlat/btrfs_qgroup_inherit_flags.in xlat/btrfs_qgroup_limit_flags.in xlat/btrfs_qgroup_status_flags.in xlat/btrfs_scrub_flags.in xlat/btrfs_send_flags.in xlat/btrfs_snap_flags_v2.in xlat/btrfs_space_info_flags.in xlat/btrfs_tree_objectids.in xlat/cacheflush_flags.in xlat/cacheflush_scope.in xlat/caif_protocols.in xlat/can_protocols.in xlat/cap.in xlat/cap_mask0.in xlat/cap_mask1.in xlat/cap_version.in xlat/clockflags.in xlat/clocknames.in xlat/clone3_flags.in xlat/clone_flags.in xlat/cpuclocknames.in xlat/crypto_msgs.in xlat/crypto_nl_attrs.in xlat/dcb_commands.in xlat/delete_module_flags.in xlat/dirent_types.in xlat/dm_flags.in xlat/ebpf_class.in xlat/ebpf_mode.in xlat/ebpf_op_alu.in xlat/ebpf_op_jmp.in xlat/ebpf_regs.in xlat/ebpf_size.in xlat/efd_flags.in xlat/elf_em.in xlat/epollctls.in xlat/epollevents.in xlat/epollflags.in xlat/ethernet_protocols.in xlat/evdev_abs.in xlat/evdev_autorepeat.in xlat/evdev_ev.in xlat/evdev_ff_status.in xlat/evdev_ff_types.in xlat/evdev_ioctl_cmds.in xlat/evdev_keycode.in xlat/evdev_leds.in xlat/evdev_misc.in xlat/evdev_mtslots.in xlat/evdev_prop.in xlat/evdev_relative_axes.in xlat/evdev_snd.in xlat/evdev_switch.in xlat/f_owner_types.in xlat/f_seals.in xlat/falloc_flags.in xlat/fan_classes.in xlat/fan_event_flags.in xlat/fan_init_flags.in xlat/fan_mark_flags.in xlat/fcntlcmds.in xlat/fdflags.in xlat/fib_rule_actions.in xlat/fib_rule_flags.in xlat/fiemap_extent_flags.in xlat/fiemap_flags.in xlat/flockcmds.in xlat/fsconfig_cmds.in xlat/fsmagic.in xlat/fsmount_flags.in xlat/fsopen_flags.in xlat/fspick_flags.in xlat/futexbitset.in xlat/futexops.in xlat/futexwakecmps.in xlat/futexwakeops.in xlat/get_mempolicy_flags.in xlat/getrandom_flags.in xlat/getsock_ip_options.in xlat/getsock_ipv6_options.in xlat/getsock_options.in xlat/hci_channels.in xlat/hw_breakpoint_len.in xlat/hw_breakpoint_type.in xlat/icmpfilterflags.in xlat/if_dqblk_valid.in xlat/if_dqinfo_flags.in xlat/if_dqinfo_valid.in xlat/ifaddrflags.in xlat/iffflags.in xlat/in6_addr_gen_mode.in xlat/inet6_devconf_indices.in xlat/inet6_if_flags.in xlat/inet_devconf_indices.in xlat/inet_diag_attrs.in xlat/inet_diag_bytecodes.in xlat/inet_diag_extended_flags.in xlat/inet_diag_req_attrs.in xlat/inet_protocols.in xlat/inotify_flags.in xlat/inotify_init_flags.in xlat/ioctl_dirs.in xlat/ioprio_class.in xlat/ioprio_who.in xlat/ip_cmsg_types.in xlat/ip_type_of_services.in xlat/ipc_msg_flags.in xlat/ipc_private.in xlat/ipccalls.in xlat/irda_protocols.in xlat/isdn_protocols.in xlat/itimer_which.in xlat/kcm_protocols.in xlat/kcmp_types.in xlat/kexec_arch_values.in xlat/kexec_file_load_flags.in xlat/kexec_load_flags.in xlat/key_perms.in xlat/key_reqkeys.in xlat/key_spec.in xlat/keyctl_caps0.in xlat/keyctl_caps1.in xlat/keyctl_commands.in xlat/keyctl_move_flags.in xlat/keyctl_pkey_ops.in xlat/kvm_cap.in xlat/kvm_cpuid_flags.in xlat/kvm_exit_reason.in xlat/kvm_mem_flags.in xlat/lockfcmds.in xlat/loop_cmds.in xlat/loop_crypt_type_options.in xlat/loop_flags_options.in xlat/lwtunnel_encap_types.in xlat/madvise_cmds.in xlat/mbind_flags.in xlat/mctl_sync.in xlat/mdb_flags.in xlat/mdb_states.in xlat/membarrier_cmds.in xlat/memfd_create_flags.in xlat/mlock_flags.in xlat/mlockall_flags.in xlat/mmap_flags.in xlat/mmap_prot.in xlat/modem_flags.in xlat/modetypes.in xlat/module_init_flags.in xlat/mount_attr_flags.in xlat/mount_flags.in xlat/move_mount_flags.in xlat/move_pages_flags.in xlat/mpol_mode_flags.in xlat/mpol_modes.in xlat/mq_attr_flags.in xlat/mremap_flags.in xlat/msg_flags.in xlat/msgctl_flags.in xlat/mtd_file_mode_options.in xlat/mtd_flags_options.in xlat/mtd_mode_options.in xlat/mtd_nandecc_options.in xlat/mtd_otp_options.in xlat/mtd_type_options.in xlat/multicast_router_types.in xlat/name_to_handle_at_flags.in xlat/nbd_ioctl_cmds.in xlat/nbd_ioctl_flags.in xlat/neighbor_cache_entry_flags.in xlat/neighbor_cache_entry_states.in xlat/netfilter_versions.in xlat/netlink_ack_flags.in xlat/netlink_delete_flags.in xlat/netlink_diag_attrs.in xlat/netlink_diag_show.in xlat/netlink_flags.in xlat/netlink_get_flags.in xlat/netlink_new_flags.in xlat/netlink_protocols.in xlat/netlink_sk_meminfo_indices.in xlat/netlink_socket_flags.in xlat/netlink_states.in xlat/netlink_types.in xlat/nf_acct_msg_types.in xlat/nf_cthelper_msg_types.in xlat/nf_ctnetlink_exp_msg_types.in xlat/nf_ctnetlink_msg_types.in xlat/nf_cttimeout_msg_types.in xlat/nf_ipset_msg_types.in xlat/nf_nft_compat_msg_types.in xlat/nf_nftables_msg_types.in xlat/nf_osf_msg_types.in xlat/nf_queue_msg_types.in xlat/nf_ulog_msg_types.in xlat/nfc_protocols.in xlat/nl_audit_types.in xlat/nl_crypto_types.in xlat/nl_netfilter_msg_types.in xlat/nl_netfilter_subsys_ids.in xlat/nl_route_types.in xlat/nl_selinux_types.in xlat/nl_sock_diag_types.in xlat/nl_xfrm_types.in xlat/nlmsgerr_attrs.in xlat/notifyflags.in xlat/nt_descriptor_types.in xlat/numa_node.in xlat/open_access_modes.in xlat/open_mode_flags.in xlat/open_tree_flags.in xlat/packet_diag_attrs.in xlat/packet_diag_info_flags.in xlat/packet_diag_show.in xlat/packet_mreq_type.in xlat/perf_attr_size.in xlat/perf_branch_sample_type.in xlat/perf_event_open_flags.in xlat/perf_event_read_format.in xlat/perf_event_sample_format.in xlat/perf_hw_cache_id.in xlat/perf_hw_cache_op_id.in xlat/perf_hw_cache_op_result_id.in xlat/perf_hw_id.in xlat/perf_ioctl_cmds.in xlat/perf_ioctl_flags.in xlat/perf_sw_ids.in xlat/perf_type_id.in xlat/personality_flags.in xlat/personality_types.in xlat/phonet_protocols.in xlat/pkey_access.in xlat/pollflags.in xlat/pr_cap_ambient.in xlat/pr_dumpable.in xlat/pr_fp_mode.in xlat/pr_mce_kill.in xlat/pr_mce_kill_policy.in xlat/pr_set_mm.in xlat/pr_spec_cmds.in xlat/pr_spec_get_store_bypass_flags.in xlat/pr_spec_set_store_bypass_flags.in xlat/pr_sve_vl_flags.in xlat/pr_tsc.in xlat/pr_unalign_flags.in xlat/prctl_options.in xlat/priorities.in xlat/ptp_extts_flags.in xlat/ptp_perout_flags.in xlat/ptrace_cmds.in xlat/ptrace_events.in xlat/ptrace_peeksiginfo_flags.in xlat/ptrace_setoptions_flags.in xlat/ptrace_syscall_info_op.in xlat/quota_formats.in xlat/quotacmds.in xlat/quotatypes.in xlat/random_ioctl_cmds.in xlat/rename_flags.in xlat/resource_flags.in xlat/resources.in xlat/riscv_flush_icache_flags.in xlat/route_nexthop_flags.in xlat/routing_flags.in xlat/routing_protocols.in xlat/routing_scopes.in xlat/routing_table_ids.in xlat/routing_types.in xlat/rtnl_addr_attrs.in xlat/rtnl_addrlabel_attrs.in xlat/rtnl_dcb_attrs.in xlat/rtnl_ifla_af_spec_inet6_attrs.in xlat/rtnl_ifla_af_spec_inet_attrs.in xlat/rtnl_ifla_brport_attrs.in xlat/rtnl_ifla_events.in xlat/rtnl_ifla_info_attrs.in xlat/rtnl_ifla_info_data_bridge_attrs.in xlat/rtnl_ifla_info_data_tun_attrs.in xlat/rtnl_ifla_port_attrs.in xlat/rtnl_ifla_vf_port_attrs.in xlat/rtnl_ifla_xdp_attached_mode.in xlat/rtnl_ifla_xdp_attrs.in xlat/rtnl_link_attrs.in xlat/rtnl_mdb_attrs.in xlat/rtnl_mdba_mdb_attrs.in xlat/rtnl_mdba_mdb_eattr_attrs.in xlat/rtnl_mdba_mdb_entry_attrs.in xlat/rtnl_mdba_router_attrs.in xlat/rtnl_mdba_router_pattr_attrs.in xlat/rtnl_neigh_attrs.in xlat/rtnl_neightbl_attrs.in xlat/rtnl_neightbl_parms_attrs.in xlat/rtnl_netconf_attrs.in xlat/rtnl_nsid_attrs.in xlat/rtnl_route_attrs.in xlat/rtnl_rta_metrics_attrs.in xlat/rtnl_rule_attrs.in xlat/rtnl_tc_action_attrs.in xlat/rtnl_tc_attrs.in xlat/rtnl_tca_act_flags.in xlat/rtnl_tca_stab_attrs.in xlat/rtnl_tca_stats_attrs.in xlat/rwf_flags.in xlat/s390_guarded_storage_commands.in xlat/s390_runtime_instr_commands.in xlat/s390_sthyi_function_codes.in xlat/sa_handler_values.in xlat/sched_flags.in xlat/schedulers.in xlat/scmvals.in xlat/scsi_sg_commands.in xlat/secbits.in xlat/seccomp_filter_flags.in xlat/seccomp_mode.in xlat/seccomp_ops.in xlat/seccomp_ret_action.in xlat/semctl_flags.in xlat/semop_flags.in xlat/setns_types.in xlat/setsock_ip_options.in xlat/setsock_ipv6_options.in xlat/setsock_options.in xlat/sfd_flags.in xlat/sg_io_dxfer_direction.in xlat/sg_io_flags.in xlat/sg_io_info.in xlat/sg_scsi_reset.in xlat/shm_flags.in xlat/shm_resource_flags.in xlat/shmctl_flags.in xlat/shutdown_modes.in xlat/sigact_flags.in xlat/sigaltstack_flags.in xlat/sigbus_codes.in xlat/sigchld_codes.in xlat/sigemt_codes.in xlat/sigev_value.in xlat/sigfpe_codes.in xlat/sigill_codes.in xlat/siginfo_codes.in xlat/sigpoll_codes.in xlat/sigprocmaskcmds.in xlat/sigprof_codes.in xlat/sigsegv_codes.in xlat/sigsys_codes.in xlat/sigtrap_codes.in xlat/skf_ad.in xlat/skf_off.in xlat/smc_decl_codes.in xlat/smc_diag_attrs.in xlat/smc_diag_extended_flags.in xlat/smc_diag_mode.in xlat/smc_link_group_roles.in xlat/smc_protocols.in xlat/smc_states.in xlat/snmp_icmp6_stats.in xlat/snmp_ip_stats.in xlat/sock_alg_options.in xlat/sock_ax25_options.in xlat/sock_bluetooth_options.in xlat/sock_caif_options.in xlat/sock_dccp_options.in xlat/sock_ip_options.in xlat/sock_ipv6_options.in xlat/sock_ipx_options.in xlat/sock_irda_options.in xlat/sock_iucv_options.in xlat/sock_kcm_options.in xlat/sock_llc_options.in xlat/sock_netlink_options.in xlat/sock_nfcllcp_options.in xlat/sock_options.in xlat/sock_packet_options.in xlat/sock_pnp_options.in xlat/sock_pppol2tp_options.in xlat/sock_raw_options.in xlat/sock_rds_options.in xlat/sock_rxrpc_options.in xlat/sock_sctp_options.in xlat/sock_shutdown_flags.in xlat/sock_tcp_options.in xlat/sock_tipc_options.in xlat/sock_tls_options.in xlat/sock_type_flags.in xlat/sock_udp_options.in xlat/sock_xdp_options.in xlat/socketcalls.in xlat/socketlayers.in xlat/socktypes.in xlat/sparc_kern_features.in xlat/splice_flags.in xlat/sram_alloc_flags.in xlat/statfs_flags.in xlat/statx_attrs.in xlat/statx_masks.in xlat/swap_flags.in xlat/sync_file_range_flags.in xlat/sysctl_kern.in xlat/sysctl_net.in xlat/sysctl_net_core.in xlat/sysctl_net_ipv4.in xlat/sysctl_net_ipv4_conf.in xlat/sysctl_net_ipv4_route.in xlat/sysctl_net_ipv6.in xlat/sysctl_net_ipv6_route.in xlat/sysctl_net_unix.in xlat/sysctl_root.in xlat/sysctl_vm.in xlat/syslog_action_type.in xlat/syslog_console_levels.in xlat/sysmips_operations.in xlat/tcflsh_options.in xlat/tcp_state_flags.in xlat/tcp_states.in xlat/tcxonc_options.in xlat/timerfdflags.in xlat/tun_device_types.in xlat/ubi_volume_props.in xlat/ubi_volume_types.in xlat/uffd_api_features.in xlat/uffd_api_flags.in xlat/uffd_copy_flags.in xlat/uffd_flags.in xlat/uffd_register_ioctl_flags.in xlat/uffd_register_mode_flags.in xlat/uffd_zeropage_flags.in xlat/umount_flags.in xlat/unix_diag_attrs.in xlat/unix_diag_show.in xlat/unshare_flags.in xlat/uring_enter_flags.in xlat/uring_register_opcodes.in xlat/uring_setup_features.in xlat/uring_setup_flags.in xlat/usagewho.in xlat/v4l2_buf_flags.in xlat/v4l2_buf_types.in xlat/v4l2_capture_modes.in xlat/v4l2_colorspaces.in xlat/v4l2_control_classes.in xlat/v4l2_control_flags.in xlat/v4l2_control_id_bases.in xlat/v4l2_control_ids.in xlat/v4l2_control_types.in xlat/v4l2_device_capabilities_flags.in xlat/v4l2_fields.in xlat/v4l2_format_description_flags.in xlat/v4l2_frameinterval_types.in xlat/v4l2_framesize_types.in xlat/v4l2_input_types.in xlat/v4l2_memories.in xlat/v4l2_pix_fmts.in xlat/v4l2_sdr_fmts.in xlat/v4l2_sliced_flags.in xlat/v4l2_streaming_capabilities.in xlat/v4l2_tuner_audmodes.in xlat/v4l2_tuner_capabilities.in xlat/v4l2_tuner_rxsubchanses.in xlat/v4l2_tuner_types.in xlat/v4l2_vbi_flags.in xlat/wait4_options.in xlat/waitid_types.in xlat/watchdog_ioctl_cmds.in xlat/whence_codes.in xlat/xattrflags.in xlat/xdp_flags.in xlat/xfs_dqblk_flags.in xlat/xfs_quota_flags.in 
-XLAT_HEADER_FILES = xlat/access_flags.h xlat/addrfams.h xlat/adjtimex_modes.h xlat/adjtimex_state.h xlat/adjtimex_status.h xlat/advise.h xlat/af_packet_types.h xlat/af_packet_versions.h xlat/aio_cmds.h xlat/aio_iocb_flags.h xlat/archvals.h xlat/arp_hardware_types.h xlat/at_flags.h xlat/at_statx_sync_types.h xlat/atomic_ops.h xlat/audit_arch.h xlat/ax25_protocols.h xlat/baud_options.h xlat/bdaddr_types.h xlat/blkpg_ops.h xlat/block_ioctl_cmds.h xlat/bluetooth_l2_cid.h xlat/bluetooth_l2_psm.h xlat/bootflags1.h xlat/bootflags2.h xlat/bootflags3.h xlat/bpf_attach_flags.h xlat/bpf_attach_type.h xlat/bpf_class.h xlat/bpf_commands.h xlat/bpf_file_mode_flags.h xlat/bpf_map_flags.h xlat/bpf_map_lookup_elem_flags.h xlat/bpf_map_types.h xlat/bpf_map_update_elem_flags.h xlat/bpf_miscop.h xlat/bpf_mode.h xlat/bpf_op_alu.h xlat/bpf_op_jmp.h xlat/bpf_prog_flags.h xlat/bpf_prog_types.h xlat/bpf_query_flags.h xlat/bpf_rval.h xlat/bpf_size.h xlat/bpf_src.h xlat/bpf_task_fd_type.h xlat/bsg_flags.h xlat/bsg_protocol.h xlat/bsg_subprotocol.h xlat/bt_protocols.h xlat/btrfs_balance_args.h xlat/btrfs_balance_ctl_cmds.h xlat/btrfs_balance_flags.h xlat/btrfs_balance_state.h xlat/btrfs_compress_types.h xlat/btrfs_cont_reading_from_srcdev_mode.h xlat/btrfs_defrag_flags.h xlat/btrfs_dev_replace_cmds.h xlat/btrfs_dev_replace_results.h xlat/btrfs_dev_replace_state.h xlat/btrfs_dev_stats_flags.h xlat/btrfs_dev_stats_values.h xlat/btrfs_features_compat.h xlat/btrfs_features_compat_ro.h xlat/btrfs_features_incompat.h xlat/btrfs_key_types.h xlat/btrfs_logical_ino_args_flags.h xlat/btrfs_qgroup_ctl_cmds.h xlat/btrfs_qgroup_inherit_flags.h xlat/btrfs_qgroup_limit_flags.h xlat/btrfs_qgroup_status_flags.h xlat/btrfs_scrub_flags.h xlat/btrfs_send_flags.h xlat/btrfs_snap_flags_v2.h xlat/btrfs_space_info_flags.h xlat/btrfs_tree_objectids.h xlat/cacheflush_flags.h xlat/cacheflush_scope.h xlat/caif_protocols.h xlat/can_protocols.h xlat/cap.h xlat/cap_mask0.h xlat/cap_mask1.h xlat/cap_version.h xlat/clockflags.h xlat/clocknames.h xlat/clone3_flags.h xlat/clone_flags.h xlat/cpuclocknames.h xlat/crypto_msgs.h xlat/crypto_nl_attrs.h xlat/dcb_commands.h xlat/delete_module_flags.h xlat/dirent_types.h xlat/dm_flags.h xlat/ebpf_class.h xlat/ebpf_mode.h xlat/ebpf_op_alu.h xlat/ebpf_op_jmp.h xlat/ebpf_regs.h xlat/ebpf_size.h xlat/efd_flags.h xlat/elf_em.h xlat/epollctls.h xlat/epollevents.h xlat/epollflags.h xlat/ethernet_protocols.h xlat/evdev_abs.h xlat/evdev_autorepeat.h xlat/evdev_ev.h xlat/evdev_ff_status.h xlat/evdev_ff_types.h xlat/evdev_ioctl_cmds.h xlat/evdev_keycode.h xlat/evdev_leds.h xlat/evdev_misc.h xlat/evdev_mtslots.h xlat/evdev_prop.h xlat/evdev_relative_axes.h xlat/evdev_snd.h xlat/evdev_switch.h xlat/f_owner_types.h xlat/f_seals.h xlat/falloc_flags.h xlat/fan_classes.h xlat/fan_event_flags.h xlat/fan_init_flags.h xlat/fan_mark_flags.h xlat/fcntlcmds.h xlat/fdflags.h xlat/fib_rule_actions.h xlat/fib_rule_flags.h xlat/fiemap_extent_flags.h xlat/fiemap_flags.h xlat/flockcmds.h xlat/fsconfig_cmds.h xlat/fsmagic.h xlat/fsmount_flags.h xlat/fsopen_flags.h xlat/fspick_flags.h xlat/futexbitset.h xlat/futexops.h xlat/futexwakecmps.h xlat/futexwakeops.h xlat/get_mempolicy_flags.h xlat/getrandom_flags.h xlat/getsock_ip_options.h xlat/getsock_ipv6_options.h xlat/getsock_options.h xlat/hci_channels.h xlat/hw_breakpoint_len.h xlat/hw_breakpoint_type.h xlat/icmpfilterflags.h xlat/if_dqblk_valid.h xlat/if_dqinfo_flags.h xlat/if_dqinfo_valid.h xlat/ifaddrflags.h xlat/iffflags.h xlat/in6_addr_gen_mode.h xlat/inet6_devconf_indices.h xlat/inet6_if_flags.h xlat/inet_devconf_indices.h xlat/inet_diag_attrs.h xlat/inet_diag_bytecodes.h xlat/inet_diag_extended_flags.h xlat/inet_diag_req_attrs.h xlat/inet_protocols.h xlat/inotify_flags.h xlat/inotify_init_flags.h xlat/ioctl_dirs.h xlat/ioprio_class.h xlat/ioprio_who.h xlat/ip_cmsg_types.h xlat/ip_type_of_services.h xlat/ipc_msg_flags.h xlat/ipc_private.h xlat/ipccalls.h xlat/irda_protocols.h xlat/isdn_protocols.h xlat/itimer_which.h xlat/kcm_protocols.h xlat/kcmp_types.h xlat/kexec_arch_values.h xlat/kexec_file_load_flags.h xlat/kexec_load_flags.h xlat/key_perms.h xlat/key_reqkeys.h xlat/key_spec.h xlat/keyctl_caps0.h xlat/keyctl_caps1.h xlat/keyctl_commands.h xlat/keyctl_move_flags.h xlat/keyctl_pkey_ops.h xlat/kvm_cap.h xlat/kvm_cpuid_flags.h xlat/kvm_exit_reason.h xlat/kvm_mem_flags.h xlat/lockfcmds.h xlat/loop_cmds.h xlat/loop_crypt_type_options.h xlat/loop_flags_options.h xlat/lwtunnel_encap_types.h xlat/madvise_cmds.h xlat/mbind_flags.h xlat/mctl_sync.h xlat/mdb_flags.h xlat/mdb_states.h xlat/membarrier_cmds.h xlat/memfd_create_flags.h xlat/mlock_flags.h xlat/mlockall_flags.h xlat/mmap_flags.h xlat/mmap_prot.h xlat/modem_flags.h xlat/modetypes.h xlat/module_init_flags.h xlat/mount_attr_flags.h xlat/mount_flags.h xlat/move_mount_flags.h xlat/move_pages_flags.h xlat/mpol_mode_flags.h xlat/mpol_modes.h xlat/mq_attr_flags.h xlat/mremap_flags.h xlat/msg_flags.h xlat/msgctl_flags.h xlat/mtd_file_mode_options.h xlat/mtd_flags_options.h xlat/mtd_mode_options.h xlat/mtd_nandecc_options.h xlat/mtd_otp_options.h xlat/mtd_type_options.h xlat/multicast_router_types.h xlat/name_to_handle_at_flags.h xlat/nbd_ioctl_cmds.h xlat/nbd_ioctl_flags.h xlat/neighbor_cache_entry_flags.h xlat/neighbor_cache_entry_states.h xlat/netfilter_versions.h xlat/netlink_ack_flags.h xlat/netlink_delete_flags.h xlat/netlink_diag_attrs.h xlat/netlink_diag_show.h xlat/netlink_flags.h xlat/netlink_get_flags.h xlat/netlink_new_flags.h xlat/netlink_protocols.h xlat/netlink_sk_meminfo_indices.h xlat/netlink_socket_flags.h xlat/netlink_states.h xlat/netlink_types.h xlat/nf_acct_msg_types.h xlat/nf_cthelper_msg_types.h xlat/nf_ctnetlink_exp_msg_types.h xlat/nf_ctnetlink_msg_types.h xlat/nf_cttimeout_msg_types.h xlat/nf_ipset_msg_types.h xlat/nf_nft_compat_msg_types.h xlat/nf_nftables_msg_types.h xlat/nf_osf_msg_types.h xlat/nf_queue_msg_types.h xlat/nf_ulog_msg_types.h xlat/nfc_protocols.h xlat/nl_audit_types.h xlat/nl_crypto_types.h xlat/nl_netfilter_msg_types.h xlat/nl_netfilter_subsys_ids.h xlat/nl_route_types.h xlat/nl_selinux_types.h xlat/nl_sock_diag_types.h xlat/nl_xfrm_types.h xlat/nlmsgerr_attrs.h xlat/notifyflags.h xlat/nt_descriptor_types.h xlat/numa_node.h xlat/open_access_modes.h xlat/open_mode_flags.h xlat/open_tree_flags.h xlat/packet_diag_attrs.h xlat/packet_diag_info_flags.h xlat/packet_diag_show.h xlat/packet_mreq_type.h xlat/perf_attr_size.h xlat/perf_branch_sample_type.h xlat/perf_event_open_flags.h xlat/perf_event_read_format.h xlat/perf_event_sample_format.h xlat/perf_hw_cache_id.h xlat/perf_hw_cache_op_id.h xlat/perf_hw_cache_op_result_id.h xlat/perf_hw_id.h xlat/perf_ioctl_cmds.h xlat/perf_ioctl_flags.h xlat/perf_sw_ids.h xlat/perf_type_id.h xlat/personality_flags.h xlat/personality_types.h xlat/phonet_protocols.h xlat/pkey_access.h xlat/pollflags.h xlat/pr_cap_ambient.h xlat/pr_dumpable.h xlat/pr_fp_mode.h xlat/pr_mce_kill.h xlat/pr_mce_kill_policy.h xlat/pr_set_mm.h xlat/pr_spec_cmds.h xlat/pr_spec_get_store_bypass_flags.h xlat/pr_spec_set_store_bypass_flags.h xlat/pr_sve_vl_flags.h xlat/pr_tsc.h xlat/pr_unalign_flags.h xlat/prctl_options.h xlat/priorities.h xlat/ptp_extts_flags.h xlat/ptp_perout_flags.h xlat/ptrace_cmds.h xlat/ptrace_events.h xlat/ptrace_peeksiginfo_flags.h xlat/ptrace_setoptions_flags.h xlat/ptrace_syscall_info_op.h xlat/quota_formats.h xlat/quotacmds.h xlat/quotatypes.h xlat/random_ioctl_cmds.h xlat/rename_flags.h xlat/resource_flags.h xlat/resources.h xlat/riscv_flush_icache_flags.h xlat/route_nexthop_flags.h xlat/routing_flags.h xlat/routing_protocols.h xlat/routing_scopes.h xlat/routing_table_ids.h xlat/routing_types.h xlat/rtnl_addr_attrs.h xlat/rtnl_addrlabel_attrs.h xlat/rtnl_dcb_attrs.h xlat/rtnl_ifla_af_spec_inet6_attrs.h xlat/rtnl_ifla_af_spec_inet_attrs.h xlat/rtnl_ifla_brport_attrs.h xlat/rtnl_ifla_events.h xlat/rtnl_ifla_info_attrs.h xlat/rtnl_ifla_info_data_bridge_attrs.h xlat/rtnl_ifla_info_data_tun_attrs.h xlat/rtnl_ifla_port_attrs.h xlat/rtnl_ifla_vf_port_attrs.h xlat/rtnl_ifla_xdp_attached_mode.h xlat/rtnl_ifla_xdp_attrs.h xlat/rtnl_link_attrs.h xlat/rtnl_mdb_attrs.h xlat/rtnl_mdba_mdb_attrs.h xlat/rtnl_mdba_mdb_eattr_attrs.h xlat/rtnl_mdba_mdb_entry_attrs.h xlat/rtnl_mdba_router_attrs.h xlat/rtnl_mdba_router_pattr_attrs.h xlat/rtnl_neigh_attrs.h xlat/rtnl_neightbl_attrs.h xlat/rtnl_neightbl_parms_attrs.h xlat/rtnl_netconf_attrs.h xlat/rtnl_nsid_attrs.h xlat/rtnl_route_attrs.h xlat/rtnl_rta_metrics_attrs.h xlat/rtnl_rule_attrs.h xlat/rtnl_tc_action_attrs.h xlat/rtnl_tc_attrs.h xlat/rtnl_tca_act_flags.h xlat/rtnl_tca_stab_attrs.h xlat/rtnl_tca_stats_attrs.h xlat/rwf_flags.h xlat/s390_guarded_storage_commands.h xlat/s390_runtime_instr_commands.h xlat/s390_sthyi_function_codes.h xlat/sa_handler_values.h xlat/sched_flags.h xlat/schedulers.h xlat/scmvals.h xlat/scsi_sg_commands.h xlat/secbits.h xlat/seccomp_filter_flags.h xlat/seccomp_mode.h xlat/seccomp_ops.h xlat/seccomp_ret_action.h xlat/semctl_flags.h xlat/semop_flags.h xlat/setns_types.h xlat/setsock_ip_options.h xlat/setsock_ipv6_options.h xlat/setsock_options.h xlat/sfd_flags.h xlat/sg_io_dxfer_direction.h xlat/sg_io_flags.h xlat/sg_io_info.h xlat/sg_scsi_reset.h xlat/shm_flags.h xlat/shm_resource_flags.h xlat/shmctl_flags.h xlat/shutdown_modes.h xlat/sigact_flags.h xlat/sigaltstack_flags.h xlat/sigbus_codes.h xlat/sigchld_codes.h xlat/sigemt_codes.h xlat/sigev_value.h xlat/sigfpe_codes.h xlat/sigill_codes.h xlat/siginfo_codes.h xlat/sigpoll_codes.h xlat/sigprocmaskcmds.h xlat/sigprof_codes.h xlat/sigsegv_codes.h xlat/sigsys_codes.h xlat/sigtrap_codes.h xlat/skf_ad.h xlat/skf_off.h xlat/smc_decl_codes.h xlat/smc_diag_attrs.h xlat/smc_diag_extended_flags.h xlat/smc_diag_mode.h xlat/smc_link_group_roles.h xlat/smc_protocols.h xlat/smc_states.h xlat/snmp_icmp6_stats.h xlat/snmp_ip_stats.h xlat/sock_alg_options.h xlat/sock_ax25_options.h xlat/sock_bluetooth_options.h xlat/sock_caif_options.h xlat/sock_dccp_options.h xlat/sock_ip_options.h xlat/sock_ipv6_options.h xlat/sock_ipx_options.h xlat/sock_irda_options.h xlat/sock_iucv_options.h xlat/sock_kcm_options.h xlat/sock_llc_options.h xlat/sock_netlink_options.h xlat/sock_nfcllcp_options.h xlat/sock_options.h xlat/sock_packet_options.h xlat/sock_pnp_options.h xlat/sock_pppol2tp_options.h xlat/sock_raw_options.h xlat/sock_rds_options.h xlat/sock_rxrpc_options.h xlat/sock_sctp_options.h xlat/sock_shutdown_flags.h xlat/sock_tcp_options.h xlat/sock_tipc_options.h xlat/sock_tls_options.h xlat/sock_type_flags.h xlat/sock_udp_options.h xlat/sock_xdp_options.h xlat/socketcalls.h xlat/socketlayers.h xlat/socktypes.h xlat/sparc_kern_features.h xlat/splice_flags.h xlat/sram_alloc_flags.h xlat/statfs_flags.h xlat/statx_attrs.h xlat/statx_masks.h xlat/swap_flags.h xlat/sync_file_range_flags.h xlat/sysctl_kern.h xlat/sysctl_net.h xlat/sysctl_net_core.h xlat/sysctl_net_ipv4.h xlat/sysctl_net_ipv4_conf.h xlat/sysctl_net_ipv4_route.h xlat/sysctl_net_ipv6.h xlat/sysctl_net_ipv6_route.h xlat/sysctl_net_unix.h xlat/sysctl_root.h xlat/sysctl_vm.h xlat/syslog_action_type.h xlat/syslog_console_levels.h xlat/sysmips_operations.h xlat/tcflsh_options.h xlat/tcp_state_flags.h xlat/tcp_states.h xlat/tcxonc_options.h xlat/timerfdflags.h xlat/tun_device_types.h xlat/ubi_volume_props.h xlat/ubi_volume_types.h xlat/uffd_api_features.h xlat/uffd_api_flags.h xlat/uffd_copy_flags.h xlat/uffd_flags.h xlat/uffd_register_ioctl_flags.h xlat/uffd_register_mode_flags.h xlat/uffd_zeropage_flags.h xlat/umount_flags.h xlat/unix_diag_attrs.h xlat/unix_diag_show.h xlat/unshare_flags.h xlat/uring_enter_flags.h xlat/uring_register_opcodes.h xlat/uring_setup_features.h xlat/uring_setup_flags.h xlat/usagewho.h xlat/v4l2_buf_flags.h xlat/v4l2_buf_types.h xlat/v4l2_capture_modes.h xlat/v4l2_colorspaces.h xlat/v4l2_control_classes.h xlat/v4l2_control_flags.h xlat/v4l2_control_id_bases.h xlat/v4l2_control_ids.h xlat/v4l2_control_types.h xlat/v4l2_device_capabilities_flags.h xlat/v4l2_fields.h xlat/v4l2_format_description_flags.h xlat/v4l2_frameinterval_types.h xlat/v4l2_framesize_types.h xlat/v4l2_input_types.h xlat/v4l2_memories.h xlat/v4l2_pix_fmts.h xlat/v4l2_sdr_fmts.h xlat/v4l2_sliced_flags.h xlat/v4l2_streaming_capabilities.h xlat/v4l2_tuner_audmodes.h xlat/v4l2_tuner_capabilities.h xlat/v4l2_tuner_rxsubchanses.h xlat/v4l2_tuner_types.h xlat/v4l2_vbi_flags.h xlat/wait4_options.h xlat/waitid_types.h xlat/watchdog_ioctl_cmds.h xlat/whence_codes.h xlat/xattrflags.h xlat/xdp_flags.h xlat/xfs_dqblk_flags.h xlat/xfs_quota_flags.h 
-$(top_srcdir)/xlat/access_flags.h: $(top_srcdir)/xlat/access_flags.in $(top_srcdir)/xlat/gen.sh
+XLAT_INPUT_FILES = xlat/access_modes.in xlat/addrfams.in xlat/adjtimex_modes.in xlat/adjtimex_state.in xlat/adjtimex_status.in xlat/advise.in xlat/af_packet_types.in xlat/af_packet_versions.in xlat/aio_cmds.in xlat/aio_iocb_flags.in xlat/archvals.in xlat/arp_hardware_types.in xlat/at_flags.in xlat/at_statx_sync_types.in xlat/atomic_ops.in xlat/audit_arch.in xlat/ax25_protocols.in xlat/baud_options.in xlat/bdaddr_types.in xlat/blkpg_ops.in xlat/block_ioctl_cmds.in xlat/bluetooth_l2_cid.in xlat/bluetooth_l2_psm.in xlat/bootflags1.in xlat/bootflags2.in xlat/bootflags3.in xlat/bpf_attach_flags.in xlat/bpf_attach_type.in xlat/bpf_class.in xlat/bpf_commands.in xlat/bpf_file_mode_flags.in xlat/bpf_map_flags.in xlat/bpf_map_lookup_elem_flags.in xlat/bpf_map_types.in xlat/bpf_map_update_elem_flags.in xlat/bpf_miscop.in xlat/bpf_mode.in xlat/bpf_op_alu.in xlat/bpf_op_jmp.in xlat/bpf_prog_flags.in xlat/bpf_prog_types.in xlat/bpf_query_flags.in xlat/bpf_rval.in xlat/bpf_size.in xlat/bpf_src.in xlat/bpf_task_fd_type.in xlat/bsg_flags.in xlat/bsg_protocol.in xlat/bsg_subprotocol.in xlat/bt_protocols.in xlat/btrfs_balance_args.in xlat/btrfs_balance_ctl_cmds.in xlat/btrfs_balance_flags.in xlat/btrfs_balance_state.in xlat/btrfs_compress_types.in xlat/btrfs_cont_reading_from_srcdev_mode.in xlat/btrfs_defrag_flags.in xlat/btrfs_dev_replace_cmds.in xlat/btrfs_dev_replace_results.in xlat/btrfs_dev_replace_state.in xlat/btrfs_dev_stats_flags.in xlat/btrfs_dev_stats_values.in xlat/btrfs_features_compat.in xlat/btrfs_features_compat_ro.in xlat/btrfs_features_incompat.in xlat/btrfs_key_types.in xlat/btrfs_logical_ino_args_flags.in xlat/btrfs_qgroup_ctl_cmds.in xlat/btrfs_qgroup_inherit_flags.in xlat/btrfs_qgroup_limit_flags.in xlat/btrfs_qgroup_status_flags.in xlat/btrfs_scrub_flags.in xlat/btrfs_send_flags.in xlat/btrfs_snap_flags_v2.in xlat/btrfs_space_info_flags.in xlat/btrfs_tree_objectids.in xlat/cacheflush_flags.in xlat/cacheflush_scope.in xlat/caif_protocols.in xlat/can_protocols.in xlat/cap.in xlat/cap_mask0.in xlat/cap_mask1.in xlat/cap_version.in xlat/clockflags.in xlat/clocknames.in xlat/clone3_flags.in xlat/clone_flags.in xlat/close_range_flags.in xlat/cpuclocknames.in xlat/crypto_msgs.in xlat/crypto_nl_attrs.in xlat/dcb_commands.in xlat/delete_module_flags.in xlat/dirent_types.in xlat/dm_flags.in xlat/ebpf_class.in xlat/ebpf_mode.in xlat/ebpf_op_alu.in xlat/ebpf_op_jmp.in xlat/ebpf_regs.in xlat/ebpf_size.in xlat/efd_flags.in xlat/elf_em.in xlat/epollctls.in xlat/epollevents.in xlat/epollflags.in xlat/ethernet_protocols.in xlat/evdev_abs.in xlat/evdev_autorepeat.in xlat/evdev_ev.in xlat/evdev_ff_status.in xlat/evdev_ff_types.in xlat/evdev_ioctl_cmds.in xlat/evdev_keycode.in xlat/evdev_leds.in xlat/evdev_misc.in xlat/evdev_mtslots.in xlat/evdev_prop.in xlat/evdev_relative_axes.in xlat/evdev_snd.in xlat/evdev_switch.in xlat/f_owner_types.in xlat/f_seals.in xlat/faccessat_flags.in xlat/falloc_flags.in xlat/fan_classes.in xlat/fan_event_flags.in xlat/fan_init_flags.in xlat/fan_mark_flags.in xlat/fcntlcmds.in xlat/fdflags.in xlat/fib_rule_actions.in xlat/fib_rule_flags.in xlat/fiemap_extent_flags.in xlat/fiemap_flags.in xlat/flockcmds.in xlat/fsconfig_cmds.in xlat/fsmagic.in xlat/fsmount_flags.in xlat/fsopen_flags.in xlat/fspick_flags.in xlat/futexbitset.in xlat/futexops.in xlat/futexwakecmps.in xlat/futexwakeops.in xlat/get_mempolicy_flags.in xlat/getrandom_flags.in xlat/getsock_ip_options.in xlat/getsock_ipv6_options.in xlat/getsock_options.in xlat/hci_channels.in xlat/hdio_drive_cmds.in xlat/hw_breakpoint_len.in xlat/hw_breakpoint_type.in xlat/icmpfilterflags.in xlat/if_dqblk_valid.in xlat/if_dqinfo_flags.in xlat/if_dqinfo_valid.in xlat/ifaddrflags.in xlat/iffflags.in xlat/in6_addr_gen_mode.in xlat/inet6_devconf_indices.in xlat/inet6_if_flags.in xlat/inet_devconf_indices.in xlat/inet_diag_attrs.in xlat/inet_diag_bytecodes.in xlat/inet_diag_extended_flags.in xlat/inet_diag_req_attrs.in xlat/inet_protocols.in xlat/inotify_flags.in xlat/inotify_init_flags.in xlat/ioctl_dirs.in xlat/ioprio_class.in xlat/ioprio_who.in xlat/ip_cmsg_types.in xlat/ip_type_of_services.in xlat/ipc_msg_flags.in xlat/ipc_private.in xlat/ipccalls.in xlat/irda_protocols.in xlat/isdn_protocols.in xlat/itimer_which.in xlat/kcm_protocols.in xlat/kcmp_types.in xlat/kexec_arch_values.in xlat/kexec_file_load_flags.in xlat/kexec_load_flags.in xlat/key_perms.in xlat/key_reqkeys.in xlat/key_spec.in xlat/keyctl_caps0.in xlat/keyctl_caps1.in xlat/keyctl_commands.in xlat/keyctl_move_flags.in xlat/keyctl_pkey_ops.in xlat/kvm_cap.in xlat/kvm_cpuid_flags.in xlat/kvm_exit_reason.in xlat/kvm_mem_flags.in xlat/lockfcmds.in xlat/loop_cmds.in xlat/loop_crypt_type_options.in xlat/loop_flags_options.in xlat/lwtunnel_encap_types.in xlat/madvise_cmds.in xlat/mbind_flags.in xlat/mctl_sync.in xlat/mdb_flags.in xlat/mdb_states.in xlat/membarrier_cmds.in xlat/memfd_create_flags.in xlat/mlock_flags.in xlat/mlockall_flags.in xlat/mmap_flags.in xlat/mmap_prot.in xlat/modem_flags.in xlat/modetypes.in xlat/module_init_flags.in xlat/mount_attr_flags.in xlat/mount_flags.in xlat/move_mount_flags.in xlat/move_pages_flags.in xlat/mpol_mode_flags.in xlat/mpol_modes.in xlat/mq_attr_flags.in xlat/mremap_flags.in xlat/msg_flags.in xlat/msgctl_flags.in xlat/mtd_file_mode_options.in xlat/mtd_flags_options.in xlat/mtd_mode_options.in xlat/mtd_nandecc_options.in xlat/mtd_otp_options.in xlat/mtd_type_options.in xlat/multicast_router_types.in xlat/name_to_handle_at_flags.in xlat/nbd_ioctl_cmds.in xlat/nbd_ioctl_flags.in xlat/neighbor_cache_entry_flags.in xlat/neighbor_cache_entry_states.in xlat/netfilter_versions.in xlat/netlink_ack_flags.in xlat/netlink_delete_flags.in xlat/netlink_diag_attrs.in xlat/netlink_diag_show.in xlat/netlink_flags.in xlat/netlink_get_flags.in xlat/netlink_new_flags.in xlat/netlink_protocols.in xlat/netlink_sk_meminfo_indices.in xlat/netlink_socket_flags.in xlat/netlink_states.in xlat/netlink_types.in xlat/nf_acct_msg_types.in xlat/nf_cthelper_msg_types.in xlat/nf_ctnetlink_exp_msg_types.in xlat/nf_ctnetlink_msg_types.in xlat/nf_cttimeout_msg_types.in xlat/nf_ipset_msg_types.in xlat/nf_nft_compat_msg_types.in xlat/nf_nftables_msg_types.in xlat/nf_osf_msg_types.in xlat/nf_queue_msg_types.in xlat/nf_ulog_msg_types.in xlat/nfc_protocols.in xlat/nl_audit_types.in xlat/nl_crypto_types.in xlat/nl_netfilter_msg_types.in xlat/nl_netfilter_subsys_ids.in xlat/nl_route_types.in xlat/nl_selinux_types.in xlat/nl_sock_diag_types.in xlat/nl_xfrm_types.in xlat/nlmsgerr_attrs.in xlat/notifyflags.in xlat/nt_descriptor_types.in xlat/numa_node.in xlat/open_access_modes.in xlat/open_mode_flags.in xlat/open_resolve_flags.in xlat/open_tree_flags.in xlat/packet_diag_attrs.in xlat/packet_diag_info_flags.in xlat/packet_diag_show.in xlat/packet_mreq_type.in xlat/perf_attr_size.in xlat/perf_branch_sample_type.in xlat/perf_event_open_flags.in xlat/perf_event_read_format.in xlat/perf_event_sample_format.in xlat/perf_hw_cache_id.in xlat/perf_hw_cache_op_id.in xlat/perf_hw_cache_op_result_id.in xlat/perf_hw_id.in xlat/perf_ioctl_cmds.in xlat/perf_ioctl_flags.in xlat/perf_sw_ids.in xlat/perf_type_id.in xlat/personality_flags.in xlat/personality_types.in xlat/phonet_protocols.in xlat/pkey_access.in xlat/pollflags.in xlat/pr_cap_ambient.in xlat/pr_dumpable.in xlat/pr_fp_mode.in xlat/pr_mce_kill.in xlat/pr_mce_kill_policy.in xlat/pr_set_mm.in xlat/pr_spec_cmds.in xlat/pr_spec_get_store_bypass_flags.in xlat/pr_spec_set_store_bypass_flags.in xlat/pr_sve_vl_flags.in xlat/pr_tsc.in xlat/pr_unalign_flags.in xlat/prctl_options.in xlat/priorities.in xlat/ptp_extts_flags.in xlat/ptp_perout_flags.in xlat/ptrace_cmds.in xlat/ptrace_events.in xlat/ptrace_peeksiginfo_flags.in xlat/ptrace_setoptions_flags.in xlat/ptrace_syscall_info_op.in xlat/quota_formats.in xlat/quotacmds.in xlat/quotatypes.in xlat/random_ioctl_cmds.in xlat/rename_flags.in xlat/resource_flags.in xlat/resources.in xlat/riscv_flush_icache_flags.in xlat/route_nexthop_flags.in xlat/routing_flags.in xlat/routing_protocols.in xlat/routing_scopes.in xlat/routing_table_ids.in xlat/routing_types.in xlat/rtc_ioctl_cmds.in xlat/rtc_vl_flags.in xlat/rtnl_addr_attrs.in xlat/rtnl_addrlabel_attrs.in xlat/rtnl_dcb_attrs.in xlat/rtnl_ifla_af_spec_inet6_attrs.in xlat/rtnl_ifla_af_spec_inet_attrs.in xlat/rtnl_ifla_brport_attrs.in xlat/rtnl_ifla_events.in xlat/rtnl_ifla_info_attrs.in xlat/rtnl_ifla_info_data_bridge_attrs.in xlat/rtnl_ifla_info_data_tun_attrs.in xlat/rtnl_ifla_port_attrs.in xlat/rtnl_ifla_vf_port_attrs.in xlat/rtnl_ifla_xdp_attached_mode.in xlat/rtnl_ifla_xdp_attrs.in xlat/rtnl_link_attrs.in xlat/rtnl_mdb_attrs.in xlat/rtnl_mdba_mdb_attrs.in xlat/rtnl_mdba_mdb_eattr_attrs.in xlat/rtnl_mdba_mdb_entry_attrs.in xlat/rtnl_mdba_router_attrs.in xlat/rtnl_mdba_router_pattr_attrs.in xlat/rtnl_neigh_attrs.in xlat/rtnl_neightbl_attrs.in xlat/rtnl_neightbl_parms_attrs.in xlat/rtnl_netconf_attrs.in xlat/rtnl_nsid_attrs.in xlat/rtnl_route_attrs.in xlat/rtnl_rta_metrics_attrs.in xlat/rtnl_rule_attrs.in xlat/rtnl_tc_action_attrs.in xlat/rtnl_tc_attrs.in xlat/rtnl_tca_act_flags.in xlat/rtnl_tca_act_hw_stats.in xlat/rtnl_tca_stab_attrs.in xlat/rtnl_tca_stats_attrs.in xlat/rwf_flags.in xlat/s390_guarded_storage_commands.in xlat/s390_runtime_instr_commands.in xlat/s390_sthyi_function_codes.in xlat/sa_handler_values.in xlat/sched_flags.in xlat/schedulers.in xlat/scmvals.in xlat/scsi_sg_commands.in xlat/secbits.in xlat/seccomp_filter_flags.in xlat/seccomp_mode.in xlat/seccomp_ops.in xlat/seccomp_ret_action.in xlat/semctl_flags.in xlat/semop_flags.in xlat/setns_types.in xlat/setsock_ip_options.in xlat/setsock_ipv6_options.in xlat/setsock_options.in xlat/sfd_flags.in xlat/sg_io_dxfer_direction.in xlat/sg_io_flags.in xlat/sg_io_info.in xlat/sg_scsi_reset.in xlat/shm_flags.in xlat/shm_resource_flags.in xlat/shmctl_flags.in xlat/shutdown_modes.in xlat/sigact_flags.in xlat/sigaltstack_flags.in xlat/sigbus_codes.in xlat/sigchld_codes.in xlat/sigemt_codes.in xlat/sigev_value.in xlat/sigfpe_codes.in xlat/sigill_codes.in xlat/siginfo_codes.in xlat/sigpoll_codes.in xlat/sigprocmaskcmds.in xlat/sigprof_codes.in xlat/sigsegv_codes.in xlat/sigsys_codes.in xlat/sigtrap_codes.in xlat/skf_ad.in xlat/skf_off.in xlat/smc_decl_codes.in xlat/smc_diag_attrs.in xlat/smc_diag_extended_flags.in xlat/smc_diag_mode.in xlat/smc_link_group_roles.in xlat/smc_protocols.in xlat/smc_states.in xlat/snmp_icmp6_stats.in xlat/snmp_ip_stats.in xlat/sock_alg_options.in xlat/sock_ax25_options.in xlat/sock_bluetooth_options.in xlat/sock_caif_options.in xlat/sock_dccp_options.in xlat/sock_ip_options.in xlat/sock_ipv6_options.in xlat/sock_ipx_options.in xlat/sock_irda_options.in xlat/sock_iucv_options.in xlat/sock_kcm_options.in xlat/sock_llc_options.in xlat/sock_netlink_options.in xlat/sock_nfcllcp_options.in xlat/sock_options.in xlat/sock_packet_options.in xlat/sock_pnp_options.in xlat/sock_pppol2tp_options.in xlat/sock_raw_options.in xlat/sock_rds_options.in xlat/sock_rxrpc_options.in xlat/sock_sctp_options.in xlat/sock_shutdown_flags.in xlat/sock_tcp_options.in xlat/sock_tipc_options.in xlat/sock_tls_options.in xlat/sock_type_flags.in xlat/sock_udp_options.in xlat/sock_xdp_options.in xlat/socketcalls.in xlat/socketlayers.in xlat/socktypes.in xlat/sparc_kern_features.in xlat/splice_flags.in xlat/sram_alloc_flags.in xlat/statfs_flags.in xlat/statx_attrs.in xlat/statx_masks.in xlat/swap_flags.in xlat/sync_file_range_flags.in xlat/sysctl_kern.in xlat/sysctl_net.in xlat/sysctl_net_core.in xlat/sysctl_net_ipv4.in xlat/sysctl_net_ipv4_conf.in xlat/sysctl_net_ipv4_route.in xlat/sysctl_net_ipv6.in xlat/sysctl_net_ipv6_route.in xlat/sysctl_net_unix.in xlat/sysctl_root.in xlat/sysctl_vm.in xlat/syslog_action_type.in xlat/syslog_console_levels.in xlat/sysmips_operations.in xlat/tcflsh_options.in xlat/tcp_state_flags.in xlat/tcp_states.in xlat/tcxonc_options.in xlat/tee_ioctl_cmds.in xlat/tee_ioctl_gen_caps.in xlat/tee_ioctl_impl_ids.in xlat/tee_ioctl_login_types.in xlat/tee_ioctl_max_arg_size.in xlat/tee_ioctl_optee_caps.in xlat/tee_ioctl_origins.in xlat/tee_ioctl_param_attr_types.in xlat/tee_ioctl_shm_flags.in xlat/timerfdflags.in xlat/tun_device_types.in xlat/ubi_volume_props.in xlat/ubi_volume_types.in xlat/uffd_api_features.in xlat/uffd_api_flags.in xlat/uffd_copy_flags.in xlat/uffd_flags.in xlat/uffd_register_ioctl_flags.in xlat/uffd_register_mode_flags.in xlat/uffd_zeropage_flags.in xlat/umount_flags.in xlat/unix_diag_attrs.in xlat/unix_diag_show.in xlat/unshare_flags.in xlat/uring_cqring_flags.in xlat/uring_enter_flags.in xlat/uring_op_flags.in xlat/uring_ops.in xlat/uring_register_opcodes.in xlat/uring_setup_features.in xlat/uring_setup_flags.in xlat/usagewho.in xlat/v4l2_buf_flags.in xlat/v4l2_buf_flags_masks.in xlat/v4l2_buf_flags_ts_src.in xlat/v4l2_buf_flags_ts_type.in xlat/v4l2_buf_types.in xlat/v4l2_capture_modes.in xlat/v4l2_colorspaces.in xlat/v4l2_control_classes.in xlat/v4l2_control_flags.in xlat/v4l2_control_id_bases.in xlat/v4l2_control_ids.in xlat/v4l2_control_query_flags.in xlat/v4l2_control_types.in xlat/v4l2_device_capabilities_flags.in xlat/v4l2_fields.in xlat/v4l2_format_description_flags.in xlat/v4l2_frameinterval_types.in xlat/v4l2_framesize_types.in xlat/v4l2_input_types.in xlat/v4l2_ioctl_cmds.in xlat/v4l2_memories.in xlat/v4l2_pix_fmts.in xlat/v4l2_sdr_fmts.in xlat/v4l2_sliced_flags.in xlat/v4l2_streaming_capabilities.in xlat/v4l2_tuner_audmodes.in xlat/v4l2_tuner_capabilities.in xlat/v4l2_tuner_rxsubchanses.in xlat/v4l2_tuner_types.in xlat/v4l2_vbi_flags.in xlat/wait4_options.in xlat/waitid_types.in xlat/watchdog_ioctl_cmds.in xlat/whence_codes.in xlat/xattrflags.in xlat/xdp_flags.in xlat/xfs_dqblk_flags.in xlat/xfs_quota_flags.in 
+XLAT_HEADER_FILES = xlat/access_modes.h xlat/addrfams.h xlat/adjtimex_modes.h xlat/adjtimex_state.h xlat/adjtimex_status.h xlat/advise.h xlat/af_packet_types.h xlat/af_packet_versions.h xlat/aio_cmds.h xlat/aio_iocb_flags.h xlat/archvals.h xlat/arp_hardware_types.h xlat/at_flags.h xlat/at_statx_sync_types.h xlat/atomic_ops.h xlat/audit_arch.h xlat/ax25_protocols.h xlat/baud_options.h xlat/bdaddr_types.h xlat/blkpg_ops.h xlat/block_ioctl_cmds.h xlat/bluetooth_l2_cid.h xlat/bluetooth_l2_psm.h xlat/bootflags1.h xlat/bootflags2.h xlat/bootflags3.h xlat/bpf_attach_flags.h xlat/bpf_attach_type.h xlat/bpf_class.h xlat/bpf_commands.h xlat/bpf_file_mode_flags.h xlat/bpf_map_flags.h xlat/bpf_map_lookup_elem_flags.h xlat/bpf_map_types.h xlat/bpf_map_update_elem_flags.h xlat/bpf_miscop.h xlat/bpf_mode.h xlat/bpf_op_alu.h xlat/bpf_op_jmp.h xlat/bpf_prog_flags.h xlat/bpf_prog_types.h xlat/bpf_query_flags.h xlat/bpf_rval.h xlat/bpf_size.h xlat/bpf_src.h xlat/bpf_task_fd_type.h xlat/bsg_flags.h xlat/bsg_protocol.h xlat/bsg_subprotocol.h xlat/bt_protocols.h xlat/btrfs_balance_args.h xlat/btrfs_balance_ctl_cmds.h xlat/btrfs_balance_flags.h xlat/btrfs_balance_state.h xlat/btrfs_compress_types.h xlat/btrfs_cont_reading_from_srcdev_mode.h xlat/btrfs_defrag_flags.h xlat/btrfs_dev_replace_cmds.h xlat/btrfs_dev_replace_results.h xlat/btrfs_dev_replace_state.h xlat/btrfs_dev_stats_flags.h xlat/btrfs_dev_stats_values.h xlat/btrfs_features_compat.h xlat/btrfs_features_compat_ro.h xlat/btrfs_features_incompat.h xlat/btrfs_key_types.h xlat/btrfs_logical_ino_args_flags.h xlat/btrfs_qgroup_ctl_cmds.h xlat/btrfs_qgroup_inherit_flags.h xlat/btrfs_qgroup_limit_flags.h xlat/btrfs_qgroup_status_flags.h xlat/btrfs_scrub_flags.h xlat/btrfs_send_flags.h xlat/btrfs_snap_flags_v2.h xlat/btrfs_space_info_flags.h xlat/btrfs_tree_objectids.h xlat/cacheflush_flags.h xlat/cacheflush_scope.h xlat/caif_protocols.h xlat/can_protocols.h xlat/cap.h xlat/cap_mask0.h xlat/cap_mask1.h xlat/cap_version.h xlat/clockflags.h xlat/clocknames.h xlat/clone3_flags.h xlat/clone_flags.h xlat/close_range_flags.h xlat/cpuclocknames.h xlat/crypto_msgs.h xlat/crypto_nl_attrs.h xlat/dcb_commands.h xlat/delete_module_flags.h xlat/dirent_types.h xlat/dm_flags.h xlat/ebpf_class.h xlat/ebpf_mode.h xlat/ebpf_op_alu.h xlat/ebpf_op_jmp.h xlat/ebpf_regs.h xlat/ebpf_size.h xlat/efd_flags.h xlat/elf_em.h xlat/epollctls.h xlat/epollevents.h xlat/epollflags.h xlat/ethernet_protocols.h xlat/evdev_abs.h xlat/evdev_autorepeat.h xlat/evdev_ev.h xlat/evdev_ff_status.h xlat/evdev_ff_types.h xlat/evdev_ioctl_cmds.h xlat/evdev_keycode.h xlat/evdev_leds.h xlat/evdev_misc.h xlat/evdev_mtslots.h xlat/evdev_prop.h xlat/evdev_relative_axes.h xlat/evdev_snd.h xlat/evdev_switch.h xlat/f_owner_types.h xlat/f_seals.h xlat/faccessat_flags.h xlat/falloc_flags.h xlat/fan_classes.h xlat/fan_event_flags.h xlat/fan_init_flags.h xlat/fan_mark_flags.h xlat/fcntlcmds.h xlat/fdflags.h xlat/fib_rule_actions.h xlat/fib_rule_flags.h xlat/fiemap_extent_flags.h xlat/fiemap_flags.h xlat/flockcmds.h xlat/fsconfig_cmds.h xlat/fsmagic.h xlat/fsmount_flags.h xlat/fsopen_flags.h xlat/fspick_flags.h xlat/futexbitset.h xlat/futexops.h xlat/futexwakecmps.h xlat/futexwakeops.h xlat/get_mempolicy_flags.h xlat/getrandom_flags.h xlat/getsock_ip_options.h xlat/getsock_ipv6_options.h xlat/getsock_options.h xlat/hci_channels.h xlat/hdio_drive_cmds.h xlat/hw_breakpoint_len.h xlat/hw_breakpoint_type.h xlat/icmpfilterflags.h xlat/if_dqblk_valid.h xlat/if_dqinfo_flags.h xlat/if_dqinfo_valid.h xlat/ifaddrflags.h xlat/iffflags.h xlat/in6_addr_gen_mode.h xlat/inet6_devconf_indices.h xlat/inet6_if_flags.h xlat/inet_devconf_indices.h xlat/inet_diag_attrs.h xlat/inet_diag_bytecodes.h xlat/inet_diag_extended_flags.h xlat/inet_diag_req_attrs.h xlat/inet_protocols.h xlat/inotify_flags.h xlat/inotify_init_flags.h xlat/ioctl_dirs.h xlat/ioprio_class.h xlat/ioprio_who.h xlat/ip_cmsg_types.h xlat/ip_type_of_services.h xlat/ipc_msg_flags.h xlat/ipc_private.h xlat/ipccalls.h xlat/irda_protocols.h xlat/isdn_protocols.h xlat/itimer_which.h xlat/kcm_protocols.h xlat/kcmp_types.h xlat/kexec_arch_values.h xlat/kexec_file_load_flags.h xlat/kexec_load_flags.h xlat/key_perms.h xlat/key_reqkeys.h xlat/key_spec.h xlat/keyctl_caps0.h xlat/keyctl_caps1.h xlat/keyctl_commands.h xlat/keyctl_move_flags.h xlat/keyctl_pkey_ops.h xlat/kvm_cap.h xlat/kvm_cpuid_flags.h xlat/kvm_exit_reason.h xlat/kvm_mem_flags.h xlat/lockfcmds.h xlat/loop_cmds.h xlat/loop_crypt_type_options.h xlat/loop_flags_options.h xlat/lwtunnel_encap_types.h xlat/madvise_cmds.h xlat/mbind_flags.h xlat/mctl_sync.h xlat/mdb_flags.h xlat/mdb_states.h xlat/membarrier_cmds.h xlat/memfd_create_flags.h xlat/mlock_flags.h xlat/mlockall_flags.h xlat/mmap_flags.h xlat/mmap_prot.h xlat/modem_flags.h xlat/modetypes.h xlat/module_init_flags.h xlat/mount_attr_flags.h xlat/mount_flags.h xlat/move_mount_flags.h xlat/move_pages_flags.h xlat/mpol_mode_flags.h xlat/mpol_modes.h xlat/mq_attr_flags.h xlat/mremap_flags.h xlat/msg_flags.h xlat/msgctl_flags.h xlat/mtd_file_mode_options.h xlat/mtd_flags_options.h xlat/mtd_mode_options.h xlat/mtd_nandecc_options.h xlat/mtd_otp_options.h xlat/mtd_type_options.h xlat/multicast_router_types.h xlat/name_to_handle_at_flags.h xlat/nbd_ioctl_cmds.h xlat/nbd_ioctl_flags.h xlat/neighbor_cache_entry_flags.h xlat/neighbor_cache_entry_states.h xlat/netfilter_versions.h xlat/netlink_ack_flags.h xlat/netlink_delete_flags.h xlat/netlink_diag_attrs.h xlat/netlink_diag_show.h xlat/netlink_flags.h xlat/netlink_get_flags.h xlat/netlink_new_flags.h xlat/netlink_protocols.h xlat/netlink_sk_meminfo_indices.h xlat/netlink_socket_flags.h xlat/netlink_states.h xlat/netlink_types.h xlat/nf_acct_msg_types.h xlat/nf_cthelper_msg_types.h xlat/nf_ctnetlink_exp_msg_types.h xlat/nf_ctnetlink_msg_types.h xlat/nf_cttimeout_msg_types.h xlat/nf_ipset_msg_types.h xlat/nf_nft_compat_msg_types.h xlat/nf_nftables_msg_types.h xlat/nf_osf_msg_types.h xlat/nf_queue_msg_types.h xlat/nf_ulog_msg_types.h xlat/nfc_protocols.h xlat/nl_audit_types.h xlat/nl_crypto_types.h xlat/nl_netfilter_msg_types.h xlat/nl_netfilter_subsys_ids.h xlat/nl_route_types.h xlat/nl_selinux_types.h xlat/nl_sock_diag_types.h xlat/nl_xfrm_types.h xlat/nlmsgerr_attrs.h xlat/notifyflags.h xlat/nt_descriptor_types.h xlat/numa_node.h xlat/open_access_modes.h xlat/open_mode_flags.h xlat/open_resolve_flags.h xlat/open_tree_flags.h xlat/packet_diag_attrs.h xlat/packet_diag_info_flags.h xlat/packet_diag_show.h xlat/packet_mreq_type.h xlat/perf_attr_size.h xlat/perf_branch_sample_type.h xlat/perf_event_open_flags.h xlat/perf_event_read_format.h xlat/perf_event_sample_format.h xlat/perf_hw_cache_id.h xlat/perf_hw_cache_op_id.h xlat/perf_hw_cache_op_result_id.h xlat/perf_hw_id.h xlat/perf_ioctl_cmds.h xlat/perf_ioctl_flags.h xlat/perf_sw_ids.h xlat/perf_type_id.h xlat/personality_flags.h xlat/personality_types.h xlat/phonet_protocols.h xlat/pkey_access.h xlat/pollflags.h xlat/pr_cap_ambient.h xlat/pr_dumpable.h xlat/pr_fp_mode.h xlat/pr_mce_kill.h xlat/pr_mce_kill_policy.h xlat/pr_set_mm.h xlat/pr_spec_cmds.h xlat/pr_spec_get_store_bypass_flags.h xlat/pr_spec_set_store_bypass_flags.h xlat/pr_sve_vl_flags.h xlat/pr_tsc.h xlat/pr_unalign_flags.h xlat/prctl_options.h xlat/priorities.h xlat/ptp_extts_flags.h xlat/ptp_perout_flags.h xlat/ptrace_cmds.h xlat/ptrace_events.h xlat/ptrace_peeksiginfo_flags.h xlat/ptrace_setoptions_flags.h xlat/ptrace_syscall_info_op.h xlat/quota_formats.h xlat/quotacmds.h xlat/quotatypes.h xlat/random_ioctl_cmds.h xlat/rename_flags.h xlat/resource_flags.h xlat/resources.h xlat/riscv_flush_icache_flags.h xlat/route_nexthop_flags.h xlat/routing_flags.h xlat/routing_protocols.h xlat/routing_scopes.h xlat/routing_table_ids.h xlat/routing_types.h xlat/rtc_ioctl_cmds.h xlat/rtc_vl_flags.h xlat/rtnl_addr_attrs.h xlat/rtnl_addrlabel_attrs.h xlat/rtnl_dcb_attrs.h xlat/rtnl_ifla_af_spec_inet6_attrs.h xlat/rtnl_ifla_af_spec_inet_attrs.h xlat/rtnl_ifla_brport_attrs.h xlat/rtnl_ifla_events.h xlat/rtnl_ifla_info_attrs.h xlat/rtnl_ifla_info_data_bridge_attrs.h xlat/rtnl_ifla_info_data_tun_attrs.h xlat/rtnl_ifla_port_attrs.h xlat/rtnl_ifla_vf_port_attrs.h xlat/rtnl_ifla_xdp_attached_mode.h xlat/rtnl_ifla_xdp_attrs.h xlat/rtnl_link_attrs.h xlat/rtnl_mdb_attrs.h xlat/rtnl_mdba_mdb_attrs.h xlat/rtnl_mdba_mdb_eattr_attrs.h xlat/rtnl_mdba_mdb_entry_attrs.h xlat/rtnl_mdba_router_attrs.h xlat/rtnl_mdba_router_pattr_attrs.h xlat/rtnl_neigh_attrs.h xlat/rtnl_neightbl_attrs.h xlat/rtnl_neightbl_parms_attrs.h xlat/rtnl_netconf_attrs.h xlat/rtnl_nsid_attrs.h xlat/rtnl_route_attrs.h xlat/rtnl_rta_metrics_attrs.h xlat/rtnl_rule_attrs.h xlat/rtnl_tc_action_attrs.h xlat/rtnl_tc_attrs.h xlat/rtnl_tca_act_flags.h xlat/rtnl_tca_act_hw_stats.h xlat/rtnl_tca_stab_attrs.h xlat/rtnl_tca_stats_attrs.h xlat/rwf_flags.h xlat/s390_guarded_storage_commands.h xlat/s390_runtime_instr_commands.h xlat/s390_sthyi_function_codes.h xlat/sa_handler_values.h xlat/sched_flags.h xlat/schedulers.h xlat/scmvals.h xlat/scsi_sg_commands.h xlat/secbits.h xlat/seccomp_filter_flags.h xlat/seccomp_mode.h xlat/seccomp_ops.h xlat/seccomp_ret_action.h xlat/semctl_flags.h xlat/semop_flags.h xlat/setns_types.h xlat/setsock_ip_options.h xlat/setsock_ipv6_options.h xlat/setsock_options.h xlat/sfd_flags.h xlat/sg_io_dxfer_direction.h xlat/sg_io_flags.h xlat/sg_io_info.h xlat/sg_scsi_reset.h xlat/shm_flags.h xlat/shm_resource_flags.h xlat/shmctl_flags.h xlat/shutdown_modes.h xlat/sigact_flags.h xlat/sigaltstack_flags.h xlat/sigbus_codes.h xlat/sigchld_codes.h xlat/sigemt_codes.h xlat/sigev_value.h xlat/sigfpe_codes.h xlat/sigill_codes.h xlat/siginfo_codes.h xlat/sigpoll_codes.h xlat/sigprocmaskcmds.h xlat/sigprof_codes.h xlat/sigsegv_codes.h xlat/sigsys_codes.h xlat/sigtrap_codes.h xlat/skf_ad.h xlat/skf_off.h xlat/smc_decl_codes.h xlat/smc_diag_attrs.h xlat/smc_diag_extended_flags.h xlat/smc_diag_mode.h xlat/smc_link_group_roles.h xlat/smc_protocols.h xlat/smc_states.h xlat/snmp_icmp6_stats.h xlat/snmp_ip_stats.h xlat/sock_alg_options.h xlat/sock_ax25_options.h xlat/sock_bluetooth_options.h xlat/sock_caif_options.h xlat/sock_dccp_options.h xlat/sock_ip_options.h xlat/sock_ipv6_options.h xlat/sock_ipx_options.h xlat/sock_irda_options.h xlat/sock_iucv_options.h xlat/sock_kcm_options.h xlat/sock_llc_options.h xlat/sock_netlink_options.h xlat/sock_nfcllcp_options.h xlat/sock_options.h xlat/sock_packet_options.h xlat/sock_pnp_options.h xlat/sock_pppol2tp_options.h xlat/sock_raw_options.h xlat/sock_rds_options.h xlat/sock_rxrpc_options.h xlat/sock_sctp_options.h xlat/sock_shutdown_flags.h xlat/sock_tcp_options.h xlat/sock_tipc_options.h xlat/sock_tls_options.h xlat/sock_type_flags.h xlat/sock_udp_options.h xlat/sock_xdp_options.h xlat/socketcalls.h xlat/socketlayers.h xlat/socktypes.h xlat/sparc_kern_features.h xlat/splice_flags.h xlat/sram_alloc_flags.h xlat/statfs_flags.h xlat/statx_attrs.h xlat/statx_masks.h xlat/swap_flags.h xlat/sync_file_range_flags.h xlat/sysctl_kern.h xlat/sysctl_net.h xlat/sysctl_net_core.h xlat/sysctl_net_ipv4.h xlat/sysctl_net_ipv4_conf.h xlat/sysctl_net_ipv4_route.h xlat/sysctl_net_ipv6.h xlat/sysctl_net_ipv6_route.h xlat/sysctl_net_unix.h xlat/sysctl_root.h xlat/sysctl_vm.h xlat/syslog_action_type.h xlat/syslog_console_levels.h xlat/sysmips_operations.h xlat/tcflsh_options.h xlat/tcp_state_flags.h xlat/tcp_states.h xlat/tcxonc_options.h xlat/tee_ioctl_cmds.h xlat/tee_ioctl_gen_caps.h xlat/tee_ioctl_impl_ids.h xlat/tee_ioctl_login_types.h xlat/tee_ioctl_max_arg_size.h xlat/tee_ioctl_optee_caps.h xlat/tee_ioctl_origins.h xlat/tee_ioctl_param_attr_types.h xlat/tee_ioctl_shm_flags.h xlat/timerfdflags.h xlat/tun_device_types.h xlat/ubi_volume_props.h xlat/ubi_volume_types.h xlat/uffd_api_features.h xlat/uffd_api_flags.h xlat/uffd_copy_flags.h xlat/uffd_flags.h xlat/uffd_register_ioctl_flags.h xlat/uffd_register_mode_flags.h xlat/uffd_zeropage_flags.h xlat/umount_flags.h xlat/unix_diag_attrs.h xlat/unix_diag_show.h xlat/unshare_flags.h xlat/uring_cqring_flags.h xlat/uring_enter_flags.h xlat/uring_op_flags.h xlat/uring_ops.h xlat/uring_register_opcodes.h xlat/uring_setup_features.h xlat/uring_setup_flags.h xlat/usagewho.h xlat/v4l2_buf_flags.h xlat/v4l2_buf_flags_masks.h xlat/v4l2_buf_flags_ts_src.h xlat/v4l2_buf_flags_ts_type.h xlat/v4l2_buf_types.h xlat/v4l2_capture_modes.h xlat/v4l2_colorspaces.h xlat/v4l2_control_classes.h xlat/v4l2_control_flags.h xlat/v4l2_control_id_bases.h xlat/v4l2_control_ids.h xlat/v4l2_control_query_flags.h xlat/v4l2_control_types.h xlat/v4l2_device_capabilities_flags.h xlat/v4l2_fields.h xlat/v4l2_format_description_flags.h xlat/v4l2_frameinterval_types.h xlat/v4l2_framesize_types.h xlat/v4l2_input_types.h xlat/v4l2_ioctl_cmds.h xlat/v4l2_memories.h xlat/v4l2_pix_fmts.h xlat/v4l2_sdr_fmts.h xlat/v4l2_sliced_flags.h xlat/v4l2_streaming_capabilities.h xlat/v4l2_tuner_audmodes.h xlat/v4l2_tuner_capabilities.h xlat/v4l2_tuner_rxsubchanses.h xlat/v4l2_tuner_types.h xlat/v4l2_vbi_flags.h xlat/wait4_options.h xlat/waitid_types.h xlat/watchdog_ioctl_cmds.h xlat/whence_codes.h xlat/xattrflags.h xlat/xdp_flags.h xlat/xfs_dqblk_flags.h xlat/xfs_quota_flags.h 
+$(top_srcdir)/xlat/access_modes.h: $(top_srcdir)/xlat/access_modes.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/addrfams.h: $(top_srcdir)/xlat/addrfams.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
@@ -176,6 +176,8 @@ $(top_srcdir)/xlat/clone3_flags.h: $(top
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/clone_flags.h: $(top_srcdir)/xlat/clone_flags.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/close_range_flags.h: $(top_srcdir)/xlat/close_range_flags.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/cpuclocknames.h: $(top_srcdir)/xlat/cpuclocknames.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/crypto_msgs.h: $(top_srcdir)/xlat/crypto_msgs.in $(top_srcdir)/xlat/gen.sh
@@ -246,6 +248,8 @@ $(top_srcdir)/xlat/f_owner_types.h: $(to
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/f_seals.h: $(top_srcdir)/xlat/f_seals.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/faccessat_flags.h: $(top_srcdir)/xlat/faccessat_flags.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/falloc_flags.h: $(top_srcdir)/xlat/falloc_flags.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/fan_classes.h: $(top_srcdir)/xlat/fan_classes.in $(top_srcdir)/xlat/gen.sh
@@ -300,6 +304,8 @@ $(top_srcdir)/xlat/getsock_options.h: $(
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/hci_channels.h: $(top_srcdir)/xlat/hci_channels.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/hdio_drive_cmds.h: $(top_srcdir)/xlat/hdio_drive_cmds.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/hw_breakpoint_len.h: $(top_srcdir)/xlat/hw_breakpoint_len.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/hw_breakpoint_type.h: $(top_srcdir)/xlat/hw_breakpoint_type.in $(top_srcdir)/xlat/gen.sh
@@ -554,6 +560,8 @@ $(top_srcdir)/xlat/open_access_modes.h:
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/open_mode_flags.h: $(top_srcdir)/xlat/open_mode_flags.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/open_resolve_flags.h: $(top_srcdir)/xlat/open_resolve_flags.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/open_tree_flags.h: $(top_srcdir)/xlat/open_tree_flags.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/packet_diag_attrs.h: $(top_srcdir)/xlat/packet_diag_attrs.in $(top_srcdir)/xlat/gen.sh
@@ -670,6 +678,10 @@ $(top_srcdir)/xlat/routing_table_ids.h:
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/routing_types.h: $(top_srcdir)/xlat/routing_types.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/rtc_ioctl_cmds.h: $(top_srcdir)/xlat/rtc_ioctl_cmds.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/rtc_vl_flags.h: $(top_srcdir)/xlat/rtc_vl_flags.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/rtnl_addr_attrs.h: $(top_srcdir)/xlat/rtnl_addr_attrs.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/rtnl_addrlabel_attrs.h: $(top_srcdir)/xlat/rtnl_addrlabel_attrs.in $(top_srcdir)/xlat/gen.sh
@@ -734,6 +746,8 @@ $(top_srcdir)/xlat/rtnl_tc_attrs.h: $(to
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/rtnl_tca_act_flags.h: $(top_srcdir)/xlat/rtnl_tca_act_flags.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/rtnl_tca_act_hw_stats.h: $(top_srcdir)/xlat/rtnl_tca_act_hw_stats.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/rtnl_tca_stab_attrs.h: $(top_srcdir)/xlat/rtnl_tca_stab_attrs.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/rtnl_tca_stats_attrs.h: $(top_srcdir)/xlat/rtnl_tca_stats_attrs.in $(top_srcdir)/xlat/gen.sh
@@ -964,6 +978,24 @@ $(top_srcdir)/xlat/tcp_states.h: $(top_s
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/tcxonc_options.h: $(top_srcdir)/xlat/tcxonc_options.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/tee_ioctl_cmds.h: $(top_srcdir)/xlat/tee_ioctl_cmds.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/tee_ioctl_gen_caps.h: $(top_srcdir)/xlat/tee_ioctl_gen_caps.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/tee_ioctl_impl_ids.h: $(top_srcdir)/xlat/tee_ioctl_impl_ids.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/tee_ioctl_login_types.h: $(top_srcdir)/xlat/tee_ioctl_login_types.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/tee_ioctl_max_arg_size.h: $(top_srcdir)/xlat/tee_ioctl_max_arg_size.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/tee_ioctl_optee_caps.h: $(top_srcdir)/xlat/tee_ioctl_optee_caps.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/tee_ioctl_origins.h: $(top_srcdir)/xlat/tee_ioctl_origins.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/tee_ioctl_param_attr_types.h: $(top_srcdir)/xlat/tee_ioctl_param_attr_types.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/tee_ioctl_shm_flags.h: $(top_srcdir)/xlat/tee_ioctl_shm_flags.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/timerfdflags.h: $(top_srcdir)/xlat/timerfdflags.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/tun_device_types.h: $(top_srcdir)/xlat/tun_device_types.in $(top_srcdir)/xlat/gen.sh
@@ -994,8 +1026,14 @@ $(top_srcdir)/xlat/unix_diag_show.h: $(t
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/unshare_flags.h: $(top_srcdir)/xlat/unshare_flags.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/uring_cqring_flags.h: $(top_srcdir)/xlat/uring_cqring_flags.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/uring_enter_flags.h: $(top_srcdir)/xlat/uring_enter_flags.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/uring_op_flags.h: $(top_srcdir)/xlat/uring_op_flags.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/uring_ops.h: $(top_srcdir)/xlat/uring_ops.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/uring_register_opcodes.h: $(top_srcdir)/xlat/uring_register_opcodes.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/uring_setup_features.h: $(top_srcdir)/xlat/uring_setup_features.in $(top_srcdir)/xlat/gen.sh
@@ -1006,6 +1044,12 @@ $(top_srcdir)/xlat/usagewho.h: $(top_src
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/v4l2_buf_flags.h: $(top_srcdir)/xlat/v4l2_buf_flags.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/v4l2_buf_flags_masks.h: $(top_srcdir)/xlat/v4l2_buf_flags_masks.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/v4l2_buf_flags_ts_src.h: $(top_srcdir)/xlat/v4l2_buf_flags_ts_src.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/v4l2_buf_flags_ts_type.h: $(top_srcdir)/xlat/v4l2_buf_flags_ts_type.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/v4l2_buf_types.h: $(top_srcdir)/xlat/v4l2_buf_types.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/v4l2_capture_modes.h: $(top_srcdir)/xlat/v4l2_capture_modes.in $(top_srcdir)/xlat/gen.sh
@@ -1020,6 +1064,8 @@ $(top_srcdir)/xlat/v4l2_control_id_bases
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/v4l2_control_ids.h: $(top_srcdir)/xlat/v4l2_control_ids.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/v4l2_control_query_flags.h: $(top_srcdir)/xlat/v4l2_control_query_flags.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/v4l2_control_types.h: $(top_srcdir)/xlat/v4l2_control_types.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/v4l2_device_capabilities_flags.h: $(top_srcdir)/xlat/v4l2_device_capabilities_flags.in $(top_srcdir)/xlat/gen.sh
@@ -1034,6 +1080,8 @@ $(top_srcdir)/xlat/v4l2_framesize_types.
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/v4l2_input_types.h: $(top_srcdir)/xlat/v4l2_input_types.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
+$(top_srcdir)/xlat/v4l2_ioctl_cmds.h: $(top_srcdir)/xlat/v4l2_ioctl_cmds.in $(top_srcdir)/xlat/gen.sh
+	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/v4l2_memories.h: $(top_srcdir)/xlat/v4l2_memories.in $(top_srcdir)/xlat/gen.sh
 	$(AM_V_GEN)$(top_srcdir)/xlat/gen.sh $< $@
 $(top_srcdir)/xlat/v4l2_pix_fmts.h: $(top_srcdir)/xlat/v4l2_pix_fmts.in $(top_srcdir)/xlat/gen.sh
diff -pruN 5.5-3/xlat/mbind_flags.h 5.9-0ubuntu2/xlat/mbind_flags.h
--- 5.5-3/xlat/mbind_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/mbind_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data mbind_flags_xdata[] = {
  XLAT(MPOL_MF_STRICT),
+ #define XLAT_VAL_0 ((unsigned) (MPOL_MF_STRICT))
+ #define XLAT_STR_0 STRINGIFY(MPOL_MF_STRICT)
  XLAT(MPOL_MF_MOVE),
+ #define XLAT_VAL_1 ((unsigned) (MPOL_MF_MOVE))
+ #define XLAT_STR_1 STRINGIFY(MPOL_MF_MOVE)
  XLAT(MPOL_MF_MOVE_ALL),
+ #define XLAT_VAL_2 ((unsigned) (MPOL_MF_MOVE_ALL))
+ #define XLAT_STR_2 STRINGIFY(MPOL_MF_MOVE_ALL)
 };
 static
 const struct xlat mbind_flags[1] = { {
  .data = mbind_flags_xdata,
  .size = ARRAY_SIZE(mbind_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/mctl_sync.h 5.9-0ubuntu2/xlat/mctl_sync.h
--- 5.5-3/xlat/mctl_sync.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/mctl_sync.h	2020-09-24 09:18:44.000000000 +0000
@@ -15,12 +15,18 @@
 static const struct xlat_data mctl_sync_xdata[] = {
 #if defined(MS_SYNC) || (defined(HAVE_DECL_MS_SYNC) && HAVE_DECL_MS_SYNC)
   XLAT(MS_SYNC),
+ #define XLAT_VAL_0 ((unsigned) (MS_SYNC))
+ #define XLAT_STR_0 STRINGIFY(MS_SYNC)
 #endif
 #if defined(MS_ASYNC) || (defined(HAVE_DECL_MS_ASYNC) && HAVE_DECL_MS_ASYNC)
   XLAT(MS_ASYNC),
+ #define XLAT_VAL_1 ((unsigned) (MS_ASYNC))
+ #define XLAT_STR_1 STRINGIFY(MS_ASYNC)
 #endif
 #if defined(MS_INVALIDATE) || (defined(HAVE_DECL_MS_INVALIDATE) && HAVE_DECL_MS_INVALIDATE)
   XLAT(MS_INVALIDATE),
+ #define XLAT_VAL_2 ((unsigned) (MS_INVALIDATE))
+ #define XLAT_STR_2 STRINGIFY(MS_INVALIDATE)
 #endif
 };
 static
@@ -28,8 +34,36 @@ const struct xlat mctl_sync[1] = { {
  .data = mctl_sync_xdata,
  .size = ARRAY_SIZE(mctl_sync_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/mdb_flags.h 5.9-0ubuntu2/xlat/mdb_flags.h
--- 5.5-3/xlat/mdb_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/mdb_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data mdb_flags_xdata[] = {
  XLAT(MDB_FLAGS_OFFLOAD),
+ #define XLAT_VAL_0 ((unsigned) (MDB_FLAGS_OFFLOAD))
+ #define XLAT_STR_0 STRINGIFY(MDB_FLAGS_OFFLOAD)
  XLAT(MDB_FLAGS_FAST_LEAVE),
+ #define XLAT_VAL_1 ((unsigned) (MDB_FLAGS_FAST_LEAVE))
+ #define XLAT_STR_1 STRINGIFY(MDB_FLAGS_FAST_LEAVE)
 };
 static
 const struct xlat mdb_flags[1] = { {
  .data = mdb_flags_xdata,
  .size = ARRAY_SIZE(mdb_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/mdb_states.h 5.9-0ubuntu2/xlat/mdb_states.h
--- 5.5-3/xlat/mdb_states.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/mdb_states.h	2020-09-24 09:18:44.000000000 +0000
@@ -15,9 +15,13 @@
 static const struct xlat_data mdb_states_xdata[] = {
 #if defined(MDB_TEMPORARY) || (defined(HAVE_DECL_MDB_TEMPORARY) && HAVE_DECL_MDB_TEMPORARY)
   XLAT(MDB_TEMPORARY),
+ #define XLAT_VAL_0 ((unsigned) (MDB_TEMPORARY))
+ #define XLAT_STR_0 STRINGIFY(MDB_TEMPORARY)
 #endif
 #if defined(MDB_PERMANENT) || (defined(HAVE_DECL_MDB_PERMANENT) && HAVE_DECL_MDB_PERMANENT)
   XLAT(MDB_PERMANENT),
+ #define XLAT_VAL_1 ((unsigned) (MDB_PERMANENT))
+ #define XLAT_STR_1 STRINGIFY(MDB_PERMANENT)
 #endif
 };
 static
@@ -25,8 +29,28 @@ const struct xlat mdb_states[1] = { {
  .data = mdb_states_xdata,
  .size = ARRAY_SIZE(mdb_states_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/membarrier_cmds.h 5.9-0ubuntu2/xlat/membarrier_cmds.h
--- 5.5-3/xlat/membarrier_cmds.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/membarrier_cmds.h	2020-09-24 09:18:44.000000000 +0000
@@ -70,21 +70,105 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data membarrier_cmds_xdata[] = {
  XLAT(MEMBARRIER_CMD_QUERY),
+ #define XLAT_VAL_0 ((unsigned) (MEMBARRIER_CMD_QUERY))
+ #define XLAT_STR_0 STRINGIFY(MEMBARRIER_CMD_QUERY)
  XLAT(MEMBARRIER_CMD_GLOBAL),
+ #define XLAT_VAL_1 ((unsigned) (MEMBARRIER_CMD_GLOBAL))
+ #define XLAT_STR_1 STRINGIFY(MEMBARRIER_CMD_GLOBAL)
  XLAT(MEMBARRIER_CMD_GLOBAL_EXPEDITED),
+ #define XLAT_VAL_2 ((unsigned) (MEMBARRIER_CMD_GLOBAL_EXPEDITED))
+ #define XLAT_STR_2 STRINGIFY(MEMBARRIER_CMD_GLOBAL_EXPEDITED)
  XLAT(MEMBARRIER_CMD_REGISTER_GLOBAL_EXPEDITED),
+ #define XLAT_VAL_3 ((unsigned) (MEMBARRIER_CMD_REGISTER_GLOBAL_EXPEDITED))
+ #define XLAT_STR_3 STRINGIFY(MEMBARRIER_CMD_REGISTER_GLOBAL_EXPEDITED)
  XLAT(MEMBARRIER_CMD_PRIVATE_EXPEDITED),
+ #define XLAT_VAL_4 ((unsigned) (MEMBARRIER_CMD_PRIVATE_EXPEDITED))
+ #define XLAT_STR_4 STRINGIFY(MEMBARRIER_CMD_PRIVATE_EXPEDITED)
  XLAT(MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED),
+ #define XLAT_VAL_5 ((unsigned) (MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED))
+ #define XLAT_STR_5 STRINGIFY(MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED)
  XLAT(MEMBARRIER_CMD_PRIVATE_EXPEDITED_SYNC_CORE),
+ #define XLAT_VAL_6 ((unsigned) (MEMBARRIER_CMD_PRIVATE_EXPEDITED_SYNC_CORE))
+ #define XLAT_STR_6 STRINGIFY(MEMBARRIER_CMD_PRIVATE_EXPEDITED_SYNC_CORE)
  XLAT(MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED_SYNC_CORE),
+ #define XLAT_VAL_7 ((unsigned) (MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED_SYNC_CORE))
+ #define XLAT_STR_7 STRINGIFY(MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED_SYNC_CORE)
 };
 static
 const struct xlat membarrier_cmds[1] = { {
  .data = membarrier_cmds_xdata,
  .size = ARRAY_SIZE(membarrier_cmds_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/memfd_create_flags.h 5.9-0ubuntu2/xlat/memfd_create_flags.h
--- 5.5-3/xlat/memfd_create_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/memfd_create_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data memfd_create_flags_xdata[] = {
  XLAT(MFD_CLOEXEC),
+ #define XLAT_VAL_0 ((unsigned) (MFD_CLOEXEC))
+ #define XLAT_STR_0 STRINGIFY(MFD_CLOEXEC)
  XLAT(MFD_ALLOW_SEALING),
+ #define XLAT_VAL_1 ((unsigned) (MFD_ALLOW_SEALING))
+ #define XLAT_STR_1 STRINGIFY(MFD_ALLOW_SEALING)
  XLAT(MFD_HUGETLB),
+ #define XLAT_VAL_2 ((unsigned) (MFD_HUGETLB))
+ #define XLAT_STR_2 STRINGIFY(MFD_HUGETLB)
 };
 static
 const struct xlat memfd_create_flags[1] = { {
  .data = memfd_create_flags_xdata,
  .size = ARRAY_SIZE(memfd_create_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/mlockall_flags.h 5.9-0ubuntu2/xlat/mlockall_flags.h
--- 5.5-3/xlat/mlockall_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/mlockall_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -60,12 +60,24 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 static const struct xlat_data mlockall_flags_xdata[] = {
 #if defined __alpha__ || defined __powerpc__ || defined __powerpc64__ || defined __sparc__
  XLAT(MCL_CURRENT),
+ #define XLAT_VAL_0 ((unsigned) (MCL_CURRENT))
+ #define XLAT_STR_0 STRINGIFY(MCL_CURRENT)
  XLAT(MCL_FUTURE),
+ #define XLAT_VAL_1 ((unsigned) (MCL_FUTURE))
+ #define XLAT_STR_1 STRINGIFY(MCL_FUTURE)
  XLAT(MCL_ONFAULT),
+ #define XLAT_VAL_2 ((unsigned) (MCL_ONFAULT))
+ #define XLAT_STR_2 STRINGIFY(MCL_ONFAULT)
 #else
  XLAT(MCL_CURRENT),
+ #define XLAT_VAL_3 ((unsigned) (MCL_CURRENT))
+ #define XLAT_STR_3 STRINGIFY(MCL_CURRENT)
  XLAT(MCL_FUTURE),
+ #define XLAT_VAL_4 ((unsigned) (MCL_FUTURE))
+ #define XLAT_STR_4 STRINGIFY(MCL_FUTURE)
  XLAT(MCL_ONFAULT),
+ #define XLAT_VAL_5 ((unsigned) (MCL_ONFAULT))
+ #define XLAT_STR_5 STRINGIFY(MCL_ONFAULT)
 #endif
 };
 static
@@ -73,8 +85,60 @@ const struct xlat mlockall_flags[1] = {
  .data = mlockall_flags_xdata,
  .size = ARRAY_SIZE(mlockall_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/mlock_flags.h 5.9-0ubuntu2/xlat/mlock_flags.h
--- 5.5-3/xlat/mlock_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/mlock_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -21,14 +21,28 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data mlock_flags_xdata[] = {
  XLAT(MLOCK_ONFAULT),
+ #define XLAT_VAL_0 ((unsigned) (MLOCK_ONFAULT))
+ #define XLAT_STR_0 STRINGIFY(MLOCK_ONFAULT)
 };
 static
 const struct xlat mlock_flags[1] = { {
  .data = mlock_flags_xdata,
  .size = ARRAY_SIZE(mlock_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/mmap_flags.h 5.9-0ubuntu2/xlat/mmap_flags.h
--- 5.5-3/xlat/mmap_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/mmap_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -480,32 +480,54 @@ static const struct xlat_data mmap_flags
 
 
  XLAT(MAP_SHARED),
+ #define XLAT_VAL_0 ((unsigned) (MAP_SHARED))
+ #define XLAT_STR_0 STRINGIFY(MAP_SHARED)
 
  XLAT(MAP_PRIVATE),
+ #define XLAT_VAL_1 ((unsigned) (MAP_PRIVATE))
+ #define XLAT_STR_1 STRINGIFY(MAP_PRIVATE)
 
  XLAT(MAP_SHARED_VALIDATE),
+ #define XLAT_VAL_2 ((unsigned) (MAP_SHARED_VALIDATE))
+ #define XLAT_STR_2 STRINGIFY(MAP_SHARED_VALIDATE)
 
 #if defined __hppa__
  XLAT(MAP_FIXED),
+ #define XLAT_VAL_3 ((unsigned) (MAP_FIXED))
+ #define XLAT_STR_3 STRINGIFY(MAP_FIXED)
 #elif defined __alpha__
  XLAT(MAP_FIXED),
+ #define XLAT_VAL_4 ((unsigned) (MAP_FIXED))
+ #define XLAT_STR_4 STRINGIFY(MAP_FIXED)
 #else
  XLAT(MAP_FIXED),
+ #define XLAT_VAL_5 ((unsigned) (MAP_FIXED))
+ #define XLAT_STR_5 STRINGIFY(MAP_FIXED)
 #endif
 
 #if defined __alpha__ || defined __hppa__
  XLAT(MAP_ANONYMOUS),
+ #define XLAT_VAL_6 ((unsigned) (MAP_ANONYMOUS))
+ #define XLAT_STR_6 STRINGIFY(MAP_ANONYMOUS)
 #elif defined __mips__ || defined __xtensa__
  XLAT(MAP_ANONYMOUS),
+ #define XLAT_VAL_7 ((unsigned) (MAP_ANONYMOUS))
+ #define XLAT_STR_7 STRINGIFY(MAP_ANONYMOUS)
 #else
  XLAT(MAP_ANONYMOUS),
+ #define XLAT_VAL_8 ((unsigned) (MAP_ANONYMOUS))
+ #define XLAT_STR_8 STRINGIFY(MAP_ANONYMOUS)
 #endif
 
 #if defined __x86_64__ || defined __i386__
  XLAT(MAP_32BIT),
+ #define XLAT_VAL_9 ((unsigned) (MAP_32BIT))
+ #define XLAT_STR_9 STRINGIFY(MAP_32BIT)
 #else
 #if defined(MAP_32BIT) || (defined(HAVE_DECL_MAP_32BIT) && HAVE_DECL_MAP_32BIT)
   XLAT(MAP_32BIT),
+ #define XLAT_VAL_10 ((unsigned) (MAP_32BIT))
+ #define XLAT_STR_10 STRINGIFY(MAP_32BIT)
 #endif
 #endif
 
@@ -520,129 +542,213 @@ static const struct xlat_data mmap_flags
 
 #if defined __mips__ || defined __xtensa__
  XLAT(MAP_RENAME),
+ #define XLAT_VAL_11 ((unsigned) (MAP_RENAME))
+ #define XLAT_STR_11 STRINGIFY(MAP_RENAME)
 #else
 #if defined(MAP_RENAME) || (defined(HAVE_DECL_MAP_RENAME) && HAVE_DECL_MAP_RENAME)
   XLAT(MAP_RENAME),
+ #define XLAT_VAL_12 ((unsigned) (MAP_RENAME))
+ #define XLAT_STR_12 STRINGIFY(MAP_RENAME)
 #endif
 #endif
 
 #if defined __powerpc__ || defined __sparc__
  XLAT(MAP_NORESERVE),
+ #define XLAT_VAL_13 ((unsigned) (MAP_NORESERVE))
+ #define XLAT_STR_13 STRINGIFY(MAP_NORESERVE)
 #elif defined __mips__ || defined __xtensa__
  XLAT(MAP_NORESERVE),
+ #define XLAT_VAL_14 ((unsigned) (MAP_NORESERVE))
+ #define XLAT_STR_14 STRINGIFY(MAP_NORESERVE)
 #elif defined __alpha__
  XLAT(MAP_NORESERVE),
+ #define XLAT_VAL_15 ((unsigned) (MAP_NORESERVE))
+ #define XLAT_STR_15 STRINGIFY(MAP_NORESERVE)
 #else
  XLAT(MAP_NORESERVE),
+ #define XLAT_VAL_16 ((unsigned) (MAP_NORESERVE))
+ #define XLAT_STR_16 STRINGIFY(MAP_NORESERVE)
 #endif
 
 #if defined __hppa__ || defined __mips__ || defined __xtensa__
  XLAT(MAP_POPULATE),
+ #define XLAT_VAL_17 ((unsigned) (MAP_POPULATE))
+ #define XLAT_STR_17 STRINGIFY(MAP_POPULATE)
 #elif defined __alpha__
  XLAT(MAP_POPULATE),
+ #define XLAT_VAL_18 ((unsigned) (MAP_POPULATE))
+ #define XLAT_STR_18 STRINGIFY(MAP_POPULATE)
 #else
  XLAT(MAP_POPULATE),
+ #define XLAT_VAL_19 ((unsigned) (MAP_POPULATE))
+ #define XLAT_STR_19 STRINGIFY(MAP_POPULATE)
 #endif
 
 #if defined __hppa__ || defined __mips__ || defined __xtensa__
  XLAT(MAP_NONBLOCK),
+ #define XLAT_VAL_20 ((unsigned) (MAP_NONBLOCK))
+ #define XLAT_STR_20 STRINGIFY(MAP_NONBLOCK)
 #elif defined __alpha__
  XLAT(MAP_NONBLOCK),
+ #define XLAT_VAL_21 ((unsigned) (MAP_NONBLOCK))
+ #define XLAT_STR_21 STRINGIFY(MAP_NONBLOCK)
 #else
  XLAT(MAP_NONBLOCK),
+ #define XLAT_VAL_22 ((unsigned) (MAP_NONBLOCK))
+ #define XLAT_STR_22 STRINGIFY(MAP_NONBLOCK)
 #endif
 
 #if defined __sparc__
  XLAT(_MAP_NEW),
+ #define XLAT_VAL_23 ((unsigned) (_MAP_NEW))
+ #define XLAT_STR_23 STRINGIFY(_MAP_NEW)
 #else
 #if defined(_MAP_NEW) || (defined(HAVE_DECL__MAP_NEW) && HAVE_DECL__MAP_NEW)
   XLAT(_MAP_NEW),
+ #define XLAT_VAL_24 ((unsigned) (_MAP_NEW))
+ #define XLAT_STR_24 STRINGIFY(_MAP_NEW)
 #endif
 #endif
 
 #if defined __sparc__
  XLAT(MAP_GROWSDOWN),
+ #define XLAT_VAL_25 ((unsigned) (MAP_GROWSDOWN))
+ #define XLAT_STR_25 STRINGIFY(MAP_GROWSDOWN)
 #elif defined __alpha__ || defined __mips__ || defined __xtensa__
  XLAT(MAP_GROWSDOWN),
+ #define XLAT_VAL_26 ((unsigned) (MAP_GROWSDOWN))
+ #define XLAT_STR_26 STRINGIFY(MAP_GROWSDOWN)
 #elif defined __hppa__
  XLAT(MAP_GROWSDOWN),
+ #define XLAT_VAL_27 ((unsigned) (MAP_GROWSDOWN))
+ #define XLAT_STR_27 STRINGIFY(MAP_GROWSDOWN)
 #else
  XLAT(MAP_GROWSDOWN),
+ #define XLAT_VAL_28 ((unsigned) (MAP_GROWSDOWN))
+ #define XLAT_STR_28 STRINGIFY(MAP_GROWSDOWN)
 #endif
 
 #if defined __ia64__
  XLAT(MAP_GROWSUP),
+ #define XLAT_VAL_29 ((unsigned) (MAP_GROWSUP))
+ #define XLAT_STR_29 STRINGIFY(MAP_GROWSUP)
 #else
 #if defined(MAP_GROWSUP) || (defined(HAVE_DECL_MAP_GROWSUP) && HAVE_DECL_MAP_GROWSUP)
   XLAT(MAP_GROWSUP),
+ #define XLAT_VAL_30 ((unsigned) (MAP_GROWSUP))
+ #define XLAT_STR_30 STRINGIFY(MAP_GROWSUP)
 #endif
 #endif
 
 #if defined __alpha__ || defined __mips__ || defined __xtensa__
  XLAT(MAP_DENYWRITE),
+ #define XLAT_VAL_31 ((unsigned) (MAP_DENYWRITE))
+ #define XLAT_STR_31 STRINGIFY(MAP_DENYWRITE)
 #else
  XLAT(MAP_DENYWRITE),
+ #define XLAT_VAL_32 ((unsigned) (MAP_DENYWRITE))
+ #define XLAT_STR_32 STRINGIFY(MAP_DENYWRITE)
 #endif
 
 #if defined __alpha__ || defined __mips__ || defined __xtensa__
  XLAT(MAP_EXECUTABLE),
+ #define XLAT_VAL_33 ((unsigned) (MAP_EXECUTABLE))
+ #define XLAT_STR_33 STRINGIFY(MAP_EXECUTABLE)
 #else
  XLAT(MAP_EXECUTABLE),
+ #define XLAT_VAL_34 ((unsigned) (MAP_EXECUTABLE))
+ #define XLAT_STR_34 STRINGIFY(MAP_EXECUTABLE)
 #endif
 
 #if defined __sparc__
  XLAT(MAP_INHERIT),
+ #define XLAT_VAL_35 ((unsigned) (MAP_INHERIT))
+ #define XLAT_STR_35 STRINGIFY(MAP_INHERIT)
 #else
 #if defined(MAP_INHERIT) || (defined(HAVE_DECL_MAP_INHERIT) && HAVE_DECL_MAP_INHERIT)
   XLAT(MAP_INHERIT),
+ #define XLAT_VAL_36 ((unsigned) (MAP_INHERIT))
+ #define XLAT_STR_36 STRINGIFY(MAP_INHERIT)
 #endif
 #endif
 
 #if defined __alpha__
  XLAT(_MAP_INHERIT),
+ #define XLAT_VAL_37 ((unsigned) (_MAP_INHERIT))
+ #define XLAT_STR_37 STRINGIFY(_MAP_INHERIT)
 #else
 #if defined(_MAP_INHERIT) || (defined(HAVE_DECL__MAP_INHERIT) && HAVE_DECL__MAP_INHERIT)
   XLAT(_MAP_INHERIT),
+ #define XLAT_VAL_38 ((unsigned) (_MAP_INHERIT))
+ #define XLAT_STR_38 STRINGIFY(_MAP_INHERIT)
 #endif
 #endif
 
  XLAT(MAP_FILE),
+ #define XLAT_VAL_39 ((unsigned) (MAP_FILE))
+ #define XLAT_STR_39 STRINGIFY(MAP_FILE)
 
 #if defined __powerpc__
  XLAT(MAP_LOCKED),
+ #define XLAT_VAL_40 ((unsigned) (MAP_LOCKED))
+ #define XLAT_STR_40 STRINGIFY(MAP_LOCKED)
 #elif defined __sparc__
  XLAT(MAP_LOCKED),
+ #define XLAT_VAL_41 ((unsigned) (MAP_LOCKED))
+ #define XLAT_STR_41 STRINGIFY(MAP_LOCKED)
 #elif defined __alpha__ || defined __mips__ || defined __xtensa__
  XLAT(MAP_LOCKED),
+ #define XLAT_VAL_42 ((unsigned) (MAP_LOCKED))
+ #define XLAT_STR_42 STRINGIFY(MAP_LOCKED)
 #else
  XLAT(MAP_LOCKED),
+ #define XLAT_VAL_43 ((unsigned) (MAP_LOCKED))
+ #define XLAT_STR_43 STRINGIFY(MAP_LOCKED)
 #endif
 
 #if defined __alpha__
  XLAT(_MAP_HASSEMAPHORE),
+ #define XLAT_VAL_44 ((unsigned) (_MAP_HASSEMAPHORE))
+ #define XLAT_STR_44 STRINGIFY(_MAP_HASSEMAPHORE)
 #else
 #if defined(_MAP_HASSEMAPHORE) || (defined(HAVE_DECL__MAP_HASSEMAPHORE) && HAVE_DECL__MAP_HASSEMAPHORE)
   XLAT(_MAP_HASSEMAPHORE),
+ #define XLAT_VAL_45 ((unsigned) (_MAP_HASSEMAPHORE))
+ #define XLAT_STR_45 STRINGIFY(_MAP_HASSEMAPHORE)
 #endif
 #endif
 
 #if defined __hppa__ || defined __mips__ || defined __xtensa__
  XLAT(MAP_STACK),
+ #define XLAT_VAL_46 ((unsigned) (MAP_STACK))
+ #define XLAT_STR_46 STRINGIFY(MAP_STACK)
 #elif defined __alpha__
  XLAT(MAP_STACK),
+ #define XLAT_VAL_47 ((unsigned) (MAP_STACK))
+ #define XLAT_STR_47 STRINGIFY(MAP_STACK)
 #else
  XLAT(MAP_STACK),
+ #define XLAT_VAL_48 ((unsigned) (MAP_STACK))
+ #define XLAT_STR_48 STRINGIFY(MAP_STACK)
 #endif
 
 #if defined __hppa__ || defined __mips__ || defined __xtensa__
  XLAT(MAP_HUGETLB),
+ #define XLAT_VAL_49 ((unsigned) (MAP_HUGETLB))
+ #define XLAT_STR_49 STRINGIFY(MAP_HUGETLB)
 #elif defined __alpha__
  XLAT(MAP_HUGETLB),
+ #define XLAT_VAL_50 ((unsigned) (MAP_HUGETLB))
+ #define XLAT_STR_50 STRINGIFY(MAP_HUGETLB)
 #else
  XLAT(MAP_HUGETLB),
+ #define XLAT_VAL_51 ((unsigned) (MAP_HUGETLB))
+ #define XLAT_STR_51 STRINGIFY(MAP_HUGETLB)
 #endif
 
  XLAT(MAP_SYNC),
+ #define XLAT_VAL_52 ((unsigned) (MAP_SYNC))
+ #define XLAT_STR_52 STRINGIFY(MAP_SYNC)
 
 #if defined MAP_UNINITIALIZED && MAP_UNINITIALIZED == 0
 
@@ -653,42 +759,64 @@ static const struct xlat_data mmap_flags
 # endif
 #endif
  XLAT(MAP_UNINITIALIZED),
+ #define XLAT_VAL_53 ((unsigned) (MAP_UNINITIALIZED))
+ #define XLAT_STR_53 STRINGIFY(MAP_UNINITIALIZED)
 
 #if defined __alpha__
  XLAT(MAP_FIXED_NOREPLACE),
+ #define XLAT_VAL_54 ((unsigned) (MAP_FIXED_NOREPLACE))
+ #define XLAT_STR_54 STRINGIFY(MAP_FIXED_NOREPLACE)
 #else
  XLAT(MAP_FIXED_NOREPLACE),
+ #define XLAT_VAL_55 ((unsigned) (MAP_FIXED_NOREPLACE))
+ #define XLAT_STR_55 STRINGIFY(MAP_FIXED_NOREPLACE)
 #endif
 
 #if defined __mips__ || defined __xtensa__
  XLAT(MAP_AUTOGROW),
+ #define XLAT_VAL_56 ((unsigned) (MAP_AUTOGROW))
+ #define XLAT_STR_56 STRINGIFY(MAP_AUTOGROW)
 #else
 #if defined(MAP_AUTOGROW) || (defined(HAVE_DECL_MAP_AUTOGROW) && HAVE_DECL_MAP_AUTOGROW)
   XLAT(MAP_AUTOGROW),
+ #define XLAT_VAL_57 ((unsigned) (MAP_AUTOGROW))
+ #define XLAT_STR_57 STRINGIFY(MAP_AUTOGROW)
 #endif
 #endif
 
 #if defined __mips__ || defined __xtensa__
  XLAT(MAP_AUTORSRV),
+ #define XLAT_VAL_58 ((unsigned) (MAP_AUTORSRV))
+ #define XLAT_STR_58 STRINGIFY(MAP_AUTORSRV)
 #else
 #if defined(MAP_AUTORSRV) || (defined(HAVE_DECL_MAP_AUTORSRV) && HAVE_DECL_MAP_AUTORSRV)
   XLAT(MAP_AUTORSRV),
+ #define XLAT_VAL_59 ((unsigned) (MAP_AUTORSRV))
+ #define XLAT_STR_59 STRINGIFY(MAP_AUTORSRV)
 #endif
 #endif
 
 #if defined __mips__ || defined __xtensa__
  XLAT(MAP_LOCAL),
+ #define XLAT_VAL_60 ((unsigned) (MAP_LOCAL))
+ #define XLAT_STR_60 STRINGIFY(MAP_LOCAL)
 #else
 #if defined(MAP_LOCAL) || (defined(HAVE_DECL_MAP_LOCAL) && HAVE_DECL_MAP_LOCAL)
   XLAT(MAP_LOCAL),
+ #define XLAT_VAL_61 ((unsigned) (MAP_LOCAL))
+ #define XLAT_STR_61 STRINGIFY(MAP_LOCAL)
 #endif
 #endif
 
 #if defined __alpha__
  XLAT(_MAP_UNALIGNED),
+ #define XLAT_VAL_62 ((unsigned) (_MAP_UNALIGNED))
+ #define XLAT_STR_62 STRINGIFY(_MAP_UNALIGNED)
 #else
 #if defined(_MAP_UNALIGNED) || (defined(HAVE_DECL__MAP_UNALIGNED) && HAVE_DECL__MAP_UNALIGNED)
   XLAT(_MAP_UNALIGNED),
+ #define XLAT_VAL_63 ((unsigned) (_MAP_UNALIGNED))
+ #define XLAT_STR_63 STRINGIFY(_MAP_UNALIGNED)
 #endif
 #endif
 };
@@ -697,8 +825,524 @@ const struct xlat mmap_flags[1] = { {
  .data = mmap_flags_xdata,
  .size = ARRAY_SIZE(mmap_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+#  ifdef XLAT_VAL_47
+  | XLAT_VAL_47
+#  endif
+#  ifdef XLAT_VAL_48
+  | XLAT_VAL_48
+#  endif
+#  ifdef XLAT_VAL_49
+  | XLAT_VAL_49
+#  endif
+#  ifdef XLAT_VAL_50
+  | XLAT_VAL_50
+#  endif
+#  ifdef XLAT_VAL_51
+  | XLAT_VAL_51
+#  endif
+#  ifdef XLAT_VAL_52
+  | XLAT_VAL_52
+#  endif
+#  ifdef XLAT_VAL_53
+  | XLAT_VAL_53
+#  endif
+#  ifdef XLAT_VAL_54
+  | XLAT_VAL_54
+#  endif
+#  ifdef XLAT_VAL_55
+  | XLAT_VAL_55
+#  endif
+#  ifdef XLAT_VAL_56
+  | XLAT_VAL_56
+#  endif
+#  ifdef XLAT_VAL_57
+  | XLAT_VAL_57
+#  endif
+#  ifdef XLAT_VAL_58
+  | XLAT_VAL_58
+#  endif
+#  ifdef XLAT_VAL_59
+  | XLAT_VAL_59
+#  endif
+#  ifdef XLAT_VAL_60
+  | XLAT_VAL_60
+#  endif
+#  ifdef XLAT_VAL_61
+  | XLAT_VAL_61
+#  endif
+#  ifdef XLAT_VAL_62
+  | XLAT_VAL_62
+#  endif
+#  ifdef XLAT_VAL_63
+  | XLAT_VAL_63
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+#  ifdef XLAT_STR_47
+  + sizeof(XLAT_STR_47)
+#  endif
+#  ifdef XLAT_STR_48
+  + sizeof(XLAT_STR_48)
+#  endif
+#  ifdef XLAT_STR_49
+  + sizeof(XLAT_STR_49)
+#  endif
+#  ifdef XLAT_STR_50
+  + sizeof(XLAT_STR_50)
+#  endif
+#  ifdef XLAT_STR_51
+  + sizeof(XLAT_STR_51)
+#  endif
+#  ifdef XLAT_STR_52
+  + sizeof(XLAT_STR_52)
+#  endif
+#  ifdef XLAT_STR_53
+  + sizeof(XLAT_STR_53)
+#  endif
+#  ifdef XLAT_STR_54
+  + sizeof(XLAT_STR_54)
+#  endif
+#  ifdef XLAT_STR_55
+  + sizeof(XLAT_STR_55)
+#  endif
+#  ifdef XLAT_STR_56
+  + sizeof(XLAT_STR_56)
+#  endif
+#  ifdef XLAT_STR_57
+  + sizeof(XLAT_STR_57)
+#  endif
+#  ifdef XLAT_STR_58
+  + sizeof(XLAT_STR_58)
+#  endif
+#  ifdef XLAT_STR_59
+  + sizeof(XLAT_STR_59)
+#  endif
+#  ifdef XLAT_STR_60
+  + sizeof(XLAT_STR_60)
+#  endif
+#  ifdef XLAT_STR_61
+  + sizeof(XLAT_STR_61)
+#  endif
+#  ifdef XLAT_STR_62
+  + sizeof(XLAT_STR_62)
+#  endif
+#  ifdef XLAT_STR_63
+  + sizeof(XLAT_STR_63)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
+#  undef XLAT_STR_47
+#  undef XLAT_VAL_47
+#  undef XLAT_STR_48
+#  undef XLAT_VAL_48
+#  undef XLAT_STR_49
+#  undef XLAT_VAL_49
+#  undef XLAT_STR_50
+#  undef XLAT_VAL_50
+#  undef XLAT_STR_51
+#  undef XLAT_VAL_51
+#  undef XLAT_STR_52
+#  undef XLAT_VAL_52
+#  undef XLAT_STR_53
+#  undef XLAT_VAL_53
+#  undef XLAT_STR_54
+#  undef XLAT_VAL_54
+#  undef XLAT_STR_55
+#  undef XLAT_VAL_55
+#  undef XLAT_STR_56
+#  undef XLAT_VAL_56
+#  undef XLAT_STR_57
+#  undef XLAT_VAL_57
+#  undef XLAT_STR_58
+#  undef XLAT_VAL_58
+#  undef XLAT_STR_59
+#  undef XLAT_VAL_59
+#  undef XLAT_STR_60
+#  undef XLAT_VAL_60
+#  undef XLAT_STR_61
+#  undef XLAT_VAL_61
+#  undef XLAT_STR_62
+#  undef XLAT_VAL_62
+#  undef XLAT_STR_63
+#  undef XLAT_VAL_63
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/mmap_prot.h 5.9-0ubuntu2/xlat/mmap_prot.h
--- 5.5-3/xlat/mmap_prot.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/mmap_prot.h	2020-09-24 09:18:44.000000000 +0000
@@ -15,30 +15,48 @@
 static const struct xlat_data mmap_prot_xdata[] = {
 #if defined(PROT_NONE) || (defined(HAVE_DECL_PROT_NONE) && HAVE_DECL_PROT_NONE)
   XLAT(PROT_NONE),
+ #define XLAT_VAL_0 ((unsigned) (PROT_NONE))
+ #define XLAT_STR_0 STRINGIFY(PROT_NONE)
 #endif
 #if defined(PROT_READ) || (defined(HAVE_DECL_PROT_READ) && HAVE_DECL_PROT_READ)
   XLAT(PROT_READ),
+ #define XLAT_VAL_1 ((unsigned) (PROT_READ))
+ #define XLAT_STR_1 STRINGIFY(PROT_READ)
 #endif
 #if defined(PROT_WRITE) || (defined(HAVE_DECL_PROT_WRITE) && HAVE_DECL_PROT_WRITE)
   XLAT(PROT_WRITE),
+ #define XLAT_VAL_2 ((unsigned) (PROT_WRITE))
+ #define XLAT_STR_2 STRINGIFY(PROT_WRITE)
 #endif
 #if defined(PROT_EXEC) || (defined(HAVE_DECL_PROT_EXEC) && HAVE_DECL_PROT_EXEC)
   XLAT(PROT_EXEC),
+ #define XLAT_VAL_3 ((unsigned) (PROT_EXEC))
+ #define XLAT_STR_3 STRINGIFY(PROT_EXEC)
 #endif
 #if defined(PROT_SEM) || (defined(HAVE_DECL_PROT_SEM) && HAVE_DECL_PROT_SEM)
   XLAT(PROT_SEM),
+ #define XLAT_VAL_4 ((unsigned) (PROT_SEM))
+ #define XLAT_STR_4 STRINGIFY(PROT_SEM)
 #endif
 #if defined(PROT_GROWSDOWN) || (defined(HAVE_DECL_PROT_GROWSDOWN) && HAVE_DECL_PROT_GROWSDOWN)
   XLAT(PROT_GROWSDOWN),
+ #define XLAT_VAL_5 ((unsigned) (PROT_GROWSDOWN))
+ #define XLAT_STR_5 STRINGIFY(PROT_GROWSDOWN)
 #endif
 #if defined(PROT_GROWSUP) || (defined(HAVE_DECL_PROT_GROWSUP) && HAVE_DECL_PROT_GROWSUP)
   XLAT(PROT_GROWSUP),
+ #define XLAT_VAL_6 ((unsigned) (PROT_GROWSUP))
+ #define XLAT_STR_6 STRINGIFY(PROT_GROWSUP)
 #endif
 #if defined(PROT_SAO) || (defined(HAVE_DECL_PROT_SAO) && HAVE_DECL_PROT_SAO)
   XLAT(PROT_SAO),
+ #define XLAT_VAL_7 ((unsigned) (PROT_SAO))
+ #define XLAT_STR_7 STRINGIFY(PROT_SAO)
 #endif
 #if defined(PROT_ADI) || (defined(HAVE_DECL_PROT_ADI) && HAVE_DECL_PROT_ADI)
   XLAT(PROT_ADI),
+ #define XLAT_VAL_8 ((unsigned) (PROT_ADI))
+ #define XLAT_STR_8 STRINGIFY(PROT_ADI)
 #endif
 };
 static
@@ -46,8 +64,84 @@ const struct xlat mmap_prot[1] = { {
  .data = mmap_prot_xdata,
  .size = ARRAY_SIZE(mmap_prot_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/modem_flags.h 5.9-0ubuntu2/xlat/modem_flags.h
--- 5.5-3/xlat/modem_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/modem_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -15,36 +15,58 @@
 static const struct xlat_data modem_flags_xdata[] = {
 #if defined(TIOCM_LE) || (defined(HAVE_DECL_TIOCM_LE) && HAVE_DECL_TIOCM_LE)
   XLAT(TIOCM_LE),
+ #define XLAT_VAL_0 ((unsigned) (TIOCM_LE))
+ #define XLAT_STR_0 STRINGIFY(TIOCM_LE)
 #endif
 #if defined(TIOCM_DTR) || (defined(HAVE_DECL_TIOCM_DTR) && HAVE_DECL_TIOCM_DTR)
   XLAT(TIOCM_DTR),
+ #define XLAT_VAL_1 ((unsigned) (TIOCM_DTR))
+ #define XLAT_STR_1 STRINGIFY(TIOCM_DTR)
 #endif
 #if defined(TIOCM_RTS) || (defined(HAVE_DECL_TIOCM_RTS) && HAVE_DECL_TIOCM_RTS)
   XLAT(TIOCM_RTS),
+ #define XLAT_VAL_2 ((unsigned) (TIOCM_RTS))
+ #define XLAT_STR_2 STRINGIFY(TIOCM_RTS)
 #endif
 #if defined(TIOCM_ST) || (defined(HAVE_DECL_TIOCM_ST) && HAVE_DECL_TIOCM_ST)
   XLAT(TIOCM_ST),
+ #define XLAT_VAL_3 ((unsigned) (TIOCM_ST))
+ #define XLAT_STR_3 STRINGIFY(TIOCM_ST)
 #endif
 #if defined(TIOCM_SR) || (defined(HAVE_DECL_TIOCM_SR) && HAVE_DECL_TIOCM_SR)
   XLAT(TIOCM_SR),
+ #define XLAT_VAL_4 ((unsigned) (TIOCM_SR))
+ #define XLAT_STR_4 STRINGIFY(TIOCM_SR)
 #endif
 #if defined(TIOCM_CTS) || (defined(HAVE_DECL_TIOCM_CTS) && HAVE_DECL_TIOCM_CTS)
   XLAT(TIOCM_CTS),
+ #define XLAT_VAL_5 ((unsigned) (TIOCM_CTS))
+ #define XLAT_STR_5 STRINGIFY(TIOCM_CTS)
 #endif
 #if defined(TIOCM_CAR) || (defined(HAVE_DECL_TIOCM_CAR) && HAVE_DECL_TIOCM_CAR)
   XLAT(TIOCM_CAR),
+ #define XLAT_VAL_6 ((unsigned) (TIOCM_CAR))
+ #define XLAT_STR_6 STRINGIFY(TIOCM_CAR)
 #endif
 #if defined(TIOCM_CD) || (defined(HAVE_DECL_TIOCM_CD) && HAVE_DECL_TIOCM_CD)
   XLAT(TIOCM_CD),
+ #define XLAT_VAL_7 ((unsigned) (TIOCM_CD))
+ #define XLAT_STR_7 STRINGIFY(TIOCM_CD)
 #endif
 #if defined(TIOCM_RNG) || (defined(HAVE_DECL_TIOCM_RNG) && HAVE_DECL_TIOCM_RNG)
   XLAT(TIOCM_RNG),
+ #define XLAT_VAL_8 ((unsigned) (TIOCM_RNG))
+ #define XLAT_STR_8 STRINGIFY(TIOCM_RNG)
 #endif
 #if defined(TIOCM_RI) || (defined(HAVE_DECL_TIOCM_RI) && HAVE_DECL_TIOCM_RI)
   XLAT(TIOCM_RI),
+ #define XLAT_VAL_9 ((unsigned) (TIOCM_RI))
+ #define XLAT_STR_9 STRINGIFY(TIOCM_RI)
 #endif
 #if defined(TIOCM_DSR) || (defined(HAVE_DECL_TIOCM_DSR) && HAVE_DECL_TIOCM_DSR)
   XLAT(TIOCM_DSR),
+ #define XLAT_VAL_10 ((unsigned) (TIOCM_DSR))
+ #define XLAT_STR_10 STRINGIFY(TIOCM_DSR)
 #endif
 };
 static
@@ -52,8 +74,100 @@ const struct xlat modem_flags[1] = { {
  .data = modem_flags_xdata,
  .size = ARRAY_SIZE(modem_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/modetypes.h 5.9-0ubuntu2/xlat/modetypes.h
--- 5.5-3/xlat/modetypes.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/modetypes.h	2020-09-24 09:18:44.000000000 +0000
@@ -15,24 +15,38 @@
 static const struct xlat_data modetypes_xdata[] = {
 #if defined(S_IFREG) || (defined(HAVE_DECL_S_IFREG) && HAVE_DECL_S_IFREG)
   XLAT(S_IFREG),
+ #define XLAT_VAL_0 ((unsigned) (S_IFREG))
+ #define XLAT_STR_0 STRINGIFY(S_IFREG)
 #endif
 #if defined(S_IFSOCK) || (defined(HAVE_DECL_S_IFSOCK) && HAVE_DECL_S_IFSOCK)
   XLAT(S_IFSOCK),
+ #define XLAT_VAL_1 ((unsigned) (S_IFSOCK))
+ #define XLAT_STR_1 STRINGIFY(S_IFSOCK)
 #endif
 #if defined(S_IFIFO) || (defined(HAVE_DECL_S_IFIFO) && HAVE_DECL_S_IFIFO)
   XLAT(S_IFIFO),
+ #define XLAT_VAL_2 ((unsigned) (S_IFIFO))
+ #define XLAT_STR_2 STRINGIFY(S_IFIFO)
 #endif
 #if defined(S_IFLNK) || (defined(HAVE_DECL_S_IFLNK) && HAVE_DECL_S_IFLNK)
   XLAT(S_IFLNK),
+ #define XLAT_VAL_3 ((unsigned) (S_IFLNK))
+ #define XLAT_STR_3 STRINGIFY(S_IFLNK)
 #endif
 #if defined(S_IFDIR) || (defined(HAVE_DECL_S_IFDIR) && HAVE_DECL_S_IFDIR)
   XLAT(S_IFDIR),
+ #define XLAT_VAL_4 ((unsigned) (S_IFDIR))
+ #define XLAT_STR_4 STRINGIFY(S_IFDIR)
 #endif
 #if defined(S_IFBLK) || (defined(HAVE_DECL_S_IFBLK) && HAVE_DECL_S_IFBLK)
   XLAT(S_IFBLK),
+ #define XLAT_VAL_5 ((unsigned) (S_IFBLK))
+ #define XLAT_STR_5 STRINGIFY(S_IFBLK)
 #endif
 #if defined(S_IFCHR) || (defined(HAVE_DECL_S_IFCHR) && HAVE_DECL_S_IFCHR)
   XLAT(S_IFCHR),
+ #define XLAT_VAL_6 ((unsigned) (S_IFCHR))
+ #define XLAT_STR_6 STRINGIFY(S_IFCHR)
 #endif
 };
 static
@@ -40,8 +54,68 @@ const struct xlat modetypes[1] = { {
  .data = modetypes_xdata,
  .size = ARRAY_SIZE(modetypes_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/module_init_flags.h 5.9-0ubuntu2/xlat/module_init_flags.h
--- 5.5-3/xlat/module_init_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/module_init_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data module_init_flags_xdata[] = {
  XLAT(MODULE_INIT_IGNORE_MODVERSIONS),
+ #define XLAT_VAL_0 ((unsigned) (MODULE_INIT_IGNORE_MODVERSIONS))
+ #define XLAT_STR_0 STRINGIFY(MODULE_INIT_IGNORE_MODVERSIONS)
  XLAT(MODULE_INIT_IGNORE_VERMAGIC),
+ #define XLAT_VAL_1 ((unsigned) (MODULE_INIT_IGNORE_VERMAGIC))
+ #define XLAT_STR_1 STRINGIFY(MODULE_INIT_IGNORE_VERMAGIC)
 };
 static
 const struct xlat module_init_flags[1] = { {
  .data = module_init_flags_xdata,
  .size = ARRAY_SIZE(module_init_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/mount_attr_flags.h 5.9-0ubuntu2/xlat/mount_attr_flags.h
--- 5.5-3/xlat/mount_attr_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/mount_attr_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -63,20 +63,94 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data mount_attr_flags_xdata[] = {
  XLAT(MOUNT_ATTR_RDONLY),
+ #define XLAT_VAL_0 ((unsigned) (MOUNT_ATTR_RDONLY))
+ #define XLAT_STR_0 STRINGIFY(MOUNT_ATTR_RDONLY)
  XLAT(MOUNT_ATTR_NOSUID),
+ #define XLAT_VAL_1 ((unsigned) (MOUNT_ATTR_NOSUID))
+ #define XLAT_STR_1 STRINGIFY(MOUNT_ATTR_NOSUID)
  XLAT(MOUNT_ATTR_NODEV),
+ #define XLAT_VAL_2 ((unsigned) (MOUNT_ATTR_NODEV))
+ #define XLAT_STR_2 STRINGIFY(MOUNT_ATTR_NODEV)
  XLAT(MOUNT_ATTR_NOEXEC),
+ #define XLAT_VAL_3 ((unsigned) (MOUNT_ATTR_NOEXEC))
+ #define XLAT_STR_3 STRINGIFY(MOUNT_ATTR_NOEXEC)
  XLAT(MOUNT_ATTR_NOATIME),
+ #define XLAT_VAL_4 ((unsigned) (MOUNT_ATTR_NOATIME))
+ #define XLAT_STR_4 STRINGIFY(MOUNT_ATTR_NOATIME)
  XLAT(MOUNT_ATTR_STRICTATIME),
+ #define XLAT_VAL_5 ((unsigned) (MOUNT_ATTR_STRICTATIME))
+ #define XLAT_STR_5 STRINGIFY(MOUNT_ATTR_STRICTATIME)
  XLAT(MOUNT_ATTR_NODIRATIME),
+ #define XLAT_VAL_6 ((unsigned) (MOUNT_ATTR_NODIRATIME))
+ #define XLAT_STR_6 STRINGIFY(MOUNT_ATTR_NODIRATIME)
 };
 static
 const struct xlat mount_attr_flags[1] = { {
  .data = mount_attr_flags_xdata,
  .size = ARRAY_SIZE(mount_attr_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/mount_flags.h 5.9-0ubuntu2/xlat/mount_flags.h
--- 5.5-3/xlat/mount_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/mount_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -224,43 +224,347 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data mount_flags_xdata[] = {
  XLAT(MS_RDONLY),
+ #define XLAT_VAL_0 ((unsigned) (MS_RDONLY))
+ #define XLAT_STR_0 STRINGIFY(MS_RDONLY)
  XLAT(MS_NOSUID),
+ #define XLAT_VAL_1 ((unsigned) (MS_NOSUID))
+ #define XLAT_STR_1 STRINGIFY(MS_NOSUID)
  XLAT(MS_NODEV),
+ #define XLAT_VAL_2 ((unsigned) (MS_NODEV))
+ #define XLAT_STR_2 STRINGIFY(MS_NODEV)
  XLAT(MS_NOEXEC),
+ #define XLAT_VAL_3 ((unsigned) (MS_NOEXEC))
+ #define XLAT_STR_3 STRINGIFY(MS_NOEXEC)
  XLAT(MS_SYNCHRONOUS),
+ #define XLAT_VAL_4 ((unsigned) (MS_SYNCHRONOUS))
+ #define XLAT_STR_4 STRINGIFY(MS_SYNCHRONOUS)
  XLAT(MS_REMOUNT),
+ #define XLAT_VAL_5 ((unsigned) (MS_REMOUNT))
+ #define XLAT_STR_5 STRINGIFY(MS_REMOUNT)
  XLAT(MS_MANDLOCK),
+ #define XLAT_VAL_6 ((unsigned) (MS_MANDLOCK))
+ #define XLAT_STR_6 STRINGIFY(MS_MANDLOCK)
  XLAT(MS_DIRSYNC),
+ #define XLAT_VAL_7 ((unsigned) (MS_DIRSYNC))
+ #define XLAT_STR_7 STRINGIFY(MS_DIRSYNC)
  XLAT(MS_NOATIME),
+ #define XLAT_VAL_8 ((unsigned) (MS_NOATIME))
+ #define XLAT_STR_8 STRINGIFY(MS_NOATIME)
  XLAT(MS_NODIRATIME),
+ #define XLAT_VAL_9 ((unsigned) (MS_NODIRATIME))
+ #define XLAT_STR_9 STRINGIFY(MS_NODIRATIME)
  XLAT(MS_BIND),
+ #define XLAT_VAL_10 ((unsigned) (MS_BIND))
+ #define XLAT_STR_10 STRINGIFY(MS_BIND)
  XLAT(MS_MOVE),
+ #define XLAT_VAL_11 ((unsigned) (MS_MOVE))
+ #define XLAT_STR_11 STRINGIFY(MS_MOVE)
  XLAT(MS_REC),
+ #define XLAT_VAL_12 ((unsigned) (MS_REC))
+ #define XLAT_STR_12 STRINGIFY(MS_REC)
  XLAT(MS_SILENT),
+ #define XLAT_VAL_13 ((unsigned) (MS_SILENT))
+ #define XLAT_STR_13 STRINGIFY(MS_SILENT)
  XLAT(MS_POSIXACL),
+ #define XLAT_VAL_14 ((unsigned) (MS_POSIXACL))
+ #define XLAT_STR_14 STRINGIFY(MS_POSIXACL)
  XLAT(MS_UNBINDABLE),
+ #define XLAT_VAL_15 ((unsigned) (MS_UNBINDABLE))
+ #define XLAT_STR_15 STRINGIFY(MS_UNBINDABLE)
  XLAT(MS_PRIVATE),
+ #define XLAT_VAL_16 ((unsigned) (MS_PRIVATE))
+ #define XLAT_STR_16 STRINGIFY(MS_PRIVATE)
  XLAT(MS_SLAVE),
+ #define XLAT_VAL_17 ((unsigned) (MS_SLAVE))
+ #define XLAT_STR_17 STRINGIFY(MS_SLAVE)
  XLAT(MS_SHARED),
+ #define XLAT_VAL_18 ((unsigned) (MS_SHARED))
+ #define XLAT_STR_18 STRINGIFY(MS_SHARED)
  XLAT(MS_RELATIME),
+ #define XLAT_VAL_19 ((unsigned) (MS_RELATIME))
+ #define XLAT_STR_19 STRINGIFY(MS_RELATIME)
  XLAT(MS_KERNMOUNT),
+ #define XLAT_VAL_20 ((unsigned) (MS_KERNMOUNT))
+ #define XLAT_STR_20 STRINGIFY(MS_KERNMOUNT)
  XLAT(MS_I_VERSION),
+ #define XLAT_VAL_21 ((unsigned) (MS_I_VERSION))
+ #define XLAT_STR_21 STRINGIFY(MS_I_VERSION)
  XLAT(MS_STRICTATIME),
+ #define XLAT_VAL_22 ((unsigned) (MS_STRICTATIME))
+ #define XLAT_STR_22 STRINGIFY(MS_STRICTATIME)
  XLAT(MS_LAZYTIME),
+ #define XLAT_VAL_23 ((unsigned) (MS_LAZYTIME))
+ #define XLAT_STR_23 STRINGIFY(MS_LAZYTIME)
  XLAT(MS_SUBMOUNT),
+ #define XLAT_VAL_24 ((unsigned) (MS_SUBMOUNT))
+ #define XLAT_STR_24 STRINGIFY(MS_SUBMOUNT)
  XLAT(MS_NOREMOTELOCK),
+ #define XLAT_VAL_25 ((unsigned) (MS_NOREMOTELOCK))
+ #define XLAT_STR_25 STRINGIFY(MS_NOREMOTELOCK)
  XLAT(MS_NOSEC),
+ #define XLAT_VAL_26 ((unsigned) (MS_NOSEC))
+ #define XLAT_STR_26 STRINGIFY(MS_NOSEC)
  XLAT(MS_BORN),
+ #define XLAT_VAL_27 ((unsigned) (MS_BORN))
+ #define XLAT_STR_27 STRINGIFY(MS_BORN)
  XLAT(MS_ACTIVE),
+ #define XLAT_VAL_28 ((unsigned) (MS_ACTIVE))
+ #define XLAT_STR_28 STRINGIFY(MS_ACTIVE)
  XLAT(MS_NOUSER),
+ #define XLAT_VAL_29 ((unsigned) (MS_NOUSER))
+ #define XLAT_STR_29 STRINGIFY(MS_NOUSER)
 };
 static
 const struct xlat mount_flags[1] = { {
  .data = mount_flags_xdata,
  .size = ARRAY_SIZE(mount_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/move_mount_flags.h 5.9-0ubuntu2/xlat/move_mount_flags.h
--- 5.5-3/xlat/move_mount_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/move_mount_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -56,19 +56,83 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data move_mount_flags_xdata[] = {
  XLAT(MOVE_MOUNT_F_SYMLINKS),
+ #define XLAT_VAL_0 ((unsigned) (MOVE_MOUNT_F_SYMLINKS))
+ #define XLAT_STR_0 STRINGIFY(MOVE_MOUNT_F_SYMLINKS)
  XLAT(MOVE_MOUNT_F_AUTOMOUNTS),
+ #define XLAT_VAL_1 ((unsigned) (MOVE_MOUNT_F_AUTOMOUNTS))
+ #define XLAT_STR_1 STRINGIFY(MOVE_MOUNT_F_AUTOMOUNTS)
  XLAT(MOVE_MOUNT_F_EMPTY_PATH),
+ #define XLAT_VAL_2 ((unsigned) (MOVE_MOUNT_F_EMPTY_PATH))
+ #define XLAT_STR_2 STRINGIFY(MOVE_MOUNT_F_EMPTY_PATH)
  XLAT(MOVE_MOUNT_T_SYMLINKS),
+ #define XLAT_VAL_3 ((unsigned) (MOVE_MOUNT_T_SYMLINKS))
+ #define XLAT_STR_3 STRINGIFY(MOVE_MOUNT_T_SYMLINKS)
  XLAT(MOVE_MOUNT_T_AUTOMOUNTS),
+ #define XLAT_VAL_4 ((unsigned) (MOVE_MOUNT_T_AUTOMOUNTS))
+ #define XLAT_STR_4 STRINGIFY(MOVE_MOUNT_T_AUTOMOUNTS)
  XLAT(MOVE_MOUNT_T_EMPTY_PATH),
+ #define XLAT_VAL_5 ((unsigned) (MOVE_MOUNT_T_EMPTY_PATH))
+ #define XLAT_STR_5 STRINGIFY(MOVE_MOUNT_T_EMPTY_PATH)
 };
 static
 const struct xlat move_mount_flags[1] = { {
  .data = move_mount_flags_xdata,
  .size = ARRAY_SIZE(move_mount_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/move_pages_flags.h 5.9-0ubuntu2/xlat/move_pages_flags.h
--- 5.5-3/xlat/move_pages_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/move_pages_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -15,9 +15,13 @@
 static const struct xlat_data move_pages_flags_xdata[] = {
 #if defined(MPOL_MF_MOVE) || (defined(HAVE_DECL_MPOL_MF_MOVE) && HAVE_DECL_MPOL_MF_MOVE)
   XLAT(MPOL_MF_MOVE),
+ #define XLAT_VAL_0 ((unsigned) (MPOL_MF_MOVE))
+ #define XLAT_STR_0 STRINGIFY(MPOL_MF_MOVE)
 #endif
 #if defined(MPOL_MF_MOVE_ALL) || (defined(HAVE_DECL_MPOL_MF_MOVE_ALL) && HAVE_DECL_MPOL_MF_MOVE_ALL)
   XLAT(MPOL_MF_MOVE_ALL),
+ #define XLAT_VAL_1 ((unsigned) (MPOL_MF_MOVE_ALL))
+ #define XLAT_STR_1 STRINGIFY(MPOL_MF_MOVE_ALL)
 #endif
 };
 static
@@ -25,8 +29,28 @@ const struct xlat move_pages_flags[1] =
  .data = move_pages_flags_xdata,
  .size = ARRAY_SIZE(move_pages_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/mpol_mode_flags.h 5.9-0ubuntu2/xlat/mpol_mode_flags.h
--- 5.5-3/xlat/mpol_mode_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/mpol_mode_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data mpol_mode_flags_xdata[] = {
  XLAT(MPOL_F_STATIC_NODES),
+ #define XLAT_VAL_0 ((unsigned) (MPOL_F_STATIC_NODES))
+ #define XLAT_STR_0 STRINGIFY(MPOL_F_STATIC_NODES)
  XLAT(MPOL_F_RELATIVE_NODES),
+ #define XLAT_VAL_1 ((unsigned) (MPOL_F_RELATIVE_NODES))
+ #define XLAT_STR_1 STRINGIFY(MPOL_F_RELATIVE_NODES)
 };
 static
 const struct xlat mpol_mode_flags[1] = { {
  .data = mpol_mode_flags_xdata,
  .size = ARRAY_SIZE(mpol_mode_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/mpol_modes.h 5.9-0ubuntu2/xlat/mpol_modes.h
--- 5.5-3/xlat/mpol_modes.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/mpol_modes.h	2020-09-24 09:18:44.000000000 +0000
@@ -49,18 +49,72 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data mpol_modes_xdata[] = {
  [MPOL_DEFAULT] = XLAT(MPOL_DEFAULT),
+ #define XLAT_VAL_0 ((unsigned) (MPOL_DEFAULT))
+ #define XLAT_STR_0 STRINGIFY(MPOL_DEFAULT)
  [MPOL_PREFERRED] = XLAT(MPOL_PREFERRED),
+ #define XLAT_VAL_1 ((unsigned) (MPOL_PREFERRED))
+ #define XLAT_STR_1 STRINGIFY(MPOL_PREFERRED)
  [MPOL_BIND] = XLAT(MPOL_BIND),
+ #define XLAT_VAL_2 ((unsigned) (MPOL_BIND))
+ #define XLAT_STR_2 STRINGIFY(MPOL_BIND)
  [MPOL_INTERLEAVE] = XLAT(MPOL_INTERLEAVE),
+ #define XLAT_VAL_3 ((unsigned) (MPOL_INTERLEAVE))
+ #define XLAT_STR_3 STRINGIFY(MPOL_INTERLEAVE)
  [MPOL_LOCAL] = XLAT(MPOL_LOCAL),
+ #define XLAT_VAL_4 ((unsigned) (MPOL_LOCAL))
+ #define XLAT_STR_4 STRINGIFY(MPOL_LOCAL)
 };
 static
 const struct xlat mpol_modes[1] = { {
  .data = mpol_modes_xdata,
  .size = ARRAY_SIZE(mpol_modes_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/mq_attr_flags.h 5.9-0ubuntu2/xlat/mq_attr_flags.h
--- 5.5-3/xlat/mq_attr_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/mq_attr_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -15,6 +15,8 @@ extern const struct xlat mq_attr_flags[]
 static const struct xlat_data mq_attr_flags_xdata[] = {
 #if defined(O_NONBLOCK) || (defined(HAVE_DECL_O_NONBLOCK) && HAVE_DECL_O_NONBLOCK)
   XLAT(O_NONBLOCK),
+ #define XLAT_VAL_0 ((unsigned) (O_NONBLOCK))
+ #define XLAT_STR_0 STRINGIFY(O_NONBLOCK)
 #endif
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
@@ -24,8 +26,20 @@ const struct xlat mq_attr_flags[1] = { {
  .data = mq_attr_flags_xdata,
  .size = ARRAY_SIZE(mq_attr_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/mremap_flags.h 5.9-0ubuntu2/xlat/mremap_flags.h
--- 5.5-3/xlat/mremap_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/mremap_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -3,6 +3,27 @@
 #include "gcc_compat.h"
 #include "static_assert.h"
 
+#if defined(MREMAP_MAYMOVE) || (defined(HAVE_DECL_MREMAP_MAYMOVE) && HAVE_DECL_MREMAP_MAYMOVE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((MREMAP_MAYMOVE) == (1), "MREMAP_MAYMOVE != 1");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define MREMAP_MAYMOVE 1
+#endif
+#if defined(MREMAP_FIXED) || (defined(HAVE_DECL_MREMAP_FIXED) && HAVE_DECL_MREMAP_FIXED)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((MREMAP_FIXED) == (2), "MREMAP_FIXED != 2");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define MREMAP_FIXED 2
+#endif
+#if defined(MREMAP_DONTUNMAP) || (defined(HAVE_DECL_MREMAP_DONTUNMAP) && HAVE_DECL_MREMAP_DONTUNMAP)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((MREMAP_DONTUNMAP) == (4), "MREMAP_DONTUNMAP != 4");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define MREMAP_DONTUNMAP 4
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -13,20 +34,51 @@
 # else
 
 static const struct xlat_data mremap_flags_xdata[] = {
-#if defined(MREMAP_MAYMOVE) || (defined(HAVE_DECL_MREMAP_MAYMOVE) && HAVE_DECL_MREMAP_MAYMOVE)
-  XLAT(MREMAP_MAYMOVE),
-#endif
-#if defined(MREMAP_FIXED) || (defined(HAVE_DECL_MREMAP_FIXED) && HAVE_DECL_MREMAP_FIXED)
-  XLAT(MREMAP_FIXED),
-#endif
+ XLAT(MREMAP_MAYMOVE),
+ #define XLAT_VAL_0 ((unsigned) (MREMAP_MAYMOVE))
+ #define XLAT_STR_0 STRINGIFY(MREMAP_MAYMOVE)
+ XLAT(MREMAP_FIXED),
+ #define XLAT_VAL_1 ((unsigned) (MREMAP_FIXED))
+ #define XLAT_STR_1 STRINGIFY(MREMAP_FIXED)
+ XLAT(MREMAP_DONTUNMAP),
+ #define XLAT_VAL_2 ((unsigned) (MREMAP_DONTUNMAP))
+ #define XLAT_STR_2 STRINGIFY(MREMAP_DONTUNMAP)
 };
 static
 const struct xlat mremap_flags[1] = { {
  .data = mremap_flags_xdata,
  .size = ARRAY_SIZE(mremap_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/mremap_flags.in 5.9-0ubuntu2/xlat/mremap_flags.in
--- 5.5-3/xlat/mremap_flags.in	2014-05-30 21:40:03.000000000 +0000
+++ 5.9-0ubuntu2/xlat/mremap_flags.in	2020-04-15 13:39:57.000000000 +0000
@@ -1,2 +1,3 @@
-MREMAP_MAYMOVE
-MREMAP_FIXED
+MREMAP_MAYMOVE		1
+MREMAP_FIXED		2
+MREMAP_DONTUNMAP	4
diff -pruN 5.5-3/xlat/msgctl_flags.h 5.9-0ubuntu2/xlat/msgctl_flags.h
--- 5.5-3/xlat/msgctl_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/msgctl_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -63,12 +63,26 @@ extern const struct xlat msgctl_flags[];
 
 static const struct xlat_data msgctl_flags_xdata[] = {
  XLAT(IPC_RMID),
+ #define XLAT_VAL_0 ((unsigned) (IPC_RMID))
+ #define XLAT_STR_0 STRINGIFY(IPC_RMID)
  XLAT(IPC_SET),
+ #define XLAT_VAL_1 ((unsigned) (IPC_SET))
+ #define XLAT_STR_1 STRINGIFY(IPC_SET)
  XLAT(IPC_STAT),
+ #define XLAT_VAL_2 ((unsigned) (IPC_STAT))
+ #define XLAT_STR_2 STRINGIFY(IPC_STAT)
  XLAT(IPC_INFO),
+ #define XLAT_VAL_3 ((unsigned) (IPC_INFO))
+ #define XLAT_STR_3 STRINGIFY(IPC_INFO)
  XLAT(MSG_STAT),
+ #define XLAT_VAL_4 ((unsigned) (MSG_STAT))
+ #define XLAT_STR_4 STRINGIFY(MSG_STAT)
  XLAT(MSG_INFO),
+ #define XLAT_VAL_5 ((unsigned) (MSG_INFO))
+ #define XLAT_STR_5 STRINGIFY(MSG_INFO)
  XLAT(MSG_STAT_ANY),
+ #define XLAT_VAL_6 ((unsigned) (MSG_STAT_ANY))
+ #define XLAT_STR_6 STRINGIFY(MSG_STAT_ANY)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -77,8 +91,68 @@ const struct xlat msgctl_flags[1] = { {
  .data = msgctl_flags_xdata,
  .size = ARRAY_SIZE(msgctl_flags_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/msg_flags.h 5.9-0ubuntu2/xlat/msg_flags.h
--- 5.5-3/xlat/msg_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/msg_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -182,30 +182,76 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data msg_flags_xdata[] = {
  XLAT(MSG_OOB),
+ #define XLAT_VAL_0 ((unsigned) (MSG_OOB))
+ #define XLAT_STR_0 STRINGIFY(MSG_OOB)
  XLAT(MSG_PEEK),
+ #define XLAT_VAL_1 ((unsigned) (MSG_PEEK))
+ #define XLAT_STR_1 STRINGIFY(MSG_PEEK)
  XLAT(MSG_DONTROUTE),
+ #define XLAT_VAL_2 ((unsigned) (MSG_DONTROUTE))
+ #define XLAT_STR_2 STRINGIFY(MSG_DONTROUTE)
 
  XLAT(MSG_CTRUNC),
+ #define XLAT_VAL_3 ((unsigned) (MSG_CTRUNC))
+ #define XLAT_STR_3 STRINGIFY(MSG_CTRUNC)
  XLAT(MSG_PROBE),
+ #define XLAT_VAL_4 ((unsigned) (MSG_PROBE))
+ #define XLAT_STR_4 STRINGIFY(MSG_PROBE)
  XLAT(MSG_TRUNC),
+ #define XLAT_VAL_5 ((unsigned) (MSG_TRUNC))
+ #define XLAT_STR_5 STRINGIFY(MSG_TRUNC)
  XLAT(MSG_DONTWAIT),
+ #define XLAT_VAL_6 ((unsigned) (MSG_DONTWAIT))
+ #define XLAT_STR_6 STRINGIFY(MSG_DONTWAIT)
  XLAT(MSG_EOR),
+ #define XLAT_VAL_7 ((unsigned) (MSG_EOR))
+ #define XLAT_STR_7 STRINGIFY(MSG_EOR)
  XLAT(MSG_WAITALL),
+ #define XLAT_VAL_8 ((unsigned) (MSG_WAITALL))
+ #define XLAT_STR_8 STRINGIFY(MSG_WAITALL)
  XLAT(MSG_FIN),
+ #define XLAT_VAL_9 ((unsigned) (MSG_FIN))
+ #define XLAT_STR_9 STRINGIFY(MSG_FIN)
  XLAT(MSG_SYN),
+ #define XLAT_VAL_10 ((unsigned) (MSG_SYN))
+ #define XLAT_STR_10 STRINGIFY(MSG_SYN)
  XLAT(MSG_CONFIRM),
+ #define XLAT_VAL_11 ((unsigned) (MSG_CONFIRM))
+ #define XLAT_STR_11 STRINGIFY(MSG_CONFIRM)
  XLAT(MSG_RST),
+ #define XLAT_VAL_12 ((unsigned) (MSG_RST))
+ #define XLAT_STR_12 STRINGIFY(MSG_RST)
  XLAT(MSG_ERRQUEUE),
+ #define XLAT_VAL_13 ((unsigned) (MSG_ERRQUEUE))
+ #define XLAT_STR_13 STRINGIFY(MSG_ERRQUEUE)
  XLAT(MSG_NOSIGNAL),
+ #define XLAT_VAL_14 ((unsigned) (MSG_NOSIGNAL))
+ #define XLAT_STR_14 STRINGIFY(MSG_NOSIGNAL)
  XLAT(MSG_MORE),
+ #define XLAT_VAL_15 ((unsigned) (MSG_MORE))
+ #define XLAT_STR_15 STRINGIFY(MSG_MORE)
  XLAT(MSG_WAITFORONE),
+ #define XLAT_VAL_16 ((unsigned) (MSG_WAITFORONE))
+ #define XLAT_STR_16 STRINGIFY(MSG_WAITFORONE)
  XLAT(MSG_SENDPAGE_NOTLAST),
+ #define XLAT_VAL_17 ((unsigned) (MSG_SENDPAGE_NOTLAST))
+ #define XLAT_STR_17 STRINGIFY(MSG_SENDPAGE_NOTLAST)
  XLAT(MSG_BATCH),
+ #define XLAT_VAL_18 ((unsigned) (MSG_BATCH))
+ #define XLAT_STR_18 STRINGIFY(MSG_BATCH)
  XLAT(MSG_NO_SHARED_FRAGS),
+ #define XLAT_VAL_19 ((unsigned) (MSG_NO_SHARED_FRAGS))
+ #define XLAT_STR_19 STRINGIFY(MSG_NO_SHARED_FRAGS)
  XLAT(MSG_ZEROCOPY),
+ #define XLAT_VAL_20 ((unsigned) (MSG_ZEROCOPY))
+ #define XLAT_STR_20 STRINGIFY(MSG_ZEROCOPY)
 
  XLAT(MSG_FASTOPEN),
+ #define XLAT_VAL_21 ((unsigned) (MSG_FASTOPEN))
+ #define XLAT_STR_21 STRINGIFY(MSG_FASTOPEN)
  XLAT(MSG_CMSG_CLOEXEC),
+ #define XLAT_VAL_22 ((unsigned) (MSG_CMSG_CLOEXEC))
+ #define XLAT_STR_22 STRINGIFY(MSG_CMSG_CLOEXEC)
 #ifndef STRACE_WORKAROUND_FOR_MSG_CMSG_COMPAT
 # define STRACE_WORKAROUND_FOR_MSG_CMSG_COMPAT
 /*
@@ -215,13 +261,211 @@ static const struct xlat_data msg_flags_
 # undef MSG_CMSG_COMPAT
 #endif
  XLAT(MSG_CMSG_COMPAT),
+ #define XLAT_VAL_23 ((unsigned) (MSG_CMSG_COMPAT))
+ #define XLAT_STR_23 STRINGIFY(MSG_CMSG_COMPAT)
 };
 const struct xlat msg_flags[1] = { {
  .data = msg_flags_xdata,
  .size = ARRAY_SIZE(msg_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/mtd_file_mode_options.h 5.9-0ubuntu2/xlat/mtd_file_mode_options.h
--- 5.5-3/xlat/mtd_file_mode_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/mtd_file_mode_options.h	2020-09-24 09:18:44.000000000 +0000
@@ -14,9 +14,17 @@ extern const struct xlat mtd_file_mode_o
 
 static const struct xlat_data mtd_file_mode_options_xdata[] = {
  XLAT(MTD_FILE_MODE_NORMAL),
+ #define XLAT_VAL_0 ((unsigned) (MTD_FILE_MODE_NORMAL))
+ #define XLAT_STR_0 STRINGIFY(MTD_FILE_MODE_NORMAL)
  XLAT(MTD_FILE_MODE_OTP_FACTORY),
+ #define XLAT_VAL_1 ((unsigned) (MTD_FILE_MODE_OTP_FACTORY))
+ #define XLAT_STR_1 STRINGIFY(MTD_FILE_MODE_OTP_FACTORY)
  XLAT(MTD_FILE_MODE_OTP_USER),
+ #define XLAT_VAL_2 ((unsigned) (MTD_FILE_MODE_OTP_USER))
+ #define XLAT_STR_2 STRINGIFY(MTD_FILE_MODE_OTP_USER)
  XLAT(MTD_FILE_MODE_RAW),
+ #define XLAT_VAL_3 ((unsigned) (MTD_FILE_MODE_RAW))
+ #define XLAT_STR_3 STRINGIFY(MTD_FILE_MODE_RAW)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -25,8 +33,44 @@ const struct xlat mtd_file_mode_options[
  .data = mtd_file_mode_options_xdata,
  .size = ARRAY_SIZE(mtd_file_mode_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/mtd_flags_options.h 5.9-0ubuntu2/xlat/mtd_flags_options.h
--- 5.5-3/xlat/mtd_flags_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/mtd_flags_options.h	2020-09-24 09:18:44.000000000 +0000
@@ -15,15 +15,23 @@ extern const struct xlat mtd_flags_optio
 static const struct xlat_data mtd_flags_options_xdata[] = {
 #if defined(MTD_WRITEABLE) || (defined(HAVE_DECL_MTD_WRITEABLE) && HAVE_DECL_MTD_WRITEABLE)
   XLAT(MTD_WRITEABLE),
+ #define XLAT_VAL_0 ((unsigned) (MTD_WRITEABLE))
+ #define XLAT_STR_0 STRINGIFY(MTD_WRITEABLE)
 #endif
 #if defined(MTD_BIT_WRITEABLE) || (defined(HAVE_DECL_MTD_BIT_WRITEABLE) && HAVE_DECL_MTD_BIT_WRITEABLE)
   XLAT(MTD_BIT_WRITEABLE),
+ #define XLAT_VAL_1 ((unsigned) (MTD_BIT_WRITEABLE))
+ #define XLAT_STR_1 STRINGIFY(MTD_BIT_WRITEABLE)
 #endif
 #if defined(MTD_NO_ERASE) || (defined(HAVE_DECL_MTD_NO_ERASE) && HAVE_DECL_MTD_NO_ERASE)
   XLAT(MTD_NO_ERASE),
+ #define XLAT_VAL_2 ((unsigned) (MTD_NO_ERASE))
+ #define XLAT_STR_2 STRINGIFY(MTD_NO_ERASE)
 #endif
 #if defined(MTD_POWERUP_LOCK) || (defined(HAVE_DECL_MTD_POWERUP_LOCK) && HAVE_DECL_MTD_POWERUP_LOCK)
   XLAT(MTD_POWERUP_LOCK),
+ #define XLAT_VAL_3 ((unsigned) (MTD_POWERUP_LOCK))
+ #define XLAT_STR_3 STRINGIFY(MTD_POWERUP_LOCK)
 #endif
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
@@ -33,8 +41,44 @@ const struct xlat mtd_flags_options[1] =
  .data = mtd_flags_options_xdata,
  .size = ARRAY_SIZE(mtd_flags_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/mtd_mode_options.h 5.9-0ubuntu2/xlat/mtd_mode_options.h
--- 5.5-3/xlat/mtd_mode_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/mtd_mode_options.h	2020-09-24 09:18:44.000000000 +0000
@@ -14,8 +14,14 @@ extern const struct xlat mtd_mode_option
 
 static const struct xlat_data mtd_mode_options_xdata[] = {
  XLAT(MTD_OPS_PLACE_OOB),
+ #define XLAT_VAL_0 ((unsigned) (MTD_OPS_PLACE_OOB))
+ #define XLAT_STR_0 STRINGIFY(MTD_OPS_PLACE_OOB)
  XLAT(MTD_OPS_AUTO_OOB),
+ #define XLAT_VAL_1 ((unsigned) (MTD_OPS_AUTO_OOB))
+ #define XLAT_STR_1 STRINGIFY(MTD_OPS_AUTO_OOB)
  XLAT(MTD_OPS_RAW),
+ #define XLAT_VAL_2 ((unsigned) (MTD_OPS_RAW))
+ #define XLAT_STR_2 STRINGIFY(MTD_OPS_RAW)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -24,8 +30,36 @@ const struct xlat mtd_mode_options[1] =
  .data = mtd_mode_options_xdata,
  .size = ARRAY_SIZE(mtd_mode_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/mtd_nandecc_options.h 5.9-0ubuntu2/xlat/mtd_nandecc_options.h
--- 5.5-3/xlat/mtd_nandecc_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/mtd_nandecc_options.h	2020-09-24 09:18:44.000000000 +0000
@@ -15,18 +15,28 @@ extern const struct xlat mtd_nandecc_opt
 static const struct xlat_data mtd_nandecc_options_xdata[] = {
 #if defined(MTD_NANDECC_OFF) || (defined(HAVE_DECL_MTD_NANDECC_OFF) && HAVE_DECL_MTD_NANDECC_OFF)
   XLAT(MTD_NANDECC_OFF),
+ #define XLAT_VAL_0 ((unsigned) (MTD_NANDECC_OFF))
+ #define XLAT_STR_0 STRINGIFY(MTD_NANDECC_OFF)
 #endif
 #if defined(MTD_NANDECC_PLACE) || (defined(HAVE_DECL_MTD_NANDECC_PLACE) && HAVE_DECL_MTD_NANDECC_PLACE)
   XLAT(MTD_NANDECC_PLACE),
+ #define XLAT_VAL_1 ((unsigned) (MTD_NANDECC_PLACE))
+ #define XLAT_STR_1 STRINGIFY(MTD_NANDECC_PLACE)
 #endif
 #if defined(MTD_NANDECC_AUTOPLACE) || (defined(HAVE_DECL_MTD_NANDECC_AUTOPLACE) && HAVE_DECL_MTD_NANDECC_AUTOPLACE)
   XLAT(MTD_NANDECC_AUTOPLACE),
+ #define XLAT_VAL_2 ((unsigned) (MTD_NANDECC_AUTOPLACE))
+ #define XLAT_STR_2 STRINGIFY(MTD_NANDECC_AUTOPLACE)
 #endif
 #if defined(MTD_NANDECC_PLACEONLY) || (defined(HAVE_DECL_MTD_NANDECC_PLACEONLY) && HAVE_DECL_MTD_NANDECC_PLACEONLY)
   XLAT(MTD_NANDECC_PLACEONLY),
+ #define XLAT_VAL_3 ((unsigned) (MTD_NANDECC_PLACEONLY))
+ #define XLAT_STR_3 STRINGIFY(MTD_NANDECC_PLACEONLY)
 #endif
 #if defined(MTD_NANDECC_AUTOPL_USR) || (defined(HAVE_DECL_MTD_NANDECC_AUTOPL_USR) && HAVE_DECL_MTD_NANDECC_AUTOPL_USR)
   XLAT(MTD_NANDECC_AUTOPL_USR),
+ #define XLAT_VAL_4 ((unsigned) (MTD_NANDECC_AUTOPL_USR))
+ #define XLAT_STR_4 STRINGIFY(MTD_NANDECC_AUTOPL_USR)
 #endif
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
@@ -36,8 +46,52 @@ const struct xlat mtd_nandecc_options[1]
  .data = mtd_nandecc_options_xdata,
  .size = ARRAY_SIZE(mtd_nandecc_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/mtd_otp_options.h 5.9-0ubuntu2/xlat/mtd_otp_options.h
--- 5.5-3/xlat/mtd_otp_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/mtd_otp_options.h	2020-09-24 09:18:44.000000000 +0000
@@ -15,12 +15,18 @@ extern const struct xlat mtd_otp_options
 static const struct xlat_data mtd_otp_options_xdata[] = {
 #if defined(MTD_OTP_OFF) || (defined(HAVE_DECL_MTD_OTP_OFF) && HAVE_DECL_MTD_OTP_OFF)
   XLAT(MTD_OTP_OFF),
+ #define XLAT_VAL_0 ((unsigned) (MTD_OTP_OFF))
+ #define XLAT_STR_0 STRINGIFY(MTD_OTP_OFF)
 #endif
 #if defined(MTD_OTP_FACTORY) || (defined(HAVE_DECL_MTD_OTP_FACTORY) && HAVE_DECL_MTD_OTP_FACTORY)
   XLAT(MTD_OTP_FACTORY),
+ #define XLAT_VAL_1 ((unsigned) (MTD_OTP_FACTORY))
+ #define XLAT_STR_1 STRINGIFY(MTD_OTP_FACTORY)
 #endif
 #if defined(MTD_OTP_USER) || (defined(HAVE_DECL_MTD_OTP_USER) && HAVE_DECL_MTD_OTP_USER)
   XLAT(MTD_OTP_USER),
+ #define XLAT_VAL_2 ((unsigned) (MTD_OTP_USER))
+ #define XLAT_STR_2 STRINGIFY(MTD_OTP_USER)
 #endif
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
@@ -30,8 +36,36 @@ const struct xlat mtd_otp_options[1] = {
  .data = mtd_otp_options_xdata,
  .size = ARRAY_SIZE(mtd_otp_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/mtd_type_options.h 5.9-0ubuntu2/xlat/mtd_type_options.h
--- 5.5-3/xlat/mtd_type_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/mtd_type_options.h	2020-09-24 09:18:44.000000000 +0000
@@ -15,27 +15,43 @@ extern const struct xlat mtd_type_option
 static const struct xlat_data mtd_type_options_xdata[] = {
 #if defined(MTD_ABSENT) || (defined(HAVE_DECL_MTD_ABSENT) && HAVE_DECL_MTD_ABSENT)
   XLAT(MTD_ABSENT),
+ #define XLAT_VAL_0 ((unsigned) (MTD_ABSENT))
+ #define XLAT_STR_0 STRINGIFY(MTD_ABSENT)
 #endif
 #if defined(MTD_RAM) || (defined(HAVE_DECL_MTD_RAM) && HAVE_DECL_MTD_RAM)
   XLAT(MTD_RAM),
+ #define XLAT_VAL_1 ((unsigned) (MTD_RAM))
+ #define XLAT_STR_1 STRINGIFY(MTD_RAM)
 #endif
 #if defined(MTD_ROM) || (defined(HAVE_DECL_MTD_ROM) && HAVE_DECL_MTD_ROM)
   XLAT(MTD_ROM),
+ #define XLAT_VAL_2 ((unsigned) (MTD_ROM))
+ #define XLAT_STR_2 STRINGIFY(MTD_ROM)
 #endif
 #if defined(MTD_NORFLASH) || (defined(HAVE_DECL_MTD_NORFLASH) && HAVE_DECL_MTD_NORFLASH)
   XLAT(MTD_NORFLASH),
+ #define XLAT_VAL_3 ((unsigned) (MTD_NORFLASH))
+ #define XLAT_STR_3 STRINGIFY(MTD_NORFLASH)
 #endif
 #if defined(MTD_NANDFLASH) || (defined(HAVE_DECL_MTD_NANDFLASH) && HAVE_DECL_MTD_NANDFLASH)
   XLAT(MTD_NANDFLASH),
+ #define XLAT_VAL_4 ((unsigned) (MTD_NANDFLASH))
+ #define XLAT_STR_4 STRINGIFY(MTD_NANDFLASH)
 #endif
 #if defined(MTD_DATAFLASH) || (defined(HAVE_DECL_MTD_DATAFLASH) && HAVE_DECL_MTD_DATAFLASH)
   XLAT(MTD_DATAFLASH),
+ #define XLAT_VAL_5 ((unsigned) (MTD_DATAFLASH))
+ #define XLAT_STR_5 STRINGIFY(MTD_DATAFLASH)
 #endif
 #if defined(MTD_UBIVOLUME) || (defined(HAVE_DECL_MTD_UBIVOLUME) && HAVE_DECL_MTD_UBIVOLUME)
   XLAT(MTD_UBIVOLUME),
+ #define XLAT_VAL_6 ((unsigned) (MTD_UBIVOLUME))
+ #define XLAT_STR_6 STRINGIFY(MTD_UBIVOLUME)
 #endif
 #if defined(MTD_MLCNANDFLASH) || (defined(HAVE_DECL_MTD_MLCNANDFLASH) && HAVE_DECL_MTD_MLCNANDFLASH)
   XLAT(MTD_MLCNANDFLASH),
+ #define XLAT_VAL_7 ((unsigned) (MTD_MLCNANDFLASH))
+ #define XLAT_STR_7 STRINGIFY(MTD_MLCNANDFLASH)
 #endif
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
@@ -45,8 +61,76 @@ const struct xlat mtd_type_options[1] =
  .data = mtd_type_options_xdata,
  .size = ARRAY_SIZE(mtd_type_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/multicast_router_types.h 5.9-0ubuntu2/xlat/multicast_router_types.h
--- 5.5-3/xlat/multicast_router_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/multicast_router_types.h	2020-09-24 09:18:44.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data multicast_router_types_xdata[] = {
  [MDB_RTR_TYPE_DISABLED] = XLAT(MDB_RTR_TYPE_DISABLED),
+ #define XLAT_VAL_0 ((unsigned) (MDB_RTR_TYPE_DISABLED))
+ #define XLAT_STR_0 STRINGIFY(MDB_RTR_TYPE_DISABLED)
  [MDB_RTR_TYPE_TEMP_QUERY] = XLAT(MDB_RTR_TYPE_TEMP_QUERY),
+ #define XLAT_VAL_1 ((unsigned) (MDB_RTR_TYPE_TEMP_QUERY))
+ #define XLAT_STR_1 STRINGIFY(MDB_RTR_TYPE_TEMP_QUERY)
  [MDB_RTR_TYPE_PERM] = XLAT(MDB_RTR_TYPE_PERM),
+ #define XLAT_VAL_2 ((unsigned) (MDB_RTR_TYPE_PERM))
+ #define XLAT_STR_2 STRINGIFY(MDB_RTR_TYPE_PERM)
  [MDB_RTR_TYPE_TEMP] = XLAT(MDB_RTR_TYPE_TEMP),
+ #define XLAT_VAL_3 ((unsigned) (MDB_RTR_TYPE_TEMP))
+ #define XLAT_STR_3 STRINGIFY(MDB_RTR_TYPE_TEMP)
 };
 static
 const struct xlat multicast_router_types[1] = { {
  .data = multicast_router_types_xdata,
  .size = ARRAY_SIZE(multicast_router_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/name_to_handle_at_flags.h 5.9-0ubuntu2/xlat/name_to_handle_at_flags.h
--- 5.5-3/xlat/name_to_handle_at_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/name_to_handle_at_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data name_to_handle_at_flags_xdata[] = {
  XLAT(AT_SYMLINK_FOLLOW),
+ #define XLAT_VAL_0 ((unsigned) (AT_SYMLINK_FOLLOW))
+ #define XLAT_STR_0 STRINGIFY(AT_SYMLINK_FOLLOW)
  XLAT(AT_EMPTY_PATH),
+ #define XLAT_VAL_1 ((unsigned) (AT_EMPTY_PATH))
+ #define XLAT_STR_1 STRINGIFY(AT_EMPTY_PATH)
 };
 static
 const struct xlat name_to_handle_at_flags[1] = { {
  .data = name_to_handle_at_flags_xdata,
  .size = ARRAY_SIZE(name_to_handle_at_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/nbd_ioctl_cmds.h 5.9-0ubuntu2/xlat/nbd_ioctl_cmds.h
--- 5.5-3/xlat/nbd_ioctl_cmds.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/nbd_ioctl_cmds.h	2020-09-24 09:18:45.000000000 +0000
@@ -91,24 +91,138 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data nbd_ioctl_cmds_xdata[] = {
  XLAT(NBD_SET_SOCK),
+ #define XLAT_VAL_0 ((unsigned) (NBD_SET_SOCK))
+ #define XLAT_STR_0 STRINGIFY(NBD_SET_SOCK)
  XLAT(NBD_SET_BLKSIZE),
+ #define XLAT_VAL_1 ((unsigned) (NBD_SET_BLKSIZE))
+ #define XLAT_STR_1 STRINGIFY(NBD_SET_BLKSIZE)
  XLAT(NBD_SET_SIZE),
+ #define XLAT_VAL_2 ((unsigned) (NBD_SET_SIZE))
+ #define XLAT_STR_2 STRINGIFY(NBD_SET_SIZE)
  XLAT(NBD_DO_IT),
+ #define XLAT_VAL_3 ((unsigned) (NBD_DO_IT))
+ #define XLAT_STR_3 STRINGIFY(NBD_DO_IT)
  XLAT(NBD_CLEAR_SOCK),
+ #define XLAT_VAL_4 ((unsigned) (NBD_CLEAR_SOCK))
+ #define XLAT_STR_4 STRINGIFY(NBD_CLEAR_SOCK)
  XLAT(NBD_CLEAR_QUE),
+ #define XLAT_VAL_5 ((unsigned) (NBD_CLEAR_QUE))
+ #define XLAT_STR_5 STRINGIFY(NBD_CLEAR_QUE)
  XLAT(NBD_PRINT_DEBUG),
+ #define XLAT_VAL_6 ((unsigned) (NBD_PRINT_DEBUG))
+ #define XLAT_STR_6 STRINGIFY(NBD_PRINT_DEBUG)
  XLAT(NBD_SET_SIZE_BLOCKS),
+ #define XLAT_VAL_7 ((unsigned) (NBD_SET_SIZE_BLOCKS))
+ #define XLAT_STR_7 STRINGIFY(NBD_SET_SIZE_BLOCKS)
  XLAT(NBD_DISCONNECT),
+ #define XLAT_VAL_8 ((unsigned) (NBD_DISCONNECT))
+ #define XLAT_STR_8 STRINGIFY(NBD_DISCONNECT)
  XLAT(NBD_SET_TIMEOUT),
+ #define XLAT_VAL_9 ((unsigned) (NBD_SET_TIMEOUT))
+ #define XLAT_STR_9 STRINGIFY(NBD_SET_TIMEOUT)
  XLAT(NBD_SET_FLAGS),
+ #define XLAT_VAL_10 ((unsigned) (NBD_SET_FLAGS))
+ #define XLAT_STR_10 STRINGIFY(NBD_SET_FLAGS)
 };
 static
 const struct xlat nbd_ioctl_cmds[1] = { {
  .data = nbd_ioctl_cmds_xdata,
  .size = ARRAY_SIZE(nbd_ioctl_cmds_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/nbd_ioctl_flags.h 5.9-0ubuntu2/xlat/nbd_ioctl_flags.h
--- 5.5-3/xlat/nbd_ioctl_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/nbd_ioctl_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -99,34 +99,148 @@ static const struct xlat_data nbd_ioctl_
 
 
  XLAT(NBD_FLAG_HAS_FLAGS),
+ #define XLAT_VAL_0 ((unsigned) (NBD_FLAG_HAS_FLAGS))
+ #define XLAT_STR_0 STRINGIFY(NBD_FLAG_HAS_FLAGS)
 
  XLAT(NBD_FLAG_READ_ONLY),
+ #define XLAT_VAL_1 ((unsigned) (NBD_FLAG_READ_ONLY))
+ #define XLAT_STR_1 STRINGIFY(NBD_FLAG_READ_ONLY)
 
  XLAT(NBD_FLAG_SEND_FLUSH),
+ #define XLAT_VAL_2 ((unsigned) (NBD_FLAG_SEND_FLUSH))
+ #define XLAT_STR_2 STRINGIFY(NBD_FLAG_SEND_FLUSH)
 
  XLAT(NBD_FLAG_SEND_FUA),
+ #define XLAT_VAL_3 ((unsigned) (NBD_FLAG_SEND_FUA))
+ #define XLAT_STR_3 STRINGIFY(NBD_FLAG_SEND_FUA)
 
  XLAT(NBD_FLAG_ROTATIONAL),
+ #define XLAT_VAL_4 ((unsigned) (NBD_FLAG_ROTATIONAL))
+ #define XLAT_STR_4 STRINGIFY(NBD_FLAG_ROTATIONAL)
 
  XLAT(NBD_FLAG_SEND_TRIM),
+ #define XLAT_VAL_5 ((unsigned) (NBD_FLAG_SEND_TRIM))
+ #define XLAT_STR_5 STRINGIFY(NBD_FLAG_SEND_TRIM)
 
  XLAT(NBD_FLAG_SEND_WRITE_ZEROES),
+ #define XLAT_VAL_6 ((unsigned) (NBD_FLAG_SEND_WRITE_ZEROES))
+ #define XLAT_STR_6 STRINGIFY(NBD_FLAG_SEND_WRITE_ZEROES)
 
  XLAT(NBD_FLAG_SEND_DF),
+ #define XLAT_VAL_7 ((unsigned) (NBD_FLAG_SEND_DF))
+ #define XLAT_STR_7 STRINGIFY(NBD_FLAG_SEND_DF)
 
  XLAT(NBD_FLAG_CAN_MULTI_CONN),
+ #define XLAT_VAL_8 ((unsigned) (NBD_FLAG_CAN_MULTI_CONN))
+ #define XLAT_STR_8 STRINGIFY(NBD_FLAG_CAN_MULTI_CONN)
 
  XLAT(NBD_FLAG_SEND_RESIZE),
+ #define XLAT_VAL_9 ((unsigned) (NBD_FLAG_SEND_RESIZE))
+ #define XLAT_STR_9 STRINGIFY(NBD_FLAG_SEND_RESIZE)
 
  XLAT(NBD_FLAG_SEND_CACHE),
+ #define XLAT_VAL_10 ((unsigned) (NBD_FLAG_SEND_CACHE))
+ #define XLAT_STR_10 STRINGIFY(NBD_FLAG_SEND_CACHE)
 };
 static
 const struct xlat nbd_ioctl_flags[1] = { {
  .data = nbd_ioctl_flags_xdata,
  .size = ARRAY_SIZE(nbd_ioctl_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/neighbor_cache_entry_flags.h 5.9-0ubuntu2/xlat/neighbor_cache_entry_flags.h
--- 5.5-3/xlat/neighbor_cache_entry_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/neighbor_cache_entry_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -70,21 +70,105 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data neighbor_cache_entry_flags_xdata[] = {
  XLAT(NTF_USE),
+ #define XLAT_VAL_0 ((unsigned) (NTF_USE))
+ #define XLAT_STR_0 STRINGIFY(NTF_USE)
  XLAT(NTF_SELF),
+ #define XLAT_VAL_1 ((unsigned) (NTF_SELF))
+ #define XLAT_STR_1 STRINGIFY(NTF_SELF)
  XLAT(NTF_MASTER),
+ #define XLAT_VAL_2 ((unsigned) (NTF_MASTER))
+ #define XLAT_STR_2 STRINGIFY(NTF_MASTER)
  XLAT(NTF_PROXY),
+ #define XLAT_VAL_3 ((unsigned) (NTF_PROXY))
+ #define XLAT_STR_3 STRINGIFY(NTF_PROXY)
  XLAT(NTF_EXT_LEARNED),
+ #define XLAT_VAL_4 ((unsigned) (NTF_EXT_LEARNED))
+ #define XLAT_STR_4 STRINGIFY(NTF_EXT_LEARNED)
  XLAT(NTF_OFFLOADED),
+ #define XLAT_VAL_5 ((unsigned) (NTF_OFFLOADED))
+ #define XLAT_STR_5 STRINGIFY(NTF_OFFLOADED)
  XLAT(NTF_STICKY),
+ #define XLAT_VAL_6 ((unsigned) (NTF_STICKY))
+ #define XLAT_STR_6 STRINGIFY(NTF_STICKY)
  XLAT(NTF_ROUTER),
+ #define XLAT_VAL_7 ((unsigned) (NTF_ROUTER))
+ #define XLAT_STR_7 STRINGIFY(NTF_ROUTER)
 };
 static
 const struct xlat neighbor_cache_entry_flags[1] = { {
  .data = neighbor_cache_entry_flags_xdata,
  .size = ARRAY_SIZE(neighbor_cache_entry_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/neighbor_cache_entry_states.h 5.9-0ubuntu2/xlat/neighbor_cache_entry_states.h
--- 5.5-3/xlat/neighbor_cache_entry_states.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/neighbor_cache_entry_states.h	2020-09-24 09:18:45.000000000 +0000
@@ -15,30 +15,48 @@
 static const struct xlat_data neighbor_cache_entry_states_xdata[] = {
 #if defined(NUD_INCOMPLETE) || (defined(HAVE_DECL_NUD_INCOMPLETE) && HAVE_DECL_NUD_INCOMPLETE)
   XLAT(NUD_INCOMPLETE),
+ #define XLAT_VAL_0 ((unsigned) (NUD_INCOMPLETE))
+ #define XLAT_STR_0 STRINGIFY(NUD_INCOMPLETE)
 #endif
 #if defined(NUD_REACHABLE) || (defined(HAVE_DECL_NUD_REACHABLE) && HAVE_DECL_NUD_REACHABLE)
   XLAT(NUD_REACHABLE),
+ #define XLAT_VAL_1 ((unsigned) (NUD_REACHABLE))
+ #define XLAT_STR_1 STRINGIFY(NUD_REACHABLE)
 #endif
 #if defined(NUD_STALE) || (defined(HAVE_DECL_NUD_STALE) && HAVE_DECL_NUD_STALE)
   XLAT(NUD_STALE),
+ #define XLAT_VAL_2 ((unsigned) (NUD_STALE))
+ #define XLAT_STR_2 STRINGIFY(NUD_STALE)
 #endif
 #if defined(NUD_DELAY) || (defined(HAVE_DECL_NUD_DELAY) && HAVE_DECL_NUD_DELAY)
   XLAT(NUD_DELAY),
+ #define XLAT_VAL_3 ((unsigned) (NUD_DELAY))
+ #define XLAT_STR_3 STRINGIFY(NUD_DELAY)
 #endif
 #if defined(NUD_PROBE) || (defined(HAVE_DECL_NUD_PROBE) && HAVE_DECL_NUD_PROBE)
   XLAT(NUD_PROBE),
+ #define XLAT_VAL_4 ((unsigned) (NUD_PROBE))
+ #define XLAT_STR_4 STRINGIFY(NUD_PROBE)
 #endif
 #if defined(NUD_FAILED) || (defined(HAVE_DECL_NUD_FAILED) && HAVE_DECL_NUD_FAILED)
   XLAT(NUD_FAILED),
+ #define XLAT_VAL_5 ((unsigned) (NUD_FAILED))
+ #define XLAT_STR_5 STRINGIFY(NUD_FAILED)
 #endif
 #if defined(NUD_NOARP) || (defined(HAVE_DECL_NUD_NOARP) && HAVE_DECL_NUD_NOARP)
   XLAT(NUD_NOARP),
+ #define XLAT_VAL_6 ((unsigned) (NUD_NOARP))
+ #define XLAT_STR_6 STRINGIFY(NUD_NOARP)
 #endif
 #if defined(NUD_PERMANENT) || (defined(HAVE_DECL_NUD_PERMANENT) && HAVE_DECL_NUD_PERMANENT)
   XLAT(NUD_PERMANENT),
+ #define XLAT_VAL_7 ((unsigned) (NUD_PERMANENT))
+ #define XLAT_STR_7 STRINGIFY(NUD_PERMANENT)
 #endif
 #if defined(NUD_NONE) || (defined(HAVE_DECL_NUD_NONE) && HAVE_DECL_NUD_NONE)
   XLAT(NUD_NONE),
+ #define XLAT_VAL_8 ((unsigned) (NUD_NONE))
+ #define XLAT_STR_8 STRINGIFY(NUD_NONE)
 #endif
 };
 static
@@ -46,8 +64,84 @@ const struct xlat neighbor_cache_entry_s
  .data = neighbor_cache_entry_states_xdata,
  .size = ARRAY_SIZE(neighbor_cache_entry_states_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/netfilter_versions.h 5.9-0ubuntu2/xlat/netfilter_versions.h
--- 5.5-3/xlat/netfilter_versions.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/netfilter_versions.h	2020-09-24 09:18:44.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data netfilter_versions_xdata[] = {
  [NFNETLINK_V0] = XLAT(NFNETLINK_V0),
+ #define XLAT_VAL_0 ((unsigned) (NFNETLINK_V0))
+ #define XLAT_STR_0 STRINGIFY(NFNETLINK_V0)
  [NFNETLINK_V1] = XLAT(NFNETLINK_V1),
+ #define XLAT_VAL_1 ((unsigned) (NFNETLINK_V1))
+ #define XLAT_STR_1 STRINGIFY(NFNETLINK_V1)
 };
 static
 const struct xlat netfilter_versions[1] = { {
  .data = netfilter_versions_xdata,
  .size = ARRAY_SIZE(netfilter_versions_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/netlink_ack_flags.h 5.9-0ubuntu2/xlat/netlink_ack_flags.h
--- 5.5-3/xlat/netlink_ack_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/netlink_ack_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data netlink_ack_flags_xdata[] = {
  XLAT(NLM_F_CAPPED),
+ #define XLAT_VAL_0 ((unsigned) (NLM_F_CAPPED))
+ #define XLAT_STR_0 STRINGIFY(NLM_F_CAPPED)
  XLAT(NLM_F_ACK_TLVS),
+ #define XLAT_VAL_1 ((unsigned) (NLM_F_ACK_TLVS))
+ #define XLAT_STR_1 STRINGIFY(NLM_F_ACK_TLVS)
 };
 static
 const struct xlat netlink_ack_flags[1] = { {
  .data = netlink_ack_flags_xdata,
  .size = ARRAY_SIZE(netlink_ack_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/netlink_delete_flags.h 5.9-0ubuntu2/xlat/netlink_delete_flags.h
--- 5.5-3/xlat/netlink_delete_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/netlink_delete_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -15,6 +15,8 @@
 static const struct xlat_data netlink_delete_flags_xdata[] = {
 #if defined(NLM_F_NONREC) || (defined(HAVE_DECL_NLM_F_NONREC) && HAVE_DECL_NLM_F_NONREC)
   XLAT(NLM_F_NONREC),
+ #define XLAT_VAL_0 ((unsigned) (NLM_F_NONREC))
+ #define XLAT_STR_0 STRINGIFY(NLM_F_NONREC)
 #endif
 };
 static
@@ -22,8 +24,20 @@ const struct xlat netlink_delete_flags[1
  .data = netlink_delete_flags_xdata,
  .size = ARRAY_SIZE(netlink_delete_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/netlink_diag_attrs.h 5.9-0ubuntu2/xlat/netlink_diag_attrs.h
--- 5.5-3/xlat/netlink_diag_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/netlink_diag_attrs.h	2020-09-24 09:18:44.000000000 +0000
@@ -14,18 +14,72 @@
 
 static const struct xlat_data netlink_diag_attrs_xdata[] = {
  XLAT(NETLINK_DIAG_MEMINFO),
+ #define XLAT_VAL_0 ((unsigned) (NETLINK_DIAG_MEMINFO))
+ #define XLAT_STR_0 STRINGIFY(NETLINK_DIAG_MEMINFO)
  XLAT(NETLINK_DIAG_GROUPS),
+ #define XLAT_VAL_1 ((unsigned) (NETLINK_DIAG_GROUPS))
+ #define XLAT_STR_1 STRINGIFY(NETLINK_DIAG_GROUPS)
  XLAT(NETLINK_DIAG_RX_RING),
+ #define XLAT_VAL_2 ((unsigned) (NETLINK_DIAG_RX_RING))
+ #define XLAT_STR_2 STRINGIFY(NETLINK_DIAG_RX_RING)
  XLAT(NETLINK_DIAG_TX_RING),
+ #define XLAT_VAL_3 ((unsigned) (NETLINK_DIAG_TX_RING))
+ #define XLAT_STR_3 STRINGIFY(NETLINK_DIAG_TX_RING)
  XLAT(NETLINK_DIAG_FLAGS),
+ #define XLAT_VAL_4 ((unsigned) (NETLINK_DIAG_FLAGS))
+ #define XLAT_STR_4 STRINGIFY(NETLINK_DIAG_FLAGS)
 };
 static
 const struct xlat netlink_diag_attrs[1] = { {
  .data = netlink_diag_attrs_xdata,
  .size = ARRAY_SIZE(netlink_diag_attrs_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/netlink_diag_show.h 5.9-0ubuntu2/xlat/netlink_diag_show.h
--- 5.5-3/xlat/netlink_diag_show.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/netlink_diag_show.h	2020-09-24 09:18:45.000000000 +0000
@@ -15,15 +15,23 @@
 static const struct xlat_data netlink_diag_show_xdata[] = {
 #if defined(NDIAG_SHOW_MEMINFO) || (defined(HAVE_DECL_NDIAG_SHOW_MEMINFO) && HAVE_DECL_NDIAG_SHOW_MEMINFO)
   XLAT(NDIAG_SHOW_MEMINFO),
+ #define XLAT_VAL_0 ((unsigned) (NDIAG_SHOW_MEMINFO))
+ #define XLAT_STR_0 STRINGIFY(NDIAG_SHOW_MEMINFO)
 #endif
 #if defined(NDIAG_SHOW_GROUPS) || (defined(HAVE_DECL_NDIAG_SHOW_GROUPS) && HAVE_DECL_NDIAG_SHOW_GROUPS)
   XLAT(NDIAG_SHOW_GROUPS),
+ #define XLAT_VAL_1 ((unsigned) (NDIAG_SHOW_GROUPS))
+ #define XLAT_STR_1 STRINGIFY(NDIAG_SHOW_GROUPS)
 #endif
 #if defined(NDIAG_SHOW_RING_CFG) || (defined(HAVE_DECL_NDIAG_SHOW_RING_CFG) && HAVE_DECL_NDIAG_SHOW_RING_CFG)
   XLAT(NDIAG_SHOW_RING_CFG),
+ #define XLAT_VAL_2 ((unsigned) (NDIAG_SHOW_RING_CFG))
+ #define XLAT_STR_2 STRINGIFY(NDIAG_SHOW_RING_CFG)
 #endif
 #if defined(NDIAG_SHOW_FLAGS) || (defined(HAVE_DECL_NDIAG_SHOW_FLAGS) && HAVE_DECL_NDIAG_SHOW_FLAGS)
   XLAT(NDIAG_SHOW_FLAGS),
+ #define XLAT_VAL_3 ((unsigned) (NDIAG_SHOW_FLAGS))
+ #define XLAT_STR_3 STRINGIFY(NDIAG_SHOW_FLAGS)
 #endif
 };
 static
@@ -31,8 +39,44 @@ const struct xlat netlink_diag_show[1] =
  .data = netlink_diag_show_xdata,
  .size = ARRAY_SIZE(netlink_diag_show_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/netlink_flags.h 5.9-0ubuntu2/xlat/netlink_flags.h
--- 5.5-3/xlat/netlink_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/netlink_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -56,19 +56,83 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data netlink_flags_xdata[] = {
  XLAT(NLM_F_REQUEST),
+ #define XLAT_VAL_0 ((unsigned) (NLM_F_REQUEST))
+ #define XLAT_STR_0 STRINGIFY(NLM_F_REQUEST)
  XLAT(NLM_F_MULTI),
+ #define XLAT_VAL_1 ((unsigned) (NLM_F_MULTI))
+ #define XLAT_STR_1 STRINGIFY(NLM_F_MULTI)
  XLAT(NLM_F_ACK),
+ #define XLAT_VAL_2 ((unsigned) (NLM_F_ACK))
+ #define XLAT_STR_2 STRINGIFY(NLM_F_ACK)
  XLAT(NLM_F_ECHO),
+ #define XLAT_VAL_3 ((unsigned) (NLM_F_ECHO))
+ #define XLAT_STR_3 STRINGIFY(NLM_F_ECHO)
  XLAT(NLM_F_DUMP_INTR),
+ #define XLAT_VAL_4 ((unsigned) (NLM_F_DUMP_INTR))
+ #define XLAT_STR_4 STRINGIFY(NLM_F_DUMP_INTR)
  XLAT(NLM_F_DUMP_FILTERED),
+ #define XLAT_VAL_5 ((unsigned) (NLM_F_DUMP_FILTERED))
+ #define XLAT_STR_5 STRINGIFY(NLM_F_DUMP_FILTERED)
 };
 static
 const struct xlat netlink_flags[1] = { {
  .data = netlink_flags_xdata,
  .size = ARRAY_SIZE(netlink_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/netlink_get_flags.h 5.9-0ubuntu2/xlat/netlink_get_flags.h
--- 5.5-3/xlat/netlink_get_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/netlink_get_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -15,15 +15,23 @@
 static const struct xlat_data netlink_get_flags_xdata[] = {
 #if defined(NLM_F_DUMP) || (defined(HAVE_DECL_NLM_F_DUMP) && HAVE_DECL_NLM_F_DUMP)
   XLAT(NLM_F_DUMP),
+ #define XLAT_VAL_0 ((unsigned) (NLM_F_DUMP))
+ #define XLAT_STR_0 STRINGIFY(NLM_F_DUMP)
 #endif
 #if defined(NLM_F_ROOT) || (defined(HAVE_DECL_NLM_F_ROOT) && HAVE_DECL_NLM_F_ROOT)
   XLAT(NLM_F_ROOT),
+ #define XLAT_VAL_1 ((unsigned) (NLM_F_ROOT))
+ #define XLAT_STR_1 STRINGIFY(NLM_F_ROOT)
 #endif
 #if defined(NLM_F_MATCH) || (defined(HAVE_DECL_NLM_F_MATCH) && HAVE_DECL_NLM_F_MATCH)
   XLAT(NLM_F_MATCH),
+ #define XLAT_VAL_2 ((unsigned) (NLM_F_MATCH))
+ #define XLAT_STR_2 STRINGIFY(NLM_F_MATCH)
 #endif
 #if defined(NLM_F_ATOMIC) || (defined(HAVE_DECL_NLM_F_ATOMIC) && HAVE_DECL_NLM_F_ATOMIC)
   XLAT(NLM_F_ATOMIC),
+ #define XLAT_VAL_3 ((unsigned) (NLM_F_ATOMIC))
+ #define XLAT_STR_3 STRINGIFY(NLM_F_ATOMIC)
 #endif
 };
 static
@@ -31,8 +39,44 @@ const struct xlat netlink_get_flags[1] =
  .data = netlink_get_flags_xdata,
  .size = ARRAY_SIZE(netlink_get_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/netlink_new_flags.h 5.9-0ubuntu2/xlat/netlink_new_flags.h
--- 5.5-3/xlat/netlink_new_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/netlink_new_flags.h	2020-09-24 09:18:44.000000000 +0000
@@ -15,15 +15,23 @@
 static const struct xlat_data netlink_new_flags_xdata[] = {
 #if defined(NLM_F_REPLACE) || (defined(HAVE_DECL_NLM_F_REPLACE) && HAVE_DECL_NLM_F_REPLACE)
   XLAT(NLM_F_REPLACE),
+ #define XLAT_VAL_0 ((unsigned) (NLM_F_REPLACE))
+ #define XLAT_STR_0 STRINGIFY(NLM_F_REPLACE)
 #endif
 #if defined(NLM_F_EXCL) || (defined(HAVE_DECL_NLM_F_EXCL) && HAVE_DECL_NLM_F_EXCL)
   XLAT(NLM_F_EXCL),
+ #define XLAT_VAL_1 ((unsigned) (NLM_F_EXCL))
+ #define XLAT_STR_1 STRINGIFY(NLM_F_EXCL)
 #endif
 #if defined(NLM_F_CREATE) || (defined(HAVE_DECL_NLM_F_CREATE) && HAVE_DECL_NLM_F_CREATE)
   XLAT(NLM_F_CREATE),
+ #define XLAT_VAL_2 ((unsigned) (NLM_F_CREATE))
+ #define XLAT_STR_2 STRINGIFY(NLM_F_CREATE)
 #endif
 #if defined(NLM_F_APPEND) || (defined(HAVE_DECL_NLM_F_APPEND) && HAVE_DECL_NLM_F_APPEND)
   XLAT(NLM_F_APPEND),
+ #define XLAT_VAL_3 ((unsigned) (NLM_F_APPEND))
+ #define XLAT_STR_3 STRINGIFY(NLM_F_APPEND)
 #endif
 };
 static
@@ -31,8 +39,44 @@ const struct xlat netlink_new_flags[1] =
  .data = netlink_new_flags_xdata,
  .size = ARRAY_SIZE(netlink_new_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/netlink_protocols.h 5.9-0ubuntu2/xlat/netlink_protocols.h
--- 5.5-3/xlat/netlink_protocols.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/netlink_protocols.h	2020-09-24 09:18:45.000000000 +0000
@@ -164,34 +164,258 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data netlink_protocols_xdata[] = {
  [NETLINK_ROUTE] = XLAT(NETLINK_ROUTE),
+ #define XLAT_VAL_0 ((unsigned) (NETLINK_ROUTE))
+ #define XLAT_STR_0 STRINGIFY(NETLINK_ROUTE)
  [NETLINK_UNUSED] = XLAT(NETLINK_UNUSED),
+ #define XLAT_VAL_1 ((unsigned) (NETLINK_UNUSED))
+ #define XLAT_STR_1 STRINGIFY(NETLINK_UNUSED)
  [NETLINK_USERSOCK] = XLAT(NETLINK_USERSOCK),
+ #define XLAT_VAL_2 ((unsigned) (NETLINK_USERSOCK))
+ #define XLAT_STR_2 STRINGIFY(NETLINK_USERSOCK)
  [NETLINK_FIREWALL] = XLAT(NETLINK_FIREWALL),
+ #define XLAT_VAL_3 ((unsigned) (NETLINK_FIREWALL))
+ #define XLAT_STR_3 STRINGIFY(NETLINK_FIREWALL)
  [NETLINK_SOCK_DIAG] = XLAT(NETLINK_SOCK_DIAG),
+ #define XLAT_VAL_4 ((unsigned) (NETLINK_SOCK_DIAG))
+ #define XLAT_STR_4 STRINGIFY(NETLINK_SOCK_DIAG)
  [NETLINK_NFLOG] = XLAT(NETLINK_NFLOG),
+ #define XLAT_VAL_5 ((unsigned) (NETLINK_NFLOG))
+ #define XLAT_STR_5 STRINGIFY(NETLINK_NFLOG)
  [NETLINK_XFRM] = XLAT(NETLINK_XFRM),
+ #define XLAT_VAL_6 ((unsigned) (NETLINK_XFRM))
+ #define XLAT_STR_6 STRINGIFY(NETLINK_XFRM)
  [NETLINK_SELINUX] = XLAT(NETLINK_SELINUX),
+ #define XLAT_VAL_7 ((unsigned) (NETLINK_SELINUX))
+ #define XLAT_STR_7 STRINGIFY(NETLINK_SELINUX)
  [NETLINK_ISCSI] = XLAT(NETLINK_ISCSI),
+ #define XLAT_VAL_8 ((unsigned) (NETLINK_ISCSI))
+ #define XLAT_STR_8 STRINGIFY(NETLINK_ISCSI)
  [NETLINK_AUDIT] = XLAT(NETLINK_AUDIT),
+ #define XLAT_VAL_9 ((unsigned) (NETLINK_AUDIT))
+ #define XLAT_STR_9 STRINGIFY(NETLINK_AUDIT)
  [NETLINK_FIB_LOOKUP] = XLAT(NETLINK_FIB_LOOKUP),
+ #define XLAT_VAL_10 ((unsigned) (NETLINK_FIB_LOOKUP))
+ #define XLAT_STR_10 STRINGIFY(NETLINK_FIB_LOOKUP)
  [NETLINK_CONNECTOR] = XLAT(NETLINK_CONNECTOR),
+ #define XLAT_VAL_11 ((unsigned) (NETLINK_CONNECTOR))
+ #define XLAT_STR_11 STRINGIFY(NETLINK_CONNECTOR)
  [NETLINK_NETFILTER] = XLAT(NETLINK_NETFILTER),
+ #define XLAT_VAL_12 ((unsigned) (NETLINK_NETFILTER))
+ #define XLAT_STR_12 STRINGIFY(NETLINK_NETFILTER)
  [NETLINK_IP6_FW] = XLAT(NETLINK_IP6_FW),
+ #define XLAT_VAL_13 ((unsigned) (NETLINK_IP6_FW))
+ #define XLAT_STR_13 STRINGIFY(NETLINK_IP6_FW)
  [NETLINK_DNRTMSG] = XLAT(NETLINK_DNRTMSG),
+ #define XLAT_VAL_14 ((unsigned) (NETLINK_DNRTMSG))
+ #define XLAT_STR_14 STRINGIFY(NETLINK_DNRTMSG)
  [NETLINK_KOBJECT_UEVENT] = XLAT(NETLINK_KOBJECT_UEVENT),
+ #define XLAT_VAL_15 ((unsigned) (NETLINK_KOBJECT_UEVENT))
+ #define XLAT_STR_15 STRINGIFY(NETLINK_KOBJECT_UEVENT)
  [NETLINK_GENERIC] = XLAT(NETLINK_GENERIC),
+ #define XLAT_VAL_16 ((unsigned) (NETLINK_GENERIC))
+ #define XLAT_STR_16 STRINGIFY(NETLINK_GENERIC)
  [NETLINK_SCSITRANSPORT] = XLAT(NETLINK_SCSITRANSPORT),
+ #define XLAT_VAL_17 ((unsigned) (NETLINK_SCSITRANSPORT))
+ #define XLAT_STR_17 STRINGIFY(NETLINK_SCSITRANSPORT)
  [NETLINK_ECRYPTFS] = XLAT(NETLINK_ECRYPTFS),
+ #define XLAT_VAL_18 ((unsigned) (NETLINK_ECRYPTFS))
+ #define XLAT_STR_18 STRINGIFY(NETLINK_ECRYPTFS)
  [NETLINK_RDMA] = XLAT(NETLINK_RDMA),
+ #define XLAT_VAL_19 ((unsigned) (NETLINK_RDMA))
+ #define XLAT_STR_19 STRINGIFY(NETLINK_RDMA)
  [NETLINK_CRYPTO] = XLAT(NETLINK_CRYPTO),
+ #define XLAT_VAL_20 ((unsigned) (NETLINK_CRYPTO))
+ #define XLAT_STR_20 STRINGIFY(NETLINK_CRYPTO)
  [NETLINK_SMC] = XLAT(NETLINK_SMC),
+ #define XLAT_VAL_21 ((unsigned) (NETLINK_SMC))
+ #define XLAT_STR_21 STRINGIFY(NETLINK_SMC)
 };
 const struct xlat netlink_protocols[1] = { {
  .data = netlink_protocols_xdata,
  .size = ARRAY_SIZE(netlink_protocols_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/netlink_sk_meminfo_indices.h 5.9-0ubuntu2/xlat/netlink_sk_meminfo_indices.h
--- 5.5-3/xlat/netlink_sk_meminfo_indices.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/netlink_sk_meminfo_indices.h	2020-09-24 09:18:45.000000000 +0000
@@ -77,22 +77,116 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data netlink_sk_meminfo_indices_xdata[] = {
  [SK_MEMINFO_RMEM_ALLOC] = XLAT(SK_MEMINFO_RMEM_ALLOC),
+ #define XLAT_VAL_0 ((unsigned) (SK_MEMINFO_RMEM_ALLOC))
+ #define XLAT_STR_0 STRINGIFY(SK_MEMINFO_RMEM_ALLOC)
  [SK_MEMINFO_RCVBUF] = XLAT(SK_MEMINFO_RCVBUF),
+ #define XLAT_VAL_1 ((unsigned) (SK_MEMINFO_RCVBUF))
+ #define XLAT_STR_1 STRINGIFY(SK_MEMINFO_RCVBUF)
  [SK_MEMINFO_WMEM_ALLOC] = XLAT(SK_MEMINFO_WMEM_ALLOC),
+ #define XLAT_VAL_2 ((unsigned) (SK_MEMINFO_WMEM_ALLOC))
+ #define XLAT_STR_2 STRINGIFY(SK_MEMINFO_WMEM_ALLOC)
  [SK_MEMINFO_SNDBUF] = XLAT(SK_MEMINFO_SNDBUF),
+ #define XLAT_VAL_3 ((unsigned) (SK_MEMINFO_SNDBUF))
+ #define XLAT_STR_3 STRINGIFY(SK_MEMINFO_SNDBUF)
  [SK_MEMINFO_FWD_ALLOC] = XLAT(SK_MEMINFO_FWD_ALLOC),
+ #define XLAT_VAL_4 ((unsigned) (SK_MEMINFO_FWD_ALLOC))
+ #define XLAT_STR_4 STRINGIFY(SK_MEMINFO_FWD_ALLOC)
  [SK_MEMINFO_WMEM_QUEUED] = XLAT(SK_MEMINFO_WMEM_QUEUED),
+ #define XLAT_VAL_5 ((unsigned) (SK_MEMINFO_WMEM_QUEUED))
+ #define XLAT_STR_5 STRINGIFY(SK_MEMINFO_WMEM_QUEUED)
  [SK_MEMINFO_OPTMEM] = XLAT(SK_MEMINFO_OPTMEM),
+ #define XLAT_VAL_6 ((unsigned) (SK_MEMINFO_OPTMEM))
+ #define XLAT_STR_6 STRINGIFY(SK_MEMINFO_OPTMEM)
  [SK_MEMINFO_BACKLOG] = XLAT(SK_MEMINFO_BACKLOG),
+ #define XLAT_VAL_7 ((unsigned) (SK_MEMINFO_BACKLOG))
+ #define XLAT_STR_7 STRINGIFY(SK_MEMINFO_BACKLOG)
  [SK_MEMINFO_DROPS] = XLAT(SK_MEMINFO_DROPS),
+ #define XLAT_VAL_8 ((unsigned) (SK_MEMINFO_DROPS))
+ #define XLAT_STR_8 STRINGIFY(SK_MEMINFO_DROPS)
 };
 static
 const struct xlat netlink_sk_meminfo_indices[1] = { {
  .data = netlink_sk_meminfo_indices_xdata,
  .size = ARRAY_SIZE(netlink_sk_meminfo_indices_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/netlink_socket_flags.h 5.9-0ubuntu2/xlat/netlink_socket_flags.h
--- 5.5-3/xlat/netlink_socket_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/netlink_socket_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -15,21 +15,33 @@
 static const struct xlat_data netlink_socket_flags_xdata[] = {
 #if defined(NDIAG_FLAG_CB_RUNNING) || (defined(HAVE_DECL_NDIAG_FLAG_CB_RUNNING) && HAVE_DECL_NDIAG_FLAG_CB_RUNNING)
   XLAT(NDIAG_FLAG_CB_RUNNING),
+ #define XLAT_VAL_0 ((unsigned) (NDIAG_FLAG_CB_RUNNING))
+ #define XLAT_STR_0 STRINGIFY(NDIAG_FLAG_CB_RUNNING)
 #endif
 #if defined(NDIAG_FLAG_PKTINFO) || (defined(HAVE_DECL_NDIAG_FLAG_PKTINFO) && HAVE_DECL_NDIAG_FLAG_PKTINFO)
   XLAT(NDIAG_FLAG_PKTINFO),
+ #define XLAT_VAL_1 ((unsigned) (NDIAG_FLAG_PKTINFO))
+ #define XLAT_STR_1 STRINGIFY(NDIAG_FLAG_PKTINFO)
 #endif
 #if defined(NDIAG_FLAG_BROADCAST_ERROR) || (defined(HAVE_DECL_NDIAG_FLAG_BROADCAST_ERROR) && HAVE_DECL_NDIAG_FLAG_BROADCAST_ERROR)
   XLAT(NDIAG_FLAG_BROADCAST_ERROR),
+ #define XLAT_VAL_2 ((unsigned) (NDIAG_FLAG_BROADCAST_ERROR))
+ #define XLAT_STR_2 STRINGIFY(NDIAG_FLAG_BROADCAST_ERROR)
 #endif
 #if defined(NDIAG_FLAG_NO_ENOBUFS) || (defined(HAVE_DECL_NDIAG_FLAG_NO_ENOBUFS) && HAVE_DECL_NDIAG_FLAG_NO_ENOBUFS)
   XLAT(NDIAG_FLAG_NO_ENOBUFS),
+ #define XLAT_VAL_3 ((unsigned) (NDIAG_FLAG_NO_ENOBUFS))
+ #define XLAT_STR_3 STRINGIFY(NDIAG_FLAG_NO_ENOBUFS)
 #endif
 #if defined(NDIAG_FLAG_LISTEN_ALL_NSID) || (defined(HAVE_DECL_NDIAG_FLAG_LISTEN_ALL_NSID) && HAVE_DECL_NDIAG_FLAG_LISTEN_ALL_NSID)
   XLAT(NDIAG_FLAG_LISTEN_ALL_NSID),
+ #define XLAT_VAL_4 ((unsigned) (NDIAG_FLAG_LISTEN_ALL_NSID))
+ #define XLAT_STR_4 STRINGIFY(NDIAG_FLAG_LISTEN_ALL_NSID)
 #endif
 #if defined(NDIAG_FLAG_CAP_ACK) || (defined(HAVE_DECL_NDIAG_FLAG_CAP_ACK) && HAVE_DECL_NDIAG_FLAG_CAP_ACK)
   XLAT(NDIAG_FLAG_CAP_ACK),
+ #define XLAT_VAL_5 ((unsigned) (NDIAG_FLAG_CAP_ACK))
+ #define XLAT_STR_5 STRINGIFY(NDIAG_FLAG_CAP_ACK)
 #endif
 };
 static
@@ -37,8 +49,60 @@ const struct xlat netlink_socket_flags[1
  .data = netlink_socket_flags_xdata,
  .size = ARRAY_SIZE(netlink_socket_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/netlink_states.h 5.9-0ubuntu2/xlat/netlink_states.h
--- 5.5-3/xlat/netlink_states.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/netlink_states.h	2020-09-24 09:18:44.000000000 +0000
@@ -35,17 +35,51 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data netlink_states_xdata[] = {
  XLAT(NETLINK_UNCONNECTED),
+ #define XLAT_VAL_0 ((unsigned) (NETLINK_UNCONNECTED))
+ #define XLAT_STR_0 STRINGIFY(NETLINK_UNCONNECTED)
  XLAT(NETLINK_CONNECTED),
+ #define XLAT_VAL_1 ((unsigned) (NETLINK_CONNECTED))
+ #define XLAT_STR_1 STRINGIFY(NETLINK_CONNECTED)
 
  XLAT(TCP_CLOSE),
+ #define XLAT_VAL_2 ((unsigned) (TCP_CLOSE))
+ #define XLAT_STR_2 STRINGIFY(TCP_CLOSE)
 };
 static
 const struct xlat netlink_states[1] = { {
  .data = netlink_states_xdata,
  .size = ARRAY_SIZE(netlink_states_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/netlink_types.h 5.9-0ubuntu2/xlat/netlink_types.h
--- 5.5-3/xlat/netlink_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/netlink_types.h	2020-09-24 09:18:45.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data netlink_types_xdata[] = {
  [NLMSG_NOOP] = XLAT(NLMSG_NOOP),
+ #define XLAT_VAL_0 ((unsigned) (NLMSG_NOOP))
+ #define XLAT_STR_0 STRINGIFY(NLMSG_NOOP)
  [NLMSG_ERROR] = XLAT(NLMSG_ERROR),
+ #define XLAT_VAL_1 ((unsigned) (NLMSG_ERROR))
+ #define XLAT_STR_1 STRINGIFY(NLMSG_ERROR)
  [NLMSG_DONE] = XLAT(NLMSG_DONE),
+ #define XLAT_VAL_2 ((unsigned) (NLMSG_DONE))
+ #define XLAT_STR_2 STRINGIFY(NLMSG_DONE)
  [NLMSG_OVERRUN] = XLAT(NLMSG_OVERRUN),
+ #define XLAT_VAL_3 ((unsigned) (NLMSG_OVERRUN))
+ #define XLAT_STR_3 STRINGIFY(NLMSG_OVERRUN)
 };
 static
 const struct xlat netlink_types[1] = { {
  .data = netlink_types_xdata,
  .size = ARRAY_SIZE(netlink_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/nf_acct_msg_types.h 5.9-0ubuntu2/xlat/nf_acct_msg_types.h
--- 5.5-3/xlat/nf_acct_msg_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/nf_acct_msg_types.h	2020-09-24 09:18:45.000000000 +0000
@@ -49,18 +49,72 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data nf_acct_msg_types_xdata[] = {
  [NFNL_MSG_ACCT_NEW] = XLAT(NFNL_MSG_ACCT_NEW),
+ #define XLAT_VAL_0 ((unsigned) (NFNL_MSG_ACCT_NEW))
+ #define XLAT_STR_0 STRINGIFY(NFNL_MSG_ACCT_NEW)
  [NFNL_MSG_ACCT_GET] = XLAT(NFNL_MSG_ACCT_GET),
+ #define XLAT_VAL_1 ((unsigned) (NFNL_MSG_ACCT_GET))
+ #define XLAT_STR_1 STRINGIFY(NFNL_MSG_ACCT_GET)
  [NFNL_MSG_ACCT_GET_CTRZERO] = XLAT(NFNL_MSG_ACCT_GET_CTRZERO),
+ #define XLAT_VAL_2 ((unsigned) (NFNL_MSG_ACCT_GET_CTRZERO))
+ #define XLAT_STR_2 STRINGIFY(NFNL_MSG_ACCT_GET_CTRZERO)
  [NFNL_MSG_ACCT_DEL] = XLAT(NFNL_MSG_ACCT_DEL),
+ #define XLAT_VAL_3 ((unsigned) (NFNL_MSG_ACCT_DEL))
+ #define XLAT_STR_3 STRINGIFY(NFNL_MSG_ACCT_DEL)
  [NFNL_MSG_ACCT_OVERQUOTA] = XLAT(NFNL_MSG_ACCT_OVERQUOTA),
+ #define XLAT_VAL_4 ((unsigned) (NFNL_MSG_ACCT_OVERQUOTA))
+ #define XLAT_STR_4 STRINGIFY(NFNL_MSG_ACCT_OVERQUOTA)
 };
 static
 const struct xlat nf_acct_msg_types[1] = { {
  .data = nf_acct_msg_types_xdata,
  .size = ARRAY_SIZE(nf_acct_msg_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/nfc_protocols.h 5.9-0ubuntu2/xlat/nfc_protocols.h
--- 5.5-3/xlat/nfc_protocols.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/nfc_protocols.h	2020-09-24 09:18:45.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data nfc_protocols_xdata[] = {
  [NFC_SOCKPROTO_RAW] = XLAT(NFC_SOCKPROTO_RAW),
+ #define XLAT_VAL_0 ((unsigned) (NFC_SOCKPROTO_RAW))
+ #define XLAT_STR_0 STRINGIFY(NFC_SOCKPROTO_RAW)
  [NFC_SOCKPROTO_LLCP] = XLAT(NFC_SOCKPROTO_LLCP),
+ #define XLAT_VAL_1 ((unsigned) (NFC_SOCKPROTO_LLCP))
+ #define XLAT_STR_1 STRINGIFY(NFC_SOCKPROTO_LLCP)
 };
 static
 const struct xlat nfc_protocols[1] = { {
  .data = nfc_protocols_xdata,
  .size = ARRAY_SIZE(nfc_protocols_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/nf_cthelper_msg_types.h 5.9-0ubuntu2/xlat/nf_cthelper_msg_types.h
--- 5.5-3/xlat/nf_cthelper_msg_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/nf_cthelper_msg_types.h	2020-09-24 09:18:44.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data nf_cthelper_msg_types_xdata[] = {
  [NFNL_MSG_CTHELPER_NEW] = XLAT(NFNL_MSG_CTHELPER_NEW),
+ #define XLAT_VAL_0 ((unsigned) (NFNL_MSG_CTHELPER_NEW))
+ #define XLAT_STR_0 STRINGIFY(NFNL_MSG_CTHELPER_NEW)
  [NFNL_MSG_CTHELPER_GET] = XLAT(NFNL_MSG_CTHELPER_GET),
+ #define XLAT_VAL_1 ((unsigned) (NFNL_MSG_CTHELPER_GET))
+ #define XLAT_STR_1 STRINGIFY(NFNL_MSG_CTHELPER_GET)
  [NFNL_MSG_CTHELPER_DEL] = XLAT(NFNL_MSG_CTHELPER_DEL),
+ #define XLAT_VAL_2 ((unsigned) (NFNL_MSG_CTHELPER_DEL))
+ #define XLAT_STR_2 STRINGIFY(NFNL_MSG_CTHELPER_DEL)
 };
 static
 const struct xlat nf_cthelper_msg_types[1] = { {
  .data = nf_cthelper_msg_types_xdata,
  .size = ARRAY_SIZE(nf_cthelper_msg_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/nf_ctnetlink_exp_msg_types.h 5.9-0ubuntu2/xlat/nf_ctnetlink_exp_msg_types.h
--- 5.5-3/xlat/nf_ctnetlink_exp_msg_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/nf_ctnetlink_exp_msg_types.h	2020-09-24 09:18:45.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data nf_ctnetlink_exp_msg_types_xdata[] = {
  [IPCTNL_MSG_EXP_NEW] = XLAT(IPCTNL_MSG_EXP_NEW),
+ #define XLAT_VAL_0 ((unsigned) (IPCTNL_MSG_EXP_NEW))
+ #define XLAT_STR_0 STRINGIFY(IPCTNL_MSG_EXP_NEW)
  [IPCTNL_MSG_EXP_GET] = XLAT(IPCTNL_MSG_EXP_GET),
+ #define XLAT_VAL_1 ((unsigned) (IPCTNL_MSG_EXP_GET))
+ #define XLAT_STR_1 STRINGIFY(IPCTNL_MSG_EXP_GET)
  [IPCTNL_MSG_EXP_DELETE] = XLAT(IPCTNL_MSG_EXP_DELETE),
+ #define XLAT_VAL_2 ((unsigned) (IPCTNL_MSG_EXP_DELETE))
+ #define XLAT_STR_2 STRINGIFY(IPCTNL_MSG_EXP_DELETE)
  [IPCTNL_MSG_EXP_GET_STATS_CPU] = XLAT(IPCTNL_MSG_EXP_GET_STATS_CPU),
+ #define XLAT_VAL_3 ((unsigned) (IPCTNL_MSG_EXP_GET_STATS_CPU))
+ #define XLAT_STR_3 STRINGIFY(IPCTNL_MSG_EXP_GET_STATS_CPU)
 };
 static
 const struct xlat nf_ctnetlink_exp_msg_types[1] = { {
  .data = nf_ctnetlink_exp_msg_types_xdata,
  .size = ARRAY_SIZE(nf_ctnetlink_exp_msg_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/nf_ctnetlink_msg_types.h 5.9-0ubuntu2/xlat/nf_ctnetlink_msg_types.h
--- 5.5-3/xlat/nf_ctnetlink_msg_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/nf_ctnetlink_msg_types.h	2020-09-24 09:18:45.000000000 +0000
@@ -70,21 +70,105 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data nf_ctnetlink_msg_types_xdata[] = {
  [IPCTNL_MSG_CT_NEW] = XLAT(IPCTNL_MSG_CT_NEW),
+ #define XLAT_VAL_0 ((unsigned) (IPCTNL_MSG_CT_NEW))
+ #define XLAT_STR_0 STRINGIFY(IPCTNL_MSG_CT_NEW)
  [IPCTNL_MSG_CT_GET] = XLAT(IPCTNL_MSG_CT_GET),
+ #define XLAT_VAL_1 ((unsigned) (IPCTNL_MSG_CT_GET))
+ #define XLAT_STR_1 STRINGIFY(IPCTNL_MSG_CT_GET)
  [IPCTNL_MSG_CT_DELETE] = XLAT(IPCTNL_MSG_CT_DELETE),
+ #define XLAT_VAL_2 ((unsigned) (IPCTNL_MSG_CT_DELETE))
+ #define XLAT_STR_2 STRINGIFY(IPCTNL_MSG_CT_DELETE)
  [IPCTNL_MSG_CT_GET_CTRZERO] = XLAT(IPCTNL_MSG_CT_GET_CTRZERO),
+ #define XLAT_VAL_3 ((unsigned) (IPCTNL_MSG_CT_GET_CTRZERO))
+ #define XLAT_STR_3 STRINGIFY(IPCTNL_MSG_CT_GET_CTRZERO)
  [IPCTNL_MSG_CT_GET_STATS_CPU] = XLAT(IPCTNL_MSG_CT_GET_STATS_CPU),
+ #define XLAT_VAL_4 ((unsigned) (IPCTNL_MSG_CT_GET_STATS_CPU))
+ #define XLAT_STR_4 STRINGIFY(IPCTNL_MSG_CT_GET_STATS_CPU)
  [IPCTNL_MSG_CT_GET_STATS] = XLAT(IPCTNL_MSG_CT_GET_STATS),
+ #define XLAT_VAL_5 ((unsigned) (IPCTNL_MSG_CT_GET_STATS))
+ #define XLAT_STR_5 STRINGIFY(IPCTNL_MSG_CT_GET_STATS)
  [IPCTNL_MSG_CT_GET_DYING] = XLAT(IPCTNL_MSG_CT_GET_DYING),
+ #define XLAT_VAL_6 ((unsigned) (IPCTNL_MSG_CT_GET_DYING))
+ #define XLAT_STR_6 STRINGIFY(IPCTNL_MSG_CT_GET_DYING)
  [IPCTNL_MSG_CT_GET_UNCONFIRMED] = XLAT(IPCTNL_MSG_CT_GET_UNCONFIRMED),
+ #define XLAT_VAL_7 ((unsigned) (IPCTNL_MSG_CT_GET_UNCONFIRMED))
+ #define XLAT_STR_7 STRINGIFY(IPCTNL_MSG_CT_GET_UNCONFIRMED)
 };
 static
 const struct xlat nf_ctnetlink_msg_types[1] = { {
  .data = nf_ctnetlink_msg_types_xdata,
  .size = ARRAY_SIZE(nf_ctnetlink_msg_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/nf_cttimeout_msg_types.h 5.9-0ubuntu2/xlat/nf_cttimeout_msg_types.h
--- 5.5-3/xlat/nf_cttimeout_msg_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/nf_cttimeout_msg_types.h	2020-09-24 09:18:45.000000000 +0000
@@ -49,18 +49,72 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data nf_cttimeout_msg_types_xdata[] = {
  [IPCTNL_MSG_TIMEOUT_NEW] = XLAT(IPCTNL_MSG_TIMEOUT_NEW),
+ #define XLAT_VAL_0 ((unsigned) (IPCTNL_MSG_TIMEOUT_NEW))
+ #define XLAT_STR_0 STRINGIFY(IPCTNL_MSG_TIMEOUT_NEW)
  [IPCTNL_MSG_TIMEOUT_GET] = XLAT(IPCTNL_MSG_TIMEOUT_GET),
+ #define XLAT_VAL_1 ((unsigned) (IPCTNL_MSG_TIMEOUT_GET))
+ #define XLAT_STR_1 STRINGIFY(IPCTNL_MSG_TIMEOUT_GET)
  [IPCTNL_MSG_TIMEOUT_DELETE] = XLAT(IPCTNL_MSG_TIMEOUT_DELETE),
+ #define XLAT_VAL_2 ((unsigned) (IPCTNL_MSG_TIMEOUT_DELETE))
+ #define XLAT_STR_2 STRINGIFY(IPCTNL_MSG_TIMEOUT_DELETE)
  [IPCTNL_MSG_TIMEOUT_DEFAULT_SET] = XLAT(IPCTNL_MSG_TIMEOUT_DEFAULT_SET),
+ #define XLAT_VAL_3 ((unsigned) (IPCTNL_MSG_TIMEOUT_DEFAULT_SET))
+ #define XLAT_STR_3 STRINGIFY(IPCTNL_MSG_TIMEOUT_DEFAULT_SET)
  [IPCTNL_MSG_TIMEOUT_DEFAULT_GET] = XLAT(IPCTNL_MSG_TIMEOUT_DEFAULT_GET),
+ #define XLAT_VAL_4 ((unsigned) (IPCTNL_MSG_TIMEOUT_DEFAULT_GET))
+ #define XLAT_STR_4 STRINGIFY(IPCTNL_MSG_TIMEOUT_DEFAULT_GET)
 };
 static
 const struct xlat nf_cttimeout_msg_types[1] = { {
  .data = nf_cttimeout_msg_types_xdata,
  .size = ARRAY_SIZE(nf_cttimeout_msg_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/nf_ipset_msg_types.h 5.9-0ubuntu2/xlat/nf_ipset_msg_types.h
--- 5.5-3/xlat/nf_ipset_msg_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/nf_ipset_msg_types.h	2020-09-24 09:18:45.000000000 +0000
@@ -147,34 +147,228 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data nf_ipset_msg_types_xdata[] = {
  [IPSET_CMD_NONE] = XLAT(IPSET_CMD_NONE),
+ #define XLAT_VAL_0 ((unsigned) (IPSET_CMD_NONE))
+ #define XLAT_STR_0 STRINGIFY(IPSET_CMD_NONE)
  [IPSET_CMD_PROTOCOL] = XLAT(IPSET_CMD_PROTOCOL),
+ #define XLAT_VAL_1 ((unsigned) (IPSET_CMD_PROTOCOL))
+ #define XLAT_STR_1 STRINGIFY(IPSET_CMD_PROTOCOL)
  [IPSET_CMD_CREATE] = XLAT(IPSET_CMD_CREATE),
+ #define XLAT_VAL_2 ((unsigned) (IPSET_CMD_CREATE))
+ #define XLAT_STR_2 STRINGIFY(IPSET_CMD_CREATE)
  [IPSET_CMD_DESTROY] = XLAT(IPSET_CMD_DESTROY),
+ #define XLAT_VAL_3 ((unsigned) (IPSET_CMD_DESTROY))
+ #define XLAT_STR_3 STRINGIFY(IPSET_CMD_DESTROY)
  [IPSET_CMD_FLUSH] = XLAT(IPSET_CMD_FLUSH),
+ #define XLAT_VAL_4 ((unsigned) (IPSET_CMD_FLUSH))
+ #define XLAT_STR_4 STRINGIFY(IPSET_CMD_FLUSH)
  [IPSET_CMD_RENAME] = XLAT(IPSET_CMD_RENAME),
+ #define XLAT_VAL_5 ((unsigned) (IPSET_CMD_RENAME))
+ #define XLAT_STR_5 STRINGIFY(IPSET_CMD_RENAME)
  [IPSET_CMD_SWAP] = XLAT(IPSET_CMD_SWAP),
+ #define XLAT_VAL_6 ((unsigned) (IPSET_CMD_SWAP))
+ #define XLAT_STR_6 STRINGIFY(IPSET_CMD_SWAP)
  [IPSET_CMD_LIST] = XLAT(IPSET_CMD_LIST),
+ #define XLAT_VAL_7 ((unsigned) (IPSET_CMD_LIST))
+ #define XLAT_STR_7 STRINGIFY(IPSET_CMD_LIST)
  [IPSET_CMD_SAVE] = XLAT(IPSET_CMD_SAVE),
+ #define XLAT_VAL_8 ((unsigned) (IPSET_CMD_SAVE))
+ #define XLAT_STR_8 STRINGIFY(IPSET_CMD_SAVE)
  [IPSET_CMD_ADD] = XLAT(IPSET_CMD_ADD),
+ #define XLAT_VAL_9 ((unsigned) (IPSET_CMD_ADD))
+ #define XLAT_STR_9 STRINGIFY(IPSET_CMD_ADD)
  [IPSET_CMD_DEL] = XLAT(IPSET_CMD_DEL),
+ #define XLAT_VAL_10 ((unsigned) (IPSET_CMD_DEL))
+ #define XLAT_STR_10 STRINGIFY(IPSET_CMD_DEL)
  [IPSET_CMD_TEST] = XLAT(IPSET_CMD_TEST),
+ #define XLAT_VAL_11 ((unsigned) (IPSET_CMD_TEST))
+ #define XLAT_STR_11 STRINGIFY(IPSET_CMD_TEST)
  [IPSET_CMD_HEADER] = XLAT(IPSET_CMD_HEADER),
+ #define XLAT_VAL_12 ((unsigned) (IPSET_CMD_HEADER))
+ #define XLAT_STR_12 STRINGIFY(IPSET_CMD_HEADER)
  [IPSET_CMD_TYPE] = XLAT(IPSET_CMD_TYPE),
+ #define XLAT_VAL_13 ((unsigned) (IPSET_CMD_TYPE))
+ #define XLAT_STR_13 STRINGIFY(IPSET_CMD_TYPE)
 
  [IPSET_CMD_RESTORE] = XLAT(IPSET_CMD_RESTORE),
+ #define XLAT_VAL_14 ((unsigned) (IPSET_CMD_RESTORE))
+ #define XLAT_STR_14 STRINGIFY(IPSET_CMD_RESTORE)
  [IPSET_CMD_HELP] = XLAT(IPSET_CMD_HELP),
+ #define XLAT_VAL_15 ((unsigned) (IPSET_CMD_HELP))
+ #define XLAT_STR_15 STRINGIFY(IPSET_CMD_HELP)
  [IPSET_CMD_VERSION] = XLAT(IPSET_CMD_VERSION),
+ #define XLAT_VAL_16 ((unsigned) (IPSET_CMD_VERSION))
+ #define XLAT_STR_16 STRINGIFY(IPSET_CMD_VERSION)
  [IPSET_CMD_QUIT] = XLAT(IPSET_CMD_QUIT),
+ #define XLAT_VAL_17 ((unsigned) (IPSET_CMD_QUIT))
+ #define XLAT_STR_17 STRINGIFY(IPSET_CMD_QUIT)
 
  [IPSET_CMD_COMMIT] = XLAT(IPSET_CMD_COMMIT),
+ #define XLAT_VAL_18 ((unsigned) (IPSET_CMD_COMMIT))
+ #define XLAT_STR_18 STRINGIFY(IPSET_CMD_COMMIT)
 };
 static
 const struct xlat nf_ipset_msg_types[1] = { {
  .data = nf_ipset_msg_types_xdata,
  .size = ARRAY_SIZE(nf_ipset_msg_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/nf_nftables_msg_types.h 5.9-0ubuntu2/xlat/nf_nftables_msg_types.h
--- 5.5-3/xlat/nf_nftables_msg_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/nf_nftables_msg_types.h	2020-09-24 09:18:45.000000000 +0000
@@ -168,35 +168,259 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data nf_nftables_msg_types_xdata[] = {
  [NFT_MSG_NEWTABLE] = XLAT(NFT_MSG_NEWTABLE),
+ #define XLAT_VAL_0 ((unsigned) (NFT_MSG_NEWTABLE))
+ #define XLAT_STR_0 STRINGIFY(NFT_MSG_NEWTABLE)
  [NFT_MSG_GETTABLE] = XLAT(NFT_MSG_GETTABLE),
+ #define XLAT_VAL_1 ((unsigned) (NFT_MSG_GETTABLE))
+ #define XLAT_STR_1 STRINGIFY(NFT_MSG_GETTABLE)
  [NFT_MSG_DELTABLE] = XLAT(NFT_MSG_DELTABLE),
+ #define XLAT_VAL_2 ((unsigned) (NFT_MSG_DELTABLE))
+ #define XLAT_STR_2 STRINGIFY(NFT_MSG_DELTABLE)
  [NFT_MSG_NEWCHAIN] = XLAT(NFT_MSG_NEWCHAIN),
+ #define XLAT_VAL_3 ((unsigned) (NFT_MSG_NEWCHAIN))
+ #define XLAT_STR_3 STRINGIFY(NFT_MSG_NEWCHAIN)
  [NFT_MSG_GETCHAIN] = XLAT(NFT_MSG_GETCHAIN),
+ #define XLAT_VAL_4 ((unsigned) (NFT_MSG_GETCHAIN))
+ #define XLAT_STR_4 STRINGIFY(NFT_MSG_GETCHAIN)
  [NFT_MSG_DELCHAIN] = XLAT(NFT_MSG_DELCHAIN),
+ #define XLAT_VAL_5 ((unsigned) (NFT_MSG_DELCHAIN))
+ #define XLAT_STR_5 STRINGIFY(NFT_MSG_DELCHAIN)
  [NFT_MSG_NEWRULE] = XLAT(NFT_MSG_NEWRULE),
+ #define XLAT_VAL_6 ((unsigned) (NFT_MSG_NEWRULE))
+ #define XLAT_STR_6 STRINGIFY(NFT_MSG_NEWRULE)
  [NFT_MSG_GETRULE] = XLAT(NFT_MSG_GETRULE),
+ #define XLAT_VAL_7 ((unsigned) (NFT_MSG_GETRULE))
+ #define XLAT_STR_7 STRINGIFY(NFT_MSG_GETRULE)
  [NFT_MSG_DELRULE] = XLAT(NFT_MSG_DELRULE),
+ #define XLAT_VAL_8 ((unsigned) (NFT_MSG_DELRULE))
+ #define XLAT_STR_8 STRINGIFY(NFT_MSG_DELRULE)
  [NFT_MSG_NEWSET] = XLAT(NFT_MSG_NEWSET),
+ #define XLAT_VAL_9 ((unsigned) (NFT_MSG_NEWSET))
+ #define XLAT_STR_9 STRINGIFY(NFT_MSG_NEWSET)
  [NFT_MSG_GETSET] = XLAT(NFT_MSG_GETSET),
+ #define XLAT_VAL_10 ((unsigned) (NFT_MSG_GETSET))
+ #define XLAT_STR_10 STRINGIFY(NFT_MSG_GETSET)
  [NFT_MSG_DELSET] = XLAT(NFT_MSG_DELSET),
+ #define XLAT_VAL_11 ((unsigned) (NFT_MSG_DELSET))
+ #define XLAT_STR_11 STRINGIFY(NFT_MSG_DELSET)
  [NFT_MSG_NEWSETELEM] = XLAT(NFT_MSG_NEWSETELEM),
+ #define XLAT_VAL_12 ((unsigned) (NFT_MSG_NEWSETELEM))
+ #define XLAT_STR_12 STRINGIFY(NFT_MSG_NEWSETELEM)
  [NFT_MSG_GETSETELEM] = XLAT(NFT_MSG_GETSETELEM),
+ #define XLAT_VAL_13 ((unsigned) (NFT_MSG_GETSETELEM))
+ #define XLAT_STR_13 STRINGIFY(NFT_MSG_GETSETELEM)
  [NFT_MSG_DELSETELEM] = XLAT(NFT_MSG_DELSETELEM),
+ #define XLAT_VAL_14 ((unsigned) (NFT_MSG_DELSETELEM))
+ #define XLAT_STR_14 STRINGIFY(NFT_MSG_DELSETELEM)
  [NFT_MSG_NEWGEN] = XLAT(NFT_MSG_NEWGEN),
+ #define XLAT_VAL_15 ((unsigned) (NFT_MSG_NEWGEN))
+ #define XLAT_STR_15 STRINGIFY(NFT_MSG_NEWGEN)
  [NFT_MSG_GETGEN] = XLAT(NFT_MSG_GETGEN),
+ #define XLAT_VAL_16 ((unsigned) (NFT_MSG_GETGEN))
+ #define XLAT_STR_16 STRINGIFY(NFT_MSG_GETGEN)
  [NFT_MSG_TRACE] = XLAT(NFT_MSG_TRACE),
+ #define XLAT_VAL_17 ((unsigned) (NFT_MSG_TRACE))
+ #define XLAT_STR_17 STRINGIFY(NFT_MSG_TRACE)
  [NFT_MSG_NEWOBJ] = XLAT(NFT_MSG_NEWOBJ),
+ #define XLAT_VAL_18 ((unsigned) (NFT_MSG_NEWOBJ))
+ #define XLAT_STR_18 STRINGIFY(NFT_MSG_NEWOBJ)
  [NFT_MSG_GETOBJ] = XLAT(NFT_MSG_GETOBJ),
+ #define XLAT_VAL_19 ((unsigned) (NFT_MSG_GETOBJ))
+ #define XLAT_STR_19 STRINGIFY(NFT_MSG_GETOBJ)
  [NFT_MSG_DELOBJ] = XLAT(NFT_MSG_DELOBJ),
+ #define XLAT_VAL_20 ((unsigned) (NFT_MSG_DELOBJ))
+ #define XLAT_STR_20 STRINGIFY(NFT_MSG_DELOBJ)
  [NFT_MSG_GETOBJ_RESET] = XLAT(NFT_MSG_GETOBJ_RESET),
+ #define XLAT_VAL_21 ((unsigned) (NFT_MSG_GETOBJ_RESET))
+ #define XLAT_STR_21 STRINGIFY(NFT_MSG_GETOBJ_RESET)
 };
 static
 const struct xlat nf_nftables_msg_types[1] = { {
  .data = nf_nftables_msg_types_xdata,
  .size = ARRAY_SIZE(nf_nftables_msg_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/nf_nft_compat_msg_types.h 5.9-0ubuntu2/xlat/nf_nft_compat_msg_types.h
--- 5.5-3/xlat/nf_nft_compat_msg_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/nf_nft_compat_msg_types.h	2020-09-24 09:18:45.000000000 +0000
@@ -21,14 +21,28 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data nf_nft_compat_msg_types_xdata[] = {
  XLAT(NFNL_MSG_COMPAT_GET),
+ #define XLAT_VAL_0 ((unsigned) (NFNL_MSG_COMPAT_GET))
+ #define XLAT_STR_0 STRINGIFY(NFNL_MSG_COMPAT_GET)
 };
 static
 const struct xlat nf_nft_compat_msg_types[1] = { {
  .data = nf_nft_compat_msg_types_xdata,
  .size = ARRAY_SIZE(nf_nft_compat_msg_types_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/nf_osf_msg_types.h 5.9-0ubuntu2/xlat/nf_osf_msg_types.h
--- 5.5-3/xlat/nf_osf_msg_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/nf_osf_msg_types.h	2020-09-24 09:18:45.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data nf_osf_msg_types_xdata[] = {
  [OSF_MSG_ADD] = XLAT(OSF_MSG_ADD),
+ #define XLAT_VAL_0 ((unsigned) (OSF_MSG_ADD))
+ #define XLAT_STR_0 STRINGIFY(OSF_MSG_ADD)
  [OSF_MSG_REMOVE] = XLAT(OSF_MSG_REMOVE),
+ #define XLAT_VAL_1 ((unsigned) (OSF_MSG_REMOVE))
+ #define XLAT_STR_1 STRINGIFY(OSF_MSG_REMOVE)
 };
 static
 const struct xlat nf_osf_msg_types[1] = { {
  .data = nf_osf_msg_types_xdata,
  .size = ARRAY_SIZE(nf_osf_msg_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/nf_queue_msg_types.h 5.9-0ubuntu2/xlat/nf_queue_msg_types.h
--- 5.5-3/xlat/nf_queue_msg_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/nf_queue_msg_types.h	2020-09-24 09:18:45.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data nf_queue_msg_types_xdata[] = {
  [NFQNL_MSG_PACKET] = XLAT(NFQNL_MSG_PACKET),
+ #define XLAT_VAL_0 ((unsigned) (NFQNL_MSG_PACKET))
+ #define XLAT_STR_0 STRINGIFY(NFQNL_MSG_PACKET)
  [NFQNL_MSG_VERDICT] = XLAT(NFQNL_MSG_VERDICT),
+ #define XLAT_VAL_1 ((unsigned) (NFQNL_MSG_VERDICT))
+ #define XLAT_STR_1 STRINGIFY(NFQNL_MSG_VERDICT)
  [NFQNL_MSG_CONFIG] = XLAT(NFQNL_MSG_CONFIG),
+ #define XLAT_VAL_2 ((unsigned) (NFQNL_MSG_CONFIG))
+ #define XLAT_STR_2 STRINGIFY(NFQNL_MSG_CONFIG)
  [NFQNL_MSG_VERDICT_BATCH] = XLAT(NFQNL_MSG_VERDICT_BATCH),
+ #define XLAT_VAL_3 ((unsigned) (NFQNL_MSG_VERDICT_BATCH))
+ #define XLAT_STR_3 STRINGIFY(NFQNL_MSG_VERDICT_BATCH)
 };
 static
 const struct xlat nf_queue_msg_types[1] = { {
  .data = nf_queue_msg_types_xdata,
  .size = ARRAY_SIZE(nf_queue_msg_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/nf_ulog_msg_types.h 5.9-0ubuntu2/xlat/nf_ulog_msg_types.h
--- 5.5-3/xlat/nf_ulog_msg_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/nf_ulog_msg_types.h	2020-09-24 09:18:45.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data nf_ulog_msg_types_xdata[] = {
  [NFULNL_MSG_PACKET] = XLAT(NFULNL_MSG_PACKET),
+ #define XLAT_VAL_0 ((unsigned) (NFULNL_MSG_PACKET))
+ #define XLAT_STR_0 STRINGIFY(NFULNL_MSG_PACKET)
  [NFULNL_MSG_CONFIG] = XLAT(NFULNL_MSG_CONFIG),
+ #define XLAT_VAL_1 ((unsigned) (NFULNL_MSG_CONFIG))
+ #define XLAT_STR_1 STRINGIFY(NFULNL_MSG_CONFIG)
 };
 static
 const struct xlat nf_ulog_msg_types[1] = { {
  .data = nf_ulog_msg_types_xdata,
  .size = ARRAY_SIZE(nf_ulog_msg_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/nl_audit_types.h 5.9-0ubuntu2/xlat/nl_audit_types.h
--- 5.5-3/xlat/nl_audit_types.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/nl_audit_types.h	2020-09-24 09:18:46.000000000 +0000
@@ -427,6 +427,20 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define AUDIT_TIME_ADJNTPVAL 1333
 #endif
+#if defined(AUDIT_BPF) || (defined(HAVE_DECL_AUDIT_BPF) && HAVE_DECL_AUDIT_BPF)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((AUDIT_BPF) == (1334), "AUDIT_BPF != 1334");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define AUDIT_BPF 1334
+#endif
+#if defined(AUDIT_EVENT_LISTENER) || (defined(HAVE_DECL_AUDIT_EVENT_LISTENER) && HAVE_DECL_AUDIT_EVENT_LISTENER)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((AUDIT_EVENT_LISTENER) == (1335), "AUDIT_EVENT_LISTENER != 1335");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define AUDIT_EVENT_LISTENER 1335
+#endif
 #if defined(AUDIT_AVC) || (defined(HAVE_DECL_AUDIT_AVC) && HAVE_DECL_AUDIT_AVC)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
 static_assert((AUDIT_AVC) == (1400), "AUDIT_AVC != 1400");
@@ -690,62 +704,170 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data nl_audit_types_xdata[] = {
  XLAT(AUDIT_GET),
+ #define XLAT_VAL_0 ((unsigned) (AUDIT_GET))
+ #define XLAT_STR_0 STRINGIFY(AUDIT_GET)
  XLAT(AUDIT_SET),
+ #define XLAT_VAL_1 ((unsigned) (AUDIT_SET))
+ #define XLAT_STR_1 STRINGIFY(AUDIT_SET)
  XLAT(AUDIT_LIST),
+ #define XLAT_VAL_2 ((unsigned) (AUDIT_LIST))
+ #define XLAT_STR_2 STRINGIFY(AUDIT_LIST)
  XLAT(AUDIT_ADD),
+ #define XLAT_VAL_3 ((unsigned) (AUDIT_ADD))
+ #define XLAT_STR_3 STRINGIFY(AUDIT_ADD)
  XLAT(AUDIT_DEL),
+ #define XLAT_VAL_4 ((unsigned) (AUDIT_DEL))
+ #define XLAT_STR_4 STRINGIFY(AUDIT_DEL)
  XLAT(AUDIT_USER),
+ #define XLAT_VAL_5 ((unsigned) (AUDIT_USER))
+ #define XLAT_STR_5 STRINGIFY(AUDIT_USER)
  XLAT(AUDIT_LOGIN),
+ #define XLAT_VAL_6 ((unsigned) (AUDIT_LOGIN))
+ #define XLAT_STR_6 STRINGIFY(AUDIT_LOGIN)
  XLAT(AUDIT_WATCH_INS),
+ #define XLAT_VAL_7 ((unsigned) (AUDIT_WATCH_INS))
+ #define XLAT_STR_7 STRINGIFY(AUDIT_WATCH_INS)
  XLAT(AUDIT_WATCH_REM),
+ #define XLAT_VAL_8 ((unsigned) (AUDIT_WATCH_REM))
+ #define XLAT_STR_8 STRINGIFY(AUDIT_WATCH_REM)
  XLAT(AUDIT_WATCH_LIST),
+ #define XLAT_VAL_9 ((unsigned) (AUDIT_WATCH_LIST))
+ #define XLAT_STR_9 STRINGIFY(AUDIT_WATCH_LIST)
  XLAT(AUDIT_SIGNAL_INFO),
+ #define XLAT_VAL_10 ((unsigned) (AUDIT_SIGNAL_INFO))
+ #define XLAT_STR_10 STRINGIFY(AUDIT_SIGNAL_INFO)
  XLAT(AUDIT_ADD_RULE),
+ #define XLAT_VAL_11 ((unsigned) (AUDIT_ADD_RULE))
+ #define XLAT_STR_11 STRINGIFY(AUDIT_ADD_RULE)
  XLAT(AUDIT_DEL_RULE),
+ #define XLAT_VAL_12 ((unsigned) (AUDIT_DEL_RULE))
+ #define XLAT_STR_12 STRINGIFY(AUDIT_DEL_RULE)
  XLAT(AUDIT_LIST_RULES),
+ #define XLAT_VAL_13 ((unsigned) (AUDIT_LIST_RULES))
+ #define XLAT_STR_13 STRINGIFY(AUDIT_LIST_RULES)
  XLAT(AUDIT_TRIM),
+ #define XLAT_VAL_14 ((unsigned) (AUDIT_TRIM))
+ #define XLAT_STR_14 STRINGIFY(AUDIT_TRIM)
  XLAT(AUDIT_MAKE_EQUIV),
+ #define XLAT_VAL_15 ((unsigned) (AUDIT_MAKE_EQUIV))
+ #define XLAT_STR_15 STRINGIFY(AUDIT_MAKE_EQUIV)
  XLAT(AUDIT_TTY_GET),
+ #define XLAT_VAL_16 ((unsigned) (AUDIT_TTY_GET))
+ #define XLAT_STR_16 STRINGIFY(AUDIT_TTY_GET)
  XLAT(AUDIT_TTY_SET),
+ #define XLAT_VAL_17 ((unsigned) (AUDIT_TTY_SET))
+ #define XLAT_STR_17 STRINGIFY(AUDIT_TTY_SET)
  XLAT(AUDIT_SET_FEATURE),
+ #define XLAT_VAL_18 ((unsigned) (AUDIT_SET_FEATURE))
+ #define XLAT_STR_18 STRINGIFY(AUDIT_SET_FEATURE)
  XLAT(AUDIT_GET_FEATURE),
+ #define XLAT_VAL_19 ((unsigned) (AUDIT_GET_FEATURE))
+ #define XLAT_STR_19 STRINGIFY(AUDIT_GET_FEATURE)
 
  XLAT(AUDIT_FIRST_USER_MSG),
+ #define XLAT_VAL_20 ((unsigned) (AUDIT_FIRST_USER_MSG))
+ #define XLAT_STR_20 STRINGIFY(AUDIT_FIRST_USER_MSG)
  XLAT(AUDIT_USER_AVC),
+ #define XLAT_VAL_21 ((unsigned) (AUDIT_USER_AVC))
+ #define XLAT_STR_21 STRINGIFY(AUDIT_USER_AVC)
  XLAT(AUDIT_USER_TTY),
+ #define XLAT_VAL_22 ((unsigned) (AUDIT_USER_TTY))
+ #define XLAT_STR_22 STRINGIFY(AUDIT_USER_TTY)
  XLAT(AUDIT_LAST_USER_MSG),
+ #define XLAT_VAL_23 ((unsigned) (AUDIT_LAST_USER_MSG))
+ #define XLAT_STR_23 STRINGIFY(AUDIT_LAST_USER_MSG)
 
  XLAT(AUDIT_DAEMON_START),
+ #define XLAT_VAL_24 ((unsigned) (AUDIT_DAEMON_START))
+ #define XLAT_STR_24 STRINGIFY(AUDIT_DAEMON_START)
  XLAT(AUDIT_DAEMON_END),
+ #define XLAT_VAL_25 ((unsigned) (AUDIT_DAEMON_END))
+ #define XLAT_STR_25 STRINGIFY(AUDIT_DAEMON_END)
  XLAT(AUDIT_DAEMON_ABORT),
+ #define XLAT_VAL_26 ((unsigned) (AUDIT_DAEMON_ABORT))
+ #define XLAT_STR_26 STRINGIFY(AUDIT_DAEMON_ABORT)
  XLAT(AUDIT_DAEMON_CONFIG),
+ #define XLAT_VAL_27 ((unsigned) (AUDIT_DAEMON_CONFIG))
+ #define XLAT_STR_27 STRINGIFY(AUDIT_DAEMON_CONFIG)
 
  XLAT(AUDIT_SYSCALL),
+ #define XLAT_VAL_28 ((unsigned) (AUDIT_SYSCALL))
+ #define XLAT_STR_28 STRINGIFY(AUDIT_SYSCALL)
  XLAT(AUDIT_FS_WATCH),
+ #define XLAT_VAL_29 ((unsigned) (AUDIT_FS_WATCH))
+ #define XLAT_STR_29 STRINGIFY(AUDIT_FS_WATCH)
  XLAT(AUDIT_PATH),
+ #define XLAT_VAL_30 ((unsigned) (AUDIT_PATH))
+ #define XLAT_STR_30 STRINGIFY(AUDIT_PATH)
  XLAT(AUDIT_IPC),
+ #define XLAT_VAL_31 ((unsigned) (AUDIT_IPC))
+ #define XLAT_STR_31 STRINGIFY(AUDIT_IPC)
  XLAT(AUDIT_SOCKETCALL),
+ #define XLAT_VAL_32 ((unsigned) (AUDIT_SOCKETCALL))
+ #define XLAT_STR_32 STRINGIFY(AUDIT_SOCKETCALL)
  XLAT(AUDIT_CONFIG_CHANGE),
+ #define XLAT_VAL_33 ((unsigned) (AUDIT_CONFIG_CHANGE))
+ #define XLAT_STR_33 STRINGIFY(AUDIT_CONFIG_CHANGE)
  XLAT(AUDIT_SOCKADDR),
+ #define XLAT_VAL_34 ((unsigned) (AUDIT_SOCKADDR))
+ #define XLAT_STR_34 STRINGIFY(AUDIT_SOCKADDR)
  XLAT(AUDIT_CWD),
+ #define XLAT_VAL_35 ((unsigned) (AUDIT_CWD))
+ #define XLAT_STR_35 STRINGIFY(AUDIT_CWD)
  XLAT(AUDIT_EXECVE),
+ #define XLAT_VAL_36 ((unsigned) (AUDIT_EXECVE))
+ #define XLAT_STR_36 STRINGIFY(AUDIT_EXECVE)
  XLAT(AUDIT_IPC_SET_PERM),
+ #define XLAT_VAL_37 ((unsigned) (AUDIT_IPC_SET_PERM))
+ #define XLAT_STR_37 STRINGIFY(AUDIT_IPC_SET_PERM)
  XLAT(AUDIT_MQ_OPEN),
+ #define XLAT_VAL_38 ((unsigned) (AUDIT_MQ_OPEN))
+ #define XLAT_STR_38 STRINGIFY(AUDIT_MQ_OPEN)
  XLAT(AUDIT_MQ_SENDRECV),
+ #define XLAT_VAL_39 ((unsigned) (AUDIT_MQ_SENDRECV))
+ #define XLAT_STR_39 STRINGIFY(AUDIT_MQ_SENDRECV)
  XLAT(AUDIT_MQ_NOTIFY),
+ #define XLAT_VAL_40 ((unsigned) (AUDIT_MQ_NOTIFY))
+ #define XLAT_STR_40 STRINGIFY(AUDIT_MQ_NOTIFY)
  XLAT(AUDIT_MQ_GETSETATTR),
+ #define XLAT_VAL_41 ((unsigned) (AUDIT_MQ_GETSETATTR))
+ #define XLAT_STR_41 STRINGIFY(AUDIT_MQ_GETSETATTR)
  XLAT(AUDIT_KERNEL_OTHER),
+ #define XLAT_VAL_42 ((unsigned) (AUDIT_KERNEL_OTHER))
+ #define XLAT_STR_42 STRINGIFY(AUDIT_KERNEL_OTHER)
  XLAT(AUDIT_FD_PAIR),
+ #define XLAT_VAL_43 ((unsigned) (AUDIT_FD_PAIR))
+ #define XLAT_STR_43 STRINGIFY(AUDIT_FD_PAIR)
  XLAT(AUDIT_OBJ_PID),
+ #define XLAT_VAL_44 ((unsigned) (AUDIT_OBJ_PID))
+ #define XLAT_STR_44 STRINGIFY(AUDIT_OBJ_PID)
  XLAT(AUDIT_TTY),
+ #define XLAT_VAL_45 ((unsigned) (AUDIT_TTY))
+ #define XLAT_STR_45 STRINGIFY(AUDIT_TTY)
  XLAT(AUDIT_EOE),
+ #define XLAT_VAL_46 ((unsigned) (AUDIT_EOE))
+ #define XLAT_STR_46 STRINGIFY(AUDIT_EOE)
  XLAT(AUDIT_BPRM_FCAPS),
+ #define XLAT_VAL_47 ((unsigned) (AUDIT_BPRM_FCAPS))
+ #define XLAT_STR_47 STRINGIFY(AUDIT_BPRM_FCAPS)
  XLAT(AUDIT_CAPSET),
+ #define XLAT_VAL_48 ((unsigned) (AUDIT_CAPSET))
+ #define XLAT_STR_48 STRINGIFY(AUDIT_CAPSET)
  XLAT(AUDIT_MMAP),
+ #define XLAT_VAL_49 ((unsigned) (AUDIT_MMAP))
+ #define XLAT_STR_49 STRINGIFY(AUDIT_MMAP)
  XLAT(AUDIT_NETFILTER_PKT),
+ #define XLAT_VAL_50 ((unsigned) (AUDIT_NETFILTER_PKT))
+ #define XLAT_STR_50 STRINGIFY(AUDIT_NETFILTER_PKT)
  XLAT(AUDIT_NETFILTER_CFG),
+ #define XLAT_VAL_51 ((unsigned) (AUDIT_NETFILTER_CFG))
+ #define XLAT_STR_51 STRINGIFY(AUDIT_NETFILTER_CFG)
  XLAT(AUDIT_SECCOMP),
+ #define XLAT_VAL_52 ((unsigned) (AUDIT_SECCOMP))
+ #define XLAT_STR_52 STRINGIFY(AUDIT_SECCOMP)
  XLAT(AUDIT_PROCTITLE),
+ #define XLAT_VAL_53 ((unsigned) (AUDIT_PROCTITLE))
+ #define XLAT_STR_53 STRINGIFY(AUDIT_PROCTITLE)
 
 #ifndef STRACE_WORKAROUND_FOR_AUDIT_FEATURE_CHANGE
 # define STRACE_WORKAROUND_FOR_AUDIT_FEATURE_CHANGE
@@ -763,61 +885,939 @@ static const struct xlat_data nl_audit_t
 # undef AUDIT_FEATURE_CHANGE
 #endif
  XLAT(AUDIT_FEATURE_CHANGE),
+ #define XLAT_VAL_54 ((unsigned) (AUDIT_FEATURE_CHANGE))
+ #define XLAT_STR_54 STRINGIFY(AUDIT_FEATURE_CHANGE)
 
  XLAT(AUDIT_REPLACE),
+ #define XLAT_VAL_55 ((unsigned) (AUDIT_REPLACE))
+ #define XLAT_STR_55 STRINGIFY(AUDIT_REPLACE)
  XLAT(AUDIT_KERN_MODULE),
+ #define XLAT_VAL_56 ((unsigned) (AUDIT_KERN_MODULE))
+ #define XLAT_STR_56 STRINGIFY(AUDIT_KERN_MODULE)
  XLAT(AUDIT_FANOTIFY),
+ #define XLAT_VAL_57 ((unsigned) (AUDIT_FANOTIFY))
+ #define XLAT_STR_57 STRINGIFY(AUDIT_FANOTIFY)
  XLAT(AUDIT_TIME_INJOFFSET),
+ #define XLAT_VAL_58 ((unsigned) (AUDIT_TIME_INJOFFSET))
+ #define XLAT_STR_58 STRINGIFY(AUDIT_TIME_INJOFFSET)
  XLAT(AUDIT_TIME_ADJNTPVAL),
+ #define XLAT_VAL_59 ((unsigned) (AUDIT_TIME_ADJNTPVAL))
+ #define XLAT_STR_59 STRINGIFY(AUDIT_TIME_ADJNTPVAL)
+ XLAT(AUDIT_BPF),
+ #define XLAT_VAL_60 ((unsigned) (AUDIT_BPF))
+ #define XLAT_STR_60 STRINGIFY(AUDIT_BPF)
+ XLAT(AUDIT_EVENT_LISTENER),
+ #define XLAT_VAL_61 ((unsigned) (AUDIT_EVENT_LISTENER))
+ #define XLAT_STR_61 STRINGIFY(AUDIT_EVENT_LISTENER)
 
  XLAT(AUDIT_AVC),
+ #define XLAT_VAL_62 ((unsigned) (AUDIT_AVC))
+ #define XLAT_STR_62 STRINGIFY(AUDIT_AVC)
  XLAT(AUDIT_SELINUX_ERR),
+ #define XLAT_VAL_63 ((unsigned) (AUDIT_SELINUX_ERR))
+ #define XLAT_STR_63 STRINGIFY(AUDIT_SELINUX_ERR)
  XLAT(AUDIT_AVC_PATH),
+ #define XLAT_VAL_64 ((unsigned) (AUDIT_AVC_PATH))
+ #define XLAT_STR_64 STRINGIFY(AUDIT_AVC_PATH)
  XLAT(AUDIT_MAC_POLICY_LOAD),
+ #define XLAT_VAL_65 ((unsigned) (AUDIT_MAC_POLICY_LOAD))
+ #define XLAT_STR_65 STRINGIFY(AUDIT_MAC_POLICY_LOAD)
  XLAT(AUDIT_MAC_STATUS),
+ #define XLAT_VAL_66 ((unsigned) (AUDIT_MAC_STATUS))
+ #define XLAT_STR_66 STRINGIFY(AUDIT_MAC_STATUS)
  XLAT(AUDIT_MAC_CONFIG_CHANGE),
+ #define XLAT_VAL_67 ((unsigned) (AUDIT_MAC_CONFIG_CHANGE))
+ #define XLAT_STR_67 STRINGIFY(AUDIT_MAC_CONFIG_CHANGE)
  XLAT(AUDIT_MAC_UNLBL_ALLOW),
+ #define XLAT_VAL_68 ((unsigned) (AUDIT_MAC_UNLBL_ALLOW))
+ #define XLAT_STR_68 STRINGIFY(AUDIT_MAC_UNLBL_ALLOW)
  XLAT(AUDIT_MAC_CIPSOV4_ADD),
+ #define XLAT_VAL_69 ((unsigned) (AUDIT_MAC_CIPSOV4_ADD))
+ #define XLAT_STR_69 STRINGIFY(AUDIT_MAC_CIPSOV4_ADD)
  XLAT(AUDIT_MAC_CIPSOV4_DEL),
+ #define XLAT_VAL_70 ((unsigned) (AUDIT_MAC_CIPSOV4_DEL))
+ #define XLAT_STR_70 STRINGIFY(AUDIT_MAC_CIPSOV4_DEL)
  XLAT(AUDIT_MAC_MAP_ADD),
+ #define XLAT_VAL_71 ((unsigned) (AUDIT_MAC_MAP_ADD))
+ #define XLAT_STR_71 STRINGIFY(AUDIT_MAC_MAP_ADD)
  XLAT(AUDIT_MAC_MAP_DEL),
+ #define XLAT_VAL_72 ((unsigned) (AUDIT_MAC_MAP_DEL))
+ #define XLAT_STR_72 STRINGIFY(AUDIT_MAC_MAP_DEL)
  XLAT(AUDIT_MAC_IPSEC_ADDSA),
+ #define XLAT_VAL_73 ((unsigned) (AUDIT_MAC_IPSEC_ADDSA))
+ #define XLAT_STR_73 STRINGIFY(AUDIT_MAC_IPSEC_ADDSA)
  XLAT(AUDIT_MAC_IPSEC_DELSA),
+ #define XLAT_VAL_74 ((unsigned) (AUDIT_MAC_IPSEC_DELSA))
+ #define XLAT_STR_74 STRINGIFY(AUDIT_MAC_IPSEC_DELSA)
  XLAT(AUDIT_MAC_IPSEC_ADDSPD),
+ #define XLAT_VAL_75 ((unsigned) (AUDIT_MAC_IPSEC_ADDSPD))
+ #define XLAT_STR_75 STRINGIFY(AUDIT_MAC_IPSEC_ADDSPD)
  XLAT(AUDIT_MAC_IPSEC_DELSPD),
+ #define XLAT_VAL_76 ((unsigned) (AUDIT_MAC_IPSEC_DELSPD))
+ #define XLAT_STR_76 STRINGIFY(AUDIT_MAC_IPSEC_DELSPD)
  XLAT(AUDIT_MAC_IPSEC_EVENT),
+ #define XLAT_VAL_77 ((unsigned) (AUDIT_MAC_IPSEC_EVENT))
+ #define XLAT_STR_77 STRINGIFY(AUDIT_MAC_IPSEC_EVENT)
  XLAT(AUDIT_MAC_UNLBL_STCADD),
+ #define XLAT_VAL_78 ((unsigned) (AUDIT_MAC_UNLBL_STCADD))
+ #define XLAT_STR_78 STRINGIFY(AUDIT_MAC_UNLBL_STCADD)
  XLAT(AUDIT_MAC_UNLBL_STCDEL),
+ #define XLAT_VAL_79 ((unsigned) (AUDIT_MAC_UNLBL_STCDEL))
+ #define XLAT_STR_79 STRINGIFY(AUDIT_MAC_UNLBL_STCDEL)
  XLAT(AUDIT_MAC_CALIPSO_ADD),
+ #define XLAT_VAL_80 ((unsigned) (AUDIT_MAC_CALIPSO_ADD))
+ #define XLAT_STR_80 STRINGIFY(AUDIT_MAC_CALIPSO_ADD)
  XLAT(AUDIT_MAC_CALIPSO_DEL),
+ #define XLAT_VAL_81 ((unsigned) (AUDIT_MAC_CALIPSO_DEL))
+ #define XLAT_STR_81 STRINGIFY(AUDIT_MAC_CALIPSO_DEL)
 
  XLAT(AUDIT_ANOM_PROMISCUOUS),
+ #define XLAT_VAL_82 ((unsigned) (AUDIT_ANOM_PROMISCUOUS))
+ #define XLAT_STR_82 STRINGIFY(AUDIT_ANOM_PROMISCUOUS)
  XLAT(AUDIT_ANOM_ABEND),
+ #define XLAT_VAL_83 ((unsigned) (AUDIT_ANOM_ABEND))
+ #define XLAT_STR_83 STRINGIFY(AUDIT_ANOM_ABEND)
  XLAT(AUDIT_ANOM_LINK),
+ #define XLAT_VAL_84 ((unsigned) (AUDIT_ANOM_LINK))
+ #define XLAT_STR_84 STRINGIFY(AUDIT_ANOM_LINK)
  XLAT(AUDIT_ANOM_CREAT),
+ #define XLAT_VAL_85 ((unsigned) (AUDIT_ANOM_CREAT))
+ #define XLAT_STR_85 STRINGIFY(AUDIT_ANOM_CREAT)
  XLAT(AUDIT_LAST_KERN_ANOM_MSG),
+ #define XLAT_VAL_86 ((unsigned) (AUDIT_LAST_KERN_ANOM_MSG))
+ #define XLAT_STR_86 STRINGIFY(AUDIT_LAST_KERN_ANOM_MSG)
 
  XLAT(AUDIT_INTEGRITY_DATA),
+ #define XLAT_VAL_87 ((unsigned) (AUDIT_INTEGRITY_DATA))
+ #define XLAT_STR_87 STRINGIFY(AUDIT_INTEGRITY_DATA)
  XLAT(AUDIT_INTEGRITY_METADATA),
+ #define XLAT_VAL_88 ((unsigned) (AUDIT_INTEGRITY_METADATA))
+ #define XLAT_STR_88 STRINGIFY(AUDIT_INTEGRITY_METADATA)
  XLAT(AUDIT_INTEGRITY_STATUS),
+ #define XLAT_VAL_89 ((unsigned) (AUDIT_INTEGRITY_STATUS))
+ #define XLAT_STR_89 STRINGIFY(AUDIT_INTEGRITY_STATUS)
  XLAT(AUDIT_INTEGRITY_HASH),
+ #define XLAT_VAL_90 ((unsigned) (AUDIT_INTEGRITY_HASH))
+ #define XLAT_STR_90 STRINGIFY(AUDIT_INTEGRITY_HASH)
  XLAT(AUDIT_INTEGRITY_PCR),
+ #define XLAT_VAL_91 ((unsigned) (AUDIT_INTEGRITY_PCR))
+ #define XLAT_STR_91 STRINGIFY(AUDIT_INTEGRITY_PCR)
  XLAT(AUDIT_INTEGRITY_RULE),
+ #define XLAT_VAL_92 ((unsigned) (AUDIT_INTEGRITY_RULE))
+ #define XLAT_STR_92 STRINGIFY(AUDIT_INTEGRITY_RULE)
  XLAT(AUDIT_INTEGRITY_EVM_XATTR),
+ #define XLAT_VAL_93 ((unsigned) (AUDIT_INTEGRITY_EVM_XATTR))
+ #define XLAT_STR_93 STRINGIFY(AUDIT_INTEGRITY_EVM_XATTR)
  XLAT(AUDIT_INTEGRITY_POLICY_RULE),
+ #define XLAT_VAL_94 ((unsigned) (AUDIT_INTEGRITY_POLICY_RULE))
+ #define XLAT_STR_94 STRINGIFY(AUDIT_INTEGRITY_POLICY_RULE)
 
  XLAT(AUDIT_KERNEL),
+ #define XLAT_VAL_95 ((unsigned) (AUDIT_KERNEL))
+ #define XLAT_STR_95 STRINGIFY(AUDIT_KERNEL)
 
  XLAT(AUDIT_FIRST_USER_MSG2),
+ #define XLAT_VAL_96 ((unsigned) (AUDIT_FIRST_USER_MSG2))
+ #define XLAT_STR_96 STRINGIFY(AUDIT_FIRST_USER_MSG2)
  XLAT(AUDIT_LAST_USER_MSG2),
+ #define XLAT_VAL_97 ((unsigned) (AUDIT_LAST_USER_MSG2))
+ #define XLAT_STR_97 STRINGIFY(AUDIT_LAST_USER_MSG2)
 };
 static
 const struct xlat nl_audit_types[1] = { {
  .data = nl_audit_types_xdata,
  .size = ARRAY_SIZE(nl_audit_types_xdata),
- .type = XT_NORMAL,
+ .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+#  ifdef XLAT_VAL_47
+  | XLAT_VAL_47
+#  endif
+#  ifdef XLAT_VAL_48
+  | XLAT_VAL_48
+#  endif
+#  ifdef XLAT_VAL_49
+  | XLAT_VAL_49
+#  endif
+#  ifdef XLAT_VAL_50
+  | XLAT_VAL_50
+#  endif
+#  ifdef XLAT_VAL_51
+  | XLAT_VAL_51
+#  endif
+#  ifdef XLAT_VAL_52
+  | XLAT_VAL_52
+#  endif
+#  ifdef XLAT_VAL_53
+  | XLAT_VAL_53
+#  endif
+#  ifdef XLAT_VAL_54
+  | XLAT_VAL_54
+#  endif
+#  ifdef XLAT_VAL_55
+  | XLAT_VAL_55
+#  endif
+#  ifdef XLAT_VAL_56
+  | XLAT_VAL_56
+#  endif
+#  ifdef XLAT_VAL_57
+  | XLAT_VAL_57
+#  endif
+#  ifdef XLAT_VAL_58
+  | XLAT_VAL_58
+#  endif
+#  ifdef XLAT_VAL_59
+  | XLAT_VAL_59
+#  endif
+#  ifdef XLAT_VAL_60
+  | XLAT_VAL_60
+#  endif
+#  ifdef XLAT_VAL_61
+  | XLAT_VAL_61
+#  endif
+#  ifdef XLAT_VAL_62
+  | XLAT_VAL_62
+#  endif
+#  ifdef XLAT_VAL_63
+  | XLAT_VAL_63
+#  endif
+#  ifdef XLAT_VAL_64
+  | XLAT_VAL_64
+#  endif
+#  ifdef XLAT_VAL_65
+  | XLAT_VAL_65
+#  endif
+#  ifdef XLAT_VAL_66
+  | XLAT_VAL_66
+#  endif
+#  ifdef XLAT_VAL_67
+  | XLAT_VAL_67
+#  endif
+#  ifdef XLAT_VAL_68
+  | XLAT_VAL_68
+#  endif
+#  ifdef XLAT_VAL_69
+  | XLAT_VAL_69
+#  endif
+#  ifdef XLAT_VAL_70
+  | XLAT_VAL_70
+#  endif
+#  ifdef XLAT_VAL_71
+  | XLAT_VAL_71
+#  endif
+#  ifdef XLAT_VAL_72
+  | XLAT_VAL_72
+#  endif
+#  ifdef XLAT_VAL_73
+  | XLAT_VAL_73
+#  endif
+#  ifdef XLAT_VAL_74
+  | XLAT_VAL_74
+#  endif
+#  ifdef XLAT_VAL_75
+  | XLAT_VAL_75
+#  endif
+#  ifdef XLAT_VAL_76
+  | XLAT_VAL_76
+#  endif
+#  ifdef XLAT_VAL_77
+  | XLAT_VAL_77
+#  endif
+#  ifdef XLAT_VAL_78
+  | XLAT_VAL_78
+#  endif
+#  ifdef XLAT_VAL_79
+  | XLAT_VAL_79
+#  endif
+#  ifdef XLAT_VAL_80
+  | XLAT_VAL_80
+#  endif
+#  ifdef XLAT_VAL_81
+  | XLAT_VAL_81
+#  endif
+#  ifdef XLAT_VAL_82
+  | XLAT_VAL_82
+#  endif
+#  ifdef XLAT_VAL_83
+  | XLAT_VAL_83
+#  endif
+#  ifdef XLAT_VAL_84
+  | XLAT_VAL_84
+#  endif
+#  ifdef XLAT_VAL_85
+  | XLAT_VAL_85
+#  endif
+#  ifdef XLAT_VAL_86
+  | XLAT_VAL_86
+#  endif
+#  ifdef XLAT_VAL_87
+  | XLAT_VAL_87
+#  endif
+#  ifdef XLAT_VAL_88
+  | XLAT_VAL_88
+#  endif
+#  ifdef XLAT_VAL_89
+  | XLAT_VAL_89
+#  endif
+#  ifdef XLAT_VAL_90
+  | XLAT_VAL_90
+#  endif
+#  ifdef XLAT_VAL_91
+  | XLAT_VAL_91
+#  endif
+#  ifdef XLAT_VAL_92
+  | XLAT_VAL_92
+#  endif
+#  ifdef XLAT_VAL_93
+  | XLAT_VAL_93
+#  endif
+#  ifdef XLAT_VAL_94
+  | XLAT_VAL_94
+#  endif
+#  ifdef XLAT_VAL_95
+  | XLAT_VAL_95
+#  endif
+#  ifdef XLAT_VAL_96
+  | XLAT_VAL_96
+#  endif
+#  ifdef XLAT_VAL_97
+  | XLAT_VAL_97
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+#  ifdef XLAT_STR_47
+  + sizeof(XLAT_STR_47)
+#  endif
+#  ifdef XLAT_STR_48
+  + sizeof(XLAT_STR_48)
+#  endif
+#  ifdef XLAT_STR_49
+  + sizeof(XLAT_STR_49)
+#  endif
+#  ifdef XLAT_STR_50
+  + sizeof(XLAT_STR_50)
+#  endif
+#  ifdef XLAT_STR_51
+  + sizeof(XLAT_STR_51)
+#  endif
+#  ifdef XLAT_STR_52
+  + sizeof(XLAT_STR_52)
+#  endif
+#  ifdef XLAT_STR_53
+  + sizeof(XLAT_STR_53)
+#  endif
+#  ifdef XLAT_STR_54
+  + sizeof(XLAT_STR_54)
+#  endif
+#  ifdef XLAT_STR_55
+  + sizeof(XLAT_STR_55)
+#  endif
+#  ifdef XLAT_STR_56
+  + sizeof(XLAT_STR_56)
+#  endif
+#  ifdef XLAT_STR_57
+  + sizeof(XLAT_STR_57)
+#  endif
+#  ifdef XLAT_STR_58
+  + sizeof(XLAT_STR_58)
+#  endif
+#  ifdef XLAT_STR_59
+  + sizeof(XLAT_STR_59)
+#  endif
+#  ifdef XLAT_STR_60
+  + sizeof(XLAT_STR_60)
+#  endif
+#  ifdef XLAT_STR_61
+  + sizeof(XLAT_STR_61)
+#  endif
+#  ifdef XLAT_STR_62
+  + sizeof(XLAT_STR_62)
+#  endif
+#  ifdef XLAT_STR_63
+  + sizeof(XLAT_STR_63)
+#  endif
+#  ifdef XLAT_STR_64
+  + sizeof(XLAT_STR_64)
+#  endif
+#  ifdef XLAT_STR_65
+  + sizeof(XLAT_STR_65)
+#  endif
+#  ifdef XLAT_STR_66
+  + sizeof(XLAT_STR_66)
+#  endif
+#  ifdef XLAT_STR_67
+  + sizeof(XLAT_STR_67)
+#  endif
+#  ifdef XLAT_STR_68
+  + sizeof(XLAT_STR_68)
+#  endif
+#  ifdef XLAT_STR_69
+  + sizeof(XLAT_STR_69)
+#  endif
+#  ifdef XLAT_STR_70
+  + sizeof(XLAT_STR_70)
+#  endif
+#  ifdef XLAT_STR_71
+  + sizeof(XLAT_STR_71)
+#  endif
+#  ifdef XLAT_STR_72
+  + sizeof(XLAT_STR_72)
+#  endif
+#  ifdef XLAT_STR_73
+  + sizeof(XLAT_STR_73)
+#  endif
+#  ifdef XLAT_STR_74
+  + sizeof(XLAT_STR_74)
+#  endif
+#  ifdef XLAT_STR_75
+  + sizeof(XLAT_STR_75)
+#  endif
+#  ifdef XLAT_STR_76
+  + sizeof(XLAT_STR_76)
+#  endif
+#  ifdef XLAT_STR_77
+  + sizeof(XLAT_STR_77)
+#  endif
+#  ifdef XLAT_STR_78
+  + sizeof(XLAT_STR_78)
+#  endif
+#  ifdef XLAT_STR_79
+  + sizeof(XLAT_STR_79)
+#  endif
+#  ifdef XLAT_STR_80
+  + sizeof(XLAT_STR_80)
+#  endif
+#  ifdef XLAT_STR_81
+  + sizeof(XLAT_STR_81)
+#  endif
+#  ifdef XLAT_STR_82
+  + sizeof(XLAT_STR_82)
+#  endif
+#  ifdef XLAT_STR_83
+  + sizeof(XLAT_STR_83)
+#  endif
+#  ifdef XLAT_STR_84
+  + sizeof(XLAT_STR_84)
+#  endif
+#  ifdef XLAT_STR_85
+  + sizeof(XLAT_STR_85)
+#  endif
+#  ifdef XLAT_STR_86
+  + sizeof(XLAT_STR_86)
+#  endif
+#  ifdef XLAT_STR_87
+  + sizeof(XLAT_STR_87)
+#  endif
+#  ifdef XLAT_STR_88
+  + sizeof(XLAT_STR_88)
+#  endif
+#  ifdef XLAT_STR_89
+  + sizeof(XLAT_STR_89)
+#  endif
+#  ifdef XLAT_STR_90
+  + sizeof(XLAT_STR_90)
+#  endif
+#  ifdef XLAT_STR_91
+  + sizeof(XLAT_STR_91)
+#  endif
+#  ifdef XLAT_STR_92
+  + sizeof(XLAT_STR_92)
+#  endif
+#  ifdef XLAT_STR_93
+  + sizeof(XLAT_STR_93)
+#  endif
+#  ifdef XLAT_STR_94
+  + sizeof(XLAT_STR_94)
+#  endif
+#  ifdef XLAT_STR_95
+  + sizeof(XLAT_STR_95)
+#  endif
+#  ifdef XLAT_STR_96
+  + sizeof(XLAT_STR_96)
+#  endif
+#  ifdef XLAT_STR_97
+  + sizeof(XLAT_STR_97)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
+#  undef XLAT_STR_47
+#  undef XLAT_VAL_47
+#  undef XLAT_STR_48
+#  undef XLAT_VAL_48
+#  undef XLAT_STR_49
+#  undef XLAT_VAL_49
+#  undef XLAT_STR_50
+#  undef XLAT_VAL_50
+#  undef XLAT_STR_51
+#  undef XLAT_VAL_51
+#  undef XLAT_STR_52
+#  undef XLAT_VAL_52
+#  undef XLAT_STR_53
+#  undef XLAT_VAL_53
+#  undef XLAT_STR_54
+#  undef XLAT_VAL_54
+#  undef XLAT_STR_55
+#  undef XLAT_VAL_55
+#  undef XLAT_STR_56
+#  undef XLAT_VAL_56
+#  undef XLAT_STR_57
+#  undef XLAT_VAL_57
+#  undef XLAT_STR_58
+#  undef XLAT_VAL_58
+#  undef XLAT_STR_59
+#  undef XLAT_VAL_59
+#  undef XLAT_STR_60
+#  undef XLAT_VAL_60
+#  undef XLAT_STR_61
+#  undef XLAT_VAL_61
+#  undef XLAT_STR_62
+#  undef XLAT_VAL_62
+#  undef XLAT_STR_63
+#  undef XLAT_VAL_63
+#  undef XLAT_STR_64
+#  undef XLAT_VAL_64
+#  undef XLAT_STR_65
+#  undef XLAT_VAL_65
+#  undef XLAT_STR_66
+#  undef XLAT_VAL_66
+#  undef XLAT_STR_67
+#  undef XLAT_VAL_67
+#  undef XLAT_STR_68
+#  undef XLAT_VAL_68
+#  undef XLAT_STR_69
+#  undef XLAT_VAL_69
+#  undef XLAT_STR_70
+#  undef XLAT_VAL_70
+#  undef XLAT_STR_71
+#  undef XLAT_VAL_71
+#  undef XLAT_STR_72
+#  undef XLAT_VAL_72
+#  undef XLAT_STR_73
+#  undef XLAT_VAL_73
+#  undef XLAT_STR_74
+#  undef XLAT_VAL_74
+#  undef XLAT_STR_75
+#  undef XLAT_VAL_75
+#  undef XLAT_STR_76
+#  undef XLAT_VAL_76
+#  undef XLAT_STR_77
+#  undef XLAT_VAL_77
+#  undef XLAT_STR_78
+#  undef XLAT_VAL_78
+#  undef XLAT_STR_79
+#  undef XLAT_VAL_79
+#  undef XLAT_STR_80
+#  undef XLAT_VAL_80
+#  undef XLAT_STR_81
+#  undef XLAT_VAL_81
+#  undef XLAT_STR_82
+#  undef XLAT_VAL_82
+#  undef XLAT_STR_83
+#  undef XLAT_VAL_83
+#  undef XLAT_STR_84
+#  undef XLAT_VAL_84
+#  undef XLAT_STR_85
+#  undef XLAT_VAL_85
+#  undef XLAT_STR_86
+#  undef XLAT_VAL_86
+#  undef XLAT_STR_87
+#  undef XLAT_VAL_87
+#  undef XLAT_STR_88
+#  undef XLAT_VAL_88
+#  undef XLAT_STR_89
+#  undef XLAT_VAL_89
+#  undef XLAT_STR_90
+#  undef XLAT_VAL_90
+#  undef XLAT_STR_91
+#  undef XLAT_VAL_91
+#  undef XLAT_STR_92
+#  undef XLAT_VAL_92
+#  undef XLAT_STR_93
+#  undef XLAT_VAL_93
+#  undef XLAT_STR_94
+#  undef XLAT_VAL_94
+#  undef XLAT_STR_95
+#  undef XLAT_VAL_95
+#  undef XLAT_STR_96
+#  undef XLAT_VAL_96
+#  undef XLAT_STR_97
+#  undef XLAT_VAL_97
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/nl_audit_types.in 5.9-0ubuntu2/xlat/nl_audit_types.in
--- 5.5-3/xlat/nl_audit_types.in	2020-01-07 23:31:49.000000000 +0000
+++ 5.9-0ubuntu2/xlat/nl_audit_types.in	2020-06-28 08:00:00.000000000 +0000
@@ -1,3 +1,4 @@
+#sorted sort -k2,2n
 AUDIT_GET	1000
 AUDIT_SET	1001
 AUDIT_LIST	1002
@@ -78,6 +79,8 @@ AUDIT_KERN_MODULE	1330
 AUDIT_FANOTIFY	1331
 AUDIT_TIME_INJOFFSET	1332
 AUDIT_TIME_ADJNTPVAL	1333
+AUDIT_BPF		1334
+AUDIT_EVENT_LISTENER	1335
 
 AUDIT_AVC	1400
 AUDIT_SELINUX_ERR	1401
diff -pruN 5.5-3/xlat/nl_crypto_types.h 5.9-0ubuntu2/xlat/nl_crypto_types.h
--- 5.5-3/xlat/nl_crypto_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/nl_crypto_types.h	2020-09-24 09:18:45.000000000 +0000
@@ -49,18 +49,72 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data nl_crypto_types_xdata[] = {
  XLAT(CRYPTO_MSG_NEWALG),
+ #define XLAT_VAL_0 ((unsigned) (CRYPTO_MSG_NEWALG))
+ #define XLAT_STR_0 STRINGIFY(CRYPTO_MSG_NEWALG)
  XLAT(CRYPTO_MSG_DELALG),
+ #define XLAT_VAL_1 ((unsigned) (CRYPTO_MSG_DELALG))
+ #define XLAT_STR_1 STRINGIFY(CRYPTO_MSG_DELALG)
  XLAT(CRYPTO_MSG_UPDATEALG),
+ #define XLAT_VAL_2 ((unsigned) (CRYPTO_MSG_UPDATEALG))
+ #define XLAT_STR_2 STRINGIFY(CRYPTO_MSG_UPDATEALG)
  XLAT(CRYPTO_MSG_GETALG),
+ #define XLAT_VAL_3 ((unsigned) (CRYPTO_MSG_GETALG))
+ #define XLAT_STR_3 STRINGIFY(CRYPTO_MSG_GETALG)
  XLAT(CRYPTO_MSG_DELRNG),
+ #define XLAT_VAL_4 ((unsigned) (CRYPTO_MSG_DELRNG))
+ #define XLAT_STR_4 STRINGIFY(CRYPTO_MSG_DELRNG)
 };
 static
 const struct xlat nl_crypto_types[1] = { {
  .data = nl_crypto_types_xdata,
  .size = ARRAY_SIZE(nl_crypto_types_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/nlmsgerr_attrs.h 5.9-0ubuntu2/xlat/nlmsgerr_attrs.h
--- 5.5-3/xlat/nlmsgerr_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/nlmsgerr_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data nlmsgerr_attrs_xdata[] = {
  [NLMSGERR_ATTR_UNUSED] = XLAT(NLMSGERR_ATTR_UNUSED),
+ #define XLAT_VAL_0 ((unsigned) (NLMSGERR_ATTR_UNUSED))
+ #define XLAT_STR_0 STRINGIFY(NLMSGERR_ATTR_UNUSED)
  [NLMSGERR_ATTR_MSG] = XLAT(NLMSGERR_ATTR_MSG),
+ #define XLAT_VAL_1 ((unsigned) (NLMSGERR_ATTR_MSG))
+ #define XLAT_STR_1 STRINGIFY(NLMSGERR_ATTR_MSG)
  [NLMSGERR_ATTR_OFFS] = XLAT(NLMSGERR_ATTR_OFFS),
+ #define XLAT_VAL_2 ((unsigned) (NLMSGERR_ATTR_OFFS))
+ #define XLAT_STR_2 STRINGIFY(NLMSGERR_ATTR_OFFS)
  [NLMSGERR_ATTR_COOKIE] = XLAT(NLMSGERR_ATTR_COOKIE),
+ #define XLAT_VAL_3 ((unsigned) (NLMSGERR_ATTR_COOKIE))
+ #define XLAT_STR_3 STRINGIFY(NLMSGERR_ATTR_COOKIE)
 };
 static
 const struct xlat nlmsgerr_attrs[1] = { {
  .data = nlmsgerr_attrs_xdata,
  .size = ARRAY_SIZE(nlmsgerr_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/nl_netfilter_msg_types.h 5.9-0ubuntu2/xlat/nl_netfilter_msg_types.h
--- 5.5-3/xlat/nl_netfilter_msg_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/nl_netfilter_msg_types.h	2020-09-24 09:18:45.000000000 +0000
@@ -24,14 +24,38 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data nl_netfilter_msg_types_xdata[] = {
  XLAT(NFNL_MSG_BATCH_BEGIN),
+ #define XLAT_VAL_0 ((unsigned) (NFNL_MSG_BATCH_BEGIN))
+ #define XLAT_STR_0 STRINGIFY(NFNL_MSG_BATCH_BEGIN)
  XLAT(NFNL_MSG_BATCH_END),
+ #define XLAT_VAL_1 ((unsigned) (NFNL_MSG_BATCH_END))
+ #define XLAT_STR_1 STRINGIFY(NFNL_MSG_BATCH_END)
 };
 const struct xlat nl_netfilter_msg_types[1] = { {
  .data = nl_netfilter_msg_types_xdata,
  .size = ARRAY_SIZE(nl_netfilter_msg_types_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/nl_netfilter_subsys_ids.h 5.9-0ubuntu2/xlat/nl_netfilter_subsys_ids.h
--- 5.5-3/xlat/nl_netfilter_subsys_ids.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/nl_netfilter_subsys_ids.h	2020-09-24 09:18:45.000000000 +0000
@@ -98,25 +98,149 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data nl_netfilter_subsys_ids_xdata[] = {
  [NFNL_SUBSYS_NONE] = XLAT(NFNL_SUBSYS_NONE),
+ #define XLAT_VAL_0 ((unsigned) (NFNL_SUBSYS_NONE))
+ #define XLAT_STR_0 STRINGIFY(NFNL_SUBSYS_NONE)
  [NFNL_SUBSYS_CTNETLINK] = XLAT(NFNL_SUBSYS_CTNETLINK),
+ #define XLAT_VAL_1 ((unsigned) (NFNL_SUBSYS_CTNETLINK))
+ #define XLAT_STR_1 STRINGIFY(NFNL_SUBSYS_CTNETLINK)
  [NFNL_SUBSYS_CTNETLINK_EXP] = XLAT(NFNL_SUBSYS_CTNETLINK_EXP),
+ #define XLAT_VAL_2 ((unsigned) (NFNL_SUBSYS_CTNETLINK_EXP))
+ #define XLAT_STR_2 STRINGIFY(NFNL_SUBSYS_CTNETLINK_EXP)
  [NFNL_SUBSYS_QUEUE] = XLAT(NFNL_SUBSYS_QUEUE),
+ #define XLAT_VAL_3 ((unsigned) (NFNL_SUBSYS_QUEUE))
+ #define XLAT_STR_3 STRINGIFY(NFNL_SUBSYS_QUEUE)
  [NFNL_SUBSYS_ULOG] = XLAT(NFNL_SUBSYS_ULOG),
+ #define XLAT_VAL_4 ((unsigned) (NFNL_SUBSYS_ULOG))
+ #define XLAT_STR_4 STRINGIFY(NFNL_SUBSYS_ULOG)
  [NFNL_SUBSYS_OSF] = XLAT(NFNL_SUBSYS_OSF),
+ #define XLAT_VAL_5 ((unsigned) (NFNL_SUBSYS_OSF))
+ #define XLAT_STR_5 STRINGIFY(NFNL_SUBSYS_OSF)
  [NFNL_SUBSYS_IPSET] = XLAT(NFNL_SUBSYS_IPSET),
+ #define XLAT_VAL_6 ((unsigned) (NFNL_SUBSYS_IPSET))
+ #define XLAT_STR_6 STRINGIFY(NFNL_SUBSYS_IPSET)
  [NFNL_SUBSYS_ACCT] = XLAT(NFNL_SUBSYS_ACCT),
+ #define XLAT_VAL_7 ((unsigned) (NFNL_SUBSYS_ACCT))
+ #define XLAT_STR_7 STRINGIFY(NFNL_SUBSYS_ACCT)
  [NFNL_SUBSYS_CTNETLINK_TIMEOUT] = XLAT(NFNL_SUBSYS_CTNETLINK_TIMEOUT),
+ #define XLAT_VAL_8 ((unsigned) (NFNL_SUBSYS_CTNETLINK_TIMEOUT))
+ #define XLAT_STR_8 STRINGIFY(NFNL_SUBSYS_CTNETLINK_TIMEOUT)
  [NFNL_SUBSYS_CTHELPER] = XLAT(NFNL_SUBSYS_CTHELPER),
+ #define XLAT_VAL_9 ((unsigned) (NFNL_SUBSYS_CTHELPER))
+ #define XLAT_STR_9 STRINGIFY(NFNL_SUBSYS_CTHELPER)
  [NFNL_SUBSYS_NFTABLES] = XLAT(NFNL_SUBSYS_NFTABLES),
+ #define XLAT_VAL_10 ((unsigned) (NFNL_SUBSYS_NFTABLES))
+ #define XLAT_STR_10 STRINGIFY(NFNL_SUBSYS_NFTABLES)
  [NFNL_SUBSYS_NFT_COMPAT] = XLAT(NFNL_SUBSYS_NFT_COMPAT),
+ #define XLAT_VAL_11 ((unsigned) (NFNL_SUBSYS_NFT_COMPAT))
+ #define XLAT_STR_11 STRINGIFY(NFNL_SUBSYS_NFT_COMPAT)
 };
 static
 const struct xlat nl_netfilter_subsys_ids[1] = { {
  .data = nl_netfilter_subsys_ids_xdata,
  .size = ARRAY_SIZE(nl_netfilter_subsys_ids_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/nl_route_types.h 5.9-0ubuntu2/xlat/nl_route_types.h
--- 5.5-3/xlat/nl_route_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/nl_route_types.h	2020-09-24 09:18:46.000000000 +0000
@@ -395,87 +395,641 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data nl_route_types_xdata[] = {
  XLAT(RTM_NEWLINK),
+ #define XLAT_VAL_0 ((unsigned) (RTM_NEWLINK))
+ #define XLAT_STR_0 STRINGIFY(RTM_NEWLINK)
  XLAT(RTM_DELLINK),
+ #define XLAT_VAL_1 ((unsigned) (RTM_DELLINK))
+ #define XLAT_STR_1 STRINGIFY(RTM_DELLINK)
  XLAT(RTM_GETLINK),
+ #define XLAT_VAL_2 ((unsigned) (RTM_GETLINK))
+ #define XLAT_STR_2 STRINGIFY(RTM_GETLINK)
  XLAT(RTM_SETLINK),
+ #define XLAT_VAL_3 ((unsigned) (RTM_SETLINK))
+ #define XLAT_STR_3 STRINGIFY(RTM_SETLINK)
 
  XLAT(RTM_NEWADDR),
+ #define XLAT_VAL_4 ((unsigned) (RTM_NEWADDR))
+ #define XLAT_STR_4 STRINGIFY(RTM_NEWADDR)
  XLAT(RTM_DELADDR),
+ #define XLAT_VAL_5 ((unsigned) (RTM_DELADDR))
+ #define XLAT_STR_5 STRINGIFY(RTM_DELADDR)
  XLAT(RTM_GETADDR),
+ #define XLAT_VAL_6 ((unsigned) (RTM_GETADDR))
+ #define XLAT_STR_6 STRINGIFY(RTM_GETADDR)
 
  XLAT(RTM_NEWROUTE),
+ #define XLAT_VAL_7 ((unsigned) (RTM_NEWROUTE))
+ #define XLAT_STR_7 STRINGIFY(RTM_NEWROUTE)
  XLAT(RTM_DELROUTE),
+ #define XLAT_VAL_8 ((unsigned) (RTM_DELROUTE))
+ #define XLAT_STR_8 STRINGIFY(RTM_DELROUTE)
  XLAT(RTM_GETROUTE),
+ #define XLAT_VAL_9 ((unsigned) (RTM_GETROUTE))
+ #define XLAT_STR_9 STRINGIFY(RTM_GETROUTE)
 
  XLAT(RTM_NEWNEIGH),
+ #define XLAT_VAL_10 ((unsigned) (RTM_NEWNEIGH))
+ #define XLAT_STR_10 STRINGIFY(RTM_NEWNEIGH)
  XLAT(RTM_DELNEIGH),
+ #define XLAT_VAL_11 ((unsigned) (RTM_DELNEIGH))
+ #define XLAT_STR_11 STRINGIFY(RTM_DELNEIGH)
  XLAT(RTM_GETNEIGH),
+ #define XLAT_VAL_12 ((unsigned) (RTM_GETNEIGH))
+ #define XLAT_STR_12 STRINGIFY(RTM_GETNEIGH)
 
  XLAT(RTM_NEWRULE),
+ #define XLAT_VAL_13 ((unsigned) (RTM_NEWRULE))
+ #define XLAT_STR_13 STRINGIFY(RTM_NEWRULE)
  XLAT(RTM_DELRULE),
+ #define XLAT_VAL_14 ((unsigned) (RTM_DELRULE))
+ #define XLAT_STR_14 STRINGIFY(RTM_DELRULE)
  XLAT(RTM_GETRULE),
+ #define XLAT_VAL_15 ((unsigned) (RTM_GETRULE))
+ #define XLAT_STR_15 STRINGIFY(RTM_GETRULE)
 
  XLAT(RTM_NEWQDISC),
+ #define XLAT_VAL_16 ((unsigned) (RTM_NEWQDISC))
+ #define XLAT_STR_16 STRINGIFY(RTM_NEWQDISC)
  XLAT(RTM_DELQDISC),
+ #define XLAT_VAL_17 ((unsigned) (RTM_DELQDISC))
+ #define XLAT_STR_17 STRINGIFY(RTM_DELQDISC)
  XLAT(RTM_GETQDISC),
+ #define XLAT_VAL_18 ((unsigned) (RTM_GETQDISC))
+ #define XLAT_STR_18 STRINGIFY(RTM_GETQDISC)
 
  XLAT(RTM_NEWTCLASS),
+ #define XLAT_VAL_19 ((unsigned) (RTM_NEWTCLASS))
+ #define XLAT_STR_19 STRINGIFY(RTM_NEWTCLASS)
  XLAT(RTM_DELTCLASS),
+ #define XLAT_VAL_20 ((unsigned) (RTM_DELTCLASS))
+ #define XLAT_STR_20 STRINGIFY(RTM_DELTCLASS)
  XLAT(RTM_GETTCLASS),
+ #define XLAT_VAL_21 ((unsigned) (RTM_GETTCLASS))
+ #define XLAT_STR_21 STRINGIFY(RTM_GETTCLASS)
 
  XLAT(RTM_NEWTFILTER),
+ #define XLAT_VAL_22 ((unsigned) (RTM_NEWTFILTER))
+ #define XLAT_STR_22 STRINGIFY(RTM_NEWTFILTER)
  XLAT(RTM_DELTFILTER),
+ #define XLAT_VAL_23 ((unsigned) (RTM_DELTFILTER))
+ #define XLAT_STR_23 STRINGIFY(RTM_DELTFILTER)
  XLAT(RTM_GETTFILTER),
+ #define XLAT_VAL_24 ((unsigned) (RTM_GETTFILTER))
+ #define XLAT_STR_24 STRINGIFY(RTM_GETTFILTER)
 
  XLAT(RTM_NEWACTION),
+ #define XLAT_VAL_25 ((unsigned) (RTM_NEWACTION))
+ #define XLAT_STR_25 STRINGIFY(RTM_NEWACTION)
  XLAT(RTM_DELACTION),
+ #define XLAT_VAL_26 ((unsigned) (RTM_DELACTION))
+ #define XLAT_STR_26 STRINGIFY(RTM_DELACTION)
  XLAT(RTM_GETACTION),
+ #define XLAT_VAL_27 ((unsigned) (RTM_GETACTION))
+ #define XLAT_STR_27 STRINGIFY(RTM_GETACTION)
 
  XLAT(RTM_NEWPREFIX),
+ #define XLAT_VAL_28 ((unsigned) (RTM_NEWPREFIX))
+ #define XLAT_STR_28 STRINGIFY(RTM_NEWPREFIX)
  XLAT(RTM_GETPREFIX),
+ #define XLAT_VAL_29 ((unsigned) (RTM_GETPREFIX))
+ #define XLAT_STR_29 STRINGIFY(RTM_GETPREFIX)
 
  XLAT(RTM_GETMULTICAST),
+ #define XLAT_VAL_30 ((unsigned) (RTM_GETMULTICAST))
+ #define XLAT_STR_30 STRINGIFY(RTM_GETMULTICAST)
 
  XLAT(RTM_GETANYCAST),
+ #define XLAT_VAL_31 ((unsigned) (RTM_GETANYCAST))
+ #define XLAT_STR_31 STRINGIFY(RTM_GETANYCAST)
 
  XLAT(RTM_NEWNEIGHTBL),
+ #define XLAT_VAL_32 ((unsigned) (RTM_NEWNEIGHTBL))
+ #define XLAT_STR_32 STRINGIFY(RTM_NEWNEIGHTBL)
  XLAT(RTM_GETNEIGHTBL),
+ #define XLAT_VAL_33 ((unsigned) (RTM_GETNEIGHTBL))
+ #define XLAT_STR_33 STRINGIFY(RTM_GETNEIGHTBL)
  XLAT(RTM_SETNEIGHTBL),
+ #define XLAT_VAL_34 ((unsigned) (RTM_SETNEIGHTBL))
+ #define XLAT_STR_34 STRINGIFY(RTM_SETNEIGHTBL)
 
  XLAT(RTM_NEWNDUSEROPT),
+ #define XLAT_VAL_35 ((unsigned) (RTM_NEWNDUSEROPT))
+ #define XLAT_STR_35 STRINGIFY(RTM_NEWNDUSEROPT)
 
  XLAT(RTM_NEWADDRLABEL),
+ #define XLAT_VAL_36 ((unsigned) (RTM_NEWADDRLABEL))
+ #define XLAT_STR_36 STRINGIFY(RTM_NEWADDRLABEL)
  XLAT(RTM_DELADDRLABEL),
+ #define XLAT_VAL_37 ((unsigned) (RTM_DELADDRLABEL))
+ #define XLAT_STR_37 STRINGIFY(RTM_DELADDRLABEL)
  XLAT(RTM_GETADDRLABEL),
+ #define XLAT_VAL_38 ((unsigned) (RTM_GETADDRLABEL))
+ #define XLAT_STR_38 STRINGIFY(RTM_GETADDRLABEL)
 
  XLAT(RTM_GETDCB),
+ #define XLAT_VAL_39 ((unsigned) (RTM_GETDCB))
+ #define XLAT_STR_39 STRINGIFY(RTM_GETDCB)
  XLAT(RTM_SETDCB),
+ #define XLAT_VAL_40 ((unsigned) (RTM_SETDCB))
+ #define XLAT_STR_40 STRINGIFY(RTM_SETDCB)
 
  XLAT(RTM_NEWNETCONF),
+ #define XLAT_VAL_41 ((unsigned) (RTM_NEWNETCONF))
+ #define XLAT_STR_41 STRINGIFY(RTM_NEWNETCONF)
  XLAT(RTM_DELNETCONF),
+ #define XLAT_VAL_42 ((unsigned) (RTM_DELNETCONF))
+ #define XLAT_STR_42 STRINGIFY(RTM_DELNETCONF)
  XLAT(RTM_GETNETCONF),
+ #define XLAT_VAL_43 ((unsigned) (RTM_GETNETCONF))
+ #define XLAT_STR_43 STRINGIFY(RTM_GETNETCONF)
 
  XLAT(RTM_NEWMDB),
+ #define XLAT_VAL_44 ((unsigned) (RTM_NEWMDB))
+ #define XLAT_STR_44 STRINGIFY(RTM_NEWMDB)
  XLAT(RTM_DELMDB),
+ #define XLAT_VAL_45 ((unsigned) (RTM_DELMDB))
+ #define XLAT_STR_45 STRINGIFY(RTM_DELMDB)
  XLAT(RTM_GETMDB),
+ #define XLAT_VAL_46 ((unsigned) (RTM_GETMDB))
+ #define XLAT_STR_46 STRINGIFY(RTM_GETMDB)
 
  XLAT(RTM_NEWNSID),
+ #define XLAT_VAL_47 ((unsigned) (RTM_NEWNSID))
+ #define XLAT_STR_47 STRINGIFY(RTM_NEWNSID)
  XLAT(RTM_DELNSID),
+ #define XLAT_VAL_48 ((unsigned) (RTM_DELNSID))
+ #define XLAT_STR_48 STRINGIFY(RTM_DELNSID)
  XLAT(RTM_GETNSID),
+ #define XLAT_VAL_49 ((unsigned) (RTM_GETNSID))
+ #define XLAT_STR_49 STRINGIFY(RTM_GETNSID)
 
  XLAT(RTM_NEWSTATS),
+ #define XLAT_VAL_50 ((unsigned) (RTM_NEWSTATS))
+ #define XLAT_STR_50 STRINGIFY(RTM_NEWSTATS)
  XLAT(RTM_GETSTATS),
+ #define XLAT_VAL_51 ((unsigned) (RTM_GETSTATS))
+ #define XLAT_STR_51 STRINGIFY(RTM_GETSTATS)
 
  XLAT(RTM_NEWCHAIN),
+ #define XLAT_VAL_52 ((unsigned) (RTM_NEWCHAIN))
+ #define XLAT_STR_52 STRINGIFY(RTM_NEWCHAIN)
  XLAT(RTM_DELCHAIN),
+ #define XLAT_VAL_53 ((unsigned) (RTM_DELCHAIN))
+ #define XLAT_STR_53 STRINGIFY(RTM_DELCHAIN)
  XLAT(RTM_GETCHAIN),
+ #define XLAT_VAL_54 ((unsigned) (RTM_GETCHAIN))
+ #define XLAT_STR_54 STRINGIFY(RTM_GETCHAIN)
 };
 const struct xlat nl_route_types[1] = { {
  .data = nl_route_types_xdata,
  .size = ARRAY_SIZE(nl_route_types_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+#  ifdef XLAT_VAL_47
+  | XLAT_VAL_47
+#  endif
+#  ifdef XLAT_VAL_48
+  | XLAT_VAL_48
+#  endif
+#  ifdef XLAT_VAL_49
+  | XLAT_VAL_49
+#  endif
+#  ifdef XLAT_VAL_50
+  | XLAT_VAL_50
+#  endif
+#  ifdef XLAT_VAL_51
+  | XLAT_VAL_51
+#  endif
+#  ifdef XLAT_VAL_52
+  | XLAT_VAL_52
+#  endif
+#  ifdef XLAT_VAL_53
+  | XLAT_VAL_53
+#  endif
+#  ifdef XLAT_VAL_54
+  | XLAT_VAL_54
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+#  ifdef XLAT_STR_47
+  + sizeof(XLAT_STR_47)
+#  endif
+#  ifdef XLAT_STR_48
+  + sizeof(XLAT_STR_48)
+#  endif
+#  ifdef XLAT_STR_49
+  + sizeof(XLAT_STR_49)
+#  endif
+#  ifdef XLAT_STR_50
+  + sizeof(XLAT_STR_50)
+#  endif
+#  ifdef XLAT_STR_51
+  + sizeof(XLAT_STR_51)
+#  endif
+#  ifdef XLAT_STR_52
+  + sizeof(XLAT_STR_52)
+#  endif
+#  ifdef XLAT_STR_53
+  + sizeof(XLAT_STR_53)
+#  endif
+#  ifdef XLAT_STR_54
+  + sizeof(XLAT_STR_54)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
+#  undef XLAT_STR_47
+#  undef XLAT_VAL_47
+#  undef XLAT_STR_48
+#  undef XLAT_VAL_48
+#  undef XLAT_STR_49
+#  undef XLAT_VAL_49
+#  undef XLAT_STR_50
+#  undef XLAT_VAL_50
+#  undef XLAT_STR_51
+#  undef XLAT_VAL_51
+#  undef XLAT_STR_52
+#  undef XLAT_VAL_52
+#  undef XLAT_STR_53
+#  undef XLAT_VAL_53
+#  undef XLAT_STR_54
+#  undef XLAT_VAL_54
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/nl_selinux_types.h 5.9-0ubuntu2/xlat/nl_selinux_types.h
--- 5.5-3/xlat/nl_selinux_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/nl_selinux_types.h	2020-09-24 09:18:45.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data nl_selinux_types_xdata[] = {
  XLAT(SELNL_MSG_SETENFORCE),
+ #define XLAT_VAL_0 ((unsigned) (SELNL_MSG_SETENFORCE))
+ #define XLAT_STR_0 STRINGIFY(SELNL_MSG_SETENFORCE)
  XLAT(SELNL_MSG_POLICYLOAD),
+ #define XLAT_VAL_1 ((unsigned) (SELNL_MSG_POLICYLOAD))
+ #define XLAT_STR_1 STRINGIFY(SELNL_MSG_POLICYLOAD)
 };
 static
 const struct xlat nl_selinux_types[1] = { {
  .data = nl_selinux_types_xdata,
  .size = ARRAY_SIZE(nl_selinux_types_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/nl_sock_diag_types.h 5.9-0ubuntu2/xlat/nl_sock_diag_types.h
--- 5.5-3/xlat/nl_sock_diag_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/nl_sock_diag_types.h	2020-09-24 09:18:45.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data nl_sock_diag_types_xdata[] = {
  XLAT(TCPDIAG_GETSOCK),
+ #define XLAT_VAL_0 ((unsigned) (TCPDIAG_GETSOCK))
+ #define XLAT_STR_0 STRINGIFY(TCPDIAG_GETSOCK)
  XLAT(DCCPDIAG_GETSOCK),
+ #define XLAT_VAL_1 ((unsigned) (DCCPDIAG_GETSOCK))
+ #define XLAT_STR_1 STRINGIFY(DCCPDIAG_GETSOCK)
  XLAT(SOCK_DIAG_BY_FAMILY),
+ #define XLAT_VAL_2 ((unsigned) (SOCK_DIAG_BY_FAMILY))
+ #define XLAT_STR_2 STRINGIFY(SOCK_DIAG_BY_FAMILY)
  XLAT(SOCK_DESTROY),
+ #define XLAT_VAL_3 ((unsigned) (SOCK_DESTROY))
+ #define XLAT_STR_3 STRINGIFY(SOCK_DESTROY)
 };
 static
 const struct xlat nl_sock_diag_types[1] = { {
  .data = nl_sock_diag_types_xdata,
  .size = ARRAY_SIZE(nl_sock_diag_types_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/nl_xfrm_types.h 5.9-0ubuntu2/xlat/nl_xfrm_types.h
--- 5.5-3/xlat/nl_xfrm_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/nl_xfrm_types.h	2020-09-24 09:18:45.000000000 +0000
@@ -175,47 +175,281 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data nl_xfrm_types_xdata[] = {
  XLAT(XFRM_MSG_NEWSA),
+ #define XLAT_VAL_0 ((unsigned) (XFRM_MSG_NEWSA))
+ #define XLAT_STR_0 STRINGIFY(XFRM_MSG_NEWSA)
  XLAT(XFRM_MSG_DELSA),
+ #define XLAT_VAL_1 ((unsigned) (XFRM_MSG_DELSA))
+ #define XLAT_STR_1 STRINGIFY(XFRM_MSG_DELSA)
  XLAT(XFRM_MSG_GETSA),
+ #define XLAT_VAL_2 ((unsigned) (XFRM_MSG_GETSA))
+ #define XLAT_STR_2 STRINGIFY(XFRM_MSG_GETSA)
 
  XLAT(XFRM_MSG_NEWPOLICY),
+ #define XLAT_VAL_3 ((unsigned) (XFRM_MSG_NEWPOLICY))
+ #define XLAT_STR_3 STRINGIFY(XFRM_MSG_NEWPOLICY)
  XLAT(XFRM_MSG_DELPOLICY),
+ #define XLAT_VAL_4 ((unsigned) (XFRM_MSG_DELPOLICY))
+ #define XLAT_STR_4 STRINGIFY(XFRM_MSG_DELPOLICY)
  XLAT(XFRM_MSG_GETPOLICY),
+ #define XLAT_VAL_5 ((unsigned) (XFRM_MSG_GETPOLICY))
+ #define XLAT_STR_5 STRINGIFY(XFRM_MSG_GETPOLICY)
 
  XLAT(XFRM_MSG_ALLOCSPI),
+ #define XLAT_VAL_6 ((unsigned) (XFRM_MSG_ALLOCSPI))
+ #define XLAT_STR_6 STRINGIFY(XFRM_MSG_ALLOCSPI)
  XLAT(XFRM_MSG_ACQUIRE),
+ #define XLAT_VAL_7 ((unsigned) (XFRM_MSG_ACQUIRE))
+ #define XLAT_STR_7 STRINGIFY(XFRM_MSG_ACQUIRE)
  XLAT(XFRM_MSG_EXPIRE),
+ #define XLAT_VAL_8 ((unsigned) (XFRM_MSG_EXPIRE))
+ #define XLAT_STR_8 STRINGIFY(XFRM_MSG_EXPIRE)
 
  XLAT(XFRM_MSG_UPDPOLICY),
+ #define XLAT_VAL_9 ((unsigned) (XFRM_MSG_UPDPOLICY))
+ #define XLAT_STR_9 STRINGIFY(XFRM_MSG_UPDPOLICY)
  XLAT(XFRM_MSG_UPDSA),
+ #define XLAT_VAL_10 ((unsigned) (XFRM_MSG_UPDSA))
+ #define XLAT_STR_10 STRINGIFY(XFRM_MSG_UPDSA)
 
  XLAT(XFRM_MSG_POLEXPIRE),
+ #define XLAT_VAL_11 ((unsigned) (XFRM_MSG_POLEXPIRE))
+ #define XLAT_STR_11 STRINGIFY(XFRM_MSG_POLEXPIRE)
 
  XLAT(XFRM_MSG_FLUSHSA),
+ #define XLAT_VAL_12 ((unsigned) (XFRM_MSG_FLUSHSA))
+ #define XLAT_STR_12 STRINGIFY(XFRM_MSG_FLUSHSA)
  XLAT(XFRM_MSG_FLUSHPOLICY),
+ #define XLAT_VAL_13 ((unsigned) (XFRM_MSG_FLUSHPOLICY))
+ #define XLAT_STR_13 STRINGIFY(XFRM_MSG_FLUSHPOLICY)
 
  XLAT(XFRM_MSG_NEWAE),
+ #define XLAT_VAL_14 ((unsigned) (XFRM_MSG_NEWAE))
+ #define XLAT_STR_14 STRINGIFY(XFRM_MSG_NEWAE)
  XLAT(XFRM_MSG_GETAE),
+ #define XLAT_VAL_15 ((unsigned) (XFRM_MSG_GETAE))
+ #define XLAT_STR_15 STRINGIFY(XFRM_MSG_GETAE)
 
  XLAT(XFRM_MSG_REPORT),
+ #define XLAT_VAL_16 ((unsigned) (XFRM_MSG_REPORT))
+ #define XLAT_STR_16 STRINGIFY(XFRM_MSG_REPORT)
 
  XLAT(XFRM_MSG_MIGRATE),
+ #define XLAT_VAL_17 ((unsigned) (XFRM_MSG_MIGRATE))
+ #define XLAT_STR_17 STRINGIFY(XFRM_MSG_MIGRATE)
 
  XLAT(XFRM_MSG_NEWSADINFO),
+ #define XLAT_VAL_18 ((unsigned) (XFRM_MSG_NEWSADINFO))
+ #define XLAT_STR_18 STRINGIFY(XFRM_MSG_NEWSADINFO)
  XLAT(XFRM_MSG_GETSADINFO),
+ #define XLAT_VAL_19 ((unsigned) (XFRM_MSG_GETSADINFO))
+ #define XLAT_STR_19 STRINGIFY(XFRM_MSG_GETSADINFO)
 
  XLAT(XFRM_MSG_NEWSPDINFO),
+ #define XLAT_VAL_20 ((unsigned) (XFRM_MSG_NEWSPDINFO))
+ #define XLAT_STR_20 STRINGIFY(XFRM_MSG_NEWSPDINFO)
  XLAT(XFRM_MSG_GETSPDINFO),
+ #define XLAT_VAL_21 ((unsigned) (XFRM_MSG_GETSPDINFO))
+ #define XLAT_STR_21 STRINGIFY(XFRM_MSG_GETSPDINFO)
 
  XLAT(XFRM_MSG_MAPPING),
+ #define XLAT_VAL_22 ((unsigned) (XFRM_MSG_MAPPING))
+ #define XLAT_STR_22 STRINGIFY(XFRM_MSG_MAPPING)
 };
 static
 const struct xlat nl_xfrm_types[1] = { {
  .data = nl_xfrm_types_xdata,
  .size = ARRAY_SIZE(nl_xfrm_types_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/notifyflags.h 5.9-0ubuntu2/xlat/notifyflags.h
--- 5.5-3/xlat/notifyflags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/notifyflags.h	2020-09-24 09:18:45.000000000 +0000
@@ -15,24 +15,38 @@
 static const struct xlat_data notifyflags_xdata[] = {
 #if defined(DN_ACCESS) || (defined(HAVE_DECL_DN_ACCESS) && HAVE_DECL_DN_ACCESS)
   XLAT(DN_ACCESS),
+ #define XLAT_VAL_0 ((unsigned) (DN_ACCESS))
+ #define XLAT_STR_0 STRINGIFY(DN_ACCESS)
 #endif
 #if defined(DN_MODIFY) || (defined(HAVE_DECL_DN_MODIFY) && HAVE_DECL_DN_MODIFY)
   XLAT(DN_MODIFY),
+ #define XLAT_VAL_1 ((unsigned) (DN_MODIFY))
+ #define XLAT_STR_1 STRINGIFY(DN_MODIFY)
 #endif
 #if defined(DN_CREATE) || (defined(HAVE_DECL_DN_CREATE) && HAVE_DECL_DN_CREATE)
   XLAT(DN_CREATE),
+ #define XLAT_VAL_2 ((unsigned) (DN_CREATE))
+ #define XLAT_STR_2 STRINGIFY(DN_CREATE)
 #endif
 #if defined(DN_DELETE) || (defined(HAVE_DECL_DN_DELETE) && HAVE_DECL_DN_DELETE)
   XLAT(DN_DELETE),
+ #define XLAT_VAL_3 ((unsigned) (DN_DELETE))
+ #define XLAT_STR_3 STRINGIFY(DN_DELETE)
 #endif
 #if defined(DN_RENAME) || (defined(HAVE_DECL_DN_RENAME) && HAVE_DECL_DN_RENAME)
   XLAT(DN_RENAME),
+ #define XLAT_VAL_4 ((unsigned) (DN_RENAME))
+ #define XLAT_STR_4 STRINGIFY(DN_RENAME)
 #endif
 #if defined(DN_ATTRIB) || (defined(HAVE_DECL_DN_ATTRIB) && HAVE_DECL_DN_ATTRIB)
   XLAT(DN_ATTRIB),
+ #define XLAT_VAL_5 ((unsigned) (DN_ATTRIB))
+ #define XLAT_STR_5 STRINGIFY(DN_ATTRIB)
 #endif
 #if defined(DN_MULTISHOT) || (defined(HAVE_DECL_DN_MULTISHOT) && HAVE_DECL_DN_MULTISHOT)
   XLAT(DN_MULTISHOT),
+ #define XLAT_VAL_6 ((unsigned) (DN_MULTISHOT))
+ #define XLAT_STR_6 STRINGIFY(DN_MULTISHOT)
 #endif
 };
 static
@@ -40,8 +54,68 @@ const struct xlat notifyflags[1] = { {
  .data = notifyflags_xdata,
  .size = ARRAY_SIZE(notifyflags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/nt_descriptor_types.h 5.9-0ubuntu2/xlat/nt_descriptor_types.h
--- 5.5-3/xlat/nt_descriptor_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/nt_descriptor_types.h	2020-09-24 09:18:46.000000000 +0000
@@ -504,83 +504,787 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data nt_descriptor_types_xdata[] = {
  XLAT(NT_PRSTATUS),
+ #define XLAT_VAL_0 ((unsigned) (NT_PRSTATUS))
+ #define XLAT_STR_0 STRINGIFY(NT_PRSTATUS)
  XLAT(NT_FPREGSET),
+ #define XLAT_VAL_1 ((unsigned) (NT_FPREGSET))
+ #define XLAT_STR_1 STRINGIFY(NT_FPREGSET)
  XLAT(NT_PRPSINFO),
+ #define XLAT_VAL_2 ((unsigned) (NT_PRPSINFO))
+ #define XLAT_STR_2 STRINGIFY(NT_PRPSINFO)
  XLAT(NT_PRXREG),
+ #define XLAT_VAL_3 ((unsigned) (NT_PRXREG))
+ #define XLAT_STR_3 STRINGIFY(NT_PRXREG)
  XLAT(NT_TASKSTRUCT),
+ #define XLAT_VAL_4 ((unsigned) (NT_TASKSTRUCT))
+ #define XLAT_STR_4 STRINGIFY(NT_TASKSTRUCT)
  XLAT(NT_PLATFORM),
+ #define XLAT_VAL_5 ((unsigned) (NT_PLATFORM))
+ #define XLAT_STR_5 STRINGIFY(NT_PLATFORM)
  XLAT(NT_AUXV),
+ #define XLAT_VAL_6 ((unsigned) (NT_AUXV))
+ #define XLAT_STR_6 STRINGIFY(NT_AUXV)
  XLAT(NT_GWINDOWS),
+ #define XLAT_VAL_7 ((unsigned) (NT_GWINDOWS))
+ #define XLAT_STR_7 STRINGIFY(NT_GWINDOWS)
  XLAT(NT_ASRS),
+ #define XLAT_VAL_8 ((unsigned) (NT_ASRS))
+ #define XLAT_STR_8 STRINGIFY(NT_ASRS)
  XLAT(NT_PSTATUS),
+ #define XLAT_VAL_9 ((unsigned) (NT_PSTATUS))
+ #define XLAT_STR_9 STRINGIFY(NT_PSTATUS)
  XLAT(NT_PSINFO),
+ #define XLAT_VAL_10 ((unsigned) (NT_PSINFO))
+ #define XLAT_STR_10 STRINGIFY(NT_PSINFO)
  XLAT(NT_PRCRED),
+ #define XLAT_VAL_11 ((unsigned) (NT_PRCRED))
+ #define XLAT_STR_11 STRINGIFY(NT_PRCRED)
  XLAT(NT_UTSNAME),
+ #define XLAT_VAL_12 ((unsigned) (NT_UTSNAME))
+ #define XLAT_STR_12 STRINGIFY(NT_UTSNAME)
  XLAT(NT_LWPSTATUS),
+ #define XLAT_VAL_13 ((unsigned) (NT_LWPSTATUS))
+ #define XLAT_STR_13 STRINGIFY(NT_LWPSTATUS)
  XLAT(NT_LWPSINFO),
+ #define XLAT_VAL_14 ((unsigned) (NT_LWPSINFO))
+ #define XLAT_STR_14 STRINGIFY(NT_LWPSINFO)
  XLAT(NT_PRFPXREG),
+ #define XLAT_VAL_15 ((unsigned) (NT_PRFPXREG))
+ #define XLAT_STR_15 STRINGIFY(NT_PRFPXREG)
  XLAT(NT_SIGINFO),
+ #define XLAT_VAL_16 ((unsigned) (NT_SIGINFO))
+ #define XLAT_STR_16 STRINGIFY(NT_SIGINFO)
  XLAT(NT_FILE),
+ #define XLAT_VAL_17 ((unsigned) (NT_FILE))
+ #define XLAT_STR_17 STRINGIFY(NT_FILE)
  XLAT(NT_PRXFPREG),
+ #define XLAT_VAL_18 ((unsigned) (NT_PRXFPREG))
+ #define XLAT_STR_18 STRINGIFY(NT_PRXFPREG)
  XLAT(NT_PPC_VMX),
+ #define XLAT_VAL_19 ((unsigned) (NT_PPC_VMX))
+ #define XLAT_STR_19 STRINGIFY(NT_PPC_VMX)
  XLAT(NT_PPC_SPE),
+ #define XLAT_VAL_20 ((unsigned) (NT_PPC_SPE))
+ #define XLAT_STR_20 STRINGIFY(NT_PPC_SPE)
  XLAT(NT_PPC_VSX),
+ #define XLAT_VAL_21 ((unsigned) (NT_PPC_VSX))
+ #define XLAT_STR_21 STRINGIFY(NT_PPC_VSX)
  XLAT(NT_PPC_TAR),
+ #define XLAT_VAL_22 ((unsigned) (NT_PPC_TAR))
+ #define XLAT_STR_22 STRINGIFY(NT_PPC_TAR)
  XLAT(NT_PPC_PPR),
+ #define XLAT_VAL_23 ((unsigned) (NT_PPC_PPR))
+ #define XLAT_STR_23 STRINGIFY(NT_PPC_PPR)
  XLAT(NT_PPC_DSCR),
+ #define XLAT_VAL_24 ((unsigned) (NT_PPC_DSCR))
+ #define XLAT_STR_24 STRINGIFY(NT_PPC_DSCR)
  XLAT(NT_PPC_EBB),
+ #define XLAT_VAL_25 ((unsigned) (NT_PPC_EBB))
+ #define XLAT_STR_25 STRINGIFY(NT_PPC_EBB)
  XLAT(NT_PPC_PMU),
+ #define XLAT_VAL_26 ((unsigned) (NT_PPC_PMU))
+ #define XLAT_STR_26 STRINGIFY(NT_PPC_PMU)
  XLAT(NT_PPC_TM_CGPR),
+ #define XLAT_VAL_27 ((unsigned) (NT_PPC_TM_CGPR))
+ #define XLAT_STR_27 STRINGIFY(NT_PPC_TM_CGPR)
  XLAT(NT_PPC_TM_CFPR),
+ #define XLAT_VAL_28 ((unsigned) (NT_PPC_TM_CFPR))
+ #define XLAT_STR_28 STRINGIFY(NT_PPC_TM_CFPR)
  XLAT(NT_PPC_TM_CVMX),
+ #define XLAT_VAL_29 ((unsigned) (NT_PPC_TM_CVMX))
+ #define XLAT_STR_29 STRINGIFY(NT_PPC_TM_CVMX)
  XLAT(NT_PPC_TM_CVSX),
+ #define XLAT_VAL_30 ((unsigned) (NT_PPC_TM_CVSX))
+ #define XLAT_STR_30 STRINGIFY(NT_PPC_TM_CVSX)
  XLAT(NT_PPC_TM_SPR),
+ #define XLAT_VAL_31 ((unsigned) (NT_PPC_TM_SPR))
+ #define XLAT_STR_31 STRINGIFY(NT_PPC_TM_SPR)
  XLAT(NT_PPC_TM_CTAR),
+ #define XLAT_VAL_32 ((unsigned) (NT_PPC_TM_CTAR))
+ #define XLAT_STR_32 STRINGIFY(NT_PPC_TM_CTAR)
  XLAT(NT_PPC_TM_CPPR),
+ #define XLAT_VAL_33 ((unsigned) (NT_PPC_TM_CPPR))
+ #define XLAT_STR_33 STRINGIFY(NT_PPC_TM_CPPR)
  XLAT(NT_PPC_TM_CDSCR),
+ #define XLAT_VAL_34 ((unsigned) (NT_PPC_TM_CDSCR))
+ #define XLAT_STR_34 STRINGIFY(NT_PPC_TM_CDSCR)
  XLAT(NT_PPC_PKEY),
+ #define XLAT_VAL_35 ((unsigned) (NT_PPC_PKEY))
+ #define XLAT_STR_35 STRINGIFY(NT_PPC_PKEY)
  XLAT(NT_386_TLS),
+ #define XLAT_VAL_36 ((unsigned) (NT_386_TLS))
+ #define XLAT_STR_36 STRINGIFY(NT_386_TLS)
  XLAT(NT_386_IOPERM),
+ #define XLAT_VAL_37 ((unsigned) (NT_386_IOPERM))
+ #define XLAT_STR_37 STRINGIFY(NT_386_IOPERM)
  XLAT(NT_X86_XSTATE),
+ #define XLAT_VAL_38 ((unsigned) (NT_X86_XSTATE))
+ #define XLAT_STR_38 STRINGIFY(NT_X86_XSTATE)
  XLAT(NT_S390_HIGH_GPRS),
+ #define XLAT_VAL_39 ((unsigned) (NT_S390_HIGH_GPRS))
+ #define XLAT_STR_39 STRINGIFY(NT_S390_HIGH_GPRS)
  XLAT(NT_S390_TIMER),
+ #define XLAT_VAL_40 ((unsigned) (NT_S390_TIMER))
+ #define XLAT_STR_40 STRINGIFY(NT_S390_TIMER)
  XLAT(NT_S390_TODCMP),
+ #define XLAT_VAL_41 ((unsigned) (NT_S390_TODCMP))
+ #define XLAT_STR_41 STRINGIFY(NT_S390_TODCMP)
  XLAT(NT_S390_TODPREG),
+ #define XLAT_VAL_42 ((unsigned) (NT_S390_TODPREG))
+ #define XLAT_STR_42 STRINGIFY(NT_S390_TODPREG)
  XLAT(NT_S390_CTRS),
+ #define XLAT_VAL_43 ((unsigned) (NT_S390_CTRS))
+ #define XLAT_STR_43 STRINGIFY(NT_S390_CTRS)
  XLAT(NT_S390_PREFIX),
+ #define XLAT_VAL_44 ((unsigned) (NT_S390_PREFIX))
+ #define XLAT_STR_44 STRINGIFY(NT_S390_PREFIX)
  XLAT(NT_S390_LAST_BREAK),
+ #define XLAT_VAL_45 ((unsigned) (NT_S390_LAST_BREAK))
+ #define XLAT_STR_45 STRINGIFY(NT_S390_LAST_BREAK)
  XLAT(NT_S390_SYSTEM_CALL),
+ #define XLAT_VAL_46 ((unsigned) (NT_S390_SYSTEM_CALL))
+ #define XLAT_STR_46 STRINGIFY(NT_S390_SYSTEM_CALL)
  XLAT(NT_S390_TDB),
+ #define XLAT_VAL_47 ((unsigned) (NT_S390_TDB))
+ #define XLAT_STR_47 STRINGIFY(NT_S390_TDB)
  XLAT(NT_S390_VXRS_LOW),
+ #define XLAT_VAL_48 ((unsigned) (NT_S390_VXRS_LOW))
+ #define XLAT_STR_48 STRINGIFY(NT_S390_VXRS_LOW)
  XLAT(NT_S390_VXRS_HIGH),
+ #define XLAT_VAL_49 ((unsigned) (NT_S390_VXRS_HIGH))
+ #define XLAT_STR_49 STRINGIFY(NT_S390_VXRS_HIGH)
  XLAT(NT_S390_GS_CB),
+ #define XLAT_VAL_50 ((unsigned) (NT_S390_GS_CB))
+ #define XLAT_STR_50 STRINGIFY(NT_S390_GS_CB)
  XLAT(NT_S390_GS_BC),
+ #define XLAT_VAL_51 ((unsigned) (NT_S390_GS_BC))
+ #define XLAT_STR_51 STRINGIFY(NT_S390_GS_BC)
  XLAT(NT_S390_RI_CB),
+ #define XLAT_VAL_52 ((unsigned) (NT_S390_RI_CB))
+ #define XLAT_STR_52 STRINGIFY(NT_S390_RI_CB)
  XLAT(NT_ARM_VFP),
+ #define XLAT_VAL_53 ((unsigned) (NT_ARM_VFP))
+ #define XLAT_STR_53 STRINGIFY(NT_ARM_VFP)
  XLAT(NT_ARM_TLS),
+ #define XLAT_VAL_54 ((unsigned) (NT_ARM_TLS))
+ #define XLAT_STR_54 STRINGIFY(NT_ARM_TLS)
  XLAT(NT_ARM_HW_BREAK),
+ #define XLAT_VAL_55 ((unsigned) (NT_ARM_HW_BREAK))
+ #define XLAT_STR_55 STRINGIFY(NT_ARM_HW_BREAK)
  XLAT(NT_ARM_HW_WATCH),
+ #define XLAT_VAL_56 ((unsigned) (NT_ARM_HW_WATCH))
+ #define XLAT_STR_56 STRINGIFY(NT_ARM_HW_WATCH)
  XLAT(NT_ARM_SYSTEM_CALL),
+ #define XLAT_VAL_57 ((unsigned) (NT_ARM_SYSTEM_CALL))
+ #define XLAT_STR_57 STRINGIFY(NT_ARM_SYSTEM_CALL)
  XLAT(NT_ARM_SVE),
+ #define XLAT_VAL_58 ((unsigned) (NT_ARM_SVE))
+ #define XLAT_STR_58 STRINGIFY(NT_ARM_SVE)
  XLAT(NT_ARM_PAC_MASK),
+ #define XLAT_VAL_59 ((unsigned) (NT_ARM_PAC_MASK))
+ #define XLAT_STR_59 STRINGIFY(NT_ARM_PAC_MASK)
  XLAT(NT_ARM_PACA_KEYS),
+ #define XLAT_VAL_60 ((unsigned) (NT_ARM_PACA_KEYS))
+ #define XLAT_STR_60 STRINGIFY(NT_ARM_PACA_KEYS)
  XLAT(NT_ARM_PACG_KEYS),
+ #define XLAT_VAL_61 ((unsigned) (NT_ARM_PACG_KEYS))
+ #define XLAT_STR_61 STRINGIFY(NT_ARM_PACG_KEYS)
  XLAT(NT_METAG_CBUF),
+ #define XLAT_VAL_62 ((unsigned) (NT_METAG_CBUF))
+ #define XLAT_STR_62 STRINGIFY(NT_METAG_CBUF)
  XLAT(NT_METAG_RPIPE),
+ #define XLAT_VAL_63 ((unsigned) (NT_METAG_RPIPE))
+ #define XLAT_STR_63 STRINGIFY(NT_METAG_RPIPE)
  XLAT(NT_METAG_TLS),
+ #define XLAT_VAL_64 ((unsigned) (NT_METAG_TLS))
+ #define XLAT_STR_64 STRINGIFY(NT_METAG_TLS)
  XLAT(NT_ARC_V2),
+ #define XLAT_VAL_65 ((unsigned) (NT_ARC_V2))
+ #define XLAT_STR_65 STRINGIFY(NT_ARC_V2)
  XLAT(NT_VMCOREDD),
+ #define XLAT_VAL_66 ((unsigned) (NT_VMCOREDD))
+ #define XLAT_STR_66 STRINGIFY(NT_VMCOREDD)
  XLAT(NT_MIPS_DSP),
+ #define XLAT_VAL_67 ((unsigned) (NT_MIPS_DSP))
+ #define XLAT_STR_67 STRINGIFY(NT_MIPS_DSP)
  XLAT(NT_MIPS_FP_MODE),
+ #define XLAT_VAL_68 ((unsigned) (NT_MIPS_FP_MODE))
+ #define XLAT_STR_68 STRINGIFY(NT_MIPS_FP_MODE)
  XLAT(NT_MIPS_MSA),
+ #define XLAT_VAL_69 ((unsigned) (NT_MIPS_MSA))
+ #define XLAT_STR_69 STRINGIFY(NT_MIPS_MSA)
 };
 static
 const struct xlat nt_descriptor_types[1] = { {
  .data = nt_descriptor_types_xdata,
  .size = ARRAY_SIZE(nt_descriptor_types_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+#  ifdef XLAT_VAL_47
+  | XLAT_VAL_47
+#  endif
+#  ifdef XLAT_VAL_48
+  | XLAT_VAL_48
+#  endif
+#  ifdef XLAT_VAL_49
+  | XLAT_VAL_49
+#  endif
+#  ifdef XLAT_VAL_50
+  | XLAT_VAL_50
+#  endif
+#  ifdef XLAT_VAL_51
+  | XLAT_VAL_51
+#  endif
+#  ifdef XLAT_VAL_52
+  | XLAT_VAL_52
+#  endif
+#  ifdef XLAT_VAL_53
+  | XLAT_VAL_53
+#  endif
+#  ifdef XLAT_VAL_54
+  | XLAT_VAL_54
+#  endif
+#  ifdef XLAT_VAL_55
+  | XLAT_VAL_55
+#  endif
+#  ifdef XLAT_VAL_56
+  | XLAT_VAL_56
+#  endif
+#  ifdef XLAT_VAL_57
+  | XLAT_VAL_57
+#  endif
+#  ifdef XLAT_VAL_58
+  | XLAT_VAL_58
+#  endif
+#  ifdef XLAT_VAL_59
+  | XLAT_VAL_59
+#  endif
+#  ifdef XLAT_VAL_60
+  | XLAT_VAL_60
+#  endif
+#  ifdef XLAT_VAL_61
+  | XLAT_VAL_61
+#  endif
+#  ifdef XLAT_VAL_62
+  | XLAT_VAL_62
+#  endif
+#  ifdef XLAT_VAL_63
+  | XLAT_VAL_63
+#  endif
+#  ifdef XLAT_VAL_64
+  | XLAT_VAL_64
+#  endif
+#  ifdef XLAT_VAL_65
+  | XLAT_VAL_65
+#  endif
+#  ifdef XLAT_VAL_66
+  | XLAT_VAL_66
+#  endif
+#  ifdef XLAT_VAL_67
+  | XLAT_VAL_67
+#  endif
+#  ifdef XLAT_VAL_68
+  | XLAT_VAL_68
+#  endif
+#  ifdef XLAT_VAL_69
+  | XLAT_VAL_69
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+#  ifdef XLAT_STR_47
+  + sizeof(XLAT_STR_47)
+#  endif
+#  ifdef XLAT_STR_48
+  + sizeof(XLAT_STR_48)
+#  endif
+#  ifdef XLAT_STR_49
+  + sizeof(XLAT_STR_49)
+#  endif
+#  ifdef XLAT_STR_50
+  + sizeof(XLAT_STR_50)
+#  endif
+#  ifdef XLAT_STR_51
+  + sizeof(XLAT_STR_51)
+#  endif
+#  ifdef XLAT_STR_52
+  + sizeof(XLAT_STR_52)
+#  endif
+#  ifdef XLAT_STR_53
+  + sizeof(XLAT_STR_53)
+#  endif
+#  ifdef XLAT_STR_54
+  + sizeof(XLAT_STR_54)
+#  endif
+#  ifdef XLAT_STR_55
+  + sizeof(XLAT_STR_55)
+#  endif
+#  ifdef XLAT_STR_56
+  + sizeof(XLAT_STR_56)
+#  endif
+#  ifdef XLAT_STR_57
+  + sizeof(XLAT_STR_57)
+#  endif
+#  ifdef XLAT_STR_58
+  + sizeof(XLAT_STR_58)
+#  endif
+#  ifdef XLAT_STR_59
+  + sizeof(XLAT_STR_59)
+#  endif
+#  ifdef XLAT_STR_60
+  + sizeof(XLAT_STR_60)
+#  endif
+#  ifdef XLAT_STR_61
+  + sizeof(XLAT_STR_61)
+#  endif
+#  ifdef XLAT_STR_62
+  + sizeof(XLAT_STR_62)
+#  endif
+#  ifdef XLAT_STR_63
+  + sizeof(XLAT_STR_63)
+#  endif
+#  ifdef XLAT_STR_64
+  + sizeof(XLAT_STR_64)
+#  endif
+#  ifdef XLAT_STR_65
+  + sizeof(XLAT_STR_65)
+#  endif
+#  ifdef XLAT_STR_66
+  + sizeof(XLAT_STR_66)
+#  endif
+#  ifdef XLAT_STR_67
+  + sizeof(XLAT_STR_67)
+#  endif
+#  ifdef XLAT_STR_68
+  + sizeof(XLAT_STR_68)
+#  endif
+#  ifdef XLAT_STR_69
+  + sizeof(XLAT_STR_69)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
+#  undef XLAT_STR_47
+#  undef XLAT_VAL_47
+#  undef XLAT_STR_48
+#  undef XLAT_VAL_48
+#  undef XLAT_STR_49
+#  undef XLAT_VAL_49
+#  undef XLAT_STR_50
+#  undef XLAT_VAL_50
+#  undef XLAT_STR_51
+#  undef XLAT_VAL_51
+#  undef XLAT_STR_52
+#  undef XLAT_VAL_52
+#  undef XLAT_STR_53
+#  undef XLAT_VAL_53
+#  undef XLAT_STR_54
+#  undef XLAT_VAL_54
+#  undef XLAT_STR_55
+#  undef XLAT_VAL_55
+#  undef XLAT_STR_56
+#  undef XLAT_VAL_56
+#  undef XLAT_STR_57
+#  undef XLAT_VAL_57
+#  undef XLAT_STR_58
+#  undef XLAT_VAL_58
+#  undef XLAT_STR_59
+#  undef XLAT_VAL_59
+#  undef XLAT_STR_60
+#  undef XLAT_VAL_60
+#  undef XLAT_STR_61
+#  undef XLAT_VAL_61
+#  undef XLAT_STR_62
+#  undef XLAT_VAL_62
+#  undef XLAT_STR_63
+#  undef XLAT_VAL_63
+#  undef XLAT_STR_64
+#  undef XLAT_VAL_64
+#  undef XLAT_STR_65
+#  undef XLAT_VAL_65
+#  undef XLAT_STR_66
+#  undef XLAT_VAL_66
+#  undef XLAT_STR_67
+#  undef XLAT_VAL_67
+#  undef XLAT_STR_68
+#  undef XLAT_VAL_68
+#  undef XLAT_STR_69
+#  undef XLAT_VAL_69
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/numa_node.h 5.9-0ubuntu2/xlat/numa_node.h
--- 5.5-3/xlat/numa_node.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/numa_node.h	2020-09-24 09:18:45.000000000 +0000
@@ -21,14 +21,28 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data numa_node_xdata[] = {
  XLAT(NUMA_NO_NODE),
+ #define XLAT_VAL_0 ((unsigned) (NUMA_NO_NODE))
+ #define XLAT_STR_0 STRINGIFY(NUMA_NO_NODE)
 };
 static
 const struct xlat numa_node[1] = { {
  .data = numa_node_xdata,
  .size = ARRAY_SIZE(numa_node_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/open_access_modes.h 5.9-0ubuntu2/xlat/open_access_modes.h
--- 5.5-3/xlat/open_access_modes.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/open_access_modes.h	2020-09-24 09:18:45.000000000 +0000
@@ -38,16 +38,60 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data open_access_modes_xdata[] = {
  [O_RDONLY] = XLAT(O_RDONLY),
+ #define XLAT_VAL_0 ((unsigned) (O_RDONLY))
+ #define XLAT_STR_0 STRINGIFY(O_RDONLY)
  [O_WRONLY] = XLAT(O_WRONLY),
+ #define XLAT_VAL_1 ((unsigned) (O_WRONLY))
+ #define XLAT_STR_1 STRINGIFY(O_WRONLY)
  [O_RDWR] = XLAT(O_RDWR),
+ #define XLAT_VAL_2 ((unsigned) (O_RDWR))
+ #define XLAT_STR_2 STRINGIFY(O_RDWR)
  [O_ACCMODE] = XLAT(O_ACCMODE),
+ #define XLAT_VAL_3 ((unsigned) (O_ACCMODE))
+ #define XLAT_STR_3 STRINGIFY(O_ACCMODE)
 };
 const struct xlat open_access_modes[1] = { {
  .data = open_access_modes_xdata,
  .size = ARRAY_SIZE(open_access_modes_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/open_mode_flags.h 5.9-0ubuntu2/xlat/open_mode_flags.h
--- 5.5-3/xlat/open_mode_flags.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/open_mode_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -592,94 +592,162 @@ static const struct xlat_data open_mode_
 
 #if defined __hppa__ || defined __mips__
  XLAT(O_CREAT),
+ #define XLAT_VAL_0 ((unsigned) (O_CREAT))
+ #define XLAT_STR_0 STRINGIFY(O_CREAT)
 #elif defined __alpha__ || defined __sparc__
  XLAT(O_CREAT),
+ #define XLAT_VAL_1 ((unsigned) (O_CREAT))
+ #define XLAT_STR_1 STRINGIFY(O_CREAT)
 #else
  XLAT(O_CREAT),
+ #define XLAT_VAL_2 ((unsigned) (O_CREAT))
+ #define XLAT_STR_2 STRINGIFY(O_CREAT)
 #endif
 
 #if defined __hppa__ || defined __mips__
  XLAT(O_EXCL),
+ #define XLAT_VAL_3 ((unsigned) (O_EXCL))
+ #define XLAT_STR_3 STRINGIFY(O_EXCL)
 #elif defined __alpha__ || defined __sparc__
  XLAT(O_EXCL),
+ #define XLAT_VAL_4 ((unsigned) (O_EXCL))
+ #define XLAT_STR_4 STRINGIFY(O_EXCL)
 #else
  XLAT(O_EXCL),
+ #define XLAT_VAL_5 ((unsigned) (O_EXCL))
+ #define XLAT_STR_5 STRINGIFY(O_EXCL)
 #endif
 
 #if defined __mips__
  XLAT(O_NOCTTY),
+ #define XLAT_VAL_6 ((unsigned) (O_NOCTTY))
+ #define XLAT_STR_6 STRINGIFY(O_NOCTTY)
 #elif defined __alpha__
  XLAT(O_NOCTTY),
+ #define XLAT_VAL_7 ((unsigned) (O_NOCTTY))
+ #define XLAT_STR_7 STRINGIFY(O_NOCTTY)
 #elif defined __sparc__
  XLAT(O_NOCTTY),
+ #define XLAT_VAL_8 ((unsigned) (O_NOCTTY))
+ #define XLAT_STR_8 STRINGIFY(O_NOCTTY)
 #elif defined __hppa__
  XLAT(O_NOCTTY),
+ #define XLAT_VAL_9 ((unsigned) (O_NOCTTY))
+ #define XLAT_STR_9 STRINGIFY(O_NOCTTY)
 #else
  XLAT(O_NOCTTY),
+ #define XLAT_VAL_10 ((unsigned) (O_NOCTTY))
+ #define XLAT_STR_10 STRINGIFY(O_NOCTTY)
 #endif
 
 #if defined __alpha__ || defined __sparc__
  XLAT(O_TRUNC),
+ #define XLAT_VAL_11 ((unsigned) (O_TRUNC))
+ #define XLAT_STR_11 STRINGIFY(O_TRUNC)
 #else
  XLAT(O_TRUNC),
+ #define XLAT_VAL_12 ((unsigned) (O_TRUNC))
+ #define XLAT_STR_12 STRINGIFY(O_TRUNC)
 #endif
 
 #if defined __alpha__ || defined __hppa__ || defined __mips__ || defined __sparc__
  XLAT(O_APPEND),
+ #define XLAT_VAL_13 ((unsigned) (O_APPEND))
+ #define XLAT_STR_13 STRINGIFY(O_APPEND)
 #else
  XLAT(O_APPEND),
+ #define XLAT_VAL_14 ((unsigned) (O_APPEND))
+ #define XLAT_STR_14 STRINGIFY(O_APPEND)
 #endif
 
 #if defined __alpha__
  XLAT(O_NONBLOCK),
+ #define XLAT_VAL_15 ((unsigned) (O_NONBLOCK))
+ #define XLAT_STR_15 STRINGIFY(O_NONBLOCK)
 #elif defined __mips__
  XLAT(O_NONBLOCK),
+ #define XLAT_VAL_16 ((unsigned) (O_NONBLOCK))
+ #define XLAT_STR_16 STRINGIFY(O_NONBLOCK)
 #elif defined __sparc__
  XLAT(O_NONBLOCK),
+ #define XLAT_VAL_17 ((unsigned) (O_NONBLOCK))
+ #define XLAT_STR_17 STRINGIFY(O_NONBLOCK)
 #elif defined __hppa__
  XLAT(O_NONBLOCK),
+ #define XLAT_VAL_18 ((unsigned) (O_NONBLOCK))
+ #define XLAT_STR_18 STRINGIFY(O_NONBLOCK)
 #else
  XLAT(O_NONBLOCK),
+ #define XLAT_VAL_19 ((unsigned) (O_NONBLOCK))
+ #define XLAT_STR_19 STRINGIFY(O_NONBLOCK)
 #endif
 
 
 #if defined(O_SYNC) || (defined(HAVE_DECL_O_SYNC) && HAVE_DECL_O_SYNC)
   XLAT(O_SYNC),
+ #define XLAT_VAL_20 ((unsigned) (O_SYNC))
+ #define XLAT_STR_20 STRINGIFY(O_SYNC)
 #endif
 
 #if defined __mips__
  XLAT(__O_SYNC),
+ #define XLAT_VAL_21 ((unsigned) (__O_SYNC))
+ #define XLAT_STR_21 STRINGIFY(__O_SYNC)
 #elif defined __hppa__
  XLAT(__O_SYNC),
+ #define XLAT_VAL_22 ((unsigned) (__O_SYNC))
+ #define XLAT_STR_22 STRINGIFY(__O_SYNC)
 #elif defined __alpha__
  XLAT(__O_SYNC),
+ #define XLAT_VAL_23 ((unsigned) (__O_SYNC))
+ #define XLAT_STR_23 STRINGIFY(__O_SYNC)
 #elif defined __sparc__
  XLAT(__O_SYNC),
+ #define XLAT_VAL_24 ((unsigned) (__O_SYNC))
+ #define XLAT_STR_24 STRINGIFY(__O_SYNC)
 #else
  XLAT(__O_SYNC),
+ #define XLAT_VAL_25 ((unsigned) (__O_SYNC))
+ #define XLAT_STR_25 STRINGIFY(__O_SYNC)
 #endif
 
 #if defined(O_ASYNC) || (defined(HAVE_DECL_O_ASYNC) && HAVE_DECL_O_ASYNC)
   XLAT(O_ASYNC),
+ #define XLAT_VAL_26 ((unsigned) (O_ASYNC))
+ #define XLAT_STR_26 STRINGIFY(O_ASYNC)
 #endif
 
 #if defined __mips__
  XLAT(O_DSYNC),
+ #define XLAT_VAL_27 ((unsigned) (O_DSYNC))
+ #define XLAT_STR_27 STRINGIFY(O_DSYNC)
 #elif defined __sparc__
  XLAT(O_DSYNC),
+ #define XLAT_VAL_28 ((unsigned) (O_DSYNC))
+ #define XLAT_STR_28 STRINGIFY(O_DSYNC)
 #elif defined __alpha__
  XLAT(O_DSYNC),
+ #define XLAT_VAL_29 ((unsigned) (O_DSYNC))
+ #define XLAT_STR_29 STRINGIFY(O_DSYNC)
 #elif defined __hppa__
  XLAT(O_DSYNC),
+ #define XLAT_VAL_30 ((unsigned) (O_DSYNC))
+ #define XLAT_STR_30 STRINGIFY(O_DSYNC)
 #else
  XLAT(O_DSYNC),
+ #define XLAT_VAL_31 ((unsigned) (O_DSYNC))
+ #define XLAT_STR_31 STRINGIFY(O_DSYNC)
 #endif
 
 #if defined __hppa__
  XLAT(O_RSYNC),
+ #define XLAT_VAL_32 ((unsigned) (O_RSYNC))
+ #define XLAT_STR_32 STRINGIFY(O_RSYNC)
 #else
 #if defined(O_RSYNC) || (defined(HAVE_DECL_O_RSYNC) && HAVE_DECL_O_RSYNC)
   XLAT(O_RSYNC),
+ #define XLAT_VAL_33 ((unsigned) (O_RSYNC))
+ #define XLAT_STR_33 STRINGIFY(O_RSYNC)
 #endif
 #endif
 
@@ -695,115 +763,791 @@ static const struct xlat_data open_mode_
 
 #if defined __sparc__
  XLAT(O_NDELAY),
+ #define XLAT_VAL_34 ((unsigned) (O_NDELAY))
+ #define XLAT_STR_34 STRINGIFY(O_NDELAY)
 #else
 #if defined(O_NDELAY) || (defined(HAVE_DECL_O_NDELAY) && HAVE_DECL_O_NDELAY)
   XLAT(O_NDELAY),
+ #define XLAT_VAL_35 ((unsigned) (O_NDELAY))
+ #define XLAT_STR_35 STRINGIFY(O_NDELAY)
 #endif
 #endif
 
 #if defined __sparc__
  XLAT(O_DIRECT),
+ #define XLAT_VAL_36 ((unsigned) (O_DIRECT))
+ #define XLAT_STR_36 STRINGIFY(O_DIRECT)
 #elif defined __mips__
  XLAT(O_DIRECT),
+ #define XLAT_VAL_37 ((unsigned) (O_DIRECT))
+ #define XLAT_STR_37 STRINGIFY(O_DIRECT)
 #elif defined __arm__ || defined __arm64__ || defined __aarch64__ || defined __m68k__
  XLAT(O_DIRECT),
+ #define XLAT_VAL_38 ((unsigned) (O_DIRECT))
+ #define XLAT_STR_38 STRINGIFY(O_DIRECT)
 #elif defined __powerpc__
  XLAT(O_DIRECT),
+ #define XLAT_VAL_39 ((unsigned) (O_DIRECT))
+ #define XLAT_STR_39 STRINGIFY(O_DIRECT)
 #elif defined __alpha__
  XLAT(O_DIRECT),
+ #define XLAT_VAL_40 ((unsigned) (O_DIRECT))
+ #define XLAT_STR_40 STRINGIFY(O_DIRECT)
 #else
  XLAT(O_DIRECT),
+ #define XLAT_VAL_41 ((unsigned) (O_DIRECT))
+ #define XLAT_STR_41 STRINGIFY(O_DIRECT)
 #endif
 
 #if defined __hppa__
  XLAT(O_LARGEFILE),
+ #define XLAT_VAL_42 ((unsigned) (O_LARGEFILE))
+ #define XLAT_STR_42 STRINGIFY(O_LARGEFILE)
 #elif defined __mips__
  XLAT(O_LARGEFILE),
+ #define XLAT_VAL_43 ((unsigned) (O_LARGEFILE))
+ #define XLAT_STR_43 STRINGIFY(O_LARGEFILE)
 #elif defined __powerpc__
  XLAT(O_LARGEFILE),
+ #define XLAT_VAL_44 ((unsigned) (O_LARGEFILE))
+ #define XLAT_STR_44 STRINGIFY(O_LARGEFILE)
 #elif defined __alpha__ || defined __arm__ || defined __arm64__ || defined __aarch64__ || defined __m68k__
  XLAT(O_LARGEFILE),
+ #define XLAT_VAL_45 ((unsigned) (O_LARGEFILE))
+ #define XLAT_STR_45 STRINGIFY(O_LARGEFILE)
 #elif defined __sparc__
  XLAT(O_LARGEFILE),
+ #define XLAT_VAL_46 ((unsigned) (O_LARGEFILE))
+ #define XLAT_STR_46 STRINGIFY(O_LARGEFILE)
 #else
  XLAT(O_LARGEFILE),
+ #define XLAT_VAL_47 ((unsigned) (O_LARGEFILE))
+ #define XLAT_STR_47 STRINGIFY(O_LARGEFILE)
 #endif
 
 #if defined __hppa__
  XLAT(O_NOFOLLOW),
+ #define XLAT_VAL_48 ((unsigned) (O_NOFOLLOW))
+ #define XLAT_STR_48 STRINGIFY(O_NOFOLLOW)
 #elif defined __arm__ || defined __arm64__ || defined __aarch64__ || defined __m68k__ || defined __powerpc__
  XLAT(O_NOFOLLOW),
+ #define XLAT_VAL_49 ((unsigned) (O_NOFOLLOW))
+ #define XLAT_STR_49 STRINGIFY(O_NOFOLLOW)
 #elif defined __alpha__
  XLAT(O_NOFOLLOW),
+ #define XLAT_VAL_50 ((unsigned) (O_NOFOLLOW))
+ #define XLAT_STR_50 STRINGIFY(O_NOFOLLOW)
 #else
  XLAT(O_NOFOLLOW),
+ #define XLAT_VAL_51 ((unsigned) (O_NOFOLLOW))
+ #define XLAT_STR_51 STRINGIFY(O_NOFOLLOW)
 #endif
 
 #if defined __alpha__ || defined __hppa__
  XLAT(O_NOATIME),
+ #define XLAT_VAL_52 ((unsigned) (O_NOATIME))
+ #define XLAT_STR_52 STRINGIFY(O_NOATIME)
 #elif defined __sparc__
  XLAT(O_NOATIME),
+ #define XLAT_VAL_53 ((unsigned) (O_NOATIME))
+ #define XLAT_STR_53 STRINGIFY(O_NOATIME)
 #else
  XLAT(O_NOATIME),
+ #define XLAT_VAL_54 ((unsigned) (O_NOATIME))
+ #define XLAT_STR_54 STRINGIFY(O_NOATIME)
 #endif
 
 #if defined __alpha__ || defined __hppa__
  XLAT(O_CLOEXEC),
+ #define XLAT_VAL_55 ((unsigned) (O_CLOEXEC))
+ #define XLAT_STR_55 STRINGIFY(O_CLOEXEC)
 #elif defined __sparc__
  XLAT(O_CLOEXEC),
+ #define XLAT_VAL_56 ((unsigned) (O_CLOEXEC))
+ #define XLAT_STR_56 STRINGIFY(O_CLOEXEC)
 #else
  XLAT(O_CLOEXEC),
+ #define XLAT_VAL_57 ((unsigned) (O_CLOEXEC))
+ #define XLAT_STR_57 STRINGIFY(O_CLOEXEC)
 #endif
 
 #if defined __hppa__
  XLAT(O_PATH),
+ #define XLAT_VAL_58 ((unsigned) (O_PATH))
+ #define XLAT_STR_58 STRINGIFY(O_PATH)
 #elif defined __alpha__
  XLAT(O_PATH),
+ #define XLAT_VAL_59 ((unsigned) (O_PATH))
+ #define XLAT_STR_59 STRINGIFY(O_PATH)
 #elif defined __sparc__
  XLAT(O_PATH),
+ #define XLAT_VAL_60 ((unsigned) (O_PATH))
+ #define XLAT_STR_60 STRINGIFY(O_PATH)
 #else
  XLAT(O_PATH),
+ #define XLAT_VAL_61 ((unsigned) (O_PATH))
+ #define XLAT_STR_61 STRINGIFY(O_PATH)
 #endif
 
 
 #if defined(O_TMPFILE) || (defined(HAVE_DECL_O_TMPFILE) && HAVE_DECL_O_TMPFILE)
   XLAT(O_TMPFILE),
+ #define XLAT_VAL_62 ((unsigned) (O_TMPFILE))
+ #define XLAT_STR_62 STRINGIFY(O_TMPFILE)
 #endif
 
 #if defined __hppa__
  XLAT(__O_TMPFILE),
+ #define XLAT_VAL_63 ((unsigned) (__O_TMPFILE))
+ #define XLAT_STR_63 STRINGIFY(__O_TMPFILE)
 #elif defined __alpha__
  XLAT(__O_TMPFILE),
+ #define XLAT_VAL_64 ((unsigned) (__O_TMPFILE))
+ #define XLAT_STR_64 STRINGIFY(__O_TMPFILE)
 #elif defined __sparc__
  XLAT(__O_TMPFILE),
+ #define XLAT_VAL_65 ((unsigned) (__O_TMPFILE))
+ #define XLAT_STR_65 STRINGIFY(__O_TMPFILE)
 #else
  XLAT(__O_TMPFILE),
+ #define XLAT_VAL_66 ((unsigned) (__O_TMPFILE))
+ #define XLAT_STR_66 STRINGIFY(__O_TMPFILE)
 #endif
 
 #if defined __hppa__
  XLAT(O_DIRECTORY),
+ #define XLAT_VAL_67 ((unsigned) (O_DIRECTORY))
+ #define XLAT_STR_67 STRINGIFY(O_DIRECTORY)
 #elif defined __arm__ || defined __arm64__ || defined __aarch64__ || defined __m68k__ || defined __powerpc__
  XLAT(O_DIRECTORY),
+ #define XLAT_VAL_68 ((unsigned) (O_DIRECTORY))
+ #define XLAT_STR_68 STRINGIFY(O_DIRECTORY)
 #elif defined __alpha__
  XLAT(O_DIRECTORY),
+ #define XLAT_VAL_69 ((unsigned) (O_DIRECTORY))
+ #define XLAT_STR_69 STRINGIFY(O_DIRECTORY)
 #else
  XLAT(O_DIRECTORY),
+ #define XLAT_VAL_70 ((unsigned) (O_DIRECTORY))
+ #define XLAT_STR_70 STRINGIFY(O_DIRECTORY)
 #endif
 
 #if defined __sparc__
  XLAT(FASYNC),
+ #define XLAT_VAL_71 ((unsigned) (FASYNC))
+ #define XLAT_STR_71 STRINGIFY(FASYNC)
 #elif defined __mips__
  XLAT(FASYNC),
+ #define XLAT_VAL_72 ((unsigned) (FASYNC))
+ #define XLAT_STR_72 STRINGIFY(FASYNC)
 #else
  XLAT(FASYNC),
+ #define XLAT_VAL_73 ((unsigned) (FASYNC))
+ #define XLAT_STR_73 STRINGIFY(FASYNC)
 #endif
 };
 const struct xlat open_mode_flags[1] = { {
  .data = open_mode_flags_xdata,
  .size = ARRAY_SIZE(open_mode_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+#  ifdef XLAT_VAL_47
+  | XLAT_VAL_47
+#  endif
+#  ifdef XLAT_VAL_48
+  | XLAT_VAL_48
+#  endif
+#  ifdef XLAT_VAL_49
+  | XLAT_VAL_49
+#  endif
+#  ifdef XLAT_VAL_50
+  | XLAT_VAL_50
+#  endif
+#  ifdef XLAT_VAL_51
+  | XLAT_VAL_51
+#  endif
+#  ifdef XLAT_VAL_52
+  | XLAT_VAL_52
+#  endif
+#  ifdef XLAT_VAL_53
+  | XLAT_VAL_53
+#  endif
+#  ifdef XLAT_VAL_54
+  | XLAT_VAL_54
+#  endif
+#  ifdef XLAT_VAL_55
+  | XLAT_VAL_55
+#  endif
+#  ifdef XLAT_VAL_56
+  | XLAT_VAL_56
+#  endif
+#  ifdef XLAT_VAL_57
+  | XLAT_VAL_57
+#  endif
+#  ifdef XLAT_VAL_58
+  | XLAT_VAL_58
+#  endif
+#  ifdef XLAT_VAL_59
+  | XLAT_VAL_59
+#  endif
+#  ifdef XLAT_VAL_60
+  | XLAT_VAL_60
+#  endif
+#  ifdef XLAT_VAL_61
+  | XLAT_VAL_61
+#  endif
+#  ifdef XLAT_VAL_62
+  | XLAT_VAL_62
+#  endif
+#  ifdef XLAT_VAL_63
+  | XLAT_VAL_63
+#  endif
+#  ifdef XLAT_VAL_64
+  | XLAT_VAL_64
+#  endif
+#  ifdef XLAT_VAL_65
+  | XLAT_VAL_65
+#  endif
+#  ifdef XLAT_VAL_66
+  | XLAT_VAL_66
+#  endif
+#  ifdef XLAT_VAL_67
+  | XLAT_VAL_67
+#  endif
+#  ifdef XLAT_VAL_68
+  | XLAT_VAL_68
+#  endif
+#  ifdef XLAT_VAL_69
+  | XLAT_VAL_69
+#  endif
+#  ifdef XLAT_VAL_70
+  | XLAT_VAL_70
+#  endif
+#  ifdef XLAT_VAL_71
+  | XLAT_VAL_71
+#  endif
+#  ifdef XLAT_VAL_72
+  | XLAT_VAL_72
+#  endif
+#  ifdef XLAT_VAL_73
+  | XLAT_VAL_73
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+#  ifdef XLAT_STR_47
+  + sizeof(XLAT_STR_47)
+#  endif
+#  ifdef XLAT_STR_48
+  + sizeof(XLAT_STR_48)
+#  endif
+#  ifdef XLAT_STR_49
+  + sizeof(XLAT_STR_49)
+#  endif
+#  ifdef XLAT_STR_50
+  + sizeof(XLAT_STR_50)
+#  endif
+#  ifdef XLAT_STR_51
+  + sizeof(XLAT_STR_51)
+#  endif
+#  ifdef XLAT_STR_52
+  + sizeof(XLAT_STR_52)
+#  endif
+#  ifdef XLAT_STR_53
+  + sizeof(XLAT_STR_53)
+#  endif
+#  ifdef XLAT_STR_54
+  + sizeof(XLAT_STR_54)
+#  endif
+#  ifdef XLAT_STR_55
+  + sizeof(XLAT_STR_55)
+#  endif
+#  ifdef XLAT_STR_56
+  + sizeof(XLAT_STR_56)
+#  endif
+#  ifdef XLAT_STR_57
+  + sizeof(XLAT_STR_57)
+#  endif
+#  ifdef XLAT_STR_58
+  + sizeof(XLAT_STR_58)
+#  endif
+#  ifdef XLAT_STR_59
+  + sizeof(XLAT_STR_59)
+#  endif
+#  ifdef XLAT_STR_60
+  + sizeof(XLAT_STR_60)
+#  endif
+#  ifdef XLAT_STR_61
+  + sizeof(XLAT_STR_61)
+#  endif
+#  ifdef XLAT_STR_62
+  + sizeof(XLAT_STR_62)
+#  endif
+#  ifdef XLAT_STR_63
+  + sizeof(XLAT_STR_63)
+#  endif
+#  ifdef XLAT_STR_64
+  + sizeof(XLAT_STR_64)
+#  endif
+#  ifdef XLAT_STR_65
+  + sizeof(XLAT_STR_65)
+#  endif
+#  ifdef XLAT_STR_66
+  + sizeof(XLAT_STR_66)
+#  endif
+#  ifdef XLAT_STR_67
+  + sizeof(XLAT_STR_67)
+#  endif
+#  ifdef XLAT_STR_68
+  + sizeof(XLAT_STR_68)
+#  endif
+#  ifdef XLAT_STR_69
+  + sizeof(XLAT_STR_69)
+#  endif
+#  ifdef XLAT_STR_70
+  + sizeof(XLAT_STR_70)
+#  endif
+#  ifdef XLAT_STR_71
+  + sizeof(XLAT_STR_71)
+#  endif
+#  ifdef XLAT_STR_72
+  + sizeof(XLAT_STR_72)
+#  endif
+#  ifdef XLAT_STR_73
+  + sizeof(XLAT_STR_73)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
+#  undef XLAT_STR_47
+#  undef XLAT_VAL_47
+#  undef XLAT_STR_48
+#  undef XLAT_VAL_48
+#  undef XLAT_STR_49
+#  undef XLAT_VAL_49
+#  undef XLAT_STR_50
+#  undef XLAT_VAL_50
+#  undef XLAT_STR_51
+#  undef XLAT_VAL_51
+#  undef XLAT_STR_52
+#  undef XLAT_VAL_52
+#  undef XLAT_STR_53
+#  undef XLAT_VAL_53
+#  undef XLAT_STR_54
+#  undef XLAT_VAL_54
+#  undef XLAT_STR_55
+#  undef XLAT_VAL_55
+#  undef XLAT_STR_56
+#  undef XLAT_VAL_56
+#  undef XLAT_STR_57
+#  undef XLAT_VAL_57
+#  undef XLAT_STR_58
+#  undef XLAT_VAL_58
+#  undef XLAT_STR_59
+#  undef XLAT_VAL_59
+#  undef XLAT_STR_60
+#  undef XLAT_VAL_60
+#  undef XLAT_STR_61
+#  undef XLAT_VAL_61
+#  undef XLAT_STR_62
+#  undef XLAT_VAL_62
+#  undef XLAT_STR_63
+#  undef XLAT_VAL_63
+#  undef XLAT_STR_64
+#  undef XLAT_VAL_64
+#  undef XLAT_STR_65
+#  undef XLAT_VAL_65
+#  undef XLAT_STR_66
+#  undef XLAT_VAL_66
+#  undef XLAT_STR_67
+#  undef XLAT_VAL_67
+#  undef XLAT_STR_68
+#  undef XLAT_VAL_68
+#  undef XLAT_STR_69
+#  undef XLAT_VAL_69
+#  undef XLAT_STR_70
+#  undef XLAT_VAL_70
+#  undef XLAT_STR_71
+#  undef XLAT_VAL_71
+#  undef XLAT_STR_72
+#  undef XLAT_VAL_72
+#  undef XLAT_STR_73
+#  undef XLAT_VAL_73
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/open_resolve_flags.h 5.9-0ubuntu2/xlat/open_resolve_flags.h
--- 5.5-3/xlat/open_resolve_flags.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/open_resolve_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -0,0 +1,120 @@
+/* Generated by ./xlat/gen.sh from ./xlat/open_resolve_flags.in; do not edit. */
+
+#include "gcc_compat.h"
+#include "static_assert.h"
+
+#if defined(RESOLVE_NO_XDEV) || (defined(HAVE_DECL_RESOLVE_NO_XDEV) && HAVE_DECL_RESOLVE_NO_XDEV)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RESOLVE_NO_XDEV) == (0x01), "RESOLVE_NO_XDEV != 0x01");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RESOLVE_NO_XDEV 0x01
+#endif
+#if defined(RESOLVE_NO_MAGICLINKS) || (defined(HAVE_DECL_RESOLVE_NO_MAGICLINKS) && HAVE_DECL_RESOLVE_NO_MAGICLINKS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RESOLVE_NO_MAGICLINKS) == (0x02), "RESOLVE_NO_MAGICLINKS != 0x02");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RESOLVE_NO_MAGICLINKS 0x02
+#endif
+#if defined(RESOLVE_NO_SYMLINKS) || (defined(HAVE_DECL_RESOLVE_NO_SYMLINKS) && HAVE_DECL_RESOLVE_NO_SYMLINKS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RESOLVE_NO_SYMLINKS) == (0x04), "RESOLVE_NO_SYMLINKS != 0x04");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RESOLVE_NO_SYMLINKS 0x04
+#endif
+#if defined(RESOLVE_BENEATH) || (defined(HAVE_DECL_RESOLVE_BENEATH) && HAVE_DECL_RESOLVE_BENEATH)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RESOLVE_BENEATH) == (0x08), "RESOLVE_BENEATH != 0x08");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RESOLVE_BENEATH 0x08
+#endif
+#if defined(RESOLVE_IN_ROOT) || (defined(HAVE_DECL_RESOLVE_IN_ROOT) && HAVE_DECL_RESOLVE_IN_ROOT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RESOLVE_IN_ROOT) == (0x10), "RESOLVE_IN_ROOT != 0x10");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RESOLVE_IN_ROOT 0x10
+#endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+#  error static const struct xlat open_resolve_flags in mpers mode
+
+# else
+
+static const struct xlat_data open_resolve_flags_xdata[] = {
+ XLAT(RESOLVE_NO_XDEV),
+ #define XLAT_VAL_0 ((unsigned) (RESOLVE_NO_XDEV))
+ #define XLAT_STR_0 STRINGIFY(RESOLVE_NO_XDEV)
+ XLAT(RESOLVE_NO_MAGICLINKS),
+ #define XLAT_VAL_1 ((unsigned) (RESOLVE_NO_MAGICLINKS))
+ #define XLAT_STR_1 STRINGIFY(RESOLVE_NO_MAGICLINKS)
+ XLAT(RESOLVE_NO_SYMLINKS),
+ #define XLAT_VAL_2 ((unsigned) (RESOLVE_NO_SYMLINKS))
+ #define XLAT_STR_2 STRINGIFY(RESOLVE_NO_SYMLINKS)
+ XLAT(RESOLVE_BENEATH),
+ #define XLAT_VAL_3 ((unsigned) (RESOLVE_BENEATH))
+ #define XLAT_STR_3 STRINGIFY(RESOLVE_BENEATH)
+ XLAT(RESOLVE_IN_ROOT),
+ #define XLAT_VAL_4 ((unsigned) (RESOLVE_IN_ROOT))
+ #define XLAT_STR_4 STRINGIFY(RESOLVE_IN_ROOT)
+};
+static
+const struct xlat open_resolve_flags[1] = { {
+ .data = open_resolve_flags_xdata,
+ .size = ARRAY_SIZE(open_resolve_flags_xdata),
+ .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
+} };
+
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+# endif /* !IN_MPERS */
+
+#endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/open_resolve_flags.in 5.9-0ubuntu2/xlat/open_resolve_flags.in
--- 5.5-3/xlat/open_resolve_flags.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/open_resolve_flags.in	2020-03-30 21:14:24.000000000 +0000
@@ -0,0 +1,5 @@
+RESOLVE_NO_XDEV		0x01
+RESOLVE_NO_MAGICLINKS	0x02
+RESOLVE_NO_SYMLINKS	0x04
+RESOLVE_BENEATH		0x08
+RESOLVE_IN_ROOT		0x10
diff -pruN 5.5-3/xlat/open_tree_flags.h 5.9-0ubuntu2/xlat/open_tree_flags.h
--- 5.5-3/xlat/open_tree_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/open_tree_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -72,23 +72,107 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data open_tree_flags_xdata[] = {
  XLAT(OPEN_TREE_CLONE),
+ #define XLAT_VAL_0 ((unsigned) (OPEN_TREE_CLONE))
+ #define XLAT_STR_0 STRINGIFY(OPEN_TREE_CLONE)
 #if defined OPEN_TREE_CLOEXEC || defined O_CLOEXEC
  XLAT(OPEN_TREE_CLOEXEC),
+ #define XLAT_VAL_1 ((unsigned) (OPEN_TREE_CLOEXEC))
+ #define XLAT_STR_1 STRINGIFY(OPEN_TREE_CLOEXEC)
 #endif
  XLAT(AT_SYMLINK_NOFOLLOW),
+ #define XLAT_VAL_2 ((unsigned) (AT_SYMLINK_NOFOLLOW))
+ #define XLAT_STR_2 STRINGIFY(AT_SYMLINK_NOFOLLOW)
  XLAT(AT_REMOVEDIR),
+ #define XLAT_VAL_3 ((unsigned) (AT_REMOVEDIR))
+ #define XLAT_STR_3 STRINGIFY(AT_REMOVEDIR)
  XLAT(AT_SYMLINK_FOLLOW),
+ #define XLAT_VAL_4 ((unsigned) (AT_SYMLINK_FOLLOW))
+ #define XLAT_STR_4 STRINGIFY(AT_SYMLINK_FOLLOW)
  XLAT(AT_NO_AUTOMOUNT),
+ #define XLAT_VAL_5 ((unsigned) (AT_NO_AUTOMOUNT))
+ #define XLAT_STR_5 STRINGIFY(AT_NO_AUTOMOUNT)
  XLAT(AT_EMPTY_PATH),
+ #define XLAT_VAL_6 ((unsigned) (AT_EMPTY_PATH))
+ #define XLAT_STR_6 STRINGIFY(AT_EMPTY_PATH)
  XLAT(AT_RECURSIVE),
+ #define XLAT_VAL_7 ((unsigned) (AT_RECURSIVE))
+ #define XLAT_STR_7 STRINGIFY(AT_RECURSIVE)
 };
 static
 const struct xlat open_tree_flags[1] = { {
  .data = open_tree_flags_xdata,
  .size = ARRAY_SIZE(open_tree_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/packet_diag_attrs.h 5.9-0ubuntu2/xlat/packet_diag_attrs.h
--- 5.5-3/xlat/packet_diag_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/packet_diag_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -14,21 +14,105 @@
 
 static const struct xlat_data packet_diag_attrs_xdata[] = {
  XLAT(PACKET_DIAG_INFO),
+ #define XLAT_VAL_0 ((unsigned) (PACKET_DIAG_INFO))
+ #define XLAT_STR_0 STRINGIFY(PACKET_DIAG_INFO)
  XLAT(PACKET_DIAG_MCLIST),
+ #define XLAT_VAL_1 ((unsigned) (PACKET_DIAG_MCLIST))
+ #define XLAT_STR_1 STRINGIFY(PACKET_DIAG_MCLIST)
  XLAT(PACKET_DIAG_RX_RING),
+ #define XLAT_VAL_2 ((unsigned) (PACKET_DIAG_RX_RING))
+ #define XLAT_STR_2 STRINGIFY(PACKET_DIAG_RX_RING)
  XLAT(PACKET_DIAG_TX_RING),
+ #define XLAT_VAL_3 ((unsigned) (PACKET_DIAG_TX_RING))
+ #define XLAT_STR_3 STRINGIFY(PACKET_DIAG_TX_RING)
  XLAT(PACKET_DIAG_FANOUT),
+ #define XLAT_VAL_4 ((unsigned) (PACKET_DIAG_FANOUT))
+ #define XLAT_STR_4 STRINGIFY(PACKET_DIAG_FANOUT)
  XLAT(PACKET_DIAG_UID),
+ #define XLAT_VAL_5 ((unsigned) (PACKET_DIAG_UID))
+ #define XLAT_STR_5 STRINGIFY(PACKET_DIAG_UID)
  XLAT(PACKET_DIAG_MEMINFO),
+ #define XLAT_VAL_6 ((unsigned) (PACKET_DIAG_MEMINFO))
+ #define XLAT_STR_6 STRINGIFY(PACKET_DIAG_MEMINFO)
  XLAT(PACKET_DIAG_FILTER),
+ #define XLAT_VAL_7 ((unsigned) (PACKET_DIAG_FILTER))
+ #define XLAT_STR_7 STRINGIFY(PACKET_DIAG_FILTER)
 };
 static
 const struct xlat packet_diag_attrs[1] = { {
  .data = packet_diag_attrs_xdata,
  .size = ARRAY_SIZE(packet_diag_attrs_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/packet_diag_info_flags.h 5.9-0ubuntu2/xlat/packet_diag_info_flags.h
--- 5.5-3/xlat/packet_diag_info_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/packet_diag_info_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -15,18 +15,28 @@
 static const struct xlat_data packet_diag_info_flags_xdata[] = {
 #if defined(PDI_RUNNING) || (defined(HAVE_DECL_PDI_RUNNING) && HAVE_DECL_PDI_RUNNING)
   XLAT(PDI_RUNNING),
+ #define XLAT_VAL_0 ((unsigned) (PDI_RUNNING))
+ #define XLAT_STR_0 STRINGIFY(PDI_RUNNING)
 #endif
 #if defined(PDI_AUXDATA) || (defined(HAVE_DECL_PDI_AUXDATA) && HAVE_DECL_PDI_AUXDATA)
   XLAT(PDI_AUXDATA),
+ #define XLAT_VAL_1 ((unsigned) (PDI_AUXDATA))
+ #define XLAT_STR_1 STRINGIFY(PDI_AUXDATA)
 #endif
 #if defined(PDI_ORIGDEV) || (defined(HAVE_DECL_PDI_ORIGDEV) && HAVE_DECL_PDI_ORIGDEV)
   XLAT(PDI_ORIGDEV),
+ #define XLAT_VAL_2 ((unsigned) (PDI_ORIGDEV))
+ #define XLAT_STR_2 STRINGIFY(PDI_ORIGDEV)
 #endif
 #if defined(PDI_VNETHDR) || (defined(HAVE_DECL_PDI_VNETHDR) && HAVE_DECL_PDI_VNETHDR)
   XLAT(PDI_VNETHDR),
+ #define XLAT_VAL_3 ((unsigned) (PDI_VNETHDR))
+ #define XLAT_STR_3 STRINGIFY(PDI_VNETHDR)
 #endif
 #if defined(PDI_LOSS) || (defined(HAVE_DECL_PDI_LOSS) && HAVE_DECL_PDI_LOSS)
   XLAT(PDI_LOSS),
+ #define XLAT_VAL_4 ((unsigned) (PDI_LOSS))
+ #define XLAT_STR_4 STRINGIFY(PDI_LOSS)
 #endif
 };
 static
@@ -34,8 +44,52 @@ const struct xlat packet_diag_info_flags
  .data = packet_diag_info_flags_xdata,
  .size = ARRAY_SIZE(packet_diag_info_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/packet_diag_show.h 5.9-0ubuntu2/xlat/packet_diag_show.h
--- 5.5-3/xlat/packet_diag_show.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/packet_diag_show.h	2020-09-24 09:18:45.000000000 +0000
@@ -15,21 +15,33 @@
 static const struct xlat_data packet_diag_show_xdata[] = {
 #if defined(PACKET_SHOW_INFO) || (defined(HAVE_DECL_PACKET_SHOW_INFO) && HAVE_DECL_PACKET_SHOW_INFO)
   XLAT(PACKET_SHOW_INFO),
+ #define XLAT_VAL_0 ((unsigned) (PACKET_SHOW_INFO))
+ #define XLAT_STR_0 STRINGIFY(PACKET_SHOW_INFO)
 #endif
 #if defined(PACKET_SHOW_MCLIST) || (defined(HAVE_DECL_PACKET_SHOW_MCLIST) && HAVE_DECL_PACKET_SHOW_MCLIST)
   XLAT(PACKET_SHOW_MCLIST),
+ #define XLAT_VAL_1 ((unsigned) (PACKET_SHOW_MCLIST))
+ #define XLAT_STR_1 STRINGIFY(PACKET_SHOW_MCLIST)
 #endif
 #if defined(PACKET_SHOW_RING_CFG) || (defined(HAVE_DECL_PACKET_SHOW_RING_CFG) && HAVE_DECL_PACKET_SHOW_RING_CFG)
   XLAT(PACKET_SHOW_RING_CFG),
+ #define XLAT_VAL_2 ((unsigned) (PACKET_SHOW_RING_CFG))
+ #define XLAT_STR_2 STRINGIFY(PACKET_SHOW_RING_CFG)
 #endif
 #if defined(PACKET_SHOW_FANOUT) || (defined(HAVE_DECL_PACKET_SHOW_FANOUT) && HAVE_DECL_PACKET_SHOW_FANOUT)
   XLAT(PACKET_SHOW_FANOUT),
+ #define XLAT_VAL_3 ((unsigned) (PACKET_SHOW_FANOUT))
+ #define XLAT_STR_3 STRINGIFY(PACKET_SHOW_FANOUT)
 #endif
 #if defined(PACKET_SHOW_MEMINFO) || (defined(HAVE_DECL_PACKET_SHOW_MEMINFO) && HAVE_DECL_PACKET_SHOW_MEMINFO)
   XLAT(PACKET_SHOW_MEMINFO),
+ #define XLAT_VAL_4 ((unsigned) (PACKET_SHOW_MEMINFO))
+ #define XLAT_STR_4 STRINGIFY(PACKET_SHOW_MEMINFO)
 #endif
 #if defined(PACKET_SHOW_FILTER) || (defined(HAVE_DECL_PACKET_SHOW_FILTER) && HAVE_DECL_PACKET_SHOW_FILTER)
   XLAT(PACKET_SHOW_FILTER),
+ #define XLAT_VAL_5 ((unsigned) (PACKET_SHOW_FILTER))
+ #define XLAT_STR_5 STRINGIFY(PACKET_SHOW_FILTER)
 #endif
 };
 static
@@ -37,8 +49,60 @@ const struct xlat packet_diag_show[1] =
  .data = packet_diag_show_xdata,
  .size = ARRAY_SIZE(packet_diag_show_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/packet_mreq_type.h 5.9-0ubuntu2/xlat/packet_mreq_type.h
--- 5.5-3/xlat/packet_mreq_type.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/packet_mreq_type.h	2020-09-24 09:18:45.000000000 +0000
@@ -15,15 +15,23 @@
 static const struct xlat_data packet_mreq_type_xdata[] = {
 #if defined(PACKET_MR_MULTICAST) || (defined(HAVE_DECL_PACKET_MR_MULTICAST) && HAVE_DECL_PACKET_MR_MULTICAST)
   XLAT(PACKET_MR_MULTICAST),
+ #define XLAT_VAL_0 ((unsigned) (PACKET_MR_MULTICAST))
+ #define XLAT_STR_0 STRINGIFY(PACKET_MR_MULTICAST)
 #endif
 #if defined(PACKET_MR_PROMISC) || (defined(HAVE_DECL_PACKET_MR_PROMISC) && HAVE_DECL_PACKET_MR_PROMISC)
   XLAT(PACKET_MR_PROMISC),
+ #define XLAT_VAL_1 ((unsigned) (PACKET_MR_PROMISC))
+ #define XLAT_STR_1 STRINGIFY(PACKET_MR_PROMISC)
 #endif
 #if defined(PACKET_MR_ALLMULTI) || (defined(HAVE_DECL_PACKET_MR_ALLMULTI) && HAVE_DECL_PACKET_MR_ALLMULTI)
   XLAT(PACKET_MR_ALLMULTI),
+ #define XLAT_VAL_2 ((unsigned) (PACKET_MR_ALLMULTI))
+ #define XLAT_STR_2 STRINGIFY(PACKET_MR_ALLMULTI)
 #endif
 #if defined(PACKET_MR_UNICAST) || (defined(HAVE_DECL_PACKET_MR_UNICAST) && HAVE_DECL_PACKET_MR_UNICAST)
   XLAT(PACKET_MR_UNICAST),
+ #define XLAT_VAL_3 ((unsigned) (PACKET_MR_UNICAST))
+ #define XLAT_STR_3 STRINGIFY(PACKET_MR_UNICAST)
 #endif
 };
 static
@@ -31,8 +39,44 @@ const struct xlat packet_mreq_type[1] =
  .data = packet_mreq_type_xdata,
  .size = ARRAY_SIZE(packet_mreq_type_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/perf_attr_size.h 5.9-0ubuntu2/xlat/perf_attr_size.h
--- 5.5-3/xlat/perf_attr_size.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/perf_attr_size.h	2020-09-24 09:18:45.000000000 +0000
@@ -63,20 +63,94 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data perf_attr_size_xdata[] = {
  XLAT(PERF_ATTR_SIZE_VER0),
+ #define XLAT_VAL_0 ((unsigned) (PERF_ATTR_SIZE_VER0))
+ #define XLAT_STR_0 STRINGIFY(PERF_ATTR_SIZE_VER0)
  XLAT(PERF_ATTR_SIZE_VER1),
+ #define XLAT_VAL_1 ((unsigned) (PERF_ATTR_SIZE_VER1))
+ #define XLAT_STR_1 STRINGIFY(PERF_ATTR_SIZE_VER1)
  XLAT(PERF_ATTR_SIZE_VER2),
+ #define XLAT_VAL_2 ((unsigned) (PERF_ATTR_SIZE_VER2))
+ #define XLAT_STR_2 STRINGIFY(PERF_ATTR_SIZE_VER2)
  XLAT(PERF_ATTR_SIZE_VER3),
+ #define XLAT_VAL_3 ((unsigned) (PERF_ATTR_SIZE_VER3))
+ #define XLAT_STR_3 STRINGIFY(PERF_ATTR_SIZE_VER3)
  XLAT(PERF_ATTR_SIZE_VER4),
+ #define XLAT_VAL_4 ((unsigned) (PERF_ATTR_SIZE_VER4))
+ #define XLAT_STR_4 STRINGIFY(PERF_ATTR_SIZE_VER4)
  XLAT(PERF_ATTR_SIZE_VER5),
+ #define XLAT_VAL_5 ((unsigned) (PERF_ATTR_SIZE_VER5))
+ #define XLAT_STR_5 STRINGIFY(PERF_ATTR_SIZE_VER5)
  XLAT(PERF_ATTR_SIZE_VER6),
+ #define XLAT_VAL_6 ((unsigned) (PERF_ATTR_SIZE_VER6))
+ #define XLAT_STR_6 STRINGIFY(PERF_ATTR_SIZE_VER6)
 };
 static
 const struct xlat perf_attr_size[1] = { {
  .data = perf_attr_size_xdata,
  .size = ARRAY_SIZE(perf_attr_size_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/perf_branch_sample_type.h 5.9-0ubuntu2/xlat/perf_branch_sample_type.h
--- 5.5-3/xlat/perf_branch_sample_type.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/perf_branch_sample_type.h	2020-09-24 09:18:45.000000000 +0000
@@ -122,6 +122,13 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define PERF_SAMPLE_BRANCH_TYPE_SAVE 1 << 16
 #endif
+#if defined(PERF_SAMPLE_BRANCH_HW_INDEX) || (defined(HAVE_DECL_PERF_SAMPLE_BRANCH_HW_INDEX) && HAVE_DECL_PERF_SAMPLE_BRANCH_HW_INDEX)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((PERF_SAMPLE_BRANCH_HW_INDEX) == (1 << 17), "PERF_SAMPLE_BRANCH_HW_INDEX != 1 << 17");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define PERF_SAMPLE_BRANCH_HW_INDEX 1 << 17
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -133,30 +140,215 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data perf_branch_sample_type_xdata[] = {
  XLAT(PERF_SAMPLE_BRANCH_USER),
+ #define XLAT_VAL_0 ((unsigned) (PERF_SAMPLE_BRANCH_USER))
+ #define XLAT_STR_0 STRINGIFY(PERF_SAMPLE_BRANCH_USER)
  XLAT(PERF_SAMPLE_BRANCH_KERNEL),
+ #define XLAT_VAL_1 ((unsigned) (PERF_SAMPLE_BRANCH_KERNEL))
+ #define XLAT_STR_1 STRINGIFY(PERF_SAMPLE_BRANCH_KERNEL)
  XLAT(PERF_SAMPLE_BRANCH_HV),
+ #define XLAT_VAL_2 ((unsigned) (PERF_SAMPLE_BRANCH_HV))
+ #define XLAT_STR_2 STRINGIFY(PERF_SAMPLE_BRANCH_HV)
  XLAT(PERF_SAMPLE_BRANCH_ANY),
+ #define XLAT_VAL_3 ((unsigned) (PERF_SAMPLE_BRANCH_ANY))
+ #define XLAT_STR_3 STRINGIFY(PERF_SAMPLE_BRANCH_ANY)
  XLAT(PERF_SAMPLE_BRANCH_ANY_CALL),
+ #define XLAT_VAL_4 ((unsigned) (PERF_SAMPLE_BRANCH_ANY_CALL))
+ #define XLAT_STR_4 STRINGIFY(PERF_SAMPLE_BRANCH_ANY_CALL)
  XLAT(PERF_SAMPLE_BRANCH_ANY_RETURN),
+ #define XLAT_VAL_5 ((unsigned) (PERF_SAMPLE_BRANCH_ANY_RETURN))
+ #define XLAT_STR_5 STRINGIFY(PERF_SAMPLE_BRANCH_ANY_RETURN)
  XLAT(PERF_SAMPLE_BRANCH_IND_CALL),
+ #define XLAT_VAL_6 ((unsigned) (PERF_SAMPLE_BRANCH_IND_CALL))
+ #define XLAT_STR_6 STRINGIFY(PERF_SAMPLE_BRANCH_IND_CALL)
  XLAT(PERF_SAMPLE_BRANCH_ABORT_TX),
+ #define XLAT_VAL_7 ((unsigned) (PERF_SAMPLE_BRANCH_ABORT_TX))
+ #define XLAT_STR_7 STRINGIFY(PERF_SAMPLE_BRANCH_ABORT_TX)
  XLAT(PERF_SAMPLE_BRANCH_IN_TX),
+ #define XLAT_VAL_8 ((unsigned) (PERF_SAMPLE_BRANCH_IN_TX))
+ #define XLAT_STR_8 STRINGIFY(PERF_SAMPLE_BRANCH_IN_TX)
  XLAT(PERF_SAMPLE_BRANCH_NO_TX),
+ #define XLAT_VAL_9 ((unsigned) (PERF_SAMPLE_BRANCH_NO_TX))
+ #define XLAT_STR_9 STRINGIFY(PERF_SAMPLE_BRANCH_NO_TX)
  XLAT(PERF_SAMPLE_BRANCH_COND),
+ #define XLAT_VAL_10 ((unsigned) (PERF_SAMPLE_BRANCH_COND))
+ #define XLAT_STR_10 STRINGIFY(PERF_SAMPLE_BRANCH_COND)
  XLAT(PERF_SAMPLE_BRANCH_CALL_STACK),
+ #define XLAT_VAL_11 ((unsigned) (PERF_SAMPLE_BRANCH_CALL_STACK))
+ #define XLAT_STR_11 STRINGIFY(PERF_SAMPLE_BRANCH_CALL_STACK)
  XLAT(PERF_SAMPLE_BRANCH_IND_JUMP),
+ #define XLAT_VAL_12 ((unsigned) (PERF_SAMPLE_BRANCH_IND_JUMP))
+ #define XLAT_STR_12 STRINGIFY(PERF_SAMPLE_BRANCH_IND_JUMP)
  XLAT(PERF_SAMPLE_BRANCH_CALL),
+ #define XLAT_VAL_13 ((unsigned) (PERF_SAMPLE_BRANCH_CALL))
+ #define XLAT_STR_13 STRINGIFY(PERF_SAMPLE_BRANCH_CALL)
  XLAT(PERF_SAMPLE_BRANCH_NO_FLAGS),
+ #define XLAT_VAL_14 ((unsigned) (PERF_SAMPLE_BRANCH_NO_FLAGS))
+ #define XLAT_STR_14 STRINGIFY(PERF_SAMPLE_BRANCH_NO_FLAGS)
  XLAT(PERF_SAMPLE_BRANCH_NO_CYCLES),
+ #define XLAT_VAL_15 ((unsigned) (PERF_SAMPLE_BRANCH_NO_CYCLES))
+ #define XLAT_STR_15 STRINGIFY(PERF_SAMPLE_BRANCH_NO_CYCLES)
  XLAT(PERF_SAMPLE_BRANCH_TYPE_SAVE),
+ #define XLAT_VAL_16 ((unsigned) (PERF_SAMPLE_BRANCH_TYPE_SAVE))
+ #define XLAT_STR_16 STRINGIFY(PERF_SAMPLE_BRANCH_TYPE_SAVE)
+ XLAT(PERF_SAMPLE_BRANCH_HW_INDEX),
+ #define XLAT_VAL_17 ((unsigned) (PERF_SAMPLE_BRANCH_HW_INDEX))
+ #define XLAT_STR_17 STRINGIFY(PERF_SAMPLE_BRANCH_HW_INDEX)
 };
 static
 const struct xlat perf_branch_sample_type[1] = { {
  .data = perf_branch_sample_type_xdata,
  .size = ARRAY_SIZE(perf_branch_sample_type_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/perf_branch_sample_type.in 5.9-0ubuntu2/xlat/perf_branch_sample_type.in
--- 5.5-3/xlat/perf_branch_sample_type.in	2018-01-11 15:54:33.000000000 +0000
+++ 5.9-0ubuntu2/xlat/perf_branch_sample_type.in	2020-04-15 13:39:57.000000000 +0000
@@ -15,3 +15,4 @@ PERF_SAMPLE_BRANCH_CALL       1 << 13
 PERF_SAMPLE_BRANCH_NO_FLAGS   1 << 14
 PERF_SAMPLE_BRANCH_NO_CYCLES  1 << 15
 PERF_SAMPLE_BRANCH_TYPE_SAVE  1 << 16
+PERF_SAMPLE_BRANCH_HW_INDEX   1 << 17
diff -pruN 5.5-3/xlat/perf_event_open_flags.h 5.9-0ubuntu2/xlat/perf_event_open_flags.h
--- 5.5-3/xlat/perf_event_open_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/perf_event_open_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data perf_event_open_flags_xdata[] = {
  XLAT(PERF_FLAG_FD_NO_GROUP),
+ #define XLAT_VAL_0 ((unsigned) (PERF_FLAG_FD_NO_GROUP))
+ #define XLAT_STR_0 STRINGIFY(PERF_FLAG_FD_NO_GROUP)
  XLAT(PERF_FLAG_FD_OUTPUT),
+ #define XLAT_VAL_1 ((unsigned) (PERF_FLAG_FD_OUTPUT))
+ #define XLAT_STR_1 STRINGIFY(PERF_FLAG_FD_OUTPUT)
  XLAT(PERF_FLAG_PID_CGROUP),
+ #define XLAT_VAL_2 ((unsigned) (PERF_FLAG_PID_CGROUP))
+ #define XLAT_STR_2 STRINGIFY(PERF_FLAG_PID_CGROUP)
  XLAT(PERF_FLAG_FD_CLOEXEC),
+ #define XLAT_VAL_3 ((unsigned) (PERF_FLAG_FD_CLOEXEC))
+ #define XLAT_STR_3 STRINGIFY(PERF_FLAG_FD_CLOEXEC)
 };
 static
 const struct xlat perf_event_open_flags[1] = { {
  .data = perf_event_open_flags_xdata,
  .size = ARRAY_SIZE(perf_event_open_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/perf_event_read_format.h 5.9-0ubuntu2/xlat/perf_event_read_format.h
--- 5.5-3/xlat/perf_event_read_format.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/perf_event_read_format.h	2020-09-24 09:18:45.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data perf_event_read_format_xdata[] = {
  XLAT(PERF_FORMAT_TOTAL_TIME_ENABLED),
+ #define XLAT_VAL_0 ((unsigned) (PERF_FORMAT_TOTAL_TIME_ENABLED))
+ #define XLAT_STR_0 STRINGIFY(PERF_FORMAT_TOTAL_TIME_ENABLED)
  XLAT(PERF_FORMAT_TOTAL_TIME_RUNNING),
+ #define XLAT_VAL_1 ((unsigned) (PERF_FORMAT_TOTAL_TIME_RUNNING))
+ #define XLAT_STR_1 STRINGIFY(PERF_FORMAT_TOTAL_TIME_RUNNING)
  XLAT(PERF_FORMAT_ID),
+ #define XLAT_VAL_2 ((unsigned) (PERF_FORMAT_ID))
+ #define XLAT_STR_2 STRINGIFY(PERF_FORMAT_ID)
  XLAT(PERF_FORMAT_GROUP),
+ #define XLAT_VAL_3 ((unsigned) (PERF_FORMAT_GROUP))
+ #define XLAT_STR_3 STRINGIFY(PERF_FORMAT_GROUP)
 };
 static
 const struct xlat perf_event_read_format[1] = { {
  .data = perf_event_read_format_xdata,
  .size = ARRAY_SIZE(perf_event_read_format_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/perf_event_sample_format.h 5.9-0ubuntu2/xlat/perf_event_sample_format.h
--- 5.5-3/xlat/perf_event_sample_format.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/perf_event_sample_format.h	2020-09-24 09:18:45.000000000 +0000
@@ -161,34 +161,248 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data perf_event_sample_format_xdata[] = {
  XLAT(PERF_SAMPLE_IP),
+ #define XLAT_VAL_0 ((unsigned) (PERF_SAMPLE_IP))
+ #define XLAT_STR_0 STRINGIFY(PERF_SAMPLE_IP)
  XLAT(PERF_SAMPLE_TID),
+ #define XLAT_VAL_1 ((unsigned) (PERF_SAMPLE_TID))
+ #define XLAT_STR_1 STRINGIFY(PERF_SAMPLE_TID)
  XLAT(PERF_SAMPLE_TIME),
+ #define XLAT_VAL_2 ((unsigned) (PERF_SAMPLE_TIME))
+ #define XLAT_STR_2 STRINGIFY(PERF_SAMPLE_TIME)
  XLAT(PERF_SAMPLE_ADDR),
+ #define XLAT_VAL_3 ((unsigned) (PERF_SAMPLE_ADDR))
+ #define XLAT_STR_3 STRINGIFY(PERF_SAMPLE_ADDR)
  XLAT(PERF_SAMPLE_READ),
+ #define XLAT_VAL_4 ((unsigned) (PERF_SAMPLE_READ))
+ #define XLAT_STR_4 STRINGIFY(PERF_SAMPLE_READ)
  XLAT(PERF_SAMPLE_CALLCHAIN),
+ #define XLAT_VAL_5 ((unsigned) (PERF_SAMPLE_CALLCHAIN))
+ #define XLAT_STR_5 STRINGIFY(PERF_SAMPLE_CALLCHAIN)
  XLAT(PERF_SAMPLE_ID),
+ #define XLAT_VAL_6 ((unsigned) (PERF_SAMPLE_ID))
+ #define XLAT_STR_6 STRINGIFY(PERF_SAMPLE_ID)
  XLAT(PERF_SAMPLE_CPU),
+ #define XLAT_VAL_7 ((unsigned) (PERF_SAMPLE_CPU))
+ #define XLAT_STR_7 STRINGIFY(PERF_SAMPLE_CPU)
  XLAT(PERF_SAMPLE_PERIOD),
+ #define XLAT_VAL_8 ((unsigned) (PERF_SAMPLE_PERIOD))
+ #define XLAT_STR_8 STRINGIFY(PERF_SAMPLE_PERIOD)
  XLAT(PERF_SAMPLE_STREAM_ID),
+ #define XLAT_VAL_9 ((unsigned) (PERF_SAMPLE_STREAM_ID))
+ #define XLAT_STR_9 STRINGIFY(PERF_SAMPLE_STREAM_ID)
  XLAT(PERF_SAMPLE_RAW),
+ #define XLAT_VAL_10 ((unsigned) (PERF_SAMPLE_RAW))
+ #define XLAT_STR_10 STRINGIFY(PERF_SAMPLE_RAW)
  XLAT(PERF_SAMPLE_BRANCH_STACK),
+ #define XLAT_VAL_11 ((unsigned) (PERF_SAMPLE_BRANCH_STACK))
+ #define XLAT_STR_11 STRINGIFY(PERF_SAMPLE_BRANCH_STACK)
  XLAT(PERF_SAMPLE_REGS_USER),
+ #define XLAT_VAL_12 ((unsigned) (PERF_SAMPLE_REGS_USER))
+ #define XLAT_STR_12 STRINGIFY(PERF_SAMPLE_REGS_USER)
  XLAT(PERF_SAMPLE_STACK_USER),
+ #define XLAT_VAL_13 ((unsigned) (PERF_SAMPLE_STACK_USER))
+ #define XLAT_STR_13 STRINGIFY(PERF_SAMPLE_STACK_USER)
  XLAT(PERF_SAMPLE_WEIGHT),
+ #define XLAT_VAL_14 ((unsigned) (PERF_SAMPLE_WEIGHT))
+ #define XLAT_STR_14 STRINGIFY(PERF_SAMPLE_WEIGHT)
  XLAT(PERF_SAMPLE_DATA_SRC),
+ #define XLAT_VAL_15 ((unsigned) (PERF_SAMPLE_DATA_SRC))
+ #define XLAT_STR_15 STRINGIFY(PERF_SAMPLE_DATA_SRC)
  XLAT(PERF_SAMPLE_IDENTIFIER),
+ #define XLAT_VAL_16 ((unsigned) (PERF_SAMPLE_IDENTIFIER))
+ #define XLAT_STR_16 STRINGIFY(PERF_SAMPLE_IDENTIFIER)
  XLAT(PERF_SAMPLE_TRANSACTION),
+ #define XLAT_VAL_17 ((unsigned) (PERF_SAMPLE_TRANSACTION))
+ #define XLAT_STR_17 STRINGIFY(PERF_SAMPLE_TRANSACTION)
  XLAT(PERF_SAMPLE_REGS_INTR),
+ #define XLAT_VAL_18 ((unsigned) (PERF_SAMPLE_REGS_INTR))
+ #define XLAT_STR_18 STRINGIFY(PERF_SAMPLE_REGS_INTR)
  XLAT(PERF_SAMPLE_PHYS_ADDR),
+ #define XLAT_VAL_19 ((unsigned) (PERF_SAMPLE_PHYS_ADDR))
+ #define XLAT_STR_19 STRINGIFY(PERF_SAMPLE_PHYS_ADDR)
  XLAT(PERF_SAMPLE_AUX),
+ #define XLAT_VAL_20 ((unsigned) (PERF_SAMPLE_AUX))
+ #define XLAT_STR_20 STRINGIFY(PERF_SAMPLE_AUX)
 };
 static
 const struct xlat perf_event_sample_format[1] = { {
  .data = perf_event_sample_format_xdata,
  .size = ARRAY_SIZE(perf_event_sample_format_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/perf_hw_cache_id.h 5.9-0ubuntu2/xlat/perf_hw_cache_id.h
--- 5.5-3/xlat/perf_hw_cache_id.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/perf_hw_cache_id.h	2020-09-24 09:18:45.000000000 +0000
@@ -63,20 +63,94 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data perf_hw_cache_id_xdata[] = {
  XLAT(PERF_COUNT_HW_CACHE_L1D),
+ #define XLAT_VAL_0 ((unsigned) (PERF_COUNT_HW_CACHE_L1D))
+ #define XLAT_STR_0 STRINGIFY(PERF_COUNT_HW_CACHE_L1D)
  XLAT(PERF_COUNT_HW_CACHE_L1I),
+ #define XLAT_VAL_1 ((unsigned) (PERF_COUNT_HW_CACHE_L1I))
+ #define XLAT_STR_1 STRINGIFY(PERF_COUNT_HW_CACHE_L1I)
  XLAT(PERF_COUNT_HW_CACHE_LL),
+ #define XLAT_VAL_2 ((unsigned) (PERF_COUNT_HW_CACHE_LL))
+ #define XLAT_STR_2 STRINGIFY(PERF_COUNT_HW_CACHE_LL)
  XLAT(PERF_COUNT_HW_CACHE_DTLB),
+ #define XLAT_VAL_3 ((unsigned) (PERF_COUNT_HW_CACHE_DTLB))
+ #define XLAT_STR_3 STRINGIFY(PERF_COUNT_HW_CACHE_DTLB)
  XLAT(PERF_COUNT_HW_CACHE_ITLB),
+ #define XLAT_VAL_4 ((unsigned) (PERF_COUNT_HW_CACHE_ITLB))
+ #define XLAT_STR_4 STRINGIFY(PERF_COUNT_HW_CACHE_ITLB)
  XLAT(PERF_COUNT_HW_CACHE_BPU),
+ #define XLAT_VAL_5 ((unsigned) (PERF_COUNT_HW_CACHE_BPU))
+ #define XLAT_STR_5 STRINGIFY(PERF_COUNT_HW_CACHE_BPU)
  XLAT(PERF_COUNT_HW_CACHE_NODE),
+ #define XLAT_VAL_6 ((unsigned) (PERF_COUNT_HW_CACHE_NODE))
+ #define XLAT_STR_6 STRINGIFY(PERF_COUNT_HW_CACHE_NODE)
 };
 static
 const struct xlat perf_hw_cache_id[1] = { {
  .data = perf_hw_cache_id_xdata,
  .size = ARRAY_SIZE(perf_hw_cache_id_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/perf_hw_cache_op_id.h 5.9-0ubuntu2/xlat/perf_hw_cache_op_id.h
--- 5.5-3/xlat/perf_hw_cache_op_id.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/perf_hw_cache_op_id.h	2020-09-24 09:18:45.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data perf_hw_cache_op_id_xdata[] = {
  XLAT(PERF_COUNT_HW_CACHE_OP_READ),
+ #define XLAT_VAL_0 ((unsigned) (PERF_COUNT_HW_CACHE_OP_READ))
+ #define XLAT_STR_0 STRINGIFY(PERF_COUNT_HW_CACHE_OP_READ)
  XLAT(PERF_COUNT_HW_CACHE_OP_WRITE),
+ #define XLAT_VAL_1 ((unsigned) (PERF_COUNT_HW_CACHE_OP_WRITE))
+ #define XLAT_STR_1 STRINGIFY(PERF_COUNT_HW_CACHE_OP_WRITE)
  XLAT(PERF_COUNT_HW_CACHE_OP_PREFETCH),
+ #define XLAT_VAL_2 ((unsigned) (PERF_COUNT_HW_CACHE_OP_PREFETCH))
+ #define XLAT_STR_2 STRINGIFY(PERF_COUNT_HW_CACHE_OP_PREFETCH)
 };
 static
 const struct xlat perf_hw_cache_op_id[1] = { {
  .data = perf_hw_cache_op_id_xdata,
  .size = ARRAY_SIZE(perf_hw_cache_op_id_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/perf_hw_cache_op_result_id.h 5.9-0ubuntu2/xlat/perf_hw_cache_op_result_id.h
--- 5.5-3/xlat/perf_hw_cache_op_result_id.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/perf_hw_cache_op_result_id.h	2020-09-24 09:18:45.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data perf_hw_cache_op_result_id_xdata[] = {
  XLAT(PERF_COUNT_HW_CACHE_RESULT_ACCESS),
+ #define XLAT_VAL_0 ((unsigned) (PERF_COUNT_HW_CACHE_RESULT_ACCESS))
+ #define XLAT_STR_0 STRINGIFY(PERF_COUNT_HW_CACHE_RESULT_ACCESS)
  XLAT(PERF_COUNT_HW_CACHE_RESULT_MISS),
+ #define XLAT_VAL_1 ((unsigned) (PERF_COUNT_HW_CACHE_RESULT_MISS))
+ #define XLAT_STR_1 STRINGIFY(PERF_COUNT_HW_CACHE_RESULT_MISS)
 };
 static
 const struct xlat perf_hw_cache_op_result_id[1] = { {
  .data = perf_hw_cache_op_result_id_xdata,
  .size = ARRAY_SIZE(perf_hw_cache_op_result_id_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/perf_hw_id.h 5.9-0ubuntu2/xlat/perf_hw_id.h
--- 5.5-3/xlat/perf_hw_id.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/perf_hw_id.h	2020-09-24 09:18:45.000000000 +0000
@@ -84,23 +84,127 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data perf_hw_id_xdata[] = {
  XLAT(PERF_COUNT_HW_CPU_CYCLES),
+ #define XLAT_VAL_0 ((unsigned) (PERF_COUNT_HW_CPU_CYCLES))
+ #define XLAT_STR_0 STRINGIFY(PERF_COUNT_HW_CPU_CYCLES)
  XLAT(PERF_COUNT_HW_INSTRUCTIONS),
+ #define XLAT_VAL_1 ((unsigned) (PERF_COUNT_HW_INSTRUCTIONS))
+ #define XLAT_STR_1 STRINGIFY(PERF_COUNT_HW_INSTRUCTIONS)
  XLAT(PERF_COUNT_HW_CACHE_REFERENCES),
+ #define XLAT_VAL_2 ((unsigned) (PERF_COUNT_HW_CACHE_REFERENCES))
+ #define XLAT_STR_2 STRINGIFY(PERF_COUNT_HW_CACHE_REFERENCES)
  XLAT(PERF_COUNT_HW_CACHE_MISSES),
+ #define XLAT_VAL_3 ((unsigned) (PERF_COUNT_HW_CACHE_MISSES))
+ #define XLAT_STR_3 STRINGIFY(PERF_COUNT_HW_CACHE_MISSES)
  XLAT(PERF_COUNT_HW_BRANCH_INSTRUCTIONS),
+ #define XLAT_VAL_4 ((unsigned) (PERF_COUNT_HW_BRANCH_INSTRUCTIONS))
+ #define XLAT_STR_4 STRINGIFY(PERF_COUNT_HW_BRANCH_INSTRUCTIONS)
  XLAT(PERF_COUNT_HW_BRANCH_MISSES),
+ #define XLAT_VAL_5 ((unsigned) (PERF_COUNT_HW_BRANCH_MISSES))
+ #define XLAT_STR_5 STRINGIFY(PERF_COUNT_HW_BRANCH_MISSES)
  XLAT(PERF_COUNT_HW_BUS_CYCLES),
+ #define XLAT_VAL_6 ((unsigned) (PERF_COUNT_HW_BUS_CYCLES))
+ #define XLAT_STR_6 STRINGIFY(PERF_COUNT_HW_BUS_CYCLES)
  XLAT(PERF_COUNT_HW_STALLED_CYCLES_FRONTEND),
+ #define XLAT_VAL_7 ((unsigned) (PERF_COUNT_HW_STALLED_CYCLES_FRONTEND))
+ #define XLAT_STR_7 STRINGIFY(PERF_COUNT_HW_STALLED_CYCLES_FRONTEND)
  XLAT(PERF_COUNT_HW_STALLED_CYCLES_BACKEND),
+ #define XLAT_VAL_8 ((unsigned) (PERF_COUNT_HW_STALLED_CYCLES_BACKEND))
+ #define XLAT_STR_8 STRINGIFY(PERF_COUNT_HW_STALLED_CYCLES_BACKEND)
  XLAT(PERF_COUNT_HW_REF_CPU_CYCLES),
+ #define XLAT_VAL_9 ((unsigned) (PERF_COUNT_HW_REF_CPU_CYCLES))
+ #define XLAT_STR_9 STRINGIFY(PERF_COUNT_HW_REF_CPU_CYCLES)
 };
 static
 const struct xlat perf_hw_id[1] = { {
  .data = perf_hw_id_xdata,
  .size = ARRAY_SIZE(perf_hw_id_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/perf_ioctl_cmds.h 5.9-0ubuntu2/xlat/perf_ioctl_cmds.h
--- 5.5-3/xlat/perf_ioctl_cmds.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/perf_ioctl_cmds.h	2020-09-24 09:18:45.000000000 +0000
@@ -98,17 +98,41 @@ extern const struct xlat perf_ioctl_cmds
 
 static const struct xlat_data perf_ioctl_cmds_xdata[] = {
  XLAT(PERF_EVENT_IOC_ENABLE),
+ #define XLAT_VAL_0 ((unsigned) (PERF_EVENT_IOC_ENABLE))
+ #define XLAT_STR_0 STRINGIFY(PERF_EVENT_IOC_ENABLE)
  XLAT(PERF_EVENT_IOC_DISABLE),
+ #define XLAT_VAL_1 ((unsigned) (PERF_EVENT_IOC_DISABLE))
+ #define XLAT_STR_1 STRINGIFY(PERF_EVENT_IOC_DISABLE)
  XLAT(PERF_EVENT_IOC_REFRESH),
+ #define XLAT_VAL_2 ((unsigned) (PERF_EVENT_IOC_REFRESH))
+ #define XLAT_STR_2 STRINGIFY(PERF_EVENT_IOC_REFRESH)
  XLAT(PERF_EVENT_IOC_RESET),
+ #define XLAT_VAL_3 ((unsigned) (PERF_EVENT_IOC_RESET))
+ #define XLAT_STR_3 STRINGIFY(PERF_EVENT_IOC_RESET)
  XLAT(PERF_EVENT_IOC_PERIOD),
+ #define XLAT_VAL_4 ((unsigned) (PERF_EVENT_IOC_PERIOD))
+ #define XLAT_STR_4 STRINGIFY(PERF_EVENT_IOC_PERIOD)
  XLAT(PERF_EVENT_IOC_SET_OUTPUT),
+ #define XLAT_VAL_5 ((unsigned) (PERF_EVENT_IOC_SET_OUTPUT))
+ #define XLAT_STR_5 STRINGIFY(PERF_EVENT_IOC_SET_OUTPUT)
  XLAT(PERF_EVENT_IOC_SET_FILTER),
+ #define XLAT_VAL_6 ((unsigned) (PERF_EVENT_IOC_SET_FILTER))
+ #define XLAT_STR_6 STRINGIFY(PERF_EVENT_IOC_SET_FILTER)
  XLAT(PERF_EVENT_IOC_ID),
+ #define XLAT_VAL_7 ((unsigned) (PERF_EVENT_IOC_ID))
+ #define XLAT_STR_7 STRINGIFY(PERF_EVENT_IOC_ID)
  XLAT(PERF_EVENT_IOC_SET_BPF),
+ #define XLAT_VAL_8 ((unsigned) (PERF_EVENT_IOC_SET_BPF))
+ #define XLAT_STR_8 STRINGIFY(PERF_EVENT_IOC_SET_BPF)
  XLAT(PERF_EVENT_IOC_PAUSE_OUTPUT),
+ #define XLAT_VAL_9 ((unsigned) (PERF_EVENT_IOC_PAUSE_OUTPUT))
+ #define XLAT_STR_9 STRINGIFY(PERF_EVENT_IOC_PAUSE_OUTPUT)
  XLAT(PERF_EVENT_IOC_QUERY_BPF),
+ #define XLAT_VAL_10 ((unsigned) (PERF_EVENT_IOC_QUERY_BPF))
+ #define XLAT_STR_10 STRINGIFY(PERF_EVENT_IOC_QUERY_BPF)
  XLAT(PERF_EVENT_IOC_MODIFY_ATTRIBUTES),
+ #define XLAT_VAL_11 ((unsigned) (PERF_EVENT_IOC_MODIFY_ATTRIBUTES))
+ #define XLAT_STR_11 STRINGIFY(PERF_EVENT_IOC_MODIFY_ATTRIBUTES)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -117,8 +141,108 @@ const struct xlat perf_ioctl_cmds[1] = {
  .data = perf_ioctl_cmds_xdata,
  .size = ARRAY_SIZE(perf_ioctl_cmds_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/perf_ioctl_flags.h 5.9-0ubuntu2/xlat/perf_ioctl_flags.h
--- 5.5-3/xlat/perf_ioctl_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/perf_ioctl_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -21,6 +21,8 @@ extern const struct xlat perf_ioctl_flag
 
 static const struct xlat_data perf_ioctl_flags_xdata[] = {
  XLAT(PERF_IOC_FLAG_GROUP),
+ #define XLAT_VAL_0 ((unsigned) (PERF_IOC_FLAG_GROUP))
+ #define XLAT_STR_0 STRINGIFY(PERF_IOC_FLAG_GROUP)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -29,8 +31,20 @@ const struct xlat perf_ioctl_flags[1] =
  .data = perf_ioctl_flags_xdata,
  .size = ARRAY_SIZE(perf_ioctl_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/perf_sw_ids.h 5.9-0ubuntu2/xlat/perf_sw_ids.h
--- 5.5-3/xlat/perf_sw_ids.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/perf_sw_ids.h	2020-09-24 09:18:45.000000000 +0000
@@ -91,24 +91,138 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data perf_sw_ids_xdata[] = {
  XLAT(PERF_COUNT_SW_CPU_CLOCK),
+ #define XLAT_VAL_0 ((unsigned) (PERF_COUNT_SW_CPU_CLOCK))
+ #define XLAT_STR_0 STRINGIFY(PERF_COUNT_SW_CPU_CLOCK)
  XLAT(PERF_COUNT_SW_TASK_CLOCK),
+ #define XLAT_VAL_1 ((unsigned) (PERF_COUNT_SW_TASK_CLOCK))
+ #define XLAT_STR_1 STRINGIFY(PERF_COUNT_SW_TASK_CLOCK)
  XLAT(PERF_COUNT_SW_PAGE_FAULTS),
+ #define XLAT_VAL_2 ((unsigned) (PERF_COUNT_SW_PAGE_FAULTS))
+ #define XLAT_STR_2 STRINGIFY(PERF_COUNT_SW_PAGE_FAULTS)
  XLAT(PERF_COUNT_SW_CONTEXT_SWITCHES),
+ #define XLAT_VAL_3 ((unsigned) (PERF_COUNT_SW_CONTEXT_SWITCHES))
+ #define XLAT_STR_3 STRINGIFY(PERF_COUNT_SW_CONTEXT_SWITCHES)
  XLAT(PERF_COUNT_SW_CPU_MIGRATIONS),
+ #define XLAT_VAL_4 ((unsigned) (PERF_COUNT_SW_CPU_MIGRATIONS))
+ #define XLAT_STR_4 STRINGIFY(PERF_COUNT_SW_CPU_MIGRATIONS)
  XLAT(PERF_COUNT_SW_PAGE_FAULTS_MIN),
+ #define XLAT_VAL_5 ((unsigned) (PERF_COUNT_SW_PAGE_FAULTS_MIN))
+ #define XLAT_STR_5 STRINGIFY(PERF_COUNT_SW_PAGE_FAULTS_MIN)
  XLAT(PERF_COUNT_SW_PAGE_FAULTS_MAJ),
+ #define XLAT_VAL_6 ((unsigned) (PERF_COUNT_SW_PAGE_FAULTS_MAJ))
+ #define XLAT_STR_6 STRINGIFY(PERF_COUNT_SW_PAGE_FAULTS_MAJ)
  XLAT(PERF_COUNT_SW_ALIGNMENT_FAULTS),
+ #define XLAT_VAL_7 ((unsigned) (PERF_COUNT_SW_ALIGNMENT_FAULTS))
+ #define XLAT_STR_7 STRINGIFY(PERF_COUNT_SW_ALIGNMENT_FAULTS)
  XLAT(PERF_COUNT_SW_EMULATION_FAULTS),
+ #define XLAT_VAL_8 ((unsigned) (PERF_COUNT_SW_EMULATION_FAULTS))
+ #define XLAT_STR_8 STRINGIFY(PERF_COUNT_SW_EMULATION_FAULTS)
  XLAT(PERF_COUNT_SW_DUMMY),
+ #define XLAT_VAL_9 ((unsigned) (PERF_COUNT_SW_DUMMY))
+ #define XLAT_STR_9 STRINGIFY(PERF_COUNT_SW_DUMMY)
  XLAT(PERF_COUNT_SW_BPF_OUTPUT),
+ #define XLAT_VAL_10 ((unsigned) (PERF_COUNT_SW_BPF_OUTPUT))
+ #define XLAT_STR_10 STRINGIFY(PERF_COUNT_SW_BPF_OUTPUT)
 };
 static
 const struct xlat perf_sw_ids[1] = { {
  .data = perf_sw_ids_xdata,
  .size = ARRAY_SIZE(perf_sw_ids_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/perf_type_id.h 5.9-0ubuntu2/xlat/perf_type_id.h
--- 5.5-3/xlat/perf_type_id.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/perf_type_id.h	2020-09-24 09:18:45.000000000 +0000
@@ -56,19 +56,83 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data perf_type_id_xdata[] = {
  XLAT(PERF_TYPE_HARDWARE),
+ #define XLAT_VAL_0 ((unsigned) (PERF_TYPE_HARDWARE))
+ #define XLAT_STR_0 STRINGIFY(PERF_TYPE_HARDWARE)
  XLAT(PERF_TYPE_SOFTWARE),
+ #define XLAT_VAL_1 ((unsigned) (PERF_TYPE_SOFTWARE))
+ #define XLAT_STR_1 STRINGIFY(PERF_TYPE_SOFTWARE)
  XLAT(PERF_TYPE_TRACEPOINT),
+ #define XLAT_VAL_2 ((unsigned) (PERF_TYPE_TRACEPOINT))
+ #define XLAT_STR_2 STRINGIFY(PERF_TYPE_TRACEPOINT)
  XLAT(PERF_TYPE_HW_CACHE),
+ #define XLAT_VAL_3 ((unsigned) (PERF_TYPE_HW_CACHE))
+ #define XLAT_STR_3 STRINGIFY(PERF_TYPE_HW_CACHE)
  XLAT(PERF_TYPE_RAW),
+ #define XLAT_VAL_4 ((unsigned) (PERF_TYPE_RAW))
+ #define XLAT_STR_4 STRINGIFY(PERF_TYPE_RAW)
  XLAT(PERF_TYPE_BREAKPOINT),
+ #define XLAT_VAL_5 ((unsigned) (PERF_TYPE_BREAKPOINT))
+ #define XLAT_STR_5 STRINGIFY(PERF_TYPE_BREAKPOINT)
 };
 static
 const struct xlat perf_type_id[1] = { {
  .data = perf_type_id_xdata,
  .size = ARRAY_SIZE(perf_type_id_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/personality_flags.h 5.9-0ubuntu2/xlat/personality_flags.h
--- 5.5-3/xlat/personality_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/personality_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -91,24 +91,138 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data personality_flags_xdata[] = {
  XLAT(UNAME26),
+ #define XLAT_VAL_0 ((unsigned) (UNAME26))
+ #define XLAT_STR_0 STRINGIFY(UNAME26)
  XLAT(ADDR_NO_RANDOMIZE),
+ #define XLAT_VAL_1 ((unsigned) (ADDR_NO_RANDOMIZE))
+ #define XLAT_STR_1 STRINGIFY(ADDR_NO_RANDOMIZE)
  XLAT(FDPIC_FUNCPTRS),
+ #define XLAT_VAL_2 ((unsigned) (FDPIC_FUNCPTRS))
+ #define XLAT_STR_2 STRINGIFY(FDPIC_FUNCPTRS)
  XLAT(MMAP_PAGE_ZERO),
+ #define XLAT_VAL_3 ((unsigned) (MMAP_PAGE_ZERO))
+ #define XLAT_STR_3 STRINGIFY(MMAP_PAGE_ZERO)
  XLAT(ADDR_COMPAT_LAYOUT),
+ #define XLAT_VAL_4 ((unsigned) (ADDR_COMPAT_LAYOUT))
+ #define XLAT_STR_4 STRINGIFY(ADDR_COMPAT_LAYOUT)
  XLAT(READ_IMPLIES_EXEC),
+ #define XLAT_VAL_5 ((unsigned) (READ_IMPLIES_EXEC))
+ #define XLAT_STR_5 STRINGIFY(READ_IMPLIES_EXEC)
  XLAT(ADDR_LIMIT_32BIT),
+ #define XLAT_VAL_6 ((unsigned) (ADDR_LIMIT_32BIT))
+ #define XLAT_STR_6 STRINGIFY(ADDR_LIMIT_32BIT)
  XLAT(SHORT_INODE),
+ #define XLAT_VAL_7 ((unsigned) (SHORT_INODE))
+ #define XLAT_STR_7 STRINGIFY(SHORT_INODE)
  XLAT(WHOLE_SECONDS),
+ #define XLAT_VAL_8 ((unsigned) (WHOLE_SECONDS))
+ #define XLAT_STR_8 STRINGIFY(WHOLE_SECONDS)
  XLAT(STICKY_TIMEOUTS),
+ #define XLAT_VAL_9 ((unsigned) (STICKY_TIMEOUTS))
+ #define XLAT_STR_9 STRINGIFY(STICKY_TIMEOUTS)
  XLAT(ADDR_LIMIT_3GB),
+ #define XLAT_VAL_10 ((unsigned) (ADDR_LIMIT_3GB))
+ #define XLAT_STR_10 STRINGIFY(ADDR_LIMIT_3GB)
 };
 static
 const struct xlat personality_flags[1] = { {
  .data = personality_flags_xdata,
  .size = ARRAY_SIZE(personality_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/personality_types.h 5.9-0ubuntu2/xlat/personality_types.h
--- 5.5-3/xlat/personality_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/personality_types.h	2020-09-24 09:18:45.000000000 +0000
@@ -175,36 +175,270 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data personality_types_xdata[] = {
  XLAT(PER_LINUX),
+ #define XLAT_VAL_0 ((unsigned) (PER_LINUX))
+ #define XLAT_STR_0 STRINGIFY(PER_LINUX)
  XLAT(PER_LINUX_32BIT),
+ #define XLAT_VAL_1 ((unsigned) (PER_LINUX_32BIT))
+ #define XLAT_STR_1 STRINGIFY(PER_LINUX_32BIT)
  XLAT(PER_LINUX_FDPIC),
+ #define XLAT_VAL_2 ((unsigned) (PER_LINUX_FDPIC))
+ #define XLAT_STR_2 STRINGIFY(PER_LINUX_FDPIC)
  XLAT(PER_SVR4),
+ #define XLAT_VAL_3 ((unsigned) (PER_SVR4))
+ #define XLAT_STR_3 STRINGIFY(PER_SVR4)
  XLAT(PER_SVR3),
+ #define XLAT_VAL_4 ((unsigned) (PER_SVR3))
+ #define XLAT_STR_4 STRINGIFY(PER_SVR3)
  XLAT(PER_SCOSVR3),
+ #define XLAT_VAL_5 ((unsigned) (PER_SCOSVR3))
+ #define XLAT_STR_5 STRINGIFY(PER_SCOSVR3)
  XLAT(PER_OSR5),
+ #define XLAT_VAL_6 ((unsigned) (PER_OSR5))
+ #define XLAT_STR_6 STRINGIFY(PER_OSR5)
  XLAT(PER_WYSEV386),
+ #define XLAT_VAL_7 ((unsigned) (PER_WYSEV386))
+ #define XLAT_STR_7 STRINGIFY(PER_WYSEV386)
  XLAT(PER_ISCR4),
+ #define XLAT_VAL_8 ((unsigned) (PER_ISCR4))
+ #define XLAT_STR_8 STRINGIFY(PER_ISCR4)
  XLAT(PER_BSD),
+ #define XLAT_VAL_9 ((unsigned) (PER_BSD))
+ #define XLAT_STR_9 STRINGIFY(PER_BSD)
  XLAT(PER_SUNOS),
+ #define XLAT_VAL_10 ((unsigned) (PER_SUNOS))
+ #define XLAT_STR_10 STRINGIFY(PER_SUNOS)
  XLAT(PER_XENIX),
+ #define XLAT_VAL_11 ((unsigned) (PER_XENIX))
+ #define XLAT_STR_11 STRINGIFY(PER_XENIX)
  XLAT(PER_LINUX32),
+ #define XLAT_VAL_12 ((unsigned) (PER_LINUX32))
+ #define XLAT_STR_12 STRINGIFY(PER_LINUX32)
  XLAT(PER_LINUX32_3GB),
+ #define XLAT_VAL_13 ((unsigned) (PER_LINUX32_3GB))
+ #define XLAT_STR_13 STRINGIFY(PER_LINUX32_3GB)
  XLAT(PER_IRIX32),
+ #define XLAT_VAL_14 ((unsigned) (PER_IRIX32))
+ #define XLAT_STR_14 STRINGIFY(PER_IRIX32)
  XLAT(PER_IRIXN32),
+ #define XLAT_VAL_15 ((unsigned) (PER_IRIXN32))
+ #define XLAT_STR_15 STRINGIFY(PER_IRIXN32)
  XLAT(PER_IRIX64),
+ #define XLAT_VAL_16 ((unsigned) (PER_IRIX64))
+ #define XLAT_STR_16 STRINGIFY(PER_IRIX64)
  XLAT(PER_RISCOS),
+ #define XLAT_VAL_17 ((unsigned) (PER_RISCOS))
+ #define XLAT_STR_17 STRINGIFY(PER_RISCOS)
  XLAT(PER_SOLARIS),
+ #define XLAT_VAL_18 ((unsigned) (PER_SOLARIS))
+ #define XLAT_STR_18 STRINGIFY(PER_SOLARIS)
  XLAT(PER_UW7),
+ #define XLAT_VAL_19 ((unsigned) (PER_UW7))
+ #define XLAT_STR_19 STRINGIFY(PER_UW7)
  XLAT(PER_OSF4),
+ #define XLAT_VAL_20 ((unsigned) (PER_OSF4))
+ #define XLAT_STR_20 STRINGIFY(PER_OSF4)
  XLAT(PER_HPUX),
+ #define XLAT_VAL_21 ((unsigned) (PER_HPUX))
+ #define XLAT_STR_21 STRINGIFY(PER_HPUX)
  XLAT(PER_MASK),
+ #define XLAT_VAL_22 ((unsigned) (PER_MASK))
+ #define XLAT_STR_22 STRINGIFY(PER_MASK)
 };
 static
 const struct xlat personality_types[1] = { {
  .data = personality_types_xdata,
  .size = ARRAY_SIZE(personality_types_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/phonet_protocols.h 5.9-0ubuntu2/xlat/phonet_protocols.h
--- 5.5-3/xlat/phonet_protocols.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/phonet_protocols.h	2020-09-24 09:18:45.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data phonet_protocols_xdata[] = {
  [PN_PROTO_TRANSPORT] = XLAT(PN_PROTO_TRANSPORT),
+ #define XLAT_VAL_0 ((unsigned) (PN_PROTO_TRANSPORT))
+ #define XLAT_STR_0 STRINGIFY(PN_PROTO_TRANSPORT)
  [PN_PROTO_PHONET] = XLAT(PN_PROTO_PHONET),
+ #define XLAT_VAL_1 ((unsigned) (PN_PROTO_PHONET))
+ #define XLAT_STR_1 STRINGIFY(PN_PROTO_PHONET)
  [PN_PROTO_PIPE] = XLAT(PN_PROTO_PIPE),
+ #define XLAT_VAL_2 ((unsigned) (PN_PROTO_PIPE))
+ #define XLAT_STR_2 STRINGIFY(PN_PROTO_PIPE)
 };
 static
 const struct xlat phonet_protocols[1] = { {
  .data = phonet_protocols_xdata,
  .size = ARRAY_SIZE(phonet_protocols_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/pkey_access.h 5.9-0ubuntu2/xlat/pkey_access.h
--- 5.5-3/xlat/pkey_access.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/pkey_access.h	2020-09-24 09:18:45.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data pkey_access_xdata[] = {
  XLAT(PKEY_DISABLE_ACCESS),
+ #define XLAT_VAL_0 ((unsigned) (PKEY_DISABLE_ACCESS))
+ #define XLAT_STR_0 STRINGIFY(PKEY_DISABLE_ACCESS)
  XLAT(PKEY_DISABLE_WRITE),
+ #define XLAT_VAL_1 ((unsigned) (PKEY_DISABLE_WRITE))
+ #define XLAT_STR_1 STRINGIFY(PKEY_DISABLE_WRITE)
  XLAT(PKEY_DISABLE_EXECUTE),
+ #define XLAT_VAL_2 ((unsigned) (PKEY_DISABLE_EXECUTE))
+ #define XLAT_STR_2 STRINGIFY(PKEY_DISABLE_EXECUTE)
 };
 static
 const struct xlat pkey_access[1] = { {
  .data = pkey_access_xdata,
  .size = ARRAY_SIZE(pkey_access_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/pollflags.h 5.9-0ubuntu2/xlat/pollflags.h
--- 5.5-3/xlat/pollflags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/pollflags.h	2020-09-24 09:18:45.000000000 +0000
@@ -159,54 +159,248 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data pollflags_xdata[] = {
  XLAT(POLLIN),
+ #define XLAT_VAL_0 ((unsigned) (POLLIN))
+ #define XLAT_STR_0 STRINGIFY(POLLIN)
  XLAT(POLLPRI),
+ #define XLAT_VAL_1 ((unsigned) (POLLPRI))
+ #define XLAT_STR_1 STRINGIFY(POLLPRI)
  XLAT(POLLOUT),
+ #define XLAT_VAL_2 ((unsigned) (POLLOUT))
+ #define XLAT_STR_2 STRINGIFY(POLLOUT)
  XLAT(POLLERR),
+ #define XLAT_VAL_3 ((unsigned) (POLLERR))
+ #define XLAT_STR_3 STRINGIFY(POLLERR)
  XLAT(POLLHUP),
+ #define XLAT_VAL_4 ((unsigned) (POLLHUP))
+ #define XLAT_STR_4 STRINGIFY(POLLHUP)
  XLAT(POLLNVAL),
+ #define XLAT_VAL_5 ((unsigned) (POLLNVAL))
+ #define XLAT_STR_5 STRINGIFY(POLLNVAL)
  XLAT(POLLRDNORM),
+ #define XLAT_VAL_6 ((unsigned) (POLLRDNORM))
+ #define XLAT_STR_6 STRINGIFY(POLLRDNORM)
  XLAT(POLLRDBAND),
+ #define XLAT_VAL_7 ((unsigned) (POLLRDBAND))
+ #define XLAT_STR_7 STRINGIFY(POLLRDBAND)
 
 #if defined(__m68k__) || defined(__mips__) || defined(__sparc__) || defined(__xtensa__)
 
 #else
  XLAT(POLLWRNORM),
+ #define XLAT_VAL_8 ((unsigned) (POLLWRNORM))
+ #define XLAT_STR_8 STRINGIFY(POLLWRNORM)
 #endif
 
 #if defined(__m68k__) || defined(__mips__) || defined(__sparc__) || defined(__xtensa__)
  XLAT(POLLWRBAND),
+ #define XLAT_VAL_9 ((unsigned) (POLLWRBAND))
+ #define XLAT_STR_9 STRINGIFY(POLLWRBAND)
 #else
  XLAT(POLLWRBAND),
+ #define XLAT_VAL_10 ((unsigned) (POLLWRBAND))
+ #define XLAT_STR_10 STRINGIFY(POLLWRBAND)
 #endif
 
 #if defined(__sparc__)
  XLAT(POLLMSG),
+ #define XLAT_VAL_11 ((unsigned) (POLLMSG))
+ #define XLAT_STR_11 STRINGIFY(POLLMSG)
 #else
  XLAT(POLLMSG),
+ #define XLAT_VAL_12 ((unsigned) (POLLMSG))
+ #define XLAT_STR_12 STRINGIFY(POLLMSG)
 #endif
 
 #if defined(__sparc__)
  XLAT(POLLREMOVE),
+ #define XLAT_VAL_13 ((unsigned) (POLLREMOVE))
+ #define XLAT_STR_13 STRINGIFY(POLLREMOVE)
 #elif defined(__xtensa__)
  XLAT(POLLREMOVE),
+ #define XLAT_VAL_14 ((unsigned) (POLLREMOVE))
+ #define XLAT_STR_14 STRINGIFY(POLLREMOVE)
 #else
  XLAT(POLLREMOVE),
+ #define XLAT_VAL_15 ((unsigned) (POLLREMOVE))
+ #define XLAT_STR_15 STRINGIFY(POLLREMOVE)
 #endif
 
 #if defined(__sparc__)
  XLAT(POLLRDHUP),
+ #define XLAT_VAL_16 ((unsigned) (POLLRDHUP))
+ #define XLAT_STR_16 STRINGIFY(POLLRDHUP)
 #else
  XLAT(POLLRDHUP),
+ #define XLAT_VAL_17 ((unsigned) (POLLRDHUP))
+ #define XLAT_STR_17 STRINGIFY(POLLRDHUP)
 #endif
 
  XLAT(POLL_BUSY_LOOP),
+ #define XLAT_VAL_18 ((unsigned) (POLL_BUSY_LOOP))
+ #define XLAT_STR_18 STRINGIFY(POLL_BUSY_LOOP)
 };
 const struct xlat pollflags[1] = { {
  .data = pollflags_xdata,
  .size = ARRAY_SIZE(pollflags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/pr_cap_ambient.h 5.9-0ubuntu2/xlat/pr_cap_ambient.h
--- 5.5-3/xlat/pr_cap_ambient.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/pr_cap_ambient.h	2020-09-24 09:18:45.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data pr_cap_ambient_xdata[] = {
  [PR_CAP_AMBIENT_IS_SET] = XLAT(PR_CAP_AMBIENT_IS_SET),
+ #define XLAT_VAL_0 ((unsigned) (PR_CAP_AMBIENT_IS_SET))
+ #define XLAT_STR_0 STRINGIFY(PR_CAP_AMBIENT_IS_SET)
  [PR_CAP_AMBIENT_RAISE] = XLAT(PR_CAP_AMBIENT_RAISE),
+ #define XLAT_VAL_1 ((unsigned) (PR_CAP_AMBIENT_RAISE))
+ #define XLAT_STR_1 STRINGIFY(PR_CAP_AMBIENT_RAISE)
  [PR_CAP_AMBIENT_LOWER] = XLAT(PR_CAP_AMBIENT_LOWER),
+ #define XLAT_VAL_2 ((unsigned) (PR_CAP_AMBIENT_LOWER))
+ #define XLAT_STR_2 STRINGIFY(PR_CAP_AMBIENT_LOWER)
  [PR_CAP_AMBIENT_CLEAR_ALL] = XLAT(PR_CAP_AMBIENT_CLEAR_ALL),
+ #define XLAT_VAL_3 ((unsigned) (PR_CAP_AMBIENT_CLEAR_ALL))
+ #define XLAT_STR_3 STRINGIFY(PR_CAP_AMBIENT_CLEAR_ALL)
 };
 static
 const struct xlat pr_cap_ambient[1] = { {
  .data = pr_cap_ambient_xdata,
  .size = ARRAY_SIZE(pr_cap_ambient_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/prctl_options.h 5.9-0ubuntu2/xlat/prctl_options.h
--- 5.5-3/xlat/prctl_options.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/prctl_options.h	2020-09-24 09:18:46.000000000 +0000
@@ -234,13 +234,6 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define PR_SET_MM 35
 #endif
-#if defined(PR_SET_PTRACER) || (defined(HAVE_DECL_PR_SET_PTRACER) && HAVE_DECL_PR_SET_PTRACER)
-DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
-static_assert((PR_SET_PTRACER) == (0x59616d61), "PR_SET_PTRACER != 0x59616d61");
-DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
-#else
-# define PR_SET_PTRACER 0x59616d61
-#endif
 #if defined(PR_SET_CHILD_SUBREAPER) || (defined(HAVE_DECL_PR_SET_CHILD_SUBREAPER) && HAVE_DECL_PR_SET_CHILD_SUBREAPER)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
 static_assert((PR_SET_CHILD_SUBREAPER) == (36), "PR_SET_CHILD_SUBREAPER != 36");
@@ -374,6 +367,20 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define PR_GET_TAGGED_ADDR_CTRL 56
 #endif
+#if defined(PR_SET_IO_FLUSHER) || (defined(HAVE_DECL_PR_SET_IO_FLUSHER) && HAVE_DECL_PR_SET_IO_FLUSHER)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((PR_SET_IO_FLUSHER) == (57), "PR_SET_IO_FLUSHER != 57");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define PR_SET_IO_FLUSHER 57
+#endif
+#if defined(PR_GET_IO_FLUSHER) || (defined(HAVE_DECL_PR_GET_IO_FLUSHER) && HAVE_DECL_PR_GET_IO_FLUSHER)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((PR_GET_IO_FLUSHER) == (58), "PR_GET_IO_FLUSHER != 58");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define PR_GET_IO_FLUSHER 58
+#endif
 #if defined(PR_SET_VMA) || (defined(HAVE_DECL_PR_SET_VMA) && HAVE_DECL_PR_SET_VMA)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
 static_assert((PR_SET_VMA) == (0x53564d41), "PR_SET_VMA != 0x53564d41");
@@ -381,6 +388,13 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define PR_SET_VMA 0x53564d41
 #endif
+#if defined(PR_SET_PTRACER) || (defined(HAVE_DECL_PR_SET_PTRACER) && HAVE_DECL_PR_SET_PTRACER)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((PR_SET_PTRACER) == (0x59616d61), "PR_SET_PTRACER != 0x59616d61");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define PR_SET_PTRACER 0x59616d61
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -392,67 +406,633 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data prctl_options_xdata[] = {
  XLAT(PR_SET_PDEATHSIG),
+ #define XLAT_VAL_0 ((unsigned) (PR_SET_PDEATHSIG))
+ #define XLAT_STR_0 STRINGIFY(PR_SET_PDEATHSIG)
  XLAT(PR_GET_PDEATHSIG),
+ #define XLAT_VAL_1 ((unsigned) (PR_GET_PDEATHSIG))
+ #define XLAT_STR_1 STRINGIFY(PR_GET_PDEATHSIG)
  XLAT(PR_GET_DUMPABLE),
+ #define XLAT_VAL_2 ((unsigned) (PR_GET_DUMPABLE))
+ #define XLAT_STR_2 STRINGIFY(PR_GET_DUMPABLE)
  XLAT(PR_SET_DUMPABLE),
+ #define XLAT_VAL_3 ((unsigned) (PR_SET_DUMPABLE))
+ #define XLAT_STR_3 STRINGIFY(PR_SET_DUMPABLE)
  XLAT(PR_GET_UNALIGN),
+ #define XLAT_VAL_4 ((unsigned) (PR_GET_UNALIGN))
+ #define XLAT_STR_4 STRINGIFY(PR_GET_UNALIGN)
  XLAT(PR_SET_UNALIGN),
+ #define XLAT_VAL_5 ((unsigned) (PR_SET_UNALIGN))
+ #define XLAT_STR_5 STRINGIFY(PR_SET_UNALIGN)
  XLAT(PR_GET_KEEPCAPS),
+ #define XLAT_VAL_6 ((unsigned) (PR_GET_KEEPCAPS))
+ #define XLAT_STR_6 STRINGIFY(PR_GET_KEEPCAPS)
  XLAT(PR_SET_KEEPCAPS),
+ #define XLAT_VAL_7 ((unsigned) (PR_SET_KEEPCAPS))
+ #define XLAT_STR_7 STRINGIFY(PR_SET_KEEPCAPS)
  XLAT(PR_GET_FPEMU),
+ #define XLAT_VAL_8 ((unsigned) (PR_GET_FPEMU))
+ #define XLAT_STR_8 STRINGIFY(PR_GET_FPEMU)
  XLAT(PR_SET_FPEMU),
+ #define XLAT_VAL_9 ((unsigned) (PR_SET_FPEMU))
+ #define XLAT_STR_9 STRINGIFY(PR_SET_FPEMU)
  XLAT(PR_GET_FPEXC),
+ #define XLAT_VAL_10 ((unsigned) (PR_GET_FPEXC))
+ #define XLAT_STR_10 STRINGIFY(PR_GET_FPEXC)
  XLAT(PR_SET_FPEXC),
+ #define XLAT_VAL_11 ((unsigned) (PR_SET_FPEXC))
+ #define XLAT_STR_11 STRINGIFY(PR_SET_FPEXC)
  XLAT(PR_GET_TIMING),
+ #define XLAT_VAL_12 ((unsigned) (PR_GET_TIMING))
+ #define XLAT_STR_12 STRINGIFY(PR_GET_TIMING)
  XLAT(PR_SET_TIMING),
+ #define XLAT_VAL_13 ((unsigned) (PR_SET_TIMING))
+ #define XLAT_STR_13 STRINGIFY(PR_SET_TIMING)
  XLAT(PR_SET_NAME),
+ #define XLAT_VAL_14 ((unsigned) (PR_SET_NAME))
+ #define XLAT_STR_14 STRINGIFY(PR_SET_NAME)
  XLAT(PR_GET_NAME),
+ #define XLAT_VAL_15 ((unsigned) (PR_GET_NAME))
+ #define XLAT_STR_15 STRINGIFY(PR_GET_NAME)
  XLAT(PR_GET_ENDIAN),
+ #define XLAT_VAL_16 ((unsigned) (PR_GET_ENDIAN))
+ #define XLAT_STR_16 STRINGIFY(PR_GET_ENDIAN)
  XLAT(PR_SET_ENDIAN),
+ #define XLAT_VAL_17 ((unsigned) (PR_SET_ENDIAN))
+ #define XLAT_STR_17 STRINGIFY(PR_SET_ENDIAN)
  XLAT(PR_GET_SECCOMP),
+ #define XLAT_VAL_18 ((unsigned) (PR_GET_SECCOMP))
+ #define XLAT_STR_18 STRINGIFY(PR_GET_SECCOMP)
  XLAT(PR_SET_SECCOMP),
+ #define XLAT_VAL_19 ((unsigned) (PR_SET_SECCOMP))
+ #define XLAT_STR_19 STRINGIFY(PR_SET_SECCOMP)
  XLAT(PR_CAPBSET_READ),
+ #define XLAT_VAL_20 ((unsigned) (PR_CAPBSET_READ))
+ #define XLAT_STR_20 STRINGIFY(PR_CAPBSET_READ)
  XLAT(PR_CAPBSET_DROP),
+ #define XLAT_VAL_21 ((unsigned) (PR_CAPBSET_DROP))
+ #define XLAT_STR_21 STRINGIFY(PR_CAPBSET_DROP)
  XLAT(PR_GET_TSC),
+ #define XLAT_VAL_22 ((unsigned) (PR_GET_TSC))
+ #define XLAT_STR_22 STRINGIFY(PR_GET_TSC)
  XLAT(PR_SET_TSC),
+ #define XLAT_VAL_23 ((unsigned) (PR_SET_TSC))
+ #define XLAT_STR_23 STRINGIFY(PR_SET_TSC)
  XLAT(PR_GET_SECUREBITS),
+ #define XLAT_VAL_24 ((unsigned) (PR_GET_SECUREBITS))
+ #define XLAT_STR_24 STRINGIFY(PR_GET_SECUREBITS)
  XLAT(PR_SET_SECUREBITS),
+ #define XLAT_VAL_25 ((unsigned) (PR_SET_SECUREBITS))
+ #define XLAT_STR_25 STRINGIFY(PR_SET_SECUREBITS)
  XLAT(PR_SET_TIMERSLACK),
+ #define XLAT_VAL_26 ((unsigned) (PR_SET_TIMERSLACK))
+ #define XLAT_STR_26 STRINGIFY(PR_SET_TIMERSLACK)
  XLAT(PR_GET_TIMERSLACK),
+ #define XLAT_VAL_27 ((unsigned) (PR_GET_TIMERSLACK))
+ #define XLAT_STR_27 STRINGIFY(PR_GET_TIMERSLACK)
  XLAT(PR_TASK_PERF_EVENTS_DISABLE),
+ #define XLAT_VAL_28 ((unsigned) (PR_TASK_PERF_EVENTS_DISABLE))
+ #define XLAT_STR_28 STRINGIFY(PR_TASK_PERF_EVENTS_DISABLE)
  XLAT(PR_TASK_PERF_EVENTS_ENABLE),
+ #define XLAT_VAL_29 ((unsigned) (PR_TASK_PERF_EVENTS_ENABLE))
+ #define XLAT_STR_29 STRINGIFY(PR_TASK_PERF_EVENTS_ENABLE)
  XLAT(PR_MCE_KILL),
+ #define XLAT_VAL_30 ((unsigned) (PR_MCE_KILL))
+ #define XLAT_STR_30 STRINGIFY(PR_MCE_KILL)
  XLAT(PR_MCE_KILL_GET),
+ #define XLAT_VAL_31 ((unsigned) (PR_MCE_KILL_GET))
+ #define XLAT_STR_31 STRINGIFY(PR_MCE_KILL_GET)
  XLAT(PR_SET_MM),
- XLAT(PR_SET_PTRACER),
+ #define XLAT_VAL_32 ((unsigned) (PR_SET_MM))
+ #define XLAT_STR_32 STRINGIFY(PR_SET_MM)
  XLAT(PR_SET_CHILD_SUBREAPER),
+ #define XLAT_VAL_33 ((unsigned) (PR_SET_CHILD_SUBREAPER))
+ #define XLAT_STR_33 STRINGIFY(PR_SET_CHILD_SUBREAPER)
  XLAT(PR_GET_CHILD_SUBREAPER),
+ #define XLAT_VAL_34 ((unsigned) (PR_GET_CHILD_SUBREAPER))
+ #define XLAT_STR_34 STRINGIFY(PR_GET_CHILD_SUBREAPER)
  XLAT(PR_SET_NO_NEW_PRIVS),
+ #define XLAT_VAL_35 ((unsigned) (PR_SET_NO_NEW_PRIVS))
+ #define XLAT_STR_35 STRINGIFY(PR_SET_NO_NEW_PRIVS)
  XLAT(PR_GET_NO_NEW_PRIVS),
+ #define XLAT_VAL_36 ((unsigned) (PR_GET_NO_NEW_PRIVS))
+ #define XLAT_STR_36 STRINGIFY(PR_GET_NO_NEW_PRIVS)
  XLAT(PR_GET_TID_ADDRESS),
+ #define XLAT_VAL_37 ((unsigned) (PR_GET_TID_ADDRESS))
+ #define XLAT_STR_37 STRINGIFY(PR_GET_TID_ADDRESS)
  XLAT(PR_SET_THP_DISABLE),
+ #define XLAT_VAL_38 ((unsigned) (PR_SET_THP_DISABLE))
+ #define XLAT_STR_38 STRINGIFY(PR_SET_THP_DISABLE)
  XLAT(PR_GET_THP_DISABLE),
+ #define XLAT_VAL_39 ((unsigned) (PR_GET_THP_DISABLE))
+ #define XLAT_STR_39 STRINGIFY(PR_GET_THP_DISABLE)
  XLAT(PR_MPX_ENABLE_MANAGEMENT),
+ #define XLAT_VAL_40 ((unsigned) (PR_MPX_ENABLE_MANAGEMENT))
+ #define XLAT_STR_40 STRINGIFY(PR_MPX_ENABLE_MANAGEMENT)
  XLAT(PR_MPX_DISABLE_MANAGEMENT),
+ #define XLAT_VAL_41 ((unsigned) (PR_MPX_DISABLE_MANAGEMENT))
+ #define XLAT_STR_41 STRINGIFY(PR_MPX_DISABLE_MANAGEMENT)
  XLAT(PR_SET_FP_MODE),
+ #define XLAT_VAL_42 ((unsigned) (PR_SET_FP_MODE))
+ #define XLAT_STR_42 STRINGIFY(PR_SET_FP_MODE)
  XLAT(PR_GET_FP_MODE),
+ #define XLAT_VAL_43 ((unsigned) (PR_GET_FP_MODE))
+ #define XLAT_STR_43 STRINGIFY(PR_GET_FP_MODE)
  XLAT(PR_CAP_AMBIENT),
+ #define XLAT_VAL_44 ((unsigned) (PR_CAP_AMBIENT))
+ #define XLAT_STR_44 STRINGIFY(PR_CAP_AMBIENT)
  XLAT(PR_SVE_SET_VL),
+ #define XLAT_VAL_45 ((unsigned) (PR_SVE_SET_VL))
+ #define XLAT_STR_45 STRINGIFY(PR_SVE_SET_VL)
  XLAT(PR_SVE_GET_VL),
+ #define XLAT_VAL_46 ((unsigned) (PR_SVE_GET_VL))
+ #define XLAT_STR_46 STRINGIFY(PR_SVE_GET_VL)
  XLAT(PR_GET_SPECULATION_CTRL),
+ #define XLAT_VAL_47 ((unsigned) (PR_GET_SPECULATION_CTRL))
+ #define XLAT_STR_47 STRINGIFY(PR_GET_SPECULATION_CTRL)
  XLAT(PR_SET_SPECULATION_CTRL),
+ #define XLAT_VAL_48 ((unsigned) (PR_SET_SPECULATION_CTRL))
+ #define XLAT_STR_48 STRINGIFY(PR_SET_SPECULATION_CTRL)
  XLAT(PR_PAC_RESET_KEYS),
+ #define XLAT_VAL_49 ((unsigned) (PR_PAC_RESET_KEYS))
+ #define XLAT_STR_49 STRINGIFY(PR_PAC_RESET_KEYS)
  XLAT(PR_SET_TAGGED_ADDR_CTRL),
+ #define XLAT_VAL_50 ((unsigned) (PR_SET_TAGGED_ADDR_CTRL))
+ #define XLAT_STR_50 STRINGIFY(PR_SET_TAGGED_ADDR_CTRL)
  XLAT(PR_GET_TAGGED_ADDR_CTRL),
+ #define XLAT_VAL_51 ((unsigned) (PR_GET_TAGGED_ADDR_CTRL))
+ #define XLAT_STR_51 STRINGIFY(PR_GET_TAGGED_ADDR_CTRL)
+ XLAT(PR_SET_IO_FLUSHER),
+ #define XLAT_VAL_52 ((unsigned) (PR_SET_IO_FLUSHER))
+ #define XLAT_STR_52 STRINGIFY(PR_SET_IO_FLUSHER)
+ XLAT(PR_GET_IO_FLUSHER),
+ #define XLAT_VAL_53 ((unsigned) (PR_GET_IO_FLUSHER))
+ #define XLAT_STR_53 STRINGIFY(PR_GET_IO_FLUSHER)
  XLAT(PR_SET_VMA),
+ #define XLAT_VAL_54 ((unsigned) (PR_SET_VMA))
+ #define XLAT_STR_54 STRINGIFY(PR_SET_VMA)
+ XLAT(PR_SET_PTRACER),
+ #define XLAT_VAL_55 ((unsigned) (PR_SET_PTRACER))
+ #define XLAT_STR_55 STRINGIFY(PR_SET_PTRACER)
 };
 static
 const struct xlat prctl_options[1] = { {
  .data = prctl_options_xdata,
  .size = ARRAY_SIZE(prctl_options_xdata),
- .type = XT_NORMAL,
+ .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+#  ifdef XLAT_VAL_47
+  | XLAT_VAL_47
+#  endif
+#  ifdef XLAT_VAL_48
+  | XLAT_VAL_48
+#  endif
+#  ifdef XLAT_VAL_49
+  | XLAT_VAL_49
+#  endif
+#  ifdef XLAT_VAL_50
+  | XLAT_VAL_50
+#  endif
+#  ifdef XLAT_VAL_51
+  | XLAT_VAL_51
+#  endif
+#  ifdef XLAT_VAL_52
+  | XLAT_VAL_52
+#  endif
+#  ifdef XLAT_VAL_53
+  | XLAT_VAL_53
+#  endif
+#  ifdef XLAT_VAL_54
+  | XLAT_VAL_54
+#  endif
+#  ifdef XLAT_VAL_55
+  | XLAT_VAL_55
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+#  ifdef XLAT_STR_47
+  + sizeof(XLAT_STR_47)
+#  endif
+#  ifdef XLAT_STR_48
+  + sizeof(XLAT_STR_48)
+#  endif
+#  ifdef XLAT_STR_49
+  + sizeof(XLAT_STR_49)
+#  endif
+#  ifdef XLAT_STR_50
+  + sizeof(XLAT_STR_50)
+#  endif
+#  ifdef XLAT_STR_51
+  + sizeof(XLAT_STR_51)
+#  endif
+#  ifdef XLAT_STR_52
+  + sizeof(XLAT_STR_52)
+#  endif
+#  ifdef XLAT_STR_53
+  + sizeof(XLAT_STR_53)
+#  endif
+#  ifdef XLAT_STR_54
+  + sizeof(XLAT_STR_54)
+#  endif
+#  ifdef XLAT_STR_55
+  + sizeof(XLAT_STR_55)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
+#  undef XLAT_STR_47
+#  undef XLAT_VAL_47
+#  undef XLAT_STR_48
+#  undef XLAT_VAL_48
+#  undef XLAT_STR_49
+#  undef XLAT_VAL_49
+#  undef XLAT_STR_50
+#  undef XLAT_VAL_50
+#  undef XLAT_STR_51
+#  undef XLAT_VAL_51
+#  undef XLAT_STR_52
+#  undef XLAT_VAL_52
+#  undef XLAT_STR_53
+#  undef XLAT_VAL_53
+#  undef XLAT_STR_54
+#  undef XLAT_VAL_54
+#  undef XLAT_STR_55
+#  undef XLAT_VAL_55
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/prctl_options.in 5.9-0ubuntu2/xlat/prctl_options.in
--- 5.5-3/xlat/prctl_options.in	2019-11-15 00:14:32.000000000 +0000
+++ 5.9-0ubuntu2/xlat/prctl_options.in	2020-03-23 03:19:09.000000000 +0000
@@ -1,54 +1,57 @@
-PR_SET_PDEATHSIG 1
-PR_GET_PDEATHSIG 2
-PR_GET_DUMPABLE 3
-PR_SET_DUMPABLE 4
-PR_GET_UNALIGN 5
-PR_SET_UNALIGN 6
-PR_GET_KEEPCAPS 7
-PR_SET_KEEPCAPS 8
-PR_GET_FPEMU 9
-PR_SET_FPEMU 10
-PR_GET_FPEXC 11
-PR_SET_FPEXC 12
-PR_GET_TIMING 13
-PR_SET_TIMING 14
-PR_SET_NAME 15
-PR_GET_NAME 16
-PR_GET_ENDIAN 19
-PR_SET_ENDIAN 20
-PR_GET_SECCOMP 21
-PR_SET_SECCOMP 22
-PR_CAPBSET_READ 23
-PR_CAPBSET_DROP 24
-PR_GET_TSC 25
-PR_SET_TSC 26
-PR_GET_SECUREBITS 27
-PR_SET_SECUREBITS 28
-PR_SET_TIMERSLACK 29
-PR_GET_TIMERSLACK 30
-PR_TASK_PERF_EVENTS_DISABLE 31
-PR_TASK_PERF_EVENTS_ENABLE 32
-PR_MCE_KILL 33
-PR_MCE_KILL_GET 34
-PR_SET_MM 35
-PR_SET_PTRACER 0x59616d61
-PR_SET_CHILD_SUBREAPER 36
-PR_GET_CHILD_SUBREAPER 37
-PR_SET_NO_NEW_PRIVS 38
-PR_GET_NO_NEW_PRIVS 39
-PR_GET_TID_ADDRESS 40
-PR_SET_THP_DISABLE 41
-PR_GET_THP_DISABLE 42
-PR_MPX_ENABLE_MANAGEMENT 43
-PR_MPX_DISABLE_MANAGEMENT 44
-PR_SET_FP_MODE 45
-PR_GET_FP_MODE 46
-PR_CAP_AMBIENT 47
-PR_SVE_SET_VL 50
-PR_SVE_GET_VL 51
-PR_GET_SPECULATION_CTRL 52
-PR_SET_SPECULATION_CTRL 53
-PR_PAC_RESET_KEYS 54
-PR_SET_TAGGED_ADDR_CTRL 55
-PR_GET_TAGGED_ADDR_CTRL 56
-PR_SET_VMA 0x53564d41
+#sorted
+PR_SET_PDEATHSIG		1
+PR_GET_PDEATHSIG		2
+PR_GET_DUMPABLE			3
+PR_SET_DUMPABLE			4
+PR_GET_UNALIGN			5
+PR_SET_UNALIGN			6
+PR_GET_KEEPCAPS			7
+PR_SET_KEEPCAPS			8
+PR_GET_FPEMU			9
+PR_SET_FPEMU			10
+PR_GET_FPEXC			11
+PR_SET_FPEXC			12
+PR_GET_TIMING			13
+PR_SET_TIMING			14
+PR_SET_NAME			15
+PR_GET_NAME			16
+PR_GET_ENDIAN			19
+PR_SET_ENDIAN			20
+PR_GET_SECCOMP			21
+PR_SET_SECCOMP			22
+PR_CAPBSET_READ			23
+PR_CAPBSET_DROP			24
+PR_GET_TSC			25
+PR_SET_TSC			26
+PR_GET_SECUREBITS		27
+PR_SET_SECUREBITS		28
+PR_SET_TIMERSLACK		29
+PR_GET_TIMERSLACK		30
+PR_TASK_PERF_EVENTS_DISABLE	31
+PR_TASK_PERF_EVENTS_ENABLE	32
+PR_MCE_KILL			33
+PR_MCE_KILL_GET			34
+PR_SET_MM			35
+PR_SET_CHILD_SUBREAPER		36
+PR_GET_CHILD_SUBREAPER		37
+PR_SET_NO_NEW_PRIVS		38
+PR_GET_NO_NEW_PRIVS		39
+PR_GET_TID_ADDRESS		40
+PR_SET_THP_DISABLE		41
+PR_GET_THP_DISABLE		42
+PR_MPX_ENABLE_MANAGEMENT	43
+PR_MPX_DISABLE_MANAGEMENT	44
+PR_SET_FP_MODE			45
+PR_GET_FP_MODE			46
+PR_CAP_AMBIENT			47
+PR_SVE_SET_VL			50
+PR_SVE_GET_VL			51
+PR_GET_SPECULATION_CTRL		52
+PR_SET_SPECULATION_CTRL		53
+PR_PAC_RESET_KEYS		54
+PR_SET_TAGGED_ADDR_CTRL		55
+PR_GET_TAGGED_ADDR_CTRL		56
+PR_SET_IO_FLUSHER		57
+PR_GET_IO_FLUSHER		58
+PR_SET_VMA			0x53564d41 /* "SVMA" */
+PR_SET_PTRACER			0x59616d61 /* "Yama" */
diff -pruN 5.5-3/xlat/pr_dumpable.h 5.9-0ubuntu2/xlat/pr_dumpable.h
--- 5.5-3/xlat/pr_dumpable.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/pr_dumpable.h	2020-09-24 09:18:45.000000000 +0000
@@ -36,16 +36,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 static const struct xlat_data pr_dumpable_xdata[] = {
 
  [SUID_DUMP_DISABLE] = XLAT(SUID_DUMP_DISABLE),
+ #define XLAT_VAL_0 ((unsigned) (SUID_DUMP_DISABLE))
+ #define XLAT_STR_0 STRINGIFY(SUID_DUMP_DISABLE)
  [SUID_DUMP_USER] = XLAT(SUID_DUMP_USER),
+ #define XLAT_VAL_1 ((unsigned) (SUID_DUMP_USER))
+ #define XLAT_STR_1 STRINGIFY(SUID_DUMP_USER)
  [SUID_DUMP_ROOT] = XLAT(SUID_DUMP_ROOT),
+ #define XLAT_VAL_2 ((unsigned) (SUID_DUMP_ROOT))
+ #define XLAT_STR_2 STRINGIFY(SUID_DUMP_ROOT)
 };
 static
 const struct xlat pr_dumpable[1] = { {
  .data = pr_dumpable_xdata,
  .size = ARRAY_SIZE(pr_dumpable_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/pr_fp_mode.h 5.9-0ubuntu2/xlat/pr_fp_mode.h
--- 5.5-3/xlat/pr_fp_mode.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/pr_fp_mode.h	2020-09-24 09:18:45.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data pr_fp_mode_xdata[] = {
  XLAT(PR_FP_MODE_FR),
+ #define XLAT_VAL_0 ((unsigned) (PR_FP_MODE_FR))
+ #define XLAT_STR_0 STRINGIFY(PR_FP_MODE_FR)
  XLAT(PR_FP_MODE_FRE),
+ #define XLAT_VAL_1 ((unsigned) (PR_FP_MODE_FRE))
+ #define XLAT_STR_1 STRINGIFY(PR_FP_MODE_FRE)
 };
 static
 const struct xlat pr_fp_mode[1] = { {
  .data = pr_fp_mode_xdata,
  .size = ARRAY_SIZE(pr_fp_mode_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/priorities.h 5.9-0ubuntu2/xlat/priorities.h
--- 5.5-3/xlat/priorities.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/priorities.h	2020-09-24 09:18:45.000000000 +0000
@@ -15,12 +15,18 @@
 static const struct xlat_data priorities_xdata[] = {
 #if defined(PRIO_PROCESS) || (defined(HAVE_DECL_PRIO_PROCESS) && HAVE_DECL_PRIO_PROCESS)
   XLAT(PRIO_PROCESS),
+ #define XLAT_VAL_0 ((unsigned) (PRIO_PROCESS))
+ #define XLAT_STR_0 STRINGIFY(PRIO_PROCESS)
 #endif
 #if defined(PRIO_PGRP) || (defined(HAVE_DECL_PRIO_PGRP) && HAVE_DECL_PRIO_PGRP)
   XLAT(PRIO_PGRP),
+ #define XLAT_VAL_1 ((unsigned) (PRIO_PGRP))
+ #define XLAT_STR_1 STRINGIFY(PRIO_PGRP)
 #endif
 #if defined(PRIO_USER) || (defined(HAVE_DECL_PRIO_USER) && HAVE_DECL_PRIO_USER)
   XLAT(PRIO_USER),
+ #define XLAT_VAL_2 ((unsigned) (PRIO_USER))
+ #define XLAT_STR_2 STRINGIFY(PRIO_USER)
 #endif
 };
 static
@@ -28,8 +34,36 @@ const struct xlat priorities[1] = { {
  .data = priorities_xdata,
  .size = ARRAY_SIZE(priorities_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/pr_mce_kill.h 5.9-0ubuntu2/xlat/pr_mce_kill.h
--- 5.5-3/xlat/pr_mce_kill.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/pr_mce_kill.h	2020-09-24 09:18:45.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data pr_mce_kill_xdata[] = {
  [PR_MCE_KILL_CLEAR] = XLAT(PR_MCE_KILL_CLEAR),
+ #define XLAT_VAL_0 ((unsigned) (PR_MCE_KILL_CLEAR))
+ #define XLAT_STR_0 STRINGIFY(PR_MCE_KILL_CLEAR)
  [PR_MCE_KILL_SET] = XLAT(PR_MCE_KILL_SET),
+ #define XLAT_VAL_1 ((unsigned) (PR_MCE_KILL_SET))
+ #define XLAT_STR_1 STRINGIFY(PR_MCE_KILL_SET)
 };
 static
 const struct xlat pr_mce_kill[1] = { {
  .data = pr_mce_kill_xdata,
  .size = ARRAY_SIZE(pr_mce_kill_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/pr_mce_kill_policy.h 5.9-0ubuntu2/xlat/pr_mce_kill_policy.h
--- 5.5-3/xlat/pr_mce_kill_policy.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/pr_mce_kill_policy.h	2020-09-24 09:18:45.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data pr_mce_kill_policy_xdata[] = {
  [PR_MCE_KILL_LATE] = XLAT(PR_MCE_KILL_LATE),
+ #define XLAT_VAL_0 ((unsigned) (PR_MCE_KILL_LATE))
+ #define XLAT_STR_0 STRINGIFY(PR_MCE_KILL_LATE)
  [PR_MCE_KILL_EARLY] = XLAT(PR_MCE_KILL_EARLY),
+ #define XLAT_VAL_1 ((unsigned) (PR_MCE_KILL_EARLY))
+ #define XLAT_STR_1 STRINGIFY(PR_MCE_KILL_EARLY)
  [PR_MCE_KILL_DEFAULT] = XLAT(PR_MCE_KILL_DEFAULT),
+ #define XLAT_VAL_2 ((unsigned) (PR_MCE_KILL_DEFAULT))
+ #define XLAT_STR_2 STRINGIFY(PR_MCE_KILL_DEFAULT)
 };
 static
 const struct xlat pr_mce_kill_policy[1] = { {
  .data = pr_mce_kill_policy_xdata,
  .size = ARRAY_SIZE(pr_mce_kill_policy_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/pr_set_mm.h 5.9-0ubuntu2/xlat/pr_set_mm.h
--- 5.5-3/xlat/pr_set_mm.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/pr_set_mm.h	2020-09-24 09:18:45.000000000 +0000
@@ -119,28 +119,182 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data pr_set_mm_xdata[] = {
  [PR_SET_MM_START_CODE] = XLAT(PR_SET_MM_START_CODE),
+ #define XLAT_VAL_0 ((unsigned) (PR_SET_MM_START_CODE))
+ #define XLAT_STR_0 STRINGIFY(PR_SET_MM_START_CODE)
  [PR_SET_MM_END_CODE] = XLAT(PR_SET_MM_END_CODE),
+ #define XLAT_VAL_1 ((unsigned) (PR_SET_MM_END_CODE))
+ #define XLAT_STR_1 STRINGIFY(PR_SET_MM_END_CODE)
  [PR_SET_MM_START_DATA] = XLAT(PR_SET_MM_START_DATA),
+ #define XLAT_VAL_2 ((unsigned) (PR_SET_MM_START_DATA))
+ #define XLAT_STR_2 STRINGIFY(PR_SET_MM_START_DATA)
  [PR_SET_MM_END_DATA] = XLAT(PR_SET_MM_END_DATA),
+ #define XLAT_VAL_3 ((unsigned) (PR_SET_MM_END_DATA))
+ #define XLAT_STR_3 STRINGIFY(PR_SET_MM_END_DATA)
  [PR_SET_MM_START_STACK] = XLAT(PR_SET_MM_START_STACK),
+ #define XLAT_VAL_4 ((unsigned) (PR_SET_MM_START_STACK))
+ #define XLAT_STR_4 STRINGIFY(PR_SET_MM_START_STACK)
  [PR_SET_MM_START_BRK] = XLAT(PR_SET_MM_START_BRK),
+ #define XLAT_VAL_5 ((unsigned) (PR_SET_MM_START_BRK))
+ #define XLAT_STR_5 STRINGIFY(PR_SET_MM_START_BRK)
  [PR_SET_MM_BRK] = XLAT(PR_SET_MM_BRK),
+ #define XLAT_VAL_6 ((unsigned) (PR_SET_MM_BRK))
+ #define XLAT_STR_6 STRINGIFY(PR_SET_MM_BRK)
  [PR_SET_MM_ARG_START] = XLAT(PR_SET_MM_ARG_START),
+ #define XLAT_VAL_7 ((unsigned) (PR_SET_MM_ARG_START))
+ #define XLAT_STR_7 STRINGIFY(PR_SET_MM_ARG_START)
  [PR_SET_MM_ARG_END] = XLAT(PR_SET_MM_ARG_END),
+ #define XLAT_VAL_8 ((unsigned) (PR_SET_MM_ARG_END))
+ #define XLAT_STR_8 STRINGIFY(PR_SET_MM_ARG_END)
  [PR_SET_MM_ENV_START] = XLAT(PR_SET_MM_ENV_START),
+ #define XLAT_VAL_9 ((unsigned) (PR_SET_MM_ENV_START))
+ #define XLAT_STR_9 STRINGIFY(PR_SET_MM_ENV_START)
  [PR_SET_MM_ENV_END] = XLAT(PR_SET_MM_ENV_END),
+ #define XLAT_VAL_10 ((unsigned) (PR_SET_MM_ENV_END))
+ #define XLAT_STR_10 STRINGIFY(PR_SET_MM_ENV_END)
  [PR_SET_MM_AUXV] = XLAT(PR_SET_MM_AUXV),
+ #define XLAT_VAL_11 ((unsigned) (PR_SET_MM_AUXV))
+ #define XLAT_STR_11 STRINGIFY(PR_SET_MM_AUXV)
  [PR_SET_MM_EXE_FILE] = XLAT(PR_SET_MM_EXE_FILE),
+ #define XLAT_VAL_12 ((unsigned) (PR_SET_MM_EXE_FILE))
+ #define XLAT_STR_12 STRINGIFY(PR_SET_MM_EXE_FILE)
  [PR_SET_MM_MAP] = XLAT(PR_SET_MM_MAP),
+ #define XLAT_VAL_13 ((unsigned) (PR_SET_MM_MAP))
+ #define XLAT_STR_13 STRINGIFY(PR_SET_MM_MAP)
  [PR_SET_MM_MAP_SIZE] = XLAT(PR_SET_MM_MAP_SIZE),
+ #define XLAT_VAL_14 ((unsigned) (PR_SET_MM_MAP_SIZE))
+ #define XLAT_STR_14 STRINGIFY(PR_SET_MM_MAP_SIZE)
 };
 static
 const struct xlat pr_set_mm[1] = { {
  .data = pr_set_mm_xdata,
  .size = ARRAY_SIZE(pr_set_mm_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/pr_spec_cmds.h 5.9-0ubuntu2/xlat/pr_spec_cmds.h
--- 5.5-3/xlat/pr_spec_cmds.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/pr_spec_cmds.h	2020-09-24 09:18:45.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data pr_spec_cmds_xdata[] = {
  [PR_SPEC_STORE_BYPASS] = XLAT(PR_SPEC_STORE_BYPASS),
+ #define XLAT_VAL_0 ((unsigned) (PR_SPEC_STORE_BYPASS))
+ #define XLAT_STR_0 STRINGIFY(PR_SPEC_STORE_BYPASS)
  [PR_SPEC_INDIRECT_BRANCH] = XLAT(PR_SPEC_INDIRECT_BRANCH),
+ #define XLAT_VAL_1 ((unsigned) (PR_SPEC_INDIRECT_BRANCH))
+ #define XLAT_STR_1 STRINGIFY(PR_SPEC_INDIRECT_BRANCH)
 };
 static
 const struct xlat pr_spec_cmds[1] = { {
  .data = pr_spec_cmds_xdata,
  .size = ARRAY_SIZE(pr_spec_cmds_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/pr_spec_get_store_bypass_flags.h 5.9-0ubuntu2/xlat/pr_spec_get_store_bypass_flags.h
--- 5.5-3/xlat/pr_spec_get_store_bypass_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/pr_spec_get_store_bypass_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -56,19 +56,83 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data pr_spec_get_store_bypass_flags_xdata[] = {
  XLAT(PR_SPEC_NOT_AFFECTED),
+ #define XLAT_VAL_0 ((unsigned) (PR_SPEC_NOT_AFFECTED))
+ #define XLAT_STR_0 STRINGIFY(PR_SPEC_NOT_AFFECTED)
  XLAT(PR_SPEC_PRCTL),
+ #define XLAT_VAL_1 ((unsigned) (PR_SPEC_PRCTL))
+ #define XLAT_STR_1 STRINGIFY(PR_SPEC_PRCTL)
  XLAT(PR_SPEC_ENABLE),
+ #define XLAT_VAL_2 ((unsigned) (PR_SPEC_ENABLE))
+ #define XLAT_STR_2 STRINGIFY(PR_SPEC_ENABLE)
  XLAT(PR_SPEC_DISABLE),
+ #define XLAT_VAL_3 ((unsigned) (PR_SPEC_DISABLE))
+ #define XLAT_STR_3 STRINGIFY(PR_SPEC_DISABLE)
  XLAT(PR_SPEC_FORCE_DISABLE),
+ #define XLAT_VAL_4 ((unsigned) (PR_SPEC_FORCE_DISABLE))
+ #define XLAT_STR_4 STRINGIFY(PR_SPEC_FORCE_DISABLE)
  XLAT(PR_SPEC_DISABLE_NOEXEC),
+ #define XLAT_VAL_5 ((unsigned) (PR_SPEC_DISABLE_NOEXEC))
+ #define XLAT_STR_5 STRINGIFY(PR_SPEC_DISABLE_NOEXEC)
 };
 static
 const struct xlat pr_spec_get_store_bypass_flags[1] = { {
  .data = pr_spec_get_store_bypass_flags_xdata,
  .size = ARRAY_SIZE(pr_spec_get_store_bypass_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/pr_spec_set_store_bypass_flags.h 5.9-0ubuntu2/xlat/pr_spec_set_store_bypass_flags.h
--- 5.5-3/xlat/pr_spec_set_store_bypass_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/pr_spec_set_store_bypass_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data pr_spec_set_store_bypass_flags_xdata[] = {
  XLAT(PR_SPEC_ENABLE),
+ #define XLAT_VAL_0 ((unsigned) (PR_SPEC_ENABLE))
+ #define XLAT_STR_0 STRINGIFY(PR_SPEC_ENABLE)
  XLAT(PR_SPEC_DISABLE),
+ #define XLAT_VAL_1 ((unsigned) (PR_SPEC_DISABLE))
+ #define XLAT_STR_1 STRINGIFY(PR_SPEC_DISABLE)
  XLAT(PR_SPEC_FORCE_DISABLE),
+ #define XLAT_VAL_2 ((unsigned) (PR_SPEC_FORCE_DISABLE))
+ #define XLAT_STR_2 STRINGIFY(PR_SPEC_FORCE_DISABLE)
  XLAT(PR_SPEC_DISABLE_NOEXEC),
+ #define XLAT_VAL_3 ((unsigned) (PR_SPEC_DISABLE_NOEXEC))
+ #define XLAT_STR_3 STRINGIFY(PR_SPEC_DISABLE_NOEXEC)
 };
 static
 const struct xlat pr_spec_set_store_bypass_flags[1] = { {
  .data = pr_spec_set_store_bypass_flags_xdata,
  .size = ARRAY_SIZE(pr_spec_set_store_bypass_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/pr_sve_vl_flags.h 5.9-0ubuntu2/xlat/pr_sve_vl_flags.h
--- 5.5-3/xlat/pr_sve_vl_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/pr_sve_vl_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data pr_sve_vl_flags_xdata[] = {
  XLAT(PR_SVE_SET_VL_ONEXEC),
+ #define XLAT_VAL_0 ((unsigned) (PR_SVE_SET_VL_ONEXEC))
+ #define XLAT_STR_0 STRINGIFY(PR_SVE_SET_VL_ONEXEC)
  XLAT(PR_SVE_VL_INHERIT),
+ #define XLAT_VAL_1 ((unsigned) (PR_SVE_VL_INHERIT))
+ #define XLAT_STR_1 STRINGIFY(PR_SVE_VL_INHERIT)
 };
 static
 const struct xlat pr_sve_vl_flags[1] = { {
  .data = pr_sve_vl_flags_xdata,
  .size = ARRAY_SIZE(pr_sve_vl_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/pr_tsc.h 5.9-0ubuntu2/xlat/pr_tsc.h
--- 5.5-3/xlat/pr_tsc.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/pr_tsc.h	2020-09-24 09:18:45.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data pr_tsc_xdata[] = {
  [PR_TSC_ENABLE] = XLAT(PR_TSC_ENABLE),
+ #define XLAT_VAL_0 ((unsigned) (PR_TSC_ENABLE))
+ #define XLAT_STR_0 STRINGIFY(PR_TSC_ENABLE)
  [PR_TSC_SIGSEGV] = XLAT(PR_TSC_SIGSEGV),
+ #define XLAT_VAL_1 ((unsigned) (PR_TSC_SIGSEGV))
+ #define XLAT_STR_1 STRINGIFY(PR_TSC_SIGSEGV)
 };
 static
 const struct xlat pr_tsc[1] = { {
  .data = pr_tsc_xdata,
  .size = ARRAY_SIZE(pr_tsc_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/pr_unalign_flags.h 5.9-0ubuntu2/xlat/pr_unalign_flags.h
--- 5.5-3/xlat/pr_unalign_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/pr_unalign_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data pr_unalign_flags_xdata[] = {
  XLAT(PR_UNALIGN_NOPRINT),
+ #define XLAT_VAL_0 ((unsigned) (PR_UNALIGN_NOPRINT))
+ #define XLAT_STR_0 STRINGIFY(PR_UNALIGN_NOPRINT)
  XLAT(PR_UNALIGN_SIGBUS),
+ #define XLAT_VAL_1 ((unsigned) (PR_UNALIGN_SIGBUS))
+ #define XLAT_STR_1 STRINGIFY(PR_UNALIGN_SIGBUS)
 };
 static
 const struct xlat pr_unalign_flags[1] = { {
  .data = pr_unalign_flags_xdata,
  .size = ARRAY_SIZE(pr_unalign_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ptp_extts_flags.h 5.9-0ubuntu2/xlat/ptp_extts_flags.h
--- 5.5-3/xlat/ptp_extts_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ptp_extts_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data ptp_extts_flags_xdata[] = {
  XLAT(PTP_ENABLE_FEATURE),
+ #define XLAT_VAL_0 ((unsigned) (PTP_ENABLE_FEATURE))
+ #define XLAT_STR_0 STRINGIFY(PTP_ENABLE_FEATURE)
  XLAT(PTP_RISING_EDGE),
+ #define XLAT_VAL_1 ((unsigned) (PTP_RISING_EDGE))
+ #define XLAT_STR_1 STRINGIFY(PTP_RISING_EDGE)
  XLAT(PTP_FALLING_EDGE),
+ #define XLAT_VAL_2 ((unsigned) (PTP_FALLING_EDGE))
+ #define XLAT_STR_2 STRINGIFY(PTP_FALLING_EDGE)
  XLAT(PTP_STRICT_FLAGS),
+ #define XLAT_VAL_3 ((unsigned) (PTP_STRICT_FLAGS))
+ #define XLAT_STR_3 STRINGIFY(PTP_STRICT_FLAGS)
 };
 static
 const struct xlat ptp_extts_flags[1] = { {
  .data = ptp_extts_flags_xdata,
  .size = ARRAY_SIZE(ptp_extts_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ptp_perout_flags.h 5.9-0ubuntu2/xlat/ptp_perout_flags.h
--- 5.5-3/xlat/ptp_perout_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ptp_perout_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -10,6 +10,20 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define PTP_PEROUT_ONE_SHOT (1<<0)
 #endif
+#if defined(PTP_PEROUT_DUTY_CYCLE) || (defined(HAVE_DECL_PTP_PEROUT_DUTY_CYCLE) && HAVE_DECL_PTP_PEROUT_DUTY_CYCLE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((PTP_PEROUT_DUTY_CYCLE) == ((1<<1)), "PTP_PEROUT_DUTY_CYCLE != (1<<1)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define PTP_PEROUT_DUTY_CYCLE (1<<1)
+#endif
+#if defined(PTP_PEROUT_PHASE) || (defined(HAVE_DECL_PTP_PEROUT_PHASE) && HAVE_DECL_PTP_PEROUT_PHASE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((PTP_PEROUT_PHASE) == ((1<<2)), "PTP_PEROUT_PHASE != (1<<2)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define PTP_PEROUT_PHASE (1<<2)
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -21,14 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data ptp_perout_flags_xdata[] = {
  XLAT(PTP_PEROUT_ONE_SHOT),
+ #define XLAT_VAL_0 ((unsigned) (PTP_PEROUT_ONE_SHOT))
+ #define XLAT_STR_0 STRINGIFY(PTP_PEROUT_ONE_SHOT)
+ XLAT(PTP_PEROUT_DUTY_CYCLE),
+ #define XLAT_VAL_1 ((unsigned) (PTP_PEROUT_DUTY_CYCLE))
+ #define XLAT_STR_1 STRINGIFY(PTP_PEROUT_DUTY_CYCLE)
+ XLAT(PTP_PEROUT_PHASE),
+ #define XLAT_VAL_2 ((unsigned) (PTP_PEROUT_PHASE))
+ #define XLAT_STR_2 STRINGIFY(PTP_PEROUT_PHASE)
 };
 static
 const struct xlat ptp_perout_flags[1] = { {
  .data = ptp_perout_flags_xdata,
  .size = ARRAY_SIZE(ptp_perout_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ptp_perout_flags.in 5.9-0ubuntu2/xlat/ptp_perout_flags.in
--- 5.5-3/xlat/ptp_perout_flags.in	2019-11-15 22:33:53.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ptp_perout_flags.in	2020-09-06 08:00:00.000000000 +0000
@@ -1 +1,3 @@
 PTP_PEROUT_ONE_SHOT	(1<<0)
+PTP_PEROUT_DUTY_CYCLE	(1<<1)
+PTP_PEROUT_PHASE	(1<<2)
diff -pruN 5.5-3/xlat/ptrace_cmds.h 5.9-0ubuntu2/xlat/ptrace_cmds.h
--- 5.5-3/xlat/ptrace_cmds.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ptrace_cmds.h	2020-09-24 09:18:47.000000000 +0000
@@ -1042,16 +1042,38 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 static const struct xlat_data ptrace_cmds_xdata[] = {
 
  XLAT(PTRACE_TRACEME),
+ #define XLAT_VAL_0 ((unsigned) (PTRACE_TRACEME))
+ #define XLAT_STR_0 STRINGIFY(PTRACE_TRACEME)
  XLAT(PTRACE_PEEKTEXT),
+ #define XLAT_VAL_1 ((unsigned) (PTRACE_PEEKTEXT))
+ #define XLAT_STR_1 STRINGIFY(PTRACE_PEEKTEXT)
  XLAT(PTRACE_PEEKDATA),
+ #define XLAT_VAL_2 ((unsigned) (PTRACE_PEEKDATA))
+ #define XLAT_STR_2 STRINGIFY(PTRACE_PEEKDATA)
  XLAT(PTRACE_PEEKUSER),
+ #define XLAT_VAL_3 ((unsigned) (PTRACE_PEEKUSER))
+ #define XLAT_STR_3 STRINGIFY(PTRACE_PEEKUSER)
  XLAT(PTRACE_POKETEXT),
+ #define XLAT_VAL_4 ((unsigned) (PTRACE_POKETEXT))
+ #define XLAT_STR_4 STRINGIFY(PTRACE_POKETEXT)
  XLAT(PTRACE_POKEDATA),
+ #define XLAT_VAL_5 ((unsigned) (PTRACE_POKEDATA))
+ #define XLAT_STR_5 STRINGIFY(PTRACE_POKEDATA)
  XLAT(PTRACE_POKEUSER),
+ #define XLAT_VAL_6 ((unsigned) (PTRACE_POKEUSER))
+ #define XLAT_STR_6 STRINGIFY(PTRACE_POKEUSER)
  XLAT(PTRACE_CONT),
+ #define XLAT_VAL_7 ((unsigned) (PTRACE_CONT))
+ #define XLAT_STR_7 STRINGIFY(PTRACE_CONT)
  XLAT(PTRACE_KILL),
+ #define XLAT_VAL_8 ((unsigned) (PTRACE_KILL))
+ #define XLAT_STR_8 STRINGIFY(PTRACE_KILL)
  XLAT(PTRACE_SINGLESTEP),
+ #define XLAT_VAL_9 ((unsigned) (PTRACE_SINGLESTEP))
+ #define XLAT_STR_9 STRINGIFY(PTRACE_SINGLESTEP)
  XLAT(PTRACE_ATTACH),
+ #define XLAT_VAL_10 ((unsigned) (PTRACE_ATTACH))
+ #define XLAT_STR_10 STRINGIFY(PTRACE_ATTACH)
 
 /*
 * On sparc, there is PTRACE_SPARC_DETACH (= 11) that is used instead
@@ -1060,612 +1082,970 @@ static const struct xlat_data ptrace_cmd
 */
 #if !defined __sparc__
  XLAT(PTRACE_DETACH),
+ #define XLAT_VAL_11 ((unsigned) (PTRACE_DETACH))
+ #define XLAT_STR_11 STRINGIFY(PTRACE_DETACH)
 #else
 #if defined(PTRACE_DETACH) || (defined(HAVE_DECL_PTRACE_DETACH) && HAVE_DECL_PTRACE_DETACH)
   XLAT(PTRACE_DETACH),
+ #define XLAT_VAL_12 ((unsigned) (PTRACE_DETACH))
+ #define XLAT_STR_12 STRINGIFY(PTRACE_DETACH)
 #endif
 #endif
 
  XLAT(PTRACE_SYSCALL),
+ #define XLAT_VAL_13 ((unsigned) (PTRACE_SYSCALL))
+ #define XLAT_STR_13 STRINGIFY(PTRACE_SYSCALL)
 
  XLAT(PTRACE_SETOPTIONS),
+ #define XLAT_VAL_14 ((unsigned) (PTRACE_SETOPTIONS))
+ #define XLAT_STR_14 STRINGIFY(PTRACE_SETOPTIONS)
  XLAT(PTRACE_GETEVENTMSG),
+ #define XLAT_VAL_15 ((unsigned) (PTRACE_GETEVENTMSG))
+ #define XLAT_STR_15 STRINGIFY(PTRACE_GETEVENTMSG)
  XLAT(PTRACE_GETSIGINFO),
+ #define XLAT_VAL_16 ((unsigned) (PTRACE_GETSIGINFO))
+ #define XLAT_STR_16 STRINGIFY(PTRACE_GETSIGINFO)
  XLAT(PTRACE_SETSIGINFO),
+ #define XLAT_VAL_17 ((unsigned) (PTRACE_SETSIGINFO))
+ #define XLAT_STR_17 STRINGIFY(PTRACE_SETSIGINFO)
  XLAT(PTRACE_GETREGSET),
+ #define XLAT_VAL_18 ((unsigned) (PTRACE_GETREGSET))
+ #define XLAT_STR_18 STRINGIFY(PTRACE_GETREGSET)
  XLAT(PTRACE_SETREGSET),
+ #define XLAT_VAL_19 ((unsigned) (PTRACE_SETREGSET))
+ #define XLAT_STR_19 STRINGIFY(PTRACE_SETREGSET)
  XLAT(PTRACE_SEIZE),
+ #define XLAT_VAL_20 ((unsigned) (PTRACE_SEIZE))
+ #define XLAT_STR_20 STRINGIFY(PTRACE_SEIZE)
  XLAT(PTRACE_INTERRUPT),
+ #define XLAT_VAL_21 ((unsigned) (PTRACE_INTERRUPT))
+ #define XLAT_STR_21 STRINGIFY(PTRACE_INTERRUPT)
  XLAT(PTRACE_LISTEN),
+ #define XLAT_VAL_22 ((unsigned) (PTRACE_LISTEN))
+ #define XLAT_STR_22 STRINGIFY(PTRACE_LISTEN)
  XLAT(PTRACE_PEEKSIGINFO),
+ #define XLAT_VAL_23 ((unsigned) (PTRACE_PEEKSIGINFO))
+ #define XLAT_STR_23 STRINGIFY(PTRACE_PEEKSIGINFO)
  XLAT(PTRACE_GETSIGMASK),
+ #define XLAT_VAL_24 ((unsigned) (PTRACE_GETSIGMASK))
+ #define XLAT_STR_24 STRINGIFY(PTRACE_GETSIGMASK)
  XLAT(PTRACE_SETSIGMASK),
+ #define XLAT_VAL_25 ((unsigned) (PTRACE_SETSIGMASK))
+ #define XLAT_STR_25 STRINGIFY(PTRACE_SETSIGMASK)
  XLAT(PTRACE_SECCOMP_GET_FILTER),
+ #define XLAT_VAL_26 ((unsigned) (PTRACE_SECCOMP_GET_FILTER))
+ #define XLAT_STR_26 STRINGIFY(PTRACE_SECCOMP_GET_FILTER)
  XLAT(PTRACE_SECCOMP_GET_METADATA),
+ #define XLAT_VAL_27 ((unsigned) (PTRACE_SECCOMP_GET_METADATA))
+ #define XLAT_STR_27 STRINGIFY(PTRACE_SECCOMP_GET_METADATA)
  XLAT(PTRACE_GET_SYSCALL_INFO),
+ #define XLAT_VAL_28 ((unsigned) (PTRACE_GET_SYSCALL_INFO))
+ #define XLAT_STR_28 STRINGIFY(PTRACE_GET_SYSCALL_INFO)
 
 
 #if defined __arm__ || defined __m68k__ || defined __mips__ || defined __powerpc__ || defined __sh__ || defined __sparc__ || defined __x86_64__ || defined __i386__ || defined __xtensa__
  XLAT(PTRACE_GETREGS),
+ #define XLAT_VAL_29 ((unsigned) (PTRACE_GETREGS))
+ #define XLAT_STR_29 STRINGIFY(PTRACE_GETREGS)
 #elif defined __hppa__ || defined __ia64__
  XLAT(PTRACE_GETREGS),
+ #define XLAT_VAL_30 ((unsigned) (PTRACE_GETREGS))
+ #define XLAT_STR_30 STRINGIFY(PTRACE_GETREGS)
 #else
 #if defined(PTRACE_GETREGS) || (defined(HAVE_DECL_PTRACE_GETREGS) && HAVE_DECL_PTRACE_GETREGS)
   XLAT(PTRACE_GETREGS),
+ #define XLAT_VAL_31 ((unsigned) (PTRACE_GETREGS))
+ #define XLAT_STR_31 STRINGIFY(PTRACE_GETREGS)
 #endif
 #endif
 
 #if defined __arm__ || defined __m68k__ || defined __mips__ || defined __powerpc__ || defined __sh__ || defined __sparc__ || defined __x86_64__ || defined __i386__ || defined __xtensa__
  XLAT(PTRACE_SETREGS),
+ #define XLAT_VAL_32 ((unsigned) (PTRACE_SETREGS))
+ #define XLAT_STR_32 STRINGIFY(PTRACE_SETREGS)
 #elif defined __hppa__ || defined __ia64__
  XLAT(PTRACE_SETREGS),
+ #define XLAT_VAL_33 ((unsigned) (PTRACE_SETREGS))
+ #define XLAT_STR_33 STRINGIFY(PTRACE_SETREGS)
 #else
 #if defined(PTRACE_SETREGS) || (defined(HAVE_DECL_PTRACE_SETREGS) && HAVE_DECL_PTRACE_SETREGS)
   XLAT(PTRACE_SETREGS),
+ #define XLAT_VAL_34 ((unsigned) (PTRACE_SETREGS))
+ #define XLAT_STR_34 STRINGIFY(PTRACE_SETREGS)
 #endif
 #endif
 
 #if defined __arm__ || defined __hppa__ || defined __m68k__ || defined __mips__ || defined __powerpc__ || defined __sh__ || defined __sparc__ || defined __x86_64__ || defined __i386__
  XLAT(PTRACE_GETFPREGS),
+ #define XLAT_VAL_35 ((unsigned) (PTRACE_GETFPREGS))
+ #define XLAT_STR_35 STRINGIFY(PTRACE_GETFPREGS)
 #else
 #if defined(PTRACE_GETFPREGS) || (defined(HAVE_DECL_PTRACE_GETFPREGS) && HAVE_DECL_PTRACE_GETFPREGS)
   XLAT(PTRACE_GETFPREGS),
+ #define XLAT_VAL_36 ((unsigned) (PTRACE_GETFPREGS))
+ #define XLAT_STR_36 STRINGIFY(PTRACE_GETFPREGS)
 #endif
 #endif
 
 #if defined __arm__ || defined __hppa__ || defined __m68k__ || defined __mips__ || defined __powerpc__ || defined __sh__ || defined __sparc__ || defined __x86_64__ || defined __i386__
  XLAT(PTRACE_SETFPREGS),
+ #define XLAT_VAL_37 ((unsigned) (PTRACE_SETFPREGS))
+ #define XLAT_STR_37 STRINGIFY(PTRACE_SETFPREGS)
 #else
 #if defined(PTRACE_SETFPREGS) || (defined(HAVE_DECL_PTRACE_SETFPREGS) && HAVE_DECL_PTRACE_SETFPREGS)
   XLAT(PTRACE_SETFPREGS),
+ #define XLAT_VAL_38 ((unsigned) (PTRACE_SETFPREGS))
+ #define XLAT_STR_38 STRINGIFY(PTRACE_SETFPREGS)
 #endif
 #endif
 
 #if defined __mips__ || defined __x86_64__ || defined __i386__
  XLAT(PTRACE_GETFPXREGS),
+ #define XLAT_VAL_39 ((unsigned) (PTRACE_GETFPXREGS))
+ #define XLAT_STR_39 STRINGIFY(PTRACE_GETFPXREGS)
 #else
 #if defined(PTRACE_GETFPXREGS) || (defined(HAVE_DECL_PTRACE_GETFPXREGS) && HAVE_DECL_PTRACE_GETFPXREGS)
   XLAT(PTRACE_GETFPXREGS),
+ #define XLAT_VAL_40 ((unsigned) (PTRACE_GETFPXREGS))
+ #define XLAT_STR_40 STRINGIFY(PTRACE_GETFPXREGS)
 #endif
 #endif
 
 #if defined __mips__ || defined __x86_64__ || defined __i386__
  XLAT(PTRACE_SETFPXREGS),
+ #define XLAT_VAL_41 ((unsigned) (PTRACE_SETFPXREGS))
+ #define XLAT_STR_41 STRINGIFY(PTRACE_SETFPXREGS)
 #else
 #if defined(PTRACE_SETFPXREGS) || (defined(HAVE_DECL_PTRACE_SETFPXREGS) && HAVE_DECL_PTRACE_SETFPXREGS)
   XLAT(PTRACE_SETFPXREGS),
+ #define XLAT_VAL_42 ((unsigned) (PTRACE_SETFPXREGS))
+ #define XLAT_STR_42 STRINGIFY(PTRACE_SETFPXREGS)
 #endif
 #endif
 
 #if defined __xtensa__
  XLAT(PTRACE_GETHBPREGS),
+ #define XLAT_VAL_43 ((unsigned) (PTRACE_GETHBPREGS))
+ #define XLAT_STR_43 STRINGIFY(PTRACE_GETHBPREGS)
 #elif defined __arm__
  XLAT(PTRACE_GETHBPREGS),
+ #define XLAT_VAL_44 ((unsigned) (PTRACE_GETHBPREGS))
+ #define XLAT_STR_44 STRINGIFY(PTRACE_GETHBPREGS)
 #else
 #if defined(PTRACE_GETHBPREGS) || (defined(HAVE_DECL_PTRACE_GETHBPREGS) && HAVE_DECL_PTRACE_GETHBPREGS)
   XLAT(PTRACE_GETHBPREGS),
+ #define XLAT_VAL_45 ((unsigned) (PTRACE_GETHBPREGS))
+ #define XLAT_STR_45 STRINGIFY(PTRACE_GETHBPREGS)
 #endif
 #endif
 
 #if defined __xtensa__
  XLAT(PTRACE_SETHBPREGS),
+ #define XLAT_VAL_46 ((unsigned) (PTRACE_SETHBPREGS))
+ #define XLAT_STR_46 STRINGIFY(PTRACE_SETHBPREGS)
 #elif defined __arm__
  XLAT(PTRACE_SETHBPREGS),
+ #define XLAT_VAL_47 ((unsigned) (PTRACE_SETHBPREGS))
+ #define XLAT_STR_47 STRINGIFY(PTRACE_SETHBPREGS)
 #else
 #if defined(PTRACE_SETHBPREGS) || (defined(HAVE_DECL_PTRACE_SETHBPREGS) && HAVE_DECL_PTRACE_SETHBPREGS)
   XLAT(PTRACE_SETHBPREGS),
+ #define XLAT_VAL_48 ((unsigned) (PTRACE_SETHBPREGS))
+ #define XLAT_STR_48 STRINGIFY(PTRACE_SETHBPREGS)
 #endif
 #endif
 
 #if defined __arm__ || defined __ia64__ || defined __mips__ || defined __s390__ || defined __x86_64__ || defined __i386__
  XLAT(PTRACE_OLDSETOPTIONS),
+ #define XLAT_VAL_49 ((unsigned) (PTRACE_OLDSETOPTIONS))
+ #define XLAT_STR_49 STRINGIFY(PTRACE_OLDSETOPTIONS)
 #else
 #if defined(PTRACE_OLDSETOPTIONS) || (defined(HAVE_DECL_PTRACE_OLDSETOPTIONS) && HAVE_DECL_PTRACE_OLDSETOPTIONS)
   XLAT(PTRACE_OLDSETOPTIONS),
+ #define XLAT_VAL_50 ((unsigned) (PTRACE_OLDSETOPTIONS))
+ #define XLAT_STR_50 STRINGIFY(PTRACE_OLDSETOPTIONS)
 #endif
 #endif
 
 #if defined __powerpc__ || defined __sparc__
  XLAT(PTRACE_GETREGS64),
+ #define XLAT_VAL_51 ((unsigned) (PTRACE_GETREGS64))
+ #define XLAT_STR_51 STRINGIFY(PTRACE_GETREGS64)
 #else
 #if defined(PTRACE_GETREGS64) || (defined(HAVE_DECL_PTRACE_GETREGS64) && HAVE_DECL_PTRACE_GETREGS64)
   XLAT(PTRACE_GETREGS64),
+ #define XLAT_VAL_52 ((unsigned) (PTRACE_GETREGS64))
+ #define XLAT_STR_52 STRINGIFY(PTRACE_GETREGS64)
 #endif
 #endif
 #if defined __powerpc__ || defined __sparc__
  XLAT(PTRACE_SETREGS64),
+ #define XLAT_VAL_53 ((unsigned) (PTRACE_SETREGS64))
+ #define XLAT_STR_53 STRINGIFY(PTRACE_SETREGS64)
 #else
 #if defined(PTRACE_SETREGS64) || (defined(HAVE_DECL_PTRACE_SETREGS64) && HAVE_DECL_PTRACE_SETREGS64)
   XLAT(PTRACE_SETREGS64),
+ #define XLAT_VAL_54 ((unsigned) (PTRACE_SETREGS64))
+ #define XLAT_STR_54 STRINGIFY(PTRACE_SETREGS64)
 #endif
 #endif
 
 #if defined __arm__ || defined __unicore32__
  XLAT(PTRACE_GET_THREAD_AREA),
+ #define XLAT_VAL_55 ((unsigned) (PTRACE_GET_THREAD_AREA))
+ #define XLAT_STR_55 STRINGIFY(PTRACE_GET_THREAD_AREA)
 #elif defined __arc__ || defined __m68k__ || defined __mips__ || defined __x86_64__ || defined __i386__
  XLAT(PTRACE_GET_THREAD_AREA),
+ #define XLAT_VAL_56 ((unsigned) (PTRACE_GET_THREAD_AREA))
+ #define XLAT_STR_56 STRINGIFY(PTRACE_GET_THREAD_AREA)
 #else
 #if defined(PTRACE_GET_THREAD_AREA) || (defined(HAVE_DECL_PTRACE_GET_THREAD_AREA) && HAVE_DECL_PTRACE_GET_THREAD_AREA)
   XLAT(PTRACE_GET_THREAD_AREA),
+ #define XLAT_VAL_57 ((unsigned) (PTRACE_GET_THREAD_AREA))
+ #define XLAT_STR_57 STRINGIFY(PTRACE_GET_THREAD_AREA)
 #endif
 #endif
 
 #if defined __mips__ || defined __x86_64__ || defined __i386__
  XLAT(PTRACE_SET_THREAD_AREA),
+ #define XLAT_VAL_58 ((unsigned) (PTRACE_SET_THREAD_AREA))
+ #define XLAT_STR_58 STRINGIFY(PTRACE_SET_THREAD_AREA)
 #else
 #if defined(PTRACE_SET_THREAD_AREA) || (defined(HAVE_DECL_PTRACE_SET_THREAD_AREA) && HAVE_DECL_PTRACE_SET_THREAD_AREA)
   XLAT(PTRACE_SET_THREAD_AREA),
+ #define XLAT_VAL_59 ((unsigned) (PTRACE_SET_THREAD_AREA))
+ #define XLAT_STR_59 STRINGIFY(PTRACE_SET_THREAD_AREA)
 #endif
 #endif
 
 #if defined __arm__ || defined __c6x__ || defined __sh__
  XLAT(PTRACE_GETFDPIC),
+ #define XLAT_VAL_60 ((unsigned) (PTRACE_GETFDPIC))
+ #define XLAT_STR_60 STRINGIFY(PTRACE_GETFDPIC)
 #else
 #if defined(PTRACE_GETFDPIC) || (defined(HAVE_DECL_PTRACE_GETFDPIC) && HAVE_DECL_PTRACE_GETFDPIC)
   XLAT(PTRACE_GETFDPIC),
+ #define XLAT_VAL_61 ((unsigned) (PTRACE_GETFDPIC))
+ #define XLAT_STR_61 STRINGIFY(PTRACE_GETFDPIC)
 #endif
 #endif
 
 #if defined __powerpc__
  XLAT(PTRACE_SYSEMU),
+ #define XLAT_VAL_62 ((unsigned) (PTRACE_SYSEMU))
+ #define XLAT_STR_62 STRINGIFY(PTRACE_SYSEMU)
 #elif defined __arm64__ || defined __aarch64__ || defined __x86_64__ || defined __i386__
  XLAT(PTRACE_SYSEMU),
+ #define XLAT_VAL_63 ((unsigned) (PTRACE_SYSEMU))
+ #define XLAT_STR_63 STRINGIFY(PTRACE_SYSEMU)
 #else
 #if defined(PTRACE_SYSEMU) || (defined(HAVE_DECL_PTRACE_SYSEMU) && HAVE_DECL_PTRACE_SYSEMU)
   XLAT(PTRACE_SYSEMU),
+ #define XLAT_VAL_64 ((unsigned) (PTRACE_SYSEMU))
+ #define XLAT_STR_64 STRINGIFY(PTRACE_SYSEMU)
 #endif
 #endif
 
 #if defined __powerpc__
  XLAT(PTRACE_SYSEMU_SINGLESTEP),
+ #define XLAT_VAL_65 ((unsigned) (PTRACE_SYSEMU_SINGLESTEP))
+ #define XLAT_STR_65 STRINGIFY(PTRACE_SYSEMU_SINGLESTEP)
 #elif defined __arm64__ || defined __aarch64__ || defined __x86_64__ || defined __i386__
  XLAT(PTRACE_SYSEMU_SINGLESTEP),
+ #define XLAT_VAL_66 ((unsigned) (PTRACE_SYSEMU_SINGLESTEP))
+ #define XLAT_STR_66 STRINGIFY(PTRACE_SYSEMU_SINGLESTEP)
 #else
 #if defined(PTRACE_SYSEMU_SINGLESTEP) || (defined(HAVE_DECL_PTRACE_SYSEMU_SINGLESTEP) && HAVE_DECL_PTRACE_SYSEMU_SINGLESTEP)
   XLAT(PTRACE_SYSEMU_SINGLESTEP),
+ #define XLAT_VAL_67 ((unsigned) (PTRACE_SYSEMU_SINGLESTEP))
+ #define XLAT_STR_67 STRINGIFY(PTRACE_SYSEMU_SINGLESTEP)
 #endif
 #endif
 
 #if defined __hppa__ || defined __ia64__ || defined __s390__
  XLAT(PTRACE_SINGLEBLOCK),
+ #define XLAT_VAL_68 ((unsigned) (PTRACE_SINGLEBLOCK))
+ #define XLAT_STR_68 STRINGIFY(PTRACE_SINGLEBLOCK)
 #elif defined __m68k__ || defined __x86_64__ || defined __i386__
  XLAT(PTRACE_SINGLEBLOCK),
+ #define XLAT_VAL_69 ((unsigned) (PTRACE_SINGLEBLOCK))
+ #define XLAT_STR_69 STRINGIFY(PTRACE_SINGLEBLOCK)
 #elif defined __powerpc__
  XLAT(PTRACE_SINGLEBLOCK),
+ #define XLAT_VAL_70 ((unsigned) (PTRACE_SINGLEBLOCK))
+ #define XLAT_STR_70 STRINGIFY(PTRACE_SINGLEBLOCK)
 #else
 #if defined(PTRACE_SINGLEBLOCK) || (defined(HAVE_DECL_PTRACE_SINGLEBLOCK) && HAVE_DECL_PTRACE_SINGLEBLOCK)
   XLAT(PTRACE_SINGLEBLOCK),
+ #define XLAT_VAL_71 ((unsigned) (PTRACE_SINGLEBLOCK))
+ #define XLAT_STR_71 STRINGIFY(PTRACE_SINGLEBLOCK)
 #endif
 #endif
 
 
 #if defined __arm__
  XLAT(PTRACE_GETWMMXREGS),
+ #define XLAT_VAL_72 ((unsigned) (PTRACE_GETWMMXREGS))
+ #define XLAT_STR_72 STRINGIFY(PTRACE_GETWMMXREGS)
 #else
 #if defined(PTRACE_GETWMMXREGS) || (defined(HAVE_DECL_PTRACE_GETWMMXREGS) && HAVE_DECL_PTRACE_GETWMMXREGS)
   XLAT(PTRACE_GETWMMXREGS),
+ #define XLAT_VAL_73 ((unsigned) (PTRACE_GETWMMXREGS))
+ #define XLAT_STR_73 STRINGIFY(PTRACE_GETWMMXREGS)
 #endif
 #endif
 #if defined __arm__
  XLAT(PTRACE_SETWMMXREGS),
+ #define XLAT_VAL_74 ((unsigned) (PTRACE_SETWMMXREGS))
+ #define XLAT_STR_74 STRINGIFY(PTRACE_SETWMMXREGS)
 #else
 #if defined(PTRACE_SETWMMXREGS) || (defined(HAVE_DECL_PTRACE_SETWMMXREGS) && HAVE_DECL_PTRACE_SETWMMXREGS)
   XLAT(PTRACE_SETWMMXREGS),
+ #define XLAT_VAL_75 ((unsigned) (PTRACE_SETWMMXREGS))
+ #define XLAT_STR_75 STRINGIFY(PTRACE_SETWMMXREGS)
 #endif
 #endif
 #if defined __arm__
  XLAT(PTRACE_SET_SYSCALL),
+ #define XLAT_VAL_76 ((unsigned) (PTRACE_SET_SYSCALL))
+ #define XLAT_STR_76 STRINGIFY(PTRACE_SET_SYSCALL)
 #else
 #if defined(PTRACE_SET_SYSCALL) || (defined(HAVE_DECL_PTRACE_SET_SYSCALL) && HAVE_DECL_PTRACE_SET_SYSCALL)
   XLAT(PTRACE_SET_SYSCALL),
+ #define XLAT_VAL_77 ((unsigned) (PTRACE_SET_SYSCALL))
+ #define XLAT_STR_77 STRINGIFY(PTRACE_SET_SYSCALL)
 #endif
 #endif
 #if defined __arm__
  XLAT(PTRACE_GETCRUNCHREGS),
+ #define XLAT_VAL_78 ((unsigned) (PTRACE_GETCRUNCHREGS))
+ #define XLAT_STR_78 STRINGIFY(PTRACE_GETCRUNCHREGS)
 #else
 #if defined(PTRACE_GETCRUNCHREGS) || (defined(HAVE_DECL_PTRACE_GETCRUNCHREGS) && HAVE_DECL_PTRACE_GETCRUNCHREGS)
   XLAT(PTRACE_GETCRUNCHREGS),
+ #define XLAT_VAL_79 ((unsigned) (PTRACE_GETCRUNCHREGS))
+ #define XLAT_STR_79 STRINGIFY(PTRACE_GETCRUNCHREGS)
 #endif
 #endif
 #if defined __arm__
  XLAT(PTRACE_SETCRUNCHREGS),
+ #define XLAT_VAL_80 ((unsigned) (PTRACE_SETCRUNCHREGS))
+ #define XLAT_STR_80 STRINGIFY(PTRACE_SETCRUNCHREGS)
 #else
 #if defined(PTRACE_SETCRUNCHREGS) || (defined(HAVE_DECL_PTRACE_SETCRUNCHREGS) && HAVE_DECL_PTRACE_SETCRUNCHREGS)
   XLAT(PTRACE_SETCRUNCHREGS),
+ #define XLAT_VAL_81 ((unsigned) (PTRACE_SETCRUNCHREGS))
+ #define XLAT_STR_81 STRINGIFY(PTRACE_SETCRUNCHREGS)
 #endif
 #endif
 #if defined __arm__
  XLAT(PTRACE_GETVFPREGS),
+ #define XLAT_VAL_82 ((unsigned) (PTRACE_GETVFPREGS))
+ #define XLAT_STR_82 STRINGIFY(PTRACE_GETVFPREGS)
 #else
 #if defined(PTRACE_GETVFPREGS) || (defined(HAVE_DECL_PTRACE_GETVFPREGS) && HAVE_DECL_PTRACE_GETVFPREGS)
   XLAT(PTRACE_GETVFPREGS),
+ #define XLAT_VAL_83 ((unsigned) (PTRACE_GETVFPREGS))
+ #define XLAT_STR_83 STRINGIFY(PTRACE_GETVFPREGS)
 #endif
 #endif
 #if defined __arm__
  XLAT(PTRACE_SETVFPREGS),
+ #define XLAT_VAL_84 ((unsigned) (PTRACE_SETVFPREGS))
+ #define XLAT_STR_84 STRINGIFY(PTRACE_SETVFPREGS)
 #else
 #if defined(PTRACE_SETVFPREGS) || (defined(HAVE_DECL_PTRACE_SETVFPREGS) && HAVE_DECL_PTRACE_SETVFPREGS)
   XLAT(PTRACE_SETVFPREGS),
+ #define XLAT_VAL_85 ((unsigned) (PTRACE_SETVFPREGS))
+ #define XLAT_STR_85 STRINGIFY(PTRACE_SETVFPREGS)
 #endif
 #endif
 
 
 #if defined __ia64__
  XLAT(PTRACE_OLD_GETSIGINFO),
+ #define XLAT_VAL_86 ((unsigned) (PTRACE_OLD_GETSIGINFO))
+ #define XLAT_STR_86 STRINGIFY(PTRACE_OLD_GETSIGINFO)
 #else
 #if defined(PTRACE_OLD_GETSIGINFO) || (defined(HAVE_DECL_PTRACE_OLD_GETSIGINFO) && HAVE_DECL_PTRACE_OLD_GETSIGINFO)
   XLAT(PTRACE_OLD_GETSIGINFO),
+ #define XLAT_VAL_87 ((unsigned) (PTRACE_OLD_GETSIGINFO))
+ #define XLAT_STR_87 STRINGIFY(PTRACE_OLD_GETSIGINFO)
 #endif
 #endif
 #if defined __ia64__
  XLAT(PTRACE_OLD_SETSIGINFO),
+ #define XLAT_VAL_88 ((unsigned) (PTRACE_OLD_SETSIGINFO))
+ #define XLAT_STR_88 STRINGIFY(PTRACE_OLD_SETSIGINFO)
 #else
 #if defined(PTRACE_OLD_SETSIGINFO) || (defined(HAVE_DECL_PTRACE_OLD_SETSIGINFO) && HAVE_DECL_PTRACE_OLD_SETSIGINFO)
   XLAT(PTRACE_OLD_SETSIGINFO),
+ #define XLAT_VAL_89 ((unsigned) (PTRACE_OLD_SETSIGINFO))
+ #define XLAT_STR_89 STRINGIFY(PTRACE_OLD_SETSIGINFO)
 #endif
 #endif
 
 
 #if defined __mips__
  XLAT(PTRACE_PEEKTEXT_3264),
+ #define XLAT_VAL_90 ((unsigned) (PTRACE_PEEKTEXT_3264))
+ #define XLAT_STR_90 STRINGIFY(PTRACE_PEEKTEXT_3264)
 #else
 #if defined(PTRACE_PEEKTEXT_3264) || (defined(HAVE_DECL_PTRACE_PEEKTEXT_3264) && HAVE_DECL_PTRACE_PEEKTEXT_3264)
   XLAT(PTRACE_PEEKTEXT_3264),
+ #define XLAT_VAL_91 ((unsigned) (PTRACE_PEEKTEXT_3264))
+ #define XLAT_STR_91 STRINGIFY(PTRACE_PEEKTEXT_3264)
 #endif
 #endif
 #if defined __mips__
  XLAT(PTRACE_PEEKDATA_3264),
+ #define XLAT_VAL_92 ((unsigned) (PTRACE_PEEKDATA_3264))
+ #define XLAT_STR_92 STRINGIFY(PTRACE_PEEKDATA_3264)
 #else
 #if defined(PTRACE_PEEKDATA_3264) || (defined(HAVE_DECL_PTRACE_PEEKDATA_3264) && HAVE_DECL_PTRACE_PEEKDATA_3264)
   XLAT(PTRACE_PEEKDATA_3264),
+ #define XLAT_VAL_93 ((unsigned) (PTRACE_PEEKDATA_3264))
+ #define XLAT_STR_93 STRINGIFY(PTRACE_PEEKDATA_3264)
 #endif
 #endif
 #if defined __mips__
  XLAT(PTRACE_POKETEXT_3264),
+ #define XLAT_VAL_94 ((unsigned) (PTRACE_POKETEXT_3264))
+ #define XLAT_STR_94 STRINGIFY(PTRACE_POKETEXT_3264)
 #else
 #if defined(PTRACE_POKETEXT_3264) || (defined(HAVE_DECL_PTRACE_POKETEXT_3264) && HAVE_DECL_PTRACE_POKETEXT_3264)
   XLAT(PTRACE_POKETEXT_3264),
+ #define XLAT_VAL_95 ((unsigned) (PTRACE_POKETEXT_3264))
+ #define XLAT_STR_95 STRINGIFY(PTRACE_POKETEXT_3264)
 #endif
 #endif
 #if defined __mips__
  XLAT(PTRACE_POKEDATA_3264),
+ #define XLAT_VAL_96 ((unsigned) (PTRACE_POKEDATA_3264))
+ #define XLAT_STR_96 STRINGIFY(PTRACE_POKEDATA_3264)
 #else
 #if defined(PTRACE_POKEDATA_3264) || (defined(HAVE_DECL_PTRACE_POKEDATA_3264) && HAVE_DECL_PTRACE_POKEDATA_3264)
   XLAT(PTRACE_POKEDATA_3264),
+ #define XLAT_VAL_97 ((unsigned) (PTRACE_POKEDATA_3264))
+ #define XLAT_STR_97 STRINGIFY(PTRACE_POKEDATA_3264)
 #endif
 #endif
 #if defined __mips__
  XLAT(PTRACE_GET_THREAD_AREA_3264),
+ #define XLAT_VAL_98 ((unsigned) (PTRACE_GET_THREAD_AREA_3264))
+ #define XLAT_STR_98 STRINGIFY(PTRACE_GET_THREAD_AREA_3264)
 #else
 #if defined(PTRACE_GET_THREAD_AREA_3264) || (defined(HAVE_DECL_PTRACE_GET_THREAD_AREA_3264) && HAVE_DECL_PTRACE_GET_THREAD_AREA_3264)
   XLAT(PTRACE_GET_THREAD_AREA_3264),
+ #define XLAT_VAL_99 ((unsigned) (PTRACE_GET_THREAD_AREA_3264))
+ #define XLAT_STR_99 STRINGIFY(PTRACE_GET_THREAD_AREA_3264)
 #endif
 #endif
 #if defined __mips__
  XLAT(PTRACE_GET_WATCH_REGS),
+ #define XLAT_VAL_100 ((unsigned) (PTRACE_GET_WATCH_REGS))
+ #define XLAT_STR_100 STRINGIFY(PTRACE_GET_WATCH_REGS)
 #else
 #if defined(PTRACE_GET_WATCH_REGS) || (defined(HAVE_DECL_PTRACE_GET_WATCH_REGS) && HAVE_DECL_PTRACE_GET_WATCH_REGS)
   XLAT(PTRACE_GET_WATCH_REGS),
+ #define XLAT_VAL_101 ((unsigned) (PTRACE_GET_WATCH_REGS))
+ #define XLAT_STR_101 STRINGIFY(PTRACE_GET_WATCH_REGS)
 #endif
 #endif
 #if defined __mips__
  XLAT(PTRACE_SET_WATCH_REGS),
+ #define XLAT_VAL_102 ((unsigned) (PTRACE_SET_WATCH_REGS))
+ #define XLAT_STR_102 STRINGIFY(PTRACE_SET_WATCH_REGS)
 #else
 #if defined(PTRACE_SET_WATCH_REGS) || (defined(HAVE_DECL_PTRACE_SET_WATCH_REGS) && HAVE_DECL_PTRACE_SET_WATCH_REGS)
   XLAT(PTRACE_SET_WATCH_REGS),
+ #define XLAT_VAL_103 ((unsigned) (PTRACE_SET_WATCH_REGS))
+ #define XLAT_STR_103 STRINGIFY(PTRACE_SET_WATCH_REGS)
 #endif
 #endif
 
 
 #if defined __powerpc__
  XLAT(PTRACE_GETVRREGS),
+ #define XLAT_VAL_104 ((unsigned) (PTRACE_GETVRREGS))
+ #define XLAT_STR_104 STRINGIFY(PTRACE_GETVRREGS)
 #else
 #if defined(PTRACE_GETVRREGS) || (defined(HAVE_DECL_PTRACE_GETVRREGS) && HAVE_DECL_PTRACE_GETVRREGS)
   XLAT(PTRACE_GETVRREGS),
+ #define XLAT_VAL_105 ((unsigned) (PTRACE_GETVRREGS))
+ #define XLAT_STR_105 STRINGIFY(PTRACE_GETVRREGS)
 #endif
 #endif
 #if defined __powerpc__
  XLAT(PTRACE_SETVRREGS),
+ #define XLAT_VAL_106 ((unsigned) (PTRACE_SETVRREGS))
+ #define XLAT_STR_106 STRINGIFY(PTRACE_SETVRREGS)
 #else
 #if defined(PTRACE_SETVRREGS) || (defined(HAVE_DECL_PTRACE_SETVRREGS) && HAVE_DECL_PTRACE_SETVRREGS)
   XLAT(PTRACE_SETVRREGS),
+ #define XLAT_VAL_107 ((unsigned) (PTRACE_SETVRREGS))
+ #define XLAT_STR_107 STRINGIFY(PTRACE_SETVRREGS)
 #endif
 #endif
 #if defined __powerpc__
  XLAT(PTRACE_GETEVRREGS),
+ #define XLAT_VAL_108 ((unsigned) (PTRACE_GETEVRREGS))
+ #define XLAT_STR_108 STRINGIFY(PTRACE_GETEVRREGS)
 #else
 #if defined(PTRACE_GETEVRREGS) || (defined(HAVE_DECL_PTRACE_GETEVRREGS) && HAVE_DECL_PTRACE_GETEVRREGS)
   XLAT(PTRACE_GETEVRREGS),
+ #define XLAT_VAL_109 ((unsigned) (PTRACE_GETEVRREGS))
+ #define XLAT_STR_109 STRINGIFY(PTRACE_GETEVRREGS)
 #endif
 #endif
 #if defined __powerpc__
  XLAT(PTRACE_SETEVRREGS),
+ #define XLAT_VAL_110 ((unsigned) (PTRACE_SETEVRREGS))
+ #define XLAT_STR_110 STRINGIFY(PTRACE_SETEVRREGS)
 #else
 #if defined(PTRACE_SETEVRREGS) || (defined(HAVE_DECL_PTRACE_SETEVRREGS) && HAVE_DECL_PTRACE_SETEVRREGS)
   XLAT(PTRACE_SETEVRREGS),
+ #define XLAT_VAL_111 ((unsigned) (PTRACE_SETEVRREGS))
+ #define XLAT_STR_111 STRINGIFY(PTRACE_SETEVRREGS)
 #endif
 #endif
 #if defined __powerpc__
  XLAT(PTRACE_GETVSRREGS),
+ #define XLAT_VAL_112 ((unsigned) (PTRACE_GETVSRREGS))
+ #define XLAT_STR_112 STRINGIFY(PTRACE_GETVSRREGS)
 #else
 #if defined(PTRACE_GETVSRREGS) || (defined(HAVE_DECL_PTRACE_GETVSRREGS) && HAVE_DECL_PTRACE_GETVSRREGS)
   XLAT(PTRACE_GETVSRREGS),
+ #define XLAT_VAL_113 ((unsigned) (PTRACE_GETVSRREGS))
+ #define XLAT_STR_113 STRINGIFY(PTRACE_GETVSRREGS)
 #endif
 #endif
 #if defined __powerpc__
  XLAT(PTRACE_SETVSRREGS),
+ #define XLAT_VAL_114 ((unsigned) (PTRACE_SETVSRREGS))
+ #define XLAT_STR_114 STRINGIFY(PTRACE_SETVSRREGS)
 #else
 #if defined(PTRACE_SETVSRREGS) || (defined(HAVE_DECL_PTRACE_SETVSRREGS) && HAVE_DECL_PTRACE_SETVSRREGS)
   XLAT(PTRACE_SETVSRREGS),
+ #define XLAT_VAL_115 ((unsigned) (PTRACE_SETVSRREGS))
+ #define XLAT_STR_115 STRINGIFY(PTRACE_SETVSRREGS)
 #endif
 #endif
 #if defined __powerpc__
  XLAT(PTRACE_GET_DEBUGREG),
+ #define XLAT_VAL_116 ((unsigned) (PTRACE_GET_DEBUGREG))
+ #define XLAT_STR_116 STRINGIFY(PTRACE_GET_DEBUGREG)
 #else
 #if defined(PTRACE_GET_DEBUGREG) || (defined(HAVE_DECL_PTRACE_GET_DEBUGREG) && HAVE_DECL_PTRACE_GET_DEBUGREG)
   XLAT(PTRACE_GET_DEBUGREG),
+ #define XLAT_VAL_117 ((unsigned) (PTRACE_GET_DEBUGREG))
+ #define XLAT_STR_117 STRINGIFY(PTRACE_GET_DEBUGREG)
 #endif
 #endif
 #if defined __powerpc__
  XLAT(PTRACE_SET_DEBUGREG),
+ #define XLAT_VAL_118 ((unsigned) (PTRACE_SET_DEBUGREG))
+ #define XLAT_STR_118 STRINGIFY(PTRACE_SET_DEBUGREG)
 #else
 #if defined(PTRACE_SET_DEBUGREG) || (defined(HAVE_DECL_PTRACE_SET_DEBUGREG) && HAVE_DECL_PTRACE_SET_DEBUGREG)
   XLAT(PTRACE_SET_DEBUGREG),
+ #define XLAT_VAL_119 ((unsigned) (PTRACE_SET_DEBUGREG))
+ #define XLAT_STR_119 STRINGIFY(PTRACE_SET_DEBUGREG)
 #endif
 #endif
 #if defined __powerpc__
  XLAT(PPC_PTRACE_DELHWDEBUG),
+ #define XLAT_VAL_120 ((unsigned) (PPC_PTRACE_DELHWDEBUG))
+ #define XLAT_STR_120 STRINGIFY(PPC_PTRACE_DELHWDEBUG)
 #else
 #if defined(PPC_PTRACE_DELHWDEBUG) || (defined(HAVE_DECL_PPC_PTRACE_DELHWDEBUG) && HAVE_DECL_PPC_PTRACE_DELHWDEBUG)
   XLAT(PPC_PTRACE_DELHWDEBUG),
+ #define XLAT_VAL_121 ((unsigned) (PPC_PTRACE_DELHWDEBUG))
+ #define XLAT_STR_121 STRINGIFY(PPC_PTRACE_DELHWDEBUG)
 #endif
 #endif
 #if defined __powerpc__
  XLAT(PPC_PTRACE_SETHWDEBUG),
+ #define XLAT_VAL_122 ((unsigned) (PPC_PTRACE_SETHWDEBUG))
+ #define XLAT_STR_122 STRINGIFY(PPC_PTRACE_SETHWDEBUG)
 #else
 #if defined(PPC_PTRACE_SETHWDEBUG) || (defined(HAVE_DECL_PPC_PTRACE_SETHWDEBUG) && HAVE_DECL_PPC_PTRACE_SETHWDEBUG)
   XLAT(PPC_PTRACE_SETHWDEBUG),
+ #define XLAT_VAL_123 ((unsigned) (PPC_PTRACE_SETHWDEBUG))
+ #define XLAT_STR_123 STRINGIFY(PPC_PTRACE_SETHWDEBUG)
 #endif
 #endif
 #if defined __powerpc__
  XLAT(PPC_PTRACE_GETHWDBGINFO),
+ #define XLAT_VAL_124 ((unsigned) (PPC_PTRACE_GETHWDBGINFO))
+ #define XLAT_STR_124 STRINGIFY(PPC_PTRACE_GETHWDBGINFO)
 #else
 #if defined(PPC_PTRACE_GETHWDBGINFO) || (defined(HAVE_DECL_PPC_PTRACE_GETHWDBGINFO) && HAVE_DECL_PPC_PTRACE_GETHWDBGINFO)
   XLAT(PPC_PTRACE_GETHWDBGINFO),
+ #define XLAT_VAL_125 ((unsigned) (PPC_PTRACE_GETHWDBGINFO))
+ #define XLAT_STR_125 STRINGIFY(PPC_PTRACE_GETHWDBGINFO)
 #endif
 #endif
 #if defined __powerpc__
  XLAT(PPC_PTRACE_POKEUSR_3264),
+ #define XLAT_VAL_126 ((unsigned) (PPC_PTRACE_POKEUSR_3264))
+ #define XLAT_STR_126 STRINGIFY(PPC_PTRACE_POKEUSR_3264)
 #else
 #if defined(PPC_PTRACE_POKEUSR_3264) || (defined(HAVE_DECL_PPC_PTRACE_POKEUSR_3264) && HAVE_DECL_PPC_PTRACE_POKEUSR_3264)
   XLAT(PPC_PTRACE_POKEUSR_3264),
+ #define XLAT_VAL_127 ((unsigned) (PPC_PTRACE_POKEUSR_3264))
+ #define XLAT_STR_127 STRINGIFY(PPC_PTRACE_POKEUSR_3264)
 #endif
 #endif
 #if defined __powerpc__
  XLAT(PPC_PTRACE_PEEKUSR_3264),
+ #define XLAT_VAL_128 ((unsigned) (PPC_PTRACE_PEEKUSR_3264))
+ #define XLAT_STR_128 STRINGIFY(PPC_PTRACE_PEEKUSR_3264)
 #else
 #if defined(PPC_PTRACE_PEEKUSR_3264) || (defined(HAVE_DECL_PPC_PTRACE_PEEKUSR_3264) && HAVE_DECL_PPC_PTRACE_PEEKUSR_3264)
   XLAT(PPC_PTRACE_PEEKUSR_3264),
+ #define XLAT_VAL_129 ((unsigned) (PPC_PTRACE_PEEKUSR_3264))
+ #define XLAT_STR_129 STRINGIFY(PPC_PTRACE_PEEKUSR_3264)
 #endif
 #endif
 #if defined __powerpc__
  XLAT(PPC_PTRACE_POKEDATA_3264),
+ #define XLAT_VAL_130 ((unsigned) (PPC_PTRACE_POKEDATA_3264))
+ #define XLAT_STR_130 STRINGIFY(PPC_PTRACE_POKEDATA_3264)
 #else
 #if defined(PPC_PTRACE_POKEDATA_3264) || (defined(HAVE_DECL_PPC_PTRACE_POKEDATA_3264) && HAVE_DECL_PPC_PTRACE_POKEDATA_3264)
   XLAT(PPC_PTRACE_POKEDATA_3264),
+ #define XLAT_VAL_131 ((unsigned) (PPC_PTRACE_POKEDATA_3264))
+ #define XLAT_STR_131 STRINGIFY(PPC_PTRACE_POKEDATA_3264)
 #endif
 #endif
 #if defined __powerpc__
  XLAT(PPC_PTRACE_POKETEXT_3264),
+ #define XLAT_VAL_132 ((unsigned) (PPC_PTRACE_POKETEXT_3264))
+ #define XLAT_STR_132 STRINGIFY(PPC_PTRACE_POKETEXT_3264)
 #else
 #if defined(PPC_PTRACE_POKETEXT_3264) || (defined(HAVE_DECL_PPC_PTRACE_POKETEXT_3264) && HAVE_DECL_PPC_PTRACE_POKETEXT_3264)
   XLAT(PPC_PTRACE_POKETEXT_3264),
+ #define XLAT_VAL_133 ((unsigned) (PPC_PTRACE_POKETEXT_3264))
+ #define XLAT_STR_133 STRINGIFY(PPC_PTRACE_POKETEXT_3264)
 #endif
 #endif
 #if defined __powerpc__
  XLAT(PPC_PTRACE_PEEKDATA_3264),
+ #define XLAT_VAL_134 ((unsigned) (PPC_PTRACE_PEEKDATA_3264))
+ #define XLAT_STR_134 STRINGIFY(PPC_PTRACE_PEEKDATA_3264)
 #else
 #if defined(PPC_PTRACE_PEEKDATA_3264) || (defined(HAVE_DECL_PPC_PTRACE_PEEKDATA_3264) && HAVE_DECL_PPC_PTRACE_PEEKDATA_3264)
   XLAT(PPC_PTRACE_PEEKDATA_3264),
+ #define XLAT_VAL_135 ((unsigned) (PPC_PTRACE_PEEKDATA_3264))
+ #define XLAT_STR_135 STRINGIFY(PPC_PTRACE_PEEKDATA_3264)
 #endif
 #endif
 #if defined __powerpc__
  XLAT(PPC_PTRACE_PEEKTEXT_3264),
+ #define XLAT_VAL_136 ((unsigned) (PPC_PTRACE_PEEKTEXT_3264))
+ #define XLAT_STR_136 STRINGIFY(PPC_PTRACE_PEEKTEXT_3264)
 #else
 #if defined(PPC_PTRACE_PEEKTEXT_3264) || (defined(HAVE_DECL_PPC_PTRACE_PEEKTEXT_3264) && HAVE_DECL_PPC_PTRACE_PEEKTEXT_3264)
   XLAT(PPC_PTRACE_PEEKTEXT_3264),
+ #define XLAT_VAL_137 ((unsigned) (PPC_PTRACE_PEEKTEXT_3264))
+ #define XLAT_STR_137 STRINGIFY(PPC_PTRACE_PEEKTEXT_3264)
 #endif
 #endif
 
 
 #if defined __s390__
  XLAT(PTRACE_PEEKUSR_AREA),
+ #define XLAT_VAL_138 ((unsigned) (PTRACE_PEEKUSR_AREA))
+ #define XLAT_STR_138 STRINGIFY(PTRACE_PEEKUSR_AREA)
 #else
 #if defined(PTRACE_PEEKUSR_AREA) || (defined(HAVE_DECL_PTRACE_PEEKUSR_AREA) && HAVE_DECL_PTRACE_PEEKUSR_AREA)
   XLAT(PTRACE_PEEKUSR_AREA),
+ #define XLAT_VAL_139 ((unsigned) (PTRACE_PEEKUSR_AREA))
+ #define XLAT_STR_139 STRINGIFY(PTRACE_PEEKUSR_AREA)
 #endif
 #endif
 #if defined __s390__
  XLAT(PTRACE_POKEUSR_AREA),
+ #define XLAT_VAL_140 ((unsigned) (PTRACE_POKEUSR_AREA))
+ #define XLAT_STR_140 STRINGIFY(PTRACE_POKEUSR_AREA)
 #else
 #if defined(PTRACE_POKEUSR_AREA) || (defined(HAVE_DECL_PTRACE_POKEUSR_AREA) && HAVE_DECL_PTRACE_POKEUSR_AREA)
   XLAT(PTRACE_POKEUSR_AREA),
+ #define XLAT_VAL_141 ((unsigned) (PTRACE_POKEUSR_AREA))
+ #define XLAT_STR_141 STRINGIFY(PTRACE_POKEUSR_AREA)
 #endif
 #endif
 #if defined __s390__
  XLAT(PTRACE_PEEKTEXT_AREA),
+ #define XLAT_VAL_142 ((unsigned) (PTRACE_PEEKTEXT_AREA))
+ #define XLAT_STR_142 STRINGIFY(PTRACE_PEEKTEXT_AREA)
 #else
 #if defined(PTRACE_PEEKTEXT_AREA) || (defined(HAVE_DECL_PTRACE_PEEKTEXT_AREA) && HAVE_DECL_PTRACE_PEEKTEXT_AREA)
   XLAT(PTRACE_PEEKTEXT_AREA),
+ #define XLAT_VAL_143 ((unsigned) (PTRACE_PEEKTEXT_AREA))
+ #define XLAT_STR_143 STRINGIFY(PTRACE_PEEKTEXT_AREA)
 #endif
 #endif
 #if defined __s390__
  XLAT(PTRACE_PEEKDATA_AREA),
+ #define XLAT_VAL_144 ((unsigned) (PTRACE_PEEKDATA_AREA))
+ #define XLAT_STR_144 STRINGIFY(PTRACE_PEEKDATA_AREA)
 #else
 #if defined(PTRACE_PEEKDATA_AREA) || (defined(HAVE_DECL_PTRACE_PEEKDATA_AREA) && HAVE_DECL_PTRACE_PEEKDATA_AREA)
   XLAT(PTRACE_PEEKDATA_AREA),
+ #define XLAT_VAL_145 ((unsigned) (PTRACE_PEEKDATA_AREA))
+ #define XLAT_STR_145 STRINGIFY(PTRACE_PEEKDATA_AREA)
 #endif
 #endif
 #if defined __s390__
  XLAT(PTRACE_POKETEXT_AREA),
+ #define XLAT_VAL_146 ((unsigned) (PTRACE_POKETEXT_AREA))
+ #define XLAT_STR_146 STRINGIFY(PTRACE_POKETEXT_AREA)
 #else
 #if defined(PTRACE_POKETEXT_AREA) || (defined(HAVE_DECL_PTRACE_POKETEXT_AREA) && HAVE_DECL_PTRACE_POKETEXT_AREA)
   XLAT(PTRACE_POKETEXT_AREA),
+ #define XLAT_VAL_147 ((unsigned) (PTRACE_POKETEXT_AREA))
+ #define XLAT_STR_147 STRINGIFY(PTRACE_POKETEXT_AREA)
 #endif
 #endif
 #if defined __s390__
  XLAT(PTRACE_POKEDATA_AREA),
+ #define XLAT_VAL_148 ((unsigned) (PTRACE_POKEDATA_AREA))
+ #define XLAT_STR_148 STRINGIFY(PTRACE_POKEDATA_AREA)
 #else
 #if defined(PTRACE_POKEDATA_AREA) || (defined(HAVE_DECL_PTRACE_POKEDATA_AREA) && HAVE_DECL_PTRACE_POKEDATA_AREA)
   XLAT(PTRACE_POKEDATA_AREA),
+ #define XLAT_VAL_149 ((unsigned) (PTRACE_POKEDATA_AREA))
+ #define XLAT_STR_149 STRINGIFY(PTRACE_POKEDATA_AREA)
 #endif
 #endif
 #if defined __s390__
  XLAT(PTRACE_GET_LAST_BREAK),
+ #define XLAT_VAL_150 ((unsigned) (PTRACE_GET_LAST_BREAK))
+ #define XLAT_STR_150 STRINGIFY(PTRACE_GET_LAST_BREAK)
 #else
 #if defined(PTRACE_GET_LAST_BREAK) || (defined(HAVE_DECL_PTRACE_GET_LAST_BREAK) && HAVE_DECL_PTRACE_GET_LAST_BREAK)
   XLAT(PTRACE_GET_LAST_BREAK),
+ #define XLAT_VAL_151 ((unsigned) (PTRACE_GET_LAST_BREAK))
+ #define XLAT_STR_151 STRINGIFY(PTRACE_GET_LAST_BREAK)
 #endif
 #endif
 #if defined __s390__
  XLAT(PTRACE_PEEK_SYSTEM_CALL),
+ #define XLAT_VAL_152 ((unsigned) (PTRACE_PEEK_SYSTEM_CALL))
+ #define XLAT_STR_152 STRINGIFY(PTRACE_PEEK_SYSTEM_CALL)
 #else
 #if defined(PTRACE_PEEK_SYSTEM_CALL) || (defined(HAVE_DECL_PTRACE_PEEK_SYSTEM_CALL) && HAVE_DECL_PTRACE_PEEK_SYSTEM_CALL)
   XLAT(PTRACE_PEEK_SYSTEM_CALL),
+ #define XLAT_VAL_153 ((unsigned) (PTRACE_PEEK_SYSTEM_CALL))
+ #define XLAT_STR_153 STRINGIFY(PTRACE_PEEK_SYSTEM_CALL)
 #endif
 #endif
 #if defined __s390__
  XLAT(PTRACE_POKE_SYSTEM_CALL),
+ #define XLAT_VAL_154 ((unsigned) (PTRACE_POKE_SYSTEM_CALL))
+ #define XLAT_STR_154 STRINGIFY(PTRACE_POKE_SYSTEM_CALL)
 #else
 #if defined(PTRACE_POKE_SYSTEM_CALL) || (defined(HAVE_DECL_PTRACE_POKE_SYSTEM_CALL) && HAVE_DECL_PTRACE_POKE_SYSTEM_CALL)
   XLAT(PTRACE_POKE_SYSTEM_CALL),
+ #define XLAT_VAL_155 ((unsigned) (PTRACE_POKE_SYSTEM_CALL))
+ #define XLAT_STR_155 STRINGIFY(PTRACE_POKE_SYSTEM_CALL)
 #endif
 #endif
 #if defined __s390__
  XLAT(PTRACE_ENABLE_TE),
+ #define XLAT_VAL_156 ((unsigned) (PTRACE_ENABLE_TE))
+ #define XLAT_STR_156 STRINGIFY(PTRACE_ENABLE_TE)
 #else
 #if defined(PTRACE_ENABLE_TE) || (defined(HAVE_DECL_PTRACE_ENABLE_TE) && HAVE_DECL_PTRACE_ENABLE_TE)
   XLAT(PTRACE_ENABLE_TE),
+ #define XLAT_VAL_157 ((unsigned) (PTRACE_ENABLE_TE))
+ #define XLAT_STR_157 STRINGIFY(PTRACE_ENABLE_TE)
 #endif
 #endif
 #if defined __s390__
  XLAT(PTRACE_DISABLE_TE),
+ #define XLAT_VAL_158 ((unsigned) (PTRACE_DISABLE_TE))
+ #define XLAT_STR_158 STRINGIFY(PTRACE_DISABLE_TE)
 #else
 #if defined(PTRACE_DISABLE_TE) || (defined(HAVE_DECL_PTRACE_DISABLE_TE) && HAVE_DECL_PTRACE_DISABLE_TE)
   XLAT(PTRACE_DISABLE_TE),
+ #define XLAT_VAL_159 ((unsigned) (PTRACE_DISABLE_TE))
+ #define XLAT_STR_159 STRINGIFY(PTRACE_DISABLE_TE)
 #endif
 #endif
 #if defined __s390__
  XLAT(PTRACE_TE_ABORT_RAND),
+ #define XLAT_VAL_160 ((unsigned) (PTRACE_TE_ABORT_RAND))
+ #define XLAT_STR_160 STRINGIFY(PTRACE_TE_ABORT_RAND)
 #else
 #if defined(PTRACE_TE_ABORT_RAND) || (defined(HAVE_DECL_PTRACE_TE_ABORT_RAND) && HAVE_DECL_PTRACE_TE_ABORT_RAND)
   XLAT(PTRACE_TE_ABORT_RAND),
+ #define XLAT_VAL_161 ((unsigned) (PTRACE_TE_ABORT_RAND))
+ #define XLAT_STR_161 STRINGIFY(PTRACE_TE_ABORT_RAND)
 #endif
 #endif
 
 
 #if defined __sh__
  XLAT(PTRACE_GETDSPREGS),
+ #define XLAT_VAL_162 ((unsigned) (PTRACE_GETDSPREGS))
+ #define XLAT_STR_162 STRINGIFY(PTRACE_GETDSPREGS)
 #else
 #if defined(PTRACE_GETDSPREGS) || (defined(HAVE_DECL_PTRACE_GETDSPREGS) && HAVE_DECL_PTRACE_GETDSPREGS)
   XLAT(PTRACE_GETDSPREGS),
+ #define XLAT_VAL_163 ((unsigned) (PTRACE_GETDSPREGS))
+ #define XLAT_STR_163 STRINGIFY(PTRACE_GETDSPREGS)
 #endif
 #endif
 #if defined __sh__
  XLAT(PTRACE_SETDSPREGS),
+ #define XLAT_VAL_164 ((unsigned) (PTRACE_SETDSPREGS))
+ #define XLAT_STR_164 STRINGIFY(PTRACE_SETDSPREGS)
 #else
 #if defined(PTRACE_SETDSPREGS) || (defined(HAVE_DECL_PTRACE_SETDSPREGS) && HAVE_DECL_PTRACE_SETDSPREGS)
   XLAT(PTRACE_SETDSPREGS),
+ #define XLAT_VAL_165 ((unsigned) (PTRACE_SETDSPREGS))
+ #define XLAT_STR_165 STRINGIFY(PTRACE_SETDSPREGS)
 #endif
 #endif
 
 
 #if defined __sparc__
  XLAT(PTRACE_SPARC_DETACH),
+ #define XLAT_VAL_166 ((unsigned) (PTRACE_SPARC_DETACH))
+ #define XLAT_STR_166 STRINGIFY(PTRACE_SPARC_DETACH)
 #else
 #if defined(PTRACE_SPARC_DETACH) || (defined(HAVE_DECL_PTRACE_SPARC_DETACH) && HAVE_DECL_PTRACE_SPARC_DETACH)
   XLAT(PTRACE_SPARC_DETACH),
+ #define XLAT_VAL_167 ((unsigned) (PTRACE_SPARC_DETACH))
+ #define XLAT_STR_167 STRINGIFY(PTRACE_SPARC_DETACH)
 #endif
 #endif
 #if defined __sparc__
  XLAT(PTRACE_READDATA),
+ #define XLAT_VAL_168 ((unsigned) (PTRACE_READDATA))
+ #define XLAT_STR_168 STRINGIFY(PTRACE_READDATA)
 #else
 #if defined(PTRACE_READDATA) || (defined(HAVE_DECL_PTRACE_READDATA) && HAVE_DECL_PTRACE_READDATA)
   XLAT(PTRACE_READDATA),
+ #define XLAT_VAL_169 ((unsigned) (PTRACE_READDATA))
+ #define XLAT_STR_169 STRINGIFY(PTRACE_READDATA)
 #endif
 #endif
 #if defined __sparc__
  XLAT(PTRACE_WRITEDATA),
+ #define XLAT_VAL_170 ((unsigned) (PTRACE_WRITEDATA))
+ #define XLAT_STR_170 STRINGIFY(PTRACE_WRITEDATA)
 #else
 #if defined(PTRACE_WRITEDATA) || (defined(HAVE_DECL_PTRACE_WRITEDATA) && HAVE_DECL_PTRACE_WRITEDATA)
   XLAT(PTRACE_WRITEDATA),
+ #define XLAT_VAL_171 ((unsigned) (PTRACE_WRITEDATA))
+ #define XLAT_STR_171 STRINGIFY(PTRACE_WRITEDATA)
 #endif
 #endif
 #if defined __sparc__
  XLAT(PTRACE_READTEXT),
+ #define XLAT_VAL_172 ((unsigned) (PTRACE_READTEXT))
+ #define XLAT_STR_172 STRINGIFY(PTRACE_READTEXT)
 #else
 #if defined(PTRACE_READTEXT) || (defined(HAVE_DECL_PTRACE_READTEXT) && HAVE_DECL_PTRACE_READTEXT)
   XLAT(PTRACE_READTEXT),
+ #define XLAT_VAL_173 ((unsigned) (PTRACE_READTEXT))
+ #define XLAT_STR_173 STRINGIFY(PTRACE_READTEXT)
 #endif
 #endif
 #if defined __sparc__
  XLAT(PTRACE_WRITETEXT),
+ #define XLAT_VAL_174 ((unsigned) (PTRACE_WRITETEXT))
+ #define XLAT_STR_174 STRINGIFY(PTRACE_WRITETEXT)
 #else
 #if defined(PTRACE_WRITETEXT) || (defined(HAVE_DECL_PTRACE_WRITETEXT) && HAVE_DECL_PTRACE_WRITETEXT)
   XLAT(PTRACE_WRITETEXT),
+ #define XLAT_VAL_175 ((unsigned) (PTRACE_WRITETEXT))
+ #define XLAT_STR_175 STRINGIFY(PTRACE_WRITETEXT)
 #endif
 #endif
 #if defined __sparc__
  XLAT(PTRACE_GETFPAREGS),
+ #define XLAT_VAL_176 ((unsigned) (PTRACE_GETFPAREGS))
+ #define XLAT_STR_176 STRINGIFY(PTRACE_GETFPAREGS)
 #else
 #if defined(PTRACE_GETFPAREGS) || (defined(HAVE_DECL_PTRACE_GETFPAREGS) && HAVE_DECL_PTRACE_GETFPAREGS)
   XLAT(PTRACE_GETFPAREGS),
+ #define XLAT_VAL_177 ((unsigned) (PTRACE_GETFPAREGS))
+ #define XLAT_STR_177 STRINGIFY(PTRACE_GETFPAREGS)
 #endif
 #endif
 #if defined __sparc__
  XLAT(PTRACE_SETFPAREGS),
+ #define XLAT_VAL_178 ((unsigned) (PTRACE_SETFPAREGS))
+ #define XLAT_STR_178 STRINGIFY(PTRACE_SETFPAREGS)
 #else
 #if defined(PTRACE_SETFPAREGS) || (defined(HAVE_DECL_PTRACE_SETFPAREGS) && HAVE_DECL_PTRACE_SETFPAREGS)
   XLAT(PTRACE_SETFPAREGS),
+ #define XLAT_VAL_179 ((unsigned) (PTRACE_SETFPAREGS))
+ #define XLAT_STR_179 STRINGIFY(PTRACE_SETFPAREGS)
 #endif
 #endif
 #if defined __sparc__
  XLAT(PTRACE_GETFPREGS64),
+ #define XLAT_VAL_180 ((unsigned) (PTRACE_GETFPREGS64))
+ #define XLAT_STR_180 STRINGIFY(PTRACE_GETFPREGS64)
 #else
 #if defined(PTRACE_GETFPREGS64) || (defined(HAVE_DECL_PTRACE_GETFPREGS64) && HAVE_DECL_PTRACE_GETFPREGS64)
   XLAT(PTRACE_GETFPREGS64),
+ #define XLAT_VAL_181 ((unsigned) (PTRACE_GETFPREGS64))
+ #define XLAT_STR_181 STRINGIFY(PTRACE_GETFPREGS64)
 #endif
 #endif
 #if defined __sparc__
  XLAT(PTRACE_SETFPREGS64),
+ #define XLAT_VAL_182 ((unsigned) (PTRACE_SETFPREGS64))
+ #define XLAT_STR_182 STRINGIFY(PTRACE_SETFPREGS64)
 #else
 #if defined(PTRACE_SETFPREGS64) || (defined(HAVE_DECL_PTRACE_SETFPREGS64) && HAVE_DECL_PTRACE_SETFPREGS64)
   XLAT(PTRACE_SETFPREGS64),
+ #define XLAT_VAL_183 ((unsigned) (PTRACE_SETFPREGS64))
+ #define XLAT_STR_183 STRINGIFY(PTRACE_SETFPREGS64)
 #endif
 #endif
 
 
 #if defined __x86_64__ || defined __i386__
  XLAT(PTRACE_ARCH_PRCTL),
+ #define XLAT_VAL_184 ((unsigned) (PTRACE_ARCH_PRCTL))
+ #define XLAT_STR_184 STRINGIFY(PTRACE_ARCH_PRCTL)
 #else
 #if defined(PTRACE_ARCH_PRCTL) || (defined(HAVE_DECL_PTRACE_ARCH_PRCTL) && HAVE_DECL_PTRACE_ARCH_PRCTL)
   XLAT(PTRACE_ARCH_PRCTL),
+ #define XLAT_VAL_185 ((unsigned) (PTRACE_ARCH_PRCTL))
+ #define XLAT_STR_185 STRINGIFY(PTRACE_ARCH_PRCTL)
 #endif
 #endif
 
 
 #if defined __xtensa__
  XLAT(PTRACE_GETXTREGS),
+ #define XLAT_VAL_186 ((unsigned) (PTRACE_GETXTREGS))
+ #define XLAT_STR_186 STRINGIFY(PTRACE_GETXTREGS)
 #else
 #if defined(PTRACE_GETXTREGS) || (defined(HAVE_DECL_PTRACE_GETXTREGS) && HAVE_DECL_PTRACE_GETXTREGS)
   XLAT(PTRACE_GETXTREGS),
+ #define XLAT_VAL_187 ((unsigned) (PTRACE_GETXTREGS))
+ #define XLAT_STR_187 STRINGIFY(PTRACE_GETXTREGS)
 #endif
 #endif
 #if defined __xtensa__
  XLAT(PTRACE_SETXTREGS),
+ #define XLAT_VAL_188 ((unsigned) (PTRACE_SETXTREGS))
+ #define XLAT_STR_188 STRINGIFY(PTRACE_SETXTREGS)
 #else
 #if defined(PTRACE_SETXTREGS) || (defined(HAVE_DECL_PTRACE_SETXTREGS) && HAVE_DECL_PTRACE_SETXTREGS)
   XLAT(PTRACE_SETXTREGS),
+ #define XLAT_VAL_189 ((unsigned) (PTRACE_SETXTREGS))
+ #define XLAT_STR_189 STRINGIFY(PTRACE_SETXTREGS)
 #endif
 #endif
 };
@@ -1673,8 +2053,1532 @@ const struct xlat ptrace_cmds[1] = { {
  .data = ptrace_cmds_xdata,
  .size = ARRAY_SIZE(ptrace_cmds_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+#  ifdef XLAT_VAL_47
+  | XLAT_VAL_47
+#  endif
+#  ifdef XLAT_VAL_48
+  | XLAT_VAL_48
+#  endif
+#  ifdef XLAT_VAL_49
+  | XLAT_VAL_49
+#  endif
+#  ifdef XLAT_VAL_50
+  | XLAT_VAL_50
+#  endif
+#  ifdef XLAT_VAL_51
+  | XLAT_VAL_51
+#  endif
+#  ifdef XLAT_VAL_52
+  | XLAT_VAL_52
+#  endif
+#  ifdef XLAT_VAL_53
+  | XLAT_VAL_53
+#  endif
+#  ifdef XLAT_VAL_54
+  | XLAT_VAL_54
+#  endif
+#  ifdef XLAT_VAL_55
+  | XLAT_VAL_55
+#  endif
+#  ifdef XLAT_VAL_56
+  | XLAT_VAL_56
+#  endif
+#  ifdef XLAT_VAL_57
+  | XLAT_VAL_57
+#  endif
+#  ifdef XLAT_VAL_58
+  | XLAT_VAL_58
+#  endif
+#  ifdef XLAT_VAL_59
+  | XLAT_VAL_59
+#  endif
+#  ifdef XLAT_VAL_60
+  | XLAT_VAL_60
+#  endif
+#  ifdef XLAT_VAL_61
+  | XLAT_VAL_61
+#  endif
+#  ifdef XLAT_VAL_62
+  | XLAT_VAL_62
+#  endif
+#  ifdef XLAT_VAL_63
+  | XLAT_VAL_63
+#  endif
+#  ifdef XLAT_VAL_64
+  | XLAT_VAL_64
+#  endif
+#  ifdef XLAT_VAL_65
+  | XLAT_VAL_65
+#  endif
+#  ifdef XLAT_VAL_66
+  | XLAT_VAL_66
+#  endif
+#  ifdef XLAT_VAL_67
+  | XLAT_VAL_67
+#  endif
+#  ifdef XLAT_VAL_68
+  | XLAT_VAL_68
+#  endif
+#  ifdef XLAT_VAL_69
+  | XLAT_VAL_69
+#  endif
+#  ifdef XLAT_VAL_70
+  | XLAT_VAL_70
+#  endif
+#  ifdef XLAT_VAL_71
+  | XLAT_VAL_71
+#  endif
+#  ifdef XLAT_VAL_72
+  | XLAT_VAL_72
+#  endif
+#  ifdef XLAT_VAL_73
+  | XLAT_VAL_73
+#  endif
+#  ifdef XLAT_VAL_74
+  | XLAT_VAL_74
+#  endif
+#  ifdef XLAT_VAL_75
+  | XLAT_VAL_75
+#  endif
+#  ifdef XLAT_VAL_76
+  | XLAT_VAL_76
+#  endif
+#  ifdef XLAT_VAL_77
+  | XLAT_VAL_77
+#  endif
+#  ifdef XLAT_VAL_78
+  | XLAT_VAL_78
+#  endif
+#  ifdef XLAT_VAL_79
+  | XLAT_VAL_79
+#  endif
+#  ifdef XLAT_VAL_80
+  | XLAT_VAL_80
+#  endif
+#  ifdef XLAT_VAL_81
+  | XLAT_VAL_81
+#  endif
+#  ifdef XLAT_VAL_82
+  | XLAT_VAL_82
+#  endif
+#  ifdef XLAT_VAL_83
+  | XLAT_VAL_83
+#  endif
+#  ifdef XLAT_VAL_84
+  | XLAT_VAL_84
+#  endif
+#  ifdef XLAT_VAL_85
+  | XLAT_VAL_85
+#  endif
+#  ifdef XLAT_VAL_86
+  | XLAT_VAL_86
+#  endif
+#  ifdef XLAT_VAL_87
+  | XLAT_VAL_87
+#  endif
+#  ifdef XLAT_VAL_88
+  | XLAT_VAL_88
+#  endif
+#  ifdef XLAT_VAL_89
+  | XLAT_VAL_89
+#  endif
+#  ifdef XLAT_VAL_90
+  | XLAT_VAL_90
+#  endif
+#  ifdef XLAT_VAL_91
+  | XLAT_VAL_91
+#  endif
+#  ifdef XLAT_VAL_92
+  | XLAT_VAL_92
+#  endif
+#  ifdef XLAT_VAL_93
+  | XLAT_VAL_93
+#  endif
+#  ifdef XLAT_VAL_94
+  | XLAT_VAL_94
+#  endif
+#  ifdef XLAT_VAL_95
+  | XLAT_VAL_95
+#  endif
+#  ifdef XLAT_VAL_96
+  | XLAT_VAL_96
+#  endif
+#  ifdef XLAT_VAL_97
+  | XLAT_VAL_97
+#  endif
+#  ifdef XLAT_VAL_98
+  | XLAT_VAL_98
+#  endif
+#  ifdef XLAT_VAL_99
+  | XLAT_VAL_99
+#  endif
+#  ifdef XLAT_VAL_100
+  | XLAT_VAL_100
+#  endif
+#  ifdef XLAT_VAL_101
+  | XLAT_VAL_101
+#  endif
+#  ifdef XLAT_VAL_102
+  | XLAT_VAL_102
+#  endif
+#  ifdef XLAT_VAL_103
+  | XLAT_VAL_103
+#  endif
+#  ifdef XLAT_VAL_104
+  | XLAT_VAL_104
+#  endif
+#  ifdef XLAT_VAL_105
+  | XLAT_VAL_105
+#  endif
+#  ifdef XLAT_VAL_106
+  | XLAT_VAL_106
+#  endif
+#  ifdef XLAT_VAL_107
+  | XLAT_VAL_107
+#  endif
+#  ifdef XLAT_VAL_108
+  | XLAT_VAL_108
+#  endif
+#  ifdef XLAT_VAL_109
+  | XLAT_VAL_109
+#  endif
+#  ifdef XLAT_VAL_110
+  | XLAT_VAL_110
+#  endif
+#  ifdef XLAT_VAL_111
+  | XLAT_VAL_111
+#  endif
+#  ifdef XLAT_VAL_112
+  | XLAT_VAL_112
+#  endif
+#  ifdef XLAT_VAL_113
+  | XLAT_VAL_113
+#  endif
+#  ifdef XLAT_VAL_114
+  | XLAT_VAL_114
+#  endif
+#  ifdef XLAT_VAL_115
+  | XLAT_VAL_115
+#  endif
+#  ifdef XLAT_VAL_116
+  | XLAT_VAL_116
+#  endif
+#  ifdef XLAT_VAL_117
+  | XLAT_VAL_117
+#  endif
+#  ifdef XLAT_VAL_118
+  | XLAT_VAL_118
+#  endif
+#  ifdef XLAT_VAL_119
+  | XLAT_VAL_119
+#  endif
+#  ifdef XLAT_VAL_120
+  | XLAT_VAL_120
+#  endif
+#  ifdef XLAT_VAL_121
+  | XLAT_VAL_121
+#  endif
+#  ifdef XLAT_VAL_122
+  | XLAT_VAL_122
+#  endif
+#  ifdef XLAT_VAL_123
+  | XLAT_VAL_123
+#  endif
+#  ifdef XLAT_VAL_124
+  | XLAT_VAL_124
+#  endif
+#  ifdef XLAT_VAL_125
+  | XLAT_VAL_125
+#  endif
+#  ifdef XLAT_VAL_126
+  | XLAT_VAL_126
+#  endif
+#  ifdef XLAT_VAL_127
+  | XLAT_VAL_127
+#  endif
+#  ifdef XLAT_VAL_128
+  | XLAT_VAL_128
+#  endif
+#  ifdef XLAT_VAL_129
+  | XLAT_VAL_129
+#  endif
+#  ifdef XLAT_VAL_130
+  | XLAT_VAL_130
+#  endif
+#  ifdef XLAT_VAL_131
+  | XLAT_VAL_131
+#  endif
+#  ifdef XLAT_VAL_132
+  | XLAT_VAL_132
+#  endif
+#  ifdef XLAT_VAL_133
+  | XLAT_VAL_133
+#  endif
+#  ifdef XLAT_VAL_134
+  | XLAT_VAL_134
+#  endif
+#  ifdef XLAT_VAL_135
+  | XLAT_VAL_135
+#  endif
+#  ifdef XLAT_VAL_136
+  | XLAT_VAL_136
+#  endif
+#  ifdef XLAT_VAL_137
+  | XLAT_VAL_137
+#  endif
+#  ifdef XLAT_VAL_138
+  | XLAT_VAL_138
+#  endif
+#  ifdef XLAT_VAL_139
+  | XLAT_VAL_139
+#  endif
+#  ifdef XLAT_VAL_140
+  | XLAT_VAL_140
+#  endif
+#  ifdef XLAT_VAL_141
+  | XLAT_VAL_141
+#  endif
+#  ifdef XLAT_VAL_142
+  | XLAT_VAL_142
+#  endif
+#  ifdef XLAT_VAL_143
+  | XLAT_VAL_143
+#  endif
+#  ifdef XLAT_VAL_144
+  | XLAT_VAL_144
+#  endif
+#  ifdef XLAT_VAL_145
+  | XLAT_VAL_145
+#  endif
+#  ifdef XLAT_VAL_146
+  | XLAT_VAL_146
+#  endif
+#  ifdef XLAT_VAL_147
+  | XLAT_VAL_147
+#  endif
+#  ifdef XLAT_VAL_148
+  | XLAT_VAL_148
+#  endif
+#  ifdef XLAT_VAL_149
+  | XLAT_VAL_149
+#  endif
+#  ifdef XLAT_VAL_150
+  | XLAT_VAL_150
+#  endif
+#  ifdef XLAT_VAL_151
+  | XLAT_VAL_151
+#  endif
+#  ifdef XLAT_VAL_152
+  | XLAT_VAL_152
+#  endif
+#  ifdef XLAT_VAL_153
+  | XLAT_VAL_153
+#  endif
+#  ifdef XLAT_VAL_154
+  | XLAT_VAL_154
+#  endif
+#  ifdef XLAT_VAL_155
+  | XLAT_VAL_155
+#  endif
+#  ifdef XLAT_VAL_156
+  | XLAT_VAL_156
+#  endif
+#  ifdef XLAT_VAL_157
+  | XLAT_VAL_157
+#  endif
+#  ifdef XLAT_VAL_158
+  | XLAT_VAL_158
+#  endif
+#  ifdef XLAT_VAL_159
+  | XLAT_VAL_159
+#  endif
+#  ifdef XLAT_VAL_160
+  | XLAT_VAL_160
+#  endif
+#  ifdef XLAT_VAL_161
+  | XLAT_VAL_161
+#  endif
+#  ifdef XLAT_VAL_162
+  | XLAT_VAL_162
+#  endif
+#  ifdef XLAT_VAL_163
+  | XLAT_VAL_163
+#  endif
+#  ifdef XLAT_VAL_164
+  | XLAT_VAL_164
+#  endif
+#  ifdef XLAT_VAL_165
+  | XLAT_VAL_165
+#  endif
+#  ifdef XLAT_VAL_166
+  | XLAT_VAL_166
+#  endif
+#  ifdef XLAT_VAL_167
+  | XLAT_VAL_167
+#  endif
+#  ifdef XLAT_VAL_168
+  | XLAT_VAL_168
+#  endif
+#  ifdef XLAT_VAL_169
+  | XLAT_VAL_169
+#  endif
+#  ifdef XLAT_VAL_170
+  | XLAT_VAL_170
+#  endif
+#  ifdef XLAT_VAL_171
+  | XLAT_VAL_171
+#  endif
+#  ifdef XLAT_VAL_172
+  | XLAT_VAL_172
+#  endif
+#  ifdef XLAT_VAL_173
+  | XLAT_VAL_173
+#  endif
+#  ifdef XLAT_VAL_174
+  | XLAT_VAL_174
+#  endif
+#  ifdef XLAT_VAL_175
+  | XLAT_VAL_175
+#  endif
+#  ifdef XLAT_VAL_176
+  | XLAT_VAL_176
+#  endif
+#  ifdef XLAT_VAL_177
+  | XLAT_VAL_177
+#  endif
+#  ifdef XLAT_VAL_178
+  | XLAT_VAL_178
+#  endif
+#  ifdef XLAT_VAL_179
+  | XLAT_VAL_179
+#  endif
+#  ifdef XLAT_VAL_180
+  | XLAT_VAL_180
+#  endif
+#  ifdef XLAT_VAL_181
+  | XLAT_VAL_181
+#  endif
+#  ifdef XLAT_VAL_182
+  | XLAT_VAL_182
+#  endif
+#  ifdef XLAT_VAL_183
+  | XLAT_VAL_183
+#  endif
+#  ifdef XLAT_VAL_184
+  | XLAT_VAL_184
+#  endif
+#  ifdef XLAT_VAL_185
+  | XLAT_VAL_185
+#  endif
+#  ifdef XLAT_VAL_186
+  | XLAT_VAL_186
+#  endif
+#  ifdef XLAT_VAL_187
+  | XLAT_VAL_187
+#  endif
+#  ifdef XLAT_VAL_188
+  | XLAT_VAL_188
+#  endif
+#  ifdef XLAT_VAL_189
+  | XLAT_VAL_189
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+#  ifdef XLAT_STR_47
+  + sizeof(XLAT_STR_47)
+#  endif
+#  ifdef XLAT_STR_48
+  + sizeof(XLAT_STR_48)
+#  endif
+#  ifdef XLAT_STR_49
+  + sizeof(XLAT_STR_49)
+#  endif
+#  ifdef XLAT_STR_50
+  + sizeof(XLAT_STR_50)
+#  endif
+#  ifdef XLAT_STR_51
+  + sizeof(XLAT_STR_51)
+#  endif
+#  ifdef XLAT_STR_52
+  + sizeof(XLAT_STR_52)
+#  endif
+#  ifdef XLAT_STR_53
+  + sizeof(XLAT_STR_53)
+#  endif
+#  ifdef XLAT_STR_54
+  + sizeof(XLAT_STR_54)
+#  endif
+#  ifdef XLAT_STR_55
+  + sizeof(XLAT_STR_55)
+#  endif
+#  ifdef XLAT_STR_56
+  + sizeof(XLAT_STR_56)
+#  endif
+#  ifdef XLAT_STR_57
+  + sizeof(XLAT_STR_57)
+#  endif
+#  ifdef XLAT_STR_58
+  + sizeof(XLAT_STR_58)
+#  endif
+#  ifdef XLAT_STR_59
+  + sizeof(XLAT_STR_59)
+#  endif
+#  ifdef XLAT_STR_60
+  + sizeof(XLAT_STR_60)
+#  endif
+#  ifdef XLAT_STR_61
+  + sizeof(XLAT_STR_61)
+#  endif
+#  ifdef XLAT_STR_62
+  + sizeof(XLAT_STR_62)
+#  endif
+#  ifdef XLAT_STR_63
+  + sizeof(XLAT_STR_63)
+#  endif
+#  ifdef XLAT_STR_64
+  + sizeof(XLAT_STR_64)
+#  endif
+#  ifdef XLAT_STR_65
+  + sizeof(XLAT_STR_65)
+#  endif
+#  ifdef XLAT_STR_66
+  + sizeof(XLAT_STR_66)
+#  endif
+#  ifdef XLAT_STR_67
+  + sizeof(XLAT_STR_67)
+#  endif
+#  ifdef XLAT_STR_68
+  + sizeof(XLAT_STR_68)
+#  endif
+#  ifdef XLAT_STR_69
+  + sizeof(XLAT_STR_69)
+#  endif
+#  ifdef XLAT_STR_70
+  + sizeof(XLAT_STR_70)
+#  endif
+#  ifdef XLAT_STR_71
+  + sizeof(XLAT_STR_71)
+#  endif
+#  ifdef XLAT_STR_72
+  + sizeof(XLAT_STR_72)
+#  endif
+#  ifdef XLAT_STR_73
+  + sizeof(XLAT_STR_73)
+#  endif
+#  ifdef XLAT_STR_74
+  + sizeof(XLAT_STR_74)
+#  endif
+#  ifdef XLAT_STR_75
+  + sizeof(XLAT_STR_75)
+#  endif
+#  ifdef XLAT_STR_76
+  + sizeof(XLAT_STR_76)
+#  endif
+#  ifdef XLAT_STR_77
+  + sizeof(XLAT_STR_77)
+#  endif
+#  ifdef XLAT_STR_78
+  + sizeof(XLAT_STR_78)
+#  endif
+#  ifdef XLAT_STR_79
+  + sizeof(XLAT_STR_79)
+#  endif
+#  ifdef XLAT_STR_80
+  + sizeof(XLAT_STR_80)
+#  endif
+#  ifdef XLAT_STR_81
+  + sizeof(XLAT_STR_81)
+#  endif
+#  ifdef XLAT_STR_82
+  + sizeof(XLAT_STR_82)
+#  endif
+#  ifdef XLAT_STR_83
+  + sizeof(XLAT_STR_83)
+#  endif
+#  ifdef XLAT_STR_84
+  + sizeof(XLAT_STR_84)
+#  endif
+#  ifdef XLAT_STR_85
+  + sizeof(XLAT_STR_85)
+#  endif
+#  ifdef XLAT_STR_86
+  + sizeof(XLAT_STR_86)
+#  endif
+#  ifdef XLAT_STR_87
+  + sizeof(XLAT_STR_87)
+#  endif
+#  ifdef XLAT_STR_88
+  + sizeof(XLAT_STR_88)
+#  endif
+#  ifdef XLAT_STR_89
+  + sizeof(XLAT_STR_89)
+#  endif
+#  ifdef XLAT_STR_90
+  + sizeof(XLAT_STR_90)
+#  endif
+#  ifdef XLAT_STR_91
+  + sizeof(XLAT_STR_91)
+#  endif
+#  ifdef XLAT_STR_92
+  + sizeof(XLAT_STR_92)
+#  endif
+#  ifdef XLAT_STR_93
+  + sizeof(XLAT_STR_93)
+#  endif
+#  ifdef XLAT_STR_94
+  + sizeof(XLAT_STR_94)
+#  endif
+#  ifdef XLAT_STR_95
+  + sizeof(XLAT_STR_95)
+#  endif
+#  ifdef XLAT_STR_96
+  + sizeof(XLAT_STR_96)
+#  endif
+#  ifdef XLAT_STR_97
+  + sizeof(XLAT_STR_97)
+#  endif
+#  ifdef XLAT_STR_98
+  + sizeof(XLAT_STR_98)
+#  endif
+#  ifdef XLAT_STR_99
+  + sizeof(XLAT_STR_99)
+#  endif
+#  ifdef XLAT_STR_100
+  + sizeof(XLAT_STR_100)
+#  endif
+#  ifdef XLAT_STR_101
+  + sizeof(XLAT_STR_101)
+#  endif
+#  ifdef XLAT_STR_102
+  + sizeof(XLAT_STR_102)
+#  endif
+#  ifdef XLAT_STR_103
+  + sizeof(XLAT_STR_103)
+#  endif
+#  ifdef XLAT_STR_104
+  + sizeof(XLAT_STR_104)
+#  endif
+#  ifdef XLAT_STR_105
+  + sizeof(XLAT_STR_105)
+#  endif
+#  ifdef XLAT_STR_106
+  + sizeof(XLAT_STR_106)
+#  endif
+#  ifdef XLAT_STR_107
+  + sizeof(XLAT_STR_107)
+#  endif
+#  ifdef XLAT_STR_108
+  + sizeof(XLAT_STR_108)
+#  endif
+#  ifdef XLAT_STR_109
+  + sizeof(XLAT_STR_109)
+#  endif
+#  ifdef XLAT_STR_110
+  + sizeof(XLAT_STR_110)
+#  endif
+#  ifdef XLAT_STR_111
+  + sizeof(XLAT_STR_111)
+#  endif
+#  ifdef XLAT_STR_112
+  + sizeof(XLAT_STR_112)
+#  endif
+#  ifdef XLAT_STR_113
+  + sizeof(XLAT_STR_113)
+#  endif
+#  ifdef XLAT_STR_114
+  + sizeof(XLAT_STR_114)
+#  endif
+#  ifdef XLAT_STR_115
+  + sizeof(XLAT_STR_115)
+#  endif
+#  ifdef XLAT_STR_116
+  + sizeof(XLAT_STR_116)
+#  endif
+#  ifdef XLAT_STR_117
+  + sizeof(XLAT_STR_117)
+#  endif
+#  ifdef XLAT_STR_118
+  + sizeof(XLAT_STR_118)
+#  endif
+#  ifdef XLAT_STR_119
+  + sizeof(XLAT_STR_119)
+#  endif
+#  ifdef XLAT_STR_120
+  + sizeof(XLAT_STR_120)
+#  endif
+#  ifdef XLAT_STR_121
+  + sizeof(XLAT_STR_121)
+#  endif
+#  ifdef XLAT_STR_122
+  + sizeof(XLAT_STR_122)
+#  endif
+#  ifdef XLAT_STR_123
+  + sizeof(XLAT_STR_123)
+#  endif
+#  ifdef XLAT_STR_124
+  + sizeof(XLAT_STR_124)
+#  endif
+#  ifdef XLAT_STR_125
+  + sizeof(XLAT_STR_125)
+#  endif
+#  ifdef XLAT_STR_126
+  + sizeof(XLAT_STR_126)
+#  endif
+#  ifdef XLAT_STR_127
+  + sizeof(XLAT_STR_127)
+#  endif
+#  ifdef XLAT_STR_128
+  + sizeof(XLAT_STR_128)
+#  endif
+#  ifdef XLAT_STR_129
+  + sizeof(XLAT_STR_129)
+#  endif
+#  ifdef XLAT_STR_130
+  + sizeof(XLAT_STR_130)
+#  endif
+#  ifdef XLAT_STR_131
+  + sizeof(XLAT_STR_131)
+#  endif
+#  ifdef XLAT_STR_132
+  + sizeof(XLAT_STR_132)
+#  endif
+#  ifdef XLAT_STR_133
+  + sizeof(XLAT_STR_133)
+#  endif
+#  ifdef XLAT_STR_134
+  + sizeof(XLAT_STR_134)
+#  endif
+#  ifdef XLAT_STR_135
+  + sizeof(XLAT_STR_135)
+#  endif
+#  ifdef XLAT_STR_136
+  + sizeof(XLAT_STR_136)
+#  endif
+#  ifdef XLAT_STR_137
+  + sizeof(XLAT_STR_137)
+#  endif
+#  ifdef XLAT_STR_138
+  + sizeof(XLAT_STR_138)
+#  endif
+#  ifdef XLAT_STR_139
+  + sizeof(XLAT_STR_139)
+#  endif
+#  ifdef XLAT_STR_140
+  + sizeof(XLAT_STR_140)
+#  endif
+#  ifdef XLAT_STR_141
+  + sizeof(XLAT_STR_141)
+#  endif
+#  ifdef XLAT_STR_142
+  + sizeof(XLAT_STR_142)
+#  endif
+#  ifdef XLAT_STR_143
+  + sizeof(XLAT_STR_143)
+#  endif
+#  ifdef XLAT_STR_144
+  + sizeof(XLAT_STR_144)
+#  endif
+#  ifdef XLAT_STR_145
+  + sizeof(XLAT_STR_145)
+#  endif
+#  ifdef XLAT_STR_146
+  + sizeof(XLAT_STR_146)
+#  endif
+#  ifdef XLAT_STR_147
+  + sizeof(XLAT_STR_147)
+#  endif
+#  ifdef XLAT_STR_148
+  + sizeof(XLAT_STR_148)
+#  endif
+#  ifdef XLAT_STR_149
+  + sizeof(XLAT_STR_149)
+#  endif
+#  ifdef XLAT_STR_150
+  + sizeof(XLAT_STR_150)
+#  endif
+#  ifdef XLAT_STR_151
+  + sizeof(XLAT_STR_151)
+#  endif
+#  ifdef XLAT_STR_152
+  + sizeof(XLAT_STR_152)
+#  endif
+#  ifdef XLAT_STR_153
+  + sizeof(XLAT_STR_153)
+#  endif
+#  ifdef XLAT_STR_154
+  + sizeof(XLAT_STR_154)
+#  endif
+#  ifdef XLAT_STR_155
+  + sizeof(XLAT_STR_155)
+#  endif
+#  ifdef XLAT_STR_156
+  + sizeof(XLAT_STR_156)
+#  endif
+#  ifdef XLAT_STR_157
+  + sizeof(XLAT_STR_157)
+#  endif
+#  ifdef XLAT_STR_158
+  + sizeof(XLAT_STR_158)
+#  endif
+#  ifdef XLAT_STR_159
+  + sizeof(XLAT_STR_159)
+#  endif
+#  ifdef XLAT_STR_160
+  + sizeof(XLAT_STR_160)
+#  endif
+#  ifdef XLAT_STR_161
+  + sizeof(XLAT_STR_161)
+#  endif
+#  ifdef XLAT_STR_162
+  + sizeof(XLAT_STR_162)
+#  endif
+#  ifdef XLAT_STR_163
+  + sizeof(XLAT_STR_163)
+#  endif
+#  ifdef XLAT_STR_164
+  + sizeof(XLAT_STR_164)
+#  endif
+#  ifdef XLAT_STR_165
+  + sizeof(XLAT_STR_165)
+#  endif
+#  ifdef XLAT_STR_166
+  + sizeof(XLAT_STR_166)
+#  endif
+#  ifdef XLAT_STR_167
+  + sizeof(XLAT_STR_167)
+#  endif
+#  ifdef XLAT_STR_168
+  + sizeof(XLAT_STR_168)
+#  endif
+#  ifdef XLAT_STR_169
+  + sizeof(XLAT_STR_169)
+#  endif
+#  ifdef XLAT_STR_170
+  + sizeof(XLAT_STR_170)
+#  endif
+#  ifdef XLAT_STR_171
+  + sizeof(XLAT_STR_171)
+#  endif
+#  ifdef XLAT_STR_172
+  + sizeof(XLAT_STR_172)
+#  endif
+#  ifdef XLAT_STR_173
+  + sizeof(XLAT_STR_173)
+#  endif
+#  ifdef XLAT_STR_174
+  + sizeof(XLAT_STR_174)
+#  endif
+#  ifdef XLAT_STR_175
+  + sizeof(XLAT_STR_175)
+#  endif
+#  ifdef XLAT_STR_176
+  + sizeof(XLAT_STR_176)
+#  endif
+#  ifdef XLAT_STR_177
+  + sizeof(XLAT_STR_177)
+#  endif
+#  ifdef XLAT_STR_178
+  + sizeof(XLAT_STR_178)
+#  endif
+#  ifdef XLAT_STR_179
+  + sizeof(XLAT_STR_179)
+#  endif
+#  ifdef XLAT_STR_180
+  + sizeof(XLAT_STR_180)
+#  endif
+#  ifdef XLAT_STR_181
+  + sizeof(XLAT_STR_181)
+#  endif
+#  ifdef XLAT_STR_182
+  + sizeof(XLAT_STR_182)
+#  endif
+#  ifdef XLAT_STR_183
+  + sizeof(XLAT_STR_183)
+#  endif
+#  ifdef XLAT_STR_184
+  + sizeof(XLAT_STR_184)
+#  endif
+#  ifdef XLAT_STR_185
+  + sizeof(XLAT_STR_185)
+#  endif
+#  ifdef XLAT_STR_186
+  + sizeof(XLAT_STR_186)
+#  endif
+#  ifdef XLAT_STR_187
+  + sizeof(XLAT_STR_187)
+#  endif
+#  ifdef XLAT_STR_188
+  + sizeof(XLAT_STR_188)
+#  endif
+#  ifdef XLAT_STR_189
+  + sizeof(XLAT_STR_189)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
+#  undef XLAT_STR_47
+#  undef XLAT_VAL_47
+#  undef XLAT_STR_48
+#  undef XLAT_VAL_48
+#  undef XLAT_STR_49
+#  undef XLAT_VAL_49
+#  undef XLAT_STR_50
+#  undef XLAT_VAL_50
+#  undef XLAT_STR_51
+#  undef XLAT_VAL_51
+#  undef XLAT_STR_52
+#  undef XLAT_VAL_52
+#  undef XLAT_STR_53
+#  undef XLAT_VAL_53
+#  undef XLAT_STR_54
+#  undef XLAT_VAL_54
+#  undef XLAT_STR_55
+#  undef XLAT_VAL_55
+#  undef XLAT_STR_56
+#  undef XLAT_VAL_56
+#  undef XLAT_STR_57
+#  undef XLAT_VAL_57
+#  undef XLAT_STR_58
+#  undef XLAT_VAL_58
+#  undef XLAT_STR_59
+#  undef XLAT_VAL_59
+#  undef XLAT_STR_60
+#  undef XLAT_VAL_60
+#  undef XLAT_STR_61
+#  undef XLAT_VAL_61
+#  undef XLAT_STR_62
+#  undef XLAT_VAL_62
+#  undef XLAT_STR_63
+#  undef XLAT_VAL_63
+#  undef XLAT_STR_64
+#  undef XLAT_VAL_64
+#  undef XLAT_STR_65
+#  undef XLAT_VAL_65
+#  undef XLAT_STR_66
+#  undef XLAT_VAL_66
+#  undef XLAT_STR_67
+#  undef XLAT_VAL_67
+#  undef XLAT_STR_68
+#  undef XLAT_VAL_68
+#  undef XLAT_STR_69
+#  undef XLAT_VAL_69
+#  undef XLAT_STR_70
+#  undef XLAT_VAL_70
+#  undef XLAT_STR_71
+#  undef XLAT_VAL_71
+#  undef XLAT_STR_72
+#  undef XLAT_VAL_72
+#  undef XLAT_STR_73
+#  undef XLAT_VAL_73
+#  undef XLAT_STR_74
+#  undef XLAT_VAL_74
+#  undef XLAT_STR_75
+#  undef XLAT_VAL_75
+#  undef XLAT_STR_76
+#  undef XLAT_VAL_76
+#  undef XLAT_STR_77
+#  undef XLAT_VAL_77
+#  undef XLAT_STR_78
+#  undef XLAT_VAL_78
+#  undef XLAT_STR_79
+#  undef XLAT_VAL_79
+#  undef XLAT_STR_80
+#  undef XLAT_VAL_80
+#  undef XLAT_STR_81
+#  undef XLAT_VAL_81
+#  undef XLAT_STR_82
+#  undef XLAT_VAL_82
+#  undef XLAT_STR_83
+#  undef XLAT_VAL_83
+#  undef XLAT_STR_84
+#  undef XLAT_VAL_84
+#  undef XLAT_STR_85
+#  undef XLAT_VAL_85
+#  undef XLAT_STR_86
+#  undef XLAT_VAL_86
+#  undef XLAT_STR_87
+#  undef XLAT_VAL_87
+#  undef XLAT_STR_88
+#  undef XLAT_VAL_88
+#  undef XLAT_STR_89
+#  undef XLAT_VAL_89
+#  undef XLAT_STR_90
+#  undef XLAT_VAL_90
+#  undef XLAT_STR_91
+#  undef XLAT_VAL_91
+#  undef XLAT_STR_92
+#  undef XLAT_VAL_92
+#  undef XLAT_STR_93
+#  undef XLAT_VAL_93
+#  undef XLAT_STR_94
+#  undef XLAT_VAL_94
+#  undef XLAT_STR_95
+#  undef XLAT_VAL_95
+#  undef XLAT_STR_96
+#  undef XLAT_VAL_96
+#  undef XLAT_STR_97
+#  undef XLAT_VAL_97
+#  undef XLAT_STR_98
+#  undef XLAT_VAL_98
+#  undef XLAT_STR_99
+#  undef XLAT_VAL_99
+#  undef XLAT_STR_100
+#  undef XLAT_VAL_100
+#  undef XLAT_STR_101
+#  undef XLAT_VAL_101
+#  undef XLAT_STR_102
+#  undef XLAT_VAL_102
+#  undef XLAT_STR_103
+#  undef XLAT_VAL_103
+#  undef XLAT_STR_104
+#  undef XLAT_VAL_104
+#  undef XLAT_STR_105
+#  undef XLAT_VAL_105
+#  undef XLAT_STR_106
+#  undef XLAT_VAL_106
+#  undef XLAT_STR_107
+#  undef XLAT_VAL_107
+#  undef XLAT_STR_108
+#  undef XLAT_VAL_108
+#  undef XLAT_STR_109
+#  undef XLAT_VAL_109
+#  undef XLAT_STR_110
+#  undef XLAT_VAL_110
+#  undef XLAT_STR_111
+#  undef XLAT_VAL_111
+#  undef XLAT_STR_112
+#  undef XLAT_VAL_112
+#  undef XLAT_STR_113
+#  undef XLAT_VAL_113
+#  undef XLAT_STR_114
+#  undef XLAT_VAL_114
+#  undef XLAT_STR_115
+#  undef XLAT_VAL_115
+#  undef XLAT_STR_116
+#  undef XLAT_VAL_116
+#  undef XLAT_STR_117
+#  undef XLAT_VAL_117
+#  undef XLAT_STR_118
+#  undef XLAT_VAL_118
+#  undef XLAT_STR_119
+#  undef XLAT_VAL_119
+#  undef XLAT_STR_120
+#  undef XLAT_VAL_120
+#  undef XLAT_STR_121
+#  undef XLAT_VAL_121
+#  undef XLAT_STR_122
+#  undef XLAT_VAL_122
+#  undef XLAT_STR_123
+#  undef XLAT_VAL_123
+#  undef XLAT_STR_124
+#  undef XLAT_VAL_124
+#  undef XLAT_STR_125
+#  undef XLAT_VAL_125
+#  undef XLAT_STR_126
+#  undef XLAT_VAL_126
+#  undef XLAT_STR_127
+#  undef XLAT_VAL_127
+#  undef XLAT_STR_128
+#  undef XLAT_VAL_128
+#  undef XLAT_STR_129
+#  undef XLAT_VAL_129
+#  undef XLAT_STR_130
+#  undef XLAT_VAL_130
+#  undef XLAT_STR_131
+#  undef XLAT_VAL_131
+#  undef XLAT_STR_132
+#  undef XLAT_VAL_132
+#  undef XLAT_STR_133
+#  undef XLAT_VAL_133
+#  undef XLAT_STR_134
+#  undef XLAT_VAL_134
+#  undef XLAT_STR_135
+#  undef XLAT_VAL_135
+#  undef XLAT_STR_136
+#  undef XLAT_VAL_136
+#  undef XLAT_STR_137
+#  undef XLAT_VAL_137
+#  undef XLAT_STR_138
+#  undef XLAT_VAL_138
+#  undef XLAT_STR_139
+#  undef XLAT_VAL_139
+#  undef XLAT_STR_140
+#  undef XLAT_VAL_140
+#  undef XLAT_STR_141
+#  undef XLAT_VAL_141
+#  undef XLAT_STR_142
+#  undef XLAT_VAL_142
+#  undef XLAT_STR_143
+#  undef XLAT_VAL_143
+#  undef XLAT_STR_144
+#  undef XLAT_VAL_144
+#  undef XLAT_STR_145
+#  undef XLAT_VAL_145
+#  undef XLAT_STR_146
+#  undef XLAT_VAL_146
+#  undef XLAT_STR_147
+#  undef XLAT_VAL_147
+#  undef XLAT_STR_148
+#  undef XLAT_VAL_148
+#  undef XLAT_STR_149
+#  undef XLAT_VAL_149
+#  undef XLAT_STR_150
+#  undef XLAT_VAL_150
+#  undef XLAT_STR_151
+#  undef XLAT_VAL_151
+#  undef XLAT_STR_152
+#  undef XLAT_VAL_152
+#  undef XLAT_STR_153
+#  undef XLAT_VAL_153
+#  undef XLAT_STR_154
+#  undef XLAT_VAL_154
+#  undef XLAT_STR_155
+#  undef XLAT_VAL_155
+#  undef XLAT_STR_156
+#  undef XLAT_VAL_156
+#  undef XLAT_STR_157
+#  undef XLAT_VAL_157
+#  undef XLAT_STR_158
+#  undef XLAT_VAL_158
+#  undef XLAT_STR_159
+#  undef XLAT_VAL_159
+#  undef XLAT_STR_160
+#  undef XLAT_VAL_160
+#  undef XLAT_STR_161
+#  undef XLAT_VAL_161
+#  undef XLAT_STR_162
+#  undef XLAT_VAL_162
+#  undef XLAT_STR_163
+#  undef XLAT_VAL_163
+#  undef XLAT_STR_164
+#  undef XLAT_VAL_164
+#  undef XLAT_STR_165
+#  undef XLAT_VAL_165
+#  undef XLAT_STR_166
+#  undef XLAT_VAL_166
+#  undef XLAT_STR_167
+#  undef XLAT_VAL_167
+#  undef XLAT_STR_168
+#  undef XLAT_VAL_168
+#  undef XLAT_STR_169
+#  undef XLAT_VAL_169
+#  undef XLAT_STR_170
+#  undef XLAT_VAL_170
+#  undef XLAT_STR_171
+#  undef XLAT_VAL_171
+#  undef XLAT_STR_172
+#  undef XLAT_VAL_172
+#  undef XLAT_STR_173
+#  undef XLAT_VAL_173
+#  undef XLAT_STR_174
+#  undef XLAT_VAL_174
+#  undef XLAT_STR_175
+#  undef XLAT_VAL_175
+#  undef XLAT_STR_176
+#  undef XLAT_VAL_176
+#  undef XLAT_STR_177
+#  undef XLAT_VAL_177
+#  undef XLAT_STR_178
+#  undef XLAT_VAL_178
+#  undef XLAT_STR_179
+#  undef XLAT_VAL_179
+#  undef XLAT_STR_180
+#  undef XLAT_VAL_180
+#  undef XLAT_STR_181
+#  undef XLAT_VAL_181
+#  undef XLAT_STR_182
+#  undef XLAT_VAL_182
+#  undef XLAT_STR_183
+#  undef XLAT_VAL_183
+#  undef XLAT_STR_184
+#  undef XLAT_VAL_184
+#  undef XLAT_STR_185
+#  undef XLAT_VAL_185
+#  undef XLAT_STR_186
+#  undef XLAT_VAL_186
+#  undef XLAT_STR_187
+#  undef XLAT_VAL_187
+#  undef XLAT_STR_188
+#  undef XLAT_VAL_188
+#  undef XLAT_STR_189
+#  undef XLAT_VAL_189
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ptrace_events.h 5.9-0ubuntu2/xlat/ptrace_events.h
--- 5.5-3/xlat/ptrace_events.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ptrace_events.h	2020-09-24 09:18:45.000000000 +0000
@@ -15,31 +15,49 @@
 static const struct xlat_data ptrace_events_xdata[] = {
 #if defined(PTRACE_EVENT_FORK) || (defined(HAVE_DECL_PTRACE_EVENT_FORK) && HAVE_DECL_PTRACE_EVENT_FORK)
   XLAT(PTRACE_EVENT_FORK),
+ #define XLAT_VAL_0 ((unsigned) (PTRACE_EVENT_FORK))
+ #define XLAT_STR_0 STRINGIFY(PTRACE_EVENT_FORK)
 #endif
 #if defined(PTRACE_EVENT_VFORK) || (defined(HAVE_DECL_PTRACE_EVENT_VFORK) && HAVE_DECL_PTRACE_EVENT_VFORK)
   XLAT(PTRACE_EVENT_VFORK),
+ #define XLAT_VAL_1 ((unsigned) (PTRACE_EVENT_VFORK))
+ #define XLAT_STR_1 STRINGIFY(PTRACE_EVENT_VFORK)
 #endif
 #if defined(PTRACE_EVENT_CLONE) || (defined(HAVE_DECL_PTRACE_EVENT_CLONE) && HAVE_DECL_PTRACE_EVENT_CLONE)
   XLAT(PTRACE_EVENT_CLONE),
+ #define XLAT_VAL_2 ((unsigned) (PTRACE_EVENT_CLONE))
+ #define XLAT_STR_2 STRINGIFY(PTRACE_EVENT_CLONE)
 #endif
 #if defined(PTRACE_EVENT_EXEC) || (defined(HAVE_DECL_PTRACE_EVENT_EXEC) && HAVE_DECL_PTRACE_EVENT_EXEC)
   XLAT(PTRACE_EVENT_EXEC),
+ #define XLAT_VAL_3 ((unsigned) (PTRACE_EVENT_EXEC))
+ #define XLAT_STR_3 STRINGIFY(PTRACE_EVENT_EXEC)
 #endif
 #if defined(PTRACE_EVENT_VFORK_DONE) || (defined(HAVE_DECL_PTRACE_EVENT_VFORK_DONE) && HAVE_DECL_PTRACE_EVENT_VFORK_DONE)
   XLAT(PTRACE_EVENT_VFORK_DONE),
+ #define XLAT_VAL_4 ((unsigned) (PTRACE_EVENT_VFORK_DONE))
+ #define XLAT_STR_4 STRINGIFY(PTRACE_EVENT_VFORK_DONE)
 #endif
 #if defined(PTRACE_EVENT_EXIT) || (defined(HAVE_DECL_PTRACE_EVENT_EXIT) && HAVE_DECL_PTRACE_EVENT_EXIT)
   XLAT(PTRACE_EVENT_EXIT),
+ #define XLAT_VAL_5 ((unsigned) (PTRACE_EVENT_EXIT))
+ #define XLAT_STR_5 STRINGIFY(PTRACE_EVENT_EXIT)
 #endif
 #if defined(PTRACE_EVENT_SECCOMP) || (defined(HAVE_DECL_PTRACE_EVENT_SECCOMP) && HAVE_DECL_PTRACE_EVENT_SECCOMP)
   XLAT(PTRACE_EVENT_SECCOMP),
+ #define XLAT_VAL_6 ((unsigned) (PTRACE_EVENT_SECCOMP))
+ #define XLAT_STR_6 STRINGIFY(PTRACE_EVENT_SECCOMP)
 #endif
 #if defined(PTRACE_EVENT_STOP) || (defined(HAVE_DECL_PTRACE_EVENT_STOP) && HAVE_DECL_PTRACE_EVENT_STOP)
   XLAT(PTRACE_EVENT_STOP),
+ #define XLAT_VAL_7 ((unsigned) (PTRACE_EVENT_STOP))
+ #define XLAT_STR_7 STRINGIFY(PTRACE_EVENT_STOP)
 #endif
 
 #if defined(PTRACE_EVENT_MIGRATE) || (defined(HAVE_DECL_PTRACE_EVENT_MIGRATE) && HAVE_DECL_PTRACE_EVENT_MIGRATE)
   XLAT(PTRACE_EVENT_MIGRATE),
+ #define XLAT_VAL_8 ((unsigned) (PTRACE_EVENT_MIGRATE))
+ #define XLAT_STR_8 STRINGIFY(PTRACE_EVENT_MIGRATE)
 #endif
 };
 static
@@ -47,8 +65,84 @@ const struct xlat ptrace_events[1] = { {
  .data = ptrace_events_xdata,
  .size = ARRAY_SIZE(ptrace_events_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ptrace_peeksiginfo_flags.h 5.9-0ubuntu2/xlat/ptrace_peeksiginfo_flags.h
--- 5.5-3/xlat/ptrace_peeksiginfo_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ptrace_peeksiginfo_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -21,14 +21,28 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data ptrace_peeksiginfo_flags_xdata[] = {
  XLAT(PTRACE_PEEKSIGINFO_SHARED),
+ #define XLAT_VAL_0 ((unsigned) (PTRACE_PEEKSIGINFO_SHARED))
+ #define XLAT_STR_0 STRINGIFY(PTRACE_PEEKSIGINFO_SHARED)
 };
 static
 const struct xlat ptrace_peeksiginfo_flags[1] = { {
  .data = ptrace_peeksiginfo_flags_xdata,
  .size = ARRAY_SIZE(ptrace_peeksiginfo_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ptrace_setoptions_flags.h 5.9-0ubuntu2/xlat/ptrace_setoptions_flags.h
--- 5.5-3/xlat/ptrace_setoptions_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ptrace_setoptions_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -15,37 +15,59 @@
 static const struct xlat_data ptrace_setoptions_flags_xdata[] = {
 #if defined(PTRACE_O_TRACESYSGOOD) || (defined(HAVE_DECL_PTRACE_O_TRACESYSGOOD) && HAVE_DECL_PTRACE_O_TRACESYSGOOD)
   XLAT(PTRACE_O_TRACESYSGOOD),
+ #define XLAT_VAL_0 ((unsigned) (PTRACE_O_TRACESYSGOOD))
+ #define XLAT_STR_0 STRINGIFY(PTRACE_O_TRACESYSGOOD)
 #endif
 #if defined(PTRACE_O_TRACEFORK) || (defined(HAVE_DECL_PTRACE_O_TRACEFORK) && HAVE_DECL_PTRACE_O_TRACEFORK)
   XLAT(PTRACE_O_TRACEFORK),
+ #define XLAT_VAL_1 ((unsigned) (PTRACE_O_TRACEFORK))
+ #define XLAT_STR_1 STRINGIFY(PTRACE_O_TRACEFORK)
 #endif
 #if defined(PTRACE_O_TRACEVFORK) || (defined(HAVE_DECL_PTRACE_O_TRACEVFORK) && HAVE_DECL_PTRACE_O_TRACEVFORK)
   XLAT(PTRACE_O_TRACEVFORK),
+ #define XLAT_VAL_2 ((unsigned) (PTRACE_O_TRACEVFORK))
+ #define XLAT_STR_2 STRINGIFY(PTRACE_O_TRACEVFORK)
 #endif
 #if defined(PTRACE_O_TRACECLONE) || (defined(HAVE_DECL_PTRACE_O_TRACECLONE) && HAVE_DECL_PTRACE_O_TRACECLONE)
   XLAT(PTRACE_O_TRACECLONE),
+ #define XLAT_VAL_3 ((unsigned) (PTRACE_O_TRACECLONE))
+ #define XLAT_STR_3 STRINGIFY(PTRACE_O_TRACECLONE)
 #endif
 #if defined(PTRACE_O_TRACEEXEC) || (defined(HAVE_DECL_PTRACE_O_TRACEEXEC) && HAVE_DECL_PTRACE_O_TRACEEXEC)
   XLAT(PTRACE_O_TRACEEXEC),
+ #define XLAT_VAL_4 ((unsigned) (PTRACE_O_TRACEEXEC))
+ #define XLAT_STR_4 STRINGIFY(PTRACE_O_TRACEEXEC)
 #endif
 #if defined(PTRACE_O_TRACEVFORKDONE) || (defined(HAVE_DECL_PTRACE_O_TRACEVFORKDONE) && HAVE_DECL_PTRACE_O_TRACEVFORKDONE)
   XLAT(PTRACE_O_TRACEVFORKDONE),
+ #define XLAT_VAL_5 ((unsigned) (PTRACE_O_TRACEVFORKDONE))
+ #define XLAT_STR_5 STRINGIFY(PTRACE_O_TRACEVFORKDONE)
 #endif
 #if defined(PTRACE_O_TRACEEXIT) || (defined(HAVE_DECL_PTRACE_O_TRACEEXIT) && HAVE_DECL_PTRACE_O_TRACEEXIT)
   XLAT(PTRACE_O_TRACEEXIT),
+ #define XLAT_VAL_6 ((unsigned) (PTRACE_O_TRACEEXIT))
+ #define XLAT_STR_6 STRINGIFY(PTRACE_O_TRACEEXIT)
 #endif
 #if defined(PTRACE_O_TRACESECCOMP) || (defined(HAVE_DECL_PTRACE_O_TRACESECCOMP) && HAVE_DECL_PTRACE_O_TRACESECCOMP)
   XLAT(PTRACE_O_TRACESECCOMP),
+ #define XLAT_VAL_7 ((unsigned) (PTRACE_O_TRACESECCOMP))
+ #define XLAT_STR_7 STRINGIFY(PTRACE_O_TRACESECCOMP)
 #endif
 #if defined(PTRACE_O_EXITKILL) || (defined(HAVE_DECL_PTRACE_O_EXITKILL) && HAVE_DECL_PTRACE_O_EXITKILL)
   XLAT(PTRACE_O_EXITKILL),
+ #define XLAT_VAL_8 ((unsigned) (PTRACE_O_EXITKILL))
+ #define XLAT_STR_8 STRINGIFY(PTRACE_O_EXITKILL)
 #endif
 #if defined(PTRACE_O_SUSPEND_SECCOMP) || (defined(HAVE_DECL_PTRACE_O_SUSPEND_SECCOMP) && HAVE_DECL_PTRACE_O_SUSPEND_SECCOMP)
   XLAT(PTRACE_O_SUSPEND_SECCOMP),
+ #define XLAT_VAL_9 ((unsigned) (PTRACE_O_SUSPEND_SECCOMP))
+ #define XLAT_STR_9 STRINGIFY(PTRACE_O_SUSPEND_SECCOMP)
 #endif
 
 #if defined(PTRACE_O_TRACEMIGRATE) || (defined(HAVE_DECL_PTRACE_O_TRACEMIGRATE) && HAVE_DECL_PTRACE_O_TRACEMIGRATE)
   XLAT(PTRACE_O_TRACEMIGRATE),
+ #define XLAT_VAL_10 ((unsigned) (PTRACE_O_TRACEMIGRATE))
+ #define XLAT_STR_10 STRINGIFY(PTRACE_O_TRACEMIGRATE)
 #endif
 };
 static
@@ -53,8 +75,100 @@ const struct xlat ptrace_setoptions_flag
  .data = ptrace_setoptions_flags_xdata,
  .size = ARRAY_SIZE(ptrace_setoptions_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ptrace_syscall_info_op.h 5.9-0ubuntu2/xlat/ptrace_syscall_info_op.h
--- 5.5-3/xlat/ptrace_syscall_info_op.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ptrace_syscall_info_op.h	2020-09-24 09:18:45.000000000 +0000
@@ -15,15 +15,23 @@
 static const struct xlat_data ptrace_syscall_info_op_xdata[] = {
 #if defined(PTRACE_SYSCALL_INFO_NONE) || (defined(HAVE_DECL_PTRACE_SYSCALL_INFO_NONE) && HAVE_DECL_PTRACE_SYSCALL_INFO_NONE)
   [PTRACE_SYSCALL_INFO_NONE] = XLAT(PTRACE_SYSCALL_INFO_NONE),
+ #define XLAT_VAL_0 ((unsigned) (PTRACE_SYSCALL_INFO_NONE))
+ #define XLAT_STR_0 STRINGIFY(PTRACE_SYSCALL_INFO_NONE)
 #endif
 #if defined(PTRACE_SYSCALL_INFO_ENTRY) || (defined(HAVE_DECL_PTRACE_SYSCALL_INFO_ENTRY) && HAVE_DECL_PTRACE_SYSCALL_INFO_ENTRY)
   [PTRACE_SYSCALL_INFO_ENTRY] = XLAT(PTRACE_SYSCALL_INFO_ENTRY),
+ #define XLAT_VAL_1 ((unsigned) (PTRACE_SYSCALL_INFO_ENTRY))
+ #define XLAT_STR_1 STRINGIFY(PTRACE_SYSCALL_INFO_ENTRY)
 #endif
 #if defined(PTRACE_SYSCALL_INFO_EXIT) || (defined(HAVE_DECL_PTRACE_SYSCALL_INFO_EXIT) && HAVE_DECL_PTRACE_SYSCALL_INFO_EXIT)
   [PTRACE_SYSCALL_INFO_EXIT] = XLAT(PTRACE_SYSCALL_INFO_EXIT),
+ #define XLAT_VAL_2 ((unsigned) (PTRACE_SYSCALL_INFO_EXIT))
+ #define XLAT_STR_2 STRINGIFY(PTRACE_SYSCALL_INFO_EXIT)
 #endif
 #if defined(PTRACE_SYSCALL_INFO_SECCOMP) || (defined(HAVE_DECL_PTRACE_SYSCALL_INFO_SECCOMP) && HAVE_DECL_PTRACE_SYSCALL_INFO_SECCOMP)
   [PTRACE_SYSCALL_INFO_SECCOMP] = XLAT(PTRACE_SYSCALL_INFO_SECCOMP),
+ #define XLAT_VAL_3 ((unsigned) (PTRACE_SYSCALL_INFO_SECCOMP))
+ #define XLAT_STR_3 STRINGIFY(PTRACE_SYSCALL_INFO_SECCOMP)
 #endif
 };
 static
@@ -31,8 +39,44 @@ const struct xlat ptrace_syscall_info_op
  .data = ptrace_syscall_info_op_xdata,
  .size = ARRAY_SIZE(ptrace_syscall_info_op_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/quotacmds.h 5.9-0ubuntu2/xlat/quotacmds.h
--- 5.5-3/xlat/quotacmds.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/quotacmds.h	2020-09-24 09:18:46.000000000 +0000
@@ -259,51 +259,405 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data quotacmds_xdata[] = {
  XLAT(Q_V1_QUOTAON),
+ #define XLAT_VAL_0 ((unsigned) (Q_V1_QUOTAON))
+ #define XLAT_STR_0 STRINGIFY(Q_V1_QUOTAON)
  XLAT(Q_V1_QUOTAOFF),
+ #define XLAT_VAL_1 ((unsigned) (Q_V1_QUOTAOFF))
+ #define XLAT_STR_1 STRINGIFY(Q_V1_QUOTAOFF)
  XLAT(Q_V1_GETQUOTA),
+ #define XLAT_VAL_2 ((unsigned) (Q_V1_GETQUOTA))
+ #define XLAT_STR_2 STRINGIFY(Q_V1_GETQUOTA)
  XLAT(Q_V1_SETQUOTA),
+ #define XLAT_VAL_3 ((unsigned) (Q_V1_SETQUOTA))
+ #define XLAT_STR_3 STRINGIFY(Q_V1_SETQUOTA)
  XLAT(Q_V1_SETUSE),
+ #define XLAT_VAL_4 ((unsigned) (Q_V1_SETUSE))
+ #define XLAT_STR_4 STRINGIFY(Q_V1_SETUSE)
  XLAT(Q_V1_SYNC),
+ #define XLAT_VAL_5 ((unsigned) (Q_V1_SYNC))
+ #define XLAT_STR_5 STRINGIFY(Q_V1_SYNC)
  XLAT(Q_SETQLIM),
+ #define XLAT_VAL_6 ((unsigned) (Q_SETQLIM))
+ #define XLAT_STR_6 STRINGIFY(Q_SETQLIM)
  XLAT(Q_V1_GETSTATS),
+ #define XLAT_VAL_7 ((unsigned) (Q_V1_GETSTATS))
+ #define XLAT_STR_7 STRINGIFY(Q_V1_GETSTATS)
  XLAT(Q_V1_RSQUASH),
+ #define XLAT_VAL_8 ((unsigned) (Q_V1_RSQUASH))
+ #define XLAT_STR_8 STRINGIFY(Q_V1_RSQUASH)
 
  XLAT(Q_V2_GETQUOTA),
+ #define XLAT_VAL_9 ((unsigned) (Q_V2_GETQUOTA))
+ #define XLAT_STR_9 STRINGIFY(Q_V2_GETQUOTA)
  XLAT(Q_V2_SETQUOTA),
+ #define XLAT_VAL_10 ((unsigned) (Q_V2_SETQUOTA))
+ #define XLAT_STR_10 STRINGIFY(Q_V2_SETQUOTA)
  XLAT(Q_V2_SETUSE),
+ #define XLAT_VAL_11 ((unsigned) (Q_V2_SETUSE))
+ #define XLAT_STR_11 STRINGIFY(Q_V2_SETUSE)
  XLAT(Q_V2_GETINFO),
+ #define XLAT_VAL_12 ((unsigned) (Q_V2_GETINFO))
+ #define XLAT_STR_12 STRINGIFY(Q_V2_GETINFO)
  XLAT(Q_V2_SETINFO),
+ #define XLAT_VAL_13 ((unsigned) (Q_V2_SETINFO))
+ #define XLAT_STR_13 STRINGIFY(Q_V2_SETINFO)
  XLAT(Q_V2_SETGRACE),
+ #define XLAT_VAL_14 ((unsigned) (Q_V2_SETGRACE))
+ #define XLAT_STR_14 STRINGIFY(Q_V2_SETGRACE)
  XLAT(Q_V2_SETFLAGS),
+ #define XLAT_VAL_15 ((unsigned) (Q_V2_SETFLAGS))
+ #define XLAT_STR_15 STRINGIFY(Q_V2_SETFLAGS)
  XLAT(Q_V2_GETSTATS),
+ #define XLAT_VAL_16 ((unsigned) (Q_V2_GETSTATS))
+ #define XLAT_STR_16 STRINGIFY(Q_V2_GETSTATS)
 
  XLAT(Q_SYNC),
+ #define XLAT_VAL_17 ((unsigned) (Q_SYNC))
+ #define XLAT_STR_17 STRINGIFY(Q_SYNC)
  XLAT(Q_QUOTAON),
+ #define XLAT_VAL_18 ((unsigned) (Q_QUOTAON))
+ #define XLAT_STR_18 STRINGIFY(Q_QUOTAON)
  XLAT(Q_QUOTAOFF),
+ #define XLAT_VAL_19 ((unsigned) (Q_QUOTAOFF))
+ #define XLAT_STR_19 STRINGIFY(Q_QUOTAOFF)
  XLAT(Q_GETFMT),
+ #define XLAT_VAL_20 ((unsigned) (Q_GETFMT))
+ #define XLAT_STR_20 STRINGIFY(Q_GETFMT)
  XLAT(Q_GETINFO),
+ #define XLAT_VAL_21 ((unsigned) (Q_GETINFO))
+ #define XLAT_STR_21 STRINGIFY(Q_GETINFO)
  XLAT(Q_SETINFO),
+ #define XLAT_VAL_22 ((unsigned) (Q_SETINFO))
+ #define XLAT_STR_22 STRINGIFY(Q_SETINFO)
  XLAT(Q_GETQUOTA),
+ #define XLAT_VAL_23 ((unsigned) (Q_GETQUOTA))
+ #define XLAT_STR_23 STRINGIFY(Q_GETQUOTA)
  XLAT(Q_SETQUOTA),
+ #define XLAT_VAL_24 ((unsigned) (Q_SETQUOTA))
+ #define XLAT_STR_24 STRINGIFY(Q_SETQUOTA)
  XLAT(Q_GETNEXTQUOTA),
+ #define XLAT_VAL_25 ((unsigned) (Q_GETNEXTQUOTA))
+ #define XLAT_STR_25 STRINGIFY(Q_GETNEXTQUOTA)
 
  XLAT(Q_XQUOTAON),
+ #define XLAT_VAL_26 ((unsigned) (Q_XQUOTAON))
+ #define XLAT_STR_26 STRINGIFY(Q_XQUOTAON)
  XLAT(Q_XQUOTAOFF),
+ #define XLAT_VAL_27 ((unsigned) (Q_XQUOTAOFF))
+ #define XLAT_STR_27 STRINGIFY(Q_XQUOTAOFF)
  XLAT(Q_XGETQUOTA),
+ #define XLAT_VAL_28 ((unsigned) (Q_XGETQUOTA))
+ #define XLAT_STR_28 STRINGIFY(Q_XGETQUOTA)
  XLAT(Q_XSETQLIM),
+ #define XLAT_VAL_29 ((unsigned) (Q_XSETQLIM))
+ #define XLAT_STR_29 STRINGIFY(Q_XSETQLIM)
  XLAT(Q_XGETQSTAT),
+ #define XLAT_VAL_30 ((unsigned) (Q_XGETQSTAT))
+ #define XLAT_STR_30 STRINGIFY(Q_XGETQSTAT)
  XLAT(Q_XQUOTARM),
+ #define XLAT_VAL_31 ((unsigned) (Q_XQUOTARM))
+ #define XLAT_STR_31 STRINGIFY(Q_XQUOTARM)
  XLAT(Q_XQUOTASYNC),
+ #define XLAT_VAL_32 ((unsigned) (Q_XQUOTASYNC))
+ #define XLAT_STR_32 STRINGIFY(Q_XQUOTASYNC)
  XLAT(Q_XGETQSTATV),
+ #define XLAT_VAL_33 ((unsigned) (Q_XGETQSTATV))
+ #define XLAT_STR_33 STRINGIFY(Q_XGETQSTATV)
  XLAT(Q_XGETNEXTQUOTA),
+ #define XLAT_VAL_34 ((unsigned) (Q_XGETNEXTQUOTA))
+ #define XLAT_STR_34 STRINGIFY(Q_XGETNEXTQUOTA)
 };
 static
 const struct xlat quotacmds[1] = { {
  .data = quotacmds_xdata,
  .size = ARRAY_SIZE(quotacmds_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/quota_formats.h 5.9-0ubuntu2/xlat/quota_formats.h
--- 5.5-3/xlat/quota_formats.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/quota_formats.h	2020-09-24 09:18:45.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data quota_formats_xdata[] = {
  [QFMT_VFS_OLD] = XLAT(QFMT_VFS_OLD),
+ #define XLAT_VAL_0 ((unsigned) (QFMT_VFS_OLD))
+ #define XLAT_STR_0 STRINGIFY(QFMT_VFS_OLD)
  [QFMT_VFS_V0] = XLAT(QFMT_VFS_V0),
+ #define XLAT_VAL_1 ((unsigned) (QFMT_VFS_V0))
+ #define XLAT_STR_1 STRINGIFY(QFMT_VFS_V0)
  [QFMT_OCFS2] = XLAT(QFMT_OCFS2),
+ #define XLAT_VAL_2 ((unsigned) (QFMT_OCFS2))
+ #define XLAT_STR_2 STRINGIFY(QFMT_OCFS2)
  [QFMT_VFS_V1] = XLAT(QFMT_VFS_V1),
+ #define XLAT_VAL_3 ((unsigned) (QFMT_VFS_V1))
+ #define XLAT_STR_3 STRINGIFY(QFMT_VFS_V1)
 };
 static
 const struct xlat quota_formats[1] = { {
  .data = quota_formats_xdata,
  .size = ARRAY_SIZE(quota_formats_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/quotatypes.h 5.9-0ubuntu2/xlat/quotatypes.h
--- 5.5-3/xlat/quotatypes.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/quotatypes.h	2020-09-24 09:18:45.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data quotatypes_xdata[] = {
  [USRQUOTA] = XLAT(USRQUOTA),
+ #define XLAT_VAL_0 ((unsigned) (USRQUOTA))
+ #define XLAT_STR_0 STRINGIFY(USRQUOTA)
  [GRPQUOTA] = XLAT(GRPQUOTA),
+ #define XLAT_VAL_1 ((unsigned) (GRPQUOTA))
+ #define XLAT_STR_1 STRINGIFY(GRPQUOTA)
  [PRJQUOTA] = XLAT(PRJQUOTA),
+ #define XLAT_VAL_2 ((unsigned) (PRJQUOTA))
+ #define XLAT_STR_2 STRINGIFY(PRJQUOTA)
 };
 static
 const struct xlat quotatypes[1] = { {
  .data = quotatypes_xdata,
  .size = ARRAY_SIZE(quotatypes_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/random_ioctl_cmds.h 5.9-0ubuntu2/xlat/random_ioctl_cmds.h
--- 5.5-3/xlat/random_ioctl_cmds.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/random_ioctl_cmds.h	2020-09-24 09:18:45.000000000 +0000
@@ -63,20 +63,94 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data random_ioctl_cmds_xdata[] = {
  XLAT(RNDGETENTCNT),
+ #define XLAT_VAL_0 ((unsigned) (RNDGETENTCNT))
+ #define XLAT_STR_0 STRINGIFY(RNDGETENTCNT)
  XLAT(RNDADDTOENTCNT),
+ #define XLAT_VAL_1 ((unsigned) (RNDADDTOENTCNT))
+ #define XLAT_STR_1 STRINGIFY(RNDADDTOENTCNT)
  XLAT(RNDGETPOOL),
+ #define XLAT_VAL_2 ((unsigned) (RNDGETPOOL))
+ #define XLAT_STR_2 STRINGIFY(RNDGETPOOL)
  XLAT(RNDADDENTROPY),
+ #define XLAT_VAL_3 ((unsigned) (RNDADDENTROPY))
+ #define XLAT_STR_3 STRINGIFY(RNDADDENTROPY)
  XLAT(RNDZAPENTCNT),
+ #define XLAT_VAL_4 ((unsigned) (RNDZAPENTCNT))
+ #define XLAT_STR_4 STRINGIFY(RNDZAPENTCNT)
  XLAT(RNDCLEARPOOL),
+ #define XLAT_VAL_5 ((unsigned) (RNDCLEARPOOL))
+ #define XLAT_STR_5 STRINGIFY(RNDCLEARPOOL)
  XLAT(RNDRESEEDCRNG),
+ #define XLAT_VAL_6 ((unsigned) (RNDRESEEDCRNG))
+ #define XLAT_STR_6 STRINGIFY(RNDRESEEDCRNG)
 };
 static
 const struct xlat random_ioctl_cmds[1] = { {
  .data = random_ioctl_cmds_xdata,
  .size = ARRAY_SIZE(random_ioctl_cmds_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rename_flags.h 5.9-0ubuntu2/xlat/rename_flags.h
--- 5.5-3/xlat/rename_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rename_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rename_flags_xdata[] = {
  XLAT(RENAME_NOREPLACE),
+ #define XLAT_VAL_0 ((unsigned) (RENAME_NOREPLACE))
+ #define XLAT_STR_0 STRINGIFY(RENAME_NOREPLACE)
  XLAT(RENAME_EXCHANGE),
+ #define XLAT_VAL_1 ((unsigned) (RENAME_EXCHANGE))
+ #define XLAT_STR_1 STRINGIFY(RENAME_EXCHANGE)
  XLAT(RENAME_WHITEOUT),
+ #define XLAT_VAL_2 ((unsigned) (RENAME_WHITEOUT))
+ #define XLAT_STR_2 STRINGIFY(RENAME_WHITEOUT)
 };
 static
 const struct xlat rename_flags[1] = { {
  .data = rename_flags_xdata,
  .size = ARRAY_SIZE(rename_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/resource_flags.h 5.9-0ubuntu2/xlat/resource_flags.h
--- 5.5-3/xlat/resource_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/resource_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -11,20 +11,54 @@
 static const struct xlat_data resource_flags_xdata[] = {
 #if defined(IPC_CREAT) || (defined(HAVE_DECL_IPC_CREAT) && HAVE_DECL_IPC_CREAT)
   XLAT(IPC_CREAT),
+ #define XLAT_VAL_0 ((unsigned) (IPC_CREAT))
+ #define XLAT_STR_0 STRINGIFY(IPC_CREAT)
 #endif
 #if defined(IPC_EXCL) || (defined(HAVE_DECL_IPC_EXCL) && HAVE_DECL_IPC_EXCL)
   XLAT(IPC_EXCL),
+ #define XLAT_VAL_1 ((unsigned) (IPC_EXCL))
+ #define XLAT_STR_1 STRINGIFY(IPC_EXCL)
 #endif
 #if defined(IPC_NOWAIT) || (defined(HAVE_DECL_IPC_NOWAIT) && HAVE_DECL_IPC_NOWAIT)
   XLAT(IPC_NOWAIT),
+ #define XLAT_VAL_2 ((unsigned) (IPC_NOWAIT))
+ #define XLAT_STR_2 STRINGIFY(IPC_NOWAIT)
 #endif
 };
 const struct xlat resource_flags[1] = { {
  .data = resource_flags_xdata,
  .size = ARRAY_SIZE(resource_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/resources.h 5.9-0ubuntu2/xlat/resources.h
--- 5.5-3/xlat/resources.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/resources.h	2020-09-24 09:18:46.000000000 +0000
@@ -236,51 +236,365 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data resources_xdata[] = {
  [RLIMIT_CPU] = XLAT(RLIMIT_CPU),
+ #define XLAT_VAL_0 ((unsigned) (RLIMIT_CPU))
+ #define XLAT_STR_0 STRINGIFY(RLIMIT_CPU)
  [RLIMIT_FSIZE] = XLAT(RLIMIT_FSIZE),
+ #define XLAT_VAL_1 ((unsigned) (RLIMIT_FSIZE))
+ #define XLAT_STR_1 STRINGIFY(RLIMIT_FSIZE)
  [RLIMIT_DATA] = XLAT(RLIMIT_DATA),
+ #define XLAT_VAL_2 ((unsigned) (RLIMIT_DATA))
+ #define XLAT_STR_2 STRINGIFY(RLIMIT_DATA)
  [RLIMIT_STACK] = XLAT(RLIMIT_STACK),
+ #define XLAT_VAL_3 ((unsigned) (RLIMIT_STACK))
+ #define XLAT_STR_3 STRINGIFY(RLIMIT_STACK)
  [RLIMIT_CORE] = XLAT(RLIMIT_CORE),
+ #define XLAT_VAL_4 ((unsigned) (RLIMIT_CORE))
+ #define XLAT_STR_4 STRINGIFY(RLIMIT_CORE)
 
 #if defined(__alpha__)
  [RLIMIT_RSS] = XLAT(RLIMIT_RSS),
+ #define XLAT_VAL_5 ((unsigned) (RLIMIT_RSS))
+ #define XLAT_STR_5 STRINGIFY(RLIMIT_RSS)
  [RLIMIT_NOFILE] = XLAT(RLIMIT_NOFILE),
+ #define XLAT_VAL_6 ((unsigned) (RLIMIT_NOFILE))
+ #define XLAT_STR_6 STRINGIFY(RLIMIT_NOFILE)
  [RLIMIT_AS] = XLAT(RLIMIT_AS),
+ #define XLAT_VAL_7 ((unsigned) (RLIMIT_AS))
+ #define XLAT_STR_7 STRINGIFY(RLIMIT_AS)
  [RLIMIT_NPROC] = XLAT(RLIMIT_NPROC),
+ #define XLAT_VAL_8 ((unsigned) (RLIMIT_NPROC))
+ #define XLAT_STR_8 STRINGIFY(RLIMIT_NPROC)
  [RLIMIT_MEMLOCK] = XLAT(RLIMIT_MEMLOCK),
+ #define XLAT_VAL_9 ((unsigned) (RLIMIT_MEMLOCK))
+ #define XLAT_STR_9 STRINGIFY(RLIMIT_MEMLOCK)
 #elif defined(__mips__)
  [RLIMIT_NOFILE] = XLAT(RLIMIT_NOFILE),
+ #define XLAT_VAL_10 ((unsigned) (RLIMIT_NOFILE))
+ #define XLAT_STR_10 STRINGIFY(RLIMIT_NOFILE)
  [RLIMIT_AS] = XLAT(RLIMIT_AS),
+ #define XLAT_VAL_11 ((unsigned) (RLIMIT_AS))
+ #define XLAT_STR_11 STRINGIFY(RLIMIT_AS)
  [RLIMIT_RSS] = XLAT(RLIMIT_RSS),
+ #define XLAT_VAL_12 ((unsigned) (RLIMIT_RSS))
+ #define XLAT_STR_12 STRINGIFY(RLIMIT_RSS)
  [RLIMIT_NPROC] = XLAT(RLIMIT_NPROC),
+ #define XLAT_VAL_13 ((unsigned) (RLIMIT_NPROC))
+ #define XLAT_STR_13 STRINGIFY(RLIMIT_NPROC)
  [RLIMIT_MEMLOCK] = XLAT(RLIMIT_MEMLOCK),
+ #define XLAT_VAL_14 ((unsigned) (RLIMIT_MEMLOCK))
+ #define XLAT_STR_14 STRINGIFY(RLIMIT_MEMLOCK)
 #elif defined(__sparc__)
  [RLIMIT_RSS] = XLAT(RLIMIT_RSS),
+ #define XLAT_VAL_15 ((unsigned) (RLIMIT_RSS))
+ #define XLAT_STR_15 STRINGIFY(RLIMIT_RSS)
  [RLIMIT_NOFILE] = XLAT(RLIMIT_NOFILE),
+ #define XLAT_VAL_16 ((unsigned) (RLIMIT_NOFILE))
+ #define XLAT_STR_16 STRINGIFY(RLIMIT_NOFILE)
  [RLIMIT_NPROC] = XLAT(RLIMIT_NPROC),
+ #define XLAT_VAL_17 ((unsigned) (RLIMIT_NPROC))
+ #define XLAT_STR_17 STRINGIFY(RLIMIT_NPROC)
  [RLIMIT_MEMLOCK] = XLAT(RLIMIT_MEMLOCK),
+ #define XLAT_VAL_18 ((unsigned) (RLIMIT_MEMLOCK))
+ #define XLAT_STR_18 STRINGIFY(RLIMIT_MEMLOCK)
  [RLIMIT_AS] = XLAT(RLIMIT_AS),
+ #define XLAT_VAL_19 ((unsigned) (RLIMIT_AS))
+ #define XLAT_STR_19 STRINGIFY(RLIMIT_AS)
 #else
  [RLIMIT_RSS] = XLAT(RLIMIT_RSS),
+ #define XLAT_VAL_20 ((unsigned) (RLIMIT_RSS))
+ #define XLAT_STR_20 STRINGIFY(RLIMIT_RSS)
  [RLIMIT_NPROC] = XLAT(RLIMIT_NPROC),
+ #define XLAT_VAL_21 ((unsigned) (RLIMIT_NPROC))
+ #define XLAT_STR_21 STRINGIFY(RLIMIT_NPROC)
  [RLIMIT_NOFILE] = XLAT(RLIMIT_NOFILE),
+ #define XLAT_VAL_22 ((unsigned) (RLIMIT_NOFILE))
+ #define XLAT_STR_22 STRINGIFY(RLIMIT_NOFILE)
  [RLIMIT_MEMLOCK] = XLAT(RLIMIT_MEMLOCK),
+ #define XLAT_VAL_23 ((unsigned) (RLIMIT_MEMLOCK))
+ #define XLAT_STR_23 STRINGIFY(RLIMIT_MEMLOCK)
  [RLIMIT_AS] = XLAT(RLIMIT_AS),
+ #define XLAT_VAL_24 ((unsigned) (RLIMIT_AS))
+ #define XLAT_STR_24 STRINGIFY(RLIMIT_AS)
 #endif
 
  [RLIMIT_LOCKS] = XLAT(RLIMIT_LOCKS),
+ #define XLAT_VAL_25 ((unsigned) (RLIMIT_LOCKS))
+ #define XLAT_STR_25 STRINGIFY(RLIMIT_LOCKS)
  [RLIMIT_SIGPENDING] = XLAT(RLIMIT_SIGPENDING),
+ #define XLAT_VAL_26 ((unsigned) (RLIMIT_SIGPENDING))
+ #define XLAT_STR_26 STRINGIFY(RLIMIT_SIGPENDING)
  [RLIMIT_MSGQUEUE] = XLAT(RLIMIT_MSGQUEUE),
+ #define XLAT_VAL_27 ((unsigned) (RLIMIT_MSGQUEUE))
+ #define XLAT_STR_27 STRINGIFY(RLIMIT_MSGQUEUE)
  [RLIMIT_NICE] = XLAT(RLIMIT_NICE),
+ #define XLAT_VAL_28 ((unsigned) (RLIMIT_NICE))
+ #define XLAT_STR_28 STRINGIFY(RLIMIT_NICE)
  [RLIMIT_RTPRIO] = XLAT(RLIMIT_RTPRIO),
+ #define XLAT_VAL_29 ((unsigned) (RLIMIT_RTPRIO))
+ #define XLAT_STR_29 STRINGIFY(RLIMIT_RTPRIO)
  [RLIMIT_RTTIME] = XLAT(RLIMIT_RTTIME),
+ #define XLAT_VAL_30 ((unsigned) (RLIMIT_RTTIME))
+ #define XLAT_STR_30 STRINGIFY(RLIMIT_RTTIME)
 };
 static
 const struct xlat resources[1] = { {
  .data = resources_xdata,
  .size = ARRAY_SIZE(resources_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/riscv_flush_icache_flags.h 5.9-0ubuntu2/xlat/riscv_flush_icache_flags.h
--- 5.5-3/xlat/riscv_flush_icache_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/riscv_flush_icache_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -21,14 +21,28 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data riscv_flush_icache_flags_xdata[] = {
  XLAT(SYS_RISCV_FLUSH_ICACHE_LOCAL),
+ #define XLAT_VAL_0 ((unsigned) (SYS_RISCV_FLUSH_ICACHE_LOCAL))
+ #define XLAT_STR_0 STRINGIFY(SYS_RISCV_FLUSH_ICACHE_LOCAL)
 };
 static
 const struct xlat riscv_flush_icache_flags[1] = { {
  .data = riscv_flush_icache_flags_xdata,
  .size = ARRAY_SIZE(riscv_flush_icache_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/route_nexthop_flags.h 5.9-0ubuntu2/xlat/route_nexthop_flags.h
--- 5.5-3/xlat/route_nexthop_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/route_nexthop_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -56,19 +56,83 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data route_nexthop_flags_xdata[] = {
  XLAT(RTNH_F_DEAD),
+ #define XLAT_VAL_0 ((unsigned) (RTNH_F_DEAD))
+ #define XLAT_STR_0 STRINGIFY(RTNH_F_DEAD)
  XLAT(RTNH_F_PERVASIVE),
+ #define XLAT_VAL_1 ((unsigned) (RTNH_F_PERVASIVE))
+ #define XLAT_STR_1 STRINGIFY(RTNH_F_PERVASIVE)
  XLAT(RTNH_F_ONLINK),
+ #define XLAT_VAL_2 ((unsigned) (RTNH_F_ONLINK))
+ #define XLAT_STR_2 STRINGIFY(RTNH_F_ONLINK)
  XLAT(RTNH_F_OFFLOAD),
+ #define XLAT_VAL_3 ((unsigned) (RTNH_F_OFFLOAD))
+ #define XLAT_STR_3 STRINGIFY(RTNH_F_OFFLOAD)
  XLAT(RTNH_F_LINKDOWN),
+ #define XLAT_VAL_4 ((unsigned) (RTNH_F_LINKDOWN))
+ #define XLAT_STR_4 STRINGIFY(RTNH_F_LINKDOWN)
  XLAT(RTNH_F_UNRESOLVED),
+ #define XLAT_VAL_5 ((unsigned) (RTNH_F_UNRESOLVED))
+ #define XLAT_STR_5 STRINGIFY(RTNH_F_UNRESOLVED)
 };
 static
 const struct xlat route_nexthop_flags[1] = { {
  .data = route_nexthop_flags_xdata,
  .size = ARRAY_SIZE(route_nexthop_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/routing_flags.h 5.9-0ubuntu2/xlat/routing_flags.h
--- 5.5-3/xlat/routing_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/routing_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -3,39 +3,172 @@
 #include "gcc_compat.h"
 #include "static_assert.h"
 
-
-#ifndef XLAT_MACROS_ONLY
-
-# ifdef IN_MPERS
-
-#  error static const struct xlat routing_flags in mpers mode
-
-# else
-
-static const struct xlat_data routing_flags_xdata[] = {
 #if defined(RTM_F_NOTIFY) || (defined(HAVE_DECL_RTM_F_NOTIFY) && HAVE_DECL_RTM_F_NOTIFY)
-  XLAT(RTM_F_NOTIFY),
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTM_F_NOTIFY) == (0x100), "RTM_F_NOTIFY != 0x100");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTM_F_NOTIFY 0x100
 #endif
 #if defined(RTM_F_CLONED) || (defined(HAVE_DECL_RTM_F_CLONED) && HAVE_DECL_RTM_F_CLONED)
-  XLAT(RTM_F_CLONED),
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTM_F_CLONED) == (0x200), "RTM_F_CLONED != 0x200");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTM_F_CLONED 0x200
 #endif
 #if defined(RTM_F_EQUALIZE) || (defined(HAVE_DECL_RTM_F_EQUALIZE) && HAVE_DECL_RTM_F_EQUALIZE)
-  XLAT(RTM_F_EQUALIZE),
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTM_F_EQUALIZE) == (0x400), "RTM_F_EQUALIZE != 0x400");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTM_F_EQUALIZE 0x400
 #endif
 #if defined(RTM_F_PREFIX) || (defined(HAVE_DECL_RTM_F_PREFIX) && HAVE_DECL_RTM_F_PREFIX)
-  XLAT(RTM_F_PREFIX),
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTM_F_PREFIX) == (0x800), "RTM_F_PREFIX != 0x800");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTM_F_PREFIX 0x800
 #endif
 #if defined(RTM_F_LOOKUP_TABLE) || (defined(HAVE_DECL_RTM_F_LOOKUP_TABLE) && HAVE_DECL_RTM_F_LOOKUP_TABLE)
-  XLAT(RTM_F_LOOKUP_TABLE),
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTM_F_LOOKUP_TABLE) == (0x1000), "RTM_F_LOOKUP_TABLE != 0x1000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTM_F_LOOKUP_TABLE 0x1000
+#endif
+#if defined(RTM_F_FIB_MATCH) || (defined(HAVE_DECL_RTM_F_FIB_MATCH) && HAVE_DECL_RTM_F_FIB_MATCH)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTM_F_FIB_MATCH) == (0x2000), "RTM_F_FIB_MATCH != 0x2000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTM_F_FIB_MATCH 0x2000
+#endif
+#if defined(RTM_F_OFFLOAD) || (defined(HAVE_DECL_RTM_F_OFFLOAD) && HAVE_DECL_RTM_F_OFFLOAD)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTM_F_OFFLOAD) == (0x4000), "RTM_F_OFFLOAD != 0x4000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTM_F_OFFLOAD 0x4000
 #endif
+#if defined(RTM_F_TRAP) || (defined(HAVE_DECL_RTM_F_TRAP) && HAVE_DECL_RTM_F_TRAP)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTM_F_TRAP) == (0x8000), "RTM_F_TRAP != 0x8000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTM_F_TRAP 0x8000
+#endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+#  error static const struct xlat routing_flags in mpers mode
+
+# else
+
+static const struct xlat_data routing_flags_xdata[] = {
+ XLAT(RTM_F_NOTIFY),
+ #define XLAT_VAL_0 ((unsigned) (RTM_F_NOTIFY))
+ #define XLAT_STR_0 STRINGIFY(RTM_F_NOTIFY)
+ XLAT(RTM_F_CLONED),
+ #define XLAT_VAL_1 ((unsigned) (RTM_F_CLONED))
+ #define XLAT_STR_1 STRINGIFY(RTM_F_CLONED)
+ XLAT(RTM_F_EQUALIZE),
+ #define XLAT_VAL_2 ((unsigned) (RTM_F_EQUALIZE))
+ #define XLAT_STR_2 STRINGIFY(RTM_F_EQUALIZE)
+ XLAT(RTM_F_PREFIX),
+ #define XLAT_VAL_3 ((unsigned) (RTM_F_PREFIX))
+ #define XLAT_STR_3 STRINGIFY(RTM_F_PREFIX)
+ XLAT(RTM_F_LOOKUP_TABLE),
+ #define XLAT_VAL_4 ((unsigned) (RTM_F_LOOKUP_TABLE))
+ #define XLAT_STR_4 STRINGIFY(RTM_F_LOOKUP_TABLE)
+ XLAT(RTM_F_FIB_MATCH),
+ #define XLAT_VAL_5 ((unsigned) (RTM_F_FIB_MATCH))
+ #define XLAT_STR_5 STRINGIFY(RTM_F_FIB_MATCH)
+ XLAT(RTM_F_OFFLOAD),
+ #define XLAT_VAL_6 ((unsigned) (RTM_F_OFFLOAD))
+ #define XLAT_STR_6 STRINGIFY(RTM_F_OFFLOAD)
+ XLAT(RTM_F_TRAP),
+ #define XLAT_VAL_7 ((unsigned) (RTM_F_TRAP))
+ #define XLAT_STR_7 STRINGIFY(RTM_F_TRAP)
 };
 static
 const struct xlat routing_flags[1] = { {
  .data = routing_flags_xdata,
  .size = ARRAY_SIZE(routing_flags_xdata),
- .type = XT_NORMAL,
+ .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/routing_flags.in 5.9-0ubuntu2/xlat/routing_flags.in
--- 5.5-3/xlat/routing_flags.in	2017-08-14 01:06:38.000000000 +0000
+++ 5.9-0ubuntu2/xlat/routing_flags.in	2020-03-01 23:25:39.000000000 +0000
@@ -1,5 +1,9 @@
-RTM_F_NOTIFY
-RTM_F_CLONED
-RTM_F_EQUALIZE
-RTM_F_PREFIX
-RTM_F_LOOKUP_TABLE
+#sorted sort -k2,2g
+RTM_F_NOTIFY		0x100
+RTM_F_CLONED		0x200
+RTM_F_EQUALIZE		0x400
+RTM_F_PREFIX		0x800
+RTM_F_LOOKUP_TABLE	0x1000
+RTM_F_FIB_MATCH		0x2000
+RTM_F_OFFLOAD		0x4000
+RTM_F_TRAP		0x8000
diff -pruN 5.5-3/xlat/routing_protocols.h 5.9-0ubuntu2/xlat/routing_protocols.h
--- 5.5-3/xlat/routing_protocols.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/routing_protocols.h	2020-09-24 09:18:45.000000000 +0000
@@ -108,6 +108,13 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define RTPROT_MROUTED 17
 #endif
+#if defined(RTPROT_KEEPALIVED) || (defined(HAVE_DECL_RTPROT_KEEPALIVED) && HAVE_DECL_RTPROT_KEEPALIVED)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTPROT_KEEPALIVED) == (18), "RTPROT_KEEPALIVED != 18");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTPROT_KEEPALIVED 18
+#endif
 #if defined(RTPROT_BABEL) || (defined(HAVE_DECL_RTPROT_BABEL) && HAVE_DECL_RTPROT_BABEL)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
 static_assert((RTPROT_BABEL) == (42), "RTPROT_BABEL != 42");
@@ -161,34 +168,259 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data routing_protocols_xdata[] = {
  XLAT(RTPROT_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (RTPROT_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(RTPROT_UNSPEC)
  XLAT(RTPROT_REDIRECT),
+ #define XLAT_VAL_1 ((unsigned) (RTPROT_REDIRECT))
+ #define XLAT_STR_1 STRINGIFY(RTPROT_REDIRECT)
  XLAT(RTPROT_KERNEL),
+ #define XLAT_VAL_2 ((unsigned) (RTPROT_KERNEL))
+ #define XLAT_STR_2 STRINGIFY(RTPROT_KERNEL)
  XLAT(RTPROT_BOOT),
+ #define XLAT_VAL_3 ((unsigned) (RTPROT_BOOT))
+ #define XLAT_STR_3 STRINGIFY(RTPROT_BOOT)
  XLAT(RTPROT_STATIC),
+ #define XLAT_VAL_4 ((unsigned) (RTPROT_STATIC))
+ #define XLAT_STR_4 STRINGIFY(RTPROT_STATIC)
  XLAT(RTPROT_GATED),
+ #define XLAT_VAL_5 ((unsigned) (RTPROT_GATED))
+ #define XLAT_STR_5 STRINGIFY(RTPROT_GATED)
  XLAT(RTPROT_RA),
+ #define XLAT_VAL_6 ((unsigned) (RTPROT_RA))
+ #define XLAT_STR_6 STRINGIFY(RTPROT_RA)
  XLAT(RTPROT_MRT),
+ #define XLAT_VAL_7 ((unsigned) (RTPROT_MRT))
+ #define XLAT_STR_7 STRINGIFY(RTPROT_MRT)
  XLAT(RTPROT_ZEBRA),
+ #define XLAT_VAL_8 ((unsigned) (RTPROT_ZEBRA))
+ #define XLAT_STR_8 STRINGIFY(RTPROT_ZEBRA)
  XLAT(RTPROT_BIRD),
+ #define XLAT_VAL_9 ((unsigned) (RTPROT_BIRD))
+ #define XLAT_STR_9 STRINGIFY(RTPROT_BIRD)
  XLAT(RTPROT_DNROUTED),
+ #define XLAT_VAL_10 ((unsigned) (RTPROT_DNROUTED))
+ #define XLAT_STR_10 STRINGIFY(RTPROT_DNROUTED)
  XLAT(RTPROT_XORP),
+ #define XLAT_VAL_11 ((unsigned) (RTPROT_XORP))
+ #define XLAT_STR_11 STRINGIFY(RTPROT_XORP)
  XLAT(RTPROT_NTK),
+ #define XLAT_VAL_12 ((unsigned) (RTPROT_NTK))
+ #define XLAT_STR_12 STRINGIFY(RTPROT_NTK)
  XLAT(RTPROT_DHCP),
+ #define XLAT_VAL_13 ((unsigned) (RTPROT_DHCP))
+ #define XLAT_STR_13 STRINGIFY(RTPROT_DHCP)
  XLAT(RTPROT_MROUTED),
+ #define XLAT_VAL_14 ((unsigned) (RTPROT_MROUTED))
+ #define XLAT_STR_14 STRINGIFY(RTPROT_MROUTED)
+ XLAT(RTPROT_KEEPALIVED),
+ #define XLAT_VAL_15 ((unsigned) (RTPROT_KEEPALIVED))
+ #define XLAT_STR_15 STRINGIFY(RTPROT_KEEPALIVED)
  XLAT(RTPROT_BABEL),
+ #define XLAT_VAL_16 ((unsigned) (RTPROT_BABEL))
+ #define XLAT_STR_16 STRINGIFY(RTPROT_BABEL)
  XLAT(RTPROT_BGP),
+ #define XLAT_VAL_17 ((unsigned) (RTPROT_BGP))
+ #define XLAT_STR_17 STRINGIFY(RTPROT_BGP)
  XLAT(RTPROT_ISIS),
+ #define XLAT_VAL_18 ((unsigned) (RTPROT_ISIS))
+ #define XLAT_STR_18 STRINGIFY(RTPROT_ISIS)
  XLAT(RTPROT_OSPF),
+ #define XLAT_VAL_19 ((unsigned) (RTPROT_OSPF))
+ #define XLAT_STR_19 STRINGIFY(RTPROT_OSPF)
  XLAT(RTPROT_RIP),
+ #define XLAT_VAL_20 ((unsigned) (RTPROT_RIP))
+ #define XLAT_STR_20 STRINGIFY(RTPROT_RIP)
  XLAT(RTPROT_EIGRP),
+ #define XLAT_VAL_21 ((unsigned) (RTPROT_EIGRP))
+ #define XLAT_STR_21 STRINGIFY(RTPROT_EIGRP)
 };
 static
 const struct xlat routing_protocols[1] = { {
  .data = routing_protocols_xdata,
  .size = ARRAY_SIZE(routing_protocols_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/routing_protocols.in 5.9-0ubuntu2/xlat/routing_protocols.in
--- 5.5-3/xlat/routing_protocols.in	2019-07-24 17:12:18.000000000 +0000
+++ 5.9-0ubuntu2/xlat/routing_protocols.in	2020-09-06 08:00:00.000000000 +0000
@@ -14,6 +14,7 @@ RTPROT_XORP	14
 RTPROT_NTK	15
 RTPROT_DHCP	16
 RTPROT_MROUTED	17
+RTPROT_KEEPALIVED 18
 RTPROT_BABEL	42
 RTPROT_BGP	186
 RTPROT_ISIS	187
diff -pruN 5.5-3/xlat/routing_scopes.h 5.9-0ubuntu2/xlat/routing_scopes.h
--- 5.5-3/xlat/routing_scopes.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/routing_scopes.h	2020-09-24 09:18:45.000000000 +0000
@@ -45,17 +45,71 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data routing_scopes_xdata[] = {
  XLAT(RT_SCOPE_UNIVERSE),
+ #define XLAT_VAL_0 ((unsigned) (RT_SCOPE_UNIVERSE))
+ #define XLAT_STR_0 STRINGIFY(RT_SCOPE_UNIVERSE)
  XLAT(RT_SCOPE_SITE),
+ #define XLAT_VAL_1 ((unsigned) (RT_SCOPE_SITE))
+ #define XLAT_STR_1 STRINGIFY(RT_SCOPE_SITE)
  XLAT(RT_SCOPE_LINK),
+ #define XLAT_VAL_2 ((unsigned) (RT_SCOPE_LINK))
+ #define XLAT_STR_2 STRINGIFY(RT_SCOPE_LINK)
  XLAT(RT_SCOPE_HOST),
+ #define XLAT_VAL_3 ((unsigned) (RT_SCOPE_HOST))
+ #define XLAT_STR_3 STRINGIFY(RT_SCOPE_HOST)
  XLAT(RT_SCOPE_NOWHERE),
+ #define XLAT_VAL_4 ((unsigned) (RT_SCOPE_NOWHERE))
+ #define XLAT_STR_4 STRINGIFY(RT_SCOPE_NOWHERE)
 };
 const struct xlat routing_scopes[1] = { {
  .data = routing_scopes_xdata,
  .size = ARRAY_SIZE(routing_scopes_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/routing_table_ids.h 5.9-0ubuntu2/xlat/routing_table_ids.h
--- 5.5-3/xlat/routing_table_ids.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/routing_table_ids.h	2020-09-24 09:18:45.000000000 +0000
@@ -45,17 +45,71 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data routing_table_ids_xdata[] = {
  XLAT(RT_TABLE_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (RT_TABLE_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(RT_TABLE_UNSPEC)
  XLAT(RT_TABLE_COMPAT),
+ #define XLAT_VAL_1 ((unsigned) (RT_TABLE_COMPAT))
+ #define XLAT_STR_1 STRINGIFY(RT_TABLE_COMPAT)
  XLAT(RT_TABLE_DEFAULT),
+ #define XLAT_VAL_2 ((unsigned) (RT_TABLE_DEFAULT))
+ #define XLAT_STR_2 STRINGIFY(RT_TABLE_DEFAULT)
  XLAT(RT_TABLE_MAIN),
+ #define XLAT_VAL_3 ((unsigned) (RT_TABLE_MAIN))
+ #define XLAT_STR_3 STRINGIFY(RT_TABLE_MAIN)
  XLAT(RT_TABLE_LOCAL),
+ #define XLAT_VAL_4 ((unsigned) (RT_TABLE_LOCAL))
+ #define XLAT_STR_4 STRINGIFY(RT_TABLE_LOCAL)
 };
 const struct xlat routing_table_ids[1] = { {
  .data = routing_table_ids_xdata,
  .size = ARRAY_SIZE(routing_table_ids_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/routing_types.h 5.9-0ubuntu2/xlat/routing_types.h
--- 5.5-3/xlat/routing_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/routing_types.h	2020-09-24 09:18:45.000000000 +0000
@@ -94,24 +94,148 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data routing_types_xdata[] = {
  [RTN_UNSPEC] = XLAT(RTN_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (RTN_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(RTN_UNSPEC)
  [RTN_UNICAST] = XLAT(RTN_UNICAST),
+ #define XLAT_VAL_1 ((unsigned) (RTN_UNICAST))
+ #define XLAT_STR_1 STRINGIFY(RTN_UNICAST)
  [RTN_LOCAL] = XLAT(RTN_LOCAL),
+ #define XLAT_VAL_2 ((unsigned) (RTN_LOCAL))
+ #define XLAT_STR_2 STRINGIFY(RTN_LOCAL)
  [RTN_BROADCAST] = XLAT(RTN_BROADCAST),
+ #define XLAT_VAL_3 ((unsigned) (RTN_BROADCAST))
+ #define XLAT_STR_3 STRINGIFY(RTN_BROADCAST)
  [RTN_ANYCAST] = XLAT(RTN_ANYCAST),
+ #define XLAT_VAL_4 ((unsigned) (RTN_ANYCAST))
+ #define XLAT_STR_4 STRINGIFY(RTN_ANYCAST)
  [RTN_MULTICAST] = XLAT(RTN_MULTICAST),
+ #define XLAT_VAL_5 ((unsigned) (RTN_MULTICAST))
+ #define XLAT_STR_5 STRINGIFY(RTN_MULTICAST)
  [RTN_BLACKHOLE] = XLAT(RTN_BLACKHOLE),
+ #define XLAT_VAL_6 ((unsigned) (RTN_BLACKHOLE))
+ #define XLAT_STR_6 STRINGIFY(RTN_BLACKHOLE)
  [RTN_UNREACHABLE] = XLAT(RTN_UNREACHABLE),
+ #define XLAT_VAL_7 ((unsigned) (RTN_UNREACHABLE))
+ #define XLAT_STR_7 STRINGIFY(RTN_UNREACHABLE)
  [RTN_PROHIBIT] = XLAT(RTN_PROHIBIT),
+ #define XLAT_VAL_8 ((unsigned) (RTN_PROHIBIT))
+ #define XLAT_STR_8 STRINGIFY(RTN_PROHIBIT)
  [RTN_THROW] = XLAT(RTN_THROW),
+ #define XLAT_VAL_9 ((unsigned) (RTN_THROW))
+ #define XLAT_STR_9 STRINGIFY(RTN_THROW)
  [RTN_NAT] = XLAT(RTN_NAT),
+ #define XLAT_VAL_10 ((unsigned) (RTN_NAT))
+ #define XLAT_STR_10 STRINGIFY(RTN_NAT)
  [RTN_XRESOLVE] = XLAT(RTN_XRESOLVE),
+ #define XLAT_VAL_11 ((unsigned) (RTN_XRESOLVE))
+ #define XLAT_STR_11 STRINGIFY(RTN_XRESOLVE)
 };
 const struct xlat routing_types[1] = { {
  .data = routing_types_xdata,
  .size = ARRAY_SIZE(routing_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtc_ioctl_cmds.h 5.9-0ubuntu2/xlat/rtc_ioctl_cmds.h
--- 5.5-3/xlat/rtc_ioctl_cmds.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtc_ioctl_cmds.h	2020-09-24 09:18:45.000000000 +0000
@@ -0,0 +1,360 @@
+/* Generated by ./xlat/gen.sh from ./xlat/rtc_ioctl_cmds.in; do not edit. */
+
+#include "gcc_compat.h"
+#include "static_assert.h"
+
+#if defined(RTC_AIE_ON) || (defined(HAVE_DECL_RTC_AIE_ON) && HAVE_DECL_RTC_AIE_ON)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTC_AIE_ON) == (_IO ('p', 0x01)), "RTC_AIE_ON != _IO ('p', 0x01)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTC_AIE_ON _IO ('p', 0x01)
+#endif
+#if defined(RTC_AIE_OFF) || (defined(HAVE_DECL_RTC_AIE_OFF) && HAVE_DECL_RTC_AIE_OFF)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTC_AIE_OFF) == (_IO ('p', 0x02)), "RTC_AIE_OFF != _IO ('p', 0x02)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTC_AIE_OFF _IO ('p', 0x02)
+#endif
+#if defined(RTC_UIE_ON) || (defined(HAVE_DECL_RTC_UIE_ON) && HAVE_DECL_RTC_UIE_ON)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTC_UIE_ON) == (_IO ('p', 0x03)), "RTC_UIE_ON != _IO ('p', 0x03)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTC_UIE_ON _IO ('p', 0x03)
+#endif
+#if defined(RTC_UIE_OFF) || (defined(HAVE_DECL_RTC_UIE_OFF) && HAVE_DECL_RTC_UIE_OFF)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTC_UIE_OFF) == (_IO ('p', 0x04)), "RTC_UIE_OFF != _IO ('p', 0x04)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTC_UIE_OFF _IO ('p', 0x04)
+#endif
+#if defined(RTC_PIE_ON) || (defined(HAVE_DECL_RTC_PIE_ON) && HAVE_DECL_RTC_PIE_ON)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTC_PIE_ON) == (_IO ('p', 0x05)), "RTC_PIE_ON != _IO ('p', 0x05)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTC_PIE_ON _IO ('p', 0x05)
+#endif
+#if defined(RTC_PIE_OFF) || (defined(HAVE_DECL_RTC_PIE_OFF) && HAVE_DECL_RTC_PIE_OFF)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTC_PIE_OFF) == (_IO ('p', 0x06)), "RTC_PIE_OFF != _IO ('p', 0x06)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTC_PIE_OFF _IO ('p', 0x06)
+#endif
+#if defined(RTC_WIE_ON) || (defined(HAVE_DECL_RTC_WIE_ON) && HAVE_DECL_RTC_WIE_ON)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTC_WIE_ON) == (_IO ('p', 0x0f)), "RTC_WIE_ON != _IO ('p', 0x0f)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTC_WIE_ON _IO ('p', 0x0f)
+#endif
+#if defined(RTC_WIE_OFF) || (defined(HAVE_DECL_RTC_WIE_OFF) && HAVE_DECL_RTC_WIE_OFF)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTC_WIE_OFF) == (_IO ('p', 0x10)), "RTC_WIE_OFF != _IO ('p', 0x10)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTC_WIE_OFF _IO ('p', 0x10)
+#endif
+#if defined(RTC_ALM_SET) || (defined(HAVE_DECL_RTC_ALM_SET) && HAVE_DECL_RTC_ALM_SET)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTC_ALM_SET) == (_IOW('p', 0x07, struct rtc_time)), "RTC_ALM_SET != _IOW('p', 0x07, struct rtc_time)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTC_ALM_SET _IOW('p', 0x07, struct rtc_time)
+#endif
+#if defined(RTC_ALM_READ) || (defined(HAVE_DECL_RTC_ALM_READ) && HAVE_DECL_RTC_ALM_READ)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTC_ALM_READ) == (_IOR('p', 0x08, struct rtc_time)), "RTC_ALM_READ != _IOR('p', 0x08, struct rtc_time)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTC_ALM_READ _IOR('p', 0x08, struct rtc_time)
+#endif
+#if defined(RTC_RD_TIME) || (defined(HAVE_DECL_RTC_RD_TIME) && HAVE_DECL_RTC_RD_TIME)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTC_RD_TIME) == (_IOR('p', 0x09, struct rtc_time)), "RTC_RD_TIME != _IOR('p', 0x09, struct rtc_time)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTC_RD_TIME _IOR('p', 0x09, struct rtc_time)
+#endif
+#if defined(RTC_SET_TIME) || (defined(HAVE_DECL_RTC_SET_TIME) && HAVE_DECL_RTC_SET_TIME)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTC_SET_TIME) == (_IOW('p', 0x0a, struct rtc_time)), "RTC_SET_TIME != _IOW('p', 0x0a, struct rtc_time)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTC_SET_TIME _IOW('p', 0x0a, struct rtc_time)
+#endif
+#if defined(RTC_WKALM_SET) || (defined(HAVE_DECL_RTC_WKALM_SET) && HAVE_DECL_RTC_WKALM_SET)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTC_WKALM_SET) == (_IOW('p', 0x0f, struct rtc_wkalrm)), "RTC_WKALM_SET != _IOW('p', 0x0f, struct rtc_wkalrm)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTC_WKALM_SET _IOW('p', 0x0f, struct rtc_wkalrm)
+#endif
+#if defined(RTC_WKALM_RD) || (defined(HAVE_DECL_RTC_WKALM_RD) && HAVE_DECL_RTC_WKALM_RD)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTC_WKALM_RD) == (_IOR('p', 0x10, struct rtc_wkalrm)), "RTC_WKALM_RD != _IOR('p', 0x10, struct rtc_wkalrm)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTC_WKALM_RD _IOR('p', 0x10, struct rtc_wkalrm)
+#endif
+#if defined(RTC_PLL_GET) || (defined(HAVE_DECL_RTC_PLL_GET) && HAVE_DECL_RTC_PLL_GET)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTC_PLL_GET) == (_IOR('p', 0x11, struct_rtc_pll_info)), "RTC_PLL_GET != _IOR('p', 0x11, struct_rtc_pll_info)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTC_PLL_GET _IOR('p', 0x11, struct_rtc_pll_info)
+#endif
+#if defined(RTC_PLL_SET) || (defined(HAVE_DECL_RTC_PLL_SET) && HAVE_DECL_RTC_PLL_SET)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTC_PLL_SET) == (_IOW('p', 0x12, struct_rtc_pll_info)), "RTC_PLL_SET != _IOW('p', 0x12, struct_rtc_pll_info)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTC_PLL_SET _IOW('p', 0x12, struct_rtc_pll_info)
+#endif
+#if defined(RTC_VL_READ) || (defined(HAVE_DECL_RTC_VL_READ) && HAVE_DECL_RTC_VL_READ)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTC_VL_READ) == (_IOR('p', 0x13, unsigned int)), "RTC_VL_READ != _IOR('p', 0x13, unsigned int)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTC_VL_READ _IOR('p', 0x13, unsigned int)
+#endif
+#if defined(RTC_VL_CLR) || (defined(HAVE_DECL_RTC_VL_CLR) && HAVE_DECL_RTC_VL_CLR)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTC_VL_CLR) == (_IO ('p', 0x14)), "RTC_VL_CLR != _IO ('p', 0x14)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTC_VL_CLR _IO ('p', 0x14)
+#endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+extern const struct xlat rtc_ioctl_cmds[];
+
+# else
+
+static const struct xlat_data rtc_ioctl_cmds_xdata[] = {
+ XLAT(RTC_AIE_ON),
+ #define XLAT_VAL_0 ((unsigned) (RTC_AIE_ON))
+ #define XLAT_STR_0 STRINGIFY(RTC_AIE_ON)
+ XLAT(RTC_AIE_OFF),
+ #define XLAT_VAL_1 ((unsigned) (RTC_AIE_OFF))
+ #define XLAT_STR_1 STRINGIFY(RTC_AIE_OFF)
+ XLAT(RTC_UIE_ON),
+ #define XLAT_VAL_2 ((unsigned) (RTC_UIE_ON))
+ #define XLAT_STR_2 STRINGIFY(RTC_UIE_ON)
+ XLAT(RTC_UIE_OFF),
+ #define XLAT_VAL_3 ((unsigned) (RTC_UIE_OFF))
+ #define XLAT_STR_3 STRINGIFY(RTC_UIE_OFF)
+ XLAT(RTC_PIE_ON),
+ #define XLAT_VAL_4 ((unsigned) (RTC_PIE_ON))
+ #define XLAT_STR_4 STRINGIFY(RTC_PIE_ON)
+ XLAT(RTC_PIE_OFF),
+ #define XLAT_VAL_5 ((unsigned) (RTC_PIE_OFF))
+ #define XLAT_STR_5 STRINGIFY(RTC_PIE_OFF)
+ XLAT(RTC_WIE_ON),
+ #define XLAT_VAL_6 ((unsigned) (RTC_WIE_ON))
+ #define XLAT_STR_6 STRINGIFY(RTC_WIE_ON)
+ XLAT(RTC_WIE_OFF),
+ #define XLAT_VAL_7 ((unsigned) (RTC_WIE_OFF))
+ #define XLAT_STR_7 STRINGIFY(RTC_WIE_OFF)
+ XLAT(RTC_ALM_SET),
+ #define XLAT_VAL_8 ((unsigned) (RTC_ALM_SET))
+ #define XLAT_STR_8 STRINGIFY(RTC_ALM_SET)
+ XLAT(RTC_ALM_READ),
+ #define XLAT_VAL_9 ((unsigned) (RTC_ALM_READ))
+ #define XLAT_STR_9 STRINGIFY(RTC_ALM_READ)
+ XLAT(RTC_RD_TIME),
+ #define XLAT_VAL_10 ((unsigned) (RTC_RD_TIME))
+ #define XLAT_STR_10 STRINGIFY(RTC_RD_TIME)
+ XLAT(RTC_SET_TIME),
+ #define XLAT_VAL_11 ((unsigned) (RTC_SET_TIME))
+ #define XLAT_STR_11 STRINGIFY(RTC_SET_TIME)
+
+
+
+
+ XLAT(RTC_WKALM_SET),
+ #define XLAT_VAL_12 ((unsigned) (RTC_WKALM_SET))
+ #define XLAT_STR_12 STRINGIFY(RTC_WKALM_SET)
+ XLAT(RTC_WKALM_RD),
+ #define XLAT_VAL_13 ((unsigned) (RTC_WKALM_RD))
+ #define XLAT_STR_13 STRINGIFY(RTC_WKALM_RD)
+ XLAT(RTC_PLL_GET),
+ #define XLAT_VAL_14 ((unsigned) (RTC_PLL_GET))
+ #define XLAT_STR_14 STRINGIFY(RTC_PLL_GET)
+ XLAT(RTC_PLL_SET),
+ #define XLAT_VAL_15 ((unsigned) (RTC_PLL_SET))
+ #define XLAT_STR_15 STRINGIFY(RTC_PLL_SET)
+ XLAT(RTC_VL_READ),
+ #define XLAT_VAL_16 ((unsigned) (RTC_VL_READ))
+ #define XLAT_STR_16 STRINGIFY(RTC_VL_READ)
+ XLAT(RTC_VL_CLR),
+ #define XLAT_VAL_17 ((unsigned) (RTC_VL_CLR))
+ #define XLAT_STR_17 STRINGIFY(RTC_VL_CLR)
+};
+#  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
+static
+#  endif
+const struct xlat rtc_ioctl_cmds[1] = { {
+ .data = rtc_ioctl_cmds_xdata,
+ .size = ARRAY_SIZE(rtc_ioctl_cmds_xdata),
+ .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+  ,
+} };
+
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+# endif /* !IN_MPERS */
+
+#endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtc_ioctl_cmds.in 5.9-0ubuntu2/xlat/rtc_ioctl_cmds.in
--- 5.5-3/xlat/rtc_ioctl_cmds.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtc_ioctl_cmds.in	2020-03-23 03:19:08.000000000 +0000
@@ -0,0 +1,22 @@
+RTC_AIE_ON	_IO ('p', 0x01)
+RTC_AIE_OFF	_IO ('p', 0x02)
+RTC_UIE_ON	_IO ('p', 0x03)
+RTC_UIE_OFF	_IO ('p', 0x04)
+RTC_PIE_ON	_IO ('p', 0x05)
+RTC_PIE_OFF	_IO ('p', 0x06)
+RTC_WIE_ON	_IO ('p', 0x0f)
+RTC_WIE_OFF	_IO ('p', 0x10)
+RTC_ALM_SET	_IOW('p', 0x07, struct rtc_time)
+RTC_ALM_READ	_IOR('p', 0x08, struct rtc_time)
+RTC_RD_TIME	_IOR('p', 0x09, struct rtc_time)
+RTC_SET_TIME	_IOW('p', 0x0a, struct rtc_time)
+/* RTC_IRQP_READ	_IOR('p', 0x0b, unsigned long) - mpers-dependent */
+/* RTC_IRQP_SET	_IOW('p', 0x0c, unsigned long) - mpers-dependent */
+/* RTC_EPOCH_READ	_IOR('p', 0x0d, unsigned long) - mpers-dependent */
+/* RTC_EPOCH_SET	_IOW('p', 0x0e, unsigned long) - mpers-dependent */
+RTC_WKALM_SET	_IOW('p', 0x0f, struct rtc_wkalrm)
+RTC_WKALM_RD	_IOR('p', 0x10, struct rtc_wkalrm)
+RTC_PLL_GET	_IOR('p', 0x11, struct_rtc_pll_info)
+RTC_PLL_SET	_IOW('p', 0x12, struct_rtc_pll_info)
+RTC_VL_READ	_IOR('p', 0x13, unsigned int)
+RTC_VL_CLR	_IO ('p', 0x14)
diff -pruN 5.5-3/xlat/rtc_vl_flags.h 5.9-0ubuntu2/xlat/rtc_vl_flags.h
--- 5.5-3/xlat/rtc_vl_flags.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtc_vl_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -0,0 +1,122 @@
+/* Generated by ./xlat/gen.sh from ./xlat/rtc_vl_flags.in; do not edit. */
+
+#include "gcc_compat.h"
+#include "static_assert.h"
+
+#if defined(RTC_VL_DATA_INVALID) || (defined(HAVE_DECL_RTC_VL_DATA_INVALID) && HAVE_DECL_RTC_VL_DATA_INVALID)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTC_VL_DATA_INVALID) == ((1 << 0)), "RTC_VL_DATA_INVALID != (1 << 0)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTC_VL_DATA_INVALID (1 << 0)
+#endif
+#if defined(RTC_VL_BACKUP_LOW) || (defined(HAVE_DECL_RTC_VL_BACKUP_LOW) && HAVE_DECL_RTC_VL_BACKUP_LOW)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTC_VL_BACKUP_LOW) == ((1 << 1)), "RTC_VL_BACKUP_LOW != (1 << 1)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTC_VL_BACKUP_LOW (1 << 1)
+#endif
+#if defined(RTC_VL_BACKUP_EMPTY) || (defined(HAVE_DECL_RTC_VL_BACKUP_EMPTY) && HAVE_DECL_RTC_VL_BACKUP_EMPTY)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTC_VL_BACKUP_EMPTY) == ((1 << 2)), "RTC_VL_BACKUP_EMPTY != (1 << 2)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTC_VL_BACKUP_EMPTY (1 << 2)
+#endif
+#if defined(RTC_VL_ACCURACY_LOW) || (defined(HAVE_DECL_RTC_VL_ACCURACY_LOW) && HAVE_DECL_RTC_VL_ACCURACY_LOW)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTC_VL_ACCURACY_LOW) == ((1 << 3)), "RTC_VL_ACCURACY_LOW != (1 << 3)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTC_VL_ACCURACY_LOW (1 << 3)
+#endif
+#if defined(RTC_VL_BACKUP_SWITCH) || (defined(HAVE_DECL_RTC_VL_BACKUP_SWITCH) && HAVE_DECL_RTC_VL_BACKUP_SWITCH)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((RTC_VL_BACKUP_SWITCH) == ((1 << 4)), "RTC_VL_BACKUP_SWITCH != (1 << 4)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define RTC_VL_BACKUP_SWITCH (1 << 4)
+#endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+extern const struct xlat rtc_vl_flags[];
+
+# else
+
+static const struct xlat_data rtc_vl_flags_xdata[] = {
+ XLAT(RTC_VL_DATA_INVALID),
+ #define XLAT_VAL_0 ((unsigned) (RTC_VL_DATA_INVALID))
+ #define XLAT_STR_0 STRINGIFY(RTC_VL_DATA_INVALID)
+ XLAT(RTC_VL_BACKUP_LOW),
+ #define XLAT_VAL_1 ((unsigned) (RTC_VL_BACKUP_LOW))
+ #define XLAT_STR_1 STRINGIFY(RTC_VL_BACKUP_LOW)
+ XLAT(RTC_VL_BACKUP_EMPTY),
+ #define XLAT_VAL_2 ((unsigned) (RTC_VL_BACKUP_EMPTY))
+ #define XLAT_STR_2 STRINGIFY(RTC_VL_BACKUP_EMPTY)
+ XLAT(RTC_VL_ACCURACY_LOW),
+ #define XLAT_VAL_3 ((unsigned) (RTC_VL_ACCURACY_LOW))
+ #define XLAT_STR_3 STRINGIFY(RTC_VL_ACCURACY_LOW)
+ XLAT(RTC_VL_BACKUP_SWITCH),
+ #define XLAT_VAL_4 ((unsigned) (RTC_VL_BACKUP_SWITCH))
+ #define XLAT_STR_4 STRINGIFY(RTC_VL_BACKUP_SWITCH)
+};
+#  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
+static
+#  endif
+const struct xlat rtc_vl_flags[1] = { {
+ .data = rtc_vl_flags_xdata,
+ .size = ARRAY_SIZE(rtc_vl_flags_xdata),
+ .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
+} };
+
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+# endif /* !IN_MPERS */
+
+#endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtc_vl_flags.in 5.9-0ubuntu2/xlat/rtc_vl_flags.in
--- 5.5-3/xlat/rtc_vl_flags.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtc_vl_flags.in	2020-06-29 08:00:00.000000000 +0000
@@ -0,0 +1,5 @@
+RTC_VL_DATA_INVALID	(1 << 0)
+RTC_VL_BACKUP_LOW	(1 << 1)
+RTC_VL_BACKUP_EMPTY	(1 << 2)
+RTC_VL_ACCURACY_LOW	(1 << 3)
+RTC_VL_BACKUP_SWITCH	(1 << 4)
diff -pruN 5.5-3/xlat/rtnl_addr_attrs.h 5.9-0ubuntu2/xlat/rtnl_addr_attrs.h
--- 5.5-3/xlat/rtnl_addr_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_addr_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -91,24 +91,138 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_addr_attrs_xdata[] = {
  [IFA_UNSPEC] = XLAT(IFA_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (IFA_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(IFA_UNSPEC)
  [IFA_ADDRESS] = XLAT(IFA_ADDRESS),
+ #define XLAT_VAL_1 ((unsigned) (IFA_ADDRESS))
+ #define XLAT_STR_1 STRINGIFY(IFA_ADDRESS)
  [IFA_LOCAL] = XLAT(IFA_LOCAL),
+ #define XLAT_VAL_2 ((unsigned) (IFA_LOCAL))
+ #define XLAT_STR_2 STRINGIFY(IFA_LOCAL)
  [IFA_LABEL] = XLAT(IFA_LABEL),
+ #define XLAT_VAL_3 ((unsigned) (IFA_LABEL))
+ #define XLAT_STR_3 STRINGIFY(IFA_LABEL)
  [IFA_BROADCAST] = XLAT(IFA_BROADCAST),
+ #define XLAT_VAL_4 ((unsigned) (IFA_BROADCAST))
+ #define XLAT_STR_4 STRINGIFY(IFA_BROADCAST)
  [IFA_ANYCAST] = XLAT(IFA_ANYCAST),
+ #define XLAT_VAL_5 ((unsigned) (IFA_ANYCAST))
+ #define XLAT_STR_5 STRINGIFY(IFA_ANYCAST)
  [IFA_CACHEINFO] = XLAT(IFA_CACHEINFO),
+ #define XLAT_VAL_6 ((unsigned) (IFA_CACHEINFO))
+ #define XLAT_STR_6 STRINGIFY(IFA_CACHEINFO)
  [IFA_MULTICAST] = XLAT(IFA_MULTICAST),
+ #define XLAT_VAL_7 ((unsigned) (IFA_MULTICAST))
+ #define XLAT_STR_7 STRINGIFY(IFA_MULTICAST)
  [IFA_FLAGS] = XLAT(IFA_FLAGS),
+ #define XLAT_VAL_8 ((unsigned) (IFA_FLAGS))
+ #define XLAT_STR_8 STRINGIFY(IFA_FLAGS)
  [IFA_RT_PRIORITY] = XLAT(IFA_RT_PRIORITY),
+ #define XLAT_VAL_9 ((unsigned) (IFA_RT_PRIORITY))
+ #define XLAT_STR_9 STRINGIFY(IFA_RT_PRIORITY)
  [IFA_TARGET_NETNSID] = XLAT(IFA_TARGET_NETNSID),
+ #define XLAT_VAL_10 ((unsigned) (IFA_TARGET_NETNSID))
+ #define XLAT_STR_10 STRINGIFY(IFA_TARGET_NETNSID)
 };
 static
 const struct xlat rtnl_addr_attrs[1] = { {
  .data = rtnl_addr_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_addr_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_addrlabel_attrs.h 5.9-0ubuntu2/xlat/rtnl_addrlabel_attrs.h
--- 5.5-3/xlat/rtnl_addrlabel_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_addrlabel_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_addrlabel_attrs_xdata[] = {
  [IFAL_ADDRESS] = XLAT(IFAL_ADDRESS),
+ #define XLAT_VAL_0 ((unsigned) (IFAL_ADDRESS))
+ #define XLAT_STR_0 STRINGIFY(IFAL_ADDRESS)
  [IFAL_LABEL] = XLAT(IFAL_LABEL),
+ #define XLAT_VAL_1 ((unsigned) (IFAL_LABEL))
+ #define XLAT_STR_1 STRINGIFY(IFAL_LABEL)
 };
 static
 const struct xlat rtnl_addrlabel_attrs[1] = { {
  .data = rtnl_addrlabel_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_addrlabel_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_dcb_attrs.h 5.9-0ubuntu2/xlat/rtnl_dcb_attrs.h
--- 5.5-3/xlat/rtnl_dcb_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_dcb_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -133,30 +133,204 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_dcb_attrs_xdata[] = {
  [DCB_ATTR_UNDEFINED] = XLAT(DCB_ATTR_UNDEFINED),
+ #define XLAT_VAL_0 ((unsigned) (DCB_ATTR_UNDEFINED))
+ #define XLAT_STR_0 STRINGIFY(DCB_ATTR_UNDEFINED)
  [DCB_ATTR_IFNAME] = XLAT(DCB_ATTR_IFNAME),
+ #define XLAT_VAL_1 ((unsigned) (DCB_ATTR_IFNAME))
+ #define XLAT_STR_1 STRINGIFY(DCB_ATTR_IFNAME)
  [DCB_ATTR_STATE] = XLAT(DCB_ATTR_STATE),
+ #define XLAT_VAL_2 ((unsigned) (DCB_ATTR_STATE))
+ #define XLAT_STR_2 STRINGIFY(DCB_ATTR_STATE)
  [DCB_ATTR_PFC_STATE] = XLAT(DCB_ATTR_PFC_STATE),
+ #define XLAT_VAL_3 ((unsigned) (DCB_ATTR_PFC_STATE))
+ #define XLAT_STR_3 STRINGIFY(DCB_ATTR_PFC_STATE)
  [DCB_ATTR_PFC_CFG] = XLAT(DCB_ATTR_PFC_CFG),
+ #define XLAT_VAL_4 ((unsigned) (DCB_ATTR_PFC_CFG))
+ #define XLAT_STR_4 STRINGIFY(DCB_ATTR_PFC_CFG)
  [DCB_ATTR_NUM_TC] = XLAT(DCB_ATTR_NUM_TC),
+ #define XLAT_VAL_5 ((unsigned) (DCB_ATTR_NUM_TC))
+ #define XLAT_STR_5 STRINGIFY(DCB_ATTR_NUM_TC)
  [DCB_ATTR_PG_CFG] = XLAT(DCB_ATTR_PG_CFG),
+ #define XLAT_VAL_6 ((unsigned) (DCB_ATTR_PG_CFG))
+ #define XLAT_STR_6 STRINGIFY(DCB_ATTR_PG_CFG)
  [DCB_ATTR_SET_ALL] = XLAT(DCB_ATTR_SET_ALL),
+ #define XLAT_VAL_7 ((unsigned) (DCB_ATTR_SET_ALL))
+ #define XLAT_STR_7 STRINGIFY(DCB_ATTR_SET_ALL)
  [DCB_ATTR_PERM_HWADDR] = XLAT(DCB_ATTR_PERM_HWADDR),
+ #define XLAT_VAL_8 ((unsigned) (DCB_ATTR_PERM_HWADDR))
+ #define XLAT_STR_8 STRINGIFY(DCB_ATTR_PERM_HWADDR)
  [DCB_ATTR_CAP] = XLAT(DCB_ATTR_CAP),
+ #define XLAT_VAL_9 ((unsigned) (DCB_ATTR_CAP))
+ #define XLAT_STR_9 STRINGIFY(DCB_ATTR_CAP)
  [DCB_ATTR_NUMTCS] = XLAT(DCB_ATTR_NUMTCS),
+ #define XLAT_VAL_10 ((unsigned) (DCB_ATTR_NUMTCS))
+ #define XLAT_STR_10 STRINGIFY(DCB_ATTR_NUMTCS)
  [DCB_ATTR_BCN] = XLAT(DCB_ATTR_BCN),
+ #define XLAT_VAL_11 ((unsigned) (DCB_ATTR_BCN))
+ #define XLAT_STR_11 STRINGIFY(DCB_ATTR_BCN)
  [DCB_ATTR_APP] = XLAT(DCB_ATTR_APP),
+ #define XLAT_VAL_12 ((unsigned) (DCB_ATTR_APP))
+ #define XLAT_STR_12 STRINGIFY(DCB_ATTR_APP)
  [DCB_ATTR_IEEE] = XLAT(DCB_ATTR_IEEE),
+ #define XLAT_VAL_13 ((unsigned) (DCB_ATTR_IEEE))
+ #define XLAT_STR_13 STRINGIFY(DCB_ATTR_IEEE)
  [DCB_ATTR_DCBX] = XLAT(DCB_ATTR_DCBX),
+ #define XLAT_VAL_14 ((unsigned) (DCB_ATTR_DCBX))
+ #define XLAT_STR_14 STRINGIFY(DCB_ATTR_DCBX)
  [DCB_ATTR_FEATCFG] = XLAT(DCB_ATTR_FEATCFG),
+ #define XLAT_VAL_15 ((unsigned) (DCB_ATTR_FEATCFG))
+ #define XLAT_STR_15 STRINGIFY(DCB_ATTR_FEATCFG)
  [DCB_ATTR_CEE] = XLAT(DCB_ATTR_CEE),
+ #define XLAT_VAL_16 ((unsigned) (DCB_ATTR_CEE))
+ #define XLAT_STR_16 STRINGIFY(DCB_ATTR_CEE)
 };
 static
 const struct xlat rtnl_dcb_attrs[1] = { {
  .data = rtnl_dcb_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_dcb_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_ifla_af_spec_inet6_attrs.h 5.9-0ubuntu2/xlat/rtnl_ifla_af_spec_inet6_attrs.h
--- 5.5-3/xlat/rtnl_ifla_af_spec_inet6_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_ifla_af_spec_inet6_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -77,22 +77,116 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_ifla_af_spec_inet6_attrs_xdata[] = {
  [IFLA_INET6_UNSPEC] = XLAT(IFLA_INET6_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (IFLA_INET6_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(IFLA_INET6_UNSPEC)
  [IFLA_INET6_FLAGS] = XLAT(IFLA_INET6_FLAGS),
+ #define XLAT_VAL_1 ((unsigned) (IFLA_INET6_FLAGS))
+ #define XLAT_STR_1 STRINGIFY(IFLA_INET6_FLAGS)
  [IFLA_INET6_CONF] = XLAT(IFLA_INET6_CONF),
+ #define XLAT_VAL_2 ((unsigned) (IFLA_INET6_CONF))
+ #define XLAT_STR_2 STRINGIFY(IFLA_INET6_CONF)
  [IFLA_INET6_STATS] = XLAT(IFLA_INET6_STATS),
+ #define XLAT_VAL_3 ((unsigned) (IFLA_INET6_STATS))
+ #define XLAT_STR_3 STRINGIFY(IFLA_INET6_STATS)
  [IFLA_INET6_MCAST] = XLAT(IFLA_INET6_MCAST),
+ #define XLAT_VAL_4 ((unsigned) (IFLA_INET6_MCAST))
+ #define XLAT_STR_4 STRINGIFY(IFLA_INET6_MCAST)
  [IFLA_INET6_CACHEINFO] = XLAT(IFLA_INET6_CACHEINFO),
+ #define XLAT_VAL_5 ((unsigned) (IFLA_INET6_CACHEINFO))
+ #define XLAT_STR_5 STRINGIFY(IFLA_INET6_CACHEINFO)
  [IFLA_INET6_ICMP6STATS] = XLAT(IFLA_INET6_ICMP6STATS),
+ #define XLAT_VAL_6 ((unsigned) (IFLA_INET6_ICMP6STATS))
+ #define XLAT_STR_6 STRINGIFY(IFLA_INET6_ICMP6STATS)
  [IFLA_INET6_TOKEN] = XLAT(IFLA_INET6_TOKEN),
+ #define XLAT_VAL_7 ((unsigned) (IFLA_INET6_TOKEN))
+ #define XLAT_STR_7 STRINGIFY(IFLA_INET6_TOKEN)
  [IFLA_INET6_ADDR_GEN_MODE] = XLAT(IFLA_INET6_ADDR_GEN_MODE),
+ #define XLAT_VAL_8 ((unsigned) (IFLA_INET6_ADDR_GEN_MODE))
+ #define XLAT_STR_8 STRINGIFY(IFLA_INET6_ADDR_GEN_MODE)
 };
 static
 const struct xlat rtnl_ifla_af_spec_inet6_attrs[1] = { {
  .data = rtnl_ifla_af_spec_inet6_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_ifla_af_spec_inet6_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_ifla_af_spec_inet_attrs.h 5.9-0ubuntu2/xlat/rtnl_ifla_af_spec_inet_attrs.h
--- 5.5-3/xlat/rtnl_ifla_af_spec_inet_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_ifla_af_spec_inet_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_ifla_af_spec_inet_attrs_xdata[] = {
  [IFLA_INET_UNSPEC] = XLAT(IFLA_INET_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (IFLA_INET_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(IFLA_INET_UNSPEC)
  [IFLA_INET_CONF] = XLAT(IFLA_INET_CONF),
+ #define XLAT_VAL_1 ((unsigned) (IFLA_INET_CONF))
+ #define XLAT_STR_1 STRINGIFY(IFLA_INET_CONF)
 };
 static
 const struct xlat rtnl_ifla_af_spec_inet_attrs[1] = { {
  .data = rtnl_ifla_af_spec_inet_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_ifla_af_spec_inet_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_ifla_brport_attrs.h 5.9-0ubuntu2/xlat/rtnl_ifla_brport_attrs.h
--- 5.5-3/xlat/rtnl_ifla_brport_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_ifla_brport_attrs.h	2020-09-24 09:18:46.000000000 +0000
@@ -259,48 +259,402 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_ifla_brport_attrs_xdata[] = {
  [IFLA_BRPORT_UNSPEC] = XLAT(IFLA_BRPORT_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (IFLA_BRPORT_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(IFLA_BRPORT_UNSPEC)
  [IFLA_BRPORT_STATE] = XLAT(IFLA_BRPORT_STATE),
+ #define XLAT_VAL_1 ((unsigned) (IFLA_BRPORT_STATE))
+ #define XLAT_STR_1 STRINGIFY(IFLA_BRPORT_STATE)
  [IFLA_BRPORT_PRIORITY] = XLAT(IFLA_BRPORT_PRIORITY),
+ #define XLAT_VAL_2 ((unsigned) (IFLA_BRPORT_PRIORITY))
+ #define XLAT_STR_2 STRINGIFY(IFLA_BRPORT_PRIORITY)
  [IFLA_BRPORT_COST] = XLAT(IFLA_BRPORT_COST),
+ #define XLAT_VAL_3 ((unsigned) (IFLA_BRPORT_COST))
+ #define XLAT_STR_3 STRINGIFY(IFLA_BRPORT_COST)
  [IFLA_BRPORT_MODE] = XLAT(IFLA_BRPORT_MODE),
+ #define XLAT_VAL_4 ((unsigned) (IFLA_BRPORT_MODE))
+ #define XLAT_STR_4 STRINGIFY(IFLA_BRPORT_MODE)
  [IFLA_BRPORT_GUARD] = XLAT(IFLA_BRPORT_GUARD),
+ #define XLAT_VAL_5 ((unsigned) (IFLA_BRPORT_GUARD))
+ #define XLAT_STR_5 STRINGIFY(IFLA_BRPORT_GUARD)
  [IFLA_BRPORT_PROTECT] = XLAT(IFLA_BRPORT_PROTECT),
+ #define XLAT_VAL_6 ((unsigned) (IFLA_BRPORT_PROTECT))
+ #define XLAT_STR_6 STRINGIFY(IFLA_BRPORT_PROTECT)
  [IFLA_BRPORT_FAST_LEAVE] = XLAT(IFLA_BRPORT_FAST_LEAVE),
+ #define XLAT_VAL_7 ((unsigned) (IFLA_BRPORT_FAST_LEAVE))
+ #define XLAT_STR_7 STRINGIFY(IFLA_BRPORT_FAST_LEAVE)
  [IFLA_BRPORT_LEARNING] = XLAT(IFLA_BRPORT_LEARNING),
+ #define XLAT_VAL_8 ((unsigned) (IFLA_BRPORT_LEARNING))
+ #define XLAT_STR_8 STRINGIFY(IFLA_BRPORT_LEARNING)
  [IFLA_BRPORT_UNICAST_FLOOD] = XLAT(IFLA_BRPORT_UNICAST_FLOOD),
+ #define XLAT_VAL_9 ((unsigned) (IFLA_BRPORT_UNICAST_FLOOD))
+ #define XLAT_STR_9 STRINGIFY(IFLA_BRPORT_UNICAST_FLOOD)
  [IFLA_BRPORT_PROXYARP] = XLAT(IFLA_BRPORT_PROXYARP),
+ #define XLAT_VAL_10 ((unsigned) (IFLA_BRPORT_PROXYARP))
+ #define XLAT_STR_10 STRINGIFY(IFLA_BRPORT_PROXYARP)
  [IFLA_BRPORT_LEARNING_SYNC] = XLAT(IFLA_BRPORT_LEARNING_SYNC),
+ #define XLAT_VAL_11 ((unsigned) (IFLA_BRPORT_LEARNING_SYNC))
+ #define XLAT_STR_11 STRINGIFY(IFLA_BRPORT_LEARNING_SYNC)
  [IFLA_BRPORT_PROXYARP_WIFI] = XLAT(IFLA_BRPORT_PROXYARP_WIFI),
+ #define XLAT_VAL_12 ((unsigned) (IFLA_BRPORT_PROXYARP_WIFI))
+ #define XLAT_STR_12 STRINGIFY(IFLA_BRPORT_PROXYARP_WIFI)
  [IFLA_BRPORT_ROOT_ID] = XLAT(IFLA_BRPORT_ROOT_ID),
+ #define XLAT_VAL_13 ((unsigned) (IFLA_BRPORT_ROOT_ID))
+ #define XLAT_STR_13 STRINGIFY(IFLA_BRPORT_ROOT_ID)
  [IFLA_BRPORT_BRIDGE_ID] = XLAT(IFLA_BRPORT_BRIDGE_ID),
+ #define XLAT_VAL_14 ((unsigned) (IFLA_BRPORT_BRIDGE_ID))
+ #define XLAT_STR_14 STRINGIFY(IFLA_BRPORT_BRIDGE_ID)
  [IFLA_BRPORT_DESIGNATED_PORT] = XLAT(IFLA_BRPORT_DESIGNATED_PORT),
+ #define XLAT_VAL_15 ((unsigned) (IFLA_BRPORT_DESIGNATED_PORT))
+ #define XLAT_STR_15 STRINGIFY(IFLA_BRPORT_DESIGNATED_PORT)
  [IFLA_BRPORT_DESIGNATED_COST] = XLAT(IFLA_BRPORT_DESIGNATED_COST),
+ #define XLAT_VAL_16 ((unsigned) (IFLA_BRPORT_DESIGNATED_COST))
+ #define XLAT_STR_16 STRINGIFY(IFLA_BRPORT_DESIGNATED_COST)
  [IFLA_BRPORT_ID] = XLAT(IFLA_BRPORT_ID),
+ #define XLAT_VAL_17 ((unsigned) (IFLA_BRPORT_ID))
+ #define XLAT_STR_17 STRINGIFY(IFLA_BRPORT_ID)
  [IFLA_BRPORT_NO] = XLAT(IFLA_BRPORT_NO),
+ #define XLAT_VAL_18 ((unsigned) (IFLA_BRPORT_NO))
+ #define XLAT_STR_18 STRINGIFY(IFLA_BRPORT_NO)
  [IFLA_BRPORT_TOPOLOGY_CHANGE_ACK] = XLAT(IFLA_BRPORT_TOPOLOGY_CHANGE_ACK),
+ #define XLAT_VAL_19 ((unsigned) (IFLA_BRPORT_TOPOLOGY_CHANGE_ACK))
+ #define XLAT_STR_19 STRINGIFY(IFLA_BRPORT_TOPOLOGY_CHANGE_ACK)
  [IFLA_BRPORT_CONFIG_PENDING] = XLAT(IFLA_BRPORT_CONFIG_PENDING),
+ #define XLAT_VAL_20 ((unsigned) (IFLA_BRPORT_CONFIG_PENDING))
+ #define XLAT_STR_20 STRINGIFY(IFLA_BRPORT_CONFIG_PENDING)
  [IFLA_BRPORT_MESSAGE_AGE_TIMER] = XLAT(IFLA_BRPORT_MESSAGE_AGE_TIMER),
+ #define XLAT_VAL_21 ((unsigned) (IFLA_BRPORT_MESSAGE_AGE_TIMER))
+ #define XLAT_STR_21 STRINGIFY(IFLA_BRPORT_MESSAGE_AGE_TIMER)
  [IFLA_BRPORT_FORWARD_DELAY_TIMER] = XLAT(IFLA_BRPORT_FORWARD_DELAY_TIMER),
+ #define XLAT_VAL_22 ((unsigned) (IFLA_BRPORT_FORWARD_DELAY_TIMER))
+ #define XLAT_STR_22 STRINGIFY(IFLA_BRPORT_FORWARD_DELAY_TIMER)
  [IFLA_BRPORT_HOLD_TIMER] = XLAT(IFLA_BRPORT_HOLD_TIMER),
+ #define XLAT_VAL_23 ((unsigned) (IFLA_BRPORT_HOLD_TIMER))
+ #define XLAT_STR_23 STRINGIFY(IFLA_BRPORT_HOLD_TIMER)
  [IFLA_BRPORT_FLUSH] = XLAT(IFLA_BRPORT_FLUSH),
+ #define XLAT_VAL_24 ((unsigned) (IFLA_BRPORT_FLUSH))
+ #define XLAT_STR_24 STRINGIFY(IFLA_BRPORT_FLUSH)
  [IFLA_BRPORT_MULTICAST_ROUTER] = XLAT(IFLA_BRPORT_MULTICAST_ROUTER),
+ #define XLAT_VAL_25 ((unsigned) (IFLA_BRPORT_MULTICAST_ROUTER))
+ #define XLAT_STR_25 STRINGIFY(IFLA_BRPORT_MULTICAST_ROUTER)
  [IFLA_BRPORT_PAD] = XLAT(IFLA_BRPORT_PAD),
+ #define XLAT_VAL_26 ((unsigned) (IFLA_BRPORT_PAD))
+ #define XLAT_STR_26 STRINGIFY(IFLA_BRPORT_PAD)
  [IFLA_BRPORT_MCAST_FLOOD] = XLAT(IFLA_BRPORT_MCAST_FLOOD),
+ #define XLAT_VAL_27 ((unsigned) (IFLA_BRPORT_MCAST_FLOOD))
+ #define XLAT_STR_27 STRINGIFY(IFLA_BRPORT_MCAST_FLOOD)
  [IFLA_BRPORT_MCAST_TO_UCAST] = XLAT(IFLA_BRPORT_MCAST_TO_UCAST),
+ #define XLAT_VAL_28 ((unsigned) (IFLA_BRPORT_MCAST_TO_UCAST))
+ #define XLAT_STR_28 STRINGIFY(IFLA_BRPORT_MCAST_TO_UCAST)
  [IFLA_BRPORT_VLAN_TUNNEL] = XLAT(IFLA_BRPORT_VLAN_TUNNEL),
+ #define XLAT_VAL_29 ((unsigned) (IFLA_BRPORT_VLAN_TUNNEL))
+ #define XLAT_STR_29 STRINGIFY(IFLA_BRPORT_VLAN_TUNNEL)
  [IFLA_BRPORT_BCAST_FLOOD] = XLAT(IFLA_BRPORT_BCAST_FLOOD),
+ #define XLAT_VAL_30 ((unsigned) (IFLA_BRPORT_BCAST_FLOOD))
+ #define XLAT_STR_30 STRINGIFY(IFLA_BRPORT_BCAST_FLOOD)
  [IFLA_BRPORT_GROUP_FWD_MASK] = XLAT(IFLA_BRPORT_GROUP_FWD_MASK),
+ #define XLAT_VAL_31 ((unsigned) (IFLA_BRPORT_GROUP_FWD_MASK))
+ #define XLAT_STR_31 STRINGIFY(IFLA_BRPORT_GROUP_FWD_MASK)
  [IFLA_BRPORT_NEIGH_SUPPRESS] = XLAT(IFLA_BRPORT_NEIGH_SUPPRESS),
+ #define XLAT_VAL_32 ((unsigned) (IFLA_BRPORT_NEIGH_SUPPRESS))
+ #define XLAT_STR_32 STRINGIFY(IFLA_BRPORT_NEIGH_SUPPRESS)
  [IFLA_BRPORT_ISOLATED] = XLAT(IFLA_BRPORT_ISOLATED),
+ #define XLAT_VAL_33 ((unsigned) (IFLA_BRPORT_ISOLATED))
+ #define XLAT_STR_33 STRINGIFY(IFLA_BRPORT_ISOLATED)
  [IFLA_BRPORT_BACKUP_PORT] = XLAT(IFLA_BRPORT_BACKUP_PORT),
+ #define XLAT_VAL_34 ((unsigned) (IFLA_BRPORT_BACKUP_PORT))
+ #define XLAT_STR_34 STRINGIFY(IFLA_BRPORT_BACKUP_PORT)
 };
 static
 const struct xlat rtnl_ifla_brport_attrs[1] = { {
  .data = rtnl_ifla_brport_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_ifla_brport_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_ifla_events.h 5.9-0ubuntu2/xlat/rtnl_ifla_events.h
--- 5.5-3/xlat/rtnl_ifla_events.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_ifla_events.h	2020-09-24 09:18:45.000000000 +0000
@@ -63,20 +63,94 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_ifla_events_xdata[] = {
  [IFLA_EVENT_NONE] = XLAT(IFLA_EVENT_NONE),
+ #define XLAT_VAL_0 ((unsigned) (IFLA_EVENT_NONE))
+ #define XLAT_STR_0 STRINGIFY(IFLA_EVENT_NONE)
  [IFLA_EVENT_REBOOT] = XLAT(IFLA_EVENT_REBOOT),
+ #define XLAT_VAL_1 ((unsigned) (IFLA_EVENT_REBOOT))
+ #define XLAT_STR_1 STRINGIFY(IFLA_EVENT_REBOOT)
  [IFLA_EVENT_FEATURES] = XLAT(IFLA_EVENT_FEATURES),
+ #define XLAT_VAL_2 ((unsigned) (IFLA_EVENT_FEATURES))
+ #define XLAT_STR_2 STRINGIFY(IFLA_EVENT_FEATURES)
  [IFLA_EVENT_BONDING_FAILOVER] = XLAT(IFLA_EVENT_BONDING_FAILOVER),
+ #define XLAT_VAL_3 ((unsigned) (IFLA_EVENT_BONDING_FAILOVER))
+ #define XLAT_STR_3 STRINGIFY(IFLA_EVENT_BONDING_FAILOVER)
  [IFLA_EVENT_NOTIFY_PEERS] = XLAT(IFLA_EVENT_NOTIFY_PEERS),
+ #define XLAT_VAL_4 ((unsigned) (IFLA_EVENT_NOTIFY_PEERS))
+ #define XLAT_STR_4 STRINGIFY(IFLA_EVENT_NOTIFY_PEERS)
  [IFLA_EVENT_IGMP_RESEND] = XLAT(IFLA_EVENT_IGMP_RESEND),
+ #define XLAT_VAL_5 ((unsigned) (IFLA_EVENT_IGMP_RESEND))
+ #define XLAT_STR_5 STRINGIFY(IFLA_EVENT_IGMP_RESEND)
  [IFLA_EVENT_BONDING_OPTIONS] = XLAT(IFLA_EVENT_BONDING_OPTIONS),
+ #define XLAT_VAL_6 ((unsigned) (IFLA_EVENT_BONDING_OPTIONS))
+ #define XLAT_STR_6 STRINGIFY(IFLA_EVENT_BONDING_OPTIONS)
 };
 static
 const struct xlat rtnl_ifla_events[1] = { {
  .data = rtnl_ifla_events_xdata,
  .size = ARRAY_SIZE(rtnl_ifla_events_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_ifla_info_attrs.h 5.9-0ubuntu2/xlat/rtnl_ifla_info_attrs.h
--- 5.5-3/xlat/rtnl_ifla_info_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_ifla_info_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -56,19 +56,83 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_ifla_info_attrs_xdata[] = {
  [IFLA_INFO_UNSPEC] = XLAT(IFLA_INFO_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (IFLA_INFO_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(IFLA_INFO_UNSPEC)
  [IFLA_INFO_KIND] = XLAT(IFLA_INFO_KIND),
+ #define XLAT_VAL_1 ((unsigned) (IFLA_INFO_KIND))
+ #define XLAT_STR_1 STRINGIFY(IFLA_INFO_KIND)
  [IFLA_INFO_DATA] = XLAT(IFLA_INFO_DATA),
+ #define XLAT_VAL_2 ((unsigned) (IFLA_INFO_DATA))
+ #define XLAT_STR_2 STRINGIFY(IFLA_INFO_DATA)
  [IFLA_INFO_XSTATS] = XLAT(IFLA_INFO_XSTATS),
+ #define XLAT_VAL_3 ((unsigned) (IFLA_INFO_XSTATS))
+ #define XLAT_STR_3 STRINGIFY(IFLA_INFO_XSTATS)
  [IFLA_INFO_SLAVE_KIND] = XLAT(IFLA_INFO_SLAVE_KIND),
+ #define XLAT_VAL_4 ((unsigned) (IFLA_INFO_SLAVE_KIND))
+ #define XLAT_STR_4 STRINGIFY(IFLA_INFO_SLAVE_KIND)
  [IFLA_INFO_SLAVE_DATA] = XLAT(IFLA_INFO_SLAVE_DATA),
+ #define XLAT_VAL_5 ((unsigned) (IFLA_INFO_SLAVE_DATA))
+ #define XLAT_STR_5 STRINGIFY(IFLA_INFO_SLAVE_DATA)
 };
 static
 const struct xlat rtnl_ifla_info_attrs[1] = { {
  .data = rtnl_ifla_info_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_ifla_info_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_ifla_info_data_bridge_attrs.h 5.9-0ubuntu2/xlat/rtnl_ifla_info_data_bridge_attrs.h
--- 5.5-3/xlat/rtnl_ifla_info_data_bridge_attrs.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_ifla_info_data_bridge_attrs.h	2020-09-24 09:18:46.000000000 +0000
@@ -343,60 +343,534 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_ifla_info_data_bridge_attrs_xdata[] = {
  [IFLA_BR_UNSPEC] = XLAT(IFLA_BR_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (IFLA_BR_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(IFLA_BR_UNSPEC)
  [IFLA_BR_FORWARD_DELAY] = XLAT(IFLA_BR_FORWARD_DELAY),
+ #define XLAT_VAL_1 ((unsigned) (IFLA_BR_FORWARD_DELAY))
+ #define XLAT_STR_1 STRINGIFY(IFLA_BR_FORWARD_DELAY)
  [IFLA_BR_HELLO_TIME] = XLAT(IFLA_BR_HELLO_TIME),
+ #define XLAT_VAL_2 ((unsigned) (IFLA_BR_HELLO_TIME))
+ #define XLAT_STR_2 STRINGIFY(IFLA_BR_HELLO_TIME)
  [IFLA_BR_MAX_AGE] = XLAT(IFLA_BR_MAX_AGE),
+ #define XLAT_VAL_3 ((unsigned) (IFLA_BR_MAX_AGE))
+ #define XLAT_STR_3 STRINGIFY(IFLA_BR_MAX_AGE)
  [IFLA_BR_AGEING_TIME] = XLAT(IFLA_BR_AGEING_TIME),
+ #define XLAT_VAL_4 ((unsigned) (IFLA_BR_AGEING_TIME))
+ #define XLAT_STR_4 STRINGIFY(IFLA_BR_AGEING_TIME)
  [IFLA_BR_STP_STATE] = XLAT(IFLA_BR_STP_STATE),
+ #define XLAT_VAL_5 ((unsigned) (IFLA_BR_STP_STATE))
+ #define XLAT_STR_5 STRINGIFY(IFLA_BR_STP_STATE)
  [IFLA_BR_PRIORITY] = XLAT(IFLA_BR_PRIORITY),
+ #define XLAT_VAL_6 ((unsigned) (IFLA_BR_PRIORITY))
+ #define XLAT_STR_6 STRINGIFY(IFLA_BR_PRIORITY)
  [IFLA_BR_VLAN_FILTERING] = XLAT(IFLA_BR_VLAN_FILTERING),
+ #define XLAT_VAL_7 ((unsigned) (IFLA_BR_VLAN_FILTERING))
+ #define XLAT_STR_7 STRINGIFY(IFLA_BR_VLAN_FILTERING)
  [IFLA_BR_VLAN_PROTOCOL] = XLAT(IFLA_BR_VLAN_PROTOCOL),
+ #define XLAT_VAL_8 ((unsigned) (IFLA_BR_VLAN_PROTOCOL))
+ #define XLAT_STR_8 STRINGIFY(IFLA_BR_VLAN_PROTOCOL)
  [IFLA_BR_GROUP_FWD_MASK] = XLAT(IFLA_BR_GROUP_FWD_MASK),
+ #define XLAT_VAL_9 ((unsigned) (IFLA_BR_GROUP_FWD_MASK))
+ #define XLAT_STR_9 STRINGIFY(IFLA_BR_GROUP_FWD_MASK)
  [IFLA_BR_ROOT_ID] = XLAT(IFLA_BR_ROOT_ID),
+ #define XLAT_VAL_10 ((unsigned) (IFLA_BR_ROOT_ID))
+ #define XLAT_STR_10 STRINGIFY(IFLA_BR_ROOT_ID)
  [IFLA_BR_BRIDGE_ID] = XLAT(IFLA_BR_BRIDGE_ID),
+ #define XLAT_VAL_11 ((unsigned) (IFLA_BR_BRIDGE_ID))
+ #define XLAT_STR_11 STRINGIFY(IFLA_BR_BRIDGE_ID)
  [IFLA_BR_ROOT_PORT] = XLAT(IFLA_BR_ROOT_PORT),
+ #define XLAT_VAL_12 ((unsigned) (IFLA_BR_ROOT_PORT))
+ #define XLAT_STR_12 STRINGIFY(IFLA_BR_ROOT_PORT)
  [IFLA_BR_ROOT_PATH_COST] = XLAT(IFLA_BR_ROOT_PATH_COST),
+ #define XLAT_VAL_13 ((unsigned) (IFLA_BR_ROOT_PATH_COST))
+ #define XLAT_STR_13 STRINGIFY(IFLA_BR_ROOT_PATH_COST)
  [IFLA_BR_TOPOLOGY_CHANGE] = XLAT(IFLA_BR_TOPOLOGY_CHANGE),
+ #define XLAT_VAL_14 ((unsigned) (IFLA_BR_TOPOLOGY_CHANGE))
+ #define XLAT_STR_14 STRINGIFY(IFLA_BR_TOPOLOGY_CHANGE)
  [IFLA_BR_TOPOLOGY_CHANGE_DETECTED] = XLAT(IFLA_BR_TOPOLOGY_CHANGE_DETECTED),
+ #define XLAT_VAL_15 ((unsigned) (IFLA_BR_TOPOLOGY_CHANGE_DETECTED))
+ #define XLAT_STR_15 STRINGIFY(IFLA_BR_TOPOLOGY_CHANGE_DETECTED)
  [IFLA_BR_HELLO_TIMER] = XLAT(IFLA_BR_HELLO_TIMER),
+ #define XLAT_VAL_16 ((unsigned) (IFLA_BR_HELLO_TIMER))
+ #define XLAT_STR_16 STRINGIFY(IFLA_BR_HELLO_TIMER)
  [IFLA_BR_TCN_TIMER] = XLAT(IFLA_BR_TCN_TIMER),
+ #define XLAT_VAL_17 ((unsigned) (IFLA_BR_TCN_TIMER))
+ #define XLAT_STR_17 STRINGIFY(IFLA_BR_TCN_TIMER)
  [IFLA_BR_TOPOLOGY_CHANGE_TIMER] = XLAT(IFLA_BR_TOPOLOGY_CHANGE_TIMER),
+ #define XLAT_VAL_18 ((unsigned) (IFLA_BR_TOPOLOGY_CHANGE_TIMER))
+ #define XLAT_STR_18 STRINGIFY(IFLA_BR_TOPOLOGY_CHANGE_TIMER)
  [IFLA_BR_GC_TIMER] = XLAT(IFLA_BR_GC_TIMER),
+ #define XLAT_VAL_19 ((unsigned) (IFLA_BR_GC_TIMER))
+ #define XLAT_STR_19 STRINGIFY(IFLA_BR_GC_TIMER)
  [IFLA_BR_GROUP_ADDR] = XLAT(IFLA_BR_GROUP_ADDR),
+ #define XLAT_VAL_20 ((unsigned) (IFLA_BR_GROUP_ADDR))
+ #define XLAT_STR_20 STRINGIFY(IFLA_BR_GROUP_ADDR)
  [IFLA_BR_FDB_FLUSH] = XLAT(IFLA_BR_FDB_FLUSH),
+ #define XLAT_VAL_21 ((unsigned) (IFLA_BR_FDB_FLUSH))
+ #define XLAT_STR_21 STRINGIFY(IFLA_BR_FDB_FLUSH)
  [IFLA_BR_MCAST_ROUTER] = XLAT(IFLA_BR_MCAST_ROUTER),
+ #define XLAT_VAL_22 ((unsigned) (IFLA_BR_MCAST_ROUTER))
+ #define XLAT_STR_22 STRINGIFY(IFLA_BR_MCAST_ROUTER)
  [IFLA_BR_MCAST_SNOOPING] = XLAT(IFLA_BR_MCAST_SNOOPING),
+ #define XLAT_VAL_23 ((unsigned) (IFLA_BR_MCAST_SNOOPING))
+ #define XLAT_STR_23 STRINGIFY(IFLA_BR_MCAST_SNOOPING)
  [IFLA_BR_MCAST_QUERY_USE_IFADDR] = XLAT(IFLA_BR_MCAST_QUERY_USE_IFADDR),
+ #define XLAT_VAL_24 ((unsigned) (IFLA_BR_MCAST_QUERY_USE_IFADDR))
+ #define XLAT_STR_24 STRINGIFY(IFLA_BR_MCAST_QUERY_USE_IFADDR)
  [IFLA_BR_MCAST_QUERIER] = XLAT(IFLA_BR_MCAST_QUERIER),
+ #define XLAT_VAL_25 ((unsigned) (IFLA_BR_MCAST_QUERIER))
+ #define XLAT_STR_25 STRINGIFY(IFLA_BR_MCAST_QUERIER)
  [IFLA_BR_MCAST_HASH_ELASTICITY] = XLAT(IFLA_BR_MCAST_HASH_ELASTICITY),
+ #define XLAT_VAL_26 ((unsigned) (IFLA_BR_MCAST_HASH_ELASTICITY))
+ #define XLAT_STR_26 STRINGIFY(IFLA_BR_MCAST_HASH_ELASTICITY)
  [IFLA_BR_MCAST_HASH_MAX] = XLAT(IFLA_BR_MCAST_HASH_MAX),
+ #define XLAT_VAL_27 ((unsigned) (IFLA_BR_MCAST_HASH_MAX))
+ #define XLAT_STR_27 STRINGIFY(IFLA_BR_MCAST_HASH_MAX)
  [IFLA_BR_MCAST_LAST_MEMBER_CNT] = XLAT(IFLA_BR_MCAST_LAST_MEMBER_CNT),
+ #define XLAT_VAL_28 ((unsigned) (IFLA_BR_MCAST_LAST_MEMBER_CNT))
+ #define XLAT_STR_28 STRINGIFY(IFLA_BR_MCAST_LAST_MEMBER_CNT)
  [IFLA_BR_MCAST_STARTUP_QUERY_CNT] = XLAT(IFLA_BR_MCAST_STARTUP_QUERY_CNT),
+ #define XLAT_VAL_29 ((unsigned) (IFLA_BR_MCAST_STARTUP_QUERY_CNT))
+ #define XLAT_STR_29 STRINGIFY(IFLA_BR_MCAST_STARTUP_QUERY_CNT)
  [IFLA_BR_MCAST_LAST_MEMBER_INTVL] = XLAT(IFLA_BR_MCAST_LAST_MEMBER_INTVL),
+ #define XLAT_VAL_30 ((unsigned) (IFLA_BR_MCAST_LAST_MEMBER_INTVL))
+ #define XLAT_STR_30 STRINGIFY(IFLA_BR_MCAST_LAST_MEMBER_INTVL)
  [IFLA_BR_MCAST_MEMBERSHIP_INTVL] = XLAT(IFLA_BR_MCAST_MEMBERSHIP_INTVL),
+ #define XLAT_VAL_31 ((unsigned) (IFLA_BR_MCAST_MEMBERSHIP_INTVL))
+ #define XLAT_STR_31 STRINGIFY(IFLA_BR_MCAST_MEMBERSHIP_INTVL)
  [IFLA_BR_MCAST_QUERIER_INTVL] = XLAT(IFLA_BR_MCAST_QUERIER_INTVL),
+ #define XLAT_VAL_32 ((unsigned) (IFLA_BR_MCAST_QUERIER_INTVL))
+ #define XLAT_STR_32 STRINGIFY(IFLA_BR_MCAST_QUERIER_INTVL)
  [IFLA_BR_MCAST_QUERY_INTVL] = XLAT(IFLA_BR_MCAST_QUERY_INTVL),
+ #define XLAT_VAL_33 ((unsigned) (IFLA_BR_MCAST_QUERY_INTVL))
+ #define XLAT_STR_33 STRINGIFY(IFLA_BR_MCAST_QUERY_INTVL)
  [IFLA_BR_MCAST_QUERY_RESPONSE_INTVL] = XLAT(IFLA_BR_MCAST_QUERY_RESPONSE_INTVL),
+ #define XLAT_VAL_34 ((unsigned) (IFLA_BR_MCAST_QUERY_RESPONSE_INTVL))
+ #define XLAT_STR_34 STRINGIFY(IFLA_BR_MCAST_QUERY_RESPONSE_INTVL)
  [IFLA_BR_MCAST_STARTUP_QUERY_INTVL] = XLAT(IFLA_BR_MCAST_STARTUP_QUERY_INTVL),
+ #define XLAT_VAL_35 ((unsigned) (IFLA_BR_MCAST_STARTUP_QUERY_INTVL))
+ #define XLAT_STR_35 STRINGIFY(IFLA_BR_MCAST_STARTUP_QUERY_INTVL)
  [IFLA_BR_NF_CALL_IPTABLES] = XLAT(IFLA_BR_NF_CALL_IPTABLES),
+ #define XLAT_VAL_36 ((unsigned) (IFLA_BR_NF_CALL_IPTABLES))
+ #define XLAT_STR_36 STRINGIFY(IFLA_BR_NF_CALL_IPTABLES)
  [IFLA_BR_NF_CALL_IP6TABLES] = XLAT(IFLA_BR_NF_CALL_IP6TABLES),
+ #define XLAT_VAL_37 ((unsigned) (IFLA_BR_NF_CALL_IP6TABLES))
+ #define XLAT_STR_37 STRINGIFY(IFLA_BR_NF_CALL_IP6TABLES)
  [IFLA_BR_NF_CALL_ARPTABLES] = XLAT(IFLA_BR_NF_CALL_ARPTABLES),
+ #define XLAT_VAL_38 ((unsigned) (IFLA_BR_NF_CALL_ARPTABLES))
+ #define XLAT_STR_38 STRINGIFY(IFLA_BR_NF_CALL_ARPTABLES)
  [IFLA_BR_VLAN_DEFAULT_PVID] = XLAT(IFLA_BR_VLAN_DEFAULT_PVID),
+ #define XLAT_VAL_39 ((unsigned) (IFLA_BR_VLAN_DEFAULT_PVID))
+ #define XLAT_STR_39 STRINGIFY(IFLA_BR_VLAN_DEFAULT_PVID)
  [IFLA_BR_PAD] = XLAT(IFLA_BR_PAD),
+ #define XLAT_VAL_40 ((unsigned) (IFLA_BR_PAD))
+ #define XLAT_STR_40 STRINGIFY(IFLA_BR_PAD)
  [IFLA_BR_VLAN_STATS_ENABLED] = XLAT(IFLA_BR_VLAN_STATS_ENABLED),
+ #define XLAT_VAL_41 ((unsigned) (IFLA_BR_VLAN_STATS_ENABLED))
+ #define XLAT_STR_41 STRINGIFY(IFLA_BR_VLAN_STATS_ENABLED)
  [IFLA_BR_MCAST_STATS_ENABLED] = XLAT(IFLA_BR_MCAST_STATS_ENABLED),
+ #define XLAT_VAL_42 ((unsigned) (IFLA_BR_MCAST_STATS_ENABLED))
+ #define XLAT_STR_42 STRINGIFY(IFLA_BR_MCAST_STATS_ENABLED)
  [IFLA_BR_MCAST_IGMP_VERSION] = XLAT(IFLA_BR_MCAST_IGMP_VERSION),
+ #define XLAT_VAL_43 ((unsigned) (IFLA_BR_MCAST_IGMP_VERSION))
+ #define XLAT_STR_43 STRINGIFY(IFLA_BR_MCAST_IGMP_VERSION)
  [IFLA_BR_MCAST_MLD_VERSION] = XLAT(IFLA_BR_MCAST_MLD_VERSION),
+ #define XLAT_VAL_44 ((unsigned) (IFLA_BR_MCAST_MLD_VERSION))
+ #define XLAT_STR_44 STRINGIFY(IFLA_BR_MCAST_MLD_VERSION)
  [IFLA_BR_VLAN_STATS_PER_PORT] = XLAT(IFLA_BR_VLAN_STATS_PER_PORT),
+ #define XLAT_VAL_45 ((unsigned) (IFLA_BR_VLAN_STATS_PER_PORT))
+ #define XLAT_STR_45 STRINGIFY(IFLA_BR_VLAN_STATS_PER_PORT)
  [IFLA_BR_MULTI_BOOLOPT] = XLAT(IFLA_BR_MULTI_BOOLOPT),
+ #define XLAT_VAL_46 ((unsigned) (IFLA_BR_MULTI_BOOLOPT))
+ #define XLAT_STR_46 STRINGIFY(IFLA_BR_MULTI_BOOLOPT)
 };
 static
 const struct xlat rtnl_ifla_info_data_bridge_attrs[1] = { {
  .data = rtnl_ifla_info_data_bridge_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_ifla_info_data_bridge_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_ifla_info_data_tun_attrs.h 5.9-0ubuntu2/xlat/rtnl_ifla_info_data_tun_attrs.h
--- 5.5-3/xlat/rtnl_ifla_info_data_tun_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_ifla_info_data_tun_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -84,23 +84,127 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_ifla_info_data_tun_attrs_xdata[] = {
  [IFLA_TUN_UNSPEC] = XLAT(IFLA_TUN_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (IFLA_TUN_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(IFLA_TUN_UNSPEC)
  [IFLA_TUN_OWNER] = XLAT(IFLA_TUN_OWNER),
+ #define XLAT_VAL_1 ((unsigned) (IFLA_TUN_OWNER))
+ #define XLAT_STR_1 STRINGIFY(IFLA_TUN_OWNER)
  [IFLA_TUN_GROUP] = XLAT(IFLA_TUN_GROUP),
+ #define XLAT_VAL_2 ((unsigned) (IFLA_TUN_GROUP))
+ #define XLAT_STR_2 STRINGIFY(IFLA_TUN_GROUP)
  [IFLA_TUN_TYPE] = XLAT(IFLA_TUN_TYPE),
+ #define XLAT_VAL_3 ((unsigned) (IFLA_TUN_TYPE))
+ #define XLAT_STR_3 STRINGIFY(IFLA_TUN_TYPE)
  [IFLA_TUN_PI] = XLAT(IFLA_TUN_PI),
+ #define XLAT_VAL_4 ((unsigned) (IFLA_TUN_PI))
+ #define XLAT_STR_4 STRINGIFY(IFLA_TUN_PI)
  [IFLA_TUN_VNET_HDR] = XLAT(IFLA_TUN_VNET_HDR),
+ #define XLAT_VAL_5 ((unsigned) (IFLA_TUN_VNET_HDR))
+ #define XLAT_STR_5 STRINGIFY(IFLA_TUN_VNET_HDR)
  [IFLA_TUN_PERSIST] = XLAT(IFLA_TUN_PERSIST),
+ #define XLAT_VAL_6 ((unsigned) (IFLA_TUN_PERSIST))
+ #define XLAT_STR_6 STRINGIFY(IFLA_TUN_PERSIST)
  [IFLA_TUN_MULTI_QUEUE] = XLAT(IFLA_TUN_MULTI_QUEUE),
+ #define XLAT_VAL_7 ((unsigned) (IFLA_TUN_MULTI_QUEUE))
+ #define XLAT_STR_7 STRINGIFY(IFLA_TUN_MULTI_QUEUE)
  [IFLA_TUN_NUM_QUEUES] = XLAT(IFLA_TUN_NUM_QUEUES),
+ #define XLAT_VAL_8 ((unsigned) (IFLA_TUN_NUM_QUEUES))
+ #define XLAT_STR_8 STRINGIFY(IFLA_TUN_NUM_QUEUES)
  [IFLA_TUN_NUM_DISABLED_QUEUES] = XLAT(IFLA_TUN_NUM_DISABLED_QUEUES),
+ #define XLAT_VAL_9 ((unsigned) (IFLA_TUN_NUM_DISABLED_QUEUES))
+ #define XLAT_STR_9 STRINGIFY(IFLA_TUN_NUM_DISABLED_QUEUES)
 };
 static
 const struct xlat rtnl_ifla_info_data_tun_attrs[1] = { {
  .data = rtnl_ifla_info_data_tun_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_ifla_info_data_tun_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_ifla_port_attrs.h 5.9-0ubuntu2/xlat/rtnl_ifla_port_attrs.h
--- 5.5-3/xlat/rtnl_ifla_port_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_ifla_port_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -70,21 +70,105 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_ifla_port_attrs_xdata[] = {
  [IFLA_PORT_UNSPEC] = XLAT(IFLA_PORT_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (IFLA_PORT_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(IFLA_PORT_UNSPEC)
  [IFLA_PORT_VF] = XLAT(IFLA_PORT_VF),
+ #define XLAT_VAL_1 ((unsigned) (IFLA_PORT_VF))
+ #define XLAT_STR_1 STRINGIFY(IFLA_PORT_VF)
  [IFLA_PORT_PROFILE] = XLAT(IFLA_PORT_PROFILE),
+ #define XLAT_VAL_2 ((unsigned) (IFLA_PORT_PROFILE))
+ #define XLAT_STR_2 STRINGIFY(IFLA_PORT_PROFILE)
  [IFLA_PORT_VSI_TYPE] = XLAT(IFLA_PORT_VSI_TYPE),
+ #define XLAT_VAL_3 ((unsigned) (IFLA_PORT_VSI_TYPE))
+ #define XLAT_STR_3 STRINGIFY(IFLA_PORT_VSI_TYPE)
  [IFLA_PORT_INSTANCE_UUID] = XLAT(IFLA_PORT_INSTANCE_UUID),
+ #define XLAT_VAL_4 ((unsigned) (IFLA_PORT_INSTANCE_UUID))
+ #define XLAT_STR_4 STRINGIFY(IFLA_PORT_INSTANCE_UUID)
  [IFLA_PORT_HOST_UUID] = XLAT(IFLA_PORT_HOST_UUID),
+ #define XLAT_VAL_5 ((unsigned) (IFLA_PORT_HOST_UUID))
+ #define XLAT_STR_5 STRINGIFY(IFLA_PORT_HOST_UUID)
  [IFLA_PORT_REQUEST] = XLAT(IFLA_PORT_REQUEST),
+ #define XLAT_VAL_6 ((unsigned) (IFLA_PORT_REQUEST))
+ #define XLAT_STR_6 STRINGIFY(IFLA_PORT_REQUEST)
  [IFLA_PORT_RESPONSE] = XLAT(IFLA_PORT_RESPONSE),
+ #define XLAT_VAL_7 ((unsigned) (IFLA_PORT_RESPONSE))
+ #define XLAT_STR_7 STRINGIFY(IFLA_PORT_RESPONSE)
 };
 static
 const struct xlat rtnl_ifla_port_attrs[1] = { {
  .data = rtnl_ifla_port_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_ifla_port_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_ifla_vf_port_attrs.h 5.9-0ubuntu2/xlat/rtnl_ifla_vf_port_attrs.h
--- 5.5-3/xlat/rtnl_ifla_vf_port_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_ifla_vf_port_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_ifla_vf_port_attrs_xdata[] = {
  [IFLA_VF_PORT_UNSPEC] = XLAT(IFLA_VF_PORT_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (IFLA_VF_PORT_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(IFLA_VF_PORT_UNSPEC)
  [IFLA_VF_PORT] = XLAT(IFLA_VF_PORT),
+ #define XLAT_VAL_1 ((unsigned) (IFLA_VF_PORT))
+ #define XLAT_STR_1 STRINGIFY(IFLA_VF_PORT)
 };
 static
 const struct xlat rtnl_ifla_vf_port_attrs[1] = { {
  .data = rtnl_ifla_vf_port_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_ifla_vf_port_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_ifla_xdp_attached_mode.h 5.9-0ubuntu2/xlat/rtnl_ifla_xdp_attached_mode.h
--- 5.5-3/xlat/rtnl_ifla_xdp_attached_mode.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_ifla_xdp_attached_mode.h	2020-09-24 09:18:45.000000000 +0000
@@ -49,18 +49,72 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_ifla_xdp_attached_mode_xdata[] = {
  [XDP_ATTACHED_NONE] = XLAT(XDP_ATTACHED_NONE),
+ #define XLAT_VAL_0 ((unsigned) (XDP_ATTACHED_NONE))
+ #define XLAT_STR_0 STRINGIFY(XDP_ATTACHED_NONE)
  [XDP_ATTACHED_DRV] = XLAT(XDP_ATTACHED_DRV),
+ #define XLAT_VAL_1 ((unsigned) (XDP_ATTACHED_DRV))
+ #define XLAT_STR_1 STRINGIFY(XDP_ATTACHED_DRV)
  [XDP_ATTACHED_SKB] = XLAT(XDP_ATTACHED_SKB),
+ #define XLAT_VAL_2 ((unsigned) (XDP_ATTACHED_SKB))
+ #define XLAT_STR_2 STRINGIFY(XDP_ATTACHED_SKB)
  [XDP_ATTACHED_HW] = XLAT(XDP_ATTACHED_HW),
+ #define XLAT_VAL_3 ((unsigned) (XDP_ATTACHED_HW))
+ #define XLAT_STR_3 STRINGIFY(XDP_ATTACHED_HW)
  [XDP_ATTACHED_MULTI] = XLAT(XDP_ATTACHED_MULTI),
+ #define XLAT_VAL_4 ((unsigned) (XDP_ATTACHED_MULTI))
+ #define XLAT_STR_4 STRINGIFY(XDP_ATTACHED_MULTI)
 };
 static
 const struct xlat rtnl_ifla_xdp_attached_mode[1] = { {
  .data = rtnl_ifla_xdp_attached_mode_xdata,
  .size = ARRAY_SIZE(rtnl_ifla_xdp_attached_mode_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_ifla_xdp_attached_mode.in 5.9-0ubuntu2/xlat/rtnl_ifla_xdp_attached_mode.in
--- 5.5-3/xlat/rtnl_ifla_xdp_attached_mode.in	2018-08-27 23:41:41.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_ifla_xdp_attached_mode.in	2020-05-30 08:00:00.000000000 +0000
@@ -1,4 +1,7 @@
 #value_indexed
+#enum
+#include <netinet/in.h>
+#include <linux/rtnetlink.h>
 XDP_ATTACHED_NONE	0
 XDP_ATTACHED_DRV	1
 XDP_ATTACHED_SKB	2
diff -pruN 5.5-3/xlat/rtnl_ifla_xdp_attached_mode.m4 5.9-0ubuntu2/xlat/rtnl_ifla_xdp_attached_mode.m4
--- 5.5-3/xlat/rtnl_ifla_xdp_attached_mode.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_ifla_xdp_attached_mode.m4	2020-09-24 09:18:45.000000000 +0000
@@ -0,0 +1,12 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/rtnl_ifla_xdp_attached_mode.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_rtnl_ifla_xdp_attached_mode],[
+AC_CHECK_DECLS(m4_normalize([
+XDP_ATTACHED_NONE,
+XDP_ATTACHED_DRV,
+XDP_ATTACHED_SKB,
+XDP_ATTACHED_HW,
+XDP_ATTACHED_MULTI
+]),,, [
+#include <netinet/in.h>
+#include <linux/rtnetlink.h>
+])])])
diff -pruN 5.5-3/xlat/rtnl_ifla_xdp_attrs.h 5.9-0ubuntu2/xlat/rtnl_ifla_xdp_attrs.h
--- 5.5-3/xlat/rtnl_ifla_xdp_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_ifla_xdp_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -59,6 +59,13 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define IFLA_XDP_HW_PROG_ID 7
 #endif
+#if defined(IFLA_XDP_EXPECTED_FD) || (defined(HAVE_DECL_IFLA_XDP_EXPECTED_FD) && HAVE_DECL_IFLA_XDP_EXPECTED_FD)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IFLA_XDP_EXPECTED_FD) == (8), "IFLA_XDP_EXPECTED_FD != 8");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IFLA_XDP_EXPECTED_FD 8
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -70,21 +77,116 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_ifla_xdp_attrs_xdata[] = {
  [IFLA_XDP_UNSPEC] = XLAT(IFLA_XDP_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (IFLA_XDP_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(IFLA_XDP_UNSPEC)
  [IFLA_XDP_FD] = XLAT(IFLA_XDP_FD),
+ #define XLAT_VAL_1 ((unsigned) (IFLA_XDP_FD))
+ #define XLAT_STR_1 STRINGIFY(IFLA_XDP_FD)
  [IFLA_XDP_ATTACHED] = XLAT(IFLA_XDP_ATTACHED),
+ #define XLAT_VAL_2 ((unsigned) (IFLA_XDP_ATTACHED))
+ #define XLAT_STR_2 STRINGIFY(IFLA_XDP_ATTACHED)
  [IFLA_XDP_FLAGS] = XLAT(IFLA_XDP_FLAGS),
+ #define XLAT_VAL_3 ((unsigned) (IFLA_XDP_FLAGS))
+ #define XLAT_STR_3 STRINGIFY(IFLA_XDP_FLAGS)
  [IFLA_XDP_PROG_ID] = XLAT(IFLA_XDP_PROG_ID),
+ #define XLAT_VAL_4 ((unsigned) (IFLA_XDP_PROG_ID))
+ #define XLAT_STR_4 STRINGIFY(IFLA_XDP_PROG_ID)
  [IFLA_XDP_DRV_PROG_ID] = XLAT(IFLA_XDP_DRV_PROG_ID),
+ #define XLAT_VAL_5 ((unsigned) (IFLA_XDP_DRV_PROG_ID))
+ #define XLAT_STR_5 STRINGIFY(IFLA_XDP_DRV_PROG_ID)
  [IFLA_XDP_SKB_PROG_ID] = XLAT(IFLA_XDP_SKB_PROG_ID),
+ #define XLAT_VAL_6 ((unsigned) (IFLA_XDP_SKB_PROG_ID))
+ #define XLAT_STR_6 STRINGIFY(IFLA_XDP_SKB_PROG_ID)
  [IFLA_XDP_HW_PROG_ID] = XLAT(IFLA_XDP_HW_PROG_ID),
+ #define XLAT_VAL_7 ((unsigned) (IFLA_XDP_HW_PROG_ID))
+ #define XLAT_STR_7 STRINGIFY(IFLA_XDP_HW_PROG_ID)
+ [IFLA_XDP_EXPECTED_FD] = XLAT(IFLA_XDP_EXPECTED_FD),
+ #define XLAT_VAL_8 ((unsigned) (IFLA_XDP_EXPECTED_FD))
+ #define XLAT_STR_8 STRINGIFY(IFLA_XDP_EXPECTED_FD)
 };
 static
 const struct xlat rtnl_ifla_xdp_attrs[1] = { {
  .data = rtnl_ifla_xdp_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_ifla_xdp_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_ifla_xdp_attrs.in 5.9-0ubuntu2/xlat/rtnl_ifla_xdp_attrs.in
--- 5.5-3/xlat/rtnl_ifla_xdp_attrs.in	2019-08-14 19:05:08.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_ifla_xdp_attrs.in	2020-05-30 08:00:00.000000000 +0000
@@ -1,4 +1,7 @@
 #value_indexed
+#enum
+#include <netinet/in.h>
+#include <linux/rtnetlink.h>
 IFLA_XDP_UNSPEC		0
 IFLA_XDP_FD		1
 IFLA_XDP_ATTACHED	2
@@ -7,3 +10,4 @@ IFLA_XDP_PROG_ID	4
 IFLA_XDP_DRV_PROG_ID	5
 IFLA_XDP_SKB_PROG_ID	6
 IFLA_XDP_HW_PROG_ID	7
+IFLA_XDP_EXPECTED_FD	8
diff -pruN 5.5-3/xlat/rtnl_ifla_xdp_attrs.m4 5.9-0ubuntu2/xlat/rtnl_ifla_xdp_attrs.m4
--- 5.5-3/xlat/rtnl_ifla_xdp_attrs.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_ifla_xdp_attrs.m4	2020-09-24 09:18:45.000000000 +0000
@@ -0,0 +1,16 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/rtnl_ifla_xdp_attrs.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_rtnl_ifla_xdp_attrs],[
+AC_CHECK_DECLS(m4_normalize([
+IFLA_XDP_UNSPEC,
+IFLA_XDP_FD,
+IFLA_XDP_ATTACHED,
+IFLA_XDP_FLAGS,
+IFLA_XDP_PROG_ID,
+IFLA_XDP_DRV_PROG_ID,
+IFLA_XDP_SKB_PROG_ID,
+IFLA_XDP_HW_PROG_ID,
+IFLA_XDP_EXPECTED_FD
+]),,, [
+#include <netinet/in.h>
+#include <linux/rtnetlink.h>
+])])])
diff -pruN 5.5-3/xlat/rtnl_link_attrs.h 5.9-0ubuntu2/xlat/rtnl_link_attrs.h
--- 5.5-3/xlat/rtnl_link_attrs.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_link_attrs.h	2020-09-24 09:18:46.000000000 +0000
@@ -367,6 +367,34 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define IFLA_MAX_MTU 51
 #endif
+#if defined(IFLA_PROP_LIST) || (defined(HAVE_DECL_IFLA_PROP_LIST) && HAVE_DECL_IFLA_PROP_LIST)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IFLA_PROP_LIST) == (52), "IFLA_PROP_LIST != 52");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IFLA_PROP_LIST 52
+#endif
+#if defined(IFLA_ALT_IFNAME) || (defined(HAVE_DECL_IFLA_ALT_IFNAME) && HAVE_DECL_IFLA_ALT_IFNAME)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IFLA_ALT_IFNAME) == (53), "IFLA_ALT_IFNAME != 53");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IFLA_ALT_IFNAME 53
+#endif
+#if defined(IFLA_PERM_ADDRESS) || (defined(HAVE_DECL_IFLA_PERM_ADDRESS) && HAVE_DECL_IFLA_PERM_ADDRESS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IFLA_PERM_ADDRESS) == (54), "IFLA_PERM_ADDRESS != 54");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IFLA_PERM_ADDRESS 54
+#endif
+#if defined(IFLA_PROTO_DOWN_REASON) || (defined(HAVE_DECL_IFLA_PROTO_DOWN_REASON) && HAVE_DECL_IFLA_PROTO_DOWN_REASON)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IFLA_PROTO_DOWN_REASON) == (55), "IFLA_PROTO_DOWN_REASON != 55");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IFLA_PROTO_DOWN_REASON 55
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -378,65 +406,633 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_link_attrs_xdata[] = {
  [IFLA_UNSPEC] = XLAT(IFLA_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (IFLA_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(IFLA_UNSPEC)
  [IFLA_ADDRESS] = XLAT(IFLA_ADDRESS),
+ #define XLAT_VAL_1 ((unsigned) (IFLA_ADDRESS))
+ #define XLAT_STR_1 STRINGIFY(IFLA_ADDRESS)
  [IFLA_BROADCAST] = XLAT(IFLA_BROADCAST),
+ #define XLAT_VAL_2 ((unsigned) (IFLA_BROADCAST))
+ #define XLAT_STR_2 STRINGIFY(IFLA_BROADCAST)
  [IFLA_IFNAME] = XLAT(IFLA_IFNAME),
+ #define XLAT_VAL_3 ((unsigned) (IFLA_IFNAME))
+ #define XLAT_STR_3 STRINGIFY(IFLA_IFNAME)
  [IFLA_MTU] = XLAT(IFLA_MTU),
+ #define XLAT_VAL_4 ((unsigned) (IFLA_MTU))
+ #define XLAT_STR_4 STRINGIFY(IFLA_MTU)
  [IFLA_LINK] = XLAT(IFLA_LINK),
+ #define XLAT_VAL_5 ((unsigned) (IFLA_LINK))
+ #define XLAT_STR_5 STRINGIFY(IFLA_LINK)
  [IFLA_QDISC] = XLAT(IFLA_QDISC),
+ #define XLAT_VAL_6 ((unsigned) (IFLA_QDISC))
+ #define XLAT_STR_6 STRINGIFY(IFLA_QDISC)
  [IFLA_STATS] = XLAT(IFLA_STATS),
+ #define XLAT_VAL_7 ((unsigned) (IFLA_STATS))
+ #define XLAT_STR_7 STRINGIFY(IFLA_STATS)
  [IFLA_COST] = XLAT(IFLA_COST),
+ #define XLAT_VAL_8 ((unsigned) (IFLA_COST))
+ #define XLAT_STR_8 STRINGIFY(IFLA_COST)
  [IFLA_PRIORITY] = XLAT(IFLA_PRIORITY),
+ #define XLAT_VAL_9 ((unsigned) (IFLA_PRIORITY))
+ #define XLAT_STR_9 STRINGIFY(IFLA_PRIORITY)
  [IFLA_MASTER] = XLAT(IFLA_MASTER),
+ #define XLAT_VAL_10 ((unsigned) (IFLA_MASTER))
+ #define XLAT_STR_10 STRINGIFY(IFLA_MASTER)
  [IFLA_WIRELESS] = XLAT(IFLA_WIRELESS),
+ #define XLAT_VAL_11 ((unsigned) (IFLA_WIRELESS))
+ #define XLAT_STR_11 STRINGIFY(IFLA_WIRELESS)
  [IFLA_PROTINFO] = XLAT(IFLA_PROTINFO),
+ #define XLAT_VAL_12 ((unsigned) (IFLA_PROTINFO))
+ #define XLAT_STR_12 STRINGIFY(IFLA_PROTINFO)
  [IFLA_TXQLEN] = XLAT(IFLA_TXQLEN),
+ #define XLAT_VAL_13 ((unsigned) (IFLA_TXQLEN))
+ #define XLAT_STR_13 STRINGIFY(IFLA_TXQLEN)
  [IFLA_MAP] = XLAT(IFLA_MAP),
+ #define XLAT_VAL_14 ((unsigned) (IFLA_MAP))
+ #define XLAT_STR_14 STRINGIFY(IFLA_MAP)
  [IFLA_WEIGHT] = XLAT(IFLA_WEIGHT),
+ #define XLAT_VAL_15 ((unsigned) (IFLA_WEIGHT))
+ #define XLAT_STR_15 STRINGIFY(IFLA_WEIGHT)
  [IFLA_OPERSTATE] = XLAT(IFLA_OPERSTATE),
+ #define XLAT_VAL_16 ((unsigned) (IFLA_OPERSTATE))
+ #define XLAT_STR_16 STRINGIFY(IFLA_OPERSTATE)
  [IFLA_LINKMODE] = XLAT(IFLA_LINKMODE),
+ #define XLAT_VAL_17 ((unsigned) (IFLA_LINKMODE))
+ #define XLAT_STR_17 STRINGIFY(IFLA_LINKMODE)
  [IFLA_LINKINFO] = XLAT(IFLA_LINKINFO),
+ #define XLAT_VAL_18 ((unsigned) (IFLA_LINKINFO))
+ #define XLAT_STR_18 STRINGIFY(IFLA_LINKINFO)
  [IFLA_NET_NS_PID] = XLAT(IFLA_NET_NS_PID),
+ #define XLAT_VAL_19 ((unsigned) (IFLA_NET_NS_PID))
+ #define XLAT_STR_19 STRINGIFY(IFLA_NET_NS_PID)
  [IFLA_IFALIAS] = XLAT(IFLA_IFALIAS),
+ #define XLAT_VAL_20 ((unsigned) (IFLA_IFALIAS))
+ #define XLAT_STR_20 STRINGIFY(IFLA_IFALIAS)
  [IFLA_NUM_VF] = XLAT(IFLA_NUM_VF),
+ #define XLAT_VAL_21 ((unsigned) (IFLA_NUM_VF))
+ #define XLAT_STR_21 STRINGIFY(IFLA_NUM_VF)
  [IFLA_VFINFO_LIST] = XLAT(IFLA_VFINFO_LIST),
+ #define XLAT_VAL_22 ((unsigned) (IFLA_VFINFO_LIST))
+ #define XLAT_STR_22 STRINGIFY(IFLA_VFINFO_LIST)
  [IFLA_STATS64] = XLAT(IFLA_STATS64),
+ #define XLAT_VAL_23 ((unsigned) (IFLA_STATS64))
+ #define XLAT_STR_23 STRINGIFY(IFLA_STATS64)
  [IFLA_VF_PORTS] = XLAT(IFLA_VF_PORTS),
+ #define XLAT_VAL_24 ((unsigned) (IFLA_VF_PORTS))
+ #define XLAT_STR_24 STRINGIFY(IFLA_VF_PORTS)
  [IFLA_PORT_SELF] = XLAT(IFLA_PORT_SELF),
+ #define XLAT_VAL_25 ((unsigned) (IFLA_PORT_SELF))
+ #define XLAT_STR_25 STRINGIFY(IFLA_PORT_SELF)
  [IFLA_AF_SPEC] = XLAT(IFLA_AF_SPEC),
+ #define XLAT_VAL_26 ((unsigned) (IFLA_AF_SPEC))
+ #define XLAT_STR_26 STRINGIFY(IFLA_AF_SPEC)
  [IFLA_GROUP] = XLAT(IFLA_GROUP),
+ #define XLAT_VAL_27 ((unsigned) (IFLA_GROUP))
+ #define XLAT_STR_27 STRINGIFY(IFLA_GROUP)
  [IFLA_NET_NS_FD] = XLAT(IFLA_NET_NS_FD),
+ #define XLAT_VAL_28 ((unsigned) (IFLA_NET_NS_FD))
+ #define XLAT_STR_28 STRINGIFY(IFLA_NET_NS_FD)
  [IFLA_EXT_MASK] = XLAT(IFLA_EXT_MASK),
+ #define XLAT_VAL_29 ((unsigned) (IFLA_EXT_MASK))
+ #define XLAT_STR_29 STRINGIFY(IFLA_EXT_MASK)
  [IFLA_PROMISCUITY] = XLAT(IFLA_PROMISCUITY),
+ #define XLAT_VAL_30 ((unsigned) (IFLA_PROMISCUITY))
+ #define XLAT_STR_30 STRINGIFY(IFLA_PROMISCUITY)
  [IFLA_NUM_TX_QUEUES] = XLAT(IFLA_NUM_TX_QUEUES),
+ #define XLAT_VAL_31 ((unsigned) (IFLA_NUM_TX_QUEUES))
+ #define XLAT_STR_31 STRINGIFY(IFLA_NUM_TX_QUEUES)
  [IFLA_NUM_RX_QUEUES] = XLAT(IFLA_NUM_RX_QUEUES),
+ #define XLAT_VAL_32 ((unsigned) (IFLA_NUM_RX_QUEUES))
+ #define XLAT_STR_32 STRINGIFY(IFLA_NUM_RX_QUEUES)
  [IFLA_CARRIER] = XLAT(IFLA_CARRIER),
+ #define XLAT_VAL_33 ((unsigned) (IFLA_CARRIER))
+ #define XLAT_STR_33 STRINGIFY(IFLA_CARRIER)
  [IFLA_PHYS_PORT_ID] = XLAT(IFLA_PHYS_PORT_ID),
+ #define XLAT_VAL_34 ((unsigned) (IFLA_PHYS_PORT_ID))
+ #define XLAT_STR_34 STRINGIFY(IFLA_PHYS_PORT_ID)
  [IFLA_CARRIER_CHANGES] = XLAT(IFLA_CARRIER_CHANGES),
+ #define XLAT_VAL_35 ((unsigned) (IFLA_CARRIER_CHANGES))
+ #define XLAT_STR_35 STRINGIFY(IFLA_CARRIER_CHANGES)
  [IFLA_PHYS_SWITCH_ID] = XLAT(IFLA_PHYS_SWITCH_ID),
+ #define XLAT_VAL_36 ((unsigned) (IFLA_PHYS_SWITCH_ID))
+ #define XLAT_STR_36 STRINGIFY(IFLA_PHYS_SWITCH_ID)
  [IFLA_LINK_NETNSID] = XLAT(IFLA_LINK_NETNSID),
+ #define XLAT_VAL_37 ((unsigned) (IFLA_LINK_NETNSID))
+ #define XLAT_STR_37 STRINGIFY(IFLA_LINK_NETNSID)
  [IFLA_PHYS_PORT_NAME] = XLAT(IFLA_PHYS_PORT_NAME),
+ #define XLAT_VAL_38 ((unsigned) (IFLA_PHYS_PORT_NAME))
+ #define XLAT_STR_38 STRINGIFY(IFLA_PHYS_PORT_NAME)
  [IFLA_PROTO_DOWN] = XLAT(IFLA_PROTO_DOWN),
+ #define XLAT_VAL_39 ((unsigned) (IFLA_PROTO_DOWN))
+ #define XLAT_STR_39 STRINGIFY(IFLA_PROTO_DOWN)
  [IFLA_GSO_MAX_SEGS] = XLAT(IFLA_GSO_MAX_SEGS),
+ #define XLAT_VAL_40 ((unsigned) (IFLA_GSO_MAX_SEGS))
+ #define XLAT_STR_40 STRINGIFY(IFLA_GSO_MAX_SEGS)
  [IFLA_GSO_MAX_SIZE] = XLAT(IFLA_GSO_MAX_SIZE),
+ #define XLAT_VAL_41 ((unsigned) (IFLA_GSO_MAX_SIZE))
+ #define XLAT_STR_41 STRINGIFY(IFLA_GSO_MAX_SIZE)
  [IFLA_PAD] = XLAT(IFLA_PAD),
+ #define XLAT_VAL_42 ((unsigned) (IFLA_PAD))
+ #define XLAT_STR_42 STRINGIFY(IFLA_PAD)
  [IFLA_XDP] = XLAT(IFLA_XDP),
+ #define XLAT_VAL_43 ((unsigned) (IFLA_XDP))
+ #define XLAT_STR_43 STRINGIFY(IFLA_XDP)
  [IFLA_EVENT] = XLAT(IFLA_EVENT),
+ #define XLAT_VAL_44 ((unsigned) (IFLA_EVENT))
+ #define XLAT_STR_44 STRINGIFY(IFLA_EVENT)
  [IFLA_NEW_NETNSID] = XLAT(IFLA_NEW_NETNSID),
+ #define XLAT_VAL_45 ((unsigned) (IFLA_NEW_NETNSID))
+ #define XLAT_STR_45 STRINGIFY(IFLA_NEW_NETNSID)
  [IFLA_IF_NETNSID] = XLAT(IFLA_IF_NETNSID),
+ #define XLAT_VAL_46 ((unsigned) (IFLA_IF_NETNSID))
+ #define XLAT_STR_46 STRINGIFY(IFLA_IF_NETNSID)
  [IFLA_CARRIER_UP_COUNT] = XLAT(IFLA_CARRIER_UP_COUNT),
+ #define XLAT_VAL_47 ((unsigned) (IFLA_CARRIER_UP_COUNT))
+ #define XLAT_STR_47 STRINGIFY(IFLA_CARRIER_UP_COUNT)
  [IFLA_CARRIER_DOWN_COUNT] = XLAT(IFLA_CARRIER_DOWN_COUNT),
+ #define XLAT_VAL_48 ((unsigned) (IFLA_CARRIER_DOWN_COUNT))
+ #define XLAT_STR_48 STRINGIFY(IFLA_CARRIER_DOWN_COUNT)
  [IFLA_NEW_IFINDEX] = XLAT(IFLA_NEW_IFINDEX),
+ #define XLAT_VAL_49 ((unsigned) (IFLA_NEW_IFINDEX))
+ #define XLAT_STR_49 STRINGIFY(IFLA_NEW_IFINDEX)
  [IFLA_MIN_MTU] = XLAT(IFLA_MIN_MTU),
+ #define XLAT_VAL_50 ((unsigned) (IFLA_MIN_MTU))
+ #define XLAT_STR_50 STRINGIFY(IFLA_MIN_MTU)
  [IFLA_MAX_MTU] = XLAT(IFLA_MAX_MTU),
+ #define XLAT_VAL_51 ((unsigned) (IFLA_MAX_MTU))
+ #define XLAT_STR_51 STRINGIFY(IFLA_MAX_MTU)
+ [IFLA_PROP_LIST] = XLAT(IFLA_PROP_LIST),
+ #define XLAT_VAL_52 ((unsigned) (IFLA_PROP_LIST))
+ #define XLAT_STR_52 STRINGIFY(IFLA_PROP_LIST)
+ [IFLA_ALT_IFNAME] = XLAT(IFLA_ALT_IFNAME),
+ #define XLAT_VAL_53 ((unsigned) (IFLA_ALT_IFNAME))
+ #define XLAT_STR_53 STRINGIFY(IFLA_ALT_IFNAME)
+ [IFLA_PERM_ADDRESS] = XLAT(IFLA_PERM_ADDRESS),
+ #define XLAT_VAL_54 ((unsigned) (IFLA_PERM_ADDRESS))
+ #define XLAT_STR_54 STRINGIFY(IFLA_PERM_ADDRESS)
+ [IFLA_PROTO_DOWN_REASON] = XLAT(IFLA_PROTO_DOWN_REASON),
+ #define XLAT_VAL_55 ((unsigned) (IFLA_PROTO_DOWN_REASON))
+ #define XLAT_STR_55 STRINGIFY(IFLA_PROTO_DOWN_REASON)
 };
 static
 const struct xlat rtnl_link_attrs[1] = { {
  .data = rtnl_link_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_link_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+#  ifdef XLAT_VAL_47
+  | XLAT_VAL_47
+#  endif
+#  ifdef XLAT_VAL_48
+  | XLAT_VAL_48
+#  endif
+#  ifdef XLAT_VAL_49
+  | XLAT_VAL_49
+#  endif
+#  ifdef XLAT_VAL_50
+  | XLAT_VAL_50
+#  endif
+#  ifdef XLAT_VAL_51
+  | XLAT_VAL_51
+#  endif
+#  ifdef XLAT_VAL_52
+  | XLAT_VAL_52
+#  endif
+#  ifdef XLAT_VAL_53
+  | XLAT_VAL_53
+#  endif
+#  ifdef XLAT_VAL_54
+  | XLAT_VAL_54
+#  endif
+#  ifdef XLAT_VAL_55
+  | XLAT_VAL_55
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+#  ifdef XLAT_STR_47
+  + sizeof(XLAT_STR_47)
+#  endif
+#  ifdef XLAT_STR_48
+  + sizeof(XLAT_STR_48)
+#  endif
+#  ifdef XLAT_STR_49
+  + sizeof(XLAT_STR_49)
+#  endif
+#  ifdef XLAT_STR_50
+  + sizeof(XLAT_STR_50)
+#  endif
+#  ifdef XLAT_STR_51
+  + sizeof(XLAT_STR_51)
+#  endif
+#  ifdef XLAT_STR_52
+  + sizeof(XLAT_STR_52)
+#  endif
+#  ifdef XLAT_STR_53
+  + sizeof(XLAT_STR_53)
+#  endif
+#  ifdef XLAT_STR_54
+  + sizeof(XLAT_STR_54)
+#  endif
+#  ifdef XLAT_STR_55
+  + sizeof(XLAT_STR_55)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
+#  undef XLAT_STR_47
+#  undef XLAT_VAL_47
+#  undef XLAT_STR_48
+#  undef XLAT_VAL_48
+#  undef XLAT_STR_49
+#  undef XLAT_VAL_49
+#  undef XLAT_STR_50
+#  undef XLAT_VAL_50
+#  undef XLAT_STR_51
+#  undef XLAT_VAL_51
+#  undef XLAT_STR_52
+#  undef XLAT_VAL_52
+#  undef XLAT_STR_53
+#  undef XLAT_VAL_53
+#  undef XLAT_STR_54
+#  undef XLAT_VAL_54
+#  undef XLAT_STR_55
+#  undef XLAT_VAL_55
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_link_attrs.in 5.9-0ubuntu2/xlat/rtnl_link_attrs.in
--- 5.5-3/xlat/rtnl_link_attrs.in	2019-08-14 19:05:08.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_link_attrs.in	2020-09-06 08:00:00.000000000 +0000
@@ -1,4 +1,7 @@
 #value_indexed
+#enum
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
 IFLA_UNSPEC		0
 IFLA_ADDRESS		1
 IFLA_BROADCAST		2
@@ -51,3 +54,7 @@ IFLA_CARRIER_DOWN_COUNT	48
 IFLA_NEW_IFINDEX	49
 IFLA_MIN_MTU		50
 IFLA_MAX_MTU		51
+IFLA_PROP_LIST		52
+IFLA_ALT_IFNAME		53
+IFLA_PERM_ADDRESS	54
+IFLA_PROTO_DOWN_REASON	55
diff -pruN 5.5-3/xlat/rtnl_link_attrs.m4 5.9-0ubuntu2/xlat/rtnl_link_attrs.m4
--- 5.5-3/xlat/rtnl_link_attrs.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_link_attrs.m4	2020-09-24 09:18:45.000000000 +0000
@@ -0,0 +1,63 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/rtnl_link_attrs.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_rtnl_link_attrs],[
+AC_CHECK_DECLS(m4_normalize([
+IFLA_UNSPEC,
+IFLA_ADDRESS,
+IFLA_BROADCAST,
+IFLA_IFNAME,
+IFLA_MTU,
+IFLA_LINK,
+IFLA_QDISC,
+IFLA_STATS,
+IFLA_COST,
+IFLA_PRIORITY,
+IFLA_MASTER,
+IFLA_WIRELESS,
+IFLA_PROTINFO,
+IFLA_TXQLEN,
+IFLA_MAP,
+IFLA_WEIGHT,
+IFLA_OPERSTATE,
+IFLA_LINKMODE,
+IFLA_LINKINFO,
+IFLA_NET_NS_PID,
+IFLA_IFALIAS,
+IFLA_NUM_VF,
+IFLA_VFINFO_LIST,
+IFLA_STATS64,
+IFLA_VF_PORTS,
+IFLA_PORT_SELF,
+IFLA_AF_SPEC,
+IFLA_GROUP,
+IFLA_NET_NS_FD,
+IFLA_EXT_MASK,
+IFLA_PROMISCUITY,
+IFLA_NUM_TX_QUEUES,
+IFLA_NUM_RX_QUEUES,
+IFLA_CARRIER,
+IFLA_PHYS_PORT_ID,
+IFLA_CARRIER_CHANGES,
+IFLA_PHYS_SWITCH_ID,
+IFLA_LINK_NETNSID,
+IFLA_PHYS_PORT_NAME,
+IFLA_PROTO_DOWN,
+IFLA_GSO_MAX_SEGS,
+IFLA_GSO_MAX_SIZE,
+IFLA_PAD,
+IFLA_XDP,
+IFLA_EVENT,
+IFLA_NEW_NETNSID,
+IFLA_IF_NETNSID,
+IFLA_CARRIER_UP_COUNT,
+IFLA_CARRIER_DOWN_COUNT,
+IFLA_NEW_IFINDEX,
+IFLA_MIN_MTU,
+IFLA_MAX_MTU,
+IFLA_PROP_LIST,
+IFLA_ALT_IFNAME,
+IFLA_PERM_ADDRESS,
+IFLA_PROTO_DOWN_REASON
+]),,, [
+#include <sys/socket.h>
+#include <linux/rtnetlink.h>
+])])])
diff -pruN 5.5-3/xlat/rtnl_mdba_mdb_attrs.h 5.9-0ubuntu2/xlat/rtnl_mdba_mdb_attrs.h
--- 5.5-3/xlat/rtnl_mdba_mdb_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_mdba_mdb_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_mdba_mdb_attrs_xdata[] = {
  [MDBA_MDB_UNSPEC] = XLAT(MDBA_MDB_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (MDBA_MDB_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(MDBA_MDB_UNSPEC)
  [MDBA_MDB_ENTRY] = XLAT(MDBA_MDB_ENTRY),
+ #define XLAT_VAL_1 ((unsigned) (MDBA_MDB_ENTRY))
+ #define XLAT_STR_1 STRINGIFY(MDBA_MDB_ENTRY)
 };
 static
 const struct xlat rtnl_mdba_mdb_attrs[1] = { {
  .data = rtnl_mdba_mdb_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_mdba_mdb_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_mdba_mdb_eattr_attrs.h 5.9-0ubuntu2/xlat/rtnl_mdba_mdb_eattr_attrs.h
--- 5.5-3/xlat/rtnl_mdba_mdb_eattr_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_mdba_mdb_eattr_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_mdba_mdb_eattr_attrs_xdata[] = {
  [MDBA_MDB_EATTR_UNSPEC] = XLAT(MDBA_MDB_EATTR_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (MDBA_MDB_EATTR_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(MDBA_MDB_EATTR_UNSPEC)
  [MDBA_MDB_EATTR_TIMER] = XLAT(MDBA_MDB_EATTR_TIMER),
+ #define XLAT_VAL_1 ((unsigned) (MDBA_MDB_EATTR_TIMER))
+ #define XLAT_STR_1 STRINGIFY(MDBA_MDB_EATTR_TIMER)
 };
 static
 const struct xlat rtnl_mdba_mdb_eattr_attrs[1] = { {
  .data = rtnl_mdba_mdb_eattr_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_mdba_mdb_eattr_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_mdba_mdb_entry_attrs.h 5.9-0ubuntu2/xlat/rtnl_mdba_mdb_entry_attrs.h
--- 5.5-3/xlat/rtnl_mdba_mdb_entry_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_mdba_mdb_entry_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_mdba_mdb_entry_attrs_xdata[] = {
  [MDBA_MDB_ENTRY_UNSPEC] = XLAT(MDBA_MDB_ENTRY_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (MDBA_MDB_ENTRY_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(MDBA_MDB_ENTRY_UNSPEC)
  [MDBA_MDB_ENTRY_INFO] = XLAT(MDBA_MDB_ENTRY_INFO),
+ #define XLAT_VAL_1 ((unsigned) (MDBA_MDB_ENTRY_INFO))
+ #define XLAT_STR_1 STRINGIFY(MDBA_MDB_ENTRY_INFO)
 };
 static
 const struct xlat rtnl_mdba_mdb_entry_attrs[1] = { {
  .data = rtnl_mdba_mdb_entry_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_mdba_mdb_entry_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_mdba_router_attrs.h 5.9-0ubuntu2/xlat/rtnl_mdba_router_attrs.h
--- 5.5-3/xlat/rtnl_mdba_router_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_mdba_router_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_mdba_router_attrs_xdata[] = {
  [MDBA_ROUTER_UNSPEC] = XLAT(MDBA_ROUTER_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (MDBA_ROUTER_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(MDBA_ROUTER_UNSPEC)
  [MDBA_ROUTER_PORT] = XLAT(MDBA_ROUTER_PORT),
+ #define XLAT_VAL_1 ((unsigned) (MDBA_ROUTER_PORT))
+ #define XLAT_STR_1 STRINGIFY(MDBA_ROUTER_PORT)
 };
 static
 const struct xlat rtnl_mdba_router_attrs[1] = { {
  .data = rtnl_mdba_router_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_mdba_router_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_mdba_router_pattr_attrs.h 5.9-0ubuntu2/xlat/rtnl_mdba_router_pattr_attrs.h
--- 5.5-3/xlat/rtnl_mdba_router_pattr_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_mdba_router_pattr_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_mdba_router_pattr_attrs_xdata[] = {
  [MDBA_ROUTER_PATTR_UNSPEC] = XLAT(MDBA_ROUTER_PATTR_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (MDBA_ROUTER_PATTR_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(MDBA_ROUTER_PATTR_UNSPEC)
  [MDBA_ROUTER_PATTR_TIMER] = XLAT(MDBA_ROUTER_PATTR_TIMER),
+ #define XLAT_VAL_1 ((unsigned) (MDBA_ROUTER_PATTR_TIMER))
+ #define XLAT_STR_1 STRINGIFY(MDBA_ROUTER_PATTR_TIMER)
  [MDBA_ROUTER_PATTR_TYPE] = XLAT(MDBA_ROUTER_PATTR_TYPE),
+ #define XLAT_VAL_2 ((unsigned) (MDBA_ROUTER_PATTR_TYPE))
+ #define XLAT_STR_2 STRINGIFY(MDBA_ROUTER_PATTR_TYPE)
 };
 static
 const struct xlat rtnl_mdba_router_pattr_attrs[1] = { {
  .data = rtnl_mdba_router_pattr_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_mdba_router_pattr_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_mdb_attrs.h 5.9-0ubuntu2/xlat/rtnl_mdb_attrs.h
--- 5.5-3/xlat/rtnl_mdb_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_mdb_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_mdb_attrs_xdata[] = {
  [MDBA_UNSPEC] = XLAT(MDBA_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (MDBA_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(MDBA_UNSPEC)
  [MDBA_MDB] = XLAT(MDBA_MDB),
+ #define XLAT_VAL_1 ((unsigned) (MDBA_MDB))
+ #define XLAT_STR_1 STRINGIFY(MDBA_MDB)
  [MDBA_ROUTER] = XLAT(MDBA_ROUTER),
+ #define XLAT_VAL_2 ((unsigned) (MDBA_ROUTER))
+ #define XLAT_STR_2 STRINGIFY(MDBA_ROUTER)
 };
 static
 const struct xlat rtnl_mdb_attrs[1] = { {
  .data = rtnl_mdb_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_mdb_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_neigh_attrs.h 5.9-0ubuntu2/xlat/rtnl_neigh_attrs.h
--- 5.5-3/xlat/rtnl_neigh_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_neigh_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -94,6 +94,20 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define NDA_PROTOCOL 12
 #endif
+#if defined(NDA_NH_ID) || (defined(HAVE_DECL_NDA_NH_ID) && HAVE_DECL_NDA_NH_ID)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((NDA_NH_ID) == (13), "NDA_NH_ID != 13");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define NDA_NH_ID 13
+#endif
+#if defined(NDA_FDB_EXT_ATTRS) || (defined(HAVE_DECL_NDA_FDB_EXT_ATTRS) && HAVE_DECL_NDA_FDB_EXT_ATTRS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((NDA_FDB_EXT_ATTRS) == (14), "NDA_FDB_EXT_ATTRS != 14");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define NDA_FDB_EXT_ATTRS 14
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -105,26 +119,182 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_neigh_attrs_xdata[] = {
  [NDA_UNSPEC] = XLAT(NDA_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (NDA_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(NDA_UNSPEC)
  [NDA_DST] = XLAT(NDA_DST),
+ #define XLAT_VAL_1 ((unsigned) (NDA_DST))
+ #define XLAT_STR_1 STRINGIFY(NDA_DST)
  [NDA_LLADDR] = XLAT(NDA_LLADDR),
+ #define XLAT_VAL_2 ((unsigned) (NDA_LLADDR))
+ #define XLAT_STR_2 STRINGIFY(NDA_LLADDR)
  [NDA_CACHEINFO] = XLAT(NDA_CACHEINFO),
+ #define XLAT_VAL_3 ((unsigned) (NDA_CACHEINFO))
+ #define XLAT_STR_3 STRINGIFY(NDA_CACHEINFO)
  [NDA_PROBES] = XLAT(NDA_PROBES),
+ #define XLAT_VAL_4 ((unsigned) (NDA_PROBES))
+ #define XLAT_STR_4 STRINGIFY(NDA_PROBES)
  [NDA_VLAN] = XLAT(NDA_VLAN),
+ #define XLAT_VAL_5 ((unsigned) (NDA_VLAN))
+ #define XLAT_STR_5 STRINGIFY(NDA_VLAN)
  [NDA_PORT] = XLAT(NDA_PORT),
+ #define XLAT_VAL_6 ((unsigned) (NDA_PORT))
+ #define XLAT_STR_6 STRINGIFY(NDA_PORT)
  [NDA_VNI] = XLAT(NDA_VNI),
+ #define XLAT_VAL_7 ((unsigned) (NDA_VNI))
+ #define XLAT_STR_7 STRINGIFY(NDA_VNI)
  [NDA_IFINDEX] = XLAT(NDA_IFINDEX),
+ #define XLAT_VAL_8 ((unsigned) (NDA_IFINDEX))
+ #define XLAT_STR_8 STRINGIFY(NDA_IFINDEX)
  [NDA_MASTER] = XLAT(NDA_MASTER),
+ #define XLAT_VAL_9 ((unsigned) (NDA_MASTER))
+ #define XLAT_STR_9 STRINGIFY(NDA_MASTER)
  [NDA_LINK_NETNSID] = XLAT(NDA_LINK_NETNSID),
+ #define XLAT_VAL_10 ((unsigned) (NDA_LINK_NETNSID))
+ #define XLAT_STR_10 STRINGIFY(NDA_LINK_NETNSID)
  [NDA_SRC_VNI] = XLAT(NDA_SRC_VNI),
+ #define XLAT_VAL_11 ((unsigned) (NDA_SRC_VNI))
+ #define XLAT_STR_11 STRINGIFY(NDA_SRC_VNI)
  [NDA_PROTOCOL] = XLAT(NDA_PROTOCOL),
+ #define XLAT_VAL_12 ((unsigned) (NDA_PROTOCOL))
+ #define XLAT_STR_12 STRINGIFY(NDA_PROTOCOL)
+ [NDA_NH_ID] = XLAT(NDA_NH_ID),
+ #define XLAT_VAL_13 ((unsigned) (NDA_NH_ID))
+ #define XLAT_STR_13 STRINGIFY(NDA_NH_ID)
+ [NDA_FDB_EXT_ATTRS] = XLAT(NDA_FDB_EXT_ATTRS),
+ #define XLAT_VAL_14 ((unsigned) (NDA_FDB_EXT_ATTRS))
+ #define XLAT_STR_14 STRINGIFY(NDA_FDB_EXT_ATTRS)
 };
 static
 const struct xlat rtnl_neigh_attrs[1] = { {
  .data = rtnl_neigh_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_neigh_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_neigh_attrs.in 5.9-0ubuntu2/xlat/rtnl_neigh_attrs.in
--- 5.5-3/xlat/rtnl_neigh_attrs.in	2019-08-14 19:05:08.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_neigh_attrs.in	2020-09-06 08:00:00.000000000 +0000
@@ -12,3 +12,5 @@ NDA_MASTER		9
 NDA_LINK_NETNSID	10
 NDA_SRC_VNI		11
 NDA_PROTOCOL		12
+NDA_NH_ID		13
+NDA_FDB_EXT_ATTRS	14
diff -pruN 5.5-3/xlat/rtnl_neightbl_attrs.h 5.9-0ubuntu2/xlat/rtnl_neightbl_attrs.h
--- 5.5-3/xlat/rtnl_neightbl_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_neightbl_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -84,23 +84,127 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_neightbl_attrs_xdata[] = {
  [NDTA_UNSPEC] = XLAT(NDTA_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (NDTA_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(NDTA_UNSPEC)
  [NDTA_NAME] = XLAT(NDTA_NAME),
+ #define XLAT_VAL_1 ((unsigned) (NDTA_NAME))
+ #define XLAT_STR_1 STRINGIFY(NDTA_NAME)
  [NDTA_THRESH1] = XLAT(NDTA_THRESH1),
+ #define XLAT_VAL_2 ((unsigned) (NDTA_THRESH1))
+ #define XLAT_STR_2 STRINGIFY(NDTA_THRESH1)
  [NDTA_THRESH2] = XLAT(NDTA_THRESH2),
+ #define XLAT_VAL_3 ((unsigned) (NDTA_THRESH2))
+ #define XLAT_STR_3 STRINGIFY(NDTA_THRESH2)
  [NDTA_THRESH3] = XLAT(NDTA_THRESH3),
+ #define XLAT_VAL_4 ((unsigned) (NDTA_THRESH3))
+ #define XLAT_STR_4 STRINGIFY(NDTA_THRESH3)
  [NDTA_CONFIG] = XLAT(NDTA_CONFIG),
+ #define XLAT_VAL_5 ((unsigned) (NDTA_CONFIG))
+ #define XLAT_STR_5 STRINGIFY(NDTA_CONFIG)
  [NDTA_PARMS] = XLAT(NDTA_PARMS),
+ #define XLAT_VAL_6 ((unsigned) (NDTA_PARMS))
+ #define XLAT_STR_6 STRINGIFY(NDTA_PARMS)
  [NDTA_STATS] = XLAT(NDTA_STATS),
+ #define XLAT_VAL_7 ((unsigned) (NDTA_STATS))
+ #define XLAT_STR_7 STRINGIFY(NDTA_STATS)
  [NDTA_GC_INTERVAL] = XLAT(NDTA_GC_INTERVAL),
+ #define XLAT_VAL_8 ((unsigned) (NDTA_GC_INTERVAL))
+ #define XLAT_STR_8 STRINGIFY(NDTA_GC_INTERVAL)
  [NDTA_PAD] = XLAT(NDTA_PAD),
+ #define XLAT_VAL_9 ((unsigned) (NDTA_PAD))
+ #define XLAT_STR_9 STRINGIFY(NDTA_PAD)
 };
 static
 const struct xlat rtnl_neightbl_attrs[1] = { {
  .data = rtnl_neightbl_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_neightbl_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_neightbl_parms_attrs.h 5.9-0ubuntu2/xlat/rtnl_neightbl_parms_attrs.h
--- 5.5-3/xlat/rtnl_neightbl_parms_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_neightbl_parms_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -147,32 +147,226 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_neightbl_parms_attrs_xdata[] = {
  [NDTPA_UNSPEC] = XLAT(NDTPA_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (NDTPA_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(NDTPA_UNSPEC)
  [NDTPA_IFINDEX] = XLAT(NDTPA_IFINDEX),
+ #define XLAT_VAL_1 ((unsigned) (NDTPA_IFINDEX))
+ #define XLAT_STR_1 STRINGIFY(NDTPA_IFINDEX)
  [NDTPA_REFCNT] = XLAT(NDTPA_REFCNT),
+ #define XLAT_VAL_2 ((unsigned) (NDTPA_REFCNT))
+ #define XLAT_STR_2 STRINGIFY(NDTPA_REFCNT)
  [NDTPA_REACHABLE_TIME] = XLAT(NDTPA_REACHABLE_TIME),
+ #define XLAT_VAL_3 ((unsigned) (NDTPA_REACHABLE_TIME))
+ #define XLAT_STR_3 STRINGIFY(NDTPA_REACHABLE_TIME)
  [NDTPA_BASE_REACHABLE_TIME] = XLAT(NDTPA_BASE_REACHABLE_TIME),
+ #define XLAT_VAL_4 ((unsigned) (NDTPA_BASE_REACHABLE_TIME))
+ #define XLAT_STR_4 STRINGIFY(NDTPA_BASE_REACHABLE_TIME)
  [NDTPA_RETRANS_TIME] = XLAT(NDTPA_RETRANS_TIME),
+ #define XLAT_VAL_5 ((unsigned) (NDTPA_RETRANS_TIME))
+ #define XLAT_STR_5 STRINGIFY(NDTPA_RETRANS_TIME)
  [NDTPA_GC_STALETIME] = XLAT(NDTPA_GC_STALETIME),
+ #define XLAT_VAL_6 ((unsigned) (NDTPA_GC_STALETIME))
+ #define XLAT_STR_6 STRINGIFY(NDTPA_GC_STALETIME)
  [NDTPA_DELAY_PROBE_TIME] = XLAT(NDTPA_DELAY_PROBE_TIME),
+ #define XLAT_VAL_7 ((unsigned) (NDTPA_DELAY_PROBE_TIME))
+ #define XLAT_STR_7 STRINGIFY(NDTPA_DELAY_PROBE_TIME)
  [NDTPA_QUEUE_LEN] = XLAT(NDTPA_QUEUE_LEN),
+ #define XLAT_VAL_8 ((unsigned) (NDTPA_QUEUE_LEN))
+ #define XLAT_STR_8 STRINGIFY(NDTPA_QUEUE_LEN)
  [NDTPA_APP_PROBES] = XLAT(NDTPA_APP_PROBES),
+ #define XLAT_VAL_9 ((unsigned) (NDTPA_APP_PROBES))
+ #define XLAT_STR_9 STRINGIFY(NDTPA_APP_PROBES)
  [NDTPA_UCAST_PROBES] = XLAT(NDTPA_UCAST_PROBES),
+ #define XLAT_VAL_10 ((unsigned) (NDTPA_UCAST_PROBES))
+ #define XLAT_STR_10 STRINGIFY(NDTPA_UCAST_PROBES)
  [NDTPA_MCAST_PROBES] = XLAT(NDTPA_MCAST_PROBES),
+ #define XLAT_VAL_11 ((unsigned) (NDTPA_MCAST_PROBES))
+ #define XLAT_STR_11 STRINGIFY(NDTPA_MCAST_PROBES)
  [NDTPA_ANYCAST_DELAY] = XLAT(NDTPA_ANYCAST_DELAY),
+ #define XLAT_VAL_12 ((unsigned) (NDTPA_ANYCAST_DELAY))
+ #define XLAT_STR_12 STRINGIFY(NDTPA_ANYCAST_DELAY)
  [NDTPA_PROXY_DELAY] = XLAT(NDTPA_PROXY_DELAY),
+ #define XLAT_VAL_13 ((unsigned) (NDTPA_PROXY_DELAY))
+ #define XLAT_STR_13 STRINGIFY(NDTPA_PROXY_DELAY)
  [NDTPA_PROXY_QLEN] = XLAT(NDTPA_PROXY_QLEN),
+ #define XLAT_VAL_14 ((unsigned) (NDTPA_PROXY_QLEN))
+ #define XLAT_STR_14 STRINGIFY(NDTPA_PROXY_QLEN)
  [NDTPA_LOCKTIME] = XLAT(NDTPA_LOCKTIME),
+ #define XLAT_VAL_15 ((unsigned) (NDTPA_LOCKTIME))
+ #define XLAT_STR_15 STRINGIFY(NDTPA_LOCKTIME)
  [NDTPA_QUEUE_LENBYTES] = XLAT(NDTPA_QUEUE_LENBYTES),
+ #define XLAT_VAL_16 ((unsigned) (NDTPA_QUEUE_LENBYTES))
+ #define XLAT_STR_16 STRINGIFY(NDTPA_QUEUE_LENBYTES)
  [NDTPA_MCAST_REPROBES] = XLAT(NDTPA_MCAST_REPROBES),
+ #define XLAT_VAL_17 ((unsigned) (NDTPA_MCAST_REPROBES))
+ #define XLAT_STR_17 STRINGIFY(NDTPA_MCAST_REPROBES)
  [NDTPA_PAD] = XLAT(NDTPA_PAD),
+ #define XLAT_VAL_18 ((unsigned) (NDTPA_PAD))
+ #define XLAT_STR_18 STRINGIFY(NDTPA_PAD)
 };
 static
 const struct xlat rtnl_neightbl_parms_attrs[1] = { {
  .data = rtnl_neightbl_parms_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_neightbl_parms_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_netconf_attrs.h 5.9-0ubuntu2/xlat/rtnl_netconf_attrs.h
--- 5.5-3/xlat/rtnl_netconf_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_netconf_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -77,22 +77,116 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_netconf_attrs_xdata[] = {
  [NETCONFA_UNSPEC] = XLAT(NETCONFA_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (NETCONFA_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(NETCONFA_UNSPEC)
  [NETCONFA_IFINDEX] = XLAT(NETCONFA_IFINDEX),
+ #define XLAT_VAL_1 ((unsigned) (NETCONFA_IFINDEX))
+ #define XLAT_STR_1 STRINGIFY(NETCONFA_IFINDEX)
  [NETCONFA_FORWARDING] = XLAT(NETCONFA_FORWARDING),
+ #define XLAT_VAL_2 ((unsigned) (NETCONFA_FORWARDING))
+ #define XLAT_STR_2 STRINGIFY(NETCONFA_FORWARDING)
  [NETCONFA_RP_FILTER] = XLAT(NETCONFA_RP_FILTER),
+ #define XLAT_VAL_3 ((unsigned) (NETCONFA_RP_FILTER))
+ #define XLAT_STR_3 STRINGIFY(NETCONFA_RP_FILTER)
  [NETCONFA_MC_FORWARDING] = XLAT(NETCONFA_MC_FORWARDING),
+ #define XLAT_VAL_4 ((unsigned) (NETCONFA_MC_FORWARDING))
+ #define XLAT_STR_4 STRINGIFY(NETCONFA_MC_FORWARDING)
  [NETCONFA_PROXY_NEIGH] = XLAT(NETCONFA_PROXY_NEIGH),
+ #define XLAT_VAL_5 ((unsigned) (NETCONFA_PROXY_NEIGH))
+ #define XLAT_STR_5 STRINGIFY(NETCONFA_PROXY_NEIGH)
  [NETCONFA_IGNORE_ROUTES_WITH_LINKDOWN] = XLAT(NETCONFA_IGNORE_ROUTES_WITH_LINKDOWN),
+ #define XLAT_VAL_6 ((unsigned) (NETCONFA_IGNORE_ROUTES_WITH_LINKDOWN))
+ #define XLAT_STR_6 STRINGIFY(NETCONFA_IGNORE_ROUTES_WITH_LINKDOWN)
  [NETCONFA_INPUT] = XLAT(NETCONFA_INPUT),
+ #define XLAT_VAL_7 ((unsigned) (NETCONFA_INPUT))
+ #define XLAT_STR_7 STRINGIFY(NETCONFA_INPUT)
  [NETCONFA_BC_FORWARDING] = XLAT(NETCONFA_BC_FORWARDING),
+ #define XLAT_VAL_8 ((unsigned) (NETCONFA_BC_FORWARDING))
+ #define XLAT_STR_8 STRINGIFY(NETCONFA_BC_FORWARDING)
 };
 static
 const struct xlat rtnl_netconf_attrs[1] = { {
  .data = rtnl_netconf_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_netconf_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_nsid_attrs.h 5.9-0ubuntu2/xlat/rtnl_nsid_attrs.h
--- 5.5-3/xlat/rtnl_nsid_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_nsid_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -63,20 +63,94 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_nsid_attrs_xdata[] = {
  XLAT(NETNSA_NSID_NOT_ASSIGNED),
+ #define XLAT_VAL_0 ((unsigned) (NETNSA_NSID_NOT_ASSIGNED))
+ #define XLAT_STR_0 STRINGIFY(NETNSA_NSID_NOT_ASSIGNED)
  XLAT(NETNSA_NONE),
+ #define XLAT_VAL_1 ((unsigned) (NETNSA_NONE))
+ #define XLAT_STR_1 STRINGIFY(NETNSA_NONE)
  XLAT(NETNSA_NSID),
+ #define XLAT_VAL_2 ((unsigned) (NETNSA_NSID))
+ #define XLAT_STR_2 STRINGIFY(NETNSA_NSID)
  XLAT(NETNSA_PID),
+ #define XLAT_VAL_3 ((unsigned) (NETNSA_PID))
+ #define XLAT_STR_3 STRINGIFY(NETNSA_PID)
  XLAT(NETNSA_FD),
+ #define XLAT_VAL_4 ((unsigned) (NETNSA_FD))
+ #define XLAT_STR_4 STRINGIFY(NETNSA_FD)
  XLAT(NETNSA_TARGET_NSID),
+ #define XLAT_VAL_5 ((unsigned) (NETNSA_TARGET_NSID))
+ #define XLAT_STR_5 STRINGIFY(NETNSA_TARGET_NSID)
  XLAT(NETNSA_CURRENT_NSID),
+ #define XLAT_VAL_6 ((unsigned) (NETNSA_CURRENT_NSID))
+ #define XLAT_STR_6 STRINGIFY(NETNSA_CURRENT_NSID)
 };
 static
 const struct xlat rtnl_nsid_attrs[1] = { {
  .data = rtnl_nsid_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_nsid_attrs_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_route_attrs.h 5.9-0ubuntu2/xlat/rtnl_route_attrs.h
--- 5.5-3/xlat/rtnl_route_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_route_attrs.h	2020-09-24 09:18:46.000000000 +0000
@@ -224,43 +224,347 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_route_attrs_xdata[] = {
  [RTA_UNSPEC] = XLAT(RTA_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (RTA_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(RTA_UNSPEC)
  [RTA_DST] = XLAT(RTA_DST),
+ #define XLAT_VAL_1 ((unsigned) (RTA_DST))
+ #define XLAT_STR_1 STRINGIFY(RTA_DST)
  [RTA_SRC] = XLAT(RTA_SRC),
+ #define XLAT_VAL_2 ((unsigned) (RTA_SRC))
+ #define XLAT_STR_2 STRINGIFY(RTA_SRC)
  [RTA_IIF] = XLAT(RTA_IIF),
+ #define XLAT_VAL_3 ((unsigned) (RTA_IIF))
+ #define XLAT_STR_3 STRINGIFY(RTA_IIF)
  [RTA_OIF] = XLAT(RTA_OIF),
+ #define XLAT_VAL_4 ((unsigned) (RTA_OIF))
+ #define XLAT_STR_4 STRINGIFY(RTA_OIF)
  [RTA_GATEWAY] = XLAT(RTA_GATEWAY),
+ #define XLAT_VAL_5 ((unsigned) (RTA_GATEWAY))
+ #define XLAT_STR_5 STRINGIFY(RTA_GATEWAY)
  [RTA_PRIORITY] = XLAT(RTA_PRIORITY),
+ #define XLAT_VAL_6 ((unsigned) (RTA_PRIORITY))
+ #define XLAT_STR_6 STRINGIFY(RTA_PRIORITY)
  [RTA_PREFSRC] = XLAT(RTA_PREFSRC),
+ #define XLAT_VAL_7 ((unsigned) (RTA_PREFSRC))
+ #define XLAT_STR_7 STRINGIFY(RTA_PREFSRC)
  [RTA_METRICS] = XLAT(RTA_METRICS),
+ #define XLAT_VAL_8 ((unsigned) (RTA_METRICS))
+ #define XLAT_STR_8 STRINGIFY(RTA_METRICS)
  [RTA_MULTIPATH] = XLAT(RTA_MULTIPATH),
+ #define XLAT_VAL_9 ((unsigned) (RTA_MULTIPATH))
+ #define XLAT_STR_9 STRINGIFY(RTA_MULTIPATH)
  [RTA_PROTOINFO] = XLAT(RTA_PROTOINFO),
+ #define XLAT_VAL_10 ((unsigned) (RTA_PROTOINFO))
+ #define XLAT_STR_10 STRINGIFY(RTA_PROTOINFO)
  [RTA_FLOW] = XLAT(RTA_FLOW),
+ #define XLAT_VAL_11 ((unsigned) (RTA_FLOW))
+ #define XLAT_STR_11 STRINGIFY(RTA_FLOW)
  [RTA_CACHEINFO] = XLAT(RTA_CACHEINFO),
+ #define XLAT_VAL_12 ((unsigned) (RTA_CACHEINFO))
+ #define XLAT_STR_12 STRINGIFY(RTA_CACHEINFO)
  [RTA_SESSION] = XLAT(RTA_SESSION),
+ #define XLAT_VAL_13 ((unsigned) (RTA_SESSION))
+ #define XLAT_STR_13 STRINGIFY(RTA_SESSION)
  [RTA_MP_ALGO] = XLAT(RTA_MP_ALGO),
+ #define XLAT_VAL_14 ((unsigned) (RTA_MP_ALGO))
+ #define XLAT_STR_14 STRINGIFY(RTA_MP_ALGO)
  [RTA_TABLE] = XLAT(RTA_TABLE),
+ #define XLAT_VAL_15 ((unsigned) (RTA_TABLE))
+ #define XLAT_STR_15 STRINGIFY(RTA_TABLE)
  [RTA_MARK] = XLAT(RTA_MARK),
+ #define XLAT_VAL_16 ((unsigned) (RTA_MARK))
+ #define XLAT_STR_16 STRINGIFY(RTA_MARK)
  [RTA_MFC_STATS] = XLAT(RTA_MFC_STATS),
+ #define XLAT_VAL_17 ((unsigned) (RTA_MFC_STATS))
+ #define XLAT_STR_17 STRINGIFY(RTA_MFC_STATS)
  [RTA_VIA] = XLAT(RTA_VIA),
+ #define XLAT_VAL_18 ((unsigned) (RTA_VIA))
+ #define XLAT_STR_18 STRINGIFY(RTA_VIA)
  [RTA_NEWDST] = XLAT(RTA_NEWDST),
+ #define XLAT_VAL_19 ((unsigned) (RTA_NEWDST))
+ #define XLAT_STR_19 STRINGIFY(RTA_NEWDST)
  [RTA_PREF] = XLAT(RTA_PREF),
+ #define XLAT_VAL_20 ((unsigned) (RTA_PREF))
+ #define XLAT_STR_20 STRINGIFY(RTA_PREF)
  [RTA_ENCAP_TYPE] = XLAT(RTA_ENCAP_TYPE),
+ #define XLAT_VAL_21 ((unsigned) (RTA_ENCAP_TYPE))
+ #define XLAT_STR_21 STRINGIFY(RTA_ENCAP_TYPE)
  [RTA_ENCAP] = XLAT(RTA_ENCAP),
+ #define XLAT_VAL_22 ((unsigned) (RTA_ENCAP))
+ #define XLAT_STR_22 STRINGIFY(RTA_ENCAP)
  [RTA_EXPIRES] = XLAT(RTA_EXPIRES),
+ #define XLAT_VAL_23 ((unsigned) (RTA_EXPIRES))
+ #define XLAT_STR_23 STRINGIFY(RTA_EXPIRES)
  [RTA_PAD] = XLAT(RTA_PAD),
+ #define XLAT_VAL_24 ((unsigned) (RTA_PAD))
+ #define XLAT_STR_24 STRINGIFY(RTA_PAD)
  [RTA_UID] = XLAT(RTA_UID),
+ #define XLAT_VAL_25 ((unsigned) (RTA_UID))
+ #define XLAT_STR_25 STRINGIFY(RTA_UID)
  [RTA_TTL_PROPAGATE] = XLAT(RTA_TTL_PROPAGATE),
+ #define XLAT_VAL_26 ((unsigned) (RTA_TTL_PROPAGATE))
+ #define XLAT_STR_26 STRINGIFY(RTA_TTL_PROPAGATE)
  [RTA_IP_PROTO] = XLAT(RTA_IP_PROTO),
+ #define XLAT_VAL_27 ((unsigned) (RTA_IP_PROTO))
+ #define XLAT_STR_27 STRINGIFY(RTA_IP_PROTO)
  [RTA_SPORT] = XLAT(RTA_SPORT),
+ #define XLAT_VAL_28 ((unsigned) (RTA_SPORT))
+ #define XLAT_STR_28 STRINGIFY(RTA_SPORT)
  [RTA_DPORT] = XLAT(RTA_DPORT),
+ #define XLAT_VAL_29 ((unsigned) (RTA_DPORT))
+ #define XLAT_STR_29 STRINGIFY(RTA_DPORT)
 };
 static
 const struct xlat rtnl_route_attrs[1] = { {
  .data = rtnl_route_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_route_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_rta_metrics_attrs.h 5.9-0ubuntu2/xlat/rtnl_rta_metrics_attrs.h
--- 5.5-3/xlat/rtnl_rta_metrics_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_rta_metrics_attrs.h	2020-09-24 09:18:46.000000000 +0000
@@ -133,30 +133,204 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_rta_metrics_attrs_xdata[] = {
  [RTAX_UNSPEC] = XLAT(RTAX_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (RTAX_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(RTAX_UNSPEC)
  [RTAX_LOCK] = XLAT(RTAX_LOCK),
+ #define XLAT_VAL_1 ((unsigned) (RTAX_LOCK))
+ #define XLAT_STR_1 STRINGIFY(RTAX_LOCK)
  [RTAX_MTU] = XLAT(RTAX_MTU),
+ #define XLAT_VAL_2 ((unsigned) (RTAX_MTU))
+ #define XLAT_STR_2 STRINGIFY(RTAX_MTU)
  [RTAX_WINDOW] = XLAT(RTAX_WINDOW),
+ #define XLAT_VAL_3 ((unsigned) (RTAX_WINDOW))
+ #define XLAT_STR_3 STRINGIFY(RTAX_WINDOW)
  [RTAX_RTT] = XLAT(RTAX_RTT),
+ #define XLAT_VAL_4 ((unsigned) (RTAX_RTT))
+ #define XLAT_STR_4 STRINGIFY(RTAX_RTT)
  [RTAX_RTTVAR] = XLAT(RTAX_RTTVAR),
+ #define XLAT_VAL_5 ((unsigned) (RTAX_RTTVAR))
+ #define XLAT_STR_5 STRINGIFY(RTAX_RTTVAR)
  [RTAX_SSTHRESH] = XLAT(RTAX_SSTHRESH),
+ #define XLAT_VAL_6 ((unsigned) (RTAX_SSTHRESH))
+ #define XLAT_STR_6 STRINGIFY(RTAX_SSTHRESH)
  [RTAX_CWND] = XLAT(RTAX_CWND),
+ #define XLAT_VAL_7 ((unsigned) (RTAX_CWND))
+ #define XLAT_STR_7 STRINGIFY(RTAX_CWND)
  [RTAX_ADVMSS] = XLAT(RTAX_ADVMSS),
+ #define XLAT_VAL_8 ((unsigned) (RTAX_ADVMSS))
+ #define XLAT_STR_8 STRINGIFY(RTAX_ADVMSS)
  [RTAX_REORDERING] = XLAT(RTAX_REORDERING),
+ #define XLAT_VAL_9 ((unsigned) (RTAX_REORDERING))
+ #define XLAT_STR_9 STRINGIFY(RTAX_REORDERING)
  [RTAX_HOPLIMIT] = XLAT(RTAX_HOPLIMIT),
+ #define XLAT_VAL_10 ((unsigned) (RTAX_HOPLIMIT))
+ #define XLAT_STR_10 STRINGIFY(RTAX_HOPLIMIT)
  [RTAX_INITCWND] = XLAT(RTAX_INITCWND),
+ #define XLAT_VAL_11 ((unsigned) (RTAX_INITCWND))
+ #define XLAT_STR_11 STRINGIFY(RTAX_INITCWND)
  [RTAX_FEATURES] = XLAT(RTAX_FEATURES),
+ #define XLAT_VAL_12 ((unsigned) (RTAX_FEATURES))
+ #define XLAT_STR_12 STRINGIFY(RTAX_FEATURES)
  [RTAX_RTO_MIN] = XLAT(RTAX_RTO_MIN),
+ #define XLAT_VAL_13 ((unsigned) (RTAX_RTO_MIN))
+ #define XLAT_STR_13 STRINGIFY(RTAX_RTO_MIN)
  [RTAX_INITRWND] = XLAT(RTAX_INITRWND),
+ #define XLAT_VAL_14 ((unsigned) (RTAX_INITRWND))
+ #define XLAT_STR_14 STRINGIFY(RTAX_INITRWND)
  [RTAX_QUICKACK] = XLAT(RTAX_QUICKACK),
+ #define XLAT_VAL_15 ((unsigned) (RTAX_QUICKACK))
+ #define XLAT_STR_15 STRINGIFY(RTAX_QUICKACK)
  [RTAX_CC_ALGO] = XLAT(RTAX_CC_ALGO),
+ #define XLAT_VAL_16 ((unsigned) (RTAX_CC_ALGO))
+ #define XLAT_STR_16 STRINGIFY(RTAX_CC_ALGO)
 };
 static
 const struct xlat rtnl_rta_metrics_attrs[1] = { {
  .data = rtnl_rta_metrics_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_rta_metrics_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_rule_attrs.h 5.9-0ubuntu2/xlat/rtnl_rule_attrs.h
--- 5.5-3/xlat/rtnl_rule_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_rule_attrs.h	2020-09-24 09:18:46.000000000 +0000
@@ -189,38 +189,292 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_rule_attrs_xdata[] = {
  [FRA_UNSPEC] = XLAT(FRA_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (FRA_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(FRA_UNSPEC)
  [FRA_DST] = XLAT(FRA_DST),
+ #define XLAT_VAL_1 ((unsigned) (FRA_DST))
+ #define XLAT_STR_1 STRINGIFY(FRA_DST)
  [FRA_SRC] = XLAT(FRA_SRC),
+ #define XLAT_VAL_2 ((unsigned) (FRA_SRC))
+ #define XLAT_STR_2 STRINGIFY(FRA_SRC)
  [FRA_IIFNAME] = XLAT(FRA_IIFNAME),
+ #define XLAT_VAL_3 ((unsigned) (FRA_IIFNAME))
+ #define XLAT_STR_3 STRINGIFY(FRA_IIFNAME)
  [FRA_GOTO] = XLAT(FRA_GOTO),
+ #define XLAT_VAL_4 ((unsigned) (FRA_GOTO))
+ #define XLAT_STR_4 STRINGIFY(FRA_GOTO)
  [FRA_UNUSED2] = XLAT(FRA_UNUSED2),
+ #define XLAT_VAL_5 ((unsigned) (FRA_UNUSED2))
+ #define XLAT_STR_5 STRINGIFY(FRA_UNUSED2)
  [FRA_PRIORITY] = XLAT(FRA_PRIORITY),
+ #define XLAT_VAL_6 ((unsigned) (FRA_PRIORITY))
+ #define XLAT_STR_6 STRINGIFY(FRA_PRIORITY)
  [FRA_UNUSED3] = XLAT(FRA_UNUSED3),
+ #define XLAT_VAL_7 ((unsigned) (FRA_UNUSED3))
+ #define XLAT_STR_7 STRINGIFY(FRA_UNUSED3)
  [FRA_UNUSED4] = XLAT(FRA_UNUSED4),
+ #define XLAT_VAL_8 ((unsigned) (FRA_UNUSED4))
+ #define XLAT_STR_8 STRINGIFY(FRA_UNUSED4)
  [FRA_UNUSED5] = XLAT(FRA_UNUSED5),
+ #define XLAT_VAL_9 ((unsigned) (FRA_UNUSED5))
+ #define XLAT_STR_9 STRINGIFY(FRA_UNUSED5)
  [FRA_FWMARK] = XLAT(FRA_FWMARK),
+ #define XLAT_VAL_10 ((unsigned) (FRA_FWMARK))
+ #define XLAT_STR_10 STRINGIFY(FRA_FWMARK)
  [FRA_FLOW] = XLAT(FRA_FLOW),
+ #define XLAT_VAL_11 ((unsigned) (FRA_FLOW))
+ #define XLAT_STR_11 STRINGIFY(FRA_FLOW)
  [FRA_TUN_ID] = XLAT(FRA_TUN_ID),
+ #define XLAT_VAL_12 ((unsigned) (FRA_TUN_ID))
+ #define XLAT_STR_12 STRINGIFY(FRA_TUN_ID)
  [FRA_SUPPRESS_IFGROUP] = XLAT(FRA_SUPPRESS_IFGROUP),
+ #define XLAT_VAL_13 ((unsigned) (FRA_SUPPRESS_IFGROUP))
+ #define XLAT_STR_13 STRINGIFY(FRA_SUPPRESS_IFGROUP)
  [FRA_SUPPRESS_PREFIXLEN] = XLAT(FRA_SUPPRESS_PREFIXLEN),
+ #define XLAT_VAL_14 ((unsigned) (FRA_SUPPRESS_PREFIXLEN))
+ #define XLAT_STR_14 STRINGIFY(FRA_SUPPRESS_PREFIXLEN)
  [FRA_TABLE] = XLAT(FRA_TABLE),
+ #define XLAT_VAL_15 ((unsigned) (FRA_TABLE))
+ #define XLAT_STR_15 STRINGIFY(FRA_TABLE)
  [FRA_FWMASK] = XLAT(FRA_FWMASK),
+ #define XLAT_VAL_16 ((unsigned) (FRA_FWMASK))
+ #define XLAT_STR_16 STRINGIFY(FRA_FWMASK)
  [FRA_OIFNAME] = XLAT(FRA_OIFNAME),
+ #define XLAT_VAL_17 ((unsigned) (FRA_OIFNAME))
+ #define XLAT_STR_17 STRINGIFY(FRA_OIFNAME)
  [FRA_PAD] = XLAT(FRA_PAD),
+ #define XLAT_VAL_18 ((unsigned) (FRA_PAD))
+ #define XLAT_STR_18 STRINGIFY(FRA_PAD)
  [FRA_L3MDEV] = XLAT(FRA_L3MDEV),
+ #define XLAT_VAL_19 ((unsigned) (FRA_L3MDEV))
+ #define XLAT_STR_19 STRINGIFY(FRA_L3MDEV)
  [FRA_UID_RANGE] = XLAT(FRA_UID_RANGE),
+ #define XLAT_VAL_20 ((unsigned) (FRA_UID_RANGE))
+ #define XLAT_STR_20 STRINGIFY(FRA_UID_RANGE)
  [FRA_PROTOCOL] = XLAT(FRA_PROTOCOL),
+ #define XLAT_VAL_21 ((unsigned) (FRA_PROTOCOL))
+ #define XLAT_STR_21 STRINGIFY(FRA_PROTOCOL)
  [FRA_IP_PROTO] = XLAT(FRA_IP_PROTO),
+ #define XLAT_VAL_22 ((unsigned) (FRA_IP_PROTO))
+ #define XLAT_STR_22 STRINGIFY(FRA_IP_PROTO)
  [FRA_SPORT_RANGE] = XLAT(FRA_SPORT_RANGE),
+ #define XLAT_VAL_23 ((unsigned) (FRA_SPORT_RANGE))
+ #define XLAT_STR_23 STRINGIFY(FRA_SPORT_RANGE)
  [FRA_DPORT_RANGE] = XLAT(FRA_DPORT_RANGE),
+ #define XLAT_VAL_24 ((unsigned) (FRA_DPORT_RANGE))
+ #define XLAT_STR_24 STRINGIFY(FRA_DPORT_RANGE)
 };
 static
 const struct xlat rtnl_rule_attrs[1] = { {
  .data = rtnl_rule_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_rule_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_tca_act_flags.h 5.9-0ubuntu2/xlat/rtnl_tca_act_flags.h
--- 5.5-3/xlat/rtnl_tca_act_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_tca_act_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -21,14 +21,28 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_tca_act_flags_xdata[] = {
  XLAT(TCA_ACT_FLAGS_NO_PERCPU_STATS),
+ #define XLAT_VAL_0 ((unsigned) (TCA_ACT_FLAGS_NO_PERCPU_STATS))
+ #define XLAT_STR_0 STRINGIFY(TCA_ACT_FLAGS_NO_PERCPU_STATS)
 };
 static
 const struct xlat rtnl_tca_act_flags[1] = { {
  .data = rtnl_tca_act_flags_xdata,
  .size = ARRAY_SIZE(rtnl_tca_act_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_tca_act_hw_stats.h 5.9-0ubuntu2/xlat/rtnl_tca_act_hw_stats.h
--- 5.5-3/xlat/rtnl_tca_act_hw_stats.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_tca_act_hw_stats.h	2020-09-24 09:18:45.000000000 +0000
@@ -0,0 +1,66 @@
+/* Generated by ./xlat/gen.sh from ./xlat/rtnl_tca_act_hw_stats.in; do not edit. */
+
+#include "gcc_compat.h"
+#include "static_assert.h"
+
+#if defined(TCA_ACT_HW_STATS_IMMEDIATE) || (defined(HAVE_DECL_TCA_ACT_HW_STATS_IMMEDIATE) && HAVE_DECL_TCA_ACT_HW_STATS_IMMEDIATE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TCA_ACT_HW_STATS_IMMEDIATE) == ((1<<0)), "TCA_ACT_HW_STATS_IMMEDIATE != (1<<0)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TCA_ACT_HW_STATS_IMMEDIATE (1<<0)
+#endif
+#if defined(TCA_ACT_HW_STATS_DELAYED) || (defined(HAVE_DECL_TCA_ACT_HW_STATS_DELAYED) && HAVE_DECL_TCA_ACT_HW_STATS_DELAYED)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TCA_ACT_HW_STATS_DELAYED) == ((1<<1)), "TCA_ACT_HW_STATS_DELAYED != (1<<1)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TCA_ACT_HW_STATS_DELAYED (1<<1)
+#endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+#  error static const struct xlat rtnl_tca_act_hw_stats in mpers mode
+
+# else
+
+static const struct xlat_data rtnl_tca_act_hw_stats_xdata[] = {
+ XLAT(TCA_ACT_HW_STATS_IMMEDIATE),
+ #define XLAT_VAL_0 ((unsigned) (TCA_ACT_HW_STATS_IMMEDIATE))
+ #define XLAT_STR_0 STRINGIFY(TCA_ACT_HW_STATS_IMMEDIATE)
+ XLAT(TCA_ACT_HW_STATS_DELAYED),
+ #define XLAT_VAL_1 ((unsigned) (TCA_ACT_HW_STATS_DELAYED))
+ #define XLAT_STR_1 STRINGIFY(TCA_ACT_HW_STATS_DELAYED)
+};
+static
+const struct xlat rtnl_tca_act_hw_stats[1] = { {
+ .data = rtnl_tca_act_hw_stats_xdata,
+ .size = ARRAY_SIZE(rtnl_tca_act_hw_stats_xdata),
+ .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
+} };
+
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+# endif /* !IN_MPERS */
+
+#endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_tca_act_hw_stats.in 5.9-0ubuntu2/xlat/rtnl_tca_act_hw_stats.in
--- 5.5-3/xlat/rtnl_tca_act_hw_stats.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_tca_act_hw_stats.in	2020-05-30 08:00:00.000000000 +0000
@@ -0,0 +1,2 @@
+TCA_ACT_HW_STATS_IMMEDIATE	(1<<0)
+TCA_ACT_HW_STATS_DELAYED	(1<<1)
diff -pruN 5.5-3/xlat/rtnl_tc_action_attrs.h 5.9-0ubuntu2/xlat/rtnl_tc_action_attrs.h
--- 5.5-3/xlat/rtnl_tc_action_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_tc_action_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -59,6 +59,20 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define TCA_ACT_FLAGS 7
 #endif
+#if defined(TCA_ACT_HW_STATS) || (defined(HAVE_DECL_TCA_ACT_HW_STATS) && HAVE_DECL_TCA_ACT_HW_STATS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TCA_ACT_HW_STATS) == (8), "TCA_ACT_HW_STATS != 8");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TCA_ACT_HW_STATS 8
+#endif
+#if defined(TCA_ACT_USED_HW_STATS) || (defined(HAVE_DECL_TCA_ACT_USED_HW_STATS) && HAVE_DECL_TCA_ACT_USED_HW_STATS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TCA_ACT_USED_HW_STATS) == (9), "TCA_ACT_USED_HW_STATS != 9");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TCA_ACT_USED_HW_STATS 9
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -70,21 +84,127 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_tc_action_attrs_xdata[] = {
  [TCA_ACT_UNSPEC] = XLAT(TCA_ACT_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (TCA_ACT_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(TCA_ACT_UNSPEC)
  [TCA_ACT_KIND] = XLAT(TCA_ACT_KIND),
+ #define XLAT_VAL_1 ((unsigned) (TCA_ACT_KIND))
+ #define XLAT_STR_1 STRINGIFY(TCA_ACT_KIND)
  [TCA_ACT_OPTIONS] = XLAT(TCA_ACT_OPTIONS),
+ #define XLAT_VAL_2 ((unsigned) (TCA_ACT_OPTIONS))
+ #define XLAT_STR_2 STRINGIFY(TCA_ACT_OPTIONS)
  [TCA_ACT_INDEX] = XLAT(TCA_ACT_INDEX),
+ #define XLAT_VAL_3 ((unsigned) (TCA_ACT_INDEX))
+ #define XLAT_STR_3 STRINGIFY(TCA_ACT_INDEX)
  [TCA_ACT_STATS] = XLAT(TCA_ACT_STATS),
+ #define XLAT_VAL_4 ((unsigned) (TCA_ACT_STATS))
+ #define XLAT_STR_4 STRINGIFY(TCA_ACT_STATS)
  [TCA_ACT_PAD] = XLAT(TCA_ACT_PAD),
+ #define XLAT_VAL_5 ((unsigned) (TCA_ACT_PAD))
+ #define XLAT_STR_5 STRINGIFY(TCA_ACT_PAD)
  [TCA_ACT_COOKIE] = XLAT(TCA_ACT_COOKIE),
+ #define XLAT_VAL_6 ((unsigned) (TCA_ACT_COOKIE))
+ #define XLAT_STR_6 STRINGIFY(TCA_ACT_COOKIE)
  [TCA_ACT_FLAGS] = XLAT(TCA_ACT_FLAGS),
+ #define XLAT_VAL_7 ((unsigned) (TCA_ACT_FLAGS))
+ #define XLAT_STR_7 STRINGIFY(TCA_ACT_FLAGS)
+ [TCA_ACT_HW_STATS] = XLAT(TCA_ACT_HW_STATS),
+ #define XLAT_VAL_8 ((unsigned) (TCA_ACT_HW_STATS))
+ #define XLAT_STR_8 STRINGIFY(TCA_ACT_HW_STATS)
+ [TCA_ACT_USED_HW_STATS] = XLAT(TCA_ACT_USED_HW_STATS),
+ #define XLAT_VAL_9 ((unsigned) (TCA_ACT_USED_HW_STATS))
+ #define XLAT_STR_9 STRINGIFY(TCA_ACT_USED_HW_STATS)
 };
 static
 const struct xlat rtnl_tc_action_attrs[1] = { {
  .data = rtnl_tc_action_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_tc_action_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_tc_action_attrs.in 5.9-0ubuntu2/xlat/rtnl_tc_action_attrs.in
--- 5.5-3/xlat/rtnl_tc_action_attrs.in	2020-01-27 13:21:44.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_tc_action_attrs.in	2020-05-30 08:00:00.000000000 +0000
@@ -1,4 +1,6 @@
 #value_indexed
+#enum
+#include <linux/pkt_cls.h>
 TCA_ACT_UNSPEC		0
 TCA_ACT_KIND		1
 TCA_ACT_OPTIONS		2
@@ -7,3 +9,5 @@ TCA_ACT_STATS		4
 TCA_ACT_PAD		5
 TCA_ACT_COOKIE		6
 TCA_ACT_FLAGS		7
+TCA_ACT_HW_STATS	8
+TCA_ACT_USED_HW_STATS	9
diff -pruN 5.5-3/xlat/rtnl_tc_action_attrs.m4 5.9-0ubuntu2/xlat/rtnl_tc_action_attrs.m4
--- 5.5-3/xlat/rtnl_tc_action_attrs.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_tc_action_attrs.m4	2020-09-24 09:18:45.000000000 +0000
@@ -0,0 +1,16 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/rtnl_tc_action_attrs.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_rtnl_tc_action_attrs],[
+AC_CHECK_DECLS(m4_normalize([
+TCA_ACT_UNSPEC,
+TCA_ACT_KIND,
+TCA_ACT_OPTIONS,
+TCA_ACT_INDEX,
+TCA_ACT_STATS,
+TCA_ACT_PAD,
+TCA_ACT_COOKIE,
+TCA_ACT_FLAGS,
+TCA_ACT_HW_STATS,
+TCA_ACT_USED_HW_STATS
+]),,, [
+#include <linux/pkt_cls.h>
+])])])
diff -pruN 5.5-3/xlat/rtnl_tca_stab_attrs.h 5.9-0ubuntu2/xlat/rtnl_tca_stab_attrs.h
--- 5.5-3/xlat/rtnl_tca_stab_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_tca_stab_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_tca_stab_attrs_xdata[] = {
  [TCA_STAB_UNSPEC] = XLAT(TCA_STAB_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (TCA_STAB_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(TCA_STAB_UNSPEC)
  [TCA_STAB_BASE] = XLAT(TCA_STAB_BASE),
+ #define XLAT_VAL_1 ((unsigned) (TCA_STAB_BASE))
+ #define XLAT_STR_1 STRINGIFY(TCA_STAB_BASE)
  [TCA_STAB_DATA] = XLAT(TCA_STAB_DATA),
+ #define XLAT_VAL_2 ((unsigned) (TCA_STAB_DATA))
+ #define XLAT_STR_2 STRINGIFY(TCA_STAB_DATA)
 };
 static
 const struct xlat rtnl_tca_stab_attrs[1] = { {
  .data = rtnl_tca_stab_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_tca_stab_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_tca_stab_attrs.in 5.9-0ubuntu2/xlat/rtnl_tca_stab_attrs.in
--- 5.5-3/xlat/rtnl_tca_stab_attrs.in	2019-08-14 19:05:08.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_tca_stab_attrs.in	2020-05-30 08:00:00.000000000 +0000
@@ -1,4 +1,7 @@
 #value_indexed
+#enum
+#include <linux/types.h>
+#include <linux/pkt_sched.h>
 TCA_STAB_UNSPEC	0
 TCA_STAB_BASE	1
 TCA_STAB_DATA	2
diff -pruN 5.5-3/xlat/rtnl_tca_stab_attrs.m4 5.9-0ubuntu2/xlat/rtnl_tca_stab_attrs.m4
--- 5.5-3/xlat/rtnl_tca_stab_attrs.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_tca_stab_attrs.m4	2020-09-24 09:18:45.000000000 +0000
@@ -0,0 +1,10 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/rtnl_tca_stab_attrs.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_rtnl_tca_stab_attrs],[
+AC_CHECK_DECLS(m4_normalize([
+TCA_STAB_UNSPEC,
+TCA_STAB_BASE,
+TCA_STAB_DATA
+]),,, [
+#include <linux/types.h>
+#include <linux/pkt_sched.h>
+])])])
diff -pruN 5.5-3/xlat/rtnl_tca_stats_attrs.h 5.9-0ubuntu2/xlat/rtnl_tca_stats_attrs.h
--- 5.5-3/xlat/rtnl_tca_stats_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_tca_stats_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -77,22 +77,116 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_tca_stats_attrs_xdata[] = {
  [TCA_STATS_UNSPEC] = XLAT(TCA_STATS_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (TCA_STATS_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(TCA_STATS_UNSPEC)
  [TCA_STATS_BASIC] = XLAT(TCA_STATS_BASIC),
+ #define XLAT_VAL_1 ((unsigned) (TCA_STATS_BASIC))
+ #define XLAT_STR_1 STRINGIFY(TCA_STATS_BASIC)
  [TCA_STATS_RATE_EST] = XLAT(TCA_STATS_RATE_EST),
+ #define XLAT_VAL_2 ((unsigned) (TCA_STATS_RATE_EST))
+ #define XLAT_STR_2 STRINGIFY(TCA_STATS_RATE_EST)
  [TCA_STATS_QUEUE] = XLAT(TCA_STATS_QUEUE),
+ #define XLAT_VAL_3 ((unsigned) (TCA_STATS_QUEUE))
+ #define XLAT_STR_3 STRINGIFY(TCA_STATS_QUEUE)
  [TCA_STATS_APP] = XLAT(TCA_STATS_APP),
+ #define XLAT_VAL_4 ((unsigned) (TCA_STATS_APP))
+ #define XLAT_STR_4 STRINGIFY(TCA_STATS_APP)
  [TCA_STATS_RATE_EST64] = XLAT(TCA_STATS_RATE_EST64),
+ #define XLAT_VAL_5 ((unsigned) (TCA_STATS_RATE_EST64))
+ #define XLAT_STR_5 STRINGIFY(TCA_STATS_RATE_EST64)
  [TCA_STATS_PAD] = XLAT(TCA_STATS_PAD),
+ #define XLAT_VAL_6 ((unsigned) (TCA_STATS_PAD))
+ #define XLAT_STR_6 STRINGIFY(TCA_STATS_PAD)
  [TCA_STATS_BASIC_HW] = XLAT(TCA_STATS_BASIC_HW),
+ #define XLAT_VAL_7 ((unsigned) (TCA_STATS_BASIC_HW))
+ #define XLAT_STR_7 STRINGIFY(TCA_STATS_BASIC_HW)
  [TCA_STATS_PKT64] = XLAT(TCA_STATS_PKT64),
+ #define XLAT_VAL_8 ((unsigned) (TCA_STATS_PKT64))
+ #define XLAT_STR_8 STRINGIFY(TCA_STATS_PKT64)
 };
 static
 const struct xlat rtnl_tca_stats_attrs[1] = { {
  .data = rtnl_tca_stats_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_tca_stats_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_tca_stats_attrs.in 5.9-0ubuntu2/xlat/rtnl_tca_stats_attrs.in
--- 5.5-3/xlat/rtnl_tca_stats_attrs.in	2020-01-27 13:21:44.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_tca_stats_attrs.in	2020-05-30 08:00:00.000000000 +0000
@@ -1,4 +1,6 @@
 #value_indexed
+#enum
+#include <linux/gen_stats.h>
 TCA_STATS_UNSPEC	0
 TCA_STATS_BASIC		1
 TCA_STATS_RATE_EST	2
diff -pruN 5.5-3/xlat/rtnl_tca_stats_attrs.m4 5.9-0ubuntu2/xlat/rtnl_tca_stats_attrs.m4
--- 5.5-3/xlat/rtnl_tca_stats_attrs.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_tca_stats_attrs.m4	2020-09-24 09:18:45.000000000 +0000
@@ -0,0 +1,15 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/rtnl_tca_stats_attrs.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_rtnl_tca_stats_attrs],[
+AC_CHECK_DECLS(m4_normalize([
+TCA_STATS_UNSPEC,
+TCA_STATS_BASIC,
+TCA_STATS_RATE_EST,
+TCA_STATS_QUEUE,
+TCA_STATS_APP,
+TCA_STATS_RATE_EST64,
+TCA_STATS_PAD,
+TCA_STATS_BASIC_HW,
+TCA_STATS_PKT64
+]),,, [
+#include <linux/gen_stats.h>
+])])])
diff -pruN 5.5-3/xlat/rtnl_tc_attrs.h 5.9-0ubuntu2/xlat/rtnl_tc_attrs.h
--- 5.5-3/xlat/rtnl_tc_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_tc_attrs.h	2020-09-24 09:18:45.000000000 +0000
@@ -108,6 +108,13 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define TCA_EGRESS_BLOCK 14
 #endif
+#if defined(TCA_DUMP_FLAGS) || (defined(HAVE_DECL_TCA_DUMP_FLAGS) && HAVE_DECL_TCA_DUMP_FLAGS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TCA_DUMP_FLAGS) == (15), "TCA_DUMP_FLAGS != 15");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TCA_DUMP_FLAGS 15
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -119,28 +126,193 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rtnl_tc_attrs_xdata[] = {
  [TCA_UNSPEC] = XLAT(TCA_UNSPEC),
+ #define XLAT_VAL_0 ((unsigned) (TCA_UNSPEC))
+ #define XLAT_STR_0 STRINGIFY(TCA_UNSPEC)
  [TCA_KIND] = XLAT(TCA_KIND),
+ #define XLAT_VAL_1 ((unsigned) (TCA_KIND))
+ #define XLAT_STR_1 STRINGIFY(TCA_KIND)
  [TCA_OPTIONS] = XLAT(TCA_OPTIONS),
+ #define XLAT_VAL_2 ((unsigned) (TCA_OPTIONS))
+ #define XLAT_STR_2 STRINGIFY(TCA_OPTIONS)
  [TCA_STATS] = XLAT(TCA_STATS),
+ #define XLAT_VAL_3 ((unsigned) (TCA_STATS))
+ #define XLAT_STR_3 STRINGIFY(TCA_STATS)
  [TCA_XSTATS] = XLAT(TCA_XSTATS),
+ #define XLAT_VAL_4 ((unsigned) (TCA_XSTATS))
+ #define XLAT_STR_4 STRINGIFY(TCA_XSTATS)
  [TCA_RATE] = XLAT(TCA_RATE),
+ #define XLAT_VAL_5 ((unsigned) (TCA_RATE))
+ #define XLAT_STR_5 STRINGIFY(TCA_RATE)
  [TCA_FCNT] = XLAT(TCA_FCNT),
+ #define XLAT_VAL_6 ((unsigned) (TCA_FCNT))
+ #define XLAT_STR_6 STRINGIFY(TCA_FCNT)
  [TCA_STATS2] = XLAT(TCA_STATS2),
+ #define XLAT_VAL_7 ((unsigned) (TCA_STATS2))
+ #define XLAT_STR_7 STRINGIFY(TCA_STATS2)
  [TCA_STAB] = XLAT(TCA_STAB),
+ #define XLAT_VAL_8 ((unsigned) (TCA_STAB))
+ #define XLAT_STR_8 STRINGIFY(TCA_STAB)
  [TCA_PAD] = XLAT(TCA_PAD),
+ #define XLAT_VAL_9 ((unsigned) (TCA_PAD))
+ #define XLAT_STR_9 STRINGIFY(TCA_PAD)
  [TCA_DUMP_INVISIBLE] = XLAT(TCA_DUMP_INVISIBLE),
+ #define XLAT_VAL_10 ((unsigned) (TCA_DUMP_INVISIBLE))
+ #define XLAT_STR_10 STRINGIFY(TCA_DUMP_INVISIBLE)
  [TCA_CHAIN] = XLAT(TCA_CHAIN),
+ #define XLAT_VAL_11 ((unsigned) (TCA_CHAIN))
+ #define XLAT_STR_11 STRINGIFY(TCA_CHAIN)
  [TCA_HW_OFFLOAD] = XLAT(TCA_HW_OFFLOAD),
+ #define XLAT_VAL_12 ((unsigned) (TCA_HW_OFFLOAD))
+ #define XLAT_STR_12 STRINGIFY(TCA_HW_OFFLOAD)
  [TCA_INGRESS_BLOCK] = XLAT(TCA_INGRESS_BLOCK),
+ #define XLAT_VAL_13 ((unsigned) (TCA_INGRESS_BLOCK))
+ #define XLAT_STR_13 STRINGIFY(TCA_INGRESS_BLOCK)
  [TCA_EGRESS_BLOCK] = XLAT(TCA_EGRESS_BLOCK),
+ #define XLAT_VAL_14 ((unsigned) (TCA_EGRESS_BLOCK))
+ #define XLAT_STR_14 STRINGIFY(TCA_EGRESS_BLOCK)
+ [TCA_DUMP_FLAGS] = XLAT(TCA_DUMP_FLAGS),
+ #define XLAT_VAL_15 ((unsigned) (TCA_DUMP_FLAGS))
+ #define XLAT_STR_15 STRINGIFY(TCA_DUMP_FLAGS)
 };
 static
 const struct xlat rtnl_tc_attrs[1] = { {
  .data = rtnl_tc_attrs_xdata,
  .size = ARRAY_SIZE(rtnl_tc_attrs_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/rtnl_tc_attrs.in 5.9-0ubuntu2/xlat/rtnl_tc_attrs.in
--- 5.5-3/xlat/rtnl_tc_attrs.in	2019-08-14 19:05:08.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rtnl_tc_attrs.in	2020-06-29 08:00:00.000000000 +0000
@@ -14,3 +14,4 @@ TCA_CHAIN		11
 TCA_HW_OFFLOAD		12
 TCA_INGRESS_BLOCK	13
 TCA_EGRESS_BLOCK	14
+TCA_DUMP_FLAGS		15
diff -pruN 5.5-3/xlat/rwf_flags.h 5.9-0ubuntu2/xlat/rwf_flags.h
--- 5.5-3/xlat/rwf_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/rwf_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -45,17 +45,71 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data rwf_flags_xdata[] = {
  XLAT(RWF_HIPRI),
+ #define XLAT_VAL_0 ((unsigned) (RWF_HIPRI))
+ #define XLAT_STR_0 STRINGIFY(RWF_HIPRI)
  XLAT(RWF_DSYNC),
+ #define XLAT_VAL_1 ((unsigned) (RWF_DSYNC))
+ #define XLAT_STR_1 STRINGIFY(RWF_DSYNC)
  XLAT(RWF_SYNC),
+ #define XLAT_VAL_2 ((unsigned) (RWF_SYNC))
+ #define XLAT_STR_2 STRINGIFY(RWF_SYNC)
  XLAT(RWF_NOWAIT),
+ #define XLAT_VAL_3 ((unsigned) (RWF_NOWAIT))
+ #define XLAT_STR_3 STRINGIFY(RWF_NOWAIT)
  XLAT(RWF_APPEND),
+ #define XLAT_VAL_4 ((unsigned) (RWF_APPEND))
+ #define XLAT_STR_4 STRINGIFY(RWF_APPEND)
 };
 const struct xlat rwf_flags[1] = { {
  .data = rwf_flags_xdata,
  .size = ARRAY_SIZE(rwf_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/s390_guarded_storage_commands.h 5.9-0ubuntu2/xlat/s390_guarded_storage_commands.h
--- 5.5-3/xlat/s390_guarded_storage_commands.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/s390_guarded_storage_commands.h	2020-09-24 09:18:45.000000000 +0000
@@ -49,18 +49,72 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data s390_guarded_storage_commands_xdata[] = {
  [GS_ENABLE] = XLAT(GS_ENABLE),
+ #define XLAT_VAL_0 ((unsigned) (GS_ENABLE))
+ #define XLAT_STR_0 STRINGIFY(GS_ENABLE)
  [GS_DISABLE] = XLAT(GS_DISABLE),
+ #define XLAT_VAL_1 ((unsigned) (GS_DISABLE))
+ #define XLAT_STR_1 STRINGIFY(GS_DISABLE)
  [GS_SET_BC_CB] = XLAT(GS_SET_BC_CB),
+ #define XLAT_VAL_2 ((unsigned) (GS_SET_BC_CB))
+ #define XLAT_STR_2 STRINGIFY(GS_SET_BC_CB)
  [GS_CLEAR_BC_CB] = XLAT(GS_CLEAR_BC_CB),
+ #define XLAT_VAL_3 ((unsigned) (GS_CLEAR_BC_CB))
+ #define XLAT_STR_3 STRINGIFY(GS_CLEAR_BC_CB)
  [GS_BROADCAST] = XLAT(GS_BROADCAST),
+ #define XLAT_VAL_4 ((unsigned) (GS_BROADCAST))
+ #define XLAT_STR_4 STRINGIFY(GS_BROADCAST)
 };
 static
 const struct xlat s390_guarded_storage_commands[1] = { {
  .data = s390_guarded_storage_commands_xdata,
  .size = ARRAY_SIZE(s390_guarded_storage_commands_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/s390_runtime_instr_commands.h 5.9-0ubuntu2/xlat/s390_runtime_instr_commands.h
--- 5.5-3/xlat/s390_runtime_instr_commands.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/s390_runtime_instr_commands.h	2020-09-24 09:18:45.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data s390_runtime_instr_commands_xdata[] = {
  [S390_RUNTIME_INSTR_START] = XLAT(S390_RUNTIME_INSTR_START),
+ #define XLAT_VAL_0 ((unsigned) (S390_RUNTIME_INSTR_START))
+ #define XLAT_STR_0 STRINGIFY(S390_RUNTIME_INSTR_START)
  [S390_RUNTIME_INSTR_STOP] = XLAT(S390_RUNTIME_INSTR_STOP),
+ #define XLAT_VAL_1 ((unsigned) (S390_RUNTIME_INSTR_STOP))
+ #define XLAT_STR_1 STRINGIFY(S390_RUNTIME_INSTR_STOP)
 };
 static
 const struct xlat s390_runtime_instr_commands[1] = { {
  .data = s390_runtime_instr_commands_xdata,
  .size = ARRAY_SIZE(s390_runtime_instr_commands_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/s390_sthyi_function_codes.h 5.9-0ubuntu2/xlat/s390_sthyi_function_codes.h
--- 5.5-3/xlat/s390_sthyi_function_codes.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/s390_sthyi_function_codes.h	2020-09-24 09:18:45.000000000 +0000
@@ -21,14 +21,28 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data s390_sthyi_function_codes_xdata[] = {
  XLAT(STHYI_FC_CP_IFL_CAP),
+ #define XLAT_VAL_0 ((unsigned) (STHYI_FC_CP_IFL_CAP))
+ #define XLAT_STR_0 STRINGIFY(STHYI_FC_CP_IFL_CAP)
 };
 static
 const struct xlat s390_sthyi_function_codes[1] = { {
  .data = s390_sthyi_function_codes_xdata,
  .size = ARRAY_SIZE(s390_sthyi_function_codes_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sa_handler_values.h 5.9-0ubuntu2/xlat/sa_handler_values.h
--- 5.5-3/xlat/sa_handler_values.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sa_handler_values.h	2020-09-24 09:18:45.000000000 +0000
@@ -15,12 +15,18 @@
 static const struct xlat_data sa_handler_values_xdata[] = {
 #if defined(SIG_ERR) || (defined(HAVE_DECL_SIG_ERR) && HAVE_DECL_SIG_ERR)
   XLAT_TYPE(unsigned long, SIG_ERR),
+ #define XLAT_VAL_0 ((unsigned long) (SIG_ERR))
+ #define XLAT_STR_0 STRINGIFY(SIG_ERR)
 #endif
 #if defined(SIG_DFL) || (defined(HAVE_DECL_SIG_DFL) && HAVE_DECL_SIG_DFL)
   XLAT_TYPE(unsigned long, SIG_DFL),
+ #define XLAT_VAL_1 ((unsigned long) (SIG_DFL))
+ #define XLAT_STR_1 STRINGIFY(SIG_DFL)
 #endif
 #if defined(SIG_IGN) || (defined(HAVE_DECL_SIG_IGN) && HAVE_DECL_SIG_IGN)
   XLAT_TYPE(unsigned long, SIG_IGN),
+ #define XLAT_VAL_2 ((unsigned long) (SIG_IGN))
+ #define XLAT_STR_2 STRINGIFY(SIG_IGN)
 #endif
 };
 static
@@ -28,8 +34,36 @@ const struct xlat sa_handler_values[1] =
  .data = sa_handler_values_xdata,
  .size = ARRAY_SIZE(sa_handler_values_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sched_flags.h 5.9-0ubuntu2/xlat/sched_flags.h
--- 5.5-3/xlat/sched_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sched_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -5,24 +5,52 @@
 
 #if defined(SCHED_FLAG_RESET_ON_FORK) || (defined(HAVE_DECL_SCHED_FLAG_RESET_ON_FORK) && HAVE_DECL_SCHED_FLAG_RESET_ON_FORK)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
-static_assert((SCHED_FLAG_RESET_ON_FORK) == (1), "SCHED_FLAG_RESET_ON_FORK != 1");
+static_assert((SCHED_FLAG_RESET_ON_FORK) == (0x01), "SCHED_FLAG_RESET_ON_FORK != 0x01");
 DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
-# define SCHED_FLAG_RESET_ON_FORK 1
+# define SCHED_FLAG_RESET_ON_FORK 0x01
 #endif
 #if defined(SCHED_FLAG_RECLAIM) || (defined(HAVE_DECL_SCHED_FLAG_RECLAIM) && HAVE_DECL_SCHED_FLAG_RECLAIM)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
-static_assert((SCHED_FLAG_RECLAIM) == (2), "SCHED_FLAG_RECLAIM != 2");
+static_assert((SCHED_FLAG_RECLAIM) == (0x02), "SCHED_FLAG_RECLAIM != 0x02");
 DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
-# define SCHED_FLAG_RECLAIM 2
+# define SCHED_FLAG_RECLAIM 0x02
 #endif
 #if defined(SCHED_FLAG_DL_OVERRUN) || (defined(HAVE_DECL_SCHED_FLAG_DL_OVERRUN) && HAVE_DECL_SCHED_FLAG_DL_OVERRUN)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
-static_assert((SCHED_FLAG_DL_OVERRUN) == (4), "SCHED_FLAG_DL_OVERRUN != 4");
+static_assert((SCHED_FLAG_DL_OVERRUN) == (0x04), "SCHED_FLAG_DL_OVERRUN != 0x04");
 DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
-# define SCHED_FLAG_DL_OVERRUN 4
+# define SCHED_FLAG_DL_OVERRUN 0x04
+#endif
+#if defined(SCHED_FLAG_KEEP_POLICY) || (defined(HAVE_DECL_SCHED_FLAG_KEEP_POLICY) && HAVE_DECL_SCHED_FLAG_KEEP_POLICY)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((SCHED_FLAG_KEEP_POLICY) == (0x08), "SCHED_FLAG_KEEP_POLICY != 0x08");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define SCHED_FLAG_KEEP_POLICY 0x08
+#endif
+#if defined(SCHED_FLAG_KEEP_PARAMS) || (defined(HAVE_DECL_SCHED_FLAG_KEEP_PARAMS) && HAVE_DECL_SCHED_FLAG_KEEP_PARAMS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((SCHED_FLAG_KEEP_PARAMS) == (0x10), "SCHED_FLAG_KEEP_PARAMS != 0x10");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define SCHED_FLAG_KEEP_PARAMS 0x10
+#endif
+#if defined(SCHED_FLAG_UTIL_CLAMP_MIN) || (defined(HAVE_DECL_SCHED_FLAG_UTIL_CLAMP_MIN) && HAVE_DECL_SCHED_FLAG_UTIL_CLAMP_MIN)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((SCHED_FLAG_UTIL_CLAMP_MIN) == (0x20), "SCHED_FLAG_UTIL_CLAMP_MIN != 0x20");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define SCHED_FLAG_UTIL_CLAMP_MIN 0x20
+#endif
+#if defined(SCHED_FLAG_UTIL_CLAMP_MAX) || (defined(HAVE_DECL_SCHED_FLAG_UTIL_CLAMP_MAX) && HAVE_DECL_SCHED_FLAG_UTIL_CLAMP_MAX)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((SCHED_FLAG_UTIL_CLAMP_MAX) == (0x40), "SCHED_FLAG_UTIL_CLAMP_MAX != 0x40");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define SCHED_FLAG_UTIL_CLAMP_MAX 0x40
 #endif
 
 #ifndef XLAT_MACROS_ONLY
@@ -35,16 +63,94 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sched_flags_xdata[] = {
  XLAT(SCHED_FLAG_RESET_ON_FORK),
+ #define XLAT_VAL_0 ((unsigned) (SCHED_FLAG_RESET_ON_FORK))
+ #define XLAT_STR_0 STRINGIFY(SCHED_FLAG_RESET_ON_FORK)
  XLAT(SCHED_FLAG_RECLAIM),
+ #define XLAT_VAL_1 ((unsigned) (SCHED_FLAG_RECLAIM))
+ #define XLAT_STR_1 STRINGIFY(SCHED_FLAG_RECLAIM)
  XLAT(SCHED_FLAG_DL_OVERRUN),
+ #define XLAT_VAL_2 ((unsigned) (SCHED_FLAG_DL_OVERRUN))
+ #define XLAT_STR_2 STRINGIFY(SCHED_FLAG_DL_OVERRUN)
+ XLAT(SCHED_FLAG_KEEP_POLICY),
+ #define XLAT_VAL_3 ((unsigned) (SCHED_FLAG_KEEP_POLICY))
+ #define XLAT_STR_3 STRINGIFY(SCHED_FLAG_KEEP_POLICY)
+ XLAT(SCHED_FLAG_KEEP_PARAMS),
+ #define XLAT_VAL_4 ((unsigned) (SCHED_FLAG_KEEP_PARAMS))
+ #define XLAT_STR_4 STRINGIFY(SCHED_FLAG_KEEP_PARAMS)
+ XLAT(SCHED_FLAG_UTIL_CLAMP_MIN),
+ #define XLAT_VAL_5 ((unsigned) (SCHED_FLAG_UTIL_CLAMP_MIN))
+ #define XLAT_STR_5 STRINGIFY(SCHED_FLAG_UTIL_CLAMP_MIN)
+ XLAT(SCHED_FLAG_UTIL_CLAMP_MAX),
+ #define XLAT_VAL_6 ((unsigned) (SCHED_FLAG_UTIL_CLAMP_MAX))
+ #define XLAT_STR_6 STRINGIFY(SCHED_FLAG_UTIL_CLAMP_MAX)
 };
 static
 const struct xlat sched_flags[1] = { {
  .data = sched_flags_xdata,
  .size = ARRAY_SIZE(sched_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sched_flags.in 5.9-0ubuntu2/xlat/sched_flags.in
--- 5.5-3/xlat/sched_flags.in	2018-02-27 13:14:38.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sched_flags.in	2020-03-23 00:31:56.000000000 +0000
@@ -1,3 +1,7 @@
-SCHED_FLAG_RESET_ON_FORK	1
-SCHED_FLAG_RECLAIM		2
-SCHED_FLAG_DL_OVERRUN		4
+SCHED_FLAG_RESET_ON_FORK	0x01
+SCHED_FLAG_RECLAIM		0x02
+SCHED_FLAG_DL_OVERRUN		0x04
+SCHED_FLAG_KEEP_POLICY		0x08
+SCHED_FLAG_KEEP_PARAMS		0x10
+SCHED_FLAG_UTIL_CLAMP_MIN	0x20
+SCHED_FLAG_UTIL_CLAMP_MAX	0x40
diff -pruN 5.5-3/xlat/schedulers.h 5.9-0ubuntu2/xlat/schedulers.h
--- 5.5-3/xlat/schedulers.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/schedulers.h	2020-09-24 09:18:45.000000000 +0000
@@ -15,24 +15,38 @@
 static const struct xlat_data schedulers_xdata[] = {
 #if defined(SCHED_OTHER) || (defined(HAVE_DECL_SCHED_OTHER) && HAVE_DECL_SCHED_OTHER)
   XLAT(SCHED_OTHER),
+ #define XLAT_VAL_0 ((unsigned) (SCHED_OTHER))
+ #define XLAT_STR_0 STRINGIFY(SCHED_OTHER)
 #endif
 #if defined(SCHED_FIFO) || (defined(HAVE_DECL_SCHED_FIFO) && HAVE_DECL_SCHED_FIFO)
   XLAT(SCHED_FIFO),
+ #define XLAT_VAL_1 ((unsigned) (SCHED_FIFO))
+ #define XLAT_STR_1 STRINGIFY(SCHED_FIFO)
 #endif
 #if defined(SCHED_RR) || (defined(HAVE_DECL_SCHED_RR) && HAVE_DECL_SCHED_RR)
   XLAT(SCHED_RR),
+ #define XLAT_VAL_2 ((unsigned) (SCHED_RR))
+ #define XLAT_STR_2 STRINGIFY(SCHED_RR)
 #endif
 #if defined(SCHED_BATCH) || (defined(HAVE_DECL_SCHED_BATCH) && HAVE_DECL_SCHED_BATCH)
   XLAT(SCHED_BATCH),
+ #define XLAT_VAL_3 ((unsigned) (SCHED_BATCH))
+ #define XLAT_STR_3 STRINGIFY(SCHED_BATCH)
 #endif
 #if defined(SCHED_ISO) || (defined(HAVE_DECL_SCHED_ISO) && HAVE_DECL_SCHED_ISO)
   XLAT(SCHED_ISO),
+ #define XLAT_VAL_4 ((unsigned) (SCHED_ISO))
+ #define XLAT_STR_4 STRINGIFY(SCHED_ISO)
 #endif
 #if defined(SCHED_IDLE) || (defined(HAVE_DECL_SCHED_IDLE) && HAVE_DECL_SCHED_IDLE)
   XLAT(SCHED_IDLE),
+ #define XLAT_VAL_5 ((unsigned) (SCHED_IDLE))
+ #define XLAT_STR_5 STRINGIFY(SCHED_IDLE)
 #endif
 #if defined(SCHED_DEADLINE) || (defined(HAVE_DECL_SCHED_DEADLINE) && HAVE_DECL_SCHED_DEADLINE)
   XLAT(SCHED_DEADLINE),
+ #define XLAT_VAL_6 ((unsigned) (SCHED_DEADLINE))
+ #define XLAT_STR_6 STRINGIFY(SCHED_DEADLINE)
 #endif
 };
 static
@@ -40,8 +54,68 @@ const struct xlat schedulers[1] = { {
  .data = schedulers_xdata,
  .size = ARRAY_SIZE(schedulers_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/scmvals.h 5.9-0ubuntu2/xlat/scmvals.h
--- 5.5-3/xlat/scmvals.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/scmvals.h	2020-09-24 09:18:46.000000000 +0000
@@ -85,48 +85,82 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data scmvals_xdata[] = {
  XLAT(SCM_RIGHTS),
+ #define XLAT_VAL_0 ((unsigned) (SCM_RIGHTS))
+ #define XLAT_STR_0 STRINGIFY(SCM_RIGHTS)
  XLAT(SCM_CREDENTIALS),
+ #define XLAT_VAL_1 ((unsigned) (SCM_CREDENTIALS))
+ #define XLAT_STR_1 STRINGIFY(SCM_CREDENTIALS)
  XLAT(SCM_SECURITY),
+ #define XLAT_VAL_2 ((unsigned) (SCM_SECURITY))
+ #define XLAT_STR_2 STRINGIFY(SCM_SECURITY)
 
 #if defined(SO_WIFI_STATUS) || (defined(HAVE_DECL_SO_WIFI_STATUS) && HAVE_DECL_SO_WIFI_STATUS)
   XLAT(SO_WIFI_STATUS),
+ #define XLAT_VAL_3 ((unsigned) (SO_WIFI_STATUS))
+ #define XLAT_STR_3 STRINGIFY(SO_WIFI_STATUS)
 #endif
 #if defined(SO_TXTIME) || (defined(HAVE_DECL_SO_TXTIME) && HAVE_DECL_SO_TXTIME)
   XLAT(SO_TXTIME),
+ #define XLAT_VAL_4 ((unsigned) (SO_TXTIME))
+ #define XLAT_STR_4 STRINGIFY(SO_TXTIME)
 #endif
 #if defined(SO_TIMESTAMP_OLD) || (defined(HAVE_DECL_SO_TIMESTAMP_OLD) && HAVE_DECL_SO_TIMESTAMP_OLD)
   XLAT(SO_TIMESTAMP_OLD),
+ #define XLAT_VAL_5 ((unsigned) (SO_TIMESTAMP_OLD))
+ #define XLAT_STR_5 STRINGIFY(SO_TIMESTAMP_OLD)
 #endif
 #if defined(SO_TIMESTAMPNS_OLD) || (defined(HAVE_DECL_SO_TIMESTAMPNS_OLD) && HAVE_DECL_SO_TIMESTAMPNS_OLD)
   XLAT(SO_TIMESTAMPNS_OLD),
+ #define XLAT_VAL_6 ((unsigned) (SO_TIMESTAMPNS_OLD))
+ #define XLAT_STR_6 STRINGIFY(SO_TIMESTAMPNS_OLD)
 #endif
 #if defined(SO_TIMESTAMPING_OLD) || (defined(HAVE_DECL_SO_TIMESTAMPING_OLD) && HAVE_DECL_SO_TIMESTAMPING_OLD)
   XLAT(SO_TIMESTAMPING_OLD),
+ #define XLAT_VAL_7 ((unsigned) (SO_TIMESTAMPING_OLD))
+ #define XLAT_STR_7 STRINGIFY(SO_TIMESTAMPING_OLD)
 #endif
 #if defined(SO_TIMESTAMP_NEW) || (defined(HAVE_DECL_SO_TIMESTAMP_NEW) && HAVE_DECL_SO_TIMESTAMP_NEW)
   XLAT(SO_TIMESTAMP_NEW),
+ #define XLAT_VAL_8 ((unsigned) (SO_TIMESTAMP_NEW))
+ #define XLAT_STR_8 STRINGIFY(SO_TIMESTAMP_NEW)
 #endif
 #if defined(SO_TIMESTAMPNS_NEW) || (defined(HAVE_DECL_SO_TIMESTAMPNS_NEW) && HAVE_DECL_SO_TIMESTAMPNS_NEW)
   XLAT(SO_TIMESTAMPNS_NEW),
+ #define XLAT_VAL_9 ((unsigned) (SO_TIMESTAMPNS_NEW))
+ #define XLAT_STR_9 STRINGIFY(SO_TIMESTAMPNS_NEW)
 #endif
 #if defined(SO_TIMESTAMPING_NEW) || (defined(HAVE_DECL_SO_TIMESTAMPING_NEW) && HAVE_DECL_SO_TIMESTAMPING_NEW)
   XLAT(SO_TIMESTAMPING_NEW),
+ #define XLAT_VAL_10 ((unsigned) (SO_TIMESTAMPING_NEW))
+ #define XLAT_STR_10 STRINGIFY(SO_TIMESTAMPING_NEW)
 #endif
 
 
 #if defined __sparc__
  XLAT(SCM_TIMESTAMPING_OPT_STATS),
+ #define XLAT_VAL_11 ((unsigned) (SCM_TIMESTAMPING_OPT_STATS))
+ #define XLAT_STR_11 STRINGIFY(SCM_TIMESTAMPING_OPT_STATS)
 #elif defined __hppa__
  XLAT(SCM_TIMESTAMPING_OPT_STATS),
+ #define XLAT_VAL_12 ((unsigned) (SCM_TIMESTAMPING_OPT_STATS))
+ #define XLAT_STR_12 STRINGIFY(SCM_TIMESTAMPING_OPT_STATS)
 #else
  XLAT(SCM_TIMESTAMPING_OPT_STATS),
+ #define XLAT_VAL_13 ((unsigned) (SCM_TIMESTAMPING_OPT_STATS))
+ #define XLAT_STR_13 STRINGIFY(SCM_TIMESTAMPING_OPT_STATS)
 #endif
 #if defined __sparc__
  XLAT(SCM_TIMESTAMPING_PKTINFO),
+ #define XLAT_VAL_14 ((unsigned) (SCM_TIMESTAMPING_PKTINFO))
+ #define XLAT_STR_14 STRINGIFY(SCM_TIMESTAMPING_PKTINFO)
 #elif defined __hppa__
  XLAT(SCM_TIMESTAMPING_PKTINFO),
+ #define XLAT_VAL_15 ((unsigned) (SCM_TIMESTAMPING_PKTINFO))
+ #define XLAT_STR_15 STRINGIFY(SCM_TIMESTAMPING_PKTINFO)
 #else
  XLAT(SCM_TIMESTAMPING_PKTINFO),
+ #define XLAT_VAL_16 ((unsigned) (SCM_TIMESTAMPING_PKTINFO))
+ #define XLAT_STR_16 STRINGIFY(SCM_TIMESTAMPING_PKTINFO)
 #endif
 };
 static
@@ -134,8 +168,148 @@ const struct xlat scmvals[1] = { {
  .data = scmvals_xdata,
  .size = ARRAY_SIZE(scmvals_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/scsi_sg_commands.h 5.9-0ubuntu2/xlat/scsi_sg_commands.h
--- 5.5-3/xlat/scsi_sg_commands.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/scsi_sg_commands.h	2020-09-24 09:18:46.000000000 +0000
@@ -189,38 +189,292 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data scsi_sg_commands_xdata[] = {
  XLAT(SG_SET_TIMEOUT),
+ #define XLAT_VAL_0 ((unsigned) (SG_SET_TIMEOUT))
+ #define XLAT_STR_0 STRINGIFY(SG_SET_TIMEOUT)
  XLAT(SG_GET_TIMEOUT),
+ #define XLAT_VAL_1 ((unsigned) (SG_GET_TIMEOUT))
+ #define XLAT_STR_1 STRINGIFY(SG_GET_TIMEOUT)
  XLAT(SG_EMULATED_HOST),
+ #define XLAT_VAL_2 ((unsigned) (SG_EMULATED_HOST))
+ #define XLAT_STR_2 STRINGIFY(SG_EMULATED_HOST)
  XLAT(SG_SET_TRANSFORM),
+ #define XLAT_VAL_3 ((unsigned) (SG_SET_TRANSFORM))
+ #define XLAT_STR_3 STRINGIFY(SG_SET_TRANSFORM)
  XLAT(SG_GET_TRANSFORM),
+ #define XLAT_VAL_4 ((unsigned) (SG_GET_TRANSFORM))
+ #define XLAT_STR_4 STRINGIFY(SG_GET_TRANSFORM)
  XLAT(SG_GET_COMMAND_Q),
+ #define XLAT_VAL_5 ((unsigned) (SG_GET_COMMAND_Q))
+ #define XLAT_STR_5 STRINGIFY(SG_GET_COMMAND_Q)
  XLAT(SG_SET_COMMAND_Q),
+ #define XLAT_VAL_6 ((unsigned) (SG_SET_COMMAND_Q))
+ #define XLAT_STR_6 STRINGIFY(SG_SET_COMMAND_Q)
  XLAT(SG_GET_RESERVED_SIZE),
+ #define XLAT_VAL_7 ((unsigned) (SG_GET_RESERVED_SIZE))
+ #define XLAT_STR_7 STRINGIFY(SG_GET_RESERVED_SIZE)
  XLAT(SG_SET_RESERVED_SIZE),
+ #define XLAT_VAL_8 ((unsigned) (SG_SET_RESERVED_SIZE))
+ #define XLAT_STR_8 STRINGIFY(SG_SET_RESERVED_SIZE)
  XLAT(SG_GET_SCSI_ID),
+ #define XLAT_VAL_9 ((unsigned) (SG_GET_SCSI_ID))
+ #define XLAT_STR_9 STRINGIFY(SG_GET_SCSI_ID)
  XLAT(SG_SET_FORCE_LOW_DMA),
+ #define XLAT_VAL_10 ((unsigned) (SG_SET_FORCE_LOW_DMA))
+ #define XLAT_STR_10 STRINGIFY(SG_SET_FORCE_LOW_DMA)
  XLAT(SG_GET_LOW_DMA),
+ #define XLAT_VAL_11 ((unsigned) (SG_GET_LOW_DMA))
+ #define XLAT_STR_11 STRINGIFY(SG_GET_LOW_DMA)
  XLAT(SG_SET_FORCE_PACK_ID),
+ #define XLAT_VAL_12 ((unsigned) (SG_SET_FORCE_PACK_ID))
+ #define XLAT_STR_12 STRINGIFY(SG_SET_FORCE_PACK_ID)
  XLAT(SG_GET_PACK_ID),
+ #define XLAT_VAL_13 ((unsigned) (SG_GET_PACK_ID))
+ #define XLAT_STR_13 STRINGIFY(SG_GET_PACK_ID)
  XLAT(SG_GET_NUM_WAITING),
+ #define XLAT_VAL_14 ((unsigned) (SG_GET_NUM_WAITING))
+ #define XLAT_STR_14 STRINGIFY(SG_GET_NUM_WAITING)
  XLAT(SG_SET_DEBUG),
+ #define XLAT_VAL_15 ((unsigned) (SG_SET_DEBUG))
+ #define XLAT_STR_15 STRINGIFY(SG_SET_DEBUG)
  XLAT(SG_GET_SG_TABLESIZE),
+ #define XLAT_VAL_16 ((unsigned) (SG_GET_SG_TABLESIZE))
+ #define XLAT_STR_16 STRINGIFY(SG_GET_SG_TABLESIZE)
  XLAT(SG_GET_VERSION_NUM),
+ #define XLAT_VAL_17 ((unsigned) (SG_GET_VERSION_NUM))
+ #define XLAT_STR_17 STRINGIFY(SG_GET_VERSION_NUM)
  XLAT(SG_NEXT_CMD_LEN),
+ #define XLAT_VAL_18 ((unsigned) (SG_NEXT_CMD_LEN))
+ #define XLAT_STR_18 STRINGIFY(SG_NEXT_CMD_LEN)
  XLAT(SG_SCSI_RESET),
+ #define XLAT_VAL_19 ((unsigned) (SG_SCSI_RESET))
+ #define XLAT_STR_19 STRINGIFY(SG_SCSI_RESET)
  XLAT(SG_IO),
+ #define XLAT_VAL_20 ((unsigned) (SG_IO))
+ #define XLAT_STR_20 STRINGIFY(SG_IO)
  XLAT(SG_GET_REQUEST_TABLE),
+ #define XLAT_VAL_21 ((unsigned) (SG_GET_REQUEST_TABLE))
+ #define XLAT_STR_21 STRINGIFY(SG_GET_REQUEST_TABLE)
  XLAT(SG_SET_KEEP_ORPHAN),
+ #define XLAT_VAL_22 ((unsigned) (SG_SET_KEEP_ORPHAN))
+ #define XLAT_STR_22 STRINGIFY(SG_SET_KEEP_ORPHAN)
  XLAT(SG_GET_KEEP_ORPHAN),
+ #define XLAT_VAL_23 ((unsigned) (SG_GET_KEEP_ORPHAN))
+ #define XLAT_STR_23 STRINGIFY(SG_GET_KEEP_ORPHAN)
  XLAT(SG_GET_ACCESS_COUNT),
+ #define XLAT_VAL_24 ((unsigned) (SG_GET_ACCESS_COUNT))
+ #define XLAT_STR_24 STRINGIFY(SG_GET_ACCESS_COUNT)
 };
 static
 const struct xlat scsi_sg_commands[1] = { {
  .data = scsi_sg_commands_xdata,
  .size = ARRAY_SIZE(scsi_sg_commands_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/secbits.h 5.9-0ubuntu2/xlat/secbits.h
--- 5.5-3/xlat/secbits.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/secbits.h	2020-09-24 09:18:45.000000000 +0000
@@ -70,21 +70,105 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data secbits_xdata[] = {
  XLAT(SECBIT_NOROOT),
+ #define XLAT_VAL_0 ((unsigned) (SECBIT_NOROOT))
+ #define XLAT_STR_0 STRINGIFY(SECBIT_NOROOT)
  XLAT(SECBIT_NOROOT_LOCKED),
+ #define XLAT_VAL_1 ((unsigned) (SECBIT_NOROOT_LOCKED))
+ #define XLAT_STR_1 STRINGIFY(SECBIT_NOROOT_LOCKED)
  XLAT(SECBIT_NO_SETUID_FIXUP),
+ #define XLAT_VAL_2 ((unsigned) (SECBIT_NO_SETUID_FIXUP))
+ #define XLAT_STR_2 STRINGIFY(SECBIT_NO_SETUID_FIXUP)
  XLAT(SECBIT_NO_SETUID_FIXUP_LOCKED),
+ #define XLAT_VAL_3 ((unsigned) (SECBIT_NO_SETUID_FIXUP_LOCKED))
+ #define XLAT_STR_3 STRINGIFY(SECBIT_NO_SETUID_FIXUP_LOCKED)
  XLAT(SECBIT_KEEP_CAPS),
+ #define XLAT_VAL_4 ((unsigned) (SECBIT_KEEP_CAPS))
+ #define XLAT_STR_4 STRINGIFY(SECBIT_KEEP_CAPS)
  XLAT(SECBIT_KEEP_CAPS_LOCKED),
+ #define XLAT_VAL_5 ((unsigned) (SECBIT_KEEP_CAPS_LOCKED))
+ #define XLAT_STR_5 STRINGIFY(SECBIT_KEEP_CAPS_LOCKED)
  XLAT(SECBIT_NO_CAP_AMBIENT_RAISE),
+ #define XLAT_VAL_6 ((unsigned) (SECBIT_NO_CAP_AMBIENT_RAISE))
+ #define XLAT_STR_6 STRINGIFY(SECBIT_NO_CAP_AMBIENT_RAISE)
  XLAT(SECBIT_NO_CAP_AMBIENT_RAISE_LOCKED),
+ #define XLAT_VAL_7 ((unsigned) (SECBIT_NO_CAP_AMBIENT_RAISE_LOCKED))
+ #define XLAT_STR_7 STRINGIFY(SECBIT_NO_CAP_AMBIENT_RAISE_LOCKED)
 };
 static
 const struct xlat secbits[1] = { {
  .data = secbits_xdata,
  .size = ARRAY_SIZE(secbits_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/seccomp_filter_flags.h 5.9-0ubuntu2/xlat/seccomp_filter_flags.h
--- 5.5-3/xlat/seccomp_filter_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/seccomp_filter_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -5,31 +5,38 @@
 
 #if defined(SECCOMP_FILTER_FLAG_TSYNC) || (defined(HAVE_DECL_SECCOMP_FILTER_FLAG_TSYNC) && HAVE_DECL_SECCOMP_FILTER_FLAG_TSYNC)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
-static_assert((SECCOMP_FILTER_FLAG_TSYNC) == (1), "SECCOMP_FILTER_FLAG_TSYNC != 1");
+static_assert((SECCOMP_FILTER_FLAG_TSYNC) == ((1<<0)), "SECCOMP_FILTER_FLAG_TSYNC != (1<<0)");
 DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
-# define SECCOMP_FILTER_FLAG_TSYNC 1
+# define SECCOMP_FILTER_FLAG_TSYNC (1<<0)
 #endif
 #if defined(SECCOMP_FILTER_FLAG_LOG) || (defined(HAVE_DECL_SECCOMP_FILTER_FLAG_LOG) && HAVE_DECL_SECCOMP_FILTER_FLAG_LOG)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
-static_assert((SECCOMP_FILTER_FLAG_LOG) == (2), "SECCOMP_FILTER_FLAG_LOG != 2");
+static_assert((SECCOMP_FILTER_FLAG_LOG) == ((1<<1)), "SECCOMP_FILTER_FLAG_LOG != (1<<1)");
 DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
-# define SECCOMP_FILTER_FLAG_LOG 2
+# define SECCOMP_FILTER_FLAG_LOG (1<<1)
 #endif
 #if defined(SECCOMP_FILTER_FLAG_SPEC_ALLOW) || (defined(HAVE_DECL_SECCOMP_FILTER_FLAG_SPEC_ALLOW) && HAVE_DECL_SECCOMP_FILTER_FLAG_SPEC_ALLOW)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
-static_assert((SECCOMP_FILTER_FLAG_SPEC_ALLOW) == (4), "SECCOMP_FILTER_FLAG_SPEC_ALLOW != 4");
+static_assert((SECCOMP_FILTER_FLAG_SPEC_ALLOW) == ((1<<2)), "SECCOMP_FILTER_FLAG_SPEC_ALLOW != (1<<2)");
 DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
-# define SECCOMP_FILTER_FLAG_SPEC_ALLOW 4
+# define SECCOMP_FILTER_FLAG_SPEC_ALLOW (1<<2)
 #endif
 #if defined(SECCOMP_FILTER_FLAG_NEW_LISTENER) || (defined(HAVE_DECL_SECCOMP_FILTER_FLAG_NEW_LISTENER) && HAVE_DECL_SECCOMP_FILTER_FLAG_NEW_LISTENER)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
-static_assert((SECCOMP_FILTER_FLAG_NEW_LISTENER) == (8), "SECCOMP_FILTER_FLAG_NEW_LISTENER != 8");
+static_assert((SECCOMP_FILTER_FLAG_NEW_LISTENER) == ((1<<3)), "SECCOMP_FILTER_FLAG_NEW_LISTENER != (1<<3)");
 DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
-# define SECCOMP_FILTER_FLAG_NEW_LISTENER 8
+# define SECCOMP_FILTER_FLAG_NEW_LISTENER (1<<3)
+#endif
+#if defined(SECCOMP_FILTER_FLAG_TSYNC_ESRCH) || (defined(HAVE_DECL_SECCOMP_FILTER_FLAG_TSYNC_ESRCH) && HAVE_DECL_SECCOMP_FILTER_FLAG_TSYNC_ESRCH)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((SECCOMP_FILTER_FLAG_TSYNC_ESRCH) == ((1<<4)), "SECCOMP_FILTER_FLAG_TSYNC_ESRCH != (1<<4)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define SECCOMP_FILTER_FLAG_TSYNC_ESRCH (1<<4)
 #endif
 
 #ifndef XLAT_MACROS_ONLY
@@ -38,16 +45,71 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data seccomp_filter_flags_xdata[] = {
  XLAT(SECCOMP_FILTER_FLAG_TSYNC),
+ #define XLAT_VAL_0 ((unsigned) (SECCOMP_FILTER_FLAG_TSYNC))
+ #define XLAT_STR_0 STRINGIFY(SECCOMP_FILTER_FLAG_TSYNC)
  XLAT(SECCOMP_FILTER_FLAG_LOG),
+ #define XLAT_VAL_1 ((unsigned) (SECCOMP_FILTER_FLAG_LOG))
+ #define XLAT_STR_1 STRINGIFY(SECCOMP_FILTER_FLAG_LOG)
  XLAT(SECCOMP_FILTER_FLAG_SPEC_ALLOW),
+ #define XLAT_VAL_2 ((unsigned) (SECCOMP_FILTER_FLAG_SPEC_ALLOW))
+ #define XLAT_STR_2 STRINGIFY(SECCOMP_FILTER_FLAG_SPEC_ALLOW)
  XLAT(SECCOMP_FILTER_FLAG_NEW_LISTENER),
+ #define XLAT_VAL_3 ((unsigned) (SECCOMP_FILTER_FLAG_NEW_LISTENER))
+ #define XLAT_STR_3 STRINGIFY(SECCOMP_FILTER_FLAG_NEW_LISTENER)
+ XLAT(SECCOMP_FILTER_FLAG_TSYNC_ESRCH),
+ #define XLAT_VAL_4 ((unsigned) (SECCOMP_FILTER_FLAG_TSYNC_ESRCH))
+ #define XLAT_STR_4 STRINGIFY(SECCOMP_FILTER_FLAG_TSYNC_ESRCH)
 };
 const struct xlat seccomp_filter_flags[1] = { {
  .data = seccomp_filter_flags_xdata,
  .size = ARRAY_SIZE(seccomp_filter_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/seccomp_filter_flags.in 5.9-0ubuntu2/xlat/seccomp_filter_flags.in
--- 5.5-3/xlat/seccomp_filter_flags.in	2019-01-05 21:14:42.000000000 +0000
+++ 5.9-0ubuntu2/xlat/seccomp_filter_flags.in	2020-04-15 13:39:57.000000000 +0000
@@ -1,4 +1,5 @@
-SECCOMP_FILTER_FLAG_TSYNC 1
-SECCOMP_FILTER_FLAG_LOG 2
-SECCOMP_FILTER_FLAG_SPEC_ALLOW 4
-SECCOMP_FILTER_FLAG_NEW_LISTENER 8
+SECCOMP_FILTER_FLAG_TSYNC		(1<<0)
+SECCOMP_FILTER_FLAG_LOG			(1<<1)
+SECCOMP_FILTER_FLAG_SPEC_ALLOW		(1<<2)
+SECCOMP_FILTER_FLAG_NEW_LISTENER	(1<<3)
+SECCOMP_FILTER_FLAG_TSYNC_ESRCH		(1<<4)
diff -pruN 5.5-3/xlat/seccomp_mode.h 5.9-0ubuntu2/xlat/seccomp_mode.h
--- 5.5-3/xlat/seccomp_mode.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/seccomp_mode.h	2020-09-24 09:18:45.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data seccomp_mode_xdata[] = {
  [SECCOMP_MODE_DISABLED] = XLAT(SECCOMP_MODE_DISABLED),
+ #define XLAT_VAL_0 ((unsigned) (SECCOMP_MODE_DISABLED))
+ #define XLAT_STR_0 STRINGIFY(SECCOMP_MODE_DISABLED)
  [SECCOMP_MODE_STRICT] = XLAT(SECCOMP_MODE_STRICT),
+ #define XLAT_VAL_1 ((unsigned) (SECCOMP_MODE_STRICT))
+ #define XLAT_STR_1 STRINGIFY(SECCOMP_MODE_STRICT)
  [SECCOMP_MODE_FILTER] = XLAT(SECCOMP_MODE_FILTER),
+ #define XLAT_VAL_2 ((unsigned) (SECCOMP_MODE_FILTER))
+ #define XLAT_STR_2 STRINGIFY(SECCOMP_MODE_FILTER)
 };
 static
 const struct xlat seccomp_mode[1] = { {
  .data = seccomp_mode_xdata,
  .size = ARRAY_SIZE(seccomp_mode_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/seccomp_ops.h 5.9-0ubuntu2/xlat/seccomp_ops.h
--- 5.5-3/xlat/seccomp_ops.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/seccomp_ops.h	2020-09-24 09:18:45.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data seccomp_ops_xdata[] = {
  [SECCOMP_SET_MODE_STRICT] = XLAT(SECCOMP_SET_MODE_STRICT),
+ #define XLAT_VAL_0 ((unsigned) (SECCOMP_SET_MODE_STRICT))
+ #define XLAT_STR_0 STRINGIFY(SECCOMP_SET_MODE_STRICT)
  [SECCOMP_SET_MODE_FILTER] = XLAT(SECCOMP_SET_MODE_FILTER),
+ #define XLAT_VAL_1 ((unsigned) (SECCOMP_SET_MODE_FILTER))
+ #define XLAT_STR_1 STRINGIFY(SECCOMP_SET_MODE_FILTER)
  [SECCOMP_GET_ACTION_AVAIL] = XLAT(SECCOMP_GET_ACTION_AVAIL),
+ #define XLAT_VAL_2 ((unsigned) (SECCOMP_GET_ACTION_AVAIL))
+ #define XLAT_STR_2 STRINGIFY(SECCOMP_GET_ACTION_AVAIL)
  [SECCOMP_GET_NOTIF_SIZES] = XLAT(SECCOMP_GET_NOTIF_SIZES),
+ #define XLAT_VAL_3 ((unsigned) (SECCOMP_GET_NOTIF_SIZES))
+ #define XLAT_STR_3 STRINGIFY(SECCOMP_GET_NOTIF_SIZES)
 };
 static
 const struct xlat seccomp_ops[1] = { {
  .data = seccomp_ops_xdata,
  .size = ARRAY_SIZE(seccomp_ops_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/seccomp_ret_action.h 5.9-0ubuntu2/xlat/seccomp_ret_action.h
--- 5.5-3/xlat/seccomp_ret_action.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/seccomp_ret_action.h	2020-09-24 09:18:45.000000000 +0000
@@ -66,20 +66,104 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data seccomp_ret_action_xdata[] = {
  XLAT(SECCOMP_RET_KILL_PROCESS),
+ #define XLAT_VAL_0 ((unsigned) (SECCOMP_RET_KILL_PROCESS))
+ #define XLAT_STR_0 STRINGIFY(SECCOMP_RET_KILL_PROCESS)
  XLAT(SECCOMP_RET_KILL_THREAD),
+ #define XLAT_VAL_1 ((unsigned) (SECCOMP_RET_KILL_THREAD))
+ #define XLAT_STR_1 STRINGIFY(SECCOMP_RET_KILL_THREAD)
  XLAT(SECCOMP_RET_TRAP),
+ #define XLAT_VAL_2 ((unsigned) (SECCOMP_RET_TRAP))
+ #define XLAT_STR_2 STRINGIFY(SECCOMP_RET_TRAP)
  XLAT(SECCOMP_RET_ERRNO),
+ #define XLAT_VAL_3 ((unsigned) (SECCOMP_RET_ERRNO))
+ #define XLAT_STR_3 STRINGIFY(SECCOMP_RET_ERRNO)
  XLAT(SECCOMP_RET_USER_NOTIF),
+ #define XLAT_VAL_4 ((unsigned) (SECCOMP_RET_USER_NOTIF))
+ #define XLAT_STR_4 STRINGIFY(SECCOMP_RET_USER_NOTIF)
  XLAT(SECCOMP_RET_TRACE),
+ #define XLAT_VAL_5 ((unsigned) (SECCOMP_RET_TRACE))
+ #define XLAT_STR_5 STRINGIFY(SECCOMP_RET_TRACE)
  XLAT(SECCOMP_RET_LOG),
+ #define XLAT_VAL_6 ((unsigned) (SECCOMP_RET_LOG))
+ #define XLAT_STR_6 STRINGIFY(SECCOMP_RET_LOG)
  XLAT(SECCOMP_RET_ALLOW),
+ #define XLAT_VAL_7 ((unsigned) (SECCOMP_RET_ALLOW))
+ #define XLAT_STR_7 STRINGIFY(SECCOMP_RET_ALLOW)
 };
 const struct xlat seccomp_ret_action[1] = { {
  .data = seccomp_ret_action_xdata,
  .size = ARRAY_SIZE(seccomp_ret_action_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/semctl_flags.h 5.9-0ubuntu2/xlat/semctl_flags.h
--- 5.5-3/xlat/semctl_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/semctl_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -106,33 +106,179 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 # ifdef IN_MPERS
 
-#  error static const struct xlat semctl_flags in mpers mode
+extern const struct xlat semctl_flags[];
 
 # else
 
 static const struct xlat_data semctl_flags_xdata[] = {
  XLAT(IPC_RMID),
+ #define XLAT_VAL_0 ((unsigned) (IPC_RMID))
+ #define XLAT_STR_0 STRINGIFY(IPC_RMID)
  XLAT(IPC_SET),
+ #define XLAT_VAL_1 ((unsigned) (IPC_SET))
+ #define XLAT_STR_1 STRINGIFY(IPC_SET)
  XLAT(IPC_STAT),
+ #define XLAT_VAL_2 ((unsigned) (IPC_STAT))
+ #define XLAT_STR_2 STRINGIFY(IPC_STAT)
  XLAT(IPC_INFO),
+ #define XLAT_VAL_3 ((unsigned) (IPC_INFO))
+ #define XLAT_STR_3 STRINGIFY(IPC_INFO)
  XLAT(GETPID),
+ #define XLAT_VAL_4 ((unsigned) (GETPID))
+ #define XLAT_STR_4 STRINGIFY(GETPID)
  XLAT(GETVAL),
+ #define XLAT_VAL_5 ((unsigned) (GETVAL))
+ #define XLAT_STR_5 STRINGIFY(GETVAL)
  XLAT(GETALL),
+ #define XLAT_VAL_6 ((unsigned) (GETALL))
+ #define XLAT_STR_6 STRINGIFY(GETALL)
  XLAT(GETNCNT),
+ #define XLAT_VAL_7 ((unsigned) (GETNCNT))
+ #define XLAT_STR_7 STRINGIFY(GETNCNT)
  XLAT(GETZCNT),
+ #define XLAT_VAL_8 ((unsigned) (GETZCNT))
+ #define XLAT_STR_8 STRINGIFY(GETZCNT)
  XLAT(SETVAL),
+ #define XLAT_VAL_9 ((unsigned) (SETVAL))
+ #define XLAT_STR_9 STRINGIFY(SETVAL)
  XLAT(SETALL),
+ #define XLAT_VAL_10 ((unsigned) (SETALL))
+ #define XLAT_STR_10 STRINGIFY(SETALL)
  XLAT(SEM_STAT),
+ #define XLAT_VAL_11 ((unsigned) (SEM_STAT))
+ #define XLAT_STR_11 STRINGIFY(SEM_STAT)
  XLAT(SEM_INFO),
+ #define XLAT_VAL_12 ((unsigned) (SEM_INFO))
+ #define XLAT_STR_12 STRINGIFY(SEM_INFO)
  XLAT(SEM_STAT_ANY),
+ #define XLAT_VAL_13 ((unsigned) (SEM_STAT_ANY))
+ #define XLAT_STR_13 STRINGIFY(SEM_STAT_ANY)
 };
+#  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
+#  endif
 const struct xlat semctl_flags[1] = { {
  .data = semctl_flags_xdata,
  .size = ARRAY_SIZE(semctl_flags_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/semop_flags.h 5.9-0ubuntu2/xlat/semop_flags.h
--- 5.5-3/xlat/semop_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/semop_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -15,9 +15,13 @@
 static const struct xlat_data semop_flags_xdata[] = {
 #if defined(SEM_UNDO) || (defined(HAVE_DECL_SEM_UNDO) && HAVE_DECL_SEM_UNDO)
   XLAT(SEM_UNDO),
+ #define XLAT_VAL_0 ((unsigned) (SEM_UNDO))
+ #define XLAT_STR_0 STRINGIFY(SEM_UNDO)
 #endif
 #if defined(IPC_NOWAIT) || (defined(HAVE_DECL_IPC_NOWAIT) && HAVE_DECL_IPC_NOWAIT)
   XLAT(IPC_NOWAIT),
+ #define XLAT_VAL_1 ((unsigned) (IPC_NOWAIT))
+ #define XLAT_STR_1 STRINGIFY(IPC_NOWAIT)
 #endif
 };
 static
@@ -25,8 +29,28 @@ const struct xlat semop_flags[1] = { {
  .data = semop_flags_xdata,
  .size = ARRAY_SIZE(semop_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/setns_types.h 5.9-0ubuntu2/xlat/setns_types.h
--- 5.5-3/xlat/setns_types.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/setns_types.h	2020-09-24 09:18:45.000000000 +0000
@@ -3,6 +3,13 @@
 #include "gcc_compat.h"
 #include "static_assert.h"
 
+#if defined(CLONE_NEWTIME) || (defined(HAVE_DECL_CLONE_NEWTIME) && HAVE_DECL_CLONE_NEWTIME)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((CLONE_NEWTIME) == (0x00000080), "CLONE_NEWTIME != 0x00000080");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define CLONE_NEWTIME 0x00000080
+#endif
 #if defined(CLONE_NEWNS) || (defined(HAVE_DECL_CLONE_NEWNS) && HAVE_DECL_CLONE_NEWNS)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
 static_assert((CLONE_NEWNS) == (0x00020000), "CLONE_NEWNS != 0x00020000");
@@ -59,20 +66,115 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data setns_types_xdata[] = {
  XLAT(0),
+ #define XLAT_VAL_0 ((unsigned) (0))
+ #define XLAT_STR_0 STRINGIFY(0)
+ XLAT(CLONE_NEWTIME),
+ #define XLAT_VAL_1 ((unsigned) (CLONE_NEWTIME))
+ #define XLAT_STR_1 STRINGIFY(CLONE_NEWTIME)
  XLAT(CLONE_NEWNS),
+ #define XLAT_VAL_2 ((unsigned) (CLONE_NEWNS))
+ #define XLAT_STR_2 STRINGIFY(CLONE_NEWNS)
  XLAT(CLONE_NEWCGROUP),
+ #define XLAT_VAL_3 ((unsigned) (CLONE_NEWCGROUP))
+ #define XLAT_STR_3 STRINGIFY(CLONE_NEWCGROUP)
  XLAT(CLONE_NEWUTS),
+ #define XLAT_VAL_4 ((unsigned) (CLONE_NEWUTS))
+ #define XLAT_STR_4 STRINGIFY(CLONE_NEWUTS)
  XLAT(CLONE_NEWIPC),
+ #define XLAT_VAL_5 ((unsigned) (CLONE_NEWIPC))
+ #define XLAT_STR_5 STRINGIFY(CLONE_NEWIPC)
  XLAT(CLONE_NEWUSER),
+ #define XLAT_VAL_6 ((unsigned) (CLONE_NEWUSER))
+ #define XLAT_STR_6 STRINGIFY(CLONE_NEWUSER)
  XLAT(CLONE_NEWPID),
+ #define XLAT_VAL_7 ((unsigned) (CLONE_NEWPID))
+ #define XLAT_STR_7 STRINGIFY(CLONE_NEWPID)
  XLAT(CLONE_NEWNET),
+ #define XLAT_VAL_8 ((unsigned) (CLONE_NEWNET))
+ #define XLAT_STR_8 STRINGIFY(CLONE_NEWNET)
 };
 const struct xlat setns_types[1] = { {
  .data = setns_types_xdata,
  .size = ARRAY_SIZE(setns_types_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/setns_types.in 5.9-0ubuntu2/xlat/setns_types.in
--- 5.5-3/xlat/setns_types.in	2016-10-28 23:54:01.000000000 +0000
+++ 5.9-0ubuntu2/xlat/setns_types.in	2020-03-01 23:25:39.000000000 +0000
@@ -1,4 +1,5 @@
 0
+CLONE_NEWTIME	0x00000080
 CLONE_NEWNS	0x00020000
 CLONE_NEWCGROUP	0x02000000
 CLONE_NEWUTS	0x04000000
diff -pruN 5.5-3/xlat/setsock_ip_options.h 5.9-0ubuntu2/xlat/setsock_ip_options.h
--- 5.5-3/xlat/setsock_ip_options.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/setsock_ip_options.h	2020-09-24 09:18:46.000000000 +0000
@@ -21,72 +21,116 @@ static const struct xlat_data setsock_ip
 
 #if defined(ARPT_SO_SET_REPLACE) || (defined(HAVE_DECL_ARPT_SO_SET_REPLACE) && HAVE_DECL_ARPT_SO_SET_REPLACE)
   XLAT(ARPT_SO_SET_REPLACE),
+ #define XLAT_VAL_0 ((unsigned) (ARPT_SO_SET_REPLACE))
+ #define XLAT_STR_0 STRINGIFY(ARPT_SO_SET_REPLACE)
 #endif
 #if defined(ARPT_SO_SET_ADD_COUNTERS) || (defined(HAVE_DECL_ARPT_SO_SET_ADD_COUNTERS) && HAVE_DECL_ARPT_SO_SET_ADD_COUNTERS)
   XLAT(ARPT_SO_SET_ADD_COUNTERS),
+ #define XLAT_VAL_1 ((unsigned) (ARPT_SO_SET_ADD_COUNTERS))
+ #define XLAT_STR_1 STRINGIFY(ARPT_SO_SET_ADD_COUNTERS)
 #endif
 
 #if defined(EBT_SO_SET_ENTRIES) || (defined(HAVE_DECL_EBT_SO_SET_ENTRIES) && HAVE_DECL_EBT_SO_SET_ENTRIES)
   XLAT(EBT_SO_SET_ENTRIES),
+ #define XLAT_VAL_2 ((unsigned) (EBT_SO_SET_ENTRIES))
+ #define XLAT_STR_2 STRINGIFY(EBT_SO_SET_ENTRIES)
 #endif
 #if defined(EBT_SO_SET_COUNTERS) || (defined(HAVE_DECL_EBT_SO_SET_COUNTERS) && HAVE_DECL_EBT_SO_SET_COUNTERS)
   XLAT(EBT_SO_SET_COUNTERS),
+ #define XLAT_VAL_3 ((unsigned) (EBT_SO_SET_COUNTERS))
+ #define XLAT_STR_3 STRINGIFY(EBT_SO_SET_COUNTERS)
 #endif
 
 #if defined(IP_VS_SO_SET_NONE) || (defined(HAVE_DECL_IP_VS_SO_SET_NONE) && HAVE_DECL_IP_VS_SO_SET_NONE)
   XLAT(IP_VS_SO_SET_NONE),
+ #define XLAT_VAL_4 ((unsigned) (IP_VS_SO_SET_NONE))
+ #define XLAT_STR_4 STRINGIFY(IP_VS_SO_SET_NONE)
 #endif
 #if defined(IP_VS_SO_SET_INSERT) || (defined(HAVE_DECL_IP_VS_SO_SET_INSERT) && HAVE_DECL_IP_VS_SO_SET_INSERT)
   XLAT(IP_VS_SO_SET_INSERT),
+ #define XLAT_VAL_5 ((unsigned) (IP_VS_SO_SET_INSERT))
+ #define XLAT_STR_5 STRINGIFY(IP_VS_SO_SET_INSERT)
 #endif
 #if defined(IP_VS_SO_SET_ADD) || (defined(HAVE_DECL_IP_VS_SO_SET_ADD) && HAVE_DECL_IP_VS_SO_SET_ADD)
   XLAT(IP_VS_SO_SET_ADD),
+ #define XLAT_VAL_6 ((unsigned) (IP_VS_SO_SET_ADD))
+ #define XLAT_STR_6 STRINGIFY(IP_VS_SO_SET_ADD)
 #endif
 #if defined(IP_VS_SO_SET_EDIT) || (defined(HAVE_DECL_IP_VS_SO_SET_EDIT) && HAVE_DECL_IP_VS_SO_SET_EDIT)
   XLAT(IP_VS_SO_SET_EDIT),
+ #define XLAT_VAL_7 ((unsigned) (IP_VS_SO_SET_EDIT))
+ #define XLAT_STR_7 STRINGIFY(IP_VS_SO_SET_EDIT)
 #endif
 #if defined(IP_VS_SO_SET_DEL) || (defined(HAVE_DECL_IP_VS_SO_SET_DEL) && HAVE_DECL_IP_VS_SO_SET_DEL)
   XLAT(IP_VS_SO_SET_DEL),
+ #define XLAT_VAL_8 ((unsigned) (IP_VS_SO_SET_DEL))
+ #define XLAT_STR_8 STRINGIFY(IP_VS_SO_SET_DEL)
 #endif
 #if defined(IP_VS_SO_SET_FLUSH) || (defined(HAVE_DECL_IP_VS_SO_SET_FLUSH) && HAVE_DECL_IP_VS_SO_SET_FLUSH)
   XLAT(IP_VS_SO_SET_FLUSH),
+ #define XLAT_VAL_9 ((unsigned) (IP_VS_SO_SET_FLUSH))
+ #define XLAT_STR_9 STRINGIFY(IP_VS_SO_SET_FLUSH)
 #endif
 #if defined(IP_VS_SO_SET_LIST) || (defined(HAVE_DECL_IP_VS_SO_SET_LIST) && HAVE_DECL_IP_VS_SO_SET_LIST)
   XLAT(IP_VS_SO_SET_LIST),
+ #define XLAT_VAL_10 ((unsigned) (IP_VS_SO_SET_LIST))
+ #define XLAT_STR_10 STRINGIFY(IP_VS_SO_SET_LIST)
 #endif
 #if defined(IP_VS_SO_SET_ADDDEST) || (defined(HAVE_DECL_IP_VS_SO_SET_ADDDEST) && HAVE_DECL_IP_VS_SO_SET_ADDDEST)
   XLAT(IP_VS_SO_SET_ADDDEST),
+ #define XLAT_VAL_11 ((unsigned) (IP_VS_SO_SET_ADDDEST))
+ #define XLAT_STR_11 STRINGIFY(IP_VS_SO_SET_ADDDEST)
 #endif
 #if defined(IP_VS_SO_SET_DELDEST) || (defined(HAVE_DECL_IP_VS_SO_SET_DELDEST) && HAVE_DECL_IP_VS_SO_SET_DELDEST)
   XLAT(IP_VS_SO_SET_DELDEST),
+ #define XLAT_VAL_12 ((unsigned) (IP_VS_SO_SET_DELDEST))
+ #define XLAT_STR_12 STRINGIFY(IP_VS_SO_SET_DELDEST)
 #endif
 #if defined(IP_VS_SO_SET_EDITDEST) || (defined(HAVE_DECL_IP_VS_SO_SET_EDITDEST) && HAVE_DECL_IP_VS_SO_SET_EDITDEST)
   XLAT(IP_VS_SO_SET_EDITDEST),
+ #define XLAT_VAL_13 ((unsigned) (IP_VS_SO_SET_EDITDEST))
+ #define XLAT_STR_13 STRINGIFY(IP_VS_SO_SET_EDITDEST)
 #endif
 #if defined(IP_VS_SO_SET_TIMEOUT) || (defined(HAVE_DECL_IP_VS_SO_SET_TIMEOUT) && HAVE_DECL_IP_VS_SO_SET_TIMEOUT)
   XLAT(IP_VS_SO_SET_TIMEOUT),
+ #define XLAT_VAL_14 ((unsigned) (IP_VS_SO_SET_TIMEOUT))
+ #define XLAT_STR_14 STRINGIFY(IP_VS_SO_SET_TIMEOUT)
 #endif
 #if defined(IP_VS_SO_SET_STARTDAEMON) || (defined(HAVE_DECL_IP_VS_SO_SET_STARTDAEMON) && HAVE_DECL_IP_VS_SO_SET_STARTDAEMON)
   XLAT(IP_VS_SO_SET_STARTDAEMON),
+ #define XLAT_VAL_15 ((unsigned) (IP_VS_SO_SET_STARTDAEMON))
+ #define XLAT_STR_15 STRINGIFY(IP_VS_SO_SET_STARTDAEMON)
 #endif
 #if defined(IP_VS_SO_SET_STOPDAEMON) || (defined(HAVE_DECL_IP_VS_SO_SET_STOPDAEMON) && HAVE_DECL_IP_VS_SO_SET_STOPDAEMON)
   XLAT(IP_VS_SO_SET_STOPDAEMON),
+ #define XLAT_VAL_16 ((unsigned) (IP_VS_SO_SET_STOPDAEMON))
+ #define XLAT_STR_16 STRINGIFY(IP_VS_SO_SET_STOPDAEMON)
 #endif
 #if defined(IP_VS_SO_SET_RESTORE) || (defined(HAVE_DECL_IP_VS_SO_SET_RESTORE) && HAVE_DECL_IP_VS_SO_SET_RESTORE)
   XLAT(IP_VS_SO_SET_RESTORE),
+ #define XLAT_VAL_17 ((unsigned) (IP_VS_SO_SET_RESTORE))
+ #define XLAT_STR_17 STRINGIFY(IP_VS_SO_SET_RESTORE)
 #endif
 #if defined(IP_VS_SO_SET_SAVE) || (defined(HAVE_DECL_IP_VS_SO_SET_SAVE) && HAVE_DECL_IP_VS_SO_SET_SAVE)
   XLAT(IP_VS_SO_SET_SAVE),
+ #define XLAT_VAL_18 ((unsigned) (IP_VS_SO_SET_SAVE))
+ #define XLAT_STR_18 STRINGIFY(IP_VS_SO_SET_SAVE)
 #endif
 #if defined(IP_VS_SO_SET_ZERO) || (defined(HAVE_DECL_IP_VS_SO_SET_ZERO) && HAVE_DECL_IP_VS_SO_SET_ZERO)
   XLAT(IP_VS_SO_SET_ZERO),
+ #define XLAT_VAL_19 ((unsigned) (IP_VS_SO_SET_ZERO))
+ #define XLAT_STR_19 STRINGIFY(IP_VS_SO_SET_ZERO)
 #endif
 
 #if defined(IPT_SO_SET_REPLACE) || (defined(HAVE_DECL_IPT_SO_SET_REPLACE) && HAVE_DECL_IPT_SO_SET_REPLACE)
   XLAT(IPT_SO_SET_REPLACE),
+ #define XLAT_VAL_20 ((unsigned) (IPT_SO_SET_REPLACE))
+ #define XLAT_STR_20 STRINGIFY(IPT_SO_SET_REPLACE)
 #endif
 #if defined(IPT_SO_SET_ADD_COUNTERS) || (defined(HAVE_DECL_IPT_SO_SET_ADD_COUNTERS) && HAVE_DECL_IPT_SO_SET_ADD_COUNTERS)
   XLAT(IPT_SO_SET_ADD_COUNTERS),
+ #define XLAT_VAL_21 ((unsigned) (IPT_SO_SET_ADD_COUNTERS))
+ #define XLAT_STR_21 STRINGIFY(IPT_SO_SET_ADD_COUNTERS)
 #endif
 };
 static
@@ -94,8 +138,188 @@ const struct xlat setsock_ip_options[1]
  .data = setsock_ip_options_xdata,
  .size = ARRAY_SIZE(setsock_ip_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/setsock_ipv6_options.h 5.9-0ubuntu2/xlat/setsock_ipv6_options.h
--- 5.5-3/xlat/setsock_ipv6_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/setsock_ipv6_options.h	2020-09-24 09:18:45.000000000 +0000
@@ -34,15 +34,39 @@ static const struct xlat_data setsock_ip
 */
 
  XLAT(IP6T_SO_SET_REPLACE),
+ #define XLAT_VAL_0 ((unsigned) (IP6T_SO_SET_REPLACE))
+ #define XLAT_STR_0 STRINGIFY(IP6T_SO_SET_REPLACE)
  XLAT(IP6T_SO_SET_ADD_COUNTERS),
+ #define XLAT_VAL_1 ((unsigned) (IP6T_SO_SET_ADD_COUNTERS))
+ #define XLAT_STR_1 STRINGIFY(IP6T_SO_SET_ADD_COUNTERS)
 };
 static
 const struct xlat setsock_ipv6_options[1] = { {
  .data = setsock_ipv6_options_xdata,
  .size = ARRAY_SIZE(setsock_ipv6_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/setsock_options.h 5.9-0ubuntu2/xlat/setsock_options.h
--- 5.5-3/xlat/setsock_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/setsock_options.h	2020-09-24 09:18:45.000000000 +0000
@@ -33,8 +33,12 @@ static const struct xlat_data setsock_op
 
 #if defined __hppa__
  XLAT(SO_ATTACH_FILTER),
+ #define XLAT_VAL_0 ((unsigned) (SO_ATTACH_FILTER))
+ #define XLAT_STR_0 STRINGIFY(SO_ATTACH_FILTER)
 #else
  XLAT(SO_ATTACH_FILTER),
+ #define XLAT_VAL_1 ((unsigned) (SO_ATTACH_FILTER))
+ #define XLAT_STR_1 STRINGIFY(SO_ATTACH_FILTER)
 #endif
 };
 static
@@ -42,8 +46,28 @@ const struct xlat setsock_options[1] = {
  .data = setsock_options_xdata,
  .size = ARRAY_SIZE(setsock_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sfd_flags.h 5.9-0ubuntu2/xlat/sfd_flags.h
--- 5.5-3/xlat/sfd_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sfd_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -31,16 +31,40 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 static const struct xlat_data sfd_flags_xdata[] = {
 #if defined SFD_CLOEXEC || defined O_CLOEXEC
  XLAT(SFD_CLOEXEC),
+ #define XLAT_VAL_0 ((unsigned) (SFD_CLOEXEC))
+ #define XLAT_STR_0 STRINGIFY(SFD_CLOEXEC)
 #endif
  XLAT(SFD_NONBLOCK),
+ #define XLAT_VAL_1 ((unsigned) (SFD_NONBLOCK))
+ #define XLAT_STR_1 STRINGIFY(SFD_NONBLOCK)
 };
 static
 const struct xlat sfd_flags[1] = { {
  .data = sfd_flags_xdata,
  .size = ARRAY_SIZE(sfd_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sg_io_dxfer_direction.h 5.9-0ubuntu2/xlat/sg_io_dxfer_direction.h
--- 5.5-3/xlat/sg_io_dxfer_direction.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sg_io_dxfer_direction.h	2020-09-24 09:18:45.000000000 +0000
@@ -15,15 +15,23 @@ extern const struct xlat sg_io_dxfer_dir
 static const struct xlat_data sg_io_dxfer_direction_xdata[] = {
 #if defined(SG_DXFER_NONE) || (defined(HAVE_DECL_SG_DXFER_NONE) && HAVE_DECL_SG_DXFER_NONE)
   XLAT(SG_DXFER_NONE),
+ #define XLAT_VAL_0 ((unsigned) (SG_DXFER_NONE))
+ #define XLAT_STR_0 STRINGIFY(SG_DXFER_NONE)
 #endif
 #if defined(SG_DXFER_TO_DEV) || (defined(HAVE_DECL_SG_DXFER_TO_DEV) && HAVE_DECL_SG_DXFER_TO_DEV)
   XLAT(SG_DXFER_TO_DEV),
+ #define XLAT_VAL_1 ((unsigned) (SG_DXFER_TO_DEV))
+ #define XLAT_STR_1 STRINGIFY(SG_DXFER_TO_DEV)
 #endif
 #if defined(SG_DXFER_FROM_DEV) || (defined(HAVE_DECL_SG_DXFER_FROM_DEV) && HAVE_DECL_SG_DXFER_FROM_DEV)
   XLAT(SG_DXFER_FROM_DEV),
+ #define XLAT_VAL_2 ((unsigned) (SG_DXFER_FROM_DEV))
+ #define XLAT_STR_2 STRINGIFY(SG_DXFER_FROM_DEV)
 #endif
 #if defined(SG_DXFER_TO_FROM_DEV) || (defined(HAVE_DECL_SG_DXFER_TO_FROM_DEV) && HAVE_DECL_SG_DXFER_TO_FROM_DEV)
   XLAT(SG_DXFER_TO_FROM_DEV),
+ #define XLAT_VAL_3 ((unsigned) (SG_DXFER_TO_FROM_DEV))
+ #define XLAT_STR_3 STRINGIFY(SG_DXFER_TO_FROM_DEV)
 #endif
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
@@ -33,8 +41,44 @@ const struct xlat sg_io_dxfer_direction[
  .data = sg_io_dxfer_direction_xdata,
  .size = ARRAY_SIZE(sg_io_dxfer_direction_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sg_io_flags.h 5.9-0ubuntu2/xlat/sg_io_flags.h
--- 5.5-3/xlat/sg_io_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sg_io_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -56,11 +56,23 @@ extern const struct xlat sg_io_flags[];
 
 static const struct xlat_data sg_io_flags_xdata[] = {
  XLAT(SG_FLAG_DIRECT_IO),
+ #define XLAT_VAL_0 ((unsigned) (SG_FLAG_DIRECT_IO))
+ #define XLAT_STR_0 STRINGIFY(SG_FLAG_DIRECT_IO)
  XLAT(SG_FLAG_UNUSED_LUN_INHIBIT),
+ #define XLAT_VAL_1 ((unsigned) (SG_FLAG_UNUSED_LUN_INHIBIT))
+ #define XLAT_STR_1 STRINGIFY(SG_FLAG_UNUSED_LUN_INHIBIT)
  XLAT(SG_FLAG_MMAP_IO),
+ #define XLAT_VAL_2 ((unsigned) (SG_FLAG_MMAP_IO))
+ #define XLAT_STR_2 STRINGIFY(SG_FLAG_MMAP_IO)
  XLAT(SG_FLAG_NO_DXFER),
+ #define XLAT_VAL_3 ((unsigned) (SG_FLAG_NO_DXFER))
+ #define XLAT_STR_3 STRINGIFY(SG_FLAG_NO_DXFER)
  XLAT(SG_FLAG_Q_AT_TAIL),
+ #define XLAT_VAL_4 ((unsigned) (SG_FLAG_Q_AT_TAIL))
+ #define XLAT_STR_4 STRINGIFY(SG_FLAG_Q_AT_TAIL)
  XLAT(SG_FLAG_Q_AT_HEAD),
+ #define XLAT_VAL_5 ((unsigned) (SG_FLAG_Q_AT_HEAD))
+ #define XLAT_STR_5 STRINGIFY(SG_FLAG_Q_AT_HEAD)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -69,8 +81,60 @@ const struct xlat sg_io_flags[1] = { {
  .data = sg_io_flags_xdata,
  .size = ARRAY_SIZE(sg_io_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sg_io_info.h 5.9-0ubuntu2/xlat/sg_io_info.h
--- 5.5-3/xlat/sg_io_info.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sg_io_info.h	2020-09-24 09:18:45.000000000 +0000
@@ -31,15 +31,49 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sg_io_info_xdata[] = {
  XLAT(SG_INFO_CHECK),
+ #define XLAT_VAL_0 ((unsigned) (SG_INFO_CHECK))
+ #define XLAT_STR_0 STRINGIFY(SG_INFO_CHECK)
  XLAT(SG_INFO_DIRECT_IO),
+ #define XLAT_VAL_1 ((unsigned) (SG_INFO_DIRECT_IO))
+ #define XLAT_STR_1 STRINGIFY(SG_INFO_DIRECT_IO)
  XLAT(SG_INFO_MIXED_IO),
+ #define XLAT_VAL_2 ((unsigned) (SG_INFO_MIXED_IO))
+ #define XLAT_STR_2 STRINGIFY(SG_INFO_MIXED_IO)
 };
 const struct xlat sg_io_info[1] = { {
  .data = sg_io_info_xdata,
  .size = ARRAY_SIZE(sg_io_info_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sg_scsi_reset.h 5.9-0ubuntu2/xlat/sg_scsi_reset.h
--- 5.5-3/xlat/sg_scsi_reset.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sg_scsi_reset.h	2020-09-24 09:18:45.000000000 +0000
@@ -56,19 +56,83 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sg_scsi_reset_xdata[] = {
  XLAT(SG_SCSI_RESET_NOTHING),
+ #define XLAT_VAL_0 ((unsigned) (SG_SCSI_RESET_NOTHING))
+ #define XLAT_STR_0 STRINGIFY(SG_SCSI_RESET_NOTHING)
  XLAT(SG_SCSI_RESET_DEVICE),
+ #define XLAT_VAL_1 ((unsigned) (SG_SCSI_RESET_DEVICE))
+ #define XLAT_STR_1 STRINGIFY(SG_SCSI_RESET_DEVICE)
  XLAT(SG_SCSI_RESET_BUS),
+ #define XLAT_VAL_2 ((unsigned) (SG_SCSI_RESET_BUS))
+ #define XLAT_STR_2 STRINGIFY(SG_SCSI_RESET_BUS)
  XLAT(SG_SCSI_RESET_HOST),
+ #define XLAT_VAL_3 ((unsigned) (SG_SCSI_RESET_HOST))
+ #define XLAT_STR_3 STRINGIFY(SG_SCSI_RESET_HOST)
  XLAT(SG_SCSI_RESET_TARGET),
+ #define XLAT_VAL_4 ((unsigned) (SG_SCSI_RESET_TARGET))
+ #define XLAT_STR_4 STRINGIFY(SG_SCSI_RESET_TARGET)
  XLAT(SG_SCSI_RESET_NO_ESCALATE),
+ #define XLAT_VAL_5 ((unsigned) (SG_SCSI_RESET_NO_ESCALATE))
+ #define XLAT_STR_5 STRINGIFY(SG_SCSI_RESET_NO_ESCALATE)
 };
 static
 const struct xlat sg_scsi_reset[1] = { {
  .data = sg_scsi_reset_xdata,
  .size = ARRAY_SIZE(sg_scsi_reset_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/shmctl_flags.h 5.9-0ubuntu2/xlat/shmctl_flags.h
--- 5.5-3/xlat/shmctl_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/shmctl_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -77,14 +77,32 @@ extern const struct xlat shmctl_flags[];
 
 static const struct xlat_data shmctl_flags_xdata[] = {
  XLAT(IPC_RMID),
+ #define XLAT_VAL_0 ((unsigned) (IPC_RMID))
+ #define XLAT_STR_0 STRINGIFY(IPC_RMID)
  XLAT(IPC_SET),
+ #define XLAT_VAL_1 ((unsigned) (IPC_SET))
+ #define XLAT_STR_1 STRINGIFY(IPC_SET)
  XLAT(IPC_STAT),
+ #define XLAT_VAL_2 ((unsigned) (IPC_STAT))
+ #define XLAT_STR_2 STRINGIFY(IPC_STAT)
  XLAT(IPC_INFO),
+ #define XLAT_VAL_3 ((unsigned) (IPC_INFO))
+ #define XLAT_STR_3 STRINGIFY(IPC_INFO)
  XLAT(SHM_LOCK),
+ #define XLAT_VAL_4 ((unsigned) (SHM_LOCK))
+ #define XLAT_STR_4 STRINGIFY(SHM_LOCK)
  XLAT(SHM_UNLOCK),
+ #define XLAT_VAL_5 ((unsigned) (SHM_UNLOCK))
+ #define XLAT_STR_5 STRINGIFY(SHM_UNLOCK)
  XLAT(SHM_STAT),
+ #define XLAT_VAL_6 ((unsigned) (SHM_STAT))
+ #define XLAT_STR_6 STRINGIFY(SHM_STAT)
  XLAT(SHM_INFO),
+ #define XLAT_VAL_7 ((unsigned) (SHM_INFO))
+ #define XLAT_STR_7 STRINGIFY(SHM_INFO)
  XLAT(SHM_STAT_ANY),
+ #define XLAT_VAL_8 ((unsigned) (SHM_STAT_ANY))
+ #define XLAT_STR_8 STRINGIFY(SHM_STAT_ANY)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -93,8 +111,84 @@ const struct xlat shmctl_flags[1] = { {
  .data = shmctl_flags_xdata,
  .size = ARRAY_SIZE(shmctl_flags_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/shm_flags.h 5.9-0ubuntu2/xlat/shm_flags.h
--- 5.5-3/xlat/shm_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/shm_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data shm_flags_xdata[] = {
  XLAT(SHM_RDONLY),
+ #define XLAT_VAL_0 ((unsigned) (SHM_RDONLY))
+ #define XLAT_STR_0 STRINGIFY(SHM_RDONLY)
  XLAT(SHM_RND),
+ #define XLAT_VAL_1 ((unsigned) (SHM_RND))
+ #define XLAT_STR_1 STRINGIFY(SHM_RND)
  XLAT(SHM_REMAP),
+ #define XLAT_VAL_2 ((unsigned) (SHM_REMAP))
+ #define XLAT_STR_2 STRINGIFY(SHM_REMAP)
  XLAT(SHM_EXEC),
+ #define XLAT_VAL_3 ((unsigned) (SHM_EXEC))
+ #define XLAT_STR_3 STRINGIFY(SHM_EXEC)
 };
 static
 const struct xlat shm_flags[1] = { {
  .data = shm_flags_xdata,
  .size = ARRAY_SIZE(shm_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/shm_resource_flags.h 5.9-0ubuntu2/xlat/shm_resource_flags.h
--- 5.5-3/xlat/shm_resource_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/shm_resource_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data shm_resource_flags_xdata[] = {
  XLAT(IPC_CREAT),
+ #define XLAT_VAL_0 ((unsigned) (IPC_CREAT))
+ #define XLAT_STR_0 STRINGIFY(IPC_CREAT)
  XLAT(IPC_EXCL),
+ #define XLAT_VAL_1 ((unsigned) (IPC_EXCL))
+ #define XLAT_STR_1 STRINGIFY(IPC_EXCL)
  XLAT(SHM_HUGETLB),
+ #define XLAT_VAL_2 ((unsigned) (SHM_HUGETLB))
+ #define XLAT_STR_2 STRINGIFY(SHM_HUGETLB)
  XLAT(SHM_NORESERVE),
+ #define XLAT_VAL_3 ((unsigned) (SHM_NORESERVE))
+ #define XLAT_STR_3 STRINGIFY(SHM_NORESERVE)
 };
 static
 const struct xlat shm_resource_flags[1] = { {
  .data = shm_resource_flags_xdata,
  .size = ARRAY_SIZE(shm_resource_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/shutdown_modes.h 5.9-0ubuntu2/xlat/shutdown_modes.h
--- 5.5-3/xlat/shutdown_modes.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/shutdown_modes.h	2020-09-24 09:18:45.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data shutdown_modes_xdata[] = {
  [SHUT_RD] = XLAT(SHUT_RD),
+ #define XLAT_VAL_0 ((unsigned) (SHUT_RD))
+ #define XLAT_STR_0 STRINGIFY(SHUT_RD)
  [SHUT_WR] = XLAT(SHUT_WR),
+ #define XLAT_VAL_1 ((unsigned) (SHUT_WR))
+ #define XLAT_STR_1 STRINGIFY(SHUT_WR)
  [SHUT_RDWR] = XLAT(SHUT_RDWR),
+ #define XLAT_VAL_2 ((unsigned) (SHUT_RDWR))
+ #define XLAT_STR_2 STRINGIFY(SHUT_RDWR)
 };
 static
 const struct xlat shutdown_modes[1] = { {
  .data = shutdown_modes_xdata,
  .size = ARRAY_SIZE(shutdown_modes_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sigact_flags.h 5.9-0ubuntu2/xlat/sigact_flags.h
--- 5.5-3/xlat/sigact_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sigact_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -19,55 +19,87 @@
 static const struct xlat_data sigact_flags_xdata[] = {
 #if defined(SA_RESTORER) || (defined(HAVE_DECL_SA_RESTORER) && HAVE_DECL_SA_RESTORER)
   XLAT(SA_RESTORER),
+ #define XLAT_VAL_0 ((unsigned) (SA_RESTORER))
+ #define XLAT_STR_0 STRINGIFY(SA_RESTORER)
 #endif
 #if defined(SA_ONSTACK) || (defined(HAVE_DECL_SA_ONSTACK) && HAVE_DECL_SA_ONSTACK)
   XLAT(SA_ONSTACK),
+ #define XLAT_VAL_1 ((unsigned) (SA_ONSTACK))
+ #define XLAT_STR_1 STRINGIFY(SA_ONSTACK)
 #endif
 #if defined(SA_RESTART) || (defined(HAVE_DECL_SA_RESTART) && HAVE_DECL_SA_RESTART)
   XLAT(SA_RESTART),
+ #define XLAT_VAL_2 ((unsigned) (SA_RESTART))
+ #define XLAT_STR_2 STRINGIFY(SA_RESTART)
 #endif
 #if defined(SA_INTERRUPT) || (defined(HAVE_DECL_SA_INTERRUPT) && HAVE_DECL_SA_INTERRUPT)
   XLAT(SA_INTERRUPT),
+ #define XLAT_VAL_3 ((unsigned) (SA_INTERRUPT))
+ #define XLAT_STR_3 STRINGIFY(SA_INTERRUPT)
 #endif
 #if defined(SA_NODEFER) || (defined(HAVE_DECL_SA_NODEFER) && HAVE_DECL_SA_NODEFER)
   XLAT(SA_NODEFER),
+ #define XLAT_VAL_4 ((unsigned) (SA_NODEFER))
+ #define XLAT_STR_4 STRINGIFY(SA_NODEFER)
 #endif
 #if defined SA_NOMASK && SA_NODEFER != SA_NOMASK
 #if defined(SA_NOMASK) || (defined(HAVE_DECL_SA_NOMASK) && HAVE_DECL_SA_NOMASK)
   XLAT(SA_NOMASK),
+ #define XLAT_VAL_5 ((unsigned) (SA_NOMASK))
+ #define XLAT_STR_5 STRINGIFY(SA_NOMASK)
 #endif
 #endif
 #if defined(SA_RESETHAND) || (defined(HAVE_DECL_SA_RESETHAND) && HAVE_DECL_SA_RESETHAND)
   XLAT(SA_RESETHAND),
+ #define XLAT_VAL_6 ((unsigned) (SA_RESETHAND))
+ #define XLAT_STR_6 STRINGIFY(SA_RESETHAND)
 #endif
 #if defined SA_ONESHOT && SA_ONESHOT != SA_RESETHAND
 #if defined(SA_ONESHOT) || (defined(HAVE_DECL_SA_ONESHOT) && HAVE_DECL_SA_ONESHOT)
   XLAT(SA_ONESHOT),
+ #define XLAT_VAL_7 ((unsigned) (SA_ONESHOT))
+ #define XLAT_STR_7 STRINGIFY(SA_ONESHOT)
 #endif
 #endif
 #if defined(SA_SIGINFO) || (defined(HAVE_DECL_SA_SIGINFO) && HAVE_DECL_SA_SIGINFO)
   XLAT(SA_SIGINFO),
+ #define XLAT_VAL_8 ((unsigned) (SA_SIGINFO))
+ #define XLAT_STR_8 STRINGIFY(SA_SIGINFO)
 #endif
 #if defined(SA_RESETHAND) || (defined(HAVE_DECL_SA_RESETHAND) && HAVE_DECL_SA_RESETHAND)
   XLAT(SA_RESETHAND),
+ #define XLAT_VAL_9 ((unsigned) (SA_RESETHAND))
+ #define XLAT_STR_9 STRINGIFY(SA_RESETHAND)
 #endif
 #if defined(SA_ONSTACK) || (defined(HAVE_DECL_SA_ONSTACK) && HAVE_DECL_SA_ONSTACK)
   XLAT(SA_ONSTACK),
+ #define XLAT_VAL_10 ((unsigned) (SA_ONSTACK))
+ #define XLAT_STR_10 STRINGIFY(SA_ONSTACK)
 #endif
 #if defined(SA_NODEFER) || (defined(HAVE_DECL_SA_NODEFER) && HAVE_DECL_SA_NODEFER)
   XLAT(SA_NODEFER),
+ #define XLAT_VAL_11 ((unsigned) (SA_NODEFER))
+ #define XLAT_STR_11 STRINGIFY(SA_NODEFER)
 #endif
 #if defined(SA_NOCLDSTOP) || (defined(HAVE_DECL_SA_NOCLDSTOP) && HAVE_DECL_SA_NOCLDSTOP)
   XLAT(SA_NOCLDSTOP),
+ #define XLAT_VAL_12 ((unsigned) (SA_NOCLDSTOP))
+ #define XLAT_STR_12 STRINGIFY(SA_NOCLDSTOP)
 #endif
 #if defined(SA_NOCLDWAIT) || (defined(HAVE_DECL_SA_NOCLDWAIT) && HAVE_DECL_SA_NOCLDWAIT)
   XLAT(SA_NOCLDWAIT),
+ #define XLAT_VAL_13 ((unsigned) (SA_NOCLDWAIT))
+ #define XLAT_STR_13 STRINGIFY(SA_NOCLDWAIT)
 #endif
 #if defined(_SA_BSDCALL) || (defined(HAVE_DECL__SA_BSDCALL) && HAVE_DECL__SA_BSDCALL)
   XLAT(_SA_BSDCALL),
+ #define XLAT_VAL_14 ((unsigned) (_SA_BSDCALL))
+ #define XLAT_STR_14 STRINGIFY(_SA_BSDCALL)
 #endif
 #if defined(SA_NOPTRACE) || (defined(HAVE_DECL_SA_NOPTRACE) && HAVE_DECL_SA_NOPTRACE)
   XLAT(SA_NOPTRACE),
+ #define XLAT_VAL_15 ((unsigned) (SA_NOPTRACE))
+ #define XLAT_STR_15 STRINGIFY(SA_NOPTRACE)
 #endif
 };
 static
@@ -75,8 +107,140 @@ const struct xlat sigact_flags[1] = { {
  .data = sigact_flags_xdata,
  .size = ARRAY_SIZE(sigact_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sigaltstack_flags.h 5.9-0ubuntu2/xlat/sigaltstack_flags.h
--- 5.5-3/xlat/sigaltstack_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sigaltstack_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -35,8 +35,14 @@ extern const struct xlat sigaltstack_fla
 
 static const struct xlat_data sigaltstack_flags_xdata[] = {
  XLAT(SS_ONSTACK),
+ #define XLAT_VAL_0 ((unsigned) (SS_ONSTACK))
+ #define XLAT_STR_0 STRINGIFY(SS_ONSTACK)
  XLAT(SS_DISABLE),
+ #define XLAT_VAL_1 ((unsigned) (SS_DISABLE))
+ #define XLAT_STR_1 STRINGIFY(SS_DISABLE)
  XLAT(SS_AUTODISARM),
+ #define XLAT_VAL_2 ((unsigned) (SS_AUTODISARM))
+ #define XLAT_STR_2 STRINGIFY(SS_AUTODISARM)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -45,8 +51,36 @@ const struct xlat sigaltstack_flags[1] =
  .data = sigaltstack_flags_xdata,
  .size = ARRAY_SIZE(sigaltstack_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sigbus_codes.h 5.9-0ubuntu2/xlat/sigbus_codes.h
--- 5.5-3/xlat/sigbus_codes.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sigbus_codes.h	2020-09-24 09:18:45.000000000 +0000
@@ -49,13 +49,25 @@ extern const struct xlat sigbus_codes[];
 
 static const struct xlat_data sigbus_codes_xdata[] = {
  XLAT(BUS_ADRALN),
+ #define XLAT_VAL_0 ((unsigned) (BUS_ADRALN))
+ #define XLAT_STR_0 STRINGIFY(BUS_ADRALN)
  XLAT(BUS_ADRERR),
+ #define XLAT_VAL_1 ((unsigned) (BUS_ADRERR))
+ #define XLAT_STR_1 STRINGIFY(BUS_ADRERR)
  XLAT(BUS_OBJERR),
+ #define XLAT_VAL_2 ((unsigned) (BUS_OBJERR))
+ #define XLAT_STR_2 STRINGIFY(BUS_OBJERR)
 #if defined(BUS_OPFETCH) || (defined(HAVE_DECL_BUS_OPFETCH) && HAVE_DECL_BUS_OPFETCH)
   XLAT(BUS_OPFETCH),
+ #define XLAT_VAL_3 ((unsigned) (BUS_OPFETCH))
+ #define XLAT_STR_3 STRINGIFY(BUS_OPFETCH)
 #endif
  XLAT(BUS_MCEERR_AR),
+ #define XLAT_VAL_4 ((unsigned) (BUS_MCEERR_AR))
+ #define XLAT_STR_4 STRINGIFY(BUS_MCEERR_AR)
  XLAT(BUS_MCEERR_AO),
+ #define XLAT_VAL_5 ((unsigned) (BUS_MCEERR_AO))
+ #define XLAT_STR_5 STRINGIFY(BUS_MCEERR_AO)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -64,8 +76,60 @@ const struct xlat sigbus_codes[1] = { {
  .data = sigbus_codes_xdata,
  .size = ARRAY_SIZE(sigbus_codes_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sigchld_codes.h 5.9-0ubuntu2/xlat/sigchld_codes.h
--- 5.5-3/xlat/sigchld_codes.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sigchld_codes.h	2020-09-24 09:18:45.000000000 +0000
@@ -56,11 +56,23 @@ extern const struct xlat sigchld_codes[]
 
 static const struct xlat_data sigchld_codes_xdata[] = {
  [CLD_EXITED] = XLAT(CLD_EXITED),
+ #define XLAT_VAL_0 ((unsigned) (CLD_EXITED))
+ #define XLAT_STR_0 STRINGIFY(CLD_EXITED)
  [CLD_KILLED] = XLAT(CLD_KILLED),
+ #define XLAT_VAL_1 ((unsigned) (CLD_KILLED))
+ #define XLAT_STR_1 STRINGIFY(CLD_KILLED)
  [CLD_DUMPED] = XLAT(CLD_DUMPED),
+ #define XLAT_VAL_2 ((unsigned) (CLD_DUMPED))
+ #define XLAT_STR_2 STRINGIFY(CLD_DUMPED)
  [CLD_TRAPPED] = XLAT(CLD_TRAPPED),
+ #define XLAT_VAL_3 ((unsigned) (CLD_TRAPPED))
+ #define XLAT_STR_3 STRINGIFY(CLD_TRAPPED)
  [CLD_STOPPED] = XLAT(CLD_STOPPED),
+ #define XLAT_VAL_4 ((unsigned) (CLD_STOPPED))
+ #define XLAT_STR_4 STRINGIFY(CLD_STOPPED)
  [CLD_CONTINUED] = XLAT(CLD_CONTINUED),
+ #define XLAT_VAL_5 ((unsigned) (CLD_CONTINUED))
+ #define XLAT_STR_5 STRINGIFY(CLD_CONTINUED)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -69,8 +81,60 @@ const struct xlat sigchld_codes[1] = { {
  .data = sigchld_codes_xdata,
  .size = ARRAY_SIZE(sigchld_codes_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sigemt_codes.h 5.9-0ubuntu2/xlat/sigemt_codes.h
--- 5.5-3/xlat/sigemt_codes.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sigemt_codes.h	2020-09-24 09:18:45.000000000 +0000
@@ -21,6 +21,8 @@ extern const struct xlat sigemt_codes[];
 
 static const struct xlat_data sigemt_codes_xdata[] = {
  XLAT(EMT_TAGOVF),
+ #define XLAT_VAL_0 ((unsigned) (EMT_TAGOVF))
+ #define XLAT_STR_0 STRINGIFY(EMT_TAGOVF)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -29,8 +31,20 @@ const struct xlat sigemt_codes[1] = { {
  .data = sigemt_codes_xdata,
  .size = ARRAY_SIZE(sigemt_codes_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sigev_value.h 5.9-0ubuntu2/xlat/sigev_value.h
--- 5.5-3/xlat/sigev_value.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sigev_value.h	2020-09-24 09:18:46.000000000 +0000
@@ -42,9 +42,17 @@ extern const struct xlat sigev_value[];
 
 static const struct xlat_data sigev_value_xdata[] = {
  [SIGEV_SIGNAL] = XLAT(SIGEV_SIGNAL),
+ #define XLAT_VAL_0 ((unsigned) (SIGEV_SIGNAL))
+ #define XLAT_STR_0 STRINGIFY(SIGEV_SIGNAL)
  [SIGEV_NONE] = XLAT(SIGEV_NONE),
+ #define XLAT_VAL_1 ((unsigned) (SIGEV_NONE))
+ #define XLAT_STR_1 STRINGIFY(SIGEV_NONE)
  [SIGEV_THREAD] = XLAT(SIGEV_THREAD),
+ #define XLAT_VAL_2 ((unsigned) (SIGEV_THREAD))
+ #define XLAT_STR_2 STRINGIFY(SIGEV_THREAD)
  [SIGEV_THREAD_ID] = XLAT(SIGEV_THREAD_ID),
+ #define XLAT_VAL_3 ((unsigned) (SIGEV_THREAD_ID))
+ #define XLAT_STR_3 STRINGIFY(SIGEV_THREAD_ID)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -53,8 +61,44 @@ const struct xlat sigev_value[1] = { {
  .data = sigev_value_xdata,
  .size = ARRAY_SIZE(sigev_value_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sigfpe_codes.h 5.9-0ubuntu2/xlat/sigfpe_codes.h
--- 5.5-3/xlat/sigfpe_codes.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sigfpe_codes.h	2020-09-24 09:18:46.000000000 +0000
@@ -84,33 +84,65 @@ extern const struct xlat sigfpe_codes[];
 
 static const struct xlat_data sigfpe_codes_xdata[] = {
  XLAT(FPE_INTDIV),
+ #define XLAT_VAL_0 ((unsigned) (FPE_INTDIV))
+ #define XLAT_STR_0 STRINGIFY(FPE_INTDIV)
  XLAT(FPE_INTOVF),
+ #define XLAT_VAL_1 ((unsigned) (FPE_INTOVF))
+ #define XLAT_STR_1 STRINGIFY(FPE_INTOVF)
  XLAT(FPE_FLTDIV),
+ #define XLAT_VAL_2 ((unsigned) (FPE_FLTDIV))
+ #define XLAT_STR_2 STRINGIFY(FPE_FLTDIV)
  XLAT(FPE_FLTOVF),
+ #define XLAT_VAL_3 ((unsigned) (FPE_FLTOVF))
+ #define XLAT_STR_3 STRINGIFY(FPE_FLTOVF)
  XLAT(FPE_FLTUND),
+ #define XLAT_VAL_4 ((unsigned) (FPE_FLTUND))
+ #define XLAT_STR_4 STRINGIFY(FPE_FLTUND)
  XLAT(FPE_FLTRES),
+ #define XLAT_VAL_5 ((unsigned) (FPE_FLTRES))
+ #define XLAT_STR_5 STRINGIFY(FPE_FLTRES)
  XLAT(FPE_FLTINV),
+ #define XLAT_VAL_6 ((unsigned) (FPE_FLTINV))
+ #define XLAT_STR_6 STRINGIFY(FPE_FLTINV)
  XLAT(FPE_FLTSUB),
+ #define XLAT_VAL_7 ((unsigned) (FPE_FLTSUB))
+ #define XLAT_STR_7 STRINGIFY(FPE_FLTSUB)
 #if defined(FPE_MDAOVF) || (defined(HAVE_DECL_FPE_MDAOVF) && HAVE_DECL_FPE_MDAOVF)
   XLAT(FPE_MDAOVF),
+ #define XLAT_VAL_8 ((unsigned) (FPE_MDAOVF))
+ #define XLAT_STR_8 STRINGIFY(FPE_MDAOVF)
 #endif
 #if defined(__FPE_DECOVF) || (defined(HAVE_DECL___FPE_DECOVF) && HAVE_DECL___FPE_DECOVF)
   XLAT(__FPE_DECOVF),
+ #define XLAT_VAL_9 ((unsigned) (__FPE_DECOVF))
+ #define XLAT_STR_9 STRINGIFY(__FPE_DECOVF)
 #endif
 #if defined(__FPE_DECDIV) || (defined(HAVE_DECL___FPE_DECDIV) && HAVE_DECL___FPE_DECDIV)
   XLAT(__FPE_DECDIV),
+ #define XLAT_VAL_10 ((unsigned) (__FPE_DECDIV))
+ #define XLAT_STR_10 STRINGIFY(__FPE_DECDIV)
 #endif
 #if defined(__FPE_DECERR) || (defined(HAVE_DECL___FPE_DECERR) && HAVE_DECL___FPE_DECERR)
   XLAT(__FPE_DECERR),
+ #define XLAT_VAL_11 ((unsigned) (__FPE_DECERR))
+ #define XLAT_STR_11 STRINGIFY(__FPE_DECERR)
 #endif
 #if defined(__FPE_INVASC) || (defined(HAVE_DECL___FPE_INVASC) && HAVE_DECL___FPE_INVASC)
   XLAT(__FPE_INVASC),
+ #define XLAT_VAL_12 ((unsigned) (__FPE_INVASC))
+ #define XLAT_STR_12 STRINGIFY(__FPE_INVASC)
 #endif
 #if defined(__FPE_INVDEC) || (defined(HAVE_DECL___FPE_INVDEC) && HAVE_DECL___FPE_INVDEC)
   XLAT(__FPE_INVDEC),
+ #define XLAT_VAL_13 ((unsigned) (__FPE_INVDEC))
+ #define XLAT_STR_13 STRINGIFY(__FPE_INVDEC)
 #endif
  XLAT(FPE_FLTUNK),
+ #define XLAT_VAL_14 ((unsigned) (FPE_FLTUNK))
+ #define XLAT_STR_14 STRINGIFY(FPE_FLTUNK)
  XLAT(FPE_CONDTRAP),
+ #define XLAT_VAL_15 ((unsigned) (FPE_CONDTRAP))
+ #define XLAT_STR_15 STRINGIFY(FPE_CONDTRAP)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -119,8 +151,140 @@ const struct xlat sigfpe_codes[1] = { {
  .data = sigfpe_codes_xdata,
  .size = ARRAY_SIZE(sigfpe_codes_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sigill_codes.h 5.9-0ubuntu2/xlat/sigill_codes.h
--- 5.5-3/xlat/sigill_codes.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sigill_codes.h	2020-09-24 09:18:46.000000000 +0000
@@ -70,42 +70,78 @@ extern const struct xlat sigill_codes[];
 
 static const struct xlat_data sigill_codes_xdata[] = {
  XLAT(ILL_ILLOPC),
+ #define XLAT_VAL_0 ((unsigned) (ILL_ILLOPC))
+ #define XLAT_STR_0 STRINGIFY(ILL_ILLOPC)
 #if defined(ILL_ILLPARAOP) || (defined(HAVE_DECL_ILL_ILLPARAOP) && HAVE_DECL_ILL_ILLPARAOP)
   XLAT(ILL_ILLPARAOP),
+ #define XLAT_VAL_1 ((unsigned) (ILL_ILLPARAOP))
+ #define XLAT_STR_1 STRINGIFY(ILL_ILLPARAOP)
 #endif
  XLAT(ILL_ILLOPN),
+ #define XLAT_VAL_2 ((unsigned) (ILL_ILLOPN))
+ #define XLAT_STR_2 STRINGIFY(ILL_ILLOPN)
  XLAT(ILL_ILLADR),
+ #define XLAT_VAL_3 ((unsigned) (ILL_ILLADR))
+ #define XLAT_STR_3 STRINGIFY(ILL_ILLADR)
 #if defined(ILL_ILLEXCPT) || (defined(HAVE_DECL_ILL_ILLEXCPT) && HAVE_DECL_ILL_ILLEXCPT)
   XLAT(ILL_ILLEXCPT),
+ #define XLAT_VAL_4 ((unsigned) (ILL_ILLEXCPT))
+ #define XLAT_STR_4 STRINGIFY(ILL_ILLEXCPT)
 #endif
  XLAT(ILL_ILLTRP),
+ #define XLAT_VAL_5 ((unsigned) (ILL_ILLTRP))
+ #define XLAT_STR_5 STRINGIFY(ILL_ILLTRP)
  XLAT(ILL_PRVOPC),
+ #define XLAT_VAL_6 ((unsigned) (ILL_PRVOPC))
+ #define XLAT_STR_6 STRINGIFY(ILL_PRVOPC)
  XLAT(ILL_PRVREG),
+ #define XLAT_VAL_7 ((unsigned) (ILL_PRVREG))
+ #define XLAT_STR_7 STRINGIFY(ILL_PRVREG)
  XLAT(ILL_COPROC),
+ #define XLAT_VAL_8 ((unsigned) (ILL_COPROC))
+ #define XLAT_STR_8 STRINGIFY(ILL_COPROC)
  XLAT(ILL_BADSTK),
+ #define XLAT_VAL_9 ((unsigned) (ILL_BADSTK))
+ #define XLAT_STR_9 STRINGIFY(ILL_BADSTK)
 #if defined(ILL_CPLB_VI) || (defined(HAVE_DECL_ILL_CPLB_VI) && HAVE_DECL_ILL_CPLB_VI)
   XLAT(ILL_CPLB_VI),
+ #define XLAT_VAL_10 ((unsigned) (ILL_CPLB_VI))
+ #define XLAT_STR_10 STRINGIFY(ILL_CPLB_VI)
 #endif
 #if defined(ILL_CPLB_MISS) || (defined(HAVE_DECL_ILL_CPLB_MISS) && HAVE_DECL_ILL_CPLB_MISS)
   XLAT(ILL_CPLB_MISS),
+ #define XLAT_VAL_11 ((unsigned) (ILL_CPLB_MISS))
+ #define XLAT_STR_11 STRINGIFY(ILL_CPLB_MISS)
 #endif
 #if defined(ILL_CPLB_MULHIT) || (defined(HAVE_DECL_ILL_CPLB_MULHIT) && HAVE_DECL_ILL_CPLB_MULHIT)
   XLAT(ILL_CPLB_MULHIT),
+ #define XLAT_VAL_12 ((unsigned) (ILL_CPLB_MULHIT))
+ #define XLAT_STR_12 STRINGIFY(ILL_CPLB_MULHIT)
 #endif
 #if defined(ILL_DBLFLT) || (defined(HAVE_DECL_ILL_DBLFLT) && HAVE_DECL_ILL_DBLFLT)
   XLAT(ILL_DBLFLT),
+ #define XLAT_VAL_13 ((unsigned) (ILL_DBLFLT))
+ #define XLAT_STR_13 STRINGIFY(ILL_DBLFLT)
 #endif
 #if defined(ILL_HARDWALL) || (defined(HAVE_DECL_ILL_HARDWALL) && HAVE_DECL_ILL_HARDWALL)
   XLAT(ILL_HARDWALL),
+ #define XLAT_VAL_14 ((unsigned) (ILL_HARDWALL))
+ #define XLAT_STR_14 STRINGIFY(ILL_HARDWALL)
 #endif
 #if defined(ILL_BADIADDR) || (defined(HAVE_DECL_ILL_BADIADDR) && HAVE_DECL_ILL_BADIADDR)
   XLAT(ILL_BADIADDR),
+ #define XLAT_VAL_15 ((unsigned) (ILL_BADIADDR))
+ #define XLAT_STR_15 STRINGIFY(ILL_BADIADDR)
 #endif
 #if defined(__ILL_BREAK) || (defined(HAVE_DECL___ILL_BREAK) && HAVE_DECL___ILL_BREAK)
   XLAT(__ILL_BREAK),
+ #define XLAT_VAL_16 ((unsigned) (__ILL_BREAK))
+ #define XLAT_STR_16 STRINGIFY(__ILL_BREAK)
 #endif
 #if defined(__ILL_BNDMOD) || (defined(HAVE_DECL___ILL_BNDMOD) && HAVE_DECL___ILL_BNDMOD)
   XLAT(__ILL_BNDMOD),
+ #define XLAT_VAL_17 ((unsigned) (__ILL_BNDMOD))
+ #define XLAT_STR_17 STRINGIFY(__ILL_BNDMOD)
 #endif
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
@@ -115,8 +151,156 @@ const struct xlat sigill_codes[1] = { {
  .data = sigill_codes_xdata,
  .size = ARRAY_SIZE(sigill_codes_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/siginfo_codes.h 5.9-0ubuntu2/xlat/siginfo_codes.h
--- 5.5-3/xlat/siginfo_codes.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/siginfo_codes.h	2020-09-24 09:18:46.000000000 +0000
@@ -117,26 +117,54 @@ extern const struct xlat siginfo_codes[]
 
 static const struct xlat_data siginfo_codes_xdata[] = {
  XLAT(SI_USER),
+ #define XLAT_VAL_0 ((unsigned) (SI_USER))
+ #define XLAT_STR_0 STRINGIFY(SI_USER)
  XLAT(SI_KERNEL),
+ #define XLAT_VAL_1 ((unsigned) (SI_KERNEL))
+ #define XLAT_STR_1 STRINGIFY(SI_KERNEL)
  XLAT(SI_QUEUE),
+ #define XLAT_VAL_2 ((unsigned) (SI_QUEUE))
+ #define XLAT_STR_2 STRINGIFY(SI_QUEUE)
 
 #ifdef __mips__
  XLAT(SI_ASYNCIO),
+ #define XLAT_VAL_3 ((unsigned) (SI_ASYNCIO))
+ #define XLAT_STR_3 STRINGIFY(SI_ASYNCIO)
  XLAT(SI_TIMER),
+ #define XLAT_VAL_4 ((unsigned) (SI_TIMER))
+ #define XLAT_STR_4 STRINGIFY(SI_TIMER)
  XLAT(SI_MESGQ),
+ #define XLAT_VAL_5 ((unsigned) (SI_MESGQ))
+ #define XLAT_STR_5 STRINGIFY(SI_MESGQ)
 #else
  XLAT(SI_TIMER),
+ #define XLAT_VAL_6 ((unsigned) (SI_TIMER))
+ #define XLAT_STR_6 STRINGIFY(SI_TIMER)
  XLAT(SI_MESGQ),
+ #define XLAT_VAL_7 ((unsigned) (SI_MESGQ))
+ #define XLAT_STR_7 STRINGIFY(SI_MESGQ)
  XLAT(SI_ASYNCIO),
+ #define XLAT_VAL_8 ((unsigned) (SI_ASYNCIO))
+ #define XLAT_STR_8 STRINGIFY(SI_ASYNCIO)
 #endif
 
  XLAT(SI_SIGIO),
+ #define XLAT_VAL_9 ((unsigned) (SI_SIGIO))
+ #define XLAT_STR_9 STRINGIFY(SI_SIGIO)
  XLAT(SI_TKILL),
+ #define XLAT_VAL_10 ((unsigned) (SI_TKILL))
+ #define XLAT_STR_10 STRINGIFY(SI_TKILL)
  XLAT(SI_DETHREAD),
+ #define XLAT_VAL_11 ((unsigned) (SI_DETHREAD))
+ #define XLAT_STR_11 STRINGIFY(SI_DETHREAD)
  XLAT(SI_ASYNCNL),
+ #define XLAT_VAL_12 ((unsigned) (SI_ASYNCNL))
+ #define XLAT_STR_12 STRINGIFY(SI_ASYNCNL)
 
 #ifdef __sparc__
  XLAT(SI_NOINFO),
+ #define XLAT_VAL_13 ((unsigned) (SI_NOINFO))
+ #define XLAT_STR_13 STRINGIFY(SI_NOINFO)
 #endif
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
@@ -146,8 +174,124 @@ const struct xlat siginfo_codes[1] = { {
  .data = siginfo_codes_xdata,
  .size = ARRAY_SIZE(siginfo_codes_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sigpoll_codes.h 5.9-0ubuntu2/xlat/sigpoll_codes.h
--- 5.5-3/xlat/sigpoll_codes.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sigpoll_codes.h	2020-09-24 09:18:45.000000000 +0000
@@ -56,11 +56,23 @@ extern const struct xlat sigpoll_codes[]
 
 static const struct xlat_data sigpoll_codes_xdata[] = {
  [POLL_IN] = XLAT(POLL_IN),
+ #define XLAT_VAL_0 ((unsigned) (POLL_IN))
+ #define XLAT_STR_0 STRINGIFY(POLL_IN)
  [POLL_OUT] = XLAT(POLL_OUT),
+ #define XLAT_VAL_1 ((unsigned) (POLL_OUT))
+ #define XLAT_STR_1 STRINGIFY(POLL_OUT)
  [POLL_MSG] = XLAT(POLL_MSG),
+ #define XLAT_VAL_2 ((unsigned) (POLL_MSG))
+ #define XLAT_STR_2 STRINGIFY(POLL_MSG)
  [POLL_ERR] = XLAT(POLL_ERR),
+ #define XLAT_VAL_3 ((unsigned) (POLL_ERR))
+ #define XLAT_STR_3 STRINGIFY(POLL_ERR)
  [POLL_PRI] = XLAT(POLL_PRI),
+ #define XLAT_VAL_4 ((unsigned) (POLL_PRI))
+ #define XLAT_STR_4 STRINGIFY(POLL_PRI)
  [POLL_HUP] = XLAT(POLL_HUP),
+ #define XLAT_VAL_5 ((unsigned) (POLL_HUP))
+ #define XLAT_STR_5 STRINGIFY(POLL_HUP)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -69,8 +81,60 @@ const struct xlat sigpoll_codes[1] = { {
  .data = sigpoll_codes_xdata,
  .size = ARRAY_SIZE(sigpoll_codes_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sigprocmaskcmds.h 5.9-0ubuntu2/xlat/sigprocmaskcmds.h
--- 5.5-3/xlat/sigprocmaskcmds.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sigprocmaskcmds.h	2020-09-24 09:18:45.000000000 +0000
@@ -15,15 +15,23 @@
 static const struct xlat_data sigprocmaskcmds_xdata[] = {
 #if defined(SIG_BLOCK) || (defined(HAVE_DECL_SIG_BLOCK) && HAVE_DECL_SIG_BLOCK)
   XLAT(SIG_BLOCK),
+ #define XLAT_VAL_0 ((unsigned) (SIG_BLOCK))
+ #define XLAT_STR_0 STRINGIFY(SIG_BLOCK)
 #endif
 #if defined(SIG_UNBLOCK) || (defined(HAVE_DECL_SIG_UNBLOCK) && HAVE_DECL_SIG_UNBLOCK)
   XLAT(SIG_UNBLOCK),
+ #define XLAT_VAL_1 ((unsigned) (SIG_UNBLOCK))
+ #define XLAT_STR_1 STRINGIFY(SIG_UNBLOCK)
 #endif
 #if defined(SIG_SETMASK) || (defined(HAVE_DECL_SIG_SETMASK) && HAVE_DECL_SIG_SETMASK)
   XLAT(SIG_SETMASK),
+ #define XLAT_VAL_2 ((unsigned) (SIG_SETMASK))
+ #define XLAT_STR_2 STRINGIFY(SIG_SETMASK)
 #endif
 #if defined(SIG_SETMASK32) || (defined(HAVE_DECL_SIG_SETMASK32) && HAVE_DECL_SIG_SETMASK32)
   XLAT(SIG_SETMASK32),
+ #define XLAT_VAL_3 ((unsigned) (SIG_SETMASK32))
+ #define XLAT_STR_3 STRINGIFY(SIG_SETMASK32)
 #endif
 };
 static
@@ -31,8 +39,44 @@ const struct xlat sigprocmaskcmds[1] = {
  .data = sigprocmaskcmds_xdata,
  .size = ARRAY_SIZE(sigprocmaskcmds_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sigprof_codes.h 5.9-0ubuntu2/xlat/sigprof_codes.h
--- 5.5-3/xlat/sigprof_codes.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sigprof_codes.h	2020-09-24 09:18:45.000000000 +0000
@@ -15,6 +15,8 @@ extern const struct xlat sigprof_codes[]
 static const struct xlat_data sigprof_codes_xdata[] = {
 #if defined(PROF_SIG) || (defined(HAVE_DECL_PROF_SIG) && HAVE_DECL_PROF_SIG)
   XLAT(PROF_SIG),
+ #define XLAT_VAL_0 ((unsigned) (PROF_SIG))
+ #define XLAT_STR_0 STRINGIFY(PROF_SIG)
 #endif
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
@@ -24,8 +26,20 @@ const struct xlat sigprof_codes[1] = { {
  .data = sigprof_codes_xdata,
  .size = ARRAY_SIZE(sigprof_codes_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sigsegv_codes.h 5.9-0ubuntu2/xlat/sigsegv_codes.h
--- 5.5-3/xlat/sigsegv_codes.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sigsegv_codes.h	2020-09-24 09:18:46.000000000 +0000
@@ -63,18 +63,36 @@ extern const struct xlat sigsegv_codes[]
 
 static const struct xlat_data sigsegv_codes_xdata[] = {
  XLAT(SEGV_MAPERR),
+ #define XLAT_VAL_0 ((unsigned) (SEGV_MAPERR))
+ #define XLAT_STR_0 STRINGIFY(SEGV_MAPERR)
  XLAT(SEGV_ACCERR),
+ #define XLAT_VAL_1 ((unsigned) (SEGV_ACCERR))
+ #define XLAT_STR_1 STRINGIFY(SEGV_ACCERR)
 #if defined(SEGV_STACKFLOW) || (defined(HAVE_DECL_SEGV_STACKFLOW) && HAVE_DECL_SEGV_STACKFLOW)
   XLAT(SEGV_STACKFLOW),
+ #define XLAT_VAL_2 ((unsigned) (SEGV_STACKFLOW))
+ #define XLAT_STR_2 STRINGIFY(SEGV_STACKFLOW)
 #endif
  XLAT(SEGV_BNDERR),
+ #define XLAT_VAL_3 ((unsigned) (SEGV_BNDERR))
+ #define XLAT_STR_3 STRINGIFY(SEGV_BNDERR)
 #if defined(__SEGV_PSTKOVF) || (defined(HAVE_DECL___SEGV_PSTKOVF) && HAVE_DECL___SEGV_PSTKOVF)
   XLAT(__SEGV_PSTKOVF),
+ #define XLAT_VAL_4 ((unsigned) (__SEGV_PSTKOVF))
+ #define XLAT_STR_4 STRINGIFY(__SEGV_PSTKOVF)
 #endif
  XLAT(SEGV_PKUERR),
+ #define XLAT_VAL_5 ((unsigned) (SEGV_PKUERR))
+ #define XLAT_STR_5 STRINGIFY(SEGV_PKUERR)
  XLAT(SEGV_ACCADI),
+ #define XLAT_VAL_6 ((unsigned) (SEGV_ACCADI))
+ #define XLAT_STR_6 STRINGIFY(SEGV_ACCADI)
  XLAT(SEGV_ADIDERR),
+ #define XLAT_VAL_7 ((unsigned) (SEGV_ADIDERR))
+ #define XLAT_STR_7 STRINGIFY(SEGV_ADIDERR)
  XLAT(SEGV_ADIPERR),
+ #define XLAT_VAL_8 ((unsigned) (SEGV_ADIPERR))
+ #define XLAT_STR_8 STRINGIFY(SEGV_ADIPERR)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -83,8 +101,84 @@ const struct xlat sigsegv_codes[1] = { {
  .data = sigsegv_codes_xdata,
  .size = ARRAY_SIZE(sigsegv_codes_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sigsys_codes.h 5.9-0ubuntu2/xlat/sigsys_codes.h
--- 5.5-3/xlat/sigsys_codes.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sigsys_codes.h	2020-09-24 09:18:45.000000000 +0000
@@ -21,6 +21,8 @@ extern const struct xlat sigsys_codes[];
 
 static const struct xlat_data sigsys_codes_xdata[] = {
  XLAT(SYS_SECCOMP),
+ #define XLAT_VAL_0 ((unsigned) (SYS_SECCOMP))
+ #define XLAT_STR_0 STRINGIFY(SYS_SECCOMP)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -29,8 +31,20 @@ const struct xlat sigsys_codes[1] = { {
  .data = sigsys_codes_xdata,
  .size = ARRAY_SIZE(sigsys_codes_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sigtrap_codes.h 5.9-0ubuntu2/xlat/sigtrap_codes.h
--- 5.5-3/xlat/sigtrap_codes.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sigtrap_codes.h	2020-09-24 09:18:46.000000000 +0000
@@ -50,21 +50,39 @@ extern const struct xlat sigtrap_codes[]
 static const struct xlat_data sigtrap_codes_xdata[] = {
 #if defined(TRAP_STEP) || (defined(HAVE_DECL_TRAP_STEP) && HAVE_DECL_TRAP_STEP)
   XLAT(TRAP_STEP),
+ #define XLAT_VAL_0 ((unsigned) (TRAP_STEP))
+ #define XLAT_STR_0 STRINGIFY(TRAP_STEP)
 #endif
  XLAT(TRAP_BRKPT),
+ #define XLAT_VAL_1 ((unsigned) (TRAP_BRKPT))
+ #define XLAT_STR_1 STRINGIFY(TRAP_BRKPT)
 #if defined(TRAP_TRACEFLOW) || (defined(HAVE_DECL_TRAP_TRACEFLOW) && HAVE_DECL_TRAP_TRACEFLOW)
   XLAT(TRAP_TRACEFLOW),
+ #define XLAT_VAL_2 ((unsigned) (TRAP_TRACEFLOW))
+ #define XLAT_STR_2 STRINGIFY(TRAP_TRACEFLOW)
 #endif
  XLAT(TRAP_TRACE),
+ #define XLAT_VAL_3 ((unsigned) (TRAP_TRACE))
+ #define XLAT_STR_3 STRINGIFY(TRAP_TRACE)
 #if defined(TRAP_WATCHPT) || (defined(HAVE_DECL_TRAP_WATCHPT) && HAVE_DECL_TRAP_WATCHPT)
   XLAT(TRAP_WATCHPT),
+ #define XLAT_VAL_4 ((unsigned) (TRAP_WATCHPT))
+ #define XLAT_STR_4 STRINGIFY(TRAP_WATCHPT)
 #endif
  XLAT(TRAP_BRANCH),
+ #define XLAT_VAL_5 ((unsigned) (TRAP_BRANCH))
+ #define XLAT_STR_5 STRINGIFY(TRAP_BRANCH)
 #if defined(TRAP_ILLTRAP) || (defined(HAVE_DECL_TRAP_ILLTRAP) && HAVE_DECL_TRAP_ILLTRAP)
   XLAT(TRAP_ILLTRAP),
+ #define XLAT_VAL_6 ((unsigned) (TRAP_ILLTRAP))
+ #define XLAT_STR_6 STRINGIFY(TRAP_ILLTRAP)
 #endif
  XLAT(TRAP_HWBKPT),
+ #define XLAT_VAL_7 ((unsigned) (TRAP_HWBKPT))
+ #define XLAT_STR_7 STRINGIFY(TRAP_HWBKPT)
  XLAT(TRAP_UNK),
+ #define XLAT_VAL_8 ((unsigned) (TRAP_UNK))
+ #define XLAT_STR_8 STRINGIFY(TRAP_UNK)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -73,8 +91,84 @@ const struct xlat sigtrap_codes[1] = { {
  .data = sigtrap_codes_xdata,
  .size = ARRAY_SIZE(sigtrap_codes_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/skf_ad.h 5.9-0ubuntu2/xlat/skf_ad.h
--- 5.5-3/xlat/skf_ad.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/skf_ad.h	2020-09-24 09:18:46.000000000 +0000
@@ -126,29 +126,193 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data skf_ad_xdata[] = {
  XLAT(SKF_AD_PROTOCOL),
+ #define XLAT_VAL_0 ((unsigned) (SKF_AD_PROTOCOL))
+ #define XLAT_STR_0 STRINGIFY(SKF_AD_PROTOCOL)
  XLAT(SKF_AD_PKTTYPE),
+ #define XLAT_VAL_1 ((unsigned) (SKF_AD_PKTTYPE))
+ #define XLAT_STR_1 STRINGIFY(SKF_AD_PKTTYPE)
  XLAT(SKF_AD_IFINDEX),
+ #define XLAT_VAL_2 ((unsigned) (SKF_AD_IFINDEX))
+ #define XLAT_STR_2 STRINGIFY(SKF_AD_IFINDEX)
  XLAT(SKF_AD_NLATTR),
+ #define XLAT_VAL_3 ((unsigned) (SKF_AD_NLATTR))
+ #define XLAT_STR_3 STRINGIFY(SKF_AD_NLATTR)
  XLAT(SKF_AD_NLATTR_NEST),
+ #define XLAT_VAL_4 ((unsigned) (SKF_AD_NLATTR_NEST))
+ #define XLAT_STR_4 STRINGIFY(SKF_AD_NLATTR_NEST)
  XLAT(SKF_AD_MARK),
+ #define XLAT_VAL_5 ((unsigned) (SKF_AD_MARK))
+ #define XLAT_STR_5 STRINGIFY(SKF_AD_MARK)
  XLAT(SKF_AD_QUEUE),
+ #define XLAT_VAL_6 ((unsigned) (SKF_AD_QUEUE))
+ #define XLAT_STR_6 STRINGIFY(SKF_AD_QUEUE)
  XLAT(SKF_AD_HATYPE),
+ #define XLAT_VAL_7 ((unsigned) (SKF_AD_HATYPE))
+ #define XLAT_STR_7 STRINGIFY(SKF_AD_HATYPE)
  XLAT(SKF_AD_RXHASH),
+ #define XLAT_VAL_8 ((unsigned) (SKF_AD_RXHASH))
+ #define XLAT_STR_8 STRINGIFY(SKF_AD_RXHASH)
  XLAT(SKF_AD_CPU),
+ #define XLAT_VAL_9 ((unsigned) (SKF_AD_CPU))
+ #define XLAT_STR_9 STRINGIFY(SKF_AD_CPU)
  XLAT(SKF_AD_ALU_XOR_X),
+ #define XLAT_VAL_10 ((unsigned) (SKF_AD_ALU_XOR_X))
+ #define XLAT_STR_10 STRINGIFY(SKF_AD_ALU_XOR_X)
  XLAT(SKF_AD_VLAN_TAG),
+ #define XLAT_VAL_11 ((unsigned) (SKF_AD_VLAN_TAG))
+ #define XLAT_STR_11 STRINGIFY(SKF_AD_VLAN_TAG)
  XLAT(SKF_AD_VLAN_TAG_PRESENT),
+ #define XLAT_VAL_12 ((unsigned) (SKF_AD_VLAN_TAG_PRESENT))
+ #define XLAT_STR_12 STRINGIFY(SKF_AD_VLAN_TAG_PRESENT)
  XLAT(SKF_AD_PAY_OFFSET),
+ #define XLAT_VAL_13 ((unsigned) (SKF_AD_PAY_OFFSET))
+ #define XLAT_STR_13 STRINGIFY(SKF_AD_PAY_OFFSET)
  XLAT(SKF_AD_RANDOM),
+ #define XLAT_VAL_14 ((unsigned) (SKF_AD_RANDOM))
+ #define XLAT_STR_14 STRINGIFY(SKF_AD_RANDOM)
  XLAT(SKF_AD_VLAN_TPID),
+ #define XLAT_VAL_15 ((unsigned) (SKF_AD_VLAN_TPID))
+ #define XLAT_STR_15 STRINGIFY(SKF_AD_VLAN_TPID)
 };
 static
 const struct xlat skf_ad[1] = { {
  .data = skf_ad_xdata,
  .size = ARRAY_SIZE(skf_ad_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/skf_off.h 5.9-0ubuntu2/xlat/skf_off.h
--- 5.5-3/xlat/skf_off.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/skf_off.h	2020-09-24 09:18:45.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data skf_off_xdata[] = {
  XLAT(SKF_AD_OFF),
+ #define XLAT_VAL_0 ((unsigned) (SKF_AD_OFF))
+ #define XLAT_STR_0 STRINGIFY(SKF_AD_OFF)
  XLAT(SKF_NET_OFF),
+ #define XLAT_VAL_1 ((unsigned) (SKF_NET_OFF))
+ #define XLAT_STR_1 STRINGIFY(SKF_NET_OFF)
  XLAT(SKF_LL_OFF),
+ #define XLAT_VAL_2 ((unsigned) (SKF_LL_OFF))
+ #define XLAT_STR_2 STRINGIFY(SKF_LL_OFF)
 };
 static
 const struct xlat skf_off[1] = { {
  .data = skf_off_xdata,
  .size = ARRAY_SIZE(skf_off_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/smc_decl_codes.h 5.9-0ubuntu2/xlat/smc_decl_codes.h
--- 5.5-3/xlat/smc_decl_codes.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/smc_decl_codes.h	2020-09-24 09:18:46.000000000 +0000
@@ -126,29 +126,193 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data smc_decl_codes_xdata[] = {
  XLAT(SMC_CLC_DECL_MEM),
+ #define XLAT_VAL_0 ((unsigned) (SMC_CLC_DECL_MEM))
+ #define XLAT_STR_0 STRINGIFY(SMC_CLC_DECL_MEM)
  XLAT(SMC_CLC_DECL_TIMEOUT_CL),
+ #define XLAT_VAL_1 ((unsigned) (SMC_CLC_DECL_TIMEOUT_CL))
+ #define XLAT_STR_1 STRINGIFY(SMC_CLC_DECL_TIMEOUT_CL)
  XLAT(SMC_CLC_DECL_TIMEOUT_AL),
+ #define XLAT_VAL_2 ((unsigned) (SMC_CLC_DECL_TIMEOUT_AL))
+ #define XLAT_STR_2 STRINGIFY(SMC_CLC_DECL_TIMEOUT_AL)
  XLAT(SMC_CLC_DECL_CNFERR),
+ #define XLAT_VAL_3 ((unsigned) (SMC_CLC_DECL_CNFERR))
+ #define XLAT_STR_3 STRINGIFY(SMC_CLC_DECL_CNFERR)
  XLAT(SMC_CLC_DECL_PEERNOSMC),
+ #define XLAT_VAL_4 ((unsigned) (SMC_CLC_DECL_PEERNOSMC))
+ #define XLAT_STR_4 STRINGIFY(SMC_CLC_DECL_PEERNOSMC)
  XLAT(SMC_CLC_DECL_IPSEC),
+ #define XLAT_VAL_5 ((unsigned) (SMC_CLC_DECL_IPSEC))
+ #define XLAT_STR_5 STRINGIFY(SMC_CLC_DECL_IPSEC)
  XLAT(SMC_CLC_DECL_NOSMCDEV),
+ #define XLAT_VAL_6 ((unsigned) (SMC_CLC_DECL_NOSMCDEV))
+ #define XLAT_STR_6 STRINGIFY(SMC_CLC_DECL_NOSMCDEV)
  XLAT(SMC_CLC_DECL_MODEUNSUPP),
+ #define XLAT_VAL_7 ((unsigned) (SMC_CLC_DECL_MODEUNSUPP))
+ #define XLAT_STR_7 STRINGIFY(SMC_CLC_DECL_MODEUNSUPP)
  XLAT(SMC_CLC_DECL_RMBE_EC),
+ #define XLAT_VAL_8 ((unsigned) (SMC_CLC_DECL_RMBE_EC))
+ #define XLAT_STR_8 STRINGIFY(SMC_CLC_DECL_RMBE_EC)
  XLAT(SMC_CLC_DECL_OPTUNSUPP),
+ #define XLAT_VAL_9 ((unsigned) (SMC_CLC_DECL_OPTUNSUPP))
+ #define XLAT_STR_9 STRINGIFY(SMC_CLC_DECL_OPTUNSUPP)
  XLAT(SMC_CLC_DECL_SYNCERR),
+ #define XLAT_VAL_10 ((unsigned) (SMC_CLC_DECL_SYNCERR))
+ #define XLAT_STR_10 STRINGIFY(SMC_CLC_DECL_SYNCERR)
  XLAT(SMC_CLC_DECL_PEERDECL),
+ #define XLAT_VAL_11 ((unsigned) (SMC_CLC_DECL_PEERDECL))
+ #define XLAT_STR_11 STRINGIFY(SMC_CLC_DECL_PEERDECL)
  XLAT(SMC_CLC_DECL_INTERR),
+ #define XLAT_VAL_12 ((unsigned) (SMC_CLC_DECL_INTERR))
+ #define XLAT_STR_12 STRINGIFY(SMC_CLC_DECL_INTERR)
  XLAT(SMC_CLC_DECL_ERR_RTOK),
+ #define XLAT_VAL_13 ((unsigned) (SMC_CLC_DECL_ERR_RTOK))
+ #define XLAT_STR_13 STRINGIFY(SMC_CLC_DECL_ERR_RTOK)
  XLAT(SMC_CLC_DECL_ERR_RDYLNK),
+ #define XLAT_VAL_14 ((unsigned) (SMC_CLC_DECL_ERR_RDYLNK))
+ #define XLAT_STR_14 STRINGIFY(SMC_CLC_DECL_ERR_RDYLNK)
  XLAT(SMC_CLC_DECL_ERR_REGRMB),
+ #define XLAT_VAL_15 ((unsigned) (SMC_CLC_DECL_ERR_REGRMB))
+ #define XLAT_STR_15 STRINGIFY(SMC_CLC_DECL_ERR_REGRMB)
 };
 static
 const struct xlat smc_decl_codes[1] = { {
  .data = smc_decl_codes_xdata,
  .size = ARRAY_SIZE(smc_decl_codes_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/smc_diag_attrs.h 5.9-0ubuntu2/xlat/smc_diag_attrs.h
--- 5.5-3/xlat/smc_diag_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/smc_diag_attrs.h	2020-09-24 09:18:46.000000000 +0000
@@ -14,19 +14,83 @@
 
 static const struct xlat_data smc_diag_attrs_xdata[] = {
  XLAT(SMC_DIAG_NONE),
+ #define XLAT_VAL_0 ((unsigned) (SMC_DIAG_NONE))
+ #define XLAT_STR_0 STRINGIFY(SMC_DIAG_NONE)
  XLAT(SMC_DIAG_CONNINFO),
+ #define XLAT_VAL_1 ((unsigned) (SMC_DIAG_CONNINFO))
+ #define XLAT_STR_1 STRINGIFY(SMC_DIAG_CONNINFO)
  XLAT(SMC_DIAG_LGRINFO),
+ #define XLAT_VAL_2 ((unsigned) (SMC_DIAG_LGRINFO))
+ #define XLAT_STR_2 STRINGIFY(SMC_DIAG_LGRINFO)
  XLAT(SMC_DIAG_SHUTDOWN),
+ #define XLAT_VAL_3 ((unsigned) (SMC_DIAG_SHUTDOWN))
+ #define XLAT_STR_3 STRINGIFY(SMC_DIAG_SHUTDOWN)
  XLAT(SMC_DIAG_DMBINFO),
+ #define XLAT_VAL_4 ((unsigned) (SMC_DIAG_DMBINFO))
+ #define XLAT_STR_4 STRINGIFY(SMC_DIAG_DMBINFO)
  XLAT(SMC_DIAG_FALLBACK),
+ #define XLAT_VAL_5 ((unsigned) (SMC_DIAG_FALLBACK))
+ #define XLAT_STR_5 STRINGIFY(SMC_DIAG_FALLBACK)
 };
 static
 const struct xlat smc_diag_attrs[1] = { {
  .data = smc_diag_attrs_xdata,
  .size = ARRAY_SIZE(smc_diag_attrs_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/smc_diag_extended_flags.h 5.9-0ubuntu2/xlat/smc_diag_extended_flags.h
--- 5.5-3/xlat/smc_diag_extended_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/smc_diag_extended_flags.h	2020-09-24 09:18:45.000000000 +0000
@@ -14,15 +14,39 @@
 
 static const struct xlat_data smc_diag_extended_flags_xdata[] = {
  XLAT(1<<(SMC_DIAG_CONNINFO-1)),
+ #define XLAT_VAL_0 ((unsigned) (1<<(SMC_DIAG_CONNINFO-1)))
+ #define XLAT_STR_0 STRINGIFY(1<<(SMC_DIAG_CONNINFO-1))
  XLAT(1<<(SMC_DIAG_LGRINFO-1)),
+ #define XLAT_VAL_1 ((unsigned) (1<<(SMC_DIAG_LGRINFO-1)))
+ #define XLAT_STR_1 STRINGIFY(1<<(SMC_DIAG_LGRINFO-1))
 };
 static
 const struct xlat smc_diag_extended_flags[1] = { {
  .data = smc_diag_extended_flags_xdata,
  .size = ARRAY_SIZE(smc_diag_extended_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/smc_diag_mode.h 5.9-0ubuntu2/xlat/smc_diag_mode.h
--- 5.5-3/xlat/smc_diag_mode.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/smc_diag_mode.h	2020-09-24 09:18:45.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data smc_diag_mode_xdata[] = {
  [SMC_DIAG_MODE_SMCR] = XLAT(SMC_DIAG_MODE_SMCR),
+ #define XLAT_VAL_0 ((unsigned) (SMC_DIAG_MODE_SMCR))
+ #define XLAT_STR_0 STRINGIFY(SMC_DIAG_MODE_SMCR)
  [SMC_DIAG_MODE_FALLBACK_TCP] = XLAT(SMC_DIAG_MODE_FALLBACK_TCP),
+ #define XLAT_VAL_1 ((unsigned) (SMC_DIAG_MODE_FALLBACK_TCP))
+ #define XLAT_STR_1 STRINGIFY(SMC_DIAG_MODE_FALLBACK_TCP)
  [SMC_DIAG_MODE_SMCD] = XLAT(SMC_DIAG_MODE_SMCD),
+ #define XLAT_VAL_2 ((unsigned) (SMC_DIAG_MODE_SMCD))
+ #define XLAT_STR_2 STRINGIFY(SMC_DIAG_MODE_SMCD)
 };
 static
 const struct xlat smc_diag_mode[1] = { {
  .data = smc_diag_mode_xdata,
  .size = ARRAY_SIZE(smc_diag_mode_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/smc_link_group_roles.h 5.9-0ubuntu2/xlat/smc_link_group_roles.h
--- 5.5-3/xlat/smc_link_group_roles.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/smc_link_group_roles.h	2020-09-24 09:18:45.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data smc_link_group_roles_xdata[] = {
  [SMC_CLNT] = XLAT(SMC_CLNT),
+ #define XLAT_VAL_0 ((unsigned) (SMC_CLNT))
+ #define XLAT_STR_0 STRINGIFY(SMC_CLNT)
  [SMC_SERV] = XLAT(SMC_SERV),
+ #define XLAT_VAL_1 ((unsigned) (SMC_SERV))
+ #define XLAT_STR_1 STRINGIFY(SMC_SERV)
 };
 static
 const struct xlat smc_link_group_roles[1] = { {
  .data = smc_link_group_roles_xdata,
  .size = ARRAY_SIZE(smc_link_group_roles_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/smc_protocols.h 5.9-0ubuntu2/xlat/smc_protocols.h
--- 5.5-3/xlat/smc_protocols.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/smc_protocols.h	2020-09-24 09:18:45.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data smc_protocols_xdata[] = {
  [SMCPROTO_SMC] = XLAT(SMCPROTO_SMC),
+ #define XLAT_VAL_0 ((unsigned) (SMCPROTO_SMC))
+ #define XLAT_STR_0 STRINGIFY(SMCPROTO_SMC)
  [SMCPROTO_SMC6] = XLAT(SMCPROTO_SMC6),
+ #define XLAT_VAL_1 ((unsigned) (SMCPROTO_SMC6))
+ #define XLAT_STR_1 STRINGIFY(SMCPROTO_SMC6)
 };
 static
 const struct xlat smc_protocols[1] = { {
  .data = smc_protocols_xdata,
  .size = ARRAY_SIZE(smc_protocols_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/smc_states.h 5.9-0ubuntu2/xlat/smc_states.h
--- 5.5-3/xlat/smc_states.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/smc_states.h	2020-09-24 09:18:46.000000000 +0000
@@ -98,25 +98,149 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data smc_states_xdata[] = {
  XLAT(SMC_ACTIVE),
+ #define XLAT_VAL_0 ((unsigned) (SMC_ACTIVE))
+ #define XLAT_STR_0 STRINGIFY(SMC_ACTIVE)
  XLAT(SMC_INIT),
+ #define XLAT_VAL_1 ((unsigned) (SMC_INIT))
+ #define XLAT_STR_1 STRINGIFY(SMC_INIT)
  XLAT(SMC_CLOSED),
+ #define XLAT_VAL_2 ((unsigned) (SMC_CLOSED))
+ #define XLAT_STR_2 STRINGIFY(SMC_CLOSED)
  XLAT(SMC_LISTEN),
+ #define XLAT_VAL_3 ((unsigned) (SMC_LISTEN))
+ #define XLAT_STR_3 STRINGIFY(SMC_LISTEN)
  XLAT(SMC_PEERCLOSEWAIT1),
+ #define XLAT_VAL_4 ((unsigned) (SMC_PEERCLOSEWAIT1))
+ #define XLAT_STR_4 STRINGIFY(SMC_PEERCLOSEWAIT1)
  XLAT(SMC_PEERCLOSEWAIT2),
+ #define XLAT_VAL_5 ((unsigned) (SMC_PEERCLOSEWAIT2))
+ #define XLAT_STR_5 STRINGIFY(SMC_PEERCLOSEWAIT2)
  XLAT(SMC_APPFINCLOSEWAIT),
+ #define XLAT_VAL_6 ((unsigned) (SMC_APPFINCLOSEWAIT))
+ #define XLAT_STR_6 STRINGIFY(SMC_APPFINCLOSEWAIT)
  XLAT(SMC_APPCLOSEWAIT1),
+ #define XLAT_VAL_7 ((unsigned) (SMC_APPCLOSEWAIT1))
+ #define XLAT_STR_7 STRINGIFY(SMC_APPCLOSEWAIT1)
  XLAT(SMC_APPCLOSEWAIT2),
+ #define XLAT_VAL_8 ((unsigned) (SMC_APPCLOSEWAIT2))
+ #define XLAT_STR_8 STRINGIFY(SMC_APPCLOSEWAIT2)
  XLAT(SMC_PEERFINCLOSEWAIT),
+ #define XLAT_VAL_9 ((unsigned) (SMC_PEERFINCLOSEWAIT))
+ #define XLAT_STR_9 STRINGIFY(SMC_PEERFINCLOSEWAIT)
  XLAT(SMC_PEERABORTWAIT),
+ #define XLAT_VAL_10 ((unsigned) (SMC_PEERABORTWAIT))
+ #define XLAT_STR_10 STRINGIFY(SMC_PEERABORTWAIT)
  XLAT(SMC_PROCESSABORT),
+ #define XLAT_VAL_11 ((unsigned) (SMC_PROCESSABORT))
+ #define XLAT_STR_11 STRINGIFY(SMC_PROCESSABORT)
 };
 static
 const struct xlat smc_states[1] = { {
  .data = smc_states_xdata,
  .size = ARRAY_SIZE(smc_states_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/snmp_icmp6_stats.h 5.9-0ubuntu2/xlat/snmp_icmp6_stats.h
--- 5.5-3/xlat/snmp_icmp6_stats.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/snmp_icmp6_stats.h	2020-09-24 09:18:46.000000000 +0000
@@ -56,19 +56,83 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data snmp_icmp6_stats_xdata[] = {
  [ICMP6_MIB_NUM] = XLAT(ICMP6_MIB_NUM),
+ #define XLAT_VAL_0 ((unsigned) (ICMP6_MIB_NUM))
+ #define XLAT_STR_0 STRINGIFY(ICMP6_MIB_NUM)
  [ICMP6_MIB_INMSGS] = XLAT(ICMP6_MIB_INMSGS),
+ #define XLAT_VAL_1 ((unsigned) (ICMP6_MIB_INMSGS))
+ #define XLAT_STR_1 STRINGIFY(ICMP6_MIB_INMSGS)
  [ICMP6_MIB_INERRORS] = XLAT(ICMP6_MIB_INERRORS),
+ #define XLAT_VAL_2 ((unsigned) (ICMP6_MIB_INERRORS))
+ #define XLAT_STR_2 STRINGIFY(ICMP6_MIB_INERRORS)
  [ICMP6_MIB_OUTMSGS] = XLAT(ICMP6_MIB_OUTMSGS),
+ #define XLAT_VAL_3 ((unsigned) (ICMP6_MIB_OUTMSGS))
+ #define XLAT_STR_3 STRINGIFY(ICMP6_MIB_OUTMSGS)
  [ICMP6_MIB_OUTERRORS] = XLAT(ICMP6_MIB_OUTERRORS),
+ #define XLAT_VAL_4 ((unsigned) (ICMP6_MIB_OUTERRORS))
+ #define XLAT_STR_4 STRINGIFY(ICMP6_MIB_OUTERRORS)
  [ICMP6_MIB_CSUMERRORS] = XLAT(ICMP6_MIB_CSUMERRORS),
+ #define XLAT_VAL_5 ((unsigned) (ICMP6_MIB_CSUMERRORS))
+ #define XLAT_STR_5 STRINGIFY(ICMP6_MIB_CSUMERRORS)
 };
 static
 const struct xlat snmp_icmp6_stats[1] = { {
  .data = snmp_icmp6_stats_xdata,
  .size = ARRAY_SIZE(snmp_icmp6_stats_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/snmp_ip_stats.h 5.9-0ubuntu2/xlat/snmp_ip_stats.h
--- 5.5-3/xlat/snmp_ip_stats.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/snmp_ip_stats.h	2020-09-24 09:18:46.000000000 +0000
@@ -273,50 +273,424 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data snmp_ip_stats_xdata[] = {
  [IPSTATS_MIB_NUM] = XLAT(IPSTATS_MIB_NUM),
+ #define XLAT_VAL_0 ((unsigned) (IPSTATS_MIB_NUM))
+ #define XLAT_STR_0 STRINGIFY(IPSTATS_MIB_NUM)
  [IPSTATS_MIB_INPKTS] = XLAT(IPSTATS_MIB_INPKTS),
+ #define XLAT_VAL_1 ((unsigned) (IPSTATS_MIB_INPKTS))
+ #define XLAT_STR_1 STRINGIFY(IPSTATS_MIB_INPKTS)
  [IPSTATS_MIB_INOCTETS] = XLAT(IPSTATS_MIB_INOCTETS),
+ #define XLAT_VAL_2 ((unsigned) (IPSTATS_MIB_INOCTETS))
+ #define XLAT_STR_2 STRINGIFY(IPSTATS_MIB_INOCTETS)
  [IPSTATS_MIB_INDELIVERS] = XLAT(IPSTATS_MIB_INDELIVERS),
+ #define XLAT_VAL_3 ((unsigned) (IPSTATS_MIB_INDELIVERS))
+ #define XLAT_STR_3 STRINGIFY(IPSTATS_MIB_INDELIVERS)
  [IPSTATS_MIB_OUTFORWDATAGRAMS] = XLAT(IPSTATS_MIB_OUTFORWDATAGRAMS),
+ #define XLAT_VAL_4 ((unsigned) (IPSTATS_MIB_OUTFORWDATAGRAMS))
+ #define XLAT_STR_4 STRINGIFY(IPSTATS_MIB_OUTFORWDATAGRAMS)
  [IPSTATS_MIB_OUTPKTS] = XLAT(IPSTATS_MIB_OUTPKTS),
+ #define XLAT_VAL_5 ((unsigned) (IPSTATS_MIB_OUTPKTS))
+ #define XLAT_STR_5 STRINGIFY(IPSTATS_MIB_OUTPKTS)
  [IPSTATS_MIB_OUTOCTETS] = XLAT(IPSTATS_MIB_OUTOCTETS),
+ #define XLAT_VAL_6 ((unsigned) (IPSTATS_MIB_OUTOCTETS))
+ #define XLAT_STR_6 STRINGIFY(IPSTATS_MIB_OUTOCTETS)
  [IPSTATS_MIB_INHDRERRORS] = XLAT(IPSTATS_MIB_INHDRERRORS),
+ #define XLAT_VAL_7 ((unsigned) (IPSTATS_MIB_INHDRERRORS))
+ #define XLAT_STR_7 STRINGIFY(IPSTATS_MIB_INHDRERRORS)
  [IPSTATS_MIB_INTOOBIGERRORS] = XLAT(IPSTATS_MIB_INTOOBIGERRORS),
+ #define XLAT_VAL_8 ((unsigned) (IPSTATS_MIB_INTOOBIGERRORS))
+ #define XLAT_STR_8 STRINGIFY(IPSTATS_MIB_INTOOBIGERRORS)
  [IPSTATS_MIB_INNOROUTES] = XLAT(IPSTATS_MIB_INNOROUTES),
+ #define XLAT_VAL_9 ((unsigned) (IPSTATS_MIB_INNOROUTES))
+ #define XLAT_STR_9 STRINGIFY(IPSTATS_MIB_INNOROUTES)
  [IPSTATS_MIB_INADDRERRORS] = XLAT(IPSTATS_MIB_INADDRERRORS),
+ #define XLAT_VAL_10 ((unsigned) (IPSTATS_MIB_INADDRERRORS))
+ #define XLAT_STR_10 STRINGIFY(IPSTATS_MIB_INADDRERRORS)
  [IPSTATS_MIB_INUNKNOWNPROTOS] = XLAT(IPSTATS_MIB_INUNKNOWNPROTOS),
+ #define XLAT_VAL_11 ((unsigned) (IPSTATS_MIB_INUNKNOWNPROTOS))
+ #define XLAT_STR_11 STRINGIFY(IPSTATS_MIB_INUNKNOWNPROTOS)
  [IPSTATS_MIB_INTRUNCATEDPKTS] = XLAT(IPSTATS_MIB_INTRUNCATEDPKTS),
+ #define XLAT_VAL_12 ((unsigned) (IPSTATS_MIB_INTRUNCATEDPKTS))
+ #define XLAT_STR_12 STRINGIFY(IPSTATS_MIB_INTRUNCATEDPKTS)
  [IPSTATS_MIB_INDISCARDS] = XLAT(IPSTATS_MIB_INDISCARDS),
+ #define XLAT_VAL_13 ((unsigned) (IPSTATS_MIB_INDISCARDS))
+ #define XLAT_STR_13 STRINGIFY(IPSTATS_MIB_INDISCARDS)
  [IPSTATS_MIB_OUTDISCARDS] = XLAT(IPSTATS_MIB_OUTDISCARDS),
+ #define XLAT_VAL_14 ((unsigned) (IPSTATS_MIB_OUTDISCARDS))
+ #define XLAT_STR_14 STRINGIFY(IPSTATS_MIB_OUTDISCARDS)
  [IPSTATS_MIB_OUTNOROUTES] = XLAT(IPSTATS_MIB_OUTNOROUTES),
+ #define XLAT_VAL_15 ((unsigned) (IPSTATS_MIB_OUTNOROUTES))
+ #define XLAT_STR_15 STRINGIFY(IPSTATS_MIB_OUTNOROUTES)
  [IPSTATS_MIB_REASMTIMEOUT] = XLAT(IPSTATS_MIB_REASMTIMEOUT),
+ #define XLAT_VAL_16 ((unsigned) (IPSTATS_MIB_REASMTIMEOUT))
+ #define XLAT_STR_16 STRINGIFY(IPSTATS_MIB_REASMTIMEOUT)
  [IPSTATS_MIB_REASMREQDS] = XLAT(IPSTATS_MIB_REASMREQDS),
+ #define XLAT_VAL_17 ((unsigned) (IPSTATS_MIB_REASMREQDS))
+ #define XLAT_STR_17 STRINGIFY(IPSTATS_MIB_REASMREQDS)
  [IPSTATS_MIB_REASMOKS] = XLAT(IPSTATS_MIB_REASMOKS),
+ #define XLAT_VAL_18 ((unsigned) (IPSTATS_MIB_REASMOKS))
+ #define XLAT_STR_18 STRINGIFY(IPSTATS_MIB_REASMOKS)
  [IPSTATS_MIB_REASMFAILS] = XLAT(IPSTATS_MIB_REASMFAILS),
+ #define XLAT_VAL_19 ((unsigned) (IPSTATS_MIB_REASMFAILS))
+ #define XLAT_STR_19 STRINGIFY(IPSTATS_MIB_REASMFAILS)
  [IPSTATS_MIB_FRAGOKS] = XLAT(IPSTATS_MIB_FRAGOKS),
+ #define XLAT_VAL_20 ((unsigned) (IPSTATS_MIB_FRAGOKS))
+ #define XLAT_STR_20 STRINGIFY(IPSTATS_MIB_FRAGOKS)
  [IPSTATS_MIB_FRAGFAILS] = XLAT(IPSTATS_MIB_FRAGFAILS),
+ #define XLAT_VAL_21 ((unsigned) (IPSTATS_MIB_FRAGFAILS))
+ #define XLAT_STR_21 STRINGIFY(IPSTATS_MIB_FRAGFAILS)
  [IPSTATS_MIB_FRAGCREATES] = XLAT(IPSTATS_MIB_FRAGCREATES),
+ #define XLAT_VAL_22 ((unsigned) (IPSTATS_MIB_FRAGCREATES))
+ #define XLAT_STR_22 STRINGIFY(IPSTATS_MIB_FRAGCREATES)
  [IPSTATS_MIB_INMCASTPKTS] = XLAT(IPSTATS_MIB_INMCASTPKTS),
+ #define XLAT_VAL_23 ((unsigned) (IPSTATS_MIB_INMCASTPKTS))
+ #define XLAT_STR_23 STRINGIFY(IPSTATS_MIB_INMCASTPKTS)
  [IPSTATS_MIB_OUTMCASTPKTS] = XLAT(IPSTATS_MIB_OUTMCASTPKTS),
+ #define XLAT_VAL_24 ((unsigned) (IPSTATS_MIB_OUTMCASTPKTS))
+ #define XLAT_STR_24 STRINGIFY(IPSTATS_MIB_OUTMCASTPKTS)
  [IPSTATS_MIB_INBCASTPKTS] = XLAT(IPSTATS_MIB_INBCASTPKTS),
+ #define XLAT_VAL_25 ((unsigned) (IPSTATS_MIB_INBCASTPKTS))
+ #define XLAT_STR_25 STRINGIFY(IPSTATS_MIB_INBCASTPKTS)
  [IPSTATS_MIB_OUTBCASTPKTS] = XLAT(IPSTATS_MIB_OUTBCASTPKTS),
+ #define XLAT_VAL_26 ((unsigned) (IPSTATS_MIB_OUTBCASTPKTS))
+ #define XLAT_STR_26 STRINGIFY(IPSTATS_MIB_OUTBCASTPKTS)
  [IPSTATS_MIB_INMCASTOCTETS] = XLAT(IPSTATS_MIB_INMCASTOCTETS),
+ #define XLAT_VAL_27 ((unsigned) (IPSTATS_MIB_INMCASTOCTETS))
+ #define XLAT_STR_27 STRINGIFY(IPSTATS_MIB_INMCASTOCTETS)
  [IPSTATS_MIB_OUTMCASTOCTETS] = XLAT(IPSTATS_MIB_OUTMCASTOCTETS),
+ #define XLAT_VAL_28 ((unsigned) (IPSTATS_MIB_OUTMCASTOCTETS))
+ #define XLAT_STR_28 STRINGIFY(IPSTATS_MIB_OUTMCASTOCTETS)
  [IPSTATS_MIB_INBCASTOCTETS] = XLAT(IPSTATS_MIB_INBCASTOCTETS),
+ #define XLAT_VAL_29 ((unsigned) (IPSTATS_MIB_INBCASTOCTETS))
+ #define XLAT_STR_29 STRINGIFY(IPSTATS_MIB_INBCASTOCTETS)
  [IPSTATS_MIB_OUTBCASTOCTETS] = XLAT(IPSTATS_MIB_OUTBCASTOCTETS),
+ #define XLAT_VAL_30 ((unsigned) (IPSTATS_MIB_OUTBCASTOCTETS))
+ #define XLAT_STR_30 STRINGIFY(IPSTATS_MIB_OUTBCASTOCTETS)
  [IPSTATS_MIB_CSUMERRORS] = XLAT(IPSTATS_MIB_CSUMERRORS),
+ #define XLAT_VAL_31 ((unsigned) (IPSTATS_MIB_CSUMERRORS))
+ #define XLAT_STR_31 STRINGIFY(IPSTATS_MIB_CSUMERRORS)
  [IPSTATS_MIB_NOECTPKTS] = XLAT(IPSTATS_MIB_NOECTPKTS),
+ #define XLAT_VAL_32 ((unsigned) (IPSTATS_MIB_NOECTPKTS))
+ #define XLAT_STR_32 STRINGIFY(IPSTATS_MIB_NOECTPKTS)
  [IPSTATS_MIB_ECT1PKTS] = XLAT(IPSTATS_MIB_ECT1PKTS),
+ #define XLAT_VAL_33 ((unsigned) (IPSTATS_MIB_ECT1PKTS))
+ #define XLAT_STR_33 STRINGIFY(IPSTATS_MIB_ECT1PKTS)
  [IPSTATS_MIB_ECT0PKTS] = XLAT(IPSTATS_MIB_ECT0PKTS),
+ #define XLAT_VAL_34 ((unsigned) (IPSTATS_MIB_ECT0PKTS))
+ #define XLAT_STR_34 STRINGIFY(IPSTATS_MIB_ECT0PKTS)
  [IPSTATS_MIB_CEPKTS] = XLAT(IPSTATS_MIB_CEPKTS),
+ #define XLAT_VAL_35 ((unsigned) (IPSTATS_MIB_CEPKTS))
+ #define XLAT_STR_35 STRINGIFY(IPSTATS_MIB_CEPKTS)
  [IPSTATS_MIB_REASM_OVERLAPS] = XLAT(IPSTATS_MIB_REASM_OVERLAPS),
+ #define XLAT_VAL_36 ((unsigned) (IPSTATS_MIB_REASM_OVERLAPS))
+ #define XLAT_STR_36 STRINGIFY(IPSTATS_MIB_REASM_OVERLAPS)
 };
 static
 const struct xlat snmp_ip_stats[1] = { {
  .data = snmp_ip_stats_xdata,
  .size = ARRAY_SIZE(snmp_ip_stats_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_alg_options.h 5.9-0ubuntu2/xlat/sock_alg_options.h
--- 5.5-3/xlat/sock_alg_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_alg_options.h	2020-09-24 09:18:45.000000000 +0000
@@ -49,18 +49,72 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sock_alg_options_xdata[] = {
  [ALG_SET_KEY] = XLAT(ALG_SET_KEY),
+ #define XLAT_VAL_0 ((unsigned) (ALG_SET_KEY))
+ #define XLAT_STR_0 STRINGIFY(ALG_SET_KEY)
  [ALG_SET_IV] = XLAT(ALG_SET_IV),
+ #define XLAT_VAL_1 ((unsigned) (ALG_SET_IV))
+ #define XLAT_STR_1 STRINGIFY(ALG_SET_IV)
  [ALG_SET_OP] = XLAT(ALG_SET_OP),
+ #define XLAT_VAL_2 ((unsigned) (ALG_SET_OP))
+ #define XLAT_STR_2 STRINGIFY(ALG_SET_OP)
  [ALG_SET_AEAD_ASSOCLEN] = XLAT(ALG_SET_AEAD_ASSOCLEN),
+ #define XLAT_VAL_3 ((unsigned) (ALG_SET_AEAD_ASSOCLEN))
+ #define XLAT_STR_3 STRINGIFY(ALG_SET_AEAD_ASSOCLEN)
  [ALG_SET_AEAD_AUTHSIZE] = XLAT(ALG_SET_AEAD_AUTHSIZE),
+ #define XLAT_VAL_4 ((unsigned) (ALG_SET_AEAD_AUTHSIZE))
+ #define XLAT_STR_4 STRINGIFY(ALG_SET_AEAD_AUTHSIZE)
 };
 static
 const struct xlat sock_alg_options[1] = { {
  .data = sock_alg_options_xdata,
  .size = ARRAY_SIZE(sock_alg_options_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_ax25_options.h 5.9-0ubuntu2/xlat/sock_ax25_options.h
--- 5.5-3/xlat/sock_ax25_options.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_ax25_options.h	2020-09-24 09:18:46.000000000 +0000
@@ -91,20 +91,44 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sock_ax25_options_xdata[] = {
  XLAT(AX25_WINDOW),
+ #define XLAT_VAL_0 ((unsigned) (AX25_WINDOW))
+ #define XLAT_STR_0 STRINGIFY(AX25_WINDOW)
  XLAT(AX25_T1),
+ #define XLAT_VAL_1 ((unsigned) (AX25_T1))
+ #define XLAT_STR_1 STRINGIFY(AX25_T1)
  XLAT(AX25_N2),
+ #define XLAT_VAL_2 ((unsigned) (AX25_N2))
+ #define XLAT_STR_2 STRINGIFY(AX25_N2)
  XLAT(AX25_T3),
+ #define XLAT_VAL_3 ((unsigned) (AX25_T3))
+ #define XLAT_STR_3 STRINGIFY(AX25_T3)
  XLAT(AX25_T2),
+ #define XLAT_VAL_4 ((unsigned) (AX25_T2))
+ #define XLAT_STR_4 STRINGIFY(AX25_T2)
  XLAT(AX25_BACKOFF),
+ #define XLAT_VAL_5 ((unsigned) (AX25_BACKOFF))
+ #define XLAT_STR_5 STRINGIFY(AX25_BACKOFF)
  XLAT(AX25_EXTSEQ),
+ #define XLAT_VAL_6 ((unsigned) (AX25_EXTSEQ))
+ #define XLAT_STR_6 STRINGIFY(AX25_EXTSEQ)
  XLAT(AX25_PIDINCL),
+ #define XLAT_VAL_7 ((unsigned) (AX25_PIDINCL))
+ #define XLAT_STR_7 STRINGIFY(AX25_PIDINCL)
  XLAT(AX25_IDLE),
+ #define XLAT_VAL_8 ((unsigned) (AX25_IDLE))
+ #define XLAT_STR_8 STRINGIFY(AX25_IDLE)
  XLAT(AX25_PACLEN),
+ #define XLAT_VAL_9 ((unsigned) (AX25_PACLEN))
+ #define XLAT_STR_9 STRINGIFY(AX25_PACLEN)
  XLAT(AX25_IAMDIGI),
+ #define XLAT_VAL_10 ((unsigned) (AX25_IAMDIGI))
+ #define XLAT_STR_10 STRINGIFY(AX25_IAMDIGI)
 
 
 #if defined(SO_BINDTODEVICE) || (defined(HAVE_DECL_SO_BINDTODEVICE) && HAVE_DECL_SO_BINDTODEVICE)
   XLAT(SO_BINDTODEVICE),
+ #define XLAT_VAL_11 ((unsigned) (SO_BINDTODEVICE))
+ #define XLAT_STR_11 STRINGIFY(SO_BINDTODEVICE)
 #endif
 };
 static
@@ -112,8 +136,108 @@ const struct xlat sock_ax25_options[1] =
  .data = sock_ax25_options_xdata,
  .size = ARRAY_SIZE(sock_ax25_options_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_bluetooth_options.h 5.9-0ubuntu2/xlat/sock_bluetooth_options.h
--- 5.5-3/xlat/sock_bluetooth_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_bluetooth_options.h	2020-09-24 09:18:46.000000000 +0000
@@ -70,21 +70,105 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sock_bluetooth_options_xdata[] = {
  XLAT(BT_SECURITY),
+ #define XLAT_VAL_0 ((unsigned) (BT_SECURITY))
+ #define XLAT_STR_0 STRINGIFY(BT_SECURITY)
  XLAT(BT_DEFER_SETUP),
+ #define XLAT_VAL_1 ((unsigned) (BT_DEFER_SETUP))
+ #define XLAT_STR_1 STRINGIFY(BT_DEFER_SETUP)
  XLAT(BT_FLUSHABLE),
+ #define XLAT_VAL_2 ((unsigned) (BT_FLUSHABLE))
+ #define XLAT_STR_2 STRINGIFY(BT_FLUSHABLE)
  XLAT(BT_POWER),
+ #define XLAT_VAL_3 ((unsigned) (BT_POWER))
+ #define XLAT_STR_3 STRINGIFY(BT_POWER)
  XLAT(BT_CHANNEL_POLICY),
+ #define XLAT_VAL_4 ((unsigned) (BT_CHANNEL_POLICY))
+ #define XLAT_STR_4 STRINGIFY(BT_CHANNEL_POLICY)
  XLAT(BT_VOICE),
+ #define XLAT_VAL_5 ((unsigned) (BT_VOICE))
+ #define XLAT_STR_5 STRINGIFY(BT_VOICE)
  XLAT(BT_SNDMTU),
+ #define XLAT_VAL_6 ((unsigned) (BT_SNDMTU))
+ #define XLAT_STR_6 STRINGIFY(BT_SNDMTU)
  XLAT(BT_RCVMTU),
+ #define XLAT_VAL_7 ((unsigned) (BT_RCVMTU))
+ #define XLAT_STR_7 STRINGIFY(BT_RCVMTU)
 };
 static
 const struct xlat sock_bluetooth_options[1] = { {
  .data = sock_bluetooth_options_xdata,
  .size = ARRAY_SIZE(sock_bluetooth_options_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_caif_options.h 5.9-0ubuntu2/xlat/sock_caif_options.h
--- 5.5-3/xlat/sock_caif_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_caif_options.h	2020-09-24 09:18:45.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sock_caif_options_xdata[] = {
  XLAT(CAIFSO_LINK_SELECT),
+ #define XLAT_VAL_0 ((unsigned) (CAIFSO_LINK_SELECT))
+ #define XLAT_STR_0 STRINGIFY(CAIFSO_LINK_SELECT)
  XLAT(CAIFSO_REQ_PARAM),
+ #define XLAT_VAL_1 ((unsigned) (CAIFSO_REQ_PARAM))
+ #define XLAT_STR_1 STRINGIFY(CAIFSO_REQ_PARAM)
  XLAT(CAIFSO_RSP_PARAM),
+ #define XLAT_VAL_2 ((unsigned) (CAIFSO_RSP_PARAM))
+ #define XLAT_STR_2 STRINGIFY(CAIFSO_RSP_PARAM)
 };
 static
 const struct xlat sock_caif_options[1] = { {
  .data = sock_caif_options_xdata,
  .size = ARRAY_SIZE(sock_caif_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_dccp_options.h 5.9-0ubuntu2/xlat/sock_dccp_options.h
--- 5.5-3/xlat/sock_dccp_options.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_dccp_options.h	2020-09-24 09:18:46.000000000 +0000
@@ -126,29 +126,193 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sock_dccp_options_xdata[] = {
  XLAT(DCCP_SOCKOPT_PACKET_SIZE),
+ #define XLAT_VAL_0 ((unsigned) (DCCP_SOCKOPT_PACKET_SIZE))
+ #define XLAT_STR_0 STRINGIFY(DCCP_SOCKOPT_PACKET_SIZE)
  XLAT(DCCP_SOCKOPT_SERVICE),
+ #define XLAT_VAL_1 ((unsigned) (DCCP_SOCKOPT_SERVICE))
+ #define XLAT_STR_1 STRINGIFY(DCCP_SOCKOPT_SERVICE)
  XLAT(DCCP_SOCKOPT_CHANGE_L),
+ #define XLAT_VAL_2 ((unsigned) (DCCP_SOCKOPT_CHANGE_L))
+ #define XLAT_STR_2 STRINGIFY(DCCP_SOCKOPT_CHANGE_L)
  XLAT(DCCP_SOCKOPT_CHANGE_R),
+ #define XLAT_VAL_3 ((unsigned) (DCCP_SOCKOPT_CHANGE_R))
+ #define XLAT_STR_3 STRINGIFY(DCCP_SOCKOPT_CHANGE_R)
  XLAT(DCCP_SOCKOPT_GET_CUR_MPS),
+ #define XLAT_VAL_4 ((unsigned) (DCCP_SOCKOPT_GET_CUR_MPS))
+ #define XLAT_STR_4 STRINGIFY(DCCP_SOCKOPT_GET_CUR_MPS)
  XLAT(DCCP_SOCKOPT_SERVER_TIMEWAIT),
+ #define XLAT_VAL_5 ((unsigned) (DCCP_SOCKOPT_SERVER_TIMEWAIT))
+ #define XLAT_STR_5 STRINGIFY(DCCP_SOCKOPT_SERVER_TIMEWAIT)
  XLAT(DCCP_SOCKOPT_SEND_CSCOV),
+ #define XLAT_VAL_6 ((unsigned) (DCCP_SOCKOPT_SEND_CSCOV))
+ #define XLAT_STR_6 STRINGIFY(DCCP_SOCKOPT_SEND_CSCOV)
  XLAT(DCCP_SOCKOPT_RECV_CSCOV),
+ #define XLAT_VAL_7 ((unsigned) (DCCP_SOCKOPT_RECV_CSCOV))
+ #define XLAT_STR_7 STRINGIFY(DCCP_SOCKOPT_RECV_CSCOV)
  XLAT(DCCP_SOCKOPT_AVAILABLE_CCIDS),
+ #define XLAT_VAL_8 ((unsigned) (DCCP_SOCKOPT_AVAILABLE_CCIDS))
+ #define XLAT_STR_8 STRINGIFY(DCCP_SOCKOPT_AVAILABLE_CCIDS)
  XLAT(DCCP_SOCKOPT_CCID),
+ #define XLAT_VAL_9 ((unsigned) (DCCP_SOCKOPT_CCID))
+ #define XLAT_STR_9 STRINGIFY(DCCP_SOCKOPT_CCID)
  XLAT(DCCP_SOCKOPT_TX_CCID),
+ #define XLAT_VAL_10 ((unsigned) (DCCP_SOCKOPT_TX_CCID))
+ #define XLAT_STR_10 STRINGIFY(DCCP_SOCKOPT_TX_CCID)
  XLAT(DCCP_SOCKOPT_RX_CCID),
+ #define XLAT_VAL_11 ((unsigned) (DCCP_SOCKOPT_RX_CCID))
+ #define XLAT_STR_11 STRINGIFY(DCCP_SOCKOPT_RX_CCID)
  XLAT(DCCP_SOCKOPT_QPOLICY_ID),
+ #define XLAT_VAL_12 ((unsigned) (DCCP_SOCKOPT_QPOLICY_ID))
+ #define XLAT_STR_12 STRINGIFY(DCCP_SOCKOPT_QPOLICY_ID)
  XLAT(DCCP_SOCKOPT_QPOLICY_TXQLEN),
+ #define XLAT_VAL_13 ((unsigned) (DCCP_SOCKOPT_QPOLICY_TXQLEN))
+ #define XLAT_STR_13 STRINGIFY(DCCP_SOCKOPT_QPOLICY_TXQLEN)
  XLAT(DCCP_SOCKOPT_CCID_RX_INFO),
+ #define XLAT_VAL_14 ((unsigned) (DCCP_SOCKOPT_CCID_RX_INFO))
+ #define XLAT_STR_14 STRINGIFY(DCCP_SOCKOPT_CCID_RX_INFO)
  XLAT(DCCP_SOCKOPT_CCID_TX_INFO),
+ #define XLAT_VAL_15 ((unsigned) (DCCP_SOCKOPT_CCID_TX_INFO))
+ #define XLAT_STR_15 STRINGIFY(DCCP_SOCKOPT_CCID_TX_INFO)
 };
 static
 const struct xlat sock_dccp_options[1] = { {
  .data = sock_dccp_options_xdata,
  .size = ARRAY_SIZE(sock_dccp_options_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/socketcalls.h 5.9-0ubuntu2/xlat/socketcalls.h
--- 5.5-3/xlat/socketcalls.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/socketcalls.h	2020-09-24 09:18:46.000000000 +0000
@@ -154,33 +154,237 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data socketcalls_xdata[] = {
  [SYS_SOCKET] = XLAT(SYS_SOCKET),
+ #define XLAT_VAL_0 ((unsigned) (SYS_SOCKET))
+ #define XLAT_STR_0 STRINGIFY(SYS_SOCKET)
  [SYS_BIND] = XLAT(SYS_BIND),
+ #define XLAT_VAL_1 ((unsigned) (SYS_BIND))
+ #define XLAT_STR_1 STRINGIFY(SYS_BIND)
  [SYS_CONNECT] = XLAT(SYS_CONNECT),
+ #define XLAT_VAL_2 ((unsigned) (SYS_CONNECT))
+ #define XLAT_STR_2 STRINGIFY(SYS_CONNECT)
  [SYS_LISTEN] = XLAT(SYS_LISTEN),
+ #define XLAT_VAL_3 ((unsigned) (SYS_LISTEN))
+ #define XLAT_STR_3 STRINGIFY(SYS_LISTEN)
  [SYS_ACCEPT] = XLAT(SYS_ACCEPT),
+ #define XLAT_VAL_4 ((unsigned) (SYS_ACCEPT))
+ #define XLAT_STR_4 STRINGIFY(SYS_ACCEPT)
  [SYS_GETSOCKNAME] = XLAT(SYS_GETSOCKNAME),
+ #define XLAT_VAL_5 ((unsigned) (SYS_GETSOCKNAME))
+ #define XLAT_STR_5 STRINGIFY(SYS_GETSOCKNAME)
  [SYS_GETPEERNAME] = XLAT(SYS_GETPEERNAME),
+ #define XLAT_VAL_6 ((unsigned) (SYS_GETPEERNAME))
+ #define XLAT_STR_6 STRINGIFY(SYS_GETPEERNAME)
  [SYS_SOCKETPAIR] = XLAT(SYS_SOCKETPAIR),
+ #define XLAT_VAL_7 ((unsigned) (SYS_SOCKETPAIR))
+ #define XLAT_STR_7 STRINGIFY(SYS_SOCKETPAIR)
  [SYS_SEND] = XLAT(SYS_SEND),
+ #define XLAT_VAL_8 ((unsigned) (SYS_SEND))
+ #define XLAT_STR_8 STRINGIFY(SYS_SEND)
  [SYS_RECV] = XLAT(SYS_RECV),
+ #define XLAT_VAL_9 ((unsigned) (SYS_RECV))
+ #define XLAT_STR_9 STRINGIFY(SYS_RECV)
  [SYS_SENDTO] = XLAT(SYS_SENDTO),
+ #define XLAT_VAL_10 ((unsigned) (SYS_SENDTO))
+ #define XLAT_STR_10 STRINGIFY(SYS_SENDTO)
  [SYS_RECVFROM] = XLAT(SYS_RECVFROM),
+ #define XLAT_VAL_11 ((unsigned) (SYS_RECVFROM))
+ #define XLAT_STR_11 STRINGIFY(SYS_RECVFROM)
  [SYS_SHUTDOWN] = XLAT(SYS_SHUTDOWN),
+ #define XLAT_VAL_12 ((unsigned) (SYS_SHUTDOWN))
+ #define XLAT_STR_12 STRINGIFY(SYS_SHUTDOWN)
  [SYS_SETSOCKOPT] = XLAT(SYS_SETSOCKOPT),
+ #define XLAT_VAL_13 ((unsigned) (SYS_SETSOCKOPT))
+ #define XLAT_STR_13 STRINGIFY(SYS_SETSOCKOPT)
  [SYS_GETSOCKOPT] = XLAT(SYS_GETSOCKOPT),
+ #define XLAT_VAL_14 ((unsigned) (SYS_GETSOCKOPT))
+ #define XLAT_STR_14 STRINGIFY(SYS_GETSOCKOPT)
  [SYS_SENDMSG] = XLAT(SYS_SENDMSG),
+ #define XLAT_VAL_15 ((unsigned) (SYS_SENDMSG))
+ #define XLAT_STR_15 STRINGIFY(SYS_SENDMSG)
  [SYS_RECVMSG] = XLAT(SYS_RECVMSG),
+ #define XLAT_VAL_16 ((unsigned) (SYS_RECVMSG))
+ #define XLAT_STR_16 STRINGIFY(SYS_RECVMSG)
  [SYS_ACCEPT4] = XLAT(SYS_ACCEPT4),
+ #define XLAT_VAL_17 ((unsigned) (SYS_ACCEPT4))
+ #define XLAT_STR_17 STRINGIFY(SYS_ACCEPT4)
  [SYS_RECVMMSG] = XLAT(SYS_RECVMMSG),
+ #define XLAT_VAL_18 ((unsigned) (SYS_RECVMMSG))
+ #define XLAT_STR_18 STRINGIFY(SYS_RECVMMSG)
  [SYS_SENDMMSG] = XLAT(SYS_SENDMMSG),
+ #define XLAT_VAL_19 ((unsigned) (SYS_SENDMMSG))
+ #define XLAT_STR_19 STRINGIFY(SYS_SENDMMSG)
 };
 static
 const struct xlat socketcalls[1] = { {
  .data = socketcalls_xdata,
  .size = ARRAY_SIZE(socketcalls_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/socketlayers.h 5.9-0ubuntu2/xlat/socketlayers.h
--- 5.5-3/xlat/socketlayers.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/socketlayers.h	2020-09-24 09:18:46.000000000 +0000
@@ -294,56 +294,460 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data socketlayers_xdata[] = {
  XLAT(SOL_IP),
+ #define XLAT_VAL_0 ((unsigned) (SOL_IP))
+ #define XLAT_STR_0 STRINGIFY(SOL_IP)
 #if !(defined __alpha__ || defined __hppa__ || defined __mips__ || defined __sparc__)
  XLAT(SOL_SOCKET),
+ #define XLAT_VAL_1 ((unsigned) (SOL_SOCKET))
+ #define XLAT_STR_1 STRINGIFY(SOL_SOCKET)
 #endif
  XLAT(SOL_TCP),
+ #define XLAT_VAL_2 ((unsigned) (SOL_TCP))
+ #define XLAT_STR_2 STRINGIFY(SOL_TCP)
  XLAT(SOL_UDP),
+ #define XLAT_VAL_3 ((unsigned) (SOL_UDP))
+ #define XLAT_STR_3 STRINGIFY(SOL_UDP)
  XLAT(SOL_IPV6),
+ #define XLAT_VAL_4 ((unsigned) (SOL_IPV6))
+ #define XLAT_STR_4 STRINGIFY(SOL_IPV6)
  XLAT(SOL_ICMPV6),
+ #define XLAT_VAL_5 ((unsigned) (SOL_ICMPV6))
+ #define XLAT_STR_5 STRINGIFY(SOL_ICMPV6)
  XLAT(SOL_CAN_BASE),
+ #define XLAT_VAL_6 ((unsigned) (SOL_CAN_BASE))
+ #define XLAT_STR_6 STRINGIFY(SOL_CAN_BASE)
  XLAT(SOL_CAN_RAW),
+ #define XLAT_VAL_7 ((unsigned) (SOL_CAN_RAW))
+ #define XLAT_STR_7 STRINGIFY(SOL_CAN_RAW)
  XLAT(SOL_SCTP),
+ #define XLAT_VAL_8 ((unsigned) (SOL_SCTP))
+ #define XLAT_STR_8 STRINGIFY(SOL_SCTP)
  XLAT(SOL_UDPLITE),
+ #define XLAT_VAL_9 ((unsigned) (SOL_UDPLITE))
+ #define XLAT_STR_9 STRINGIFY(SOL_UDPLITE)
  XLAT(SOL_RAW),
+ #define XLAT_VAL_10 ((unsigned) (SOL_RAW))
+ #define XLAT_STR_10 STRINGIFY(SOL_RAW)
  XLAT(SOL_IPX),
+ #define XLAT_VAL_11 ((unsigned) (SOL_IPX))
+ #define XLAT_STR_11 STRINGIFY(SOL_IPX)
  XLAT(SOL_AX25),
+ #define XLAT_VAL_12 ((unsigned) (SOL_AX25))
+ #define XLAT_STR_12 STRINGIFY(SOL_AX25)
  XLAT(SOL_ATALK),
+ #define XLAT_VAL_13 ((unsigned) (SOL_ATALK))
+ #define XLAT_STR_13 STRINGIFY(SOL_ATALK)
  XLAT(SOL_NETROM),
+ #define XLAT_VAL_14 ((unsigned) (SOL_NETROM))
+ #define XLAT_STR_14 STRINGIFY(SOL_NETROM)
  XLAT(SOL_ROSE),
+ #define XLAT_VAL_15 ((unsigned) (SOL_ROSE))
+ #define XLAT_STR_15 STRINGIFY(SOL_ROSE)
  XLAT(SOL_DECNET),
+ #define XLAT_VAL_16 ((unsigned) (SOL_DECNET))
+ #define XLAT_STR_16 STRINGIFY(SOL_DECNET)
  XLAT(SOL_X25),
+ #define XLAT_VAL_17 ((unsigned) (SOL_X25))
+ #define XLAT_STR_17 STRINGIFY(SOL_X25)
  XLAT(SOL_PACKET),
+ #define XLAT_VAL_18 ((unsigned) (SOL_PACKET))
+ #define XLAT_STR_18 STRINGIFY(SOL_PACKET)
  XLAT(SOL_ATM),
+ #define XLAT_VAL_19 ((unsigned) (SOL_ATM))
+ #define XLAT_STR_19 STRINGIFY(SOL_ATM)
  XLAT(SOL_AAL),
+ #define XLAT_VAL_20 ((unsigned) (SOL_AAL))
+ #define XLAT_STR_20 STRINGIFY(SOL_AAL)
  XLAT(SOL_IRDA),
+ #define XLAT_VAL_21 ((unsigned) (SOL_IRDA))
+ #define XLAT_STR_21 STRINGIFY(SOL_IRDA)
  XLAT(SOL_NETBEUI),
+ #define XLAT_VAL_22 ((unsigned) (SOL_NETBEUI))
+ #define XLAT_STR_22 STRINGIFY(SOL_NETBEUI)
  XLAT(SOL_LLC),
+ #define XLAT_VAL_23 ((unsigned) (SOL_LLC))
+ #define XLAT_STR_23 STRINGIFY(SOL_LLC)
  XLAT(SOL_DCCP),
+ #define XLAT_VAL_24 ((unsigned) (SOL_DCCP))
+ #define XLAT_STR_24 STRINGIFY(SOL_DCCP)
  XLAT(SOL_NETLINK),
+ #define XLAT_VAL_25 ((unsigned) (SOL_NETLINK))
+ #define XLAT_STR_25 STRINGIFY(SOL_NETLINK)
  XLAT(SOL_TIPC),
+ #define XLAT_VAL_26 ((unsigned) (SOL_TIPC))
+ #define XLAT_STR_26 STRINGIFY(SOL_TIPC)
  XLAT(SOL_RXRPC),
+ #define XLAT_VAL_27 ((unsigned) (SOL_RXRPC))
+ #define XLAT_STR_27 STRINGIFY(SOL_RXRPC)
  XLAT(SOL_PPPOL2TP),
+ #define XLAT_VAL_28 ((unsigned) (SOL_PPPOL2TP))
+ #define XLAT_STR_28 STRINGIFY(SOL_PPPOL2TP)
  XLAT(SOL_BLUETOOTH),
+ #define XLAT_VAL_29 ((unsigned) (SOL_BLUETOOTH))
+ #define XLAT_STR_29 STRINGIFY(SOL_BLUETOOTH)
  XLAT(SOL_PNPIPE),
+ #define XLAT_VAL_30 ((unsigned) (SOL_PNPIPE))
+ #define XLAT_STR_30 STRINGIFY(SOL_PNPIPE)
  XLAT(SOL_RDS),
+ #define XLAT_VAL_31 ((unsigned) (SOL_RDS))
+ #define XLAT_STR_31 STRINGIFY(SOL_RDS)
  XLAT(SOL_IUCV),
+ #define XLAT_VAL_32 ((unsigned) (SOL_IUCV))
+ #define XLAT_STR_32 STRINGIFY(SOL_IUCV)
  XLAT(SOL_CAIF),
+ #define XLAT_VAL_33 ((unsigned) (SOL_CAIF))
+ #define XLAT_STR_33 STRINGIFY(SOL_CAIF)
  XLAT(SOL_ALG),
+ #define XLAT_VAL_34 ((unsigned) (SOL_ALG))
+ #define XLAT_STR_34 STRINGIFY(SOL_ALG)
  XLAT(SOL_NFC),
+ #define XLAT_VAL_35 ((unsigned) (SOL_NFC))
+ #define XLAT_STR_35 STRINGIFY(SOL_NFC)
  XLAT(SOL_KCM),
+ #define XLAT_VAL_36 ((unsigned) (SOL_KCM))
+ #define XLAT_STR_36 STRINGIFY(SOL_KCM)
  XLAT(SOL_TLS),
+ #define XLAT_VAL_37 ((unsigned) (SOL_TLS))
+ #define XLAT_STR_37 STRINGIFY(SOL_TLS)
  XLAT(SOL_XDP),
+ #define XLAT_VAL_38 ((unsigned) (SOL_XDP))
+ #define XLAT_STR_38 STRINGIFY(SOL_XDP)
 #if defined __alpha__ || defined __hppa__ || defined __mips__ || defined __sparc__
  XLAT(SOL_SOCKET),
+ #define XLAT_VAL_39 ((unsigned) (SOL_SOCKET))
+ #define XLAT_STR_39 STRINGIFY(SOL_SOCKET)
 #endif
 };
 const struct xlat socketlayers[1] = { {
  .data = socketlayers_xdata,
  .size = ARRAY_SIZE(socketlayers_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_ip_options.h 5.9-0ubuntu2/xlat/sock_ip_options.h
--- 5.5-3/xlat/sock_ip_options.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_ip_options.h	2020-09-24 09:18:46.000000000 +0000
@@ -15,153 +15,258 @@
 static const struct xlat_data sock_ip_options_xdata[] = {
 #if defined(IP_TOS) || (defined(HAVE_DECL_IP_TOS) && HAVE_DECL_IP_TOS)
   XLAT(IP_TOS),
+ #define XLAT_VAL_0 ((unsigned) (IP_TOS))
+ #define XLAT_STR_0 STRINGIFY(IP_TOS)
 #endif
 #if defined(IP_TTL) || (defined(HAVE_DECL_IP_TTL) && HAVE_DECL_IP_TTL)
   XLAT(IP_TTL),
+ #define XLAT_VAL_1 ((unsigned) (IP_TTL))
+ #define XLAT_STR_1 STRINGIFY(IP_TTL)
 #endif
 #if defined(IP_HDRINCL) || (defined(HAVE_DECL_IP_HDRINCL) && HAVE_DECL_IP_HDRINCL)
   XLAT(IP_HDRINCL),
+ #define XLAT_VAL_2 ((unsigned) (IP_HDRINCL))
+ #define XLAT_STR_2 STRINGIFY(IP_HDRINCL)
 #endif
 #if defined(IP_OPTIONS) || (defined(HAVE_DECL_IP_OPTIONS) && HAVE_DECL_IP_OPTIONS)
   XLAT(IP_OPTIONS),
+ #define XLAT_VAL_3 ((unsigned) (IP_OPTIONS))
+ #define XLAT_STR_3 STRINGIFY(IP_OPTIONS)
 #endif
 #if defined(IP_ROUTER_ALERT) || (defined(HAVE_DECL_IP_ROUTER_ALERT) && HAVE_DECL_IP_ROUTER_ALERT)
   XLAT(IP_ROUTER_ALERT),
+ #define XLAT_VAL_4 ((unsigned) (IP_ROUTER_ALERT))
+ #define XLAT_STR_4 STRINGIFY(IP_ROUTER_ALERT)
 #endif
 #if defined(IP_RECVOPTIONS) || (defined(HAVE_DECL_IP_RECVOPTIONS) && HAVE_DECL_IP_RECVOPTIONS)
   XLAT(IP_RECVOPTIONS),
+ #define XLAT_VAL_5 ((unsigned) (IP_RECVOPTIONS))
+ #define XLAT_STR_5 STRINGIFY(IP_RECVOPTIONS)
 #endif
 #if defined(IP_RECVOPTS) || (defined(HAVE_DECL_IP_RECVOPTS) && HAVE_DECL_IP_RECVOPTS)
   XLAT(IP_RECVOPTS),
+ #define XLAT_VAL_6 ((unsigned) (IP_RECVOPTS))
+ #define XLAT_STR_6 STRINGIFY(IP_RECVOPTS)
 #endif
 #if defined(IP_RETOPTS) || (defined(HAVE_DECL_IP_RETOPTS) && HAVE_DECL_IP_RETOPTS)
   XLAT(IP_RETOPTS),
+ #define XLAT_VAL_7 ((unsigned) (IP_RETOPTS))
+ #define XLAT_STR_7 STRINGIFY(IP_RETOPTS)
 #endif
 #if defined(IP_RECVRETOPTS) || (defined(HAVE_DECL_IP_RECVRETOPTS) && HAVE_DECL_IP_RECVRETOPTS)
   XLAT(IP_RECVRETOPTS),
+ #define XLAT_VAL_8 ((unsigned) (IP_RECVRETOPTS))
+ #define XLAT_STR_8 STRINGIFY(IP_RECVRETOPTS)
 #endif
 #if defined(IP_RECVDSTADDR) || (defined(HAVE_DECL_IP_RECVDSTADDR) && HAVE_DECL_IP_RECVDSTADDR)
   XLAT(IP_RECVDSTADDR),
+ #define XLAT_VAL_9 ((unsigned) (IP_RECVDSTADDR))
+ #define XLAT_STR_9 STRINGIFY(IP_RECVDSTADDR)
 #endif
 #if defined(IP_PKTINFO) || (defined(HAVE_DECL_IP_PKTINFO) && HAVE_DECL_IP_PKTINFO)
   XLAT(IP_PKTINFO),
+ #define XLAT_VAL_10 ((unsigned) (IP_PKTINFO))
+ #define XLAT_STR_10 STRINGIFY(IP_PKTINFO)
 #endif
 #if defined(IP_PKTOPTIONS) || (defined(HAVE_DECL_IP_PKTOPTIONS) && HAVE_DECL_IP_PKTOPTIONS)
   XLAT(IP_PKTOPTIONS),
+ #define XLAT_VAL_11 ((unsigned) (IP_PKTOPTIONS))
+ #define XLAT_STR_11 STRINGIFY(IP_PKTOPTIONS)
 #endif
 #if defined(IP_MTU_DISCOVER) || (defined(HAVE_DECL_IP_MTU_DISCOVER) && HAVE_DECL_IP_MTU_DISCOVER)
   XLAT(IP_MTU_DISCOVER),
+ #define XLAT_VAL_12 ((unsigned) (IP_MTU_DISCOVER))
+ #define XLAT_STR_12 STRINGIFY(IP_MTU_DISCOVER)
 #endif
 #if defined(IP_RECVERR) || (defined(HAVE_DECL_IP_RECVERR) && HAVE_DECL_IP_RECVERR)
   XLAT(IP_RECVERR),
+ #define XLAT_VAL_13 ((unsigned) (IP_RECVERR))
+ #define XLAT_STR_13 STRINGIFY(IP_RECVERR)
 #endif
 #if defined(IP_RECVTTL) || (defined(HAVE_DECL_IP_RECVTTL) && HAVE_DECL_IP_RECVTTL)
   XLAT(IP_RECVTTL),
+ #define XLAT_VAL_14 ((unsigned) (IP_RECVTTL))
+ #define XLAT_STR_14 STRINGIFY(IP_RECVTTL)
 #endif
 #if defined(IP_RECVTOS) || (defined(HAVE_DECL_IP_RECVTOS) && HAVE_DECL_IP_RECVTOS)
   XLAT(IP_RECVTOS),
+ #define XLAT_VAL_15 ((unsigned) (IP_RECVTOS))
+ #define XLAT_STR_15 STRINGIFY(IP_RECVTOS)
 #endif
 #if defined(IP_MTU) || (defined(HAVE_DECL_IP_MTU) && HAVE_DECL_IP_MTU)
   XLAT(IP_MTU),
+ #define XLAT_VAL_16 ((unsigned) (IP_MTU))
+ #define XLAT_STR_16 STRINGIFY(IP_MTU)
 #endif
 #if defined(IP_MULTICAST_IF) || (defined(HAVE_DECL_IP_MULTICAST_IF) && HAVE_DECL_IP_MULTICAST_IF)
   XLAT(IP_MULTICAST_IF),
+ #define XLAT_VAL_17 ((unsigned) (IP_MULTICAST_IF))
+ #define XLAT_STR_17 STRINGIFY(IP_MULTICAST_IF)
 #endif
 #if defined(IP_MULTICAST_TTL) || (defined(HAVE_DECL_IP_MULTICAST_TTL) && HAVE_DECL_IP_MULTICAST_TTL)
   XLAT(IP_MULTICAST_TTL),
+ #define XLAT_VAL_18 ((unsigned) (IP_MULTICAST_TTL))
+ #define XLAT_STR_18 STRINGIFY(IP_MULTICAST_TTL)
 #endif
 #if defined(IP_MULTICAST_LOOP) || (defined(HAVE_DECL_IP_MULTICAST_LOOP) && HAVE_DECL_IP_MULTICAST_LOOP)
   XLAT(IP_MULTICAST_LOOP),
+ #define XLAT_VAL_19 ((unsigned) (IP_MULTICAST_LOOP))
+ #define XLAT_STR_19 STRINGIFY(IP_MULTICAST_LOOP)
 #endif
 #if defined(IP_ADD_MEMBERSHIP) || (defined(HAVE_DECL_IP_ADD_MEMBERSHIP) && HAVE_DECL_IP_ADD_MEMBERSHIP)
   XLAT(IP_ADD_MEMBERSHIP),
+ #define XLAT_VAL_20 ((unsigned) (IP_ADD_MEMBERSHIP))
+ #define XLAT_STR_20 STRINGIFY(IP_ADD_MEMBERSHIP)
 #endif
 #if defined(IP_DROP_MEMBERSHIP) || (defined(HAVE_DECL_IP_DROP_MEMBERSHIP) && HAVE_DECL_IP_DROP_MEMBERSHIP)
   XLAT(IP_DROP_MEMBERSHIP),
+ #define XLAT_VAL_21 ((unsigned) (IP_DROP_MEMBERSHIP))
+ #define XLAT_STR_21 STRINGIFY(IP_DROP_MEMBERSHIP)
 #endif
 #if defined(IP_BROADCAST_IF) || (defined(HAVE_DECL_IP_BROADCAST_IF) && HAVE_DECL_IP_BROADCAST_IF)
   XLAT(IP_BROADCAST_IF),
+ #define XLAT_VAL_22 ((unsigned) (IP_BROADCAST_IF))
+ #define XLAT_STR_22 STRINGIFY(IP_BROADCAST_IF)
 #endif
 #if defined(IP_RECVIFINDEX) || (defined(HAVE_DECL_IP_RECVIFINDEX) && HAVE_DECL_IP_RECVIFINDEX)
   XLAT(IP_RECVIFINDEX),
+ #define XLAT_VAL_23 ((unsigned) (IP_RECVIFINDEX))
+ #define XLAT_STR_23 STRINGIFY(IP_RECVIFINDEX)
 #endif
 #if defined(IP_MSFILTER) || (defined(HAVE_DECL_IP_MSFILTER) && HAVE_DECL_IP_MSFILTER)
   XLAT(IP_MSFILTER),
+ #define XLAT_VAL_24 ((unsigned) (IP_MSFILTER))
+ #define XLAT_STR_24 STRINGIFY(IP_MSFILTER)
 #endif
 #if defined(IP_FREEBIND) || (defined(HAVE_DECL_IP_FREEBIND) && HAVE_DECL_IP_FREEBIND)
   XLAT(IP_FREEBIND),
+ #define XLAT_VAL_25 ((unsigned) (IP_FREEBIND))
+ #define XLAT_STR_25 STRINGIFY(IP_FREEBIND)
 #endif
 #if defined(IP_IPSEC_POLICY) || (defined(HAVE_DECL_IP_IPSEC_POLICY) && HAVE_DECL_IP_IPSEC_POLICY)
   XLAT(IP_IPSEC_POLICY),
+ #define XLAT_VAL_26 ((unsigned) (IP_IPSEC_POLICY))
+ #define XLAT_STR_26 STRINGIFY(IP_IPSEC_POLICY)
 #endif
 #if defined(IP_XFRM_POLICY) || (defined(HAVE_DECL_IP_XFRM_POLICY) && HAVE_DECL_IP_XFRM_POLICY)
   XLAT(IP_XFRM_POLICY),
+ #define XLAT_VAL_27 ((unsigned) (IP_XFRM_POLICY))
+ #define XLAT_STR_27 STRINGIFY(IP_XFRM_POLICY)
 #endif
 #if defined(IP_PASSSEC) || (defined(HAVE_DECL_IP_PASSSEC) && HAVE_DECL_IP_PASSSEC)
   XLAT(IP_PASSSEC),
+ #define XLAT_VAL_28 ((unsigned) (IP_PASSSEC))
+ #define XLAT_STR_28 STRINGIFY(IP_PASSSEC)
 #endif
 #if defined(IP_TRANSPARENT) || (defined(HAVE_DECL_IP_TRANSPARENT) && HAVE_DECL_IP_TRANSPARENT)
   XLAT(IP_TRANSPARENT),
+ #define XLAT_VAL_29 ((unsigned) (IP_TRANSPARENT))
+ #define XLAT_STR_29 STRINGIFY(IP_TRANSPARENT)
 #endif
 #if defined(IP_ORIGDSTADDR) || (defined(HAVE_DECL_IP_ORIGDSTADDR) && HAVE_DECL_IP_ORIGDSTADDR)
   XLAT(IP_ORIGDSTADDR),
+ #define XLAT_VAL_30 ((unsigned) (IP_ORIGDSTADDR))
+ #define XLAT_STR_30 STRINGIFY(IP_ORIGDSTADDR)
 #endif
 #if defined(IP_RECVORIGDSTADDR) || (defined(HAVE_DECL_IP_RECVORIGDSTADDR) && HAVE_DECL_IP_RECVORIGDSTADDR)
   XLAT(IP_RECVORIGDSTADDR),
+ #define XLAT_VAL_31 ((unsigned) (IP_RECVORIGDSTADDR))
+ #define XLAT_STR_31 STRINGIFY(IP_RECVORIGDSTADDR)
 #endif
 #if defined(IP_MINTTL) || (defined(HAVE_DECL_IP_MINTTL) && HAVE_DECL_IP_MINTTL)
   XLAT(IP_MINTTL),
+ #define XLAT_VAL_32 ((unsigned) (IP_MINTTL))
+ #define XLAT_STR_32 STRINGIFY(IP_MINTTL)
 #endif
 #if defined(IP_NODEFRAG) || (defined(HAVE_DECL_IP_NODEFRAG) && HAVE_DECL_IP_NODEFRAG)
   XLAT(IP_NODEFRAG),
+ #define XLAT_VAL_33 ((unsigned) (IP_NODEFRAG))
+ #define XLAT_STR_33 STRINGIFY(IP_NODEFRAG)
 #endif
 #if defined(IP_CHECKSUM) || (defined(HAVE_DECL_IP_CHECKSUM) && HAVE_DECL_IP_CHECKSUM)
   XLAT(IP_CHECKSUM),
+ #define XLAT_VAL_34 ((unsigned) (IP_CHECKSUM))
+ #define XLAT_STR_34 STRINGIFY(IP_CHECKSUM)
 #endif
 #if defined(IP_BIND_ADDRESS_NO_PORT) || (defined(HAVE_DECL_IP_BIND_ADDRESS_NO_PORT) && HAVE_DECL_IP_BIND_ADDRESS_NO_PORT)
   XLAT(IP_BIND_ADDRESS_NO_PORT),
+ #define XLAT_VAL_35 ((unsigned) (IP_BIND_ADDRESS_NO_PORT))
+ #define XLAT_STR_35 STRINGIFY(IP_BIND_ADDRESS_NO_PORT)
 #endif
 #if defined(IP_RECVFRAGSIZE) || (defined(HAVE_DECL_IP_RECVFRAGSIZE) && HAVE_DECL_IP_RECVFRAGSIZE)
   XLAT(IP_RECVFRAGSIZE),
+ #define XLAT_VAL_36 ((unsigned) (IP_RECVFRAGSIZE))
+ #define XLAT_STR_36 STRINGIFY(IP_RECVFRAGSIZE)
+#endif
+#if defined(IP_RECVERR_RFC4884) || (defined(HAVE_DECL_IP_RECVERR_RFC4884) && HAVE_DECL_IP_RECVERR_RFC4884)
+  XLAT(IP_RECVERR_RFC4884),
+ #define XLAT_VAL_37 ((unsigned) (IP_RECVERR_RFC4884))
+ #define XLAT_STR_37 STRINGIFY(IP_RECVERR_RFC4884)
 #endif
 #if defined(IP_UNBLOCK_SOURCE) || (defined(HAVE_DECL_IP_UNBLOCK_SOURCE) && HAVE_DECL_IP_UNBLOCK_SOURCE)
   XLAT(IP_UNBLOCK_SOURCE),
+ #define XLAT_VAL_38 ((unsigned) (IP_UNBLOCK_SOURCE))
+ #define XLAT_STR_38 STRINGIFY(IP_UNBLOCK_SOURCE)
 #endif
 #if defined(IP_BLOCK_SOURCE) || (defined(HAVE_DECL_IP_BLOCK_SOURCE) && HAVE_DECL_IP_BLOCK_SOURCE)
   XLAT(IP_BLOCK_SOURCE),
+ #define XLAT_VAL_39 ((unsigned) (IP_BLOCK_SOURCE))
+ #define XLAT_STR_39 STRINGIFY(IP_BLOCK_SOURCE)
 #endif
 #if defined(IP_ADD_SOURCE_MEMBERSHIP) || (defined(HAVE_DECL_IP_ADD_SOURCE_MEMBERSHIP) && HAVE_DECL_IP_ADD_SOURCE_MEMBERSHIP)
   XLAT(IP_ADD_SOURCE_MEMBERSHIP),
+ #define XLAT_VAL_40 ((unsigned) (IP_ADD_SOURCE_MEMBERSHIP))
+ #define XLAT_STR_40 STRINGIFY(IP_ADD_SOURCE_MEMBERSHIP)
 #endif
 #if defined(IP_DROP_SOURCE_MEMBERSHIP) || (defined(HAVE_DECL_IP_DROP_SOURCE_MEMBERSHIP) && HAVE_DECL_IP_DROP_SOURCE_MEMBERSHIP)
   XLAT(IP_DROP_SOURCE_MEMBERSHIP),
+ #define XLAT_VAL_41 ((unsigned) (IP_DROP_SOURCE_MEMBERSHIP))
+ #define XLAT_STR_41 STRINGIFY(IP_DROP_SOURCE_MEMBERSHIP)
 #endif
 #if defined(MCAST_JOIN_GROUP) || (defined(HAVE_DECL_MCAST_JOIN_GROUP) && HAVE_DECL_MCAST_JOIN_GROUP)
   XLAT(MCAST_JOIN_GROUP),
+ #define XLAT_VAL_42 ((unsigned) (MCAST_JOIN_GROUP))
+ #define XLAT_STR_42 STRINGIFY(MCAST_JOIN_GROUP)
 #endif
 #if defined(MCAST_BLOCK_SOURCE) || (defined(HAVE_DECL_MCAST_BLOCK_SOURCE) && HAVE_DECL_MCAST_BLOCK_SOURCE)
   XLAT(MCAST_BLOCK_SOURCE),
+ #define XLAT_VAL_43 ((unsigned) (MCAST_BLOCK_SOURCE))
+ #define XLAT_STR_43 STRINGIFY(MCAST_BLOCK_SOURCE)
 #endif
 #if defined(MCAST_UNBLOCK_SOURCE) || (defined(HAVE_DECL_MCAST_UNBLOCK_SOURCE) && HAVE_DECL_MCAST_UNBLOCK_SOURCE)
   XLAT(MCAST_UNBLOCK_SOURCE),
+ #define XLAT_VAL_44 ((unsigned) (MCAST_UNBLOCK_SOURCE))
+ #define XLAT_STR_44 STRINGIFY(MCAST_UNBLOCK_SOURCE)
 #endif
 #if defined(MCAST_LEAVE_GROUP) || (defined(HAVE_DECL_MCAST_LEAVE_GROUP) && HAVE_DECL_MCAST_LEAVE_GROUP)
   XLAT(MCAST_LEAVE_GROUP),
+ #define XLAT_VAL_45 ((unsigned) (MCAST_LEAVE_GROUP))
+ #define XLAT_STR_45 STRINGIFY(MCAST_LEAVE_GROUP)
 #endif
 #if defined(MCAST_JOIN_SOURCE_GROUP) || (defined(HAVE_DECL_MCAST_JOIN_SOURCE_GROUP) && HAVE_DECL_MCAST_JOIN_SOURCE_GROUP)
   XLAT(MCAST_JOIN_SOURCE_GROUP),
+ #define XLAT_VAL_46 ((unsigned) (MCAST_JOIN_SOURCE_GROUP))
+ #define XLAT_STR_46 STRINGIFY(MCAST_JOIN_SOURCE_GROUP)
 #endif
 #if defined(MCAST_LEAVE_SOURCE_GROUP) || (defined(HAVE_DECL_MCAST_LEAVE_SOURCE_GROUP) && HAVE_DECL_MCAST_LEAVE_SOURCE_GROUP)
   XLAT(MCAST_LEAVE_SOURCE_GROUP),
+ #define XLAT_VAL_47 ((unsigned) (MCAST_LEAVE_SOURCE_GROUP))
+ #define XLAT_STR_47 STRINGIFY(MCAST_LEAVE_SOURCE_GROUP)
 #endif
 #if defined(MCAST_MSFILTER) || (defined(HAVE_DECL_MCAST_MSFILTER) && HAVE_DECL_MCAST_MSFILTER)
   XLAT(MCAST_MSFILTER),
+ #define XLAT_VAL_48 ((unsigned) (MCAST_MSFILTER))
+ #define XLAT_STR_48 STRINGIFY(MCAST_MSFILTER)
 #endif
 #if defined(IP_MULTICAST_ALL) || (defined(HAVE_DECL_IP_MULTICAST_ALL) && HAVE_DECL_IP_MULTICAST_ALL)
   XLAT(IP_MULTICAST_ALL),
+ #define XLAT_VAL_49 ((unsigned) (IP_MULTICAST_ALL))
+ #define XLAT_STR_49 STRINGIFY(IP_MULTICAST_ALL)
 #endif
 #if defined(IP_UNICAST_IF) || (defined(HAVE_DECL_IP_UNICAST_IF) && HAVE_DECL_IP_UNICAST_IF)
   XLAT(IP_UNICAST_IF),
+ #define XLAT_VAL_50 ((unsigned) (IP_UNICAST_IF))
+ #define XLAT_STR_50 STRINGIFY(IP_UNICAST_IF)
 #endif
 };
 static
@@ -169,8 +274,420 @@ const struct xlat sock_ip_options[1] = {
  .data = sock_ip_options_xdata,
  .size = ARRAY_SIZE(sock_ip_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+#  ifdef XLAT_VAL_47
+  | XLAT_VAL_47
+#  endif
+#  ifdef XLAT_VAL_48
+  | XLAT_VAL_48
+#  endif
+#  ifdef XLAT_VAL_49
+  | XLAT_VAL_49
+#  endif
+#  ifdef XLAT_VAL_50
+  | XLAT_VAL_50
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+#  ifdef XLAT_STR_47
+  + sizeof(XLAT_STR_47)
+#  endif
+#  ifdef XLAT_STR_48
+  + sizeof(XLAT_STR_48)
+#  endif
+#  ifdef XLAT_STR_49
+  + sizeof(XLAT_STR_49)
+#  endif
+#  ifdef XLAT_STR_50
+  + sizeof(XLAT_STR_50)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
+#  undef XLAT_STR_47
+#  undef XLAT_VAL_47
+#  undef XLAT_STR_48
+#  undef XLAT_VAL_48
+#  undef XLAT_STR_49
+#  undef XLAT_VAL_49
+#  undef XLAT_STR_50
+#  undef XLAT_VAL_50
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_ip_options.in 5.9-0ubuntu2/xlat/sock_ip_options.in
--- 5.5-3/xlat/sock_ip_options.in	2018-05-08 20:59:20.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_ip_options.in	2020-09-06 08:00:00.000000000 +0000
@@ -35,6 +35,7 @@ IP_NODEFRAG
 IP_CHECKSUM
 IP_BIND_ADDRESS_NO_PORT
 IP_RECVFRAGSIZE
+IP_RECVERR_RFC4884
 IP_UNBLOCK_SOURCE
 IP_BLOCK_SOURCE
 IP_ADD_SOURCE_MEMBERSHIP
diff -pruN 5.5-3/xlat/sock_ipv6_options.h 5.9-0ubuntu2/xlat/sock_ipv6_options.h
--- 5.5-3/xlat/sock_ipv6_options.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_ipv6_options.h	2020-09-24 09:18:46.000000000 +0000
@@ -15,195 +15,328 @@
 static const struct xlat_data sock_ipv6_options_xdata[] = {
 #if defined(IPV6_ADDRFORM) || (defined(HAVE_DECL_IPV6_ADDRFORM) && HAVE_DECL_IPV6_ADDRFORM)
   XLAT(IPV6_ADDRFORM),
+ #define XLAT_VAL_0 ((unsigned) (IPV6_ADDRFORM))
+ #define XLAT_STR_0 STRINGIFY(IPV6_ADDRFORM)
 #endif
 #if defined(IPV6_2292PKTINFO) || (defined(HAVE_DECL_IPV6_2292PKTINFO) && HAVE_DECL_IPV6_2292PKTINFO)
   XLAT(IPV6_2292PKTINFO),
+ #define XLAT_VAL_1 ((unsigned) (IPV6_2292PKTINFO))
+ #define XLAT_STR_1 STRINGIFY(IPV6_2292PKTINFO)
 #endif
 #if defined(IPV6_2292HOPOPTS) || (defined(HAVE_DECL_IPV6_2292HOPOPTS) && HAVE_DECL_IPV6_2292HOPOPTS)
   XLAT(IPV6_2292HOPOPTS),
+ #define XLAT_VAL_2 ((unsigned) (IPV6_2292HOPOPTS))
+ #define XLAT_STR_2 STRINGIFY(IPV6_2292HOPOPTS)
 #endif
 #if defined(IPV6_2292DSTOPTS) || (defined(HAVE_DECL_IPV6_2292DSTOPTS) && HAVE_DECL_IPV6_2292DSTOPTS)
   XLAT(IPV6_2292DSTOPTS),
+ #define XLAT_VAL_3 ((unsigned) (IPV6_2292DSTOPTS))
+ #define XLAT_STR_3 STRINGIFY(IPV6_2292DSTOPTS)
 #endif
 #if defined(IPV6_2292RTHDR) || (defined(HAVE_DECL_IPV6_2292RTHDR) && HAVE_DECL_IPV6_2292RTHDR)
   XLAT(IPV6_2292RTHDR),
+ #define XLAT_VAL_4 ((unsigned) (IPV6_2292RTHDR))
+ #define XLAT_STR_4 STRINGIFY(IPV6_2292RTHDR)
 #endif
 #if defined(IPV6_2292PKTOPTIONS) || (defined(HAVE_DECL_IPV6_2292PKTOPTIONS) && HAVE_DECL_IPV6_2292PKTOPTIONS)
   XLAT(IPV6_2292PKTOPTIONS),
+ #define XLAT_VAL_5 ((unsigned) (IPV6_2292PKTOPTIONS))
+ #define XLAT_STR_5 STRINGIFY(IPV6_2292PKTOPTIONS)
 #endif
 #if defined(IPV6_CHECKSUM) || (defined(HAVE_DECL_IPV6_CHECKSUM) && HAVE_DECL_IPV6_CHECKSUM)
   XLAT(IPV6_CHECKSUM),
+ #define XLAT_VAL_6 ((unsigned) (IPV6_CHECKSUM))
+ #define XLAT_STR_6 STRINGIFY(IPV6_CHECKSUM)
 #endif
 #if defined(IPV6_2292HOPLIMIT) || (defined(HAVE_DECL_IPV6_2292HOPLIMIT) && HAVE_DECL_IPV6_2292HOPLIMIT)
   XLAT(IPV6_2292HOPLIMIT),
+ #define XLAT_VAL_7 ((unsigned) (IPV6_2292HOPLIMIT))
+ #define XLAT_STR_7 STRINGIFY(IPV6_2292HOPLIMIT)
 #endif
 #if defined(IPV6_NEXTHOP) || (defined(HAVE_DECL_IPV6_NEXTHOP) && HAVE_DECL_IPV6_NEXTHOP)
   XLAT(IPV6_NEXTHOP),
+ #define XLAT_VAL_8 ((unsigned) (IPV6_NEXTHOP))
+ #define XLAT_STR_8 STRINGIFY(IPV6_NEXTHOP)
 #endif
 #if defined(IPV6_AUTHHDR) || (defined(HAVE_DECL_IPV6_AUTHHDR) && HAVE_DECL_IPV6_AUTHHDR)
   XLAT(IPV6_AUTHHDR),
+ #define XLAT_VAL_9 ((unsigned) (IPV6_AUTHHDR))
+ #define XLAT_STR_9 STRINGIFY(IPV6_AUTHHDR)
 #endif
 #if defined(IPV6_FLOWINFO) || (defined(HAVE_DECL_IPV6_FLOWINFO) && HAVE_DECL_IPV6_FLOWINFO)
   XLAT(IPV6_FLOWINFO),
+ #define XLAT_VAL_10 ((unsigned) (IPV6_FLOWINFO))
+ #define XLAT_STR_10 STRINGIFY(IPV6_FLOWINFO)
 #endif
 #if defined(IPV6_UNICAST_HOPS) || (defined(HAVE_DECL_IPV6_UNICAST_HOPS) && HAVE_DECL_IPV6_UNICAST_HOPS)
   XLAT(IPV6_UNICAST_HOPS),
+ #define XLAT_VAL_11 ((unsigned) (IPV6_UNICAST_HOPS))
+ #define XLAT_STR_11 STRINGIFY(IPV6_UNICAST_HOPS)
 #endif
 #if defined(IPV6_MULTICAST_IF) || (defined(HAVE_DECL_IPV6_MULTICAST_IF) && HAVE_DECL_IPV6_MULTICAST_IF)
   XLAT(IPV6_MULTICAST_IF),
+ #define XLAT_VAL_12 ((unsigned) (IPV6_MULTICAST_IF))
+ #define XLAT_STR_12 STRINGIFY(IPV6_MULTICAST_IF)
 #endif
 #if defined(IPV6_MULTICAST_HOPS) || (defined(HAVE_DECL_IPV6_MULTICAST_HOPS) && HAVE_DECL_IPV6_MULTICAST_HOPS)
   XLAT(IPV6_MULTICAST_HOPS),
+ #define XLAT_VAL_13 ((unsigned) (IPV6_MULTICAST_HOPS))
+ #define XLAT_STR_13 STRINGIFY(IPV6_MULTICAST_HOPS)
 #endif
 #if defined(IPV6_MULTICAST_LOOP) || (defined(HAVE_DECL_IPV6_MULTICAST_LOOP) && HAVE_DECL_IPV6_MULTICAST_LOOP)
   XLAT(IPV6_MULTICAST_LOOP),
+ #define XLAT_VAL_14 ((unsigned) (IPV6_MULTICAST_LOOP))
+ #define XLAT_STR_14 STRINGIFY(IPV6_MULTICAST_LOOP)
 #endif
 #if defined(IPV6_ADD_MEMBERSHIP) || (defined(HAVE_DECL_IPV6_ADD_MEMBERSHIP) && HAVE_DECL_IPV6_ADD_MEMBERSHIP)
   XLAT(IPV6_ADD_MEMBERSHIP),
+ #define XLAT_VAL_15 ((unsigned) (IPV6_ADD_MEMBERSHIP))
+ #define XLAT_STR_15 STRINGIFY(IPV6_ADD_MEMBERSHIP)
 #endif
 #if defined(IPV6_DROP_MEMBERSHIP) || (defined(HAVE_DECL_IPV6_DROP_MEMBERSHIP) && HAVE_DECL_IPV6_DROP_MEMBERSHIP)
   XLAT(IPV6_DROP_MEMBERSHIP),
+ #define XLAT_VAL_16 ((unsigned) (IPV6_DROP_MEMBERSHIP))
+ #define XLAT_STR_16 STRINGIFY(IPV6_DROP_MEMBERSHIP)
 #endif
 #if defined(IPV6_ROUTER_ALERT) || (defined(HAVE_DECL_IPV6_ROUTER_ALERT) && HAVE_DECL_IPV6_ROUTER_ALERT)
   XLAT(IPV6_ROUTER_ALERT),
+ #define XLAT_VAL_17 ((unsigned) (IPV6_ROUTER_ALERT))
+ #define XLAT_STR_17 STRINGIFY(IPV6_ROUTER_ALERT)
 #endif
 #if defined(IPV6_MTU_DISCOVER) || (defined(HAVE_DECL_IPV6_MTU_DISCOVER) && HAVE_DECL_IPV6_MTU_DISCOVER)
   XLAT(IPV6_MTU_DISCOVER),
+ #define XLAT_VAL_18 ((unsigned) (IPV6_MTU_DISCOVER))
+ #define XLAT_STR_18 STRINGIFY(IPV6_MTU_DISCOVER)
 #endif
 #if defined(IPV6_MTU) || (defined(HAVE_DECL_IPV6_MTU) && HAVE_DECL_IPV6_MTU)
   XLAT(IPV6_MTU),
+ #define XLAT_VAL_19 ((unsigned) (IPV6_MTU))
+ #define XLAT_STR_19 STRINGIFY(IPV6_MTU)
 #endif
 #if defined(IPV6_RECVERR) || (defined(HAVE_DECL_IPV6_RECVERR) && HAVE_DECL_IPV6_RECVERR)
   XLAT(IPV6_RECVERR),
+ #define XLAT_VAL_20 ((unsigned) (IPV6_RECVERR))
+ #define XLAT_STR_20 STRINGIFY(IPV6_RECVERR)
 #endif
 #if defined(IPV6_V6ONLY) || (defined(HAVE_DECL_IPV6_V6ONLY) && HAVE_DECL_IPV6_V6ONLY)
   XLAT(IPV6_V6ONLY),
+ #define XLAT_VAL_21 ((unsigned) (IPV6_V6ONLY))
+ #define XLAT_STR_21 STRINGIFY(IPV6_V6ONLY)
 #endif
 #if defined(IPV6_JOIN_ANYCAST) || (defined(HAVE_DECL_IPV6_JOIN_ANYCAST) && HAVE_DECL_IPV6_JOIN_ANYCAST)
   XLAT(IPV6_JOIN_ANYCAST),
+ #define XLAT_VAL_22 ((unsigned) (IPV6_JOIN_ANYCAST))
+ #define XLAT_STR_22 STRINGIFY(IPV6_JOIN_ANYCAST)
 #endif
 #if defined(IPV6_LEAVE_ANYCAST) || (defined(HAVE_DECL_IPV6_LEAVE_ANYCAST) && HAVE_DECL_IPV6_LEAVE_ANYCAST)
   XLAT(IPV6_LEAVE_ANYCAST),
+ #define XLAT_VAL_23 ((unsigned) (IPV6_LEAVE_ANYCAST))
+ #define XLAT_STR_23 STRINGIFY(IPV6_LEAVE_ANYCAST)
 #endif
 #if defined(IPV6_MULTICAST_ALL) || (defined(HAVE_DECL_IPV6_MULTICAST_ALL) && HAVE_DECL_IPV6_MULTICAST_ALL)
   XLAT(IPV6_MULTICAST_ALL),
+ #define XLAT_VAL_24 ((unsigned) (IPV6_MULTICAST_ALL))
+ #define XLAT_STR_24 STRINGIFY(IPV6_MULTICAST_ALL)
 #endif
 #if defined(IPV6_ROUTER_ALERT_ISOLATE) || (defined(HAVE_DECL_IPV6_ROUTER_ALERT_ISOLATE) && HAVE_DECL_IPV6_ROUTER_ALERT_ISOLATE)
   XLAT(IPV6_ROUTER_ALERT_ISOLATE),
+ #define XLAT_VAL_25 ((unsigned) (IPV6_ROUTER_ALERT_ISOLATE))
+ #define XLAT_STR_25 STRINGIFY(IPV6_ROUTER_ALERT_ISOLATE)
+#endif
+#if defined(IPV6_RECVERR_RFC4884) || (defined(HAVE_DECL_IPV6_RECVERR_RFC4884) && HAVE_DECL_IPV6_RECVERR_RFC4884)
+  XLAT(IPV6_RECVERR_RFC4884),
+ #define XLAT_VAL_26 ((unsigned) (IPV6_RECVERR_RFC4884))
+ #define XLAT_STR_26 STRINGIFY(IPV6_RECVERR_RFC4884)
 #endif
 #if defined(IPV6_FLOWLABEL_MGR) || (defined(HAVE_DECL_IPV6_FLOWLABEL_MGR) && HAVE_DECL_IPV6_FLOWLABEL_MGR)
   XLAT(IPV6_FLOWLABEL_MGR),
+ #define XLAT_VAL_27 ((unsigned) (IPV6_FLOWLABEL_MGR))
+ #define XLAT_STR_27 STRINGIFY(IPV6_FLOWLABEL_MGR)
 #endif
 #if defined(IPV6_FLOWINFO_SEND) || (defined(HAVE_DECL_IPV6_FLOWINFO_SEND) && HAVE_DECL_IPV6_FLOWINFO_SEND)
   XLAT(IPV6_FLOWINFO_SEND),
+ #define XLAT_VAL_28 ((unsigned) (IPV6_FLOWINFO_SEND))
+ #define XLAT_STR_28 STRINGIFY(IPV6_FLOWINFO_SEND)
 #endif
 #if defined(IPV6_IPSEC_POLICY) || (defined(HAVE_DECL_IPV6_IPSEC_POLICY) && HAVE_DECL_IPV6_IPSEC_POLICY)
   XLAT(IPV6_IPSEC_POLICY),
+ #define XLAT_VAL_29 ((unsigned) (IPV6_IPSEC_POLICY))
+ #define XLAT_STR_29 STRINGIFY(IPV6_IPSEC_POLICY)
 #endif
 #if defined(IPV6_XFRM_POLICY) || (defined(HAVE_DECL_IPV6_XFRM_POLICY) && HAVE_DECL_IPV6_XFRM_POLICY)
   XLAT(IPV6_XFRM_POLICY),
+ #define XLAT_VAL_30 ((unsigned) (IPV6_XFRM_POLICY))
+ #define XLAT_STR_30 STRINGIFY(IPV6_XFRM_POLICY)
 #endif
 #if defined(IPV6_HDRINCL) || (defined(HAVE_DECL_IPV6_HDRINCL) && HAVE_DECL_IPV6_HDRINCL)
   XLAT(IPV6_HDRINCL),
+ #define XLAT_VAL_31 ((unsigned) (IPV6_HDRINCL))
+ #define XLAT_STR_31 STRINGIFY(IPV6_HDRINCL)
 #endif
 #if defined(MCAST_JOIN_GROUP) || (defined(HAVE_DECL_MCAST_JOIN_GROUP) && HAVE_DECL_MCAST_JOIN_GROUP)
   XLAT(MCAST_JOIN_GROUP),
+ #define XLAT_VAL_32 ((unsigned) (MCAST_JOIN_GROUP))
+ #define XLAT_STR_32 STRINGIFY(MCAST_JOIN_GROUP)
 #endif
 #if defined(MCAST_BLOCK_SOURCE) || (defined(HAVE_DECL_MCAST_BLOCK_SOURCE) && HAVE_DECL_MCAST_BLOCK_SOURCE)
   XLAT(MCAST_BLOCK_SOURCE),
+ #define XLAT_VAL_33 ((unsigned) (MCAST_BLOCK_SOURCE))
+ #define XLAT_STR_33 STRINGIFY(MCAST_BLOCK_SOURCE)
 #endif
 #if defined(MCAST_UNBLOCK_SOURCE) || (defined(HAVE_DECL_MCAST_UNBLOCK_SOURCE) && HAVE_DECL_MCAST_UNBLOCK_SOURCE)
   XLAT(MCAST_UNBLOCK_SOURCE),
+ #define XLAT_VAL_34 ((unsigned) (MCAST_UNBLOCK_SOURCE))
+ #define XLAT_STR_34 STRINGIFY(MCAST_UNBLOCK_SOURCE)
 #endif
 #if defined(MCAST_LEAVE_GROUP) || (defined(HAVE_DECL_MCAST_LEAVE_GROUP) && HAVE_DECL_MCAST_LEAVE_GROUP)
   XLAT(MCAST_LEAVE_GROUP),
+ #define XLAT_VAL_35 ((unsigned) (MCAST_LEAVE_GROUP))
+ #define XLAT_STR_35 STRINGIFY(MCAST_LEAVE_GROUP)
 #endif
 #if defined(MCAST_JOIN_SOURCE_GROUP) || (defined(HAVE_DECL_MCAST_JOIN_SOURCE_GROUP) && HAVE_DECL_MCAST_JOIN_SOURCE_GROUP)
   XLAT(MCAST_JOIN_SOURCE_GROUP),
+ #define XLAT_VAL_36 ((unsigned) (MCAST_JOIN_SOURCE_GROUP))
+ #define XLAT_STR_36 STRINGIFY(MCAST_JOIN_SOURCE_GROUP)
 #endif
 #if defined(MCAST_LEAVE_SOURCE_GROUP) || (defined(HAVE_DECL_MCAST_LEAVE_SOURCE_GROUP) && HAVE_DECL_MCAST_LEAVE_SOURCE_GROUP)
   XLAT(MCAST_LEAVE_SOURCE_GROUP),
+ #define XLAT_VAL_37 ((unsigned) (MCAST_LEAVE_SOURCE_GROUP))
+ #define XLAT_STR_37 STRINGIFY(MCAST_LEAVE_SOURCE_GROUP)
 #endif
 #if defined(MCAST_MSFILTER) || (defined(HAVE_DECL_MCAST_MSFILTER) && HAVE_DECL_MCAST_MSFILTER)
   XLAT(MCAST_MSFILTER),
+ #define XLAT_VAL_38 ((unsigned) (MCAST_MSFILTER))
+ #define XLAT_STR_38 STRINGIFY(MCAST_MSFILTER)
 #endif
 #if defined(IPV6_RECVPKTINFO) || (defined(HAVE_DECL_IPV6_RECVPKTINFO) && HAVE_DECL_IPV6_RECVPKTINFO)
   XLAT(IPV6_RECVPKTINFO),
+ #define XLAT_VAL_39 ((unsigned) (IPV6_RECVPKTINFO))
+ #define XLAT_STR_39 STRINGIFY(IPV6_RECVPKTINFO)
 #endif
 #if defined(IPV6_PKTINFO) || (defined(HAVE_DECL_IPV6_PKTINFO) && HAVE_DECL_IPV6_PKTINFO)
   XLAT(IPV6_PKTINFO),
+ #define XLAT_VAL_40 ((unsigned) (IPV6_PKTINFO))
+ #define XLAT_STR_40 STRINGIFY(IPV6_PKTINFO)
 #endif
 #if defined(IPV6_RECVHOPLIMIT) || (defined(HAVE_DECL_IPV6_RECVHOPLIMIT) && HAVE_DECL_IPV6_RECVHOPLIMIT)
   XLAT(IPV6_RECVHOPLIMIT),
+ #define XLAT_VAL_41 ((unsigned) (IPV6_RECVHOPLIMIT))
+ #define XLAT_STR_41 STRINGIFY(IPV6_RECVHOPLIMIT)
 #endif
 #if defined(IPV6_HOPLIMIT) || (defined(HAVE_DECL_IPV6_HOPLIMIT) && HAVE_DECL_IPV6_HOPLIMIT)
   XLAT(IPV6_HOPLIMIT),
+ #define XLAT_VAL_42 ((unsigned) (IPV6_HOPLIMIT))
+ #define XLAT_STR_42 STRINGIFY(IPV6_HOPLIMIT)
 #endif
 #if defined(IPV6_RECVHOPOPTS) || (defined(HAVE_DECL_IPV6_RECVHOPOPTS) && HAVE_DECL_IPV6_RECVHOPOPTS)
   XLAT(IPV6_RECVHOPOPTS),
+ #define XLAT_VAL_43 ((unsigned) (IPV6_RECVHOPOPTS))
+ #define XLAT_STR_43 STRINGIFY(IPV6_RECVHOPOPTS)
 #endif
 #if defined(IPV6_HOPOPTS) || (defined(HAVE_DECL_IPV6_HOPOPTS) && HAVE_DECL_IPV6_HOPOPTS)
   XLAT(IPV6_HOPOPTS),
+ #define XLAT_VAL_44 ((unsigned) (IPV6_HOPOPTS))
+ #define XLAT_STR_44 STRINGIFY(IPV6_HOPOPTS)
 #endif
 #if defined(IPV6_RTHDRDSTOPTS) || (defined(HAVE_DECL_IPV6_RTHDRDSTOPTS) && HAVE_DECL_IPV6_RTHDRDSTOPTS)
   XLAT(IPV6_RTHDRDSTOPTS),
+ #define XLAT_VAL_45 ((unsigned) (IPV6_RTHDRDSTOPTS))
+ #define XLAT_STR_45 STRINGIFY(IPV6_RTHDRDSTOPTS)
 #endif
 #if defined(IPV6_RECVRTHDR) || (defined(HAVE_DECL_IPV6_RECVRTHDR) && HAVE_DECL_IPV6_RECVRTHDR)
   XLAT(IPV6_RECVRTHDR),
+ #define XLAT_VAL_46 ((unsigned) (IPV6_RECVRTHDR))
+ #define XLAT_STR_46 STRINGIFY(IPV6_RECVRTHDR)
 #endif
 #if defined(IPV6_RTHDR) || (defined(HAVE_DECL_IPV6_RTHDR) && HAVE_DECL_IPV6_RTHDR)
   XLAT(IPV6_RTHDR),
+ #define XLAT_VAL_47 ((unsigned) (IPV6_RTHDR))
+ #define XLAT_STR_47 STRINGIFY(IPV6_RTHDR)
 #endif
 #if defined(IPV6_RECVDSTOPTS) || (defined(HAVE_DECL_IPV6_RECVDSTOPTS) && HAVE_DECL_IPV6_RECVDSTOPTS)
   XLAT(IPV6_RECVDSTOPTS),
+ #define XLAT_VAL_48 ((unsigned) (IPV6_RECVDSTOPTS))
+ #define XLAT_STR_48 STRINGIFY(IPV6_RECVDSTOPTS)
 #endif
 #if defined(IPV6_DSTOPTS) || (defined(HAVE_DECL_IPV6_DSTOPTS) && HAVE_DECL_IPV6_DSTOPTS)
   XLAT(IPV6_DSTOPTS),
+ #define XLAT_VAL_49 ((unsigned) (IPV6_DSTOPTS))
+ #define XLAT_STR_49 STRINGIFY(IPV6_DSTOPTS)
 #endif
 #if defined(IPV6_RECVPATHMTU) || (defined(HAVE_DECL_IPV6_RECVPATHMTU) && HAVE_DECL_IPV6_RECVPATHMTU)
   XLAT(IPV6_RECVPATHMTU),
+ #define XLAT_VAL_50 ((unsigned) (IPV6_RECVPATHMTU))
+ #define XLAT_STR_50 STRINGIFY(IPV6_RECVPATHMTU)
 #endif
 #if defined(IPV6_PATHMTU) || (defined(HAVE_DECL_IPV6_PATHMTU) && HAVE_DECL_IPV6_PATHMTU)
   XLAT(IPV6_PATHMTU),
+ #define XLAT_VAL_51 ((unsigned) (IPV6_PATHMTU))
+ #define XLAT_STR_51 STRINGIFY(IPV6_PATHMTU)
 #endif
 #if defined(IPV6_DONTFRAG) || (defined(HAVE_DECL_IPV6_DONTFRAG) && HAVE_DECL_IPV6_DONTFRAG)
   XLAT(IPV6_DONTFRAG),
+ #define XLAT_VAL_52 ((unsigned) (IPV6_DONTFRAG))
+ #define XLAT_STR_52 STRINGIFY(IPV6_DONTFRAG)
 #endif
 #if defined(IPV6_USE_MIN_MTU) || (defined(HAVE_DECL_IPV6_USE_MIN_MTU) && HAVE_DECL_IPV6_USE_MIN_MTU)
   XLAT(IPV6_USE_MIN_MTU),
+ #define XLAT_VAL_53 ((unsigned) (IPV6_USE_MIN_MTU))
+ #define XLAT_STR_53 STRINGIFY(IPV6_USE_MIN_MTU)
 #endif
 #if defined(IPV6_RECVTCLASS) || (defined(HAVE_DECL_IPV6_RECVTCLASS) && HAVE_DECL_IPV6_RECVTCLASS)
   XLAT(IPV6_RECVTCLASS),
+ #define XLAT_VAL_54 ((unsigned) (IPV6_RECVTCLASS))
+ #define XLAT_STR_54 STRINGIFY(IPV6_RECVTCLASS)
 #endif
 #if defined(IPV6_TCLASS) || (defined(HAVE_DECL_IPV6_TCLASS) && HAVE_DECL_IPV6_TCLASS)
   XLAT(IPV6_TCLASS),
+ #define XLAT_VAL_55 ((unsigned) (IPV6_TCLASS))
+ #define XLAT_STR_55 STRINGIFY(IPV6_TCLASS)
 #endif
 #if defined(IPV6_AUTOFLOWLABEL) || (defined(HAVE_DECL_IPV6_AUTOFLOWLABEL) && HAVE_DECL_IPV6_AUTOFLOWLABEL)
   XLAT(IPV6_AUTOFLOWLABEL),
+ #define XLAT_VAL_56 ((unsigned) (IPV6_AUTOFLOWLABEL))
+ #define XLAT_STR_56 STRINGIFY(IPV6_AUTOFLOWLABEL)
 #endif
 #if defined(IPV6_ADDR_PREFERENCES) || (defined(HAVE_DECL_IPV6_ADDR_PREFERENCES) && HAVE_DECL_IPV6_ADDR_PREFERENCES)
   XLAT(IPV6_ADDR_PREFERENCES),
+ #define XLAT_VAL_57 ((unsigned) (IPV6_ADDR_PREFERENCES))
+ #define XLAT_STR_57 STRINGIFY(IPV6_ADDR_PREFERENCES)
 #endif
 #if defined(IPV6_MINHOPCOUNT) || (defined(HAVE_DECL_IPV6_MINHOPCOUNT) && HAVE_DECL_IPV6_MINHOPCOUNT)
   XLAT(IPV6_MINHOPCOUNT),
+ #define XLAT_VAL_58 ((unsigned) (IPV6_MINHOPCOUNT))
+ #define XLAT_STR_58 STRINGIFY(IPV6_MINHOPCOUNT)
 #endif
 #if defined(IPV6_ORIGDSTADDR) || (defined(HAVE_DECL_IPV6_ORIGDSTADDR) && HAVE_DECL_IPV6_ORIGDSTADDR)
   XLAT(IPV6_ORIGDSTADDR),
+ #define XLAT_VAL_59 ((unsigned) (IPV6_ORIGDSTADDR))
+ #define XLAT_STR_59 STRINGIFY(IPV6_ORIGDSTADDR)
 #endif
 #if defined(IPV6_RECVORIGDSTADDR) || (defined(HAVE_DECL_IPV6_RECVORIGDSTADDR) && HAVE_DECL_IPV6_RECVORIGDSTADDR)
   XLAT(IPV6_RECVORIGDSTADDR),
+ #define XLAT_VAL_60 ((unsigned) (IPV6_RECVORIGDSTADDR))
+ #define XLAT_STR_60 STRINGIFY(IPV6_RECVORIGDSTADDR)
 #endif
 #if defined(IPV6_TRANSPARENT) || (defined(HAVE_DECL_IPV6_TRANSPARENT) && HAVE_DECL_IPV6_TRANSPARENT)
   XLAT(IPV6_TRANSPARENT),
+ #define XLAT_VAL_61 ((unsigned) (IPV6_TRANSPARENT))
+ #define XLAT_STR_61 STRINGIFY(IPV6_TRANSPARENT)
 #endif
 #if defined(IPV6_UNICAST_IF) || (defined(HAVE_DECL_IPV6_UNICAST_IF) && HAVE_DECL_IPV6_UNICAST_IF)
   XLAT(IPV6_UNICAST_IF),
+ #define XLAT_VAL_62 ((unsigned) (IPV6_UNICAST_IF))
+ #define XLAT_STR_62 STRINGIFY(IPV6_UNICAST_IF)
 #endif
 #if defined(IPV6_RECVFRAGSIZE) || (defined(HAVE_DECL_IPV6_RECVFRAGSIZE) && HAVE_DECL_IPV6_RECVFRAGSIZE)
   XLAT(IPV6_RECVFRAGSIZE),
+ #define XLAT_VAL_63 ((unsigned) (IPV6_RECVFRAGSIZE))
+ #define XLAT_STR_63 STRINGIFY(IPV6_RECVFRAGSIZE)
 #endif
 #if defined(IPV6_FREEBIND) || (defined(HAVE_DECL_IPV6_FREEBIND) && HAVE_DECL_IPV6_FREEBIND)
   XLAT(IPV6_FREEBIND),
+ #define XLAT_VAL_64 ((unsigned) (IPV6_FREEBIND))
+ #define XLAT_STR_64 STRINGIFY(IPV6_FREEBIND)
 #endif
 };
 static
@@ -211,8 +344,532 @@ const struct xlat sock_ipv6_options[1] =
  .data = sock_ipv6_options_xdata,
  .size = ARRAY_SIZE(sock_ipv6_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+#  ifdef XLAT_VAL_47
+  | XLAT_VAL_47
+#  endif
+#  ifdef XLAT_VAL_48
+  | XLAT_VAL_48
+#  endif
+#  ifdef XLAT_VAL_49
+  | XLAT_VAL_49
+#  endif
+#  ifdef XLAT_VAL_50
+  | XLAT_VAL_50
+#  endif
+#  ifdef XLAT_VAL_51
+  | XLAT_VAL_51
+#  endif
+#  ifdef XLAT_VAL_52
+  | XLAT_VAL_52
+#  endif
+#  ifdef XLAT_VAL_53
+  | XLAT_VAL_53
+#  endif
+#  ifdef XLAT_VAL_54
+  | XLAT_VAL_54
+#  endif
+#  ifdef XLAT_VAL_55
+  | XLAT_VAL_55
+#  endif
+#  ifdef XLAT_VAL_56
+  | XLAT_VAL_56
+#  endif
+#  ifdef XLAT_VAL_57
+  | XLAT_VAL_57
+#  endif
+#  ifdef XLAT_VAL_58
+  | XLAT_VAL_58
+#  endif
+#  ifdef XLAT_VAL_59
+  | XLAT_VAL_59
+#  endif
+#  ifdef XLAT_VAL_60
+  | XLAT_VAL_60
+#  endif
+#  ifdef XLAT_VAL_61
+  | XLAT_VAL_61
+#  endif
+#  ifdef XLAT_VAL_62
+  | XLAT_VAL_62
+#  endif
+#  ifdef XLAT_VAL_63
+  | XLAT_VAL_63
+#  endif
+#  ifdef XLAT_VAL_64
+  | XLAT_VAL_64
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+#  ifdef XLAT_STR_47
+  + sizeof(XLAT_STR_47)
+#  endif
+#  ifdef XLAT_STR_48
+  + sizeof(XLAT_STR_48)
+#  endif
+#  ifdef XLAT_STR_49
+  + sizeof(XLAT_STR_49)
+#  endif
+#  ifdef XLAT_STR_50
+  + sizeof(XLAT_STR_50)
+#  endif
+#  ifdef XLAT_STR_51
+  + sizeof(XLAT_STR_51)
+#  endif
+#  ifdef XLAT_STR_52
+  + sizeof(XLAT_STR_52)
+#  endif
+#  ifdef XLAT_STR_53
+  + sizeof(XLAT_STR_53)
+#  endif
+#  ifdef XLAT_STR_54
+  + sizeof(XLAT_STR_54)
+#  endif
+#  ifdef XLAT_STR_55
+  + sizeof(XLAT_STR_55)
+#  endif
+#  ifdef XLAT_STR_56
+  + sizeof(XLAT_STR_56)
+#  endif
+#  ifdef XLAT_STR_57
+  + sizeof(XLAT_STR_57)
+#  endif
+#  ifdef XLAT_STR_58
+  + sizeof(XLAT_STR_58)
+#  endif
+#  ifdef XLAT_STR_59
+  + sizeof(XLAT_STR_59)
+#  endif
+#  ifdef XLAT_STR_60
+  + sizeof(XLAT_STR_60)
+#  endif
+#  ifdef XLAT_STR_61
+  + sizeof(XLAT_STR_61)
+#  endif
+#  ifdef XLAT_STR_62
+  + sizeof(XLAT_STR_62)
+#  endif
+#  ifdef XLAT_STR_63
+  + sizeof(XLAT_STR_63)
+#  endif
+#  ifdef XLAT_STR_64
+  + sizeof(XLAT_STR_64)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
+#  undef XLAT_STR_47
+#  undef XLAT_VAL_47
+#  undef XLAT_STR_48
+#  undef XLAT_VAL_48
+#  undef XLAT_STR_49
+#  undef XLAT_VAL_49
+#  undef XLAT_STR_50
+#  undef XLAT_VAL_50
+#  undef XLAT_STR_51
+#  undef XLAT_VAL_51
+#  undef XLAT_STR_52
+#  undef XLAT_VAL_52
+#  undef XLAT_STR_53
+#  undef XLAT_VAL_53
+#  undef XLAT_STR_54
+#  undef XLAT_VAL_54
+#  undef XLAT_STR_55
+#  undef XLAT_VAL_55
+#  undef XLAT_STR_56
+#  undef XLAT_VAL_56
+#  undef XLAT_STR_57
+#  undef XLAT_VAL_57
+#  undef XLAT_STR_58
+#  undef XLAT_VAL_58
+#  undef XLAT_STR_59
+#  undef XLAT_VAL_59
+#  undef XLAT_STR_60
+#  undef XLAT_VAL_60
+#  undef XLAT_STR_61
+#  undef XLAT_VAL_61
+#  undef XLAT_STR_62
+#  undef XLAT_VAL_62
+#  undef XLAT_STR_63
+#  undef XLAT_VAL_63
+#  undef XLAT_STR_64
+#  undef XLAT_VAL_64
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_ipv6_options.in 5.9-0ubuntu2/xlat/sock_ipv6_options.in
--- 5.5-3/xlat/sock_ipv6_options.in	2019-05-21 21:26:52.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_ipv6_options.in	2020-09-06 08:00:00.000000000 +0000
@@ -24,6 +24,7 @@ IPV6_JOIN_ANYCAST
 IPV6_LEAVE_ANYCAST
 IPV6_MULTICAST_ALL
 IPV6_ROUTER_ALERT_ISOLATE
+IPV6_RECVERR_RFC4884
 IPV6_FLOWLABEL_MGR
 IPV6_FLOWINFO_SEND
 IPV6_IPSEC_POLICY
diff -pruN 5.5-3/xlat/sock_ipx_options.h 5.9-0ubuntu2/xlat/sock_ipx_options.h
--- 5.5-3/xlat/sock_ipx_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_ipx_options.h	2020-09-24 09:18:45.000000000 +0000
@@ -15,6 +15,8 @@
 static const struct xlat_data sock_ipx_options_xdata[] = {
 #if defined(IPX_TYPE) || (defined(HAVE_DECL_IPX_TYPE) && HAVE_DECL_IPX_TYPE)
   XLAT(IPX_TYPE),
+ #define XLAT_VAL_0 ((unsigned) (IPX_TYPE))
+ #define XLAT_STR_0 STRINGIFY(IPX_TYPE)
 #endif
 };
 static
@@ -22,8 +24,20 @@ const struct xlat sock_ipx_options[1] =
  .data = sock_ipx_options_xdata,
  .size = ARRAY_SIZE(sock_ipx_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_irda_options.h 5.9-0ubuntu2/xlat/sock_irda_options.h
--- 5.5-3/xlat/sock_irda_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_irda_options.h	2020-09-24 09:18:46.000000000 +0000
@@ -91,24 +91,138 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sock_irda_options_xdata[] = {
  [IRLMP_ENUMDEVICES] = XLAT(IRLMP_ENUMDEVICES),
+ #define XLAT_VAL_0 ((unsigned) (IRLMP_ENUMDEVICES))
+ #define XLAT_STR_0 STRINGIFY(IRLMP_ENUMDEVICES)
  [IRLMP_IAS_SET] = XLAT(IRLMP_IAS_SET),
+ #define XLAT_VAL_1 ((unsigned) (IRLMP_IAS_SET))
+ #define XLAT_STR_1 STRINGIFY(IRLMP_IAS_SET)
  [IRLMP_IAS_QUERY] = XLAT(IRLMP_IAS_QUERY),
+ #define XLAT_VAL_2 ((unsigned) (IRLMP_IAS_QUERY))
+ #define XLAT_STR_2 STRINGIFY(IRLMP_IAS_QUERY)
  [IRLMP_HINTS_SET] = XLAT(IRLMP_HINTS_SET),
+ #define XLAT_VAL_3 ((unsigned) (IRLMP_HINTS_SET))
+ #define XLAT_STR_3 STRINGIFY(IRLMP_HINTS_SET)
  [IRLMP_QOS_SET] = XLAT(IRLMP_QOS_SET),
+ #define XLAT_VAL_4 ((unsigned) (IRLMP_QOS_SET))
+ #define XLAT_STR_4 STRINGIFY(IRLMP_QOS_SET)
  [IRLMP_QOS_GET] = XLAT(IRLMP_QOS_GET),
+ #define XLAT_VAL_5 ((unsigned) (IRLMP_QOS_GET))
+ #define XLAT_STR_5 STRINGIFY(IRLMP_QOS_GET)
  [IRLMP_MAX_SDU_SIZE] = XLAT(IRLMP_MAX_SDU_SIZE),
+ #define XLAT_VAL_6 ((unsigned) (IRLMP_MAX_SDU_SIZE))
+ #define XLAT_STR_6 STRINGIFY(IRLMP_MAX_SDU_SIZE)
  [IRLMP_IAS_GET] = XLAT(IRLMP_IAS_GET),
+ #define XLAT_VAL_7 ((unsigned) (IRLMP_IAS_GET))
+ #define XLAT_STR_7 STRINGIFY(IRLMP_IAS_GET)
  [IRLMP_IAS_DEL] = XLAT(IRLMP_IAS_DEL),
+ #define XLAT_VAL_8 ((unsigned) (IRLMP_IAS_DEL))
+ #define XLAT_STR_8 STRINGIFY(IRLMP_IAS_DEL)
  [IRLMP_HINT_MASK_SET] = XLAT(IRLMP_HINT_MASK_SET),
+ #define XLAT_VAL_9 ((unsigned) (IRLMP_HINT_MASK_SET))
+ #define XLAT_STR_9 STRINGIFY(IRLMP_HINT_MASK_SET)
  [IRLMP_WAITDEVICE] = XLAT(IRLMP_WAITDEVICE),
+ #define XLAT_VAL_10 ((unsigned) (IRLMP_WAITDEVICE))
+ #define XLAT_STR_10 STRINGIFY(IRLMP_WAITDEVICE)
 };
 static
 const struct xlat sock_irda_options[1] = { {
  .data = sock_irda_options_xdata,
  .size = ARRAY_SIZE(sock_irda_options_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_iucv_options.h 5.9-0ubuntu2/xlat/sock_iucv_options.h
--- 5.5-3/xlat/sock_iucv_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_iucv_options.h	2020-09-24 09:18:46.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sock_iucv_options_xdata[] = {
  XLAT(SO_IPRMDATA_MSG),
+ #define XLAT_VAL_0 ((unsigned) (SO_IPRMDATA_MSG))
+ #define XLAT_STR_0 STRINGIFY(SO_IPRMDATA_MSG)
  XLAT(SO_MSGLIMIT),
+ #define XLAT_VAL_1 ((unsigned) (SO_MSGLIMIT))
+ #define XLAT_STR_1 STRINGIFY(SO_MSGLIMIT)
  XLAT(SO_MSGSIZE),
+ #define XLAT_VAL_2 ((unsigned) (SO_MSGSIZE))
+ #define XLAT_STR_2 STRINGIFY(SO_MSGSIZE)
 };
 static
 const struct xlat sock_iucv_options[1] = { {
  .data = sock_iucv_options_xdata,
  .size = ARRAY_SIZE(sock_iucv_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_kcm_options.h 5.9-0ubuntu2/xlat/sock_kcm_options.h
--- 5.5-3/xlat/sock_kcm_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_kcm_options.h	2020-09-24 09:18:45.000000000 +0000
@@ -21,14 +21,28 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sock_kcm_options_xdata[] = {
  XLAT(KCM_RECV_DISABLE),
+ #define XLAT_VAL_0 ((unsigned) (KCM_RECV_DISABLE))
+ #define XLAT_STR_0 STRINGIFY(KCM_RECV_DISABLE)
 };
 static
 const struct xlat sock_kcm_options[1] = { {
  .data = sock_kcm_options_xdata,
  .size = ARRAY_SIZE(sock_kcm_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_llc_options.h 5.9-0ubuntu2/xlat/sock_llc_options.h
--- 5.5-3/xlat/sock_llc_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_llc_options.h	2020-09-24 09:18:46.000000000 +0000
@@ -84,23 +84,127 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sock_llc_options_xdata[] = {
  [LLC_OPT_UNKNOWN] = XLAT(LLC_OPT_UNKNOWN),
+ #define XLAT_VAL_0 ((unsigned) (LLC_OPT_UNKNOWN))
+ #define XLAT_STR_0 STRINGIFY(LLC_OPT_UNKNOWN)
  [LLC_OPT_RETRY] = XLAT(LLC_OPT_RETRY),
+ #define XLAT_VAL_1 ((unsigned) (LLC_OPT_RETRY))
+ #define XLAT_STR_1 STRINGIFY(LLC_OPT_RETRY)
  [LLC_OPT_SIZE] = XLAT(LLC_OPT_SIZE),
+ #define XLAT_VAL_2 ((unsigned) (LLC_OPT_SIZE))
+ #define XLAT_STR_2 STRINGIFY(LLC_OPT_SIZE)
  [LLC_OPT_ACK_TMR_EXP] = XLAT(LLC_OPT_ACK_TMR_EXP),
+ #define XLAT_VAL_3 ((unsigned) (LLC_OPT_ACK_TMR_EXP))
+ #define XLAT_STR_3 STRINGIFY(LLC_OPT_ACK_TMR_EXP)
  [LLC_OPT_P_TMR_EXP] = XLAT(LLC_OPT_P_TMR_EXP),
+ #define XLAT_VAL_4 ((unsigned) (LLC_OPT_P_TMR_EXP))
+ #define XLAT_STR_4 STRINGIFY(LLC_OPT_P_TMR_EXP)
  [LLC_OPT_REJ_TMR_EXP] = XLAT(LLC_OPT_REJ_TMR_EXP),
+ #define XLAT_VAL_5 ((unsigned) (LLC_OPT_REJ_TMR_EXP))
+ #define XLAT_STR_5 STRINGIFY(LLC_OPT_REJ_TMR_EXP)
  [LLC_OPT_BUSY_TMR_EXP] = XLAT(LLC_OPT_BUSY_TMR_EXP),
+ #define XLAT_VAL_6 ((unsigned) (LLC_OPT_BUSY_TMR_EXP))
+ #define XLAT_STR_6 STRINGIFY(LLC_OPT_BUSY_TMR_EXP)
  [LLC_OPT_TX_WIN] = XLAT(LLC_OPT_TX_WIN),
+ #define XLAT_VAL_7 ((unsigned) (LLC_OPT_TX_WIN))
+ #define XLAT_STR_7 STRINGIFY(LLC_OPT_TX_WIN)
  [LLC_OPT_RX_WIN] = XLAT(LLC_OPT_RX_WIN),
+ #define XLAT_VAL_8 ((unsigned) (LLC_OPT_RX_WIN))
+ #define XLAT_STR_8 STRINGIFY(LLC_OPT_RX_WIN)
  [LLC_OPT_PKTINFO] = XLAT(LLC_OPT_PKTINFO),
+ #define XLAT_VAL_9 ((unsigned) (LLC_OPT_PKTINFO))
+ #define XLAT_STR_9 STRINGIFY(LLC_OPT_PKTINFO)
 };
 static
 const struct xlat sock_llc_options[1] = { {
  .data = sock_llc_options_xdata,
  .size = ARRAY_SIZE(sock_llc_options_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_netlink_options.h 5.9-0ubuntu2/xlat/sock_netlink_options.h
--- 5.5-3/xlat/sock_netlink_options.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_netlink_options.h	2020-09-24 09:18:46.000000000 +0000
@@ -98,25 +98,149 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sock_netlink_options_xdata[] = {
  [NETLINK_ADD_MEMBERSHIP] = XLAT(NETLINK_ADD_MEMBERSHIP),
+ #define XLAT_VAL_0 ((unsigned) (NETLINK_ADD_MEMBERSHIP))
+ #define XLAT_STR_0 STRINGIFY(NETLINK_ADD_MEMBERSHIP)
  [NETLINK_DROP_MEMBERSHIP] = XLAT(NETLINK_DROP_MEMBERSHIP),
+ #define XLAT_VAL_1 ((unsigned) (NETLINK_DROP_MEMBERSHIP))
+ #define XLAT_STR_1 STRINGIFY(NETLINK_DROP_MEMBERSHIP)
  [NETLINK_PKTINFO] = XLAT(NETLINK_PKTINFO),
+ #define XLAT_VAL_2 ((unsigned) (NETLINK_PKTINFO))
+ #define XLAT_STR_2 STRINGIFY(NETLINK_PKTINFO)
  [NETLINK_BROADCAST_ERROR] = XLAT(NETLINK_BROADCAST_ERROR),
+ #define XLAT_VAL_3 ((unsigned) (NETLINK_BROADCAST_ERROR))
+ #define XLAT_STR_3 STRINGIFY(NETLINK_BROADCAST_ERROR)
  [NETLINK_NO_ENOBUFS] = XLAT(NETLINK_NO_ENOBUFS),
+ #define XLAT_VAL_4 ((unsigned) (NETLINK_NO_ENOBUFS))
+ #define XLAT_STR_4 STRINGIFY(NETLINK_NO_ENOBUFS)
  [NETLINK_RX_RING] = XLAT(NETLINK_RX_RING),
+ #define XLAT_VAL_5 ((unsigned) (NETLINK_RX_RING))
+ #define XLAT_STR_5 STRINGIFY(NETLINK_RX_RING)
  [NETLINK_TX_RING] = XLAT(NETLINK_TX_RING),
+ #define XLAT_VAL_6 ((unsigned) (NETLINK_TX_RING))
+ #define XLAT_STR_6 STRINGIFY(NETLINK_TX_RING)
  [NETLINK_LISTEN_ALL_NSID] = XLAT(NETLINK_LISTEN_ALL_NSID),
+ #define XLAT_VAL_7 ((unsigned) (NETLINK_LISTEN_ALL_NSID))
+ #define XLAT_STR_7 STRINGIFY(NETLINK_LISTEN_ALL_NSID)
  [NETLINK_LIST_MEMBERSHIPS] = XLAT(NETLINK_LIST_MEMBERSHIPS),
+ #define XLAT_VAL_8 ((unsigned) (NETLINK_LIST_MEMBERSHIPS))
+ #define XLAT_STR_8 STRINGIFY(NETLINK_LIST_MEMBERSHIPS)
  [NETLINK_CAP_ACK] = XLAT(NETLINK_CAP_ACK),
+ #define XLAT_VAL_9 ((unsigned) (NETLINK_CAP_ACK))
+ #define XLAT_STR_9 STRINGIFY(NETLINK_CAP_ACK)
  [NETLINK_EXT_ACK] = XLAT(NETLINK_EXT_ACK),
+ #define XLAT_VAL_10 ((unsigned) (NETLINK_EXT_ACK))
+ #define XLAT_STR_10 STRINGIFY(NETLINK_EXT_ACK)
  [NETLINK_DUMP_STRICT_CHK] = XLAT(NETLINK_DUMP_STRICT_CHK),
+ #define XLAT_VAL_11 ((unsigned) (NETLINK_DUMP_STRICT_CHK))
+ #define XLAT_STR_11 STRINGIFY(NETLINK_DUMP_STRICT_CHK)
 };
 static
 const struct xlat sock_netlink_options[1] = { {
  .data = sock_netlink_options_xdata,
  .size = ARRAY_SIZE(sock_netlink_options_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_nfcllcp_options.h 5.9-0ubuntu2/xlat/sock_nfcllcp_options.h
--- 5.5-3/xlat/sock_nfcllcp_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_nfcllcp_options.h	2020-09-24 09:18:46.000000000 +0000
@@ -49,18 +49,72 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sock_nfcllcp_options_xdata[] = {
  [NFC_LLCP_RW] = XLAT(NFC_LLCP_RW),
+ #define XLAT_VAL_0 ((unsigned) (NFC_LLCP_RW))
+ #define XLAT_STR_0 STRINGIFY(NFC_LLCP_RW)
  [NFC_LLCP_MIUX] = XLAT(NFC_LLCP_MIUX),
+ #define XLAT_VAL_1 ((unsigned) (NFC_LLCP_MIUX))
+ #define XLAT_STR_1 STRINGIFY(NFC_LLCP_MIUX)
  [NFC_LLCP_REMOTE_MIU] = XLAT(NFC_LLCP_REMOTE_MIU),
+ #define XLAT_VAL_2 ((unsigned) (NFC_LLCP_REMOTE_MIU))
+ #define XLAT_STR_2 STRINGIFY(NFC_LLCP_REMOTE_MIU)
  [NFC_LLCP_REMOTE_LTO] = XLAT(NFC_LLCP_REMOTE_LTO),
+ #define XLAT_VAL_3 ((unsigned) (NFC_LLCP_REMOTE_LTO))
+ #define XLAT_STR_3 STRINGIFY(NFC_LLCP_REMOTE_LTO)
  [NFC_LLCP_REMOTE_RW] = XLAT(NFC_LLCP_REMOTE_RW),
+ #define XLAT_VAL_4 ((unsigned) (NFC_LLCP_REMOTE_RW))
+ #define XLAT_STR_4 STRINGIFY(NFC_LLCP_REMOTE_RW)
 };
 static
 const struct xlat sock_nfcllcp_options[1] = { {
  .data = sock_nfcllcp_options_xdata,
  .size = ARRAY_SIZE(sock_nfcllcp_options_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_options.h 5.9-0ubuntu2/xlat/sock_options.h
--- 5.5-3/xlat/sock_options.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_options.h	2020-09-24 09:18:47.000000000 +0000
@@ -1607,515 +1607,897 @@ static const struct xlat_data sock_optio
 
 
  XLAT(SO_DEBUG),
+ #define XLAT_VAL_0 ((unsigned) (SO_DEBUG))
+ #define XLAT_STR_0 STRINGIFY(SO_DEBUG)
 
 #if defined __alpha__ || defined __hppa__ || defined __mips__ || defined __sparc__
  XLAT(SO_REUSEADDR),
+ #define XLAT_VAL_1 ((unsigned) (SO_REUSEADDR))
+ #define XLAT_STR_1 STRINGIFY(SO_REUSEADDR)
 #else
  XLAT(SO_REUSEADDR),
+ #define XLAT_VAL_2 ((unsigned) (SO_REUSEADDR))
+ #define XLAT_STR_2 STRINGIFY(SO_REUSEADDR)
 #endif
 
 #if defined __alpha__ || defined __hppa__ || defined __mips__ || defined __sparc__
  XLAT(SO_TYPE),
+ #define XLAT_VAL_3 ((unsigned) (SO_TYPE))
+ #define XLAT_STR_3 STRINGIFY(SO_TYPE)
 #else
  XLAT(SO_TYPE),
+ #define XLAT_VAL_4 ((unsigned) (SO_TYPE))
+ #define XLAT_STR_4 STRINGIFY(SO_TYPE)
 #endif
 
 #if defined __alpha__ || defined __hppa__ || defined __mips__ || defined __sparc__
  XLAT(SO_ERROR),
+ #define XLAT_VAL_5 ((unsigned) (SO_ERROR))
+ #define XLAT_STR_5 STRINGIFY(SO_ERROR)
 #else
  XLAT(SO_ERROR),
+ #define XLAT_VAL_6 ((unsigned) (SO_ERROR))
+ #define XLAT_STR_6 STRINGIFY(SO_ERROR)
 #endif
 
 #if defined __alpha__ || defined __hppa__ || defined __mips__ || defined __sparc__
  XLAT(SO_DONTROUTE),
+ #define XLAT_VAL_7 ((unsigned) (SO_DONTROUTE))
+ #define XLAT_STR_7 STRINGIFY(SO_DONTROUTE)
 #else
  XLAT(SO_DONTROUTE),
+ #define XLAT_VAL_8 ((unsigned) (SO_DONTROUTE))
+ #define XLAT_STR_8 STRINGIFY(SO_DONTROUTE)
 #endif
 
 #if defined __alpha__ || defined __hppa__ || defined __mips__ || defined __sparc__
  XLAT(SO_BROADCAST),
+ #define XLAT_VAL_9 ((unsigned) (SO_BROADCAST))
+ #define XLAT_STR_9 STRINGIFY(SO_BROADCAST)
 #else
  XLAT(SO_BROADCAST),
+ #define XLAT_VAL_10 ((unsigned) (SO_BROADCAST))
+ #define XLAT_STR_10 STRINGIFY(SO_BROADCAST)
 #endif
 
 #if defined __alpha__ || defined __hppa__ || defined __mips__ || defined __sparc__
  XLAT(SO_SNDBUF),
+ #define XLAT_VAL_11 ((unsigned) (SO_SNDBUF))
+ #define XLAT_STR_11 STRINGIFY(SO_SNDBUF)
 #else
  XLAT(SO_SNDBUF),
+ #define XLAT_VAL_12 ((unsigned) (SO_SNDBUF))
+ #define XLAT_STR_12 STRINGIFY(SO_SNDBUF)
 #endif
 
 #if defined __alpha__ || defined __hppa__ || defined __mips__ || defined __sparc__
  XLAT(SO_RCVBUF),
+ #define XLAT_VAL_13 ((unsigned) (SO_RCVBUF))
+ #define XLAT_STR_13 STRINGIFY(SO_RCVBUF)
 #else
  XLAT(SO_RCVBUF),
+ #define XLAT_VAL_14 ((unsigned) (SO_RCVBUF))
+ #define XLAT_STR_14 STRINGIFY(SO_RCVBUF)
 #endif
 
 #if defined __alpha__ || defined __hppa__ || defined __mips__ || defined __sparc__
  XLAT(SO_KEEPALIVE),
+ #define XLAT_VAL_15 ((unsigned) (SO_KEEPALIVE))
+ #define XLAT_STR_15 STRINGIFY(SO_KEEPALIVE)
 #else
  XLAT(SO_KEEPALIVE),
+ #define XLAT_VAL_16 ((unsigned) (SO_KEEPALIVE))
+ #define XLAT_STR_16 STRINGIFY(SO_KEEPALIVE)
 #endif
 
 #if defined __alpha__ || defined __hppa__ || defined __mips__ || defined __sparc__
  XLAT(SO_OOBINLINE),
+ #define XLAT_VAL_17 ((unsigned) (SO_OOBINLINE))
+ #define XLAT_STR_17 STRINGIFY(SO_OOBINLINE)
 #else
  XLAT(SO_OOBINLINE),
+ #define XLAT_VAL_18 ((unsigned) (SO_OOBINLINE))
+ #define XLAT_STR_18 STRINGIFY(SO_OOBINLINE)
 #endif
 
 #if defined __hppa__
  XLAT(SO_NO_CHECK),
+ #define XLAT_VAL_19 ((unsigned) (SO_NO_CHECK))
+ #define XLAT_STR_19 STRINGIFY(SO_NO_CHECK)
 #else
  XLAT(SO_NO_CHECK),
+ #define XLAT_VAL_20 ((unsigned) (SO_NO_CHECK))
+ #define XLAT_STR_20 STRINGIFY(SO_NO_CHECK)
 #endif
 
 #if defined __hppa__
  XLAT(SO_PRIORITY),
+ #define XLAT_VAL_21 ((unsigned) (SO_PRIORITY))
+ #define XLAT_STR_21 STRINGIFY(SO_PRIORITY)
 #else
  XLAT(SO_PRIORITY),
+ #define XLAT_VAL_22 ((unsigned) (SO_PRIORITY))
+ #define XLAT_STR_22 STRINGIFY(SO_PRIORITY)
 #endif
 
 #if defined __alpha__ || defined __hppa__ || defined __mips__ || defined __sparc__
  XLAT(SO_LINGER),
+ #define XLAT_VAL_23 ((unsigned) (SO_LINGER))
+ #define XLAT_STR_23 STRINGIFY(SO_LINGER)
 #else
  XLAT(SO_LINGER),
+ #define XLAT_VAL_24 ((unsigned) (SO_LINGER))
+ #define XLAT_STR_24 STRINGIFY(SO_LINGER)
 #endif
 
 #if defined __sparc__
  XLAT(SO_BSDCOMPAT),
+ #define XLAT_VAL_25 ((unsigned) (SO_BSDCOMPAT))
+ #define XLAT_STR_25 STRINGIFY(SO_BSDCOMPAT)
 #elif defined __hppa__
  XLAT(SO_BSDCOMPAT),
+ #define XLAT_VAL_26 ((unsigned) (SO_BSDCOMPAT))
+ #define XLAT_STR_26 STRINGIFY(SO_BSDCOMPAT)
 #else
  XLAT(SO_BSDCOMPAT),
+ #define XLAT_VAL_27 ((unsigned) (SO_BSDCOMPAT))
+ #define XLAT_STR_27 STRINGIFY(SO_BSDCOMPAT)
 #endif
 
 #if defined __alpha__ || defined __hppa__ || defined __mips__ || defined __sparc__
  XLAT(SO_REUSEPORT),
+ #define XLAT_VAL_28 ((unsigned) (SO_REUSEPORT))
+ #define XLAT_STR_28 STRINGIFY(SO_REUSEPORT)
 #else
  XLAT(SO_REUSEPORT),
+ #define XLAT_VAL_29 ((unsigned) (SO_REUSEPORT))
+ #define XLAT_STR_29 STRINGIFY(SO_REUSEPORT)
 #endif
 
 #if defined __sparc__
  XLAT(SO_PASSCRED),
+ #define XLAT_VAL_30 ((unsigned) (SO_PASSCRED))
+ #define XLAT_STR_30 STRINGIFY(SO_PASSCRED)
 #elif defined __alpha__ || defined __mips__
  XLAT(SO_PASSCRED),
+ #define XLAT_VAL_31 ((unsigned) (SO_PASSCRED))
+ #define XLAT_STR_31 STRINGIFY(SO_PASSCRED)
 #elif defined __powerpc__
  XLAT(SO_PASSCRED),
+ #define XLAT_VAL_32 ((unsigned) (SO_PASSCRED))
+ #define XLAT_STR_32 STRINGIFY(SO_PASSCRED)
 #elif defined __hppa__
  XLAT(SO_PASSCRED),
+ #define XLAT_VAL_33 ((unsigned) (SO_PASSCRED))
+ #define XLAT_STR_33 STRINGIFY(SO_PASSCRED)
 #else
  XLAT(SO_PASSCRED),
+ #define XLAT_VAL_34 ((unsigned) (SO_PASSCRED))
+ #define XLAT_STR_34 STRINGIFY(SO_PASSCRED)
 #endif
 
 #if defined __alpha__ || defined __mips__
  XLAT(SO_PEERCRED),
+ #define XLAT_VAL_35 ((unsigned) (SO_PEERCRED))
+ #define XLAT_STR_35 STRINGIFY(SO_PEERCRED)
 #elif defined __powerpc__
  XLAT(SO_PEERCRED),
+ #define XLAT_VAL_36 ((unsigned) (SO_PEERCRED))
+ #define XLAT_STR_36 STRINGIFY(SO_PEERCRED)
 #elif defined __sparc__
  XLAT(SO_PEERCRED),
+ #define XLAT_VAL_37 ((unsigned) (SO_PEERCRED))
+ #define XLAT_STR_37 STRINGIFY(SO_PEERCRED)
 #elif defined __hppa__
  XLAT(SO_PEERCRED),
+ #define XLAT_VAL_38 ((unsigned) (SO_PEERCRED))
+ #define XLAT_STR_38 STRINGIFY(SO_PEERCRED)
 #else
  XLAT(SO_PEERCRED),
+ #define XLAT_VAL_39 ((unsigned) (SO_PEERCRED))
+ #define XLAT_STR_39 STRINGIFY(SO_PEERCRED)
 #endif
 
 #if defined __powerpc__
  XLAT(SO_RCVLOWAT),
+ #define XLAT_VAL_40 ((unsigned) (SO_RCVLOWAT))
+ #define XLAT_STR_40 STRINGIFY(SO_RCVLOWAT)
 #elif defined __sparc__
  XLAT(SO_RCVLOWAT),
+ #define XLAT_VAL_41 ((unsigned) (SO_RCVLOWAT))
+ #define XLAT_STR_41 STRINGIFY(SO_RCVLOWAT)
 #elif defined __hppa__ || defined __mips__
  XLAT(SO_RCVLOWAT),
+ #define XLAT_VAL_42 ((unsigned) (SO_RCVLOWAT))
+ #define XLAT_STR_42 STRINGIFY(SO_RCVLOWAT)
 #elif defined __alpha__
  XLAT(SO_RCVLOWAT),
+ #define XLAT_VAL_43 ((unsigned) (SO_RCVLOWAT))
+ #define XLAT_STR_43 STRINGIFY(SO_RCVLOWAT)
 #else
  XLAT(SO_RCVLOWAT),
+ #define XLAT_VAL_44 ((unsigned) (SO_RCVLOWAT))
+ #define XLAT_STR_44 STRINGIFY(SO_RCVLOWAT)
 #endif
 
 #if defined __powerpc__
  XLAT(SO_SNDLOWAT),
+ #define XLAT_VAL_45 ((unsigned) (SO_SNDLOWAT))
+ #define XLAT_STR_45 STRINGIFY(SO_SNDLOWAT)
 #elif defined __sparc__
  XLAT(SO_SNDLOWAT),
+ #define XLAT_VAL_46 ((unsigned) (SO_SNDLOWAT))
+ #define XLAT_STR_46 STRINGIFY(SO_SNDLOWAT)
 #elif defined __hppa__ || defined __mips__
  XLAT(SO_SNDLOWAT),
+ #define XLAT_VAL_47 ((unsigned) (SO_SNDLOWAT))
+ #define XLAT_STR_47 STRINGIFY(SO_SNDLOWAT)
 #elif defined __alpha__
  XLAT(SO_SNDLOWAT),
+ #define XLAT_VAL_48 ((unsigned) (SO_SNDLOWAT))
+ #define XLAT_STR_48 STRINGIFY(SO_SNDLOWAT)
 #else
  XLAT(SO_SNDLOWAT),
+ #define XLAT_VAL_49 ((unsigned) (SO_SNDLOWAT))
+ #define XLAT_STR_49 STRINGIFY(SO_SNDLOWAT)
 #endif
 
 #if defined __powerpc__
  XLAT(SO_RCVTIMEO_OLD),
+ #define XLAT_VAL_50 ((unsigned) (SO_RCVTIMEO_OLD))
+ #define XLAT_STR_50 STRINGIFY(SO_RCVTIMEO_OLD)
 #elif defined __hppa__ || defined __mips__
  XLAT(SO_RCVTIMEO_OLD),
+ #define XLAT_VAL_51 ((unsigned) (SO_RCVTIMEO_OLD))
+ #define XLAT_STR_51 STRINGIFY(SO_RCVTIMEO_OLD)
 #elif defined __alpha__
  XLAT(SO_RCVTIMEO_OLD),
+ #define XLAT_VAL_52 ((unsigned) (SO_RCVTIMEO_OLD))
+ #define XLAT_STR_52 STRINGIFY(SO_RCVTIMEO_OLD)
 #elif defined __sparc__
  XLAT(SO_RCVTIMEO_OLD),
+ #define XLAT_VAL_53 ((unsigned) (SO_RCVTIMEO_OLD))
+ #define XLAT_STR_53 STRINGIFY(SO_RCVTIMEO_OLD)
 #else
  XLAT(SO_RCVTIMEO_OLD),
+ #define XLAT_VAL_54 ((unsigned) (SO_RCVTIMEO_OLD))
+ #define XLAT_STR_54 STRINGIFY(SO_RCVTIMEO_OLD)
 #endif
 
 #if defined __powerpc__
  XLAT(SO_SNDTIMEO_OLD),
+ #define XLAT_VAL_55 ((unsigned) (SO_SNDTIMEO_OLD))
+ #define XLAT_STR_55 STRINGIFY(SO_SNDTIMEO_OLD)
 #elif defined __hppa__ || defined __mips__
  XLAT(SO_SNDTIMEO_OLD),
+ #define XLAT_VAL_56 ((unsigned) (SO_SNDTIMEO_OLD))
+ #define XLAT_STR_56 STRINGIFY(SO_SNDTIMEO_OLD)
 #elif defined __alpha__
  XLAT(SO_SNDTIMEO_OLD),
+ #define XLAT_VAL_57 ((unsigned) (SO_SNDTIMEO_OLD))
+ #define XLAT_STR_57 STRINGIFY(SO_SNDTIMEO_OLD)
 #elif defined __sparc__
  XLAT(SO_SNDTIMEO_OLD),
+ #define XLAT_VAL_58 ((unsigned) (SO_SNDTIMEO_OLD))
+ #define XLAT_STR_58 STRINGIFY(SO_SNDTIMEO_OLD)
 #else
  XLAT(SO_SNDTIMEO_OLD),
+ #define XLAT_VAL_59 ((unsigned) (SO_SNDTIMEO_OLD))
+ #define XLAT_STR_59 STRINGIFY(SO_SNDTIMEO_OLD)
 #endif
 
 #if defined __alpha__
  XLAT(SO_SECURITY_AUTHENTICATION),
+ #define XLAT_VAL_60 ((unsigned) (SO_SECURITY_AUTHENTICATION))
+ #define XLAT_STR_60 STRINGIFY(SO_SECURITY_AUTHENTICATION)
 #elif defined __hppa__
  XLAT(SO_SECURITY_AUTHENTICATION),
+ #define XLAT_VAL_61 ((unsigned) (SO_SECURITY_AUTHENTICATION))
+ #define XLAT_STR_61 STRINGIFY(SO_SECURITY_AUTHENTICATION)
 #elif defined __sparc__
  XLAT(SO_SECURITY_AUTHENTICATION),
+ #define XLAT_VAL_62 ((unsigned) (SO_SECURITY_AUTHENTICATION))
+ #define XLAT_STR_62 STRINGIFY(SO_SECURITY_AUTHENTICATION)
 #else
  XLAT(SO_SECURITY_AUTHENTICATION),
+ #define XLAT_VAL_63 ((unsigned) (SO_SECURITY_AUTHENTICATION))
+ #define XLAT_STR_63 STRINGIFY(SO_SECURITY_AUTHENTICATION)
 #endif
 
 #if defined __alpha__
  XLAT(SO_SECURITY_ENCRYPTION_TRANSPORT),
+ #define XLAT_VAL_64 ((unsigned) (SO_SECURITY_ENCRYPTION_TRANSPORT))
+ #define XLAT_STR_64 STRINGIFY(SO_SECURITY_ENCRYPTION_TRANSPORT)
 #elif defined __hppa__
  XLAT(SO_SECURITY_ENCRYPTION_TRANSPORT),
+ #define XLAT_VAL_65 ((unsigned) (SO_SECURITY_ENCRYPTION_TRANSPORT))
+ #define XLAT_STR_65 STRINGIFY(SO_SECURITY_ENCRYPTION_TRANSPORT)
 #elif defined __sparc__
  XLAT(SO_SECURITY_ENCRYPTION_TRANSPORT),
+ #define XLAT_VAL_66 ((unsigned) (SO_SECURITY_ENCRYPTION_TRANSPORT))
+ #define XLAT_STR_66 STRINGIFY(SO_SECURITY_ENCRYPTION_TRANSPORT)
 #else
  XLAT(SO_SECURITY_ENCRYPTION_TRANSPORT),
+ #define XLAT_VAL_67 ((unsigned) (SO_SECURITY_ENCRYPTION_TRANSPORT))
+ #define XLAT_STR_67 STRINGIFY(SO_SECURITY_ENCRYPTION_TRANSPORT)
 #endif
 
 #if defined __alpha__
  XLAT(SO_SECURITY_ENCRYPTION_NETWORK),
+ #define XLAT_VAL_68 ((unsigned) (SO_SECURITY_ENCRYPTION_NETWORK))
+ #define XLAT_STR_68 STRINGIFY(SO_SECURITY_ENCRYPTION_NETWORK)
 #elif defined __hppa__
  XLAT(SO_SECURITY_ENCRYPTION_NETWORK),
+ #define XLAT_VAL_69 ((unsigned) (SO_SECURITY_ENCRYPTION_NETWORK))
+ #define XLAT_STR_69 STRINGIFY(SO_SECURITY_ENCRYPTION_NETWORK)
 #elif defined __sparc__
  XLAT(SO_SECURITY_ENCRYPTION_NETWORK),
+ #define XLAT_VAL_70 ((unsigned) (SO_SECURITY_ENCRYPTION_NETWORK))
+ #define XLAT_STR_70 STRINGIFY(SO_SECURITY_ENCRYPTION_NETWORK)
 #else
  XLAT(SO_SECURITY_ENCRYPTION_NETWORK),
+ #define XLAT_VAL_71 ((unsigned) (SO_SECURITY_ENCRYPTION_NETWORK))
+ #define XLAT_STR_71 STRINGIFY(SO_SECURITY_ENCRYPTION_NETWORK)
 #endif
 
 #if defined __sparc__
  XLAT(SO_BINDTODEVICE),
+ #define XLAT_VAL_72 ((unsigned) (SO_BINDTODEVICE))
+ #define XLAT_STR_72 STRINGIFY(SO_BINDTODEVICE)
 #elif defined __hppa__
  XLAT(SO_BINDTODEVICE),
+ #define XLAT_VAL_73 ((unsigned) (SO_BINDTODEVICE))
+ #define XLAT_STR_73 STRINGIFY(SO_BINDTODEVICE)
 #else
  XLAT(SO_BINDTODEVICE),
+ #define XLAT_VAL_74 ((unsigned) (SO_BINDTODEVICE))
+ #define XLAT_STR_74 STRINGIFY(SO_BINDTODEVICE)
 #endif
 
 
 
 #if defined __hppa__
  XLAT(SO_DETACH_FILTER),
+ #define XLAT_VAL_75 ((unsigned) (SO_DETACH_FILTER))
+ #define XLAT_STR_75 STRINGIFY(SO_DETACH_FILTER)
 #else
  XLAT(SO_DETACH_FILTER),
+ #define XLAT_VAL_76 ((unsigned) (SO_DETACH_FILTER))
+ #define XLAT_STR_76 STRINGIFY(SO_DETACH_FILTER)
 #endif
 
 #if defined __hppa__
  XLAT(SO_PEERNAME),
+ #define XLAT_VAL_77 ((unsigned) (SO_PEERNAME))
+ #define XLAT_STR_77 STRINGIFY(SO_PEERNAME)
 #else
  XLAT(SO_PEERNAME),
+ #define XLAT_VAL_78 ((unsigned) (SO_PEERNAME))
+ #define XLAT_STR_78 STRINGIFY(SO_PEERNAME)
 #endif
 
 #if defined __hppa__
  XLAT(SO_TIMESTAMP_OLD),
+ #define XLAT_VAL_79 ((unsigned) (SO_TIMESTAMP_OLD))
+ #define XLAT_STR_79 STRINGIFY(SO_TIMESTAMP_OLD)
 #else
  XLAT(SO_TIMESTAMP_OLD),
+ #define XLAT_VAL_80 ((unsigned) (SO_TIMESTAMP_OLD))
+ #define XLAT_STR_80 STRINGIFY(SO_TIMESTAMP_OLD)
 #endif
 
 #if defined __mips__
  XLAT(SO_ACCEPTCONN),
+ #define XLAT_VAL_81 ((unsigned) (SO_ACCEPTCONN))
+ #define XLAT_STR_81 STRINGIFY(SO_ACCEPTCONN)
 #elif defined __alpha__
  XLAT(SO_ACCEPTCONN),
+ #define XLAT_VAL_82 ((unsigned) (SO_ACCEPTCONN))
+ #define XLAT_STR_82 STRINGIFY(SO_ACCEPTCONN)
 #elif defined __hppa__
  XLAT(SO_ACCEPTCONN),
+ #define XLAT_VAL_83 ((unsigned) (SO_ACCEPTCONN))
+ #define XLAT_STR_83 STRINGIFY(SO_ACCEPTCONN)
 #elif defined __sparc__
  XLAT(SO_ACCEPTCONN),
+ #define XLAT_VAL_84 ((unsigned) (SO_ACCEPTCONN))
+ #define XLAT_STR_84 STRINGIFY(SO_ACCEPTCONN)
 #else
  XLAT(SO_ACCEPTCONN),
+ #define XLAT_VAL_85 ((unsigned) (SO_ACCEPTCONN))
+ #define XLAT_STR_85 STRINGIFY(SO_ACCEPTCONN)
 #endif
 
 #if defined __alpha__ || defined __mips__ || defined __sparc__
  XLAT(SO_PEERSEC),
+ #define XLAT_VAL_86 ((unsigned) (SO_PEERSEC))
+ #define XLAT_STR_86 STRINGIFY(SO_PEERSEC)
 #elif defined __hppa__
  XLAT(SO_PEERSEC),
+ #define XLAT_VAL_87 ((unsigned) (SO_PEERSEC))
+ #define XLAT_STR_87 STRINGIFY(SO_PEERSEC)
 #else
  XLAT(SO_PEERSEC),
+ #define XLAT_VAL_88 ((unsigned) (SO_PEERSEC))
+ #define XLAT_STR_88 STRINGIFY(SO_PEERSEC)
 #endif
 
 #if defined __mips__
  XLAT(SO_SNDBUFFORCE),
+ #define XLAT_VAL_89 ((unsigned) (SO_SNDBUFFORCE))
+ #define XLAT_STR_89 STRINGIFY(SO_SNDBUFFORCE)
 #elif defined __alpha__ || defined __hppa__ || defined __sparc__
  XLAT(SO_SNDBUFFORCE),
+ #define XLAT_VAL_90 ((unsigned) (SO_SNDBUFFORCE))
+ #define XLAT_STR_90 STRINGIFY(SO_SNDBUFFORCE)
 #else
  XLAT(SO_SNDBUFFORCE),
+ #define XLAT_VAL_91 ((unsigned) (SO_SNDBUFFORCE))
+ #define XLAT_STR_91 STRINGIFY(SO_SNDBUFFORCE)
 #endif
 
 #if defined __alpha__ || defined __hppa__ || defined __sparc__
  XLAT(SO_RCVBUFFORCE),
+ #define XLAT_VAL_92 ((unsigned) (SO_RCVBUFFORCE))
+ #define XLAT_STR_92 STRINGIFY(SO_RCVBUFFORCE)
 #else
  XLAT(SO_RCVBUFFORCE),
+ #define XLAT_VAL_93 ((unsigned) (SO_RCVBUFFORCE))
+ #define XLAT_STR_93 STRINGIFY(SO_RCVBUFFORCE)
 #endif
 
 #if defined __sparc__
  XLAT(SO_PASSSEC),
+ #define XLAT_VAL_94 ((unsigned) (SO_PASSSEC))
+ #define XLAT_STR_94 STRINGIFY(SO_PASSSEC)
 #elif defined __hppa__
  XLAT(SO_PASSSEC),
+ #define XLAT_VAL_95 ((unsigned) (SO_PASSSEC))
+ #define XLAT_STR_95 STRINGIFY(SO_PASSSEC)
 #else
  XLAT(SO_PASSSEC),
+ #define XLAT_VAL_96 ((unsigned) (SO_PASSSEC))
+ #define XLAT_STR_96 STRINGIFY(SO_PASSSEC)
 #endif
 
 #if defined __sparc__
  XLAT(SO_TIMESTAMPNS_OLD),
+ #define XLAT_VAL_97 ((unsigned) (SO_TIMESTAMPNS_OLD))
+ #define XLAT_STR_97 STRINGIFY(SO_TIMESTAMPNS_OLD)
 #elif defined __hppa__
  XLAT(SO_TIMESTAMPNS_OLD),
+ #define XLAT_VAL_98 ((unsigned) (SO_TIMESTAMPNS_OLD))
+ #define XLAT_STR_98 STRINGIFY(SO_TIMESTAMPNS_OLD)
 #else
  XLAT(SO_TIMESTAMPNS_OLD),
+ #define XLAT_VAL_99 ((unsigned) (SO_TIMESTAMPNS_OLD))
+ #define XLAT_STR_99 STRINGIFY(SO_TIMESTAMPNS_OLD)
 #endif
 
 #if defined __sparc__
  XLAT(SO_MARK),
+ #define XLAT_VAL_100 ((unsigned) (SO_MARK))
+ #define XLAT_STR_100 STRINGIFY(SO_MARK)
 #elif defined __hppa__
  XLAT(SO_MARK),
+ #define XLAT_VAL_101 ((unsigned) (SO_MARK))
+ #define XLAT_STR_101 STRINGIFY(SO_MARK)
 #else
  XLAT(SO_MARK),
+ #define XLAT_VAL_102 ((unsigned) (SO_MARK))
+ #define XLAT_STR_102 STRINGIFY(SO_MARK)
 #endif
 
 #if defined __sparc__
  XLAT(SO_TIMESTAMPING_OLD),
+ #define XLAT_VAL_103 ((unsigned) (SO_TIMESTAMPING_OLD))
+ #define XLAT_STR_103 STRINGIFY(SO_TIMESTAMPING_OLD)
 #elif defined __hppa__
  XLAT(SO_TIMESTAMPING_OLD),
+ #define XLAT_VAL_104 ((unsigned) (SO_TIMESTAMPING_OLD))
+ #define XLAT_STR_104 STRINGIFY(SO_TIMESTAMPING_OLD)
 #else
  XLAT(SO_TIMESTAMPING_OLD),
+ #define XLAT_VAL_105 ((unsigned) (SO_TIMESTAMPING_OLD))
+ #define XLAT_STR_105 STRINGIFY(SO_TIMESTAMPING_OLD)
 #endif
 
 #if defined __alpha__ || defined __hppa__ || defined __mips__ || defined __sparc__
  XLAT(SO_PROTOCOL),
+ #define XLAT_VAL_106 ((unsigned) (SO_PROTOCOL))
+ #define XLAT_STR_106 STRINGIFY(SO_PROTOCOL)
 #else
  XLAT(SO_PROTOCOL),
+ #define XLAT_VAL_107 ((unsigned) (SO_PROTOCOL))
+ #define XLAT_STR_107 STRINGIFY(SO_PROTOCOL)
 #endif
 
 #if defined __alpha__ || defined __hppa__ || defined __mips__ || defined __sparc__
  XLAT(SO_DOMAIN),
+ #define XLAT_VAL_108 ((unsigned) (SO_DOMAIN))
+ #define XLAT_STR_108 STRINGIFY(SO_DOMAIN)
 #else
  XLAT(SO_DOMAIN),
+ #define XLAT_VAL_109 ((unsigned) (SO_DOMAIN))
+ #define XLAT_STR_109 STRINGIFY(SO_DOMAIN)
 #endif
 
 #if defined __sparc__
  XLAT(SO_RXQ_OVFL),
+ #define XLAT_VAL_110 ((unsigned) (SO_RXQ_OVFL))
+ #define XLAT_STR_110 STRINGIFY(SO_RXQ_OVFL)
 #elif defined __hppa__
  XLAT(SO_RXQ_OVFL),
+ #define XLAT_VAL_111 ((unsigned) (SO_RXQ_OVFL))
+ #define XLAT_STR_111 STRINGIFY(SO_RXQ_OVFL)
 #else
  XLAT(SO_RXQ_OVFL),
+ #define XLAT_VAL_112 ((unsigned) (SO_RXQ_OVFL))
+ #define XLAT_STR_112 STRINGIFY(SO_RXQ_OVFL)
 #endif
 
 #if defined __sparc__
  XLAT(SO_WIFI_STATUS),
+ #define XLAT_VAL_113 ((unsigned) (SO_WIFI_STATUS))
+ #define XLAT_STR_113 STRINGIFY(SO_WIFI_STATUS)
 #elif defined __hppa__
  XLAT(SO_WIFI_STATUS),
+ #define XLAT_VAL_114 ((unsigned) (SO_WIFI_STATUS))
+ #define XLAT_STR_114 STRINGIFY(SO_WIFI_STATUS)
 #else
  XLAT(SO_WIFI_STATUS),
+ #define XLAT_VAL_115 ((unsigned) (SO_WIFI_STATUS))
+ #define XLAT_STR_115 STRINGIFY(SO_WIFI_STATUS)
 #endif
 
 #if defined __sparc__
  XLAT(SO_PEEK_OFF),
+ #define XLAT_VAL_116 ((unsigned) (SO_PEEK_OFF))
+ #define XLAT_STR_116 STRINGIFY(SO_PEEK_OFF)
 #elif defined __hppa__
  XLAT(SO_PEEK_OFF),
+ #define XLAT_VAL_117 ((unsigned) (SO_PEEK_OFF))
+ #define XLAT_STR_117 STRINGIFY(SO_PEEK_OFF)
 #else
  XLAT(SO_PEEK_OFF),
+ #define XLAT_VAL_118 ((unsigned) (SO_PEEK_OFF))
+ #define XLAT_STR_118 STRINGIFY(SO_PEEK_OFF)
 #endif
 
 #if defined __sparc__
  XLAT(SO_NOFCS),
+ #define XLAT_VAL_119 ((unsigned) (SO_NOFCS))
+ #define XLAT_STR_119 STRINGIFY(SO_NOFCS)
 #elif defined __hppa__
  XLAT(SO_NOFCS),
+ #define XLAT_VAL_120 ((unsigned) (SO_NOFCS))
+ #define XLAT_STR_120 STRINGIFY(SO_NOFCS)
 #else
  XLAT(SO_NOFCS),
+ #define XLAT_VAL_121 ((unsigned) (SO_NOFCS))
+ #define XLAT_STR_121 STRINGIFY(SO_NOFCS)
 #endif
 
 #if defined __sparc__
  XLAT(SO_LOCK_FILTER),
+ #define XLAT_VAL_122 ((unsigned) (SO_LOCK_FILTER))
+ #define XLAT_STR_122 STRINGIFY(SO_LOCK_FILTER)
 #elif defined __hppa__
  XLAT(SO_LOCK_FILTER),
+ #define XLAT_VAL_123 ((unsigned) (SO_LOCK_FILTER))
+ #define XLAT_STR_123 STRINGIFY(SO_LOCK_FILTER)
 #else
  XLAT(SO_LOCK_FILTER),
+ #define XLAT_VAL_124 ((unsigned) (SO_LOCK_FILTER))
+ #define XLAT_STR_124 STRINGIFY(SO_LOCK_FILTER)
 #endif
 
 #if defined __sparc__
  XLAT(SO_SELECT_ERR_QUEUE),
+ #define XLAT_VAL_125 ((unsigned) (SO_SELECT_ERR_QUEUE))
+ #define XLAT_STR_125 STRINGIFY(SO_SELECT_ERR_QUEUE)
 #elif defined __hppa__
  XLAT(SO_SELECT_ERR_QUEUE),
+ #define XLAT_VAL_126 ((unsigned) (SO_SELECT_ERR_QUEUE))
+ #define XLAT_STR_126 STRINGIFY(SO_SELECT_ERR_QUEUE)
 #else
  XLAT(SO_SELECT_ERR_QUEUE),
+ #define XLAT_VAL_127 ((unsigned) (SO_SELECT_ERR_QUEUE))
+ #define XLAT_STR_127 STRINGIFY(SO_SELECT_ERR_QUEUE)
 #endif
 
 #if defined __sparc__
  XLAT(SO_BUSY_POLL),
+ #define XLAT_VAL_128 ((unsigned) (SO_BUSY_POLL))
+ #define XLAT_STR_128 STRINGIFY(SO_BUSY_POLL)
 #elif defined __hppa__
  XLAT(SO_BUSY_POLL),
+ #define XLAT_VAL_129 ((unsigned) (SO_BUSY_POLL))
+ #define XLAT_STR_129 STRINGIFY(SO_BUSY_POLL)
 #else
  XLAT(SO_BUSY_POLL),
+ #define XLAT_VAL_130 ((unsigned) (SO_BUSY_POLL))
+ #define XLAT_STR_130 STRINGIFY(SO_BUSY_POLL)
 #endif
 
 #if defined __sparc__
  XLAT(SO_MAX_PACING_RATE),
+ #define XLAT_VAL_131 ((unsigned) (SO_MAX_PACING_RATE))
+ #define XLAT_STR_131 STRINGIFY(SO_MAX_PACING_RATE)
 #elif defined __hppa__
  XLAT(SO_MAX_PACING_RATE),
+ #define XLAT_VAL_132 ((unsigned) (SO_MAX_PACING_RATE))
+ #define XLAT_STR_132 STRINGIFY(SO_MAX_PACING_RATE)
 #else
  XLAT(SO_MAX_PACING_RATE),
+ #define XLAT_VAL_133 ((unsigned) (SO_MAX_PACING_RATE))
+ #define XLAT_STR_133 STRINGIFY(SO_MAX_PACING_RATE)
 #endif
 
 #if defined __sparc__
  XLAT(SO_BPF_EXTENSIONS),
+ #define XLAT_VAL_134 ((unsigned) (SO_BPF_EXTENSIONS))
+ #define XLAT_STR_134 STRINGIFY(SO_BPF_EXTENSIONS)
 #elif defined __hppa__
  XLAT(SO_BPF_EXTENSIONS),
+ #define XLAT_VAL_135 ((unsigned) (SO_BPF_EXTENSIONS))
+ #define XLAT_STR_135 STRINGIFY(SO_BPF_EXTENSIONS)
 #else
  XLAT(SO_BPF_EXTENSIONS),
+ #define XLAT_VAL_136 ((unsigned) (SO_BPF_EXTENSIONS))
+ #define XLAT_STR_136 STRINGIFY(SO_BPF_EXTENSIONS)
 #endif
 
 #if defined __sparc__
  XLAT(SO_INCOMING_CPU),
+ #define XLAT_VAL_137 ((unsigned) (SO_INCOMING_CPU))
+ #define XLAT_STR_137 STRINGIFY(SO_INCOMING_CPU)
 #elif defined __hppa__
  XLAT(SO_INCOMING_CPU),
+ #define XLAT_VAL_138 ((unsigned) (SO_INCOMING_CPU))
+ #define XLAT_STR_138 STRINGIFY(SO_INCOMING_CPU)
 #else
  XLAT(SO_INCOMING_CPU),
+ #define XLAT_VAL_139 ((unsigned) (SO_INCOMING_CPU))
+ #define XLAT_STR_139 STRINGIFY(SO_INCOMING_CPU)
 #endif
 
 #if defined __sparc__
  XLAT(SO_ATTACH_BPF),
+ #define XLAT_VAL_140 ((unsigned) (SO_ATTACH_BPF))
+ #define XLAT_STR_140 STRINGIFY(SO_ATTACH_BPF)
 #elif defined __hppa__
  XLAT(SO_ATTACH_BPF),
+ #define XLAT_VAL_141 ((unsigned) (SO_ATTACH_BPF))
+ #define XLAT_STR_141 STRINGIFY(SO_ATTACH_BPF)
 #else
  XLAT(SO_ATTACH_BPF),
+ #define XLAT_VAL_142 ((unsigned) (SO_ATTACH_BPF))
+ #define XLAT_STR_142 STRINGIFY(SO_ATTACH_BPF)
 #endif
 
 #if defined __sparc__
  XLAT(SO_ATTACH_REUSEPORT_CBPF),
+ #define XLAT_VAL_143 ((unsigned) (SO_ATTACH_REUSEPORT_CBPF))
+ #define XLAT_STR_143 STRINGIFY(SO_ATTACH_REUSEPORT_CBPF)
 #elif defined __hppa__
  XLAT(SO_ATTACH_REUSEPORT_CBPF),
+ #define XLAT_VAL_144 ((unsigned) (SO_ATTACH_REUSEPORT_CBPF))
+ #define XLAT_STR_144 STRINGIFY(SO_ATTACH_REUSEPORT_CBPF)
 #else
  XLAT(SO_ATTACH_REUSEPORT_CBPF),
+ #define XLAT_VAL_145 ((unsigned) (SO_ATTACH_REUSEPORT_CBPF))
+ #define XLAT_STR_145 STRINGIFY(SO_ATTACH_REUSEPORT_CBPF)
 #endif
 
 #if defined __sparc__
  XLAT(SO_ATTACH_REUSEPORT_EBPF),
+ #define XLAT_VAL_146 ((unsigned) (SO_ATTACH_REUSEPORT_EBPF))
+ #define XLAT_STR_146 STRINGIFY(SO_ATTACH_REUSEPORT_EBPF)
 #elif defined __hppa__
  XLAT(SO_ATTACH_REUSEPORT_EBPF),
+ #define XLAT_VAL_147 ((unsigned) (SO_ATTACH_REUSEPORT_EBPF))
+ #define XLAT_STR_147 STRINGIFY(SO_ATTACH_REUSEPORT_EBPF)
 #else
  XLAT(SO_ATTACH_REUSEPORT_EBPF),
+ #define XLAT_VAL_148 ((unsigned) (SO_ATTACH_REUSEPORT_EBPF))
+ #define XLAT_STR_148 STRINGIFY(SO_ATTACH_REUSEPORT_EBPF)
 #endif
 
 #if defined __sparc__
  XLAT(SO_CNX_ADVICE),
+ #define XLAT_VAL_149 ((unsigned) (SO_CNX_ADVICE))
+ #define XLAT_STR_149 STRINGIFY(SO_CNX_ADVICE)
 #elif defined __hppa__
  XLAT(SO_CNX_ADVICE),
+ #define XLAT_VAL_150 ((unsigned) (SO_CNX_ADVICE))
+ #define XLAT_STR_150 STRINGIFY(SO_CNX_ADVICE)
 #else
  XLAT(SO_CNX_ADVICE),
+ #define XLAT_VAL_151 ((unsigned) (SO_CNX_ADVICE))
+ #define XLAT_STR_151 STRINGIFY(SO_CNX_ADVICE)
 #endif
 
 #if defined __sparc__
  XLAT(SO_MEMINFO),
+ #define XLAT_VAL_152 ((unsigned) (SO_MEMINFO))
+ #define XLAT_STR_152 STRINGIFY(SO_MEMINFO)
 #elif defined __hppa__
  XLAT(SO_MEMINFO),
+ #define XLAT_VAL_153 ((unsigned) (SO_MEMINFO))
+ #define XLAT_STR_153 STRINGIFY(SO_MEMINFO)
 #else
  XLAT(SO_MEMINFO),
+ #define XLAT_VAL_154 ((unsigned) (SO_MEMINFO))
+ #define XLAT_STR_154 STRINGIFY(SO_MEMINFO)
 #endif
 
 #if defined __sparc__
  XLAT(SO_INCOMING_NAPI_ID),
+ #define XLAT_VAL_155 ((unsigned) (SO_INCOMING_NAPI_ID))
+ #define XLAT_STR_155 STRINGIFY(SO_INCOMING_NAPI_ID)
 #elif defined __hppa__
  XLAT(SO_INCOMING_NAPI_ID),
+ #define XLAT_VAL_156 ((unsigned) (SO_INCOMING_NAPI_ID))
+ #define XLAT_STR_156 STRINGIFY(SO_INCOMING_NAPI_ID)
 #else
  XLAT(SO_INCOMING_NAPI_ID),
+ #define XLAT_VAL_157 ((unsigned) (SO_INCOMING_NAPI_ID))
+ #define XLAT_STR_157 STRINGIFY(SO_INCOMING_NAPI_ID)
 #endif
 
 #if defined __sparc__
  XLAT(SO_COOKIE),
+ #define XLAT_VAL_158 ((unsigned) (SO_COOKIE))
+ #define XLAT_STR_158 STRINGIFY(SO_COOKIE)
 #elif defined __hppa__
  XLAT(SO_COOKIE),
+ #define XLAT_VAL_159 ((unsigned) (SO_COOKIE))
+ #define XLAT_STR_159 STRINGIFY(SO_COOKIE)
 #else
  XLAT(SO_COOKIE),
+ #define XLAT_VAL_160 ((unsigned) (SO_COOKIE))
+ #define XLAT_STR_160 STRINGIFY(SO_COOKIE)
 #endif
 
 #if defined __sparc__
  XLAT(SO_PEERGROUPS),
+ #define XLAT_VAL_161 ((unsigned) (SO_PEERGROUPS))
+ #define XLAT_STR_161 STRINGIFY(SO_PEERGROUPS)
 #elif defined __hppa__
  XLAT(SO_PEERGROUPS),
+ #define XLAT_VAL_162 ((unsigned) (SO_PEERGROUPS))
+ #define XLAT_STR_162 STRINGIFY(SO_PEERGROUPS)
 #else
  XLAT(SO_PEERGROUPS),
+ #define XLAT_VAL_163 ((unsigned) (SO_PEERGROUPS))
+ #define XLAT_STR_163 STRINGIFY(SO_PEERGROUPS)
 #endif
 
 #if defined __sparc__
  XLAT(SO_ZEROCOPY),
+ #define XLAT_VAL_164 ((unsigned) (SO_ZEROCOPY))
+ #define XLAT_STR_164 STRINGIFY(SO_ZEROCOPY)
 #elif defined __hppa__
  XLAT(SO_ZEROCOPY),
+ #define XLAT_VAL_165 ((unsigned) (SO_ZEROCOPY))
+ #define XLAT_STR_165 STRINGIFY(SO_ZEROCOPY)
 #else
  XLAT(SO_ZEROCOPY),
+ #define XLAT_VAL_166 ((unsigned) (SO_ZEROCOPY))
+ #define XLAT_STR_166 STRINGIFY(SO_ZEROCOPY)
 #endif
 
 #if defined __sparc__
  XLAT(SO_TXTIME),
+ #define XLAT_VAL_167 ((unsigned) (SO_TXTIME))
+ #define XLAT_STR_167 STRINGIFY(SO_TXTIME)
 #elif defined __hppa__
  XLAT(SO_TXTIME),
+ #define XLAT_VAL_168 ((unsigned) (SO_TXTIME))
+ #define XLAT_STR_168 STRINGIFY(SO_TXTIME)
 #else
  XLAT(SO_TXTIME),
+ #define XLAT_VAL_169 ((unsigned) (SO_TXTIME))
+ #define XLAT_STR_169 STRINGIFY(SO_TXTIME)
 #endif
 
 #if defined __sparc__
  XLAT(SO_BINDTOIFINDEX),
+ #define XLAT_VAL_170 ((unsigned) (SO_BINDTOIFINDEX))
+ #define XLAT_STR_170 STRINGIFY(SO_BINDTOIFINDEX)
 #elif defined __hppa__
  XLAT(SO_BINDTOIFINDEX),
+ #define XLAT_VAL_171 ((unsigned) (SO_BINDTOIFINDEX))
+ #define XLAT_STR_171 STRINGIFY(SO_BINDTOIFINDEX)
 #else
  XLAT(SO_BINDTOIFINDEX),
+ #define XLAT_VAL_172 ((unsigned) (SO_BINDTOIFINDEX))
+ #define XLAT_STR_172 STRINGIFY(SO_BINDTOIFINDEX)
 #endif
 
 #if defined __sparc__
  XLAT(SO_TIMESTAMP_NEW),
+ #define XLAT_VAL_173 ((unsigned) (SO_TIMESTAMP_NEW))
+ #define XLAT_STR_173 STRINGIFY(SO_TIMESTAMP_NEW)
 #elif defined __hppa__
  XLAT(SO_TIMESTAMP_NEW),
+ #define XLAT_VAL_174 ((unsigned) (SO_TIMESTAMP_NEW))
+ #define XLAT_STR_174 STRINGIFY(SO_TIMESTAMP_NEW)
 #else
  XLAT(SO_TIMESTAMP_NEW),
+ #define XLAT_VAL_175 ((unsigned) (SO_TIMESTAMP_NEW))
+ #define XLAT_STR_175 STRINGIFY(SO_TIMESTAMP_NEW)
 #endif
 
 #if defined __sparc__
  XLAT(SO_TIMESTAMPNS_NEW),
+ #define XLAT_VAL_176 ((unsigned) (SO_TIMESTAMPNS_NEW))
+ #define XLAT_STR_176 STRINGIFY(SO_TIMESTAMPNS_NEW)
 #elif defined __hppa__
  XLAT(SO_TIMESTAMPNS_NEW),
+ #define XLAT_VAL_177 ((unsigned) (SO_TIMESTAMPNS_NEW))
+ #define XLAT_STR_177 STRINGIFY(SO_TIMESTAMPNS_NEW)
 #else
  XLAT(SO_TIMESTAMPNS_NEW),
+ #define XLAT_VAL_178 ((unsigned) (SO_TIMESTAMPNS_NEW))
+ #define XLAT_STR_178 STRINGIFY(SO_TIMESTAMPNS_NEW)
 #endif
 
 #if defined __sparc__
  XLAT(SO_TIMESTAMPING_NEW),
+ #define XLAT_VAL_179 ((unsigned) (SO_TIMESTAMPING_NEW))
+ #define XLAT_STR_179 STRINGIFY(SO_TIMESTAMPING_NEW)
 #elif defined __hppa__
  XLAT(SO_TIMESTAMPING_NEW),
+ #define XLAT_VAL_180 ((unsigned) (SO_TIMESTAMPING_NEW))
+ #define XLAT_STR_180 STRINGIFY(SO_TIMESTAMPING_NEW)
 #else
  XLAT(SO_TIMESTAMPING_NEW),
+ #define XLAT_VAL_181 ((unsigned) (SO_TIMESTAMPING_NEW))
+ #define XLAT_STR_181 STRINGIFY(SO_TIMESTAMPING_NEW)
 #endif
 
 #if defined __sparc__
  XLAT(SO_RCVTIMEO_NEW),
+ #define XLAT_VAL_182 ((unsigned) (SO_RCVTIMEO_NEW))
+ #define XLAT_STR_182 STRINGIFY(SO_RCVTIMEO_NEW)
 #elif defined __hppa__
  XLAT(SO_RCVTIMEO_NEW),
+ #define XLAT_VAL_183 ((unsigned) (SO_RCVTIMEO_NEW))
+ #define XLAT_STR_183 STRINGIFY(SO_RCVTIMEO_NEW)
 #else
  XLAT(SO_RCVTIMEO_NEW),
+ #define XLAT_VAL_184 ((unsigned) (SO_RCVTIMEO_NEW))
+ #define XLAT_STR_184 STRINGIFY(SO_RCVTIMEO_NEW)
 #endif
 
 #if defined __sparc__
  XLAT(SO_SNDTIMEO_NEW),
+ #define XLAT_VAL_185 ((unsigned) (SO_SNDTIMEO_NEW))
+ #define XLAT_STR_185 STRINGIFY(SO_SNDTIMEO_NEW)
 #elif defined __hppa__
  XLAT(SO_SNDTIMEO_NEW),
+ #define XLAT_VAL_186 ((unsigned) (SO_SNDTIMEO_NEW))
+ #define XLAT_STR_186 STRINGIFY(SO_SNDTIMEO_NEW)
 #else
  XLAT(SO_SNDTIMEO_NEW),
+ #define XLAT_VAL_187 ((unsigned) (SO_SNDTIMEO_NEW))
+ #define XLAT_STR_187 STRINGIFY(SO_SNDTIMEO_NEW)
 #endif
 
 #if defined __sparc__
  XLAT(SO_DETACH_REUSEPORT_BPF),
+ #define XLAT_VAL_188 ((unsigned) (SO_DETACH_REUSEPORT_BPF))
+ #define XLAT_STR_188 STRINGIFY(SO_DETACH_REUSEPORT_BPF)
 #elif defined __hppa__
  XLAT(SO_DETACH_REUSEPORT_BPF),
+ #define XLAT_VAL_189 ((unsigned) (SO_DETACH_REUSEPORT_BPF))
+ #define XLAT_STR_189 STRINGIFY(SO_DETACH_REUSEPORT_BPF)
 #else
  XLAT(SO_DETACH_REUSEPORT_BPF),
+ #define XLAT_VAL_190 ((unsigned) (SO_DETACH_REUSEPORT_BPF))
+ #define XLAT_STR_190 STRINGIFY(SO_DETACH_REUSEPORT_BPF)
 #endif
 };
 static
@@ -2123,8 +2505,1540 @@ const struct xlat sock_options[1] = { {
  .data = sock_options_xdata,
  .size = ARRAY_SIZE(sock_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+#  ifdef XLAT_VAL_47
+  | XLAT_VAL_47
+#  endif
+#  ifdef XLAT_VAL_48
+  | XLAT_VAL_48
+#  endif
+#  ifdef XLAT_VAL_49
+  | XLAT_VAL_49
+#  endif
+#  ifdef XLAT_VAL_50
+  | XLAT_VAL_50
+#  endif
+#  ifdef XLAT_VAL_51
+  | XLAT_VAL_51
+#  endif
+#  ifdef XLAT_VAL_52
+  | XLAT_VAL_52
+#  endif
+#  ifdef XLAT_VAL_53
+  | XLAT_VAL_53
+#  endif
+#  ifdef XLAT_VAL_54
+  | XLAT_VAL_54
+#  endif
+#  ifdef XLAT_VAL_55
+  | XLAT_VAL_55
+#  endif
+#  ifdef XLAT_VAL_56
+  | XLAT_VAL_56
+#  endif
+#  ifdef XLAT_VAL_57
+  | XLAT_VAL_57
+#  endif
+#  ifdef XLAT_VAL_58
+  | XLAT_VAL_58
+#  endif
+#  ifdef XLAT_VAL_59
+  | XLAT_VAL_59
+#  endif
+#  ifdef XLAT_VAL_60
+  | XLAT_VAL_60
+#  endif
+#  ifdef XLAT_VAL_61
+  | XLAT_VAL_61
+#  endif
+#  ifdef XLAT_VAL_62
+  | XLAT_VAL_62
+#  endif
+#  ifdef XLAT_VAL_63
+  | XLAT_VAL_63
+#  endif
+#  ifdef XLAT_VAL_64
+  | XLAT_VAL_64
+#  endif
+#  ifdef XLAT_VAL_65
+  | XLAT_VAL_65
+#  endif
+#  ifdef XLAT_VAL_66
+  | XLAT_VAL_66
+#  endif
+#  ifdef XLAT_VAL_67
+  | XLAT_VAL_67
+#  endif
+#  ifdef XLAT_VAL_68
+  | XLAT_VAL_68
+#  endif
+#  ifdef XLAT_VAL_69
+  | XLAT_VAL_69
+#  endif
+#  ifdef XLAT_VAL_70
+  | XLAT_VAL_70
+#  endif
+#  ifdef XLAT_VAL_71
+  | XLAT_VAL_71
+#  endif
+#  ifdef XLAT_VAL_72
+  | XLAT_VAL_72
+#  endif
+#  ifdef XLAT_VAL_73
+  | XLAT_VAL_73
+#  endif
+#  ifdef XLAT_VAL_74
+  | XLAT_VAL_74
+#  endif
+#  ifdef XLAT_VAL_75
+  | XLAT_VAL_75
+#  endif
+#  ifdef XLAT_VAL_76
+  | XLAT_VAL_76
+#  endif
+#  ifdef XLAT_VAL_77
+  | XLAT_VAL_77
+#  endif
+#  ifdef XLAT_VAL_78
+  | XLAT_VAL_78
+#  endif
+#  ifdef XLAT_VAL_79
+  | XLAT_VAL_79
+#  endif
+#  ifdef XLAT_VAL_80
+  | XLAT_VAL_80
+#  endif
+#  ifdef XLAT_VAL_81
+  | XLAT_VAL_81
+#  endif
+#  ifdef XLAT_VAL_82
+  | XLAT_VAL_82
+#  endif
+#  ifdef XLAT_VAL_83
+  | XLAT_VAL_83
+#  endif
+#  ifdef XLAT_VAL_84
+  | XLAT_VAL_84
+#  endif
+#  ifdef XLAT_VAL_85
+  | XLAT_VAL_85
+#  endif
+#  ifdef XLAT_VAL_86
+  | XLAT_VAL_86
+#  endif
+#  ifdef XLAT_VAL_87
+  | XLAT_VAL_87
+#  endif
+#  ifdef XLAT_VAL_88
+  | XLAT_VAL_88
+#  endif
+#  ifdef XLAT_VAL_89
+  | XLAT_VAL_89
+#  endif
+#  ifdef XLAT_VAL_90
+  | XLAT_VAL_90
+#  endif
+#  ifdef XLAT_VAL_91
+  | XLAT_VAL_91
+#  endif
+#  ifdef XLAT_VAL_92
+  | XLAT_VAL_92
+#  endif
+#  ifdef XLAT_VAL_93
+  | XLAT_VAL_93
+#  endif
+#  ifdef XLAT_VAL_94
+  | XLAT_VAL_94
+#  endif
+#  ifdef XLAT_VAL_95
+  | XLAT_VAL_95
+#  endif
+#  ifdef XLAT_VAL_96
+  | XLAT_VAL_96
+#  endif
+#  ifdef XLAT_VAL_97
+  | XLAT_VAL_97
+#  endif
+#  ifdef XLAT_VAL_98
+  | XLAT_VAL_98
+#  endif
+#  ifdef XLAT_VAL_99
+  | XLAT_VAL_99
+#  endif
+#  ifdef XLAT_VAL_100
+  | XLAT_VAL_100
+#  endif
+#  ifdef XLAT_VAL_101
+  | XLAT_VAL_101
+#  endif
+#  ifdef XLAT_VAL_102
+  | XLAT_VAL_102
+#  endif
+#  ifdef XLAT_VAL_103
+  | XLAT_VAL_103
+#  endif
+#  ifdef XLAT_VAL_104
+  | XLAT_VAL_104
+#  endif
+#  ifdef XLAT_VAL_105
+  | XLAT_VAL_105
+#  endif
+#  ifdef XLAT_VAL_106
+  | XLAT_VAL_106
+#  endif
+#  ifdef XLAT_VAL_107
+  | XLAT_VAL_107
+#  endif
+#  ifdef XLAT_VAL_108
+  | XLAT_VAL_108
+#  endif
+#  ifdef XLAT_VAL_109
+  | XLAT_VAL_109
+#  endif
+#  ifdef XLAT_VAL_110
+  | XLAT_VAL_110
+#  endif
+#  ifdef XLAT_VAL_111
+  | XLAT_VAL_111
+#  endif
+#  ifdef XLAT_VAL_112
+  | XLAT_VAL_112
+#  endif
+#  ifdef XLAT_VAL_113
+  | XLAT_VAL_113
+#  endif
+#  ifdef XLAT_VAL_114
+  | XLAT_VAL_114
+#  endif
+#  ifdef XLAT_VAL_115
+  | XLAT_VAL_115
+#  endif
+#  ifdef XLAT_VAL_116
+  | XLAT_VAL_116
+#  endif
+#  ifdef XLAT_VAL_117
+  | XLAT_VAL_117
+#  endif
+#  ifdef XLAT_VAL_118
+  | XLAT_VAL_118
+#  endif
+#  ifdef XLAT_VAL_119
+  | XLAT_VAL_119
+#  endif
+#  ifdef XLAT_VAL_120
+  | XLAT_VAL_120
+#  endif
+#  ifdef XLAT_VAL_121
+  | XLAT_VAL_121
+#  endif
+#  ifdef XLAT_VAL_122
+  | XLAT_VAL_122
+#  endif
+#  ifdef XLAT_VAL_123
+  | XLAT_VAL_123
+#  endif
+#  ifdef XLAT_VAL_124
+  | XLAT_VAL_124
+#  endif
+#  ifdef XLAT_VAL_125
+  | XLAT_VAL_125
+#  endif
+#  ifdef XLAT_VAL_126
+  | XLAT_VAL_126
+#  endif
+#  ifdef XLAT_VAL_127
+  | XLAT_VAL_127
+#  endif
+#  ifdef XLAT_VAL_128
+  | XLAT_VAL_128
+#  endif
+#  ifdef XLAT_VAL_129
+  | XLAT_VAL_129
+#  endif
+#  ifdef XLAT_VAL_130
+  | XLAT_VAL_130
+#  endif
+#  ifdef XLAT_VAL_131
+  | XLAT_VAL_131
+#  endif
+#  ifdef XLAT_VAL_132
+  | XLAT_VAL_132
+#  endif
+#  ifdef XLAT_VAL_133
+  | XLAT_VAL_133
+#  endif
+#  ifdef XLAT_VAL_134
+  | XLAT_VAL_134
+#  endif
+#  ifdef XLAT_VAL_135
+  | XLAT_VAL_135
+#  endif
+#  ifdef XLAT_VAL_136
+  | XLAT_VAL_136
+#  endif
+#  ifdef XLAT_VAL_137
+  | XLAT_VAL_137
+#  endif
+#  ifdef XLAT_VAL_138
+  | XLAT_VAL_138
+#  endif
+#  ifdef XLAT_VAL_139
+  | XLAT_VAL_139
+#  endif
+#  ifdef XLAT_VAL_140
+  | XLAT_VAL_140
+#  endif
+#  ifdef XLAT_VAL_141
+  | XLAT_VAL_141
+#  endif
+#  ifdef XLAT_VAL_142
+  | XLAT_VAL_142
+#  endif
+#  ifdef XLAT_VAL_143
+  | XLAT_VAL_143
+#  endif
+#  ifdef XLAT_VAL_144
+  | XLAT_VAL_144
+#  endif
+#  ifdef XLAT_VAL_145
+  | XLAT_VAL_145
+#  endif
+#  ifdef XLAT_VAL_146
+  | XLAT_VAL_146
+#  endif
+#  ifdef XLAT_VAL_147
+  | XLAT_VAL_147
+#  endif
+#  ifdef XLAT_VAL_148
+  | XLAT_VAL_148
+#  endif
+#  ifdef XLAT_VAL_149
+  | XLAT_VAL_149
+#  endif
+#  ifdef XLAT_VAL_150
+  | XLAT_VAL_150
+#  endif
+#  ifdef XLAT_VAL_151
+  | XLAT_VAL_151
+#  endif
+#  ifdef XLAT_VAL_152
+  | XLAT_VAL_152
+#  endif
+#  ifdef XLAT_VAL_153
+  | XLAT_VAL_153
+#  endif
+#  ifdef XLAT_VAL_154
+  | XLAT_VAL_154
+#  endif
+#  ifdef XLAT_VAL_155
+  | XLAT_VAL_155
+#  endif
+#  ifdef XLAT_VAL_156
+  | XLAT_VAL_156
+#  endif
+#  ifdef XLAT_VAL_157
+  | XLAT_VAL_157
+#  endif
+#  ifdef XLAT_VAL_158
+  | XLAT_VAL_158
+#  endif
+#  ifdef XLAT_VAL_159
+  | XLAT_VAL_159
+#  endif
+#  ifdef XLAT_VAL_160
+  | XLAT_VAL_160
+#  endif
+#  ifdef XLAT_VAL_161
+  | XLAT_VAL_161
+#  endif
+#  ifdef XLAT_VAL_162
+  | XLAT_VAL_162
+#  endif
+#  ifdef XLAT_VAL_163
+  | XLAT_VAL_163
+#  endif
+#  ifdef XLAT_VAL_164
+  | XLAT_VAL_164
+#  endif
+#  ifdef XLAT_VAL_165
+  | XLAT_VAL_165
+#  endif
+#  ifdef XLAT_VAL_166
+  | XLAT_VAL_166
+#  endif
+#  ifdef XLAT_VAL_167
+  | XLAT_VAL_167
+#  endif
+#  ifdef XLAT_VAL_168
+  | XLAT_VAL_168
+#  endif
+#  ifdef XLAT_VAL_169
+  | XLAT_VAL_169
+#  endif
+#  ifdef XLAT_VAL_170
+  | XLAT_VAL_170
+#  endif
+#  ifdef XLAT_VAL_171
+  | XLAT_VAL_171
+#  endif
+#  ifdef XLAT_VAL_172
+  | XLAT_VAL_172
+#  endif
+#  ifdef XLAT_VAL_173
+  | XLAT_VAL_173
+#  endif
+#  ifdef XLAT_VAL_174
+  | XLAT_VAL_174
+#  endif
+#  ifdef XLAT_VAL_175
+  | XLAT_VAL_175
+#  endif
+#  ifdef XLAT_VAL_176
+  | XLAT_VAL_176
+#  endif
+#  ifdef XLAT_VAL_177
+  | XLAT_VAL_177
+#  endif
+#  ifdef XLAT_VAL_178
+  | XLAT_VAL_178
+#  endif
+#  ifdef XLAT_VAL_179
+  | XLAT_VAL_179
+#  endif
+#  ifdef XLAT_VAL_180
+  | XLAT_VAL_180
+#  endif
+#  ifdef XLAT_VAL_181
+  | XLAT_VAL_181
+#  endif
+#  ifdef XLAT_VAL_182
+  | XLAT_VAL_182
+#  endif
+#  ifdef XLAT_VAL_183
+  | XLAT_VAL_183
+#  endif
+#  ifdef XLAT_VAL_184
+  | XLAT_VAL_184
+#  endif
+#  ifdef XLAT_VAL_185
+  | XLAT_VAL_185
+#  endif
+#  ifdef XLAT_VAL_186
+  | XLAT_VAL_186
+#  endif
+#  ifdef XLAT_VAL_187
+  | XLAT_VAL_187
+#  endif
+#  ifdef XLAT_VAL_188
+  | XLAT_VAL_188
+#  endif
+#  ifdef XLAT_VAL_189
+  | XLAT_VAL_189
+#  endif
+#  ifdef XLAT_VAL_190
+  | XLAT_VAL_190
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+#  ifdef XLAT_STR_47
+  + sizeof(XLAT_STR_47)
+#  endif
+#  ifdef XLAT_STR_48
+  + sizeof(XLAT_STR_48)
+#  endif
+#  ifdef XLAT_STR_49
+  + sizeof(XLAT_STR_49)
+#  endif
+#  ifdef XLAT_STR_50
+  + sizeof(XLAT_STR_50)
+#  endif
+#  ifdef XLAT_STR_51
+  + sizeof(XLAT_STR_51)
+#  endif
+#  ifdef XLAT_STR_52
+  + sizeof(XLAT_STR_52)
+#  endif
+#  ifdef XLAT_STR_53
+  + sizeof(XLAT_STR_53)
+#  endif
+#  ifdef XLAT_STR_54
+  + sizeof(XLAT_STR_54)
+#  endif
+#  ifdef XLAT_STR_55
+  + sizeof(XLAT_STR_55)
+#  endif
+#  ifdef XLAT_STR_56
+  + sizeof(XLAT_STR_56)
+#  endif
+#  ifdef XLAT_STR_57
+  + sizeof(XLAT_STR_57)
+#  endif
+#  ifdef XLAT_STR_58
+  + sizeof(XLAT_STR_58)
+#  endif
+#  ifdef XLAT_STR_59
+  + sizeof(XLAT_STR_59)
+#  endif
+#  ifdef XLAT_STR_60
+  + sizeof(XLAT_STR_60)
+#  endif
+#  ifdef XLAT_STR_61
+  + sizeof(XLAT_STR_61)
+#  endif
+#  ifdef XLAT_STR_62
+  + sizeof(XLAT_STR_62)
+#  endif
+#  ifdef XLAT_STR_63
+  + sizeof(XLAT_STR_63)
+#  endif
+#  ifdef XLAT_STR_64
+  + sizeof(XLAT_STR_64)
+#  endif
+#  ifdef XLAT_STR_65
+  + sizeof(XLAT_STR_65)
+#  endif
+#  ifdef XLAT_STR_66
+  + sizeof(XLAT_STR_66)
+#  endif
+#  ifdef XLAT_STR_67
+  + sizeof(XLAT_STR_67)
+#  endif
+#  ifdef XLAT_STR_68
+  + sizeof(XLAT_STR_68)
+#  endif
+#  ifdef XLAT_STR_69
+  + sizeof(XLAT_STR_69)
+#  endif
+#  ifdef XLAT_STR_70
+  + sizeof(XLAT_STR_70)
+#  endif
+#  ifdef XLAT_STR_71
+  + sizeof(XLAT_STR_71)
+#  endif
+#  ifdef XLAT_STR_72
+  + sizeof(XLAT_STR_72)
+#  endif
+#  ifdef XLAT_STR_73
+  + sizeof(XLAT_STR_73)
+#  endif
+#  ifdef XLAT_STR_74
+  + sizeof(XLAT_STR_74)
+#  endif
+#  ifdef XLAT_STR_75
+  + sizeof(XLAT_STR_75)
+#  endif
+#  ifdef XLAT_STR_76
+  + sizeof(XLAT_STR_76)
+#  endif
+#  ifdef XLAT_STR_77
+  + sizeof(XLAT_STR_77)
+#  endif
+#  ifdef XLAT_STR_78
+  + sizeof(XLAT_STR_78)
+#  endif
+#  ifdef XLAT_STR_79
+  + sizeof(XLAT_STR_79)
+#  endif
+#  ifdef XLAT_STR_80
+  + sizeof(XLAT_STR_80)
+#  endif
+#  ifdef XLAT_STR_81
+  + sizeof(XLAT_STR_81)
+#  endif
+#  ifdef XLAT_STR_82
+  + sizeof(XLAT_STR_82)
+#  endif
+#  ifdef XLAT_STR_83
+  + sizeof(XLAT_STR_83)
+#  endif
+#  ifdef XLAT_STR_84
+  + sizeof(XLAT_STR_84)
+#  endif
+#  ifdef XLAT_STR_85
+  + sizeof(XLAT_STR_85)
+#  endif
+#  ifdef XLAT_STR_86
+  + sizeof(XLAT_STR_86)
+#  endif
+#  ifdef XLAT_STR_87
+  + sizeof(XLAT_STR_87)
+#  endif
+#  ifdef XLAT_STR_88
+  + sizeof(XLAT_STR_88)
+#  endif
+#  ifdef XLAT_STR_89
+  + sizeof(XLAT_STR_89)
+#  endif
+#  ifdef XLAT_STR_90
+  + sizeof(XLAT_STR_90)
+#  endif
+#  ifdef XLAT_STR_91
+  + sizeof(XLAT_STR_91)
+#  endif
+#  ifdef XLAT_STR_92
+  + sizeof(XLAT_STR_92)
+#  endif
+#  ifdef XLAT_STR_93
+  + sizeof(XLAT_STR_93)
+#  endif
+#  ifdef XLAT_STR_94
+  + sizeof(XLAT_STR_94)
+#  endif
+#  ifdef XLAT_STR_95
+  + sizeof(XLAT_STR_95)
+#  endif
+#  ifdef XLAT_STR_96
+  + sizeof(XLAT_STR_96)
+#  endif
+#  ifdef XLAT_STR_97
+  + sizeof(XLAT_STR_97)
+#  endif
+#  ifdef XLAT_STR_98
+  + sizeof(XLAT_STR_98)
+#  endif
+#  ifdef XLAT_STR_99
+  + sizeof(XLAT_STR_99)
+#  endif
+#  ifdef XLAT_STR_100
+  + sizeof(XLAT_STR_100)
+#  endif
+#  ifdef XLAT_STR_101
+  + sizeof(XLAT_STR_101)
+#  endif
+#  ifdef XLAT_STR_102
+  + sizeof(XLAT_STR_102)
+#  endif
+#  ifdef XLAT_STR_103
+  + sizeof(XLAT_STR_103)
+#  endif
+#  ifdef XLAT_STR_104
+  + sizeof(XLAT_STR_104)
+#  endif
+#  ifdef XLAT_STR_105
+  + sizeof(XLAT_STR_105)
+#  endif
+#  ifdef XLAT_STR_106
+  + sizeof(XLAT_STR_106)
+#  endif
+#  ifdef XLAT_STR_107
+  + sizeof(XLAT_STR_107)
+#  endif
+#  ifdef XLAT_STR_108
+  + sizeof(XLAT_STR_108)
+#  endif
+#  ifdef XLAT_STR_109
+  + sizeof(XLAT_STR_109)
+#  endif
+#  ifdef XLAT_STR_110
+  + sizeof(XLAT_STR_110)
+#  endif
+#  ifdef XLAT_STR_111
+  + sizeof(XLAT_STR_111)
+#  endif
+#  ifdef XLAT_STR_112
+  + sizeof(XLAT_STR_112)
+#  endif
+#  ifdef XLAT_STR_113
+  + sizeof(XLAT_STR_113)
+#  endif
+#  ifdef XLAT_STR_114
+  + sizeof(XLAT_STR_114)
+#  endif
+#  ifdef XLAT_STR_115
+  + sizeof(XLAT_STR_115)
+#  endif
+#  ifdef XLAT_STR_116
+  + sizeof(XLAT_STR_116)
+#  endif
+#  ifdef XLAT_STR_117
+  + sizeof(XLAT_STR_117)
+#  endif
+#  ifdef XLAT_STR_118
+  + sizeof(XLAT_STR_118)
+#  endif
+#  ifdef XLAT_STR_119
+  + sizeof(XLAT_STR_119)
+#  endif
+#  ifdef XLAT_STR_120
+  + sizeof(XLAT_STR_120)
+#  endif
+#  ifdef XLAT_STR_121
+  + sizeof(XLAT_STR_121)
+#  endif
+#  ifdef XLAT_STR_122
+  + sizeof(XLAT_STR_122)
+#  endif
+#  ifdef XLAT_STR_123
+  + sizeof(XLAT_STR_123)
+#  endif
+#  ifdef XLAT_STR_124
+  + sizeof(XLAT_STR_124)
+#  endif
+#  ifdef XLAT_STR_125
+  + sizeof(XLAT_STR_125)
+#  endif
+#  ifdef XLAT_STR_126
+  + sizeof(XLAT_STR_126)
+#  endif
+#  ifdef XLAT_STR_127
+  + sizeof(XLAT_STR_127)
+#  endif
+#  ifdef XLAT_STR_128
+  + sizeof(XLAT_STR_128)
+#  endif
+#  ifdef XLAT_STR_129
+  + sizeof(XLAT_STR_129)
+#  endif
+#  ifdef XLAT_STR_130
+  + sizeof(XLAT_STR_130)
+#  endif
+#  ifdef XLAT_STR_131
+  + sizeof(XLAT_STR_131)
+#  endif
+#  ifdef XLAT_STR_132
+  + sizeof(XLAT_STR_132)
+#  endif
+#  ifdef XLAT_STR_133
+  + sizeof(XLAT_STR_133)
+#  endif
+#  ifdef XLAT_STR_134
+  + sizeof(XLAT_STR_134)
+#  endif
+#  ifdef XLAT_STR_135
+  + sizeof(XLAT_STR_135)
+#  endif
+#  ifdef XLAT_STR_136
+  + sizeof(XLAT_STR_136)
+#  endif
+#  ifdef XLAT_STR_137
+  + sizeof(XLAT_STR_137)
+#  endif
+#  ifdef XLAT_STR_138
+  + sizeof(XLAT_STR_138)
+#  endif
+#  ifdef XLAT_STR_139
+  + sizeof(XLAT_STR_139)
+#  endif
+#  ifdef XLAT_STR_140
+  + sizeof(XLAT_STR_140)
+#  endif
+#  ifdef XLAT_STR_141
+  + sizeof(XLAT_STR_141)
+#  endif
+#  ifdef XLAT_STR_142
+  + sizeof(XLAT_STR_142)
+#  endif
+#  ifdef XLAT_STR_143
+  + sizeof(XLAT_STR_143)
+#  endif
+#  ifdef XLAT_STR_144
+  + sizeof(XLAT_STR_144)
+#  endif
+#  ifdef XLAT_STR_145
+  + sizeof(XLAT_STR_145)
+#  endif
+#  ifdef XLAT_STR_146
+  + sizeof(XLAT_STR_146)
+#  endif
+#  ifdef XLAT_STR_147
+  + sizeof(XLAT_STR_147)
+#  endif
+#  ifdef XLAT_STR_148
+  + sizeof(XLAT_STR_148)
+#  endif
+#  ifdef XLAT_STR_149
+  + sizeof(XLAT_STR_149)
+#  endif
+#  ifdef XLAT_STR_150
+  + sizeof(XLAT_STR_150)
+#  endif
+#  ifdef XLAT_STR_151
+  + sizeof(XLAT_STR_151)
+#  endif
+#  ifdef XLAT_STR_152
+  + sizeof(XLAT_STR_152)
+#  endif
+#  ifdef XLAT_STR_153
+  + sizeof(XLAT_STR_153)
+#  endif
+#  ifdef XLAT_STR_154
+  + sizeof(XLAT_STR_154)
+#  endif
+#  ifdef XLAT_STR_155
+  + sizeof(XLAT_STR_155)
+#  endif
+#  ifdef XLAT_STR_156
+  + sizeof(XLAT_STR_156)
+#  endif
+#  ifdef XLAT_STR_157
+  + sizeof(XLAT_STR_157)
+#  endif
+#  ifdef XLAT_STR_158
+  + sizeof(XLAT_STR_158)
+#  endif
+#  ifdef XLAT_STR_159
+  + sizeof(XLAT_STR_159)
+#  endif
+#  ifdef XLAT_STR_160
+  + sizeof(XLAT_STR_160)
+#  endif
+#  ifdef XLAT_STR_161
+  + sizeof(XLAT_STR_161)
+#  endif
+#  ifdef XLAT_STR_162
+  + sizeof(XLAT_STR_162)
+#  endif
+#  ifdef XLAT_STR_163
+  + sizeof(XLAT_STR_163)
+#  endif
+#  ifdef XLAT_STR_164
+  + sizeof(XLAT_STR_164)
+#  endif
+#  ifdef XLAT_STR_165
+  + sizeof(XLAT_STR_165)
+#  endif
+#  ifdef XLAT_STR_166
+  + sizeof(XLAT_STR_166)
+#  endif
+#  ifdef XLAT_STR_167
+  + sizeof(XLAT_STR_167)
+#  endif
+#  ifdef XLAT_STR_168
+  + sizeof(XLAT_STR_168)
+#  endif
+#  ifdef XLAT_STR_169
+  + sizeof(XLAT_STR_169)
+#  endif
+#  ifdef XLAT_STR_170
+  + sizeof(XLAT_STR_170)
+#  endif
+#  ifdef XLAT_STR_171
+  + sizeof(XLAT_STR_171)
+#  endif
+#  ifdef XLAT_STR_172
+  + sizeof(XLAT_STR_172)
+#  endif
+#  ifdef XLAT_STR_173
+  + sizeof(XLAT_STR_173)
+#  endif
+#  ifdef XLAT_STR_174
+  + sizeof(XLAT_STR_174)
+#  endif
+#  ifdef XLAT_STR_175
+  + sizeof(XLAT_STR_175)
+#  endif
+#  ifdef XLAT_STR_176
+  + sizeof(XLAT_STR_176)
+#  endif
+#  ifdef XLAT_STR_177
+  + sizeof(XLAT_STR_177)
+#  endif
+#  ifdef XLAT_STR_178
+  + sizeof(XLAT_STR_178)
+#  endif
+#  ifdef XLAT_STR_179
+  + sizeof(XLAT_STR_179)
+#  endif
+#  ifdef XLAT_STR_180
+  + sizeof(XLAT_STR_180)
+#  endif
+#  ifdef XLAT_STR_181
+  + sizeof(XLAT_STR_181)
+#  endif
+#  ifdef XLAT_STR_182
+  + sizeof(XLAT_STR_182)
+#  endif
+#  ifdef XLAT_STR_183
+  + sizeof(XLAT_STR_183)
+#  endif
+#  ifdef XLAT_STR_184
+  + sizeof(XLAT_STR_184)
+#  endif
+#  ifdef XLAT_STR_185
+  + sizeof(XLAT_STR_185)
+#  endif
+#  ifdef XLAT_STR_186
+  + sizeof(XLAT_STR_186)
+#  endif
+#  ifdef XLAT_STR_187
+  + sizeof(XLAT_STR_187)
+#  endif
+#  ifdef XLAT_STR_188
+  + sizeof(XLAT_STR_188)
+#  endif
+#  ifdef XLAT_STR_189
+  + sizeof(XLAT_STR_189)
+#  endif
+#  ifdef XLAT_STR_190
+  + sizeof(XLAT_STR_190)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
+#  undef XLAT_STR_47
+#  undef XLAT_VAL_47
+#  undef XLAT_STR_48
+#  undef XLAT_VAL_48
+#  undef XLAT_STR_49
+#  undef XLAT_VAL_49
+#  undef XLAT_STR_50
+#  undef XLAT_VAL_50
+#  undef XLAT_STR_51
+#  undef XLAT_VAL_51
+#  undef XLAT_STR_52
+#  undef XLAT_VAL_52
+#  undef XLAT_STR_53
+#  undef XLAT_VAL_53
+#  undef XLAT_STR_54
+#  undef XLAT_VAL_54
+#  undef XLAT_STR_55
+#  undef XLAT_VAL_55
+#  undef XLAT_STR_56
+#  undef XLAT_VAL_56
+#  undef XLAT_STR_57
+#  undef XLAT_VAL_57
+#  undef XLAT_STR_58
+#  undef XLAT_VAL_58
+#  undef XLAT_STR_59
+#  undef XLAT_VAL_59
+#  undef XLAT_STR_60
+#  undef XLAT_VAL_60
+#  undef XLAT_STR_61
+#  undef XLAT_VAL_61
+#  undef XLAT_STR_62
+#  undef XLAT_VAL_62
+#  undef XLAT_STR_63
+#  undef XLAT_VAL_63
+#  undef XLAT_STR_64
+#  undef XLAT_VAL_64
+#  undef XLAT_STR_65
+#  undef XLAT_VAL_65
+#  undef XLAT_STR_66
+#  undef XLAT_VAL_66
+#  undef XLAT_STR_67
+#  undef XLAT_VAL_67
+#  undef XLAT_STR_68
+#  undef XLAT_VAL_68
+#  undef XLAT_STR_69
+#  undef XLAT_VAL_69
+#  undef XLAT_STR_70
+#  undef XLAT_VAL_70
+#  undef XLAT_STR_71
+#  undef XLAT_VAL_71
+#  undef XLAT_STR_72
+#  undef XLAT_VAL_72
+#  undef XLAT_STR_73
+#  undef XLAT_VAL_73
+#  undef XLAT_STR_74
+#  undef XLAT_VAL_74
+#  undef XLAT_STR_75
+#  undef XLAT_VAL_75
+#  undef XLAT_STR_76
+#  undef XLAT_VAL_76
+#  undef XLAT_STR_77
+#  undef XLAT_VAL_77
+#  undef XLAT_STR_78
+#  undef XLAT_VAL_78
+#  undef XLAT_STR_79
+#  undef XLAT_VAL_79
+#  undef XLAT_STR_80
+#  undef XLAT_VAL_80
+#  undef XLAT_STR_81
+#  undef XLAT_VAL_81
+#  undef XLAT_STR_82
+#  undef XLAT_VAL_82
+#  undef XLAT_STR_83
+#  undef XLAT_VAL_83
+#  undef XLAT_STR_84
+#  undef XLAT_VAL_84
+#  undef XLAT_STR_85
+#  undef XLAT_VAL_85
+#  undef XLAT_STR_86
+#  undef XLAT_VAL_86
+#  undef XLAT_STR_87
+#  undef XLAT_VAL_87
+#  undef XLAT_STR_88
+#  undef XLAT_VAL_88
+#  undef XLAT_STR_89
+#  undef XLAT_VAL_89
+#  undef XLAT_STR_90
+#  undef XLAT_VAL_90
+#  undef XLAT_STR_91
+#  undef XLAT_VAL_91
+#  undef XLAT_STR_92
+#  undef XLAT_VAL_92
+#  undef XLAT_STR_93
+#  undef XLAT_VAL_93
+#  undef XLAT_STR_94
+#  undef XLAT_VAL_94
+#  undef XLAT_STR_95
+#  undef XLAT_VAL_95
+#  undef XLAT_STR_96
+#  undef XLAT_VAL_96
+#  undef XLAT_STR_97
+#  undef XLAT_VAL_97
+#  undef XLAT_STR_98
+#  undef XLAT_VAL_98
+#  undef XLAT_STR_99
+#  undef XLAT_VAL_99
+#  undef XLAT_STR_100
+#  undef XLAT_VAL_100
+#  undef XLAT_STR_101
+#  undef XLAT_VAL_101
+#  undef XLAT_STR_102
+#  undef XLAT_VAL_102
+#  undef XLAT_STR_103
+#  undef XLAT_VAL_103
+#  undef XLAT_STR_104
+#  undef XLAT_VAL_104
+#  undef XLAT_STR_105
+#  undef XLAT_VAL_105
+#  undef XLAT_STR_106
+#  undef XLAT_VAL_106
+#  undef XLAT_STR_107
+#  undef XLAT_VAL_107
+#  undef XLAT_STR_108
+#  undef XLAT_VAL_108
+#  undef XLAT_STR_109
+#  undef XLAT_VAL_109
+#  undef XLAT_STR_110
+#  undef XLAT_VAL_110
+#  undef XLAT_STR_111
+#  undef XLAT_VAL_111
+#  undef XLAT_STR_112
+#  undef XLAT_VAL_112
+#  undef XLAT_STR_113
+#  undef XLAT_VAL_113
+#  undef XLAT_STR_114
+#  undef XLAT_VAL_114
+#  undef XLAT_STR_115
+#  undef XLAT_VAL_115
+#  undef XLAT_STR_116
+#  undef XLAT_VAL_116
+#  undef XLAT_STR_117
+#  undef XLAT_VAL_117
+#  undef XLAT_STR_118
+#  undef XLAT_VAL_118
+#  undef XLAT_STR_119
+#  undef XLAT_VAL_119
+#  undef XLAT_STR_120
+#  undef XLAT_VAL_120
+#  undef XLAT_STR_121
+#  undef XLAT_VAL_121
+#  undef XLAT_STR_122
+#  undef XLAT_VAL_122
+#  undef XLAT_STR_123
+#  undef XLAT_VAL_123
+#  undef XLAT_STR_124
+#  undef XLAT_VAL_124
+#  undef XLAT_STR_125
+#  undef XLAT_VAL_125
+#  undef XLAT_STR_126
+#  undef XLAT_VAL_126
+#  undef XLAT_STR_127
+#  undef XLAT_VAL_127
+#  undef XLAT_STR_128
+#  undef XLAT_VAL_128
+#  undef XLAT_STR_129
+#  undef XLAT_VAL_129
+#  undef XLAT_STR_130
+#  undef XLAT_VAL_130
+#  undef XLAT_STR_131
+#  undef XLAT_VAL_131
+#  undef XLAT_STR_132
+#  undef XLAT_VAL_132
+#  undef XLAT_STR_133
+#  undef XLAT_VAL_133
+#  undef XLAT_STR_134
+#  undef XLAT_VAL_134
+#  undef XLAT_STR_135
+#  undef XLAT_VAL_135
+#  undef XLAT_STR_136
+#  undef XLAT_VAL_136
+#  undef XLAT_STR_137
+#  undef XLAT_VAL_137
+#  undef XLAT_STR_138
+#  undef XLAT_VAL_138
+#  undef XLAT_STR_139
+#  undef XLAT_VAL_139
+#  undef XLAT_STR_140
+#  undef XLAT_VAL_140
+#  undef XLAT_STR_141
+#  undef XLAT_VAL_141
+#  undef XLAT_STR_142
+#  undef XLAT_VAL_142
+#  undef XLAT_STR_143
+#  undef XLAT_VAL_143
+#  undef XLAT_STR_144
+#  undef XLAT_VAL_144
+#  undef XLAT_STR_145
+#  undef XLAT_VAL_145
+#  undef XLAT_STR_146
+#  undef XLAT_VAL_146
+#  undef XLAT_STR_147
+#  undef XLAT_VAL_147
+#  undef XLAT_STR_148
+#  undef XLAT_VAL_148
+#  undef XLAT_STR_149
+#  undef XLAT_VAL_149
+#  undef XLAT_STR_150
+#  undef XLAT_VAL_150
+#  undef XLAT_STR_151
+#  undef XLAT_VAL_151
+#  undef XLAT_STR_152
+#  undef XLAT_VAL_152
+#  undef XLAT_STR_153
+#  undef XLAT_VAL_153
+#  undef XLAT_STR_154
+#  undef XLAT_VAL_154
+#  undef XLAT_STR_155
+#  undef XLAT_VAL_155
+#  undef XLAT_STR_156
+#  undef XLAT_VAL_156
+#  undef XLAT_STR_157
+#  undef XLAT_VAL_157
+#  undef XLAT_STR_158
+#  undef XLAT_VAL_158
+#  undef XLAT_STR_159
+#  undef XLAT_VAL_159
+#  undef XLAT_STR_160
+#  undef XLAT_VAL_160
+#  undef XLAT_STR_161
+#  undef XLAT_VAL_161
+#  undef XLAT_STR_162
+#  undef XLAT_VAL_162
+#  undef XLAT_STR_163
+#  undef XLAT_VAL_163
+#  undef XLAT_STR_164
+#  undef XLAT_VAL_164
+#  undef XLAT_STR_165
+#  undef XLAT_VAL_165
+#  undef XLAT_STR_166
+#  undef XLAT_VAL_166
+#  undef XLAT_STR_167
+#  undef XLAT_VAL_167
+#  undef XLAT_STR_168
+#  undef XLAT_VAL_168
+#  undef XLAT_STR_169
+#  undef XLAT_VAL_169
+#  undef XLAT_STR_170
+#  undef XLAT_VAL_170
+#  undef XLAT_STR_171
+#  undef XLAT_VAL_171
+#  undef XLAT_STR_172
+#  undef XLAT_VAL_172
+#  undef XLAT_STR_173
+#  undef XLAT_VAL_173
+#  undef XLAT_STR_174
+#  undef XLAT_VAL_174
+#  undef XLAT_STR_175
+#  undef XLAT_VAL_175
+#  undef XLAT_STR_176
+#  undef XLAT_VAL_176
+#  undef XLAT_STR_177
+#  undef XLAT_VAL_177
+#  undef XLAT_STR_178
+#  undef XLAT_VAL_178
+#  undef XLAT_STR_179
+#  undef XLAT_VAL_179
+#  undef XLAT_STR_180
+#  undef XLAT_VAL_180
+#  undef XLAT_STR_181
+#  undef XLAT_VAL_181
+#  undef XLAT_STR_182
+#  undef XLAT_VAL_182
+#  undef XLAT_STR_183
+#  undef XLAT_VAL_183
+#  undef XLAT_STR_184
+#  undef XLAT_VAL_184
+#  undef XLAT_STR_185
+#  undef XLAT_VAL_185
+#  undef XLAT_STR_186
+#  undef XLAT_VAL_186
+#  undef XLAT_STR_187
+#  undef XLAT_VAL_187
+#  undef XLAT_STR_188
+#  undef XLAT_VAL_188
+#  undef XLAT_STR_189
+#  undef XLAT_VAL_189
+#  undef XLAT_STR_190
+#  undef XLAT_VAL_190
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_packet_options.h 5.9-0ubuntu2/xlat/sock_packet_options.h
--- 5.5-3/xlat/sock_packet_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_packet_options.h	2020-09-24 09:18:46.000000000 +0000
@@ -15,66 +15,108 @@
 static const struct xlat_data sock_packet_options_xdata[] = {
 #if defined(PACKET_ADD_MEMBERSHIP) || (defined(HAVE_DECL_PACKET_ADD_MEMBERSHIP) && HAVE_DECL_PACKET_ADD_MEMBERSHIP)
   XLAT(PACKET_ADD_MEMBERSHIP),
+ #define XLAT_VAL_0 ((unsigned) (PACKET_ADD_MEMBERSHIP))
+ #define XLAT_STR_0 STRINGIFY(PACKET_ADD_MEMBERSHIP)
 #endif
 #if defined(PACKET_DROP_MEMBERSHIP) || (defined(HAVE_DECL_PACKET_DROP_MEMBERSHIP) && HAVE_DECL_PACKET_DROP_MEMBERSHIP)
   XLAT(PACKET_DROP_MEMBERSHIP),
+ #define XLAT_VAL_1 ((unsigned) (PACKET_DROP_MEMBERSHIP))
+ #define XLAT_STR_1 STRINGIFY(PACKET_DROP_MEMBERSHIP)
 #endif
 #if defined(PACKET_RECV_OUTPUT) || (defined(HAVE_DECL_PACKET_RECV_OUTPUT) && HAVE_DECL_PACKET_RECV_OUTPUT)
   XLAT(PACKET_RECV_OUTPUT),
+ #define XLAT_VAL_2 ((unsigned) (PACKET_RECV_OUTPUT))
+ #define XLAT_STR_2 STRINGIFY(PACKET_RECV_OUTPUT)
 #endif
 #if defined(PACKET_RX_RING) || (defined(HAVE_DECL_PACKET_RX_RING) && HAVE_DECL_PACKET_RX_RING)
   XLAT(PACKET_RX_RING),
+ #define XLAT_VAL_3 ((unsigned) (PACKET_RX_RING))
+ #define XLAT_STR_3 STRINGIFY(PACKET_RX_RING)
 #endif
 #if defined(PACKET_STATISTICS) || (defined(HAVE_DECL_PACKET_STATISTICS) && HAVE_DECL_PACKET_STATISTICS)
   XLAT(PACKET_STATISTICS),
+ #define XLAT_VAL_4 ((unsigned) (PACKET_STATISTICS))
+ #define XLAT_STR_4 STRINGIFY(PACKET_STATISTICS)
 #endif
 #if defined(PACKET_COPY_THRESH) || (defined(HAVE_DECL_PACKET_COPY_THRESH) && HAVE_DECL_PACKET_COPY_THRESH)
   XLAT(PACKET_COPY_THRESH),
+ #define XLAT_VAL_5 ((unsigned) (PACKET_COPY_THRESH))
+ #define XLAT_STR_5 STRINGIFY(PACKET_COPY_THRESH)
 #endif
 #if defined(PACKET_AUXDATA) || (defined(HAVE_DECL_PACKET_AUXDATA) && HAVE_DECL_PACKET_AUXDATA)
   XLAT(PACKET_AUXDATA),
+ #define XLAT_VAL_6 ((unsigned) (PACKET_AUXDATA))
+ #define XLAT_STR_6 STRINGIFY(PACKET_AUXDATA)
 #endif
 #if defined(PACKET_ORIGDEV) || (defined(HAVE_DECL_PACKET_ORIGDEV) && HAVE_DECL_PACKET_ORIGDEV)
   XLAT(PACKET_ORIGDEV),
+ #define XLAT_VAL_7 ((unsigned) (PACKET_ORIGDEV))
+ #define XLAT_STR_7 STRINGIFY(PACKET_ORIGDEV)
 #endif
 #if defined(PACKET_VERSION) || (defined(HAVE_DECL_PACKET_VERSION) && HAVE_DECL_PACKET_VERSION)
   XLAT(PACKET_VERSION),
+ #define XLAT_VAL_8 ((unsigned) (PACKET_VERSION))
+ #define XLAT_STR_8 STRINGIFY(PACKET_VERSION)
 #endif
 #if defined(PACKET_HDRLEN) || (defined(HAVE_DECL_PACKET_HDRLEN) && HAVE_DECL_PACKET_HDRLEN)
   XLAT(PACKET_HDRLEN),
+ #define XLAT_VAL_9 ((unsigned) (PACKET_HDRLEN))
+ #define XLAT_STR_9 STRINGIFY(PACKET_HDRLEN)
 #endif
 #if defined(PACKET_RESERVE) || (defined(HAVE_DECL_PACKET_RESERVE) && HAVE_DECL_PACKET_RESERVE)
   XLAT(PACKET_RESERVE),
+ #define XLAT_VAL_10 ((unsigned) (PACKET_RESERVE))
+ #define XLAT_STR_10 STRINGIFY(PACKET_RESERVE)
 #endif
 #if defined(PACKET_TX_RING) || (defined(HAVE_DECL_PACKET_TX_RING) && HAVE_DECL_PACKET_TX_RING)
   XLAT(PACKET_TX_RING),
+ #define XLAT_VAL_11 ((unsigned) (PACKET_TX_RING))
+ #define XLAT_STR_11 STRINGIFY(PACKET_TX_RING)
 #endif
 #if defined(PACKET_LOSS) || (defined(HAVE_DECL_PACKET_LOSS) && HAVE_DECL_PACKET_LOSS)
   XLAT(PACKET_LOSS),
+ #define XLAT_VAL_12 ((unsigned) (PACKET_LOSS))
+ #define XLAT_STR_12 STRINGIFY(PACKET_LOSS)
 #endif
 #if defined(PACKET_VNET_HDR) || (defined(HAVE_DECL_PACKET_VNET_HDR) && HAVE_DECL_PACKET_VNET_HDR)
   XLAT(PACKET_VNET_HDR),
+ #define XLAT_VAL_13 ((unsigned) (PACKET_VNET_HDR))
+ #define XLAT_STR_13 STRINGIFY(PACKET_VNET_HDR)
 #endif
 #if defined(PACKET_TX_TIMESTAMP) || (defined(HAVE_DECL_PACKET_TX_TIMESTAMP) && HAVE_DECL_PACKET_TX_TIMESTAMP)
   XLAT(PACKET_TX_TIMESTAMP),
+ #define XLAT_VAL_14 ((unsigned) (PACKET_TX_TIMESTAMP))
+ #define XLAT_STR_14 STRINGIFY(PACKET_TX_TIMESTAMP)
 #endif
 #if defined(PACKET_TIMESTAMP) || (defined(HAVE_DECL_PACKET_TIMESTAMP) && HAVE_DECL_PACKET_TIMESTAMP)
   XLAT(PACKET_TIMESTAMP),
+ #define XLAT_VAL_15 ((unsigned) (PACKET_TIMESTAMP))
+ #define XLAT_STR_15 STRINGIFY(PACKET_TIMESTAMP)
 #endif
 #if defined(PACKET_FANOUT) || (defined(HAVE_DECL_PACKET_FANOUT) && HAVE_DECL_PACKET_FANOUT)
   XLAT(PACKET_FANOUT),
+ #define XLAT_VAL_16 ((unsigned) (PACKET_FANOUT))
+ #define XLAT_STR_16 STRINGIFY(PACKET_FANOUT)
 #endif
 #if defined(PACKET_TX_HAS_OFF) || (defined(HAVE_DECL_PACKET_TX_HAS_OFF) && HAVE_DECL_PACKET_TX_HAS_OFF)
   XLAT(PACKET_TX_HAS_OFF),
+ #define XLAT_VAL_17 ((unsigned) (PACKET_TX_HAS_OFF))
+ #define XLAT_STR_17 STRINGIFY(PACKET_TX_HAS_OFF)
 #endif
 #if defined(PACKET_QDISC_BYPASS) || (defined(HAVE_DECL_PACKET_QDISC_BYPASS) && HAVE_DECL_PACKET_QDISC_BYPASS)
   XLAT(PACKET_QDISC_BYPASS),
+ #define XLAT_VAL_18 ((unsigned) (PACKET_QDISC_BYPASS))
+ #define XLAT_STR_18 STRINGIFY(PACKET_QDISC_BYPASS)
 #endif
 #if defined(PACKET_ROLLOVER_STATS) || (defined(HAVE_DECL_PACKET_ROLLOVER_STATS) && HAVE_DECL_PACKET_ROLLOVER_STATS)
   XLAT(PACKET_ROLLOVER_STATS),
+ #define XLAT_VAL_19 ((unsigned) (PACKET_ROLLOVER_STATS))
+ #define XLAT_STR_19 STRINGIFY(PACKET_ROLLOVER_STATS)
 #endif
 #if defined(PACKET_FANOUT_DATA) || (defined(HAVE_DECL_PACKET_FANOUT_DATA) && HAVE_DECL_PACKET_FANOUT_DATA)
   XLAT(PACKET_FANOUT_DATA),
+ #define XLAT_VAL_20 ((unsigned) (PACKET_FANOUT_DATA))
+ #define XLAT_STR_20 STRINGIFY(PACKET_FANOUT_DATA)
 #endif
 };
 static
@@ -82,8 +124,180 @@ const struct xlat sock_packet_options[1]
  .data = sock_packet_options_xdata,
  .size = ARRAY_SIZE(sock_packet_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_pnp_options.h 5.9-0ubuntu2/xlat/sock_pnp_options.h
--- 5.5-3/xlat/sock_pnp_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_pnp_options.h	2020-09-24 09:18:46.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sock_pnp_options_xdata[] = {
  [PNPIPE_ENCAP] = XLAT(PNPIPE_ENCAP),
+ #define XLAT_VAL_0 ((unsigned) (PNPIPE_ENCAP))
+ #define XLAT_STR_0 STRINGIFY(PNPIPE_ENCAP)
  [PNPIPE_IFINDEX] = XLAT(PNPIPE_IFINDEX),
+ #define XLAT_VAL_1 ((unsigned) (PNPIPE_IFINDEX))
+ #define XLAT_STR_1 STRINGIFY(PNPIPE_IFINDEX)
  [PNPIPE_HANDLE] = XLAT(PNPIPE_HANDLE),
+ #define XLAT_VAL_2 ((unsigned) (PNPIPE_HANDLE))
+ #define XLAT_STR_2 STRINGIFY(PNPIPE_HANDLE)
  [PNPIPE_INITSTATE] = XLAT(PNPIPE_INITSTATE),
+ #define XLAT_VAL_3 ((unsigned) (PNPIPE_INITSTATE))
+ #define XLAT_STR_3 STRINGIFY(PNPIPE_INITSTATE)
 };
 static
 const struct xlat sock_pnp_options[1] = { {
  .data = sock_pnp_options_xdata,
  .size = ARRAY_SIZE(sock_pnp_options_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_pppol2tp_options.h 5.9-0ubuntu2/xlat/sock_pppol2tp_options.h
--- 5.5-3/xlat/sock_pppol2tp_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_pppol2tp_options.h	2020-09-24 09:18:46.000000000 +0000
@@ -49,18 +49,72 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sock_pppol2tp_options_xdata[] = {
  [PPPOL2TP_SO_DEBUG] = XLAT(PPPOL2TP_SO_DEBUG),
+ #define XLAT_VAL_0 ((unsigned) (PPPOL2TP_SO_DEBUG))
+ #define XLAT_STR_0 STRINGIFY(PPPOL2TP_SO_DEBUG)
  [PPPOL2TP_SO_RECVSEQ] = XLAT(PPPOL2TP_SO_RECVSEQ),
+ #define XLAT_VAL_1 ((unsigned) (PPPOL2TP_SO_RECVSEQ))
+ #define XLAT_STR_1 STRINGIFY(PPPOL2TP_SO_RECVSEQ)
  [PPPOL2TP_SO_SENDSEQ] = XLAT(PPPOL2TP_SO_SENDSEQ),
+ #define XLAT_VAL_2 ((unsigned) (PPPOL2TP_SO_SENDSEQ))
+ #define XLAT_STR_2 STRINGIFY(PPPOL2TP_SO_SENDSEQ)
  [PPPOL2TP_SO_LNSMODE] = XLAT(PPPOL2TP_SO_LNSMODE),
+ #define XLAT_VAL_3 ((unsigned) (PPPOL2TP_SO_LNSMODE))
+ #define XLAT_STR_3 STRINGIFY(PPPOL2TP_SO_LNSMODE)
  [PPPOL2TP_SO_REORDERTO] = XLAT(PPPOL2TP_SO_REORDERTO),
+ #define XLAT_VAL_4 ((unsigned) (PPPOL2TP_SO_REORDERTO))
+ #define XLAT_STR_4 STRINGIFY(PPPOL2TP_SO_REORDERTO)
 };
 static
 const struct xlat sock_pppol2tp_options[1] = { {
  .data = sock_pppol2tp_options_xdata,
  .size = ARRAY_SIZE(sock_pppol2tp_options_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_raw_options.h 5.9-0ubuntu2/xlat/sock_raw_options.h
--- 5.5-3/xlat/sock_raw_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_raw_options.h	2020-09-24 09:18:46.000000000 +0000
@@ -15,6 +15,8 @@
 static const struct xlat_data sock_raw_options_xdata[] = {
 #if defined(ICMP_FILTER) || (defined(HAVE_DECL_ICMP_FILTER) && HAVE_DECL_ICMP_FILTER)
   XLAT(ICMP_FILTER),
+ #define XLAT_VAL_0 ((unsigned) (ICMP_FILTER))
+ #define XLAT_STR_0 STRINGIFY(ICMP_FILTER)
 #endif
 };
 static
@@ -22,8 +24,20 @@ const struct xlat sock_raw_options[1] =
  .data = sock_raw_options_xdata,
  .size = ARRAY_SIZE(sock_raw_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_rds_options.h 5.9-0ubuntu2/xlat/sock_rds_options.h
--- 5.5-3/xlat/sock_rds_options.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_rds_options.h	2020-09-24 09:18:46.000000000 +0000
@@ -172,33 +172,77 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sock_rds_options_xdata[] = {
  XLAT(RDS_CANCEL_SENT_TO),
+ #define XLAT_VAL_0 ((unsigned) (RDS_CANCEL_SENT_TO))
+ #define XLAT_STR_0 STRINGIFY(RDS_CANCEL_SENT_TO)
  XLAT(RDS_GET_MR),
+ #define XLAT_VAL_1 ((unsigned) (RDS_GET_MR))
+ #define XLAT_STR_1 STRINGIFY(RDS_GET_MR)
  XLAT(RDS_FREE_MR),
+ #define XLAT_VAL_2 ((unsigned) (RDS_FREE_MR))
+ #define XLAT_STR_2 STRINGIFY(RDS_FREE_MR)
  XLAT(RDS_BARRIER),
+ #define XLAT_VAL_3 ((unsigned) (RDS_BARRIER))
+ #define XLAT_STR_3 STRINGIFY(RDS_BARRIER)
  XLAT(RDS_RECVERR),
+ #define XLAT_VAL_4 ((unsigned) (RDS_RECVERR))
+ #define XLAT_STR_4 STRINGIFY(RDS_RECVERR)
  XLAT(RDS_CONG_MONITOR),
+ #define XLAT_VAL_5 ((unsigned) (RDS_CONG_MONITOR))
+ #define XLAT_STR_5 STRINGIFY(RDS_CONG_MONITOR)
  XLAT(RDS_GET_MR_FOR_DEST),
+ #define XLAT_VAL_6 ((unsigned) (RDS_GET_MR_FOR_DEST))
+ #define XLAT_STR_6 STRINGIFY(RDS_GET_MR_FOR_DEST)
  XLAT(SO_RDS_TRANSPORT),
+ #define XLAT_VAL_7 ((unsigned) (SO_RDS_TRANSPORT))
+ #define XLAT_STR_7 STRINGIFY(SO_RDS_TRANSPORT)
  XLAT(SO_RDS_MSG_RXPATH_LATENCY),
+ #define XLAT_VAL_8 ((unsigned) (SO_RDS_MSG_RXPATH_LATENCY))
+ #define XLAT_STR_8 STRINGIFY(SO_RDS_MSG_RXPATH_LATENCY)
 
 #ifndef __hppa__
  XLAT(SO_TIMESTAMP_OLD),
+ #define XLAT_VAL_9 ((unsigned) (SO_TIMESTAMP_OLD))
+ #define XLAT_STR_9 STRINGIFY(SO_TIMESTAMP_OLD)
 #endif
 
  XLAT(RDS_INFO_COUNTERS),
+ #define XLAT_VAL_10 ((unsigned) (RDS_INFO_COUNTERS))
+ #define XLAT_STR_10 STRINGIFY(RDS_INFO_COUNTERS)
  XLAT(RDS_INFO_CONNECTIONS),
+ #define XLAT_VAL_11 ((unsigned) (RDS_INFO_CONNECTIONS))
+ #define XLAT_STR_11 STRINGIFY(RDS_INFO_CONNECTIONS)
  XLAT(RDS_INFO_FLOWS),
+ #define XLAT_VAL_12 ((unsigned) (RDS_INFO_FLOWS))
+ #define XLAT_STR_12 STRINGIFY(RDS_INFO_FLOWS)
  XLAT(RDS_INFO_SEND_MESSAGES),
+ #define XLAT_VAL_13 ((unsigned) (RDS_INFO_SEND_MESSAGES))
+ #define XLAT_STR_13 STRINGIFY(RDS_INFO_SEND_MESSAGES)
  XLAT(RDS_INFO_RETRANS_MESSAGES),
+ #define XLAT_VAL_14 ((unsigned) (RDS_INFO_RETRANS_MESSAGES))
+ #define XLAT_STR_14 STRINGIFY(RDS_INFO_RETRANS_MESSAGES)
  XLAT(RDS_INFO_RECV_MESSAGES),
+ #define XLAT_VAL_15 ((unsigned) (RDS_INFO_RECV_MESSAGES))
+ #define XLAT_STR_15 STRINGIFY(RDS_INFO_RECV_MESSAGES)
  XLAT(RDS_INFO_SOCKETS),
+ #define XLAT_VAL_16 ((unsigned) (RDS_INFO_SOCKETS))
+ #define XLAT_STR_16 STRINGIFY(RDS_INFO_SOCKETS)
  XLAT(RDS_INFO_TCP_SOCKETS),
+ #define XLAT_VAL_17 ((unsigned) (RDS_INFO_TCP_SOCKETS))
+ #define XLAT_STR_17 STRINGIFY(RDS_INFO_TCP_SOCKETS)
  XLAT(RDS_INFO_IB_CONNECTIONS),
+ #define XLAT_VAL_18 ((unsigned) (RDS_INFO_IB_CONNECTIONS))
+ #define XLAT_STR_18 STRINGIFY(RDS_INFO_IB_CONNECTIONS)
  XLAT(RDS_INFO_CONNECTION_STATS),
+ #define XLAT_VAL_19 ((unsigned) (RDS_INFO_CONNECTION_STATS))
+ #define XLAT_STR_19 STRINGIFY(RDS_INFO_CONNECTION_STATS)
  XLAT(RDS_INFO_IWARP_CONNECTIONS),
+ #define XLAT_VAL_20 ((unsigned) (RDS_INFO_IWARP_CONNECTIONS))
+ #define XLAT_STR_20 STRINGIFY(RDS_INFO_IWARP_CONNECTIONS)
 
 #ifdef __hppa__
  XLAT(SO_TIMESTAMP_OLD),
+ #define XLAT_VAL_21 ((unsigned) (SO_TIMESTAMP_OLD))
+ #define XLAT_STR_21 STRINGIFY(SO_TIMESTAMP_OLD)
 #endif
 };
 static
@@ -206,8 +250,188 @@ const struct xlat sock_rds_options[1] =
  .data = sock_rds_options_xdata,
  .size = ARRAY_SIZE(sock_rds_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_rxrpc_options.h 5.9-0ubuntu2/xlat/sock_rxrpc_options.h
--- 5.5-3/xlat/sock_rxrpc_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_rxrpc_options.h	2020-09-24 09:18:46.000000000 +0000
@@ -56,19 +56,83 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sock_rxrpc_options_xdata[] = {
  [RXRPC_SECURITY_KEY] = XLAT(RXRPC_SECURITY_KEY),
+ #define XLAT_VAL_0 ((unsigned) (RXRPC_SECURITY_KEY))
+ #define XLAT_STR_0 STRINGIFY(RXRPC_SECURITY_KEY)
  [RXRPC_SECURITY_KEYRING] = XLAT(RXRPC_SECURITY_KEYRING),
+ #define XLAT_VAL_1 ((unsigned) (RXRPC_SECURITY_KEYRING))
+ #define XLAT_STR_1 STRINGIFY(RXRPC_SECURITY_KEYRING)
  [RXRPC_EXCLUSIVE_CONNECTION] = XLAT(RXRPC_EXCLUSIVE_CONNECTION),
+ #define XLAT_VAL_2 ((unsigned) (RXRPC_EXCLUSIVE_CONNECTION))
+ #define XLAT_STR_2 STRINGIFY(RXRPC_EXCLUSIVE_CONNECTION)
  [RXRPC_MIN_SECURITY_LEVEL] = XLAT(RXRPC_MIN_SECURITY_LEVEL),
+ #define XLAT_VAL_3 ((unsigned) (RXRPC_MIN_SECURITY_LEVEL))
+ #define XLAT_STR_3 STRINGIFY(RXRPC_MIN_SECURITY_LEVEL)
  [RXRPC_UPGRADEABLE_SERVICE] = XLAT(RXRPC_UPGRADEABLE_SERVICE),
+ #define XLAT_VAL_4 ((unsigned) (RXRPC_UPGRADEABLE_SERVICE))
+ #define XLAT_STR_4 STRINGIFY(RXRPC_UPGRADEABLE_SERVICE)
  [RXRPC_SUPPORTED_CMSG] = XLAT(RXRPC_SUPPORTED_CMSG),
+ #define XLAT_VAL_5 ((unsigned) (RXRPC_SUPPORTED_CMSG))
+ #define XLAT_STR_5 STRINGIFY(RXRPC_SUPPORTED_CMSG)
 };
 static
 const struct xlat sock_rxrpc_options[1] = { {
  .data = sock_rxrpc_options_xdata,
  .size = ARRAY_SIZE(sock_rxrpc_options_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_sctp_options.h 5.9-0ubuntu2/xlat/sock_sctp_options.h
--- 5.5-3/xlat/sock_sctp_options.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_sctp_options.h	2020-09-24 09:18:47.000000000 +0000
@@ -504,84 +504,788 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sock_sctp_options_xdata[] = {
  XLAT(SCTP_RTOINFO),
+ #define XLAT_VAL_0 ((unsigned) (SCTP_RTOINFO))
+ #define XLAT_STR_0 STRINGIFY(SCTP_RTOINFO)
  XLAT(SCTP_ASSOCINFO),
+ #define XLAT_VAL_1 ((unsigned) (SCTP_ASSOCINFO))
+ #define XLAT_STR_1 STRINGIFY(SCTP_ASSOCINFO)
  XLAT(SCTP_INITMSG),
+ #define XLAT_VAL_2 ((unsigned) (SCTP_INITMSG))
+ #define XLAT_STR_2 STRINGIFY(SCTP_INITMSG)
  XLAT(SCTP_NODELAY),
+ #define XLAT_VAL_3 ((unsigned) (SCTP_NODELAY))
+ #define XLAT_STR_3 STRINGIFY(SCTP_NODELAY)
  XLAT(SCTP_AUTOCLOSE),
+ #define XLAT_VAL_4 ((unsigned) (SCTP_AUTOCLOSE))
+ #define XLAT_STR_4 STRINGIFY(SCTP_AUTOCLOSE)
  XLAT(SCTP_SET_PEER_PRIMARY_ADDR),
+ #define XLAT_VAL_5 ((unsigned) (SCTP_SET_PEER_PRIMARY_ADDR))
+ #define XLAT_STR_5 STRINGIFY(SCTP_SET_PEER_PRIMARY_ADDR)
  XLAT(SCTP_PRIMARY_ADDR),
+ #define XLAT_VAL_6 ((unsigned) (SCTP_PRIMARY_ADDR))
+ #define XLAT_STR_6 STRINGIFY(SCTP_PRIMARY_ADDR)
  XLAT(SCTP_ADAPTATION_LAYER),
+ #define XLAT_VAL_7 ((unsigned) (SCTP_ADAPTATION_LAYER))
+ #define XLAT_STR_7 STRINGIFY(SCTP_ADAPTATION_LAYER)
  XLAT(SCTP_DISABLE_FRAGMENTS),
+ #define XLAT_VAL_8 ((unsigned) (SCTP_DISABLE_FRAGMENTS))
+ #define XLAT_STR_8 STRINGIFY(SCTP_DISABLE_FRAGMENTS)
  XLAT(SCTP_PEER_ADDR_PARAMS),
+ #define XLAT_VAL_9 ((unsigned) (SCTP_PEER_ADDR_PARAMS))
+ #define XLAT_STR_9 STRINGIFY(SCTP_PEER_ADDR_PARAMS)
  XLAT(SCTP_DEFAULT_SEND_PARAM),
+ #define XLAT_VAL_10 ((unsigned) (SCTP_DEFAULT_SEND_PARAM))
+ #define XLAT_STR_10 STRINGIFY(SCTP_DEFAULT_SEND_PARAM)
  XLAT(SCTP_EVENTS),
+ #define XLAT_VAL_11 ((unsigned) (SCTP_EVENTS))
+ #define XLAT_STR_11 STRINGIFY(SCTP_EVENTS)
  XLAT(SCTP_I_WANT_MAPPED_V4_ADDR),
+ #define XLAT_VAL_12 ((unsigned) (SCTP_I_WANT_MAPPED_V4_ADDR))
+ #define XLAT_STR_12 STRINGIFY(SCTP_I_WANT_MAPPED_V4_ADDR)
  XLAT(SCTP_MAXSEG),
+ #define XLAT_VAL_13 ((unsigned) (SCTP_MAXSEG))
+ #define XLAT_STR_13 STRINGIFY(SCTP_MAXSEG)
  XLAT(SCTP_STATUS),
+ #define XLAT_VAL_14 ((unsigned) (SCTP_STATUS))
+ #define XLAT_STR_14 STRINGIFY(SCTP_STATUS)
  XLAT(SCTP_GET_PEER_ADDR_INFO),
+ #define XLAT_VAL_15 ((unsigned) (SCTP_GET_PEER_ADDR_INFO))
+ #define XLAT_STR_15 STRINGIFY(SCTP_GET_PEER_ADDR_INFO)
  XLAT(SCTP_DELAYED_SACK),
+ #define XLAT_VAL_16 ((unsigned) (SCTP_DELAYED_SACK))
+ #define XLAT_STR_16 STRINGIFY(SCTP_DELAYED_SACK)
  XLAT(SCTP_CONTEXT),
+ #define XLAT_VAL_17 ((unsigned) (SCTP_CONTEXT))
+ #define XLAT_STR_17 STRINGIFY(SCTP_CONTEXT)
  XLAT(SCTP_FRAGMENT_INTERLEAVE),
+ #define XLAT_VAL_18 ((unsigned) (SCTP_FRAGMENT_INTERLEAVE))
+ #define XLAT_STR_18 STRINGIFY(SCTP_FRAGMENT_INTERLEAVE)
  XLAT(SCTP_PARTIAL_DELIVERY_POINT),
+ #define XLAT_VAL_19 ((unsigned) (SCTP_PARTIAL_DELIVERY_POINT))
+ #define XLAT_STR_19 STRINGIFY(SCTP_PARTIAL_DELIVERY_POINT)
  XLAT(SCTP_MAX_BURST),
+ #define XLAT_VAL_20 ((unsigned) (SCTP_MAX_BURST))
+ #define XLAT_STR_20 STRINGIFY(SCTP_MAX_BURST)
  XLAT(SCTP_AUTH_CHUNK),
+ #define XLAT_VAL_21 ((unsigned) (SCTP_AUTH_CHUNK))
+ #define XLAT_STR_21 STRINGIFY(SCTP_AUTH_CHUNK)
  XLAT(SCTP_HMAC_IDENT),
+ #define XLAT_VAL_22 ((unsigned) (SCTP_HMAC_IDENT))
+ #define XLAT_STR_22 STRINGIFY(SCTP_HMAC_IDENT)
  XLAT(SCTP_AUTH_KEY),
+ #define XLAT_VAL_23 ((unsigned) (SCTP_AUTH_KEY))
+ #define XLAT_STR_23 STRINGIFY(SCTP_AUTH_KEY)
  XLAT(SCTP_AUTH_ACTIVE_KEY),
+ #define XLAT_VAL_24 ((unsigned) (SCTP_AUTH_ACTIVE_KEY))
+ #define XLAT_STR_24 STRINGIFY(SCTP_AUTH_ACTIVE_KEY)
  XLAT(SCTP_AUTH_DELETE_KEY),
+ #define XLAT_VAL_25 ((unsigned) (SCTP_AUTH_DELETE_KEY))
+ #define XLAT_STR_25 STRINGIFY(SCTP_AUTH_DELETE_KEY)
  XLAT(SCTP_PEER_AUTH_CHUNKS),
+ #define XLAT_VAL_26 ((unsigned) (SCTP_PEER_AUTH_CHUNKS))
+ #define XLAT_STR_26 STRINGIFY(SCTP_PEER_AUTH_CHUNKS)
  XLAT(SCTP_LOCAL_AUTH_CHUNKS),
+ #define XLAT_VAL_27 ((unsigned) (SCTP_LOCAL_AUTH_CHUNKS))
+ #define XLAT_STR_27 STRINGIFY(SCTP_LOCAL_AUTH_CHUNKS)
  XLAT(SCTP_GET_ASSOC_NUMBER),
+ #define XLAT_VAL_28 ((unsigned) (SCTP_GET_ASSOC_NUMBER))
+ #define XLAT_STR_28 STRINGIFY(SCTP_GET_ASSOC_NUMBER)
  XLAT(SCTP_GET_ASSOC_ID_LIST),
+ #define XLAT_VAL_29 ((unsigned) (SCTP_GET_ASSOC_ID_LIST))
+ #define XLAT_STR_29 STRINGIFY(SCTP_GET_ASSOC_ID_LIST)
  XLAT(SCTP_AUTO_ASCONF),
+ #define XLAT_VAL_30 ((unsigned) (SCTP_AUTO_ASCONF))
+ #define XLAT_STR_30 STRINGIFY(SCTP_AUTO_ASCONF)
  XLAT(SCTP_PEER_ADDR_THLDS),
+ #define XLAT_VAL_31 ((unsigned) (SCTP_PEER_ADDR_THLDS))
+ #define XLAT_STR_31 STRINGIFY(SCTP_PEER_ADDR_THLDS)
  XLAT(SCTP_RECVRCVINFO),
+ #define XLAT_VAL_32 ((unsigned) (SCTP_RECVRCVINFO))
+ #define XLAT_STR_32 STRINGIFY(SCTP_RECVRCVINFO)
  XLAT(SCTP_RECVNXTINFO),
+ #define XLAT_VAL_33 ((unsigned) (SCTP_RECVNXTINFO))
+ #define XLAT_STR_33 STRINGIFY(SCTP_RECVNXTINFO)
  XLAT(SCTP_DEFAULT_SNDINFO),
+ #define XLAT_VAL_34 ((unsigned) (SCTP_DEFAULT_SNDINFO))
+ #define XLAT_STR_34 STRINGIFY(SCTP_DEFAULT_SNDINFO)
  XLAT(SCTP_AUTH_DEACTIVATE_KEY),
+ #define XLAT_VAL_35 ((unsigned) (SCTP_AUTH_DEACTIVATE_KEY))
+ #define XLAT_STR_35 STRINGIFY(SCTP_AUTH_DEACTIVATE_KEY)
  XLAT(SCTP_REUSE_PORT),
+ #define XLAT_VAL_36 ((unsigned) (SCTP_REUSE_PORT))
+ #define XLAT_STR_36 STRINGIFY(SCTP_REUSE_PORT)
  XLAT(SCTP_PEER_ADDR_THLDS_V2),
+ #define XLAT_VAL_37 ((unsigned) (SCTP_PEER_ADDR_THLDS_V2))
+ #define XLAT_STR_37 STRINGIFY(SCTP_PEER_ADDR_THLDS_V2)
 
  XLAT(SCTP_SOCKOPT_BINDX_ADD),
+ #define XLAT_VAL_38 ((unsigned) (SCTP_SOCKOPT_BINDX_ADD))
+ #define XLAT_STR_38 STRINGIFY(SCTP_SOCKOPT_BINDX_ADD)
  XLAT(SCTP_SOCKOPT_BINDX_REM),
+ #define XLAT_VAL_39 ((unsigned) (SCTP_SOCKOPT_BINDX_REM))
+ #define XLAT_STR_39 STRINGIFY(SCTP_SOCKOPT_BINDX_REM)
  XLAT(SCTP_SOCKOPT_PEELOFF),
+ #define XLAT_VAL_40 ((unsigned) (SCTP_SOCKOPT_PEELOFF))
+ #define XLAT_STR_40 STRINGIFY(SCTP_SOCKOPT_PEELOFF)
  XLAT(SCTP_GET_PEER_ADDRS_NUM_OLD),
+ #define XLAT_VAL_41 ((unsigned) (SCTP_GET_PEER_ADDRS_NUM_OLD))
+ #define XLAT_STR_41 STRINGIFY(SCTP_GET_PEER_ADDRS_NUM_OLD)
  XLAT(SCTP_GET_PEER_ADDRS_OLD),
+ #define XLAT_VAL_42 ((unsigned) (SCTP_GET_PEER_ADDRS_OLD))
+ #define XLAT_STR_42 STRINGIFY(SCTP_GET_PEER_ADDRS_OLD)
  XLAT(SCTP_GET_LOCAL_ADDRS_NUM_OLD),
+ #define XLAT_VAL_43 ((unsigned) (SCTP_GET_LOCAL_ADDRS_NUM_OLD))
+ #define XLAT_STR_43 STRINGIFY(SCTP_GET_LOCAL_ADDRS_NUM_OLD)
  XLAT(SCTP_GET_LOCAL_ADDRS_OLD),
+ #define XLAT_VAL_44 ((unsigned) (SCTP_GET_LOCAL_ADDRS_OLD))
+ #define XLAT_STR_44 STRINGIFY(SCTP_GET_LOCAL_ADDRS_OLD)
  XLAT(SCTP_SOCKOPT_CONNECTX_OLD),
+ #define XLAT_VAL_45 ((unsigned) (SCTP_SOCKOPT_CONNECTX_OLD))
+ #define XLAT_STR_45 STRINGIFY(SCTP_SOCKOPT_CONNECTX_OLD)
  XLAT(SCTP_GET_PEER_ADDRS),
+ #define XLAT_VAL_46 ((unsigned) (SCTP_GET_PEER_ADDRS))
+ #define XLAT_STR_46 STRINGIFY(SCTP_GET_PEER_ADDRS)
  XLAT(SCTP_GET_LOCAL_ADDRS),
+ #define XLAT_VAL_47 ((unsigned) (SCTP_GET_LOCAL_ADDRS))
+ #define XLAT_STR_47 STRINGIFY(SCTP_GET_LOCAL_ADDRS)
  XLAT(SCTP_SOCKOPT_CONNECTX),
+ #define XLAT_VAL_48 ((unsigned) (SCTP_SOCKOPT_CONNECTX))
+ #define XLAT_STR_48 STRINGIFY(SCTP_SOCKOPT_CONNECTX)
  XLAT(SCTP_SOCKOPT_CONNECTX3),
+ #define XLAT_VAL_49 ((unsigned) (SCTP_SOCKOPT_CONNECTX3))
+ #define XLAT_STR_49 STRINGIFY(SCTP_SOCKOPT_CONNECTX3)
  XLAT(SCTP_GET_ASSOC_STATS),
+ #define XLAT_VAL_50 ((unsigned) (SCTP_GET_ASSOC_STATS))
+ #define XLAT_STR_50 STRINGIFY(SCTP_GET_ASSOC_STATS)
  XLAT(SCTP_PR_SUPPORTED),
+ #define XLAT_VAL_51 ((unsigned) (SCTP_PR_SUPPORTED))
+ #define XLAT_STR_51 STRINGIFY(SCTP_PR_SUPPORTED)
  XLAT(SCTP_DEFAULT_PRINFO),
+ #define XLAT_VAL_52 ((unsigned) (SCTP_DEFAULT_PRINFO))
+ #define XLAT_STR_52 STRINGIFY(SCTP_DEFAULT_PRINFO)
  XLAT(SCTP_PR_ASSOC_STATUS),
+ #define XLAT_VAL_53 ((unsigned) (SCTP_PR_ASSOC_STATUS))
+ #define XLAT_STR_53 STRINGIFY(SCTP_PR_ASSOC_STATUS)
  XLAT(SCTP_PR_STREAM_STATUS),
+ #define XLAT_VAL_54 ((unsigned) (SCTP_PR_STREAM_STATUS))
+ #define XLAT_STR_54 STRINGIFY(SCTP_PR_STREAM_STATUS)
  XLAT(SCTP_RECONFIG_SUPPORTED),
+ #define XLAT_VAL_55 ((unsigned) (SCTP_RECONFIG_SUPPORTED))
+ #define XLAT_STR_55 STRINGIFY(SCTP_RECONFIG_SUPPORTED)
  XLAT(SCTP_ENABLE_STREAM_RESET),
+ #define XLAT_VAL_56 ((unsigned) (SCTP_ENABLE_STREAM_RESET))
+ #define XLAT_STR_56 STRINGIFY(SCTP_ENABLE_STREAM_RESET)
  XLAT(SCTP_RESET_STREAMS),
+ #define XLAT_VAL_57 ((unsigned) (SCTP_RESET_STREAMS))
+ #define XLAT_STR_57 STRINGIFY(SCTP_RESET_STREAMS)
  XLAT(SCTP_RESET_ASSOC),
+ #define XLAT_VAL_58 ((unsigned) (SCTP_RESET_ASSOC))
+ #define XLAT_STR_58 STRINGIFY(SCTP_RESET_ASSOC)
  XLAT(SCTP_ADD_STREAMS),
+ #define XLAT_VAL_59 ((unsigned) (SCTP_ADD_STREAMS))
+ #define XLAT_STR_59 STRINGIFY(SCTP_ADD_STREAMS)
  XLAT(SCTP_SOCKOPT_PEELOFF_FLAGS),
+ #define XLAT_VAL_60 ((unsigned) (SCTP_SOCKOPT_PEELOFF_FLAGS))
+ #define XLAT_STR_60 STRINGIFY(SCTP_SOCKOPT_PEELOFF_FLAGS)
  XLAT(SCTP_STREAM_SCHEDULER),
+ #define XLAT_VAL_61 ((unsigned) (SCTP_STREAM_SCHEDULER))
+ #define XLAT_STR_61 STRINGIFY(SCTP_STREAM_SCHEDULER)
  XLAT(SCTP_STREAM_SCHEDULER_VALUE),
+ #define XLAT_VAL_62 ((unsigned) (SCTP_STREAM_SCHEDULER_VALUE))
+ #define XLAT_STR_62 STRINGIFY(SCTP_STREAM_SCHEDULER_VALUE)
  XLAT(SCTP_INTERLEAVING_SUPPORTED),
+ #define XLAT_VAL_63 ((unsigned) (SCTP_INTERLEAVING_SUPPORTED))
+ #define XLAT_STR_63 STRINGIFY(SCTP_INTERLEAVING_SUPPORTED)
  XLAT(SCTP_SENDMSG_CONNECT),
+ #define XLAT_VAL_64 ((unsigned) (SCTP_SENDMSG_CONNECT))
+ #define XLAT_STR_64 STRINGIFY(SCTP_SENDMSG_CONNECT)
  XLAT(SCTP_EVENT),
+ #define XLAT_VAL_65 ((unsigned) (SCTP_EVENT))
+ #define XLAT_STR_65 STRINGIFY(SCTP_EVENT)
  XLAT(SCTP_ASCONF_SUPPORTED),
+ #define XLAT_VAL_66 ((unsigned) (SCTP_ASCONF_SUPPORTED))
+ #define XLAT_STR_66 STRINGIFY(SCTP_ASCONF_SUPPORTED)
  XLAT(SCTP_AUTH_SUPPORTED),
+ #define XLAT_VAL_67 ((unsigned) (SCTP_AUTH_SUPPORTED))
+ #define XLAT_STR_67 STRINGIFY(SCTP_AUTH_SUPPORTED)
  XLAT(SCTP_ECN_SUPPORTED),
+ #define XLAT_VAL_68 ((unsigned) (SCTP_ECN_SUPPORTED))
+ #define XLAT_STR_68 STRINGIFY(SCTP_ECN_SUPPORTED)
  XLAT(SCTP_EXPOSE_POTENTIALLY_FAILED_STATE),
+ #define XLAT_VAL_69 ((unsigned) (SCTP_EXPOSE_POTENTIALLY_FAILED_STATE))
+ #define XLAT_STR_69 STRINGIFY(SCTP_EXPOSE_POTENTIALLY_FAILED_STATE)
 };
 static
 const struct xlat sock_sctp_options[1] = { {
  .data = sock_sctp_options_xdata,
  .size = ARRAY_SIZE(sock_sctp_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+#  ifdef XLAT_VAL_47
+  | XLAT_VAL_47
+#  endif
+#  ifdef XLAT_VAL_48
+  | XLAT_VAL_48
+#  endif
+#  ifdef XLAT_VAL_49
+  | XLAT_VAL_49
+#  endif
+#  ifdef XLAT_VAL_50
+  | XLAT_VAL_50
+#  endif
+#  ifdef XLAT_VAL_51
+  | XLAT_VAL_51
+#  endif
+#  ifdef XLAT_VAL_52
+  | XLAT_VAL_52
+#  endif
+#  ifdef XLAT_VAL_53
+  | XLAT_VAL_53
+#  endif
+#  ifdef XLAT_VAL_54
+  | XLAT_VAL_54
+#  endif
+#  ifdef XLAT_VAL_55
+  | XLAT_VAL_55
+#  endif
+#  ifdef XLAT_VAL_56
+  | XLAT_VAL_56
+#  endif
+#  ifdef XLAT_VAL_57
+  | XLAT_VAL_57
+#  endif
+#  ifdef XLAT_VAL_58
+  | XLAT_VAL_58
+#  endif
+#  ifdef XLAT_VAL_59
+  | XLAT_VAL_59
+#  endif
+#  ifdef XLAT_VAL_60
+  | XLAT_VAL_60
+#  endif
+#  ifdef XLAT_VAL_61
+  | XLAT_VAL_61
+#  endif
+#  ifdef XLAT_VAL_62
+  | XLAT_VAL_62
+#  endif
+#  ifdef XLAT_VAL_63
+  | XLAT_VAL_63
+#  endif
+#  ifdef XLAT_VAL_64
+  | XLAT_VAL_64
+#  endif
+#  ifdef XLAT_VAL_65
+  | XLAT_VAL_65
+#  endif
+#  ifdef XLAT_VAL_66
+  | XLAT_VAL_66
+#  endif
+#  ifdef XLAT_VAL_67
+  | XLAT_VAL_67
+#  endif
+#  ifdef XLAT_VAL_68
+  | XLAT_VAL_68
+#  endif
+#  ifdef XLAT_VAL_69
+  | XLAT_VAL_69
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+#  ifdef XLAT_STR_47
+  + sizeof(XLAT_STR_47)
+#  endif
+#  ifdef XLAT_STR_48
+  + sizeof(XLAT_STR_48)
+#  endif
+#  ifdef XLAT_STR_49
+  + sizeof(XLAT_STR_49)
+#  endif
+#  ifdef XLAT_STR_50
+  + sizeof(XLAT_STR_50)
+#  endif
+#  ifdef XLAT_STR_51
+  + sizeof(XLAT_STR_51)
+#  endif
+#  ifdef XLAT_STR_52
+  + sizeof(XLAT_STR_52)
+#  endif
+#  ifdef XLAT_STR_53
+  + sizeof(XLAT_STR_53)
+#  endif
+#  ifdef XLAT_STR_54
+  + sizeof(XLAT_STR_54)
+#  endif
+#  ifdef XLAT_STR_55
+  + sizeof(XLAT_STR_55)
+#  endif
+#  ifdef XLAT_STR_56
+  + sizeof(XLAT_STR_56)
+#  endif
+#  ifdef XLAT_STR_57
+  + sizeof(XLAT_STR_57)
+#  endif
+#  ifdef XLAT_STR_58
+  + sizeof(XLAT_STR_58)
+#  endif
+#  ifdef XLAT_STR_59
+  + sizeof(XLAT_STR_59)
+#  endif
+#  ifdef XLAT_STR_60
+  + sizeof(XLAT_STR_60)
+#  endif
+#  ifdef XLAT_STR_61
+  + sizeof(XLAT_STR_61)
+#  endif
+#  ifdef XLAT_STR_62
+  + sizeof(XLAT_STR_62)
+#  endif
+#  ifdef XLAT_STR_63
+  + sizeof(XLAT_STR_63)
+#  endif
+#  ifdef XLAT_STR_64
+  + sizeof(XLAT_STR_64)
+#  endif
+#  ifdef XLAT_STR_65
+  + sizeof(XLAT_STR_65)
+#  endif
+#  ifdef XLAT_STR_66
+  + sizeof(XLAT_STR_66)
+#  endif
+#  ifdef XLAT_STR_67
+  + sizeof(XLAT_STR_67)
+#  endif
+#  ifdef XLAT_STR_68
+  + sizeof(XLAT_STR_68)
+#  endif
+#  ifdef XLAT_STR_69
+  + sizeof(XLAT_STR_69)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
+#  undef XLAT_STR_47
+#  undef XLAT_VAL_47
+#  undef XLAT_STR_48
+#  undef XLAT_VAL_48
+#  undef XLAT_STR_49
+#  undef XLAT_VAL_49
+#  undef XLAT_STR_50
+#  undef XLAT_VAL_50
+#  undef XLAT_STR_51
+#  undef XLAT_VAL_51
+#  undef XLAT_STR_52
+#  undef XLAT_VAL_52
+#  undef XLAT_STR_53
+#  undef XLAT_VAL_53
+#  undef XLAT_STR_54
+#  undef XLAT_VAL_54
+#  undef XLAT_STR_55
+#  undef XLAT_VAL_55
+#  undef XLAT_STR_56
+#  undef XLAT_VAL_56
+#  undef XLAT_STR_57
+#  undef XLAT_VAL_57
+#  undef XLAT_STR_58
+#  undef XLAT_VAL_58
+#  undef XLAT_STR_59
+#  undef XLAT_VAL_59
+#  undef XLAT_STR_60
+#  undef XLAT_VAL_60
+#  undef XLAT_STR_61
+#  undef XLAT_VAL_61
+#  undef XLAT_STR_62
+#  undef XLAT_VAL_62
+#  undef XLAT_STR_63
+#  undef XLAT_VAL_63
+#  undef XLAT_STR_64
+#  undef XLAT_VAL_64
+#  undef XLAT_STR_65
+#  undef XLAT_VAL_65
+#  undef XLAT_STR_66
+#  undef XLAT_VAL_66
+#  undef XLAT_STR_67
+#  undef XLAT_VAL_67
+#  undef XLAT_STR_68
+#  undef XLAT_VAL_68
+#  undef XLAT_STR_69
+#  undef XLAT_VAL_69
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_shutdown_flags.h 5.9-0ubuntu2/xlat/sock_shutdown_flags.h
--- 5.5-3/xlat/sock_shutdown_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_shutdown_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sock_shutdown_flags_xdata[] = {
  XLAT(RCV_SHUTDOWN),
+ #define XLAT_VAL_0 ((unsigned) (RCV_SHUTDOWN))
+ #define XLAT_STR_0 STRINGIFY(RCV_SHUTDOWN)
  XLAT(SEND_SHUTDOWN),
+ #define XLAT_VAL_1 ((unsigned) (SEND_SHUTDOWN))
+ #define XLAT_STR_1 STRINGIFY(SEND_SHUTDOWN)
 };
 static
 const struct xlat sock_shutdown_flags[1] = { {
  .data = sock_shutdown_flags_xdata,
  .size = ARRAY_SIZE(sock_shutdown_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_tcp_options.h 5.9-0ubuntu2/xlat/sock_tcp_options.h
--- 5.5-3/xlat/sock_tcp_options.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_tcp_options.h	2020-09-24 09:18:46.000000000 +0000
@@ -273,50 +273,424 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sock_tcp_options_xdata[] = {
  [TCP_NODELAY] = XLAT(TCP_NODELAY),
+ #define XLAT_VAL_0 ((unsigned) (TCP_NODELAY))
+ #define XLAT_STR_0 STRINGIFY(TCP_NODELAY)
  [TCP_MAXSEG] = XLAT(TCP_MAXSEG),
+ #define XLAT_VAL_1 ((unsigned) (TCP_MAXSEG))
+ #define XLAT_STR_1 STRINGIFY(TCP_MAXSEG)
  [TCP_CORK] = XLAT(TCP_CORK),
+ #define XLAT_VAL_2 ((unsigned) (TCP_CORK))
+ #define XLAT_STR_2 STRINGIFY(TCP_CORK)
  [TCP_KEEPIDLE] = XLAT(TCP_KEEPIDLE),
+ #define XLAT_VAL_3 ((unsigned) (TCP_KEEPIDLE))
+ #define XLAT_STR_3 STRINGIFY(TCP_KEEPIDLE)
  [TCP_KEEPINTVL] = XLAT(TCP_KEEPINTVL),
+ #define XLAT_VAL_4 ((unsigned) (TCP_KEEPINTVL))
+ #define XLAT_STR_4 STRINGIFY(TCP_KEEPINTVL)
  [TCP_KEEPCNT] = XLAT(TCP_KEEPCNT),
+ #define XLAT_VAL_5 ((unsigned) (TCP_KEEPCNT))
+ #define XLAT_STR_5 STRINGIFY(TCP_KEEPCNT)
  [TCP_SYNCNT] = XLAT(TCP_SYNCNT),
+ #define XLAT_VAL_6 ((unsigned) (TCP_SYNCNT))
+ #define XLAT_STR_6 STRINGIFY(TCP_SYNCNT)
  [TCP_LINGER2] = XLAT(TCP_LINGER2),
+ #define XLAT_VAL_7 ((unsigned) (TCP_LINGER2))
+ #define XLAT_STR_7 STRINGIFY(TCP_LINGER2)
  [TCP_DEFER_ACCEPT] = XLAT(TCP_DEFER_ACCEPT),
+ #define XLAT_VAL_8 ((unsigned) (TCP_DEFER_ACCEPT))
+ #define XLAT_STR_8 STRINGIFY(TCP_DEFER_ACCEPT)
  [TCP_WINDOW_CLAMP] = XLAT(TCP_WINDOW_CLAMP),
+ #define XLAT_VAL_9 ((unsigned) (TCP_WINDOW_CLAMP))
+ #define XLAT_STR_9 STRINGIFY(TCP_WINDOW_CLAMP)
  [TCP_INFO] = XLAT(TCP_INFO),
+ #define XLAT_VAL_10 ((unsigned) (TCP_INFO))
+ #define XLAT_STR_10 STRINGIFY(TCP_INFO)
  [TCP_QUICKACK] = XLAT(TCP_QUICKACK),
+ #define XLAT_VAL_11 ((unsigned) (TCP_QUICKACK))
+ #define XLAT_STR_11 STRINGIFY(TCP_QUICKACK)
  [TCP_CONGESTION] = XLAT(TCP_CONGESTION),
+ #define XLAT_VAL_12 ((unsigned) (TCP_CONGESTION))
+ #define XLAT_STR_12 STRINGIFY(TCP_CONGESTION)
  [TCP_MD5SIG] = XLAT(TCP_MD5SIG),
+ #define XLAT_VAL_13 ((unsigned) (TCP_MD5SIG))
+ #define XLAT_STR_13 STRINGIFY(TCP_MD5SIG)
  [TCP_COOKIE_TRANSACTIONS] = XLAT(TCP_COOKIE_TRANSACTIONS),
+ #define XLAT_VAL_14 ((unsigned) (TCP_COOKIE_TRANSACTIONS))
+ #define XLAT_STR_14 STRINGIFY(TCP_COOKIE_TRANSACTIONS)
  [TCP_THIN_LINEAR_TIMEOUTS] = XLAT(TCP_THIN_LINEAR_TIMEOUTS),
+ #define XLAT_VAL_15 ((unsigned) (TCP_THIN_LINEAR_TIMEOUTS))
+ #define XLAT_STR_15 STRINGIFY(TCP_THIN_LINEAR_TIMEOUTS)
  [TCP_THIN_DUPACK] = XLAT(TCP_THIN_DUPACK),
+ #define XLAT_VAL_16 ((unsigned) (TCP_THIN_DUPACK))
+ #define XLAT_STR_16 STRINGIFY(TCP_THIN_DUPACK)
  [TCP_USER_TIMEOUT] = XLAT(TCP_USER_TIMEOUT),
+ #define XLAT_VAL_17 ((unsigned) (TCP_USER_TIMEOUT))
+ #define XLAT_STR_17 STRINGIFY(TCP_USER_TIMEOUT)
  [TCP_REPAIR] = XLAT(TCP_REPAIR),
+ #define XLAT_VAL_18 ((unsigned) (TCP_REPAIR))
+ #define XLAT_STR_18 STRINGIFY(TCP_REPAIR)
  [TCP_REPAIR_QUEUE] = XLAT(TCP_REPAIR_QUEUE),
+ #define XLAT_VAL_19 ((unsigned) (TCP_REPAIR_QUEUE))
+ #define XLAT_STR_19 STRINGIFY(TCP_REPAIR_QUEUE)
  [TCP_QUEUE_SEQ] = XLAT(TCP_QUEUE_SEQ),
+ #define XLAT_VAL_20 ((unsigned) (TCP_QUEUE_SEQ))
+ #define XLAT_STR_20 STRINGIFY(TCP_QUEUE_SEQ)
  [TCP_REPAIR_OPTIONS] = XLAT(TCP_REPAIR_OPTIONS),
+ #define XLAT_VAL_21 ((unsigned) (TCP_REPAIR_OPTIONS))
+ #define XLAT_STR_21 STRINGIFY(TCP_REPAIR_OPTIONS)
  [TCP_FASTOPEN] = XLAT(TCP_FASTOPEN),
+ #define XLAT_VAL_22 ((unsigned) (TCP_FASTOPEN))
+ #define XLAT_STR_22 STRINGIFY(TCP_FASTOPEN)
  [TCP_TIMESTAMP] = XLAT(TCP_TIMESTAMP),
+ #define XLAT_VAL_23 ((unsigned) (TCP_TIMESTAMP))
+ #define XLAT_STR_23 STRINGIFY(TCP_TIMESTAMP)
  [TCP_NOTSENT_LOWAT] = XLAT(TCP_NOTSENT_LOWAT),
+ #define XLAT_VAL_24 ((unsigned) (TCP_NOTSENT_LOWAT))
+ #define XLAT_STR_24 STRINGIFY(TCP_NOTSENT_LOWAT)
  [TCP_CC_INFO] = XLAT(TCP_CC_INFO),
+ #define XLAT_VAL_25 ((unsigned) (TCP_CC_INFO))
+ #define XLAT_STR_25 STRINGIFY(TCP_CC_INFO)
  [TCP_SAVE_SYN] = XLAT(TCP_SAVE_SYN),
+ #define XLAT_VAL_26 ((unsigned) (TCP_SAVE_SYN))
+ #define XLAT_STR_26 STRINGIFY(TCP_SAVE_SYN)
  [TCP_SAVED_SYN] = XLAT(TCP_SAVED_SYN),
+ #define XLAT_VAL_27 ((unsigned) (TCP_SAVED_SYN))
+ #define XLAT_STR_27 STRINGIFY(TCP_SAVED_SYN)
  [TCP_REPAIR_WINDOW] = XLAT(TCP_REPAIR_WINDOW),
+ #define XLAT_VAL_28 ((unsigned) (TCP_REPAIR_WINDOW))
+ #define XLAT_STR_28 STRINGIFY(TCP_REPAIR_WINDOW)
  [TCP_FASTOPEN_CONNECT] = XLAT(TCP_FASTOPEN_CONNECT),
+ #define XLAT_VAL_29 ((unsigned) (TCP_FASTOPEN_CONNECT))
+ #define XLAT_STR_29 STRINGIFY(TCP_FASTOPEN_CONNECT)
  [TCP_ULP] = XLAT(TCP_ULP),
+ #define XLAT_VAL_30 ((unsigned) (TCP_ULP))
+ #define XLAT_STR_30 STRINGIFY(TCP_ULP)
  [TCP_MD5SIG_EXT] = XLAT(TCP_MD5SIG_EXT),
+ #define XLAT_VAL_31 ((unsigned) (TCP_MD5SIG_EXT))
+ #define XLAT_STR_31 STRINGIFY(TCP_MD5SIG_EXT)
  [TCP_FASTOPEN_KEY] = XLAT(TCP_FASTOPEN_KEY),
+ #define XLAT_VAL_32 ((unsigned) (TCP_FASTOPEN_KEY))
+ #define XLAT_STR_32 STRINGIFY(TCP_FASTOPEN_KEY)
  [TCP_FASTOPEN_NO_COOKIE] = XLAT(TCP_FASTOPEN_NO_COOKIE),
+ #define XLAT_VAL_33 ((unsigned) (TCP_FASTOPEN_NO_COOKIE))
+ #define XLAT_STR_33 STRINGIFY(TCP_FASTOPEN_NO_COOKIE)
  [TCP_ZEROCOPY_RECEIVE] = XLAT(TCP_ZEROCOPY_RECEIVE),
+ #define XLAT_VAL_34 ((unsigned) (TCP_ZEROCOPY_RECEIVE))
+ #define XLAT_STR_34 STRINGIFY(TCP_ZEROCOPY_RECEIVE)
  [TCP_INQ] = XLAT(TCP_INQ),
+ #define XLAT_VAL_35 ((unsigned) (TCP_INQ))
+ #define XLAT_STR_35 STRINGIFY(TCP_INQ)
  [TCP_TX_DELAY] = XLAT(TCP_TX_DELAY),
+ #define XLAT_VAL_36 ((unsigned) (TCP_TX_DELAY))
+ #define XLAT_STR_36 STRINGIFY(TCP_TX_DELAY)
 };
 static
 const struct xlat sock_tcp_options[1] = { {
  .data = sock_tcp_options_xdata,
  .size = ARRAY_SIZE(sock_tcp_options_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_tipc_options.h 5.9-0ubuntu2/xlat/sock_tipc_options.h
--- 5.5-3/xlat/sock_tipc_options.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_tipc_options.h	2020-09-24 09:18:46.000000000 +0000
@@ -98,25 +98,149 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sock_tipc_options_xdata[] = {
  XLAT(TIPC_IMPORTANCE),
+ #define XLAT_VAL_0 ((unsigned) (TIPC_IMPORTANCE))
+ #define XLAT_STR_0 STRINGIFY(TIPC_IMPORTANCE)
  XLAT(TIPC_SRC_DROPPABLE),
+ #define XLAT_VAL_1 ((unsigned) (TIPC_SRC_DROPPABLE))
+ #define XLAT_STR_1 STRINGIFY(TIPC_SRC_DROPPABLE)
  XLAT(TIPC_DEST_DROPPABLE),
+ #define XLAT_VAL_2 ((unsigned) (TIPC_DEST_DROPPABLE))
+ #define XLAT_STR_2 STRINGIFY(TIPC_DEST_DROPPABLE)
  XLAT(TIPC_CONN_TIMEOUT),
+ #define XLAT_VAL_3 ((unsigned) (TIPC_CONN_TIMEOUT))
+ #define XLAT_STR_3 STRINGIFY(TIPC_CONN_TIMEOUT)
  XLAT(TIPC_NODE_RECVQ_DEPTH),
+ #define XLAT_VAL_4 ((unsigned) (TIPC_NODE_RECVQ_DEPTH))
+ #define XLAT_STR_4 STRINGIFY(TIPC_NODE_RECVQ_DEPTH)
  XLAT(TIPC_SOCK_RECVQ_DEPTH),
+ #define XLAT_VAL_5 ((unsigned) (TIPC_SOCK_RECVQ_DEPTH))
+ #define XLAT_STR_5 STRINGIFY(TIPC_SOCK_RECVQ_DEPTH)
  XLAT(TIPC_MCAST_BROADCAST),
+ #define XLAT_VAL_6 ((unsigned) (TIPC_MCAST_BROADCAST))
+ #define XLAT_STR_6 STRINGIFY(TIPC_MCAST_BROADCAST)
  XLAT(TIPC_MCAST_REPLICAST),
+ #define XLAT_VAL_7 ((unsigned) (TIPC_MCAST_REPLICAST))
+ #define XLAT_STR_7 STRINGIFY(TIPC_MCAST_REPLICAST)
  XLAT(TIPC_GROUP_JOIN),
+ #define XLAT_VAL_8 ((unsigned) (TIPC_GROUP_JOIN))
+ #define XLAT_STR_8 STRINGIFY(TIPC_GROUP_JOIN)
  XLAT(TIPC_GROUP_LEAVE),
+ #define XLAT_VAL_9 ((unsigned) (TIPC_GROUP_LEAVE))
+ #define XLAT_STR_9 STRINGIFY(TIPC_GROUP_LEAVE)
  XLAT(TIPC_SOCK_RECVQ_USED),
+ #define XLAT_VAL_10 ((unsigned) (TIPC_SOCK_RECVQ_USED))
+ #define XLAT_STR_10 STRINGIFY(TIPC_SOCK_RECVQ_USED)
  XLAT(TIPC_NODELAY),
+ #define XLAT_VAL_11 ((unsigned) (TIPC_NODELAY))
+ #define XLAT_STR_11 STRINGIFY(TIPC_NODELAY)
 };
 static
 const struct xlat sock_tipc_options[1] = { {
  .data = sock_tipc_options_xdata,
  .size = ARRAY_SIZE(sock_tipc_options_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_tls_options.h 5.9-0ubuntu2/xlat/sock_tls_options.h
--- 5.5-3/xlat/sock_tls_options.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_tls_options.h	2020-09-24 09:18:46.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sock_tls_options_xdata[] = {
  [TLS_TX] = XLAT(TLS_TX),
+ #define XLAT_VAL_0 ((unsigned) (TLS_TX))
+ #define XLAT_STR_0 STRINGIFY(TLS_TX)
  [TLS_RX] = XLAT(TLS_RX),
+ #define XLAT_VAL_1 ((unsigned) (TLS_RX))
+ #define XLAT_STR_1 STRINGIFY(TLS_RX)
 };
 static
 const struct xlat sock_tls_options[1] = { {
  .data = sock_tls_options_xdata,
  .size = ARRAY_SIZE(sock_tls_options_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_type_flags.h 5.9-0ubuntu2/xlat/sock_type_flags.h
--- 5.5-3/xlat/sock_type_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_type_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -15,9 +15,13 @@
 static const struct xlat_data sock_type_flags_xdata[] = {
 #if defined(SOCK_CLOEXEC) || (defined(HAVE_DECL_SOCK_CLOEXEC) && HAVE_DECL_SOCK_CLOEXEC)
   XLAT(SOCK_CLOEXEC),
+ #define XLAT_VAL_0 ((unsigned) (SOCK_CLOEXEC))
+ #define XLAT_STR_0 STRINGIFY(SOCK_CLOEXEC)
 #endif
 #if defined(SOCK_NONBLOCK) || (defined(HAVE_DECL_SOCK_NONBLOCK) && HAVE_DECL_SOCK_NONBLOCK)
   XLAT(SOCK_NONBLOCK),
+ #define XLAT_VAL_1 ((unsigned) (SOCK_NONBLOCK))
+ #define XLAT_STR_1 STRINGIFY(SOCK_NONBLOCK)
 #endif
 };
 static
@@ -25,8 +29,28 @@ const struct xlat sock_type_flags[1] = {
  .data = sock_type_flags_xdata,
  .size = ARRAY_SIZE(sock_type_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/socktypes.h 5.9-0ubuntu2/xlat/socktypes.h
--- 5.5-3/xlat/socktypes.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/socktypes.h	2020-09-24 09:18:46.000000000 +0000
@@ -77,23 +77,117 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 static const struct xlat_data socktypes_xdata[] = {
 #ifdef __mips__
  XLAT(SOCK_DGRAM),
+ #define XLAT_VAL_0 ((unsigned) (SOCK_DGRAM))
+ #define XLAT_STR_0 STRINGIFY(SOCK_DGRAM)
  XLAT(SOCK_STREAM),
+ #define XLAT_VAL_1 ((unsigned) (SOCK_STREAM))
+ #define XLAT_STR_1 STRINGIFY(SOCK_STREAM)
 #else
  XLAT(SOCK_STREAM),
+ #define XLAT_VAL_2 ((unsigned) (SOCK_STREAM))
+ #define XLAT_STR_2 STRINGIFY(SOCK_STREAM)
  XLAT(SOCK_DGRAM),
+ #define XLAT_VAL_3 ((unsigned) (SOCK_DGRAM))
+ #define XLAT_STR_3 STRINGIFY(SOCK_DGRAM)
 #endif
  XLAT(SOCK_RAW),
+ #define XLAT_VAL_4 ((unsigned) (SOCK_RAW))
+ #define XLAT_STR_4 STRINGIFY(SOCK_RAW)
  XLAT(SOCK_RDM),
+ #define XLAT_VAL_5 ((unsigned) (SOCK_RDM))
+ #define XLAT_STR_5 STRINGIFY(SOCK_RDM)
  XLAT(SOCK_SEQPACKET),
+ #define XLAT_VAL_6 ((unsigned) (SOCK_SEQPACKET))
+ #define XLAT_STR_6 STRINGIFY(SOCK_SEQPACKET)
  XLAT(SOCK_DCCP),
+ #define XLAT_VAL_7 ((unsigned) (SOCK_DCCP))
+ #define XLAT_STR_7 STRINGIFY(SOCK_DCCP)
  XLAT(SOCK_PACKET),
+ #define XLAT_VAL_8 ((unsigned) (SOCK_PACKET))
+ #define XLAT_STR_8 STRINGIFY(SOCK_PACKET)
 };
 const struct xlat socktypes[1] = { {
  .data = socktypes_xdata,
  .size = ARRAY_SIZE(socktypes_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_udp_options.h 5.9-0ubuntu2/xlat/sock_udp_options.h
--- 5.5-3/xlat/sock_udp_options.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_udp_options.h	2020-09-24 09:18:46.000000000 +0000
@@ -56,19 +56,83 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sock_udp_options_xdata[] = {
  XLAT(UDP_CORK),
+ #define XLAT_VAL_0 ((unsigned) (UDP_CORK))
+ #define XLAT_STR_0 STRINGIFY(UDP_CORK)
  XLAT(UDP_ENCAP),
+ #define XLAT_VAL_1 ((unsigned) (UDP_ENCAP))
+ #define XLAT_STR_1 STRINGIFY(UDP_ENCAP)
  XLAT(UDP_NO_CHECK6_TX),
+ #define XLAT_VAL_2 ((unsigned) (UDP_NO_CHECK6_TX))
+ #define XLAT_STR_2 STRINGIFY(UDP_NO_CHECK6_TX)
  XLAT(UDP_NO_CHECK6_RX),
+ #define XLAT_VAL_3 ((unsigned) (UDP_NO_CHECK6_RX))
+ #define XLAT_STR_3 STRINGIFY(UDP_NO_CHECK6_RX)
  XLAT(UDP_SEGMENT),
+ #define XLAT_VAL_4 ((unsigned) (UDP_SEGMENT))
+ #define XLAT_STR_4 STRINGIFY(UDP_SEGMENT)
  XLAT(UDP_GRO),
+ #define XLAT_VAL_5 ((unsigned) (UDP_GRO))
+ #define XLAT_STR_5 STRINGIFY(UDP_GRO)
 };
 static
 const struct xlat sock_udp_options[1] = { {
  .data = sock_udp_options_xdata,
  .size = ARRAY_SIZE(sock_udp_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sock_xdp_options.h 5.9-0ubuntu2/xlat/sock_xdp_options.h
--- 5.5-3/xlat/sock_xdp_options.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sock_xdp_options.h	2020-09-24 09:18:46.000000000 +0000
@@ -70,21 +70,105 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sock_xdp_options_xdata[] = {
  [XDP_MMAP_OFFSETS] = XLAT(XDP_MMAP_OFFSETS),
+ #define XLAT_VAL_0 ((unsigned) (XDP_MMAP_OFFSETS))
+ #define XLAT_STR_0 STRINGIFY(XDP_MMAP_OFFSETS)
  [XDP_RX_RING] = XLAT(XDP_RX_RING),
+ #define XLAT_VAL_1 ((unsigned) (XDP_RX_RING))
+ #define XLAT_STR_1 STRINGIFY(XDP_RX_RING)
  [XDP_TX_RING] = XLAT(XDP_TX_RING),
+ #define XLAT_VAL_2 ((unsigned) (XDP_TX_RING))
+ #define XLAT_STR_2 STRINGIFY(XDP_TX_RING)
  [XDP_UMEM_REG] = XLAT(XDP_UMEM_REG),
+ #define XLAT_VAL_3 ((unsigned) (XDP_UMEM_REG))
+ #define XLAT_STR_3 STRINGIFY(XDP_UMEM_REG)
  [XDP_UMEM_FILL_RING] = XLAT(XDP_UMEM_FILL_RING),
+ #define XLAT_VAL_4 ((unsigned) (XDP_UMEM_FILL_RING))
+ #define XLAT_STR_4 STRINGIFY(XDP_UMEM_FILL_RING)
  [XDP_UMEM_COMPLETION_RING] = XLAT(XDP_UMEM_COMPLETION_RING),
+ #define XLAT_VAL_5 ((unsigned) (XDP_UMEM_COMPLETION_RING))
+ #define XLAT_STR_5 STRINGIFY(XDP_UMEM_COMPLETION_RING)
  [XDP_STATISTICS] = XLAT(XDP_STATISTICS),
+ #define XLAT_VAL_6 ((unsigned) (XDP_STATISTICS))
+ #define XLAT_STR_6 STRINGIFY(XDP_STATISTICS)
  [XDP_OPTIONS] = XLAT(XDP_OPTIONS),
+ #define XLAT_VAL_7 ((unsigned) (XDP_OPTIONS))
+ #define XLAT_STR_7 STRINGIFY(XDP_OPTIONS)
 };
 static
 const struct xlat sock_xdp_options[1] = { {
  .data = sock_xdp_options_xdata,
  .size = ARRAY_SIZE(sock_xdp_options_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sparc_kern_features.h 5.9-0ubuntu2/xlat/sparc_kern_features.h
--- 5.5-3/xlat/sparc_kern_features.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sparc_kern_features.h	2020-09-24 09:18:46.000000000 +0000
@@ -21,14 +21,28 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sparc_kern_features_xdata[] = {
  XLAT(KERN_FEATURE_MIXED_MODE_STACK),
+ #define XLAT_VAL_0 ((unsigned) (KERN_FEATURE_MIXED_MODE_STACK))
+ #define XLAT_STR_0 STRINGIFY(KERN_FEATURE_MIXED_MODE_STACK)
 };
 static
 const struct xlat sparc_kern_features[1] = { {
  .data = sparc_kern_features_xdata,
  .size = ARRAY_SIZE(sparc_kern_features_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/splice_flags.h 5.9-0ubuntu2/xlat/splice_flags.h
--- 5.5-3/xlat/splice_flags.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/splice_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -15,15 +15,23 @@
 static const struct xlat_data splice_flags_xdata[] = {
 #if defined(SPLICE_F_MOVE) || (defined(HAVE_DECL_SPLICE_F_MOVE) && HAVE_DECL_SPLICE_F_MOVE)
   XLAT(SPLICE_F_MOVE),
+ #define XLAT_VAL_0 ((unsigned) (SPLICE_F_MOVE))
+ #define XLAT_STR_0 STRINGIFY(SPLICE_F_MOVE)
 #endif
 #if defined(SPLICE_F_NONBLOCK) || (defined(HAVE_DECL_SPLICE_F_NONBLOCK) && HAVE_DECL_SPLICE_F_NONBLOCK)
   XLAT(SPLICE_F_NONBLOCK),
+ #define XLAT_VAL_1 ((unsigned) (SPLICE_F_NONBLOCK))
+ #define XLAT_STR_1 STRINGIFY(SPLICE_F_NONBLOCK)
 #endif
 #if defined(SPLICE_F_MORE) || (defined(HAVE_DECL_SPLICE_F_MORE) && HAVE_DECL_SPLICE_F_MORE)
   XLAT(SPLICE_F_MORE),
+ #define XLAT_VAL_2 ((unsigned) (SPLICE_F_MORE))
+ #define XLAT_STR_2 STRINGIFY(SPLICE_F_MORE)
 #endif
 #if defined(SPLICE_F_GIFT) || (defined(HAVE_DECL_SPLICE_F_GIFT) && HAVE_DECL_SPLICE_F_GIFT)
   XLAT(SPLICE_F_GIFT),
+ #define XLAT_VAL_3 ((unsigned) (SPLICE_F_GIFT))
+ #define XLAT_STR_3 STRINGIFY(SPLICE_F_GIFT)
 #endif
 };
 static
@@ -31,8 +39,44 @@ const struct xlat splice_flags[1] = { {
  .data = splice_flags_xdata,
  .size = ARRAY_SIZE(splice_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sram_alloc_flags.h 5.9-0ubuntu2/xlat/sram_alloc_flags.h
--- 5.5-3/xlat/sram_alloc_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sram_alloc_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -15,18 +15,28 @@
 static const struct xlat_data sram_alloc_flags_xdata[] = {
 #if defined(L1_INST_SRAM) || (defined(HAVE_DECL_L1_INST_SRAM) && HAVE_DECL_L1_INST_SRAM)
   XLAT(L1_INST_SRAM),
+ #define XLAT_VAL_0 ((unsigned) (L1_INST_SRAM))
+ #define XLAT_STR_0 STRINGIFY(L1_INST_SRAM)
 #endif
 #if defined(L1_DATA_A_SRAM) || (defined(HAVE_DECL_L1_DATA_A_SRAM) && HAVE_DECL_L1_DATA_A_SRAM)
   XLAT(L1_DATA_A_SRAM),
+ #define XLAT_VAL_1 ((unsigned) (L1_DATA_A_SRAM))
+ #define XLAT_STR_1 STRINGIFY(L1_DATA_A_SRAM)
 #endif
 #if defined(L1_DATA_B_SRAM) || (defined(HAVE_DECL_L1_DATA_B_SRAM) && HAVE_DECL_L1_DATA_B_SRAM)
   XLAT(L1_DATA_B_SRAM),
+ #define XLAT_VAL_2 ((unsigned) (L1_DATA_B_SRAM))
+ #define XLAT_STR_2 STRINGIFY(L1_DATA_B_SRAM)
 #endif
 #if defined(L1_DATA_SRAM) || (defined(HAVE_DECL_L1_DATA_SRAM) && HAVE_DECL_L1_DATA_SRAM)
   XLAT(L1_DATA_SRAM),
+ #define XLAT_VAL_3 ((unsigned) (L1_DATA_SRAM))
+ #define XLAT_STR_3 STRINGIFY(L1_DATA_SRAM)
 #endif
 #if defined(L2_SRAM) || (defined(HAVE_DECL_L2_SRAM) && HAVE_DECL_L2_SRAM)
   XLAT(L2_SRAM),
+ #define XLAT_VAL_4 ((unsigned) (L2_SRAM))
+ #define XLAT_STR_4 STRINGIFY(L2_SRAM)
 #endif
 };
 static
@@ -34,8 +44,52 @@ const struct xlat sram_alloc_flags[1] =
  .data = sram_alloc_flags_xdata,
  .size = ARRAY_SIZE(sram_alloc_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/statfs_flags.h 5.9-0ubuntu2/xlat/statfs_flags.h
--- 5.5-3/xlat/statfs_flags.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/statfs_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -84,23 +84,127 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data statfs_flags_xdata[] = {
  XLAT(ST_VALID),
+ #define XLAT_VAL_0 ((unsigned) (ST_VALID))
+ #define XLAT_STR_0 STRINGIFY(ST_VALID)
  XLAT(ST_RDONLY),
+ #define XLAT_VAL_1 ((unsigned) (ST_RDONLY))
+ #define XLAT_STR_1 STRINGIFY(ST_RDONLY)
  XLAT(ST_NOSUID),
+ #define XLAT_VAL_2 ((unsigned) (ST_NOSUID))
+ #define XLAT_STR_2 STRINGIFY(ST_NOSUID)
  XLAT(ST_NODEV),
+ #define XLAT_VAL_3 ((unsigned) (ST_NODEV))
+ #define XLAT_STR_3 STRINGIFY(ST_NODEV)
  XLAT(ST_NOEXEC),
+ #define XLAT_VAL_4 ((unsigned) (ST_NOEXEC))
+ #define XLAT_STR_4 STRINGIFY(ST_NOEXEC)
  XLAT(ST_SYNCHRONOUS),
+ #define XLAT_VAL_5 ((unsigned) (ST_SYNCHRONOUS))
+ #define XLAT_STR_5 STRINGIFY(ST_SYNCHRONOUS)
  XLAT(ST_MANDLOCK),
+ #define XLAT_VAL_6 ((unsigned) (ST_MANDLOCK))
+ #define XLAT_STR_6 STRINGIFY(ST_MANDLOCK)
  XLAT(ST_NOATIME),
+ #define XLAT_VAL_7 ((unsigned) (ST_NOATIME))
+ #define XLAT_STR_7 STRINGIFY(ST_NOATIME)
  XLAT(ST_NODIRATIME),
+ #define XLAT_VAL_8 ((unsigned) (ST_NODIRATIME))
+ #define XLAT_STR_8 STRINGIFY(ST_NODIRATIME)
  XLAT(ST_RELATIME),
+ #define XLAT_VAL_9 ((unsigned) (ST_RELATIME))
+ #define XLAT_STR_9 STRINGIFY(ST_RELATIME)
 };
 static
 const struct xlat statfs_flags[1] = { {
  .data = statfs_flags_xdata,
  .size = ARRAY_SIZE(statfs_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/statx_attrs.h 5.9-0ubuntu2/xlat/statx_attrs.h
--- 5.5-3/xlat/statx_attrs.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/statx_attrs.h	2020-09-24 09:18:46.000000000 +0000
@@ -45,6 +45,13 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define STATX_ATTR_AUTOMOUNT 0x00001000
 #endif
+#if defined(STATX_ATTR_MOUNT_ROOT) || (defined(HAVE_DECL_STATX_ATTR_MOUNT_ROOT) && HAVE_DECL_STATX_ATTR_MOUNT_ROOT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((STATX_ATTR_MOUNT_ROOT) == (0x00002000), "STATX_ATTR_MOUNT_ROOT != 0x00002000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define STATX_ATTR_MOUNT_ROOT 0x00002000
+#endif
 #if defined(STATX_ATTR_VERITY) || (defined(HAVE_DECL_STATX_ATTR_VERITY) && HAVE_DECL_STATX_ATTR_VERITY)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
 static_assert((STATX_ATTR_VERITY) == (0x00100000), "STATX_ATTR_VERITY != 0x00100000");
@@ -63,20 +70,105 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data statx_attrs_xdata[] = {
  XLAT(STATX_ATTR_COMPRESSED),
+ #define XLAT_VAL_0 ((unsigned) (STATX_ATTR_COMPRESSED))
+ #define XLAT_STR_0 STRINGIFY(STATX_ATTR_COMPRESSED)
  XLAT(STATX_ATTR_IMMUTABLE),
+ #define XLAT_VAL_1 ((unsigned) (STATX_ATTR_IMMUTABLE))
+ #define XLAT_STR_1 STRINGIFY(STATX_ATTR_IMMUTABLE)
  XLAT(STATX_ATTR_APPEND),
+ #define XLAT_VAL_2 ((unsigned) (STATX_ATTR_APPEND))
+ #define XLAT_STR_2 STRINGIFY(STATX_ATTR_APPEND)
  XLAT(STATX_ATTR_NODUMP),
+ #define XLAT_VAL_3 ((unsigned) (STATX_ATTR_NODUMP))
+ #define XLAT_STR_3 STRINGIFY(STATX_ATTR_NODUMP)
  XLAT(STATX_ATTR_ENCRYPTED),
+ #define XLAT_VAL_4 ((unsigned) (STATX_ATTR_ENCRYPTED))
+ #define XLAT_STR_4 STRINGIFY(STATX_ATTR_ENCRYPTED)
  XLAT(STATX_ATTR_AUTOMOUNT),
+ #define XLAT_VAL_5 ((unsigned) (STATX_ATTR_AUTOMOUNT))
+ #define XLAT_STR_5 STRINGIFY(STATX_ATTR_AUTOMOUNT)
+ XLAT(STATX_ATTR_MOUNT_ROOT),
+ #define XLAT_VAL_6 ((unsigned) (STATX_ATTR_MOUNT_ROOT))
+ #define XLAT_STR_6 STRINGIFY(STATX_ATTR_MOUNT_ROOT)
  XLAT(STATX_ATTR_VERITY),
+ #define XLAT_VAL_7 ((unsigned) (STATX_ATTR_VERITY))
+ #define XLAT_STR_7 STRINGIFY(STATX_ATTR_VERITY)
 };
 static
 const struct xlat statx_attrs[1] = { {
  .data = statx_attrs_xdata,
  .size = ARRAY_SIZE(statx_attrs_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/statx_attrs.in 5.9-0ubuntu2/xlat/statx_attrs.in
--- 5.5-3/xlat/statx_attrs.in	2020-01-21 18:02:38.000000000 +0000
+++ 5.9-0ubuntu2/xlat/statx_attrs.in	2020-06-29 08:00:00.000000000 +0000
@@ -4,4 +4,5 @@ STATX_ATTR_APPEND	0x00000020
 STATX_ATTR_NODUMP	0x00000040
 STATX_ATTR_ENCRYPTED	0x00000800
 STATX_ATTR_AUTOMOUNT	0x00001000
+STATX_ATTR_MOUNT_ROOT	0x00002000
 STATX_ATTR_VERITY	0x00100000
diff -pruN 5.5-3/xlat/statx_masks.h 5.9-0ubuntu2/xlat/statx_masks.h
--- 5.5-3/xlat/statx_masks.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/statx_masks.h	2020-09-24 09:18:46.000000000 +0000
@@ -101,6 +101,13 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define STATX_BTIME 0x00000800U
 #endif
+#if defined(STATX_MNT_ID) || (defined(HAVE_DECL_STATX_MNT_ID) && HAVE_DECL_STATX_MNT_ID)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((STATX_MNT_ID) == (0x00001000U), "STATX_MNT_ID != 0x00001000U");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define STATX_MNT_ID 0x00001000U
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -112,28 +119,183 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data statx_masks_xdata[] = {
  XLAT(STATX_ALL),
+ #define XLAT_VAL_0 ((unsigned) (STATX_ALL))
+ #define XLAT_STR_0 STRINGIFY(STATX_ALL)
  XLAT(STATX_BASIC_STATS),
+ #define XLAT_VAL_1 ((unsigned) (STATX_BASIC_STATS))
+ #define XLAT_STR_1 STRINGIFY(STATX_BASIC_STATS)
 
  XLAT(STATX_TYPE),
+ #define XLAT_VAL_2 ((unsigned) (STATX_TYPE))
+ #define XLAT_STR_2 STRINGIFY(STATX_TYPE)
  XLAT(STATX_MODE),
+ #define XLAT_VAL_3 ((unsigned) (STATX_MODE))
+ #define XLAT_STR_3 STRINGIFY(STATX_MODE)
  XLAT(STATX_NLINK),
+ #define XLAT_VAL_4 ((unsigned) (STATX_NLINK))
+ #define XLAT_STR_4 STRINGIFY(STATX_NLINK)
  XLAT(STATX_UID),
+ #define XLAT_VAL_5 ((unsigned) (STATX_UID))
+ #define XLAT_STR_5 STRINGIFY(STATX_UID)
  XLAT(STATX_GID),
+ #define XLAT_VAL_6 ((unsigned) (STATX_GID))
+ #define XLAT_STR_6 STRINGIFY(STATX_GID)
  XLAT(STATX_ATIME),
+ #define XLAT_VAL_7 ((unsigned) (STATX_ATIME))
+ #define XLAT_STR_7 STRINGIFY(STATX_ATIME)
  XLAT(STATX_MTIME),
+ #define XLAT_VAL_8 ((unsigned) (STATX_MTIME))
+ #define XLAT_STR_8 STRINGIFY(STATX_MTIME)
  XLAT(STATX_CTIME),
+ #define XLAT_VAL_9 ((unsigned) (STATX_CTIME))
+ #define XLAT_STR_9 STRINGIFY(STATX_CTIME)
  XLAT(STATX_INO),
+ #define XLAT_VAL_10 ((unsigned) (STATX_INO))
+ #define XLAT_STR_10 STRINGIFY(STATX_INO)
  XLAT(STATX_SIZE),
+ #define XLAT_VAL_11 ((unsigned) (STATX_SIZE))
+ #define XLAT_STR_11 STRINGIFY(STATX_SIZE)
  XLAT(STATX_BLOCKS),
+ #define XLAT_VAL_12 ((unsigned) (STATX_BLOCKS))
+ #define XLAT_STR_12 STRINGIFY(STATX_BLOCKS)
  XLAT(STATX_BTIME),
+ #define XLAT_VAL_13 ((unsigned) (STATX_BTIME))
+ #define XLAT_STR_13 STRINGIFY(STATX_BTIME)
+ XLAT(STATX_MNT_ID),
+ #define XLAT_VAL_14 ((unsigned) (STATX_MNT_ID))
+ #define XLAT_STR_14 STRINGIFY(STATX_MNT_ID)
 };
 static
 const struct xlat statx_masks[1] = { {
  .data = statx_masks_xdata,
  .size = ARRAY_SIZE(statx_masks_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/statx_masks.in 5.9-0ubuntu2/xlat/statx_masks.in
--- 5.5-3/xlat/statx_masks.in	2017-03-18 22:14:16.000000000 +0000
+++ 5.9-0ubuntu2/xlat/statx_masks.in	2020-06-29 08:00:00.000000000 +0000
@@ -13,3 +13,4 @@ STATX_INO		0x00000100U
 STATX_SIZE		0x00000200U
 STATX_BLOCKS		0x00000400U
 STATX_BTIME		0x00000800U
+STATX_MNT_ID		0x00001000U
diff -pruN 5.5-3/xlat/st_check_enums.m4 5.9-0ubuntu2/xlat/st_check_enums.m4
--- 5.5-3/xlat/st_check_enums.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/st_check_enums.m4	2020-09-24 09:18:49.000000000 +0000
@@ -0,0 +1,30 @@
+AC_DEFUN([st_CHECK_ENUMS],[
+	st_CHECK_ENUMS_btrfs_compress_types
+	st_CHECK_ENUMS_close_range_flags
+	st_CHECK_ENUMS_loop_flags_options
+	st_CHECK_ENUMS_rtnl_ifla_xdp_attached_mode
+	st_CHECK_ENUMS_rtnl_ifla_xdp_attrs
+	st_CHECK_ENUMS_rtnl_link_attrs
+	st_CHECK_ENUMS_rtnl_tc_action_attrs
+	st_CHECK_ENUMS_rtnl_tca_stab_attrs
+	st_CHECK_ENUMS_rtnl_tca_stats_attrs
+	st_CHECK_ENUMS_sysctl_kern
+	st_CHECK_ENUMS_sysctl_net
+	st_CHECK_ENUMS_sysctl_net_core
+	st_CHECK_ENUMS_sysctl_net_ipv4
+	st_CHECK_ENUMS_sysctl_net_ipv4_conf
+	st_CHECK_ENUMS_sysctl_net_ipv4_route
+	st_CHECK_ENUMS_sysctl_net_ipv6
+	st_CHECK_ENUMS_sysctl_net_ipv6_route
+	st_CHECK_ENUMS_sysctl_net_unix
+	st_CHECK_ENUMS_sysctl_root
+	st_CHECK_ENUMS_sysctl_vm
+	st_CHECK_ENUMS_v4l2_buf_types
+	st_CHECK_ENUMS_v4l2_colorspaces
+	st_CHECK_ENUMS_v4l2_control_types
+	st_CHECK_ENUMS_v4l2_fields
+	st_CHECK_ENUMS_v4l2_framesize_types
+	st_CHECK_ENUMS_v4l2_memories
+	st_CHECK_ENUMS_v4l2_tuner_types
+	st_CHECK_ENUMS_waitid_types
+])
diff -pruN 5.5-3/xlat/swap_flags.h 5.9-0ubuntu2/xlat/swap_flags.h
--- 5.5-3/xlat/swap_flags.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/swap_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data swap_flags_xdata[] = {
  XLAT(SWAP_FLAG_PREFER),
+ #define XLAT_VAL_0 ((unsigned) (SWAP_FLAG_PREFER))
+ #define XLAT_STR_0 STRINGIFY(SWAP_FLAG_PREFER)
  XLAT(SWAP_FLAG_DISCARD),
+ #define XLAT_VAL_1 ((unsigned) (SWAP_FLAG_DISCARD))
+ #define XLAT_STR_1 STRINGIFY(SWAP_FLAG_DISCARD)
  XLAT(SWAP_FLAG_DISCARD_ONCE),
+ #define XLAT_VAL_2 ((unsigned) (SWAP_FLAG_DISCARD_ONCE))
+ #define XLAT_STR_2 STRINGIFY(SWAP_FLAG_DISCARD_ONCE)
  XLAT(SWAP_FLAG_DISCARD_PAGES),
+ #define XLAT_VAL_3 ((unsigned) (SWAP_FLAG_DISCARD_PAGES))
+ #define XLAT_STR_3 STRINGIFY(SWAP_FLAG_DISCARD_PAGES)
 };
 static
 const struct xlat swap_flags[1] = { {
  .data = swap_flags_xdata,
  .size = ARRAY_SIZE(swap_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sync_file_range_flags.h 5.9-0ubuntu2/xlat/sync_file_range_flags.h
--- 5.5-3/xlat/sync_file_range_flags.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sync_file_range_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data sync_file_range_flags_xdata[] = {
  XLAT(SYNC_FILE_RANGE_WAIT_BEFORE),
+ #define XLAT_VAL_0 ((unsigned) (SYNC_FILE_RANGE_WAIT_BEFORE))
+ #define XLAT_STR_0 STRINGIFY(SYNC_FILE_RANGE_WAIT_BEFORE)
  XLAT(SYNC_FILE_RANGE_WRITE),
+ #define XLAT_VAL_1 ((unsigned) (SYNC_FILE_RANGE_WRITE))
+ #define XLAT_STR_1 STRINGIFY(SYNC_FILE_RANGE_WRITE)
  XLAT(SYNC_FILE_RANGE_WAIT_AFTER),
+ #define XLAT_VAL_2 ((unsigned) (SYNC_FILE_RANGE_WAIT_AFTER))
+ #define XLAT_STR_2 STRINGIFY(SYNC_FILE_RANGE_WAIT_AFTER)
 };
 static
 const struct xlat sync_file_range_flags[1] = { {
  .data = sync_file_range_flags_xdata,
  .size = ARRAY_SIZE(sync_file_range_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sysctl_kern.h 5.9-0ubuntu2/xlat/sysctl_kern.h
--- 5.5-3/xlat/sysctl_kern.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_kern.h	2020-09-24 09:18:47.000000000 +0000
@@ -14,110 +14,246 @@
 
 static const struct xlat_data sysctl_kern_xdata[] = {
  XLAT(KERN_OSTYPE),
+ #define XLAT_VAL_0 ((unsigned) (KERN_OSTYPE))
+ #define XLAT_STR_0 STRINGIFY(KERN_OSTYPE)
  XLAT(KERN_OSRELEASE),
+ #define XLAT_VAL_1 ((unsigned) (KERN_OSRELEASE))
+ #define XLAT_STR_1 STRINGIFY(KERN_OSRELEASE)
  XLAT(KERN_OSREV),
+ #define XLAT_VAL_2 ((unsigned) (KERN_OSREV))
+ #define XLAT_STR_2 STRINGIFY(KERN_OSREV)
  XLAT(KERN_VERSION),
+ #define XLAT_VAL_3 ((unsigned) (KERN_VERSION))
+ #define XLAT_STR_3 STRINGIFY(KERN_VERSION)
  XLAT(KERN_SECUREMASK),
+ #define XLAT_VAL_4 ((unsigned) (KERN_SECUREMASK))
+ #define XLAT_STR_4 STRINGIFY(KERN_SECUREMASK)
  XLAT(KERN_PROF),
+ #define XLAT_VAL_5 ((unsigned) (KERN_PROF))
+ #define XLAT_STR_5 STRINGIFY(KERN_PROF)
  XLAT(KERN_NODENAME),
+ #define XLAT_VAL_6 ((unsigned) (KERN_NODENAME))
+ #define XLAT_STR_6 STRINGIFY(KERN_NODENAME)
  XLAT(KERN_DOMAINNAME),
+ #define XLAT_VAL_7 ((unsigned) (KERN_DOMAINNAME))
+ #define XLAT_STR_7 STRINGIFY(KERN_DOMAINNAME)
  XLAT(KERN_PANIC),
+ #define XLAT_VAL_8 ((unsigned) (KERN_PANIC))
+ #define XLAT_STR_8 STRINGIFY(KERN_PANIC)
  XLAT(KERN_REALROOTDEV),
+ #define XLAT_VAL_9 ((unsigned) (KERN_REALROOTDEV))
+ #define XLAT_STR_9 STRINGIFY(KERN_REALROOTDEV)
  XLAT(KERN_SPARC_REBOOT),
+ #define XLAT_VAL_10 ((unsigned) (KERN_SPARC_REBOOT))
+ #define XLAT_STR_10 STRINGIFY(KERN_SPARC_REBOOT)
  XLAT(KERN_CTLALTDEL),
+ #define XLAT_VAL_11 ((unsigned) (KERN_CTLALTDEL))
+ #define XLAT_STR_11 STRINGIFY(KERN_CTLALTDEL)
  XLAT(KERN_PRINTK),
+ #define XLAT_VAL_12 ((unsigned) (KERN_PRINTK))
+ #define XLAT_STR_12 STRINGIFY(KERN_PRINTK)
  XLAT(KERN_NAMETRANS),
+ #define XLAT_VAL_13 ((unsigned) (KERN_NAMETRANS))
+ #define XLAT_STR_13 STRINGIFY(KERN_NAMETRANS)
  XLAT(KERN_PPC_HTABRECLAIM),
+ #define XLAT_VAL_14 ((unsigned) (KERN_PPC_HTABRECLAIM))
+ #define XLAT_STR_14 STRINGIFY(KERN_PPC_HTABRECLAIM)
  XLAT(KERN_PPC_ZEROPAGED),
+ #define XLAT_VAL_15 ((unsigned) (KERN_PPC_ZEROPAGED))
+ #define XLAT_STR_15 STRINGIFY(KERN_PPC_ZEROPAGED)
  XLAT(KERN_PPC_POWERSAVE_NAP),
+ #define XLAT_VAL_16 ((unsigned) (KERN_PPC_POWERSAVE_NAP))
+ #define XLAT_STR_16 STRINGIFY(KERN_PPC_POWERSAVE_NAP)
  XLAT(KERN_MODPROBE),
+ #define XLAT_VAL_17 ((unsigned) (KERN_MODPROBE))
+ #define XLAT_STR_17 STRINGIFY(KERN_MODPROBE)
  XLAT(KERN_SG_BIG_BUFF),
+ #define XLAT_VAL_18 ((unsigned) (KERN_SG_BIG_BUFF))
+ #define XLAT_STR_18 STRINGIFY(KERN_SG_BIG_BUFF)
  XLAT(KERN_ACCT),
+ #define XLAT_VAL_19 ((unsigned) (KERN_ACCT))
+ #define XLAT_STR_19 STRINGIFY(KERN_ACCT)
  XLAT(KERN_PPC_L2CR),
+ #define XLAT_VAL_20 ((unsigned) (KERN_PPC_L2CR))
+ #define XLAT_STR_20 STRINGIFY(KERN_PPC_L2CR)
  XLAT(KERN_RTSIGNR),
+ #define XLAT_VAL_21 ((unsigned) (KERN_RTSIGNR))
+ #define XLAT_STR_21 STRINGIFY(KERN_RTSIGNR)
  XLAT(KERN_RTSIGMAX),
+ #define XLAT_VAL_22 ((unsigned) (KERN_RTSIGMAX))
+ #define XLAT_STR_22 STRINGIFY(KERN_RTSIGMAX)
  XLAT(KERN_SHMMAX),
+ #define XLAT_VAL_23 ((unsigned) (KERN_SHMMAX))
+ #define XLAT_STR_23 STRINGIFY(KERN_SHMMAX)
  XLAT(KERN_MSGMAX),
+ #define XLAT_VAL_24 ((unsigned) (KERN_MSGMAX))
+ #define XLAT_STR_24 STRINGIFY(KERN_MSGMAX)
  XLAT(KERN_MSGMNB),
+ #define XLAT_VAL_25 ((unsigned) (KERN_MSGMNB))
+ #define XLAT_STR_25 STRINGIFY(KERN_MSGMNB)
  XLAT(KERN_MSGPOOL),
+ #define XLAT_VAL_26 ((unsigned) (KERN_MSGPOOL))
+ #define XLAT_STR_26 STRINGIFY(KERN_MSGPOOL)
  XLAT(KERN_SYSRQ),
+ #define XLAT_VAL_27 ((unsigned) (KERN_SYSRQ))
+ #define XLAT_STR_27 STRINGIFY(KERN_SYSRQ)
  XLAT(KERN_MAX_THREADS),
+ #define XLAT_VAL_28 ((unsigned) (KERN_MAX_THREADS))
+ #define XLAT_STR_28 STRINGIFY(KERN_MAX_THREADS)
  XLAT(KERN_RANDOM),
+ #define XLAT_VAL_29 ((unsigned) (KERN_RANDOM))
+ #define XLAT_STR_29 STRINGIFY(KERN_RANDOM)
  XLAT(KERN_SHMALL),
+ #define XLAT_VAL_30 ((unsigned) (KERN_SHMALL))
+ #define XLAT_STR_30 STRINGIFY(KERN_SHMALL)
  XLAT(KERN_MSGMNI),
+ #define XLAT_VAL_31 ((unsigned) (KERN_MSGMNI))
+ #define XLAT_STR_31 STRINGIFY(KERN_MSGMNI)
  XLAT(KERN_SEM),
+ #define XLAT_VAL_32 ((unsigned) (KERN_SEM))
+ #define XLAT_STR_32 STRINGIFY(KERN_SEM)
  XLAT(KERN_SPARC_STOP_A),
+ #define XLAT_VAL_33 ((unsigned) (KERN_SPARC_STOP_A))
+ #define XLAT_STR_33 STRINGIFY(KERN_SPARC_STOP_A)
  XLAT(KERN_SHMMNI),
+ #define XLAT_VAL_34 ((unsigned) (KERN_SHMMNI))
+ #define XLAT_STR_34 STRINGIFY(KERN_SHMMNI)
  XLAT(KERN_OVERFLOWUID),
+ #define XLAT_VAL_35 ((unsigned) (KERN_OVERFLOWUID))
+ #define XLAT_STR_35 STRINGIFY(KERN_OVERFLOWUID)
  XLAT(KERN_OVERFLOWGID),
+ #define XLAT_VAL_36 ((unsigned) (KERN_OVERFLOWGID))
+ #define XLAT_STR_36 STRINGIFY(KERN_OVERFLOWGID)
  XLAT(KERN_SHMPATH),
+ #define XLAT_VAL_37 ((unsigned) (KERN_SHMPATH))
+ #define XLAT_STR_37 STRINGIFY(KERN_SHMPATH)
  XLAT(KERN_HOTPLUG),
+ #define XLAT_VAL_38 ((unsigned) (KERN_HOTPLUG))
+ #define XLAT_STR_38 STRINGIFY(KERN_HOTPLUG)
  XLAT(KERN_IEEE_EMULATION_WARNINGS),
+ #define XLAT_VAL_39 ((unsigned) (KERN_IEEE_EMULATION_WARNINGS))
+ #define XLAT_STR_39 STRINGIFY(KERN_IEEE_EMULATION_WARNINGS)
  XLAT(KERN_S390_USER_DEBUG_LOGGING),
+ #define XLAT_VAL_40 ((unsigned) (KERN_S390_USER_DEBUG_LOGGING))
+ #define XLAT_STR_40 STRINGIFY(KERN_S390_USER_DEBUG_LOGGING)
  XLAT(KERN_CORE_USES_PID),
+ #define XLAT_VAL_41 ((unsigned) (KERN_CORE_USES_PID))
+ #define XLAT_STR_41 STRINGIFY(KERN_CORE_USES_PID)
  XLAT(KERN_TAINTED),
+ #define XLAT_VAL_42 ((unsigned) (KERN_TAINTED))
+ #define XLAT_STR_42 STRINGIFY(KERN_TAINTED)
  XLAT(KERN_CADPID),
+ #define XLAT_VAL_43 ((unsigned) (KERN_CADPID))
+ #define XLAT_STR_43 STRINGIFY(KERN_CADPID)
  XLAT(KERN_PIDMAX),
+ #define XLAT_VAL_44 ((unsigned) (KERN_PIDMAX))
+ #define XLAT_STR_44 STRINGIFY(KERN_PIDMAX)
  XLAT(KERN_CORE_PATTERN),
+ #define XLAT_VAL_45 ((unsigned) (KERN_CORE_PATTERN))
+ #define XLAT_STR_45 STRINGIFY(KERN_CORE_PATTERN)
  XLAT(KERN_PANIC_ON_OOPS),
+ #define XLAT_VAL_46 ((unsigned) (KERN_PANIC_ON_OOPS))
+ #define XLAT_STR_46 STRINGIFY(KERN_PANIC_ON_OOPS)
  XLAT(KERN_HPPA_PWRSW),
+ #define XLAT_VAL_47 ((unsigned) (KERN_HPPA_PWRSW))
+ #define XLAT_STR_47 STRINGIFY(KERN_HPPA_PWRSW)
  XLAT(KERN_HPPA_UNALIGNED),
+ #define XLAT_VAL_48 ((unsigned) (KERN_HPPA_UNALIGNED))
+ #define XLAT_STR_48 STRINGIFY(KERN_HPPA_UNALIGNED)
 #if defined(KERN_PRINTK_RATELIMIT) || (defined(HAVE_DECL_KERN_PRINTK_RATELIMIT) && HAVE_DECL_KERN_PRINTK_RATELIMIT)
   XLAT(KERN_PRINTK_RATELIMIT),
+ #define XLAT_VAL_49 ((unsigned) (KERN_PRINTK_RATELIMIT))
+ #define XLAT_STR_49 STRINGIFY(KERN_PRINTK_RATELIMIT)
 #endif
 #if defined(KERN_PRINTK_RATELIMIT_BURST) || (defined(HAVE_DECL_KERN_PRINTK_RATELIMIT_BURST) && HAVE_DECL_KERN_PRINTK_RATELIMIT_BURST)
   XLAT(KERN_PRINTK_RATELIMIT_BURST),
+ #define XLAT_VAL_50 ((unsigned) (KERN_PRINTK_RATELIMIT_BURST))
+ #define XLAT_STR_50 STRINGIFY(KERN_PRINTK_RATELIMIT_BURST)
 #endif
 #if defined(KERN_PTY) || (defined(HAVE_DECL_KERN_PTY) && HAVE_DECL_KERN_PTY)
   XLAT(KERN_PTY),
+ #define XLAT_VAL_51 ((unsigned) (KERN_PTY))
+ #define XLAT_STR_51 STRINGIFY(KERN_PTY)
 #endif
 #if defined(KERN_NGROUPS_MAX) || (defined(HAVE_DECL_KERN_NGROUPS_MAX) && HAVE_DECL_KERN_NGROUPS_MAX)
   XLAT(KERN_NGROUPS_MAX),
+ #define XLAT_VAL_52 ((unsigned) (KERN_NGROUPS_MAX))
+ #define XLAT_STR_52 STRINGIFY(KERN_NGROUPS_MAX)
 #endif
 #if defined(KERN_SPARC_SCONS_PWROFF) || (defined(HAVE_DECL_KERN_SPARC_SCONS_PWROFF) && HAVE_DECL_KERN_SPARC_SCONS_PWROFF)
   XLAT(KERN_SPARC_SCONS_PWROFF),
+ #define XLAT_VAL_53 ((unsigned) (KERN_SPARC_SCONS_PWROFF))
+ #define XLAT_STR_53 STRINGIFY(KERN_SPARC_SCONS_PWROFF)
 #endif
 #if defined(KERN_HZ_TIMER) || (defined(HAVE_DECL_KERN_HZ_TIMER) && HAVE_DECL_KERN_HZ_TIMER)
   XLAT(KERN_HZ_TIMER),
+ #define XLAT_VAL_54 ((unsigned) (KERN_HZ_TIMER))
+ #define XLAT_STR_54 STRINGIFY(KERN_HZ_TIMER)
 #endif
 #if defined(KERN_UNKNOWN_NMI_PANIC) || (defined(HAVE_DECL_KERN_UNKNOWN_NMI_PANIC) && HAVE_DECL_KERN_UNKNOWN_NMI_PANIC)
   XLAT(KERN_UNKNOWN_NMI_PANIC),
+ #define XLAT_VAL_55 ((unsigned) (KERN_UNKNOWN_NMI_PANIC))
+ #define XLAT_STR_55 STRINGIFY(KERN_UNKNOWN_NMI_PANIC)
 #endif
 #if defined(KERN_BOOTLOADER_TYPE) || (defined(HAVE_DECL_KERN_BOOTLOADER_TYPE) && HAVE_DECL_KERN_BOOTLOADER_TYPE)
   XLAT(KERN_BOOTLOADER_TYPE),
+ #define XLAT_VAL_56 ((unsigned) (KERN_BOOTLOADER_TYPE))
+ #define XLAT_STR_56 STRINGIFY(KERN_BOOTLOADER_TYPE)
 #endif
 #if defined(KERN_RANDOMIZE) || (defined(HAVE_DECL_KERN_RANDOMIZE) && HAVE_DECL_KERN_RANDOMIZE)
   XLAT(KERN_RANDOMIZE),
+ #define XLAT_VAL_57 ((unsigned) (KERN_RANDOMIZE))
+ #define XLAT_STR_57 STRINGIFY(KERN_RANDOMIZE)
 #endif
 #if defined(KERN_SETUID_DUMPABLE) || (defined(HAVE_DECL_KERN_SETUID_DUMPABLE) && HAVE_DECL_KERN_SETUID_DUMPABLE)
   XLAT(KERN_SETUID_DUMPABLE),
+ #define XLAT_VAL_58 ((unsigned) (KERN_SETUID_DUMPABLE))
+ #define XLAT_STR_58 STRINGIFY(KERN_SETUID_DUMPABLE)
 #endif
 #if defined(KERN_SPIN_RETRY) || (defined(HAVE_DECL_KERN_SPIN_RETRY) && HAVE_DECL_KERN_SPIN_RETRY)
   XLAT(KERN_SPIN_RETRY),
+ #define XLAT_VAL_59 ((unsigned) (KERN_SPIN_RETRY))
+ #define XLAT_STR_59 STRINGIFY(KERN_SPIN_RETRY)
 #endif
 #if defined(KERN_ACPI_VIDEO_FLAGS) || (defined(HAVE_DECL_KERN_ACPI_VIDEO_FLAGS) && HAVE_DECL_KERN_ACPI_VIDEO_FLAGS)
   XLAT(KERN_ACPI_VIDEO_FLAGS),
+ #define XLAT_VAL_60 ((unsigned) (KERN_ACPI_VIDEO_FLAGS))
+ #define XLAT_STR_60 STRINGIFY(KERN_ACPI_VIDEO_FLAGS)
 #endif
 #if defined(KERN_IA64_UNALIGNED) || (defined(HAVE_DECL_KERN_IA64_UNALIGNED) && HAVE_DECL_KERN_IA64_UNALIGNED)
   XLAT(KERN_IA64_UNALIGNED),
+ #define XLAT_VAL_61 ((unsigned) (KERN_IA64_UNALIGNED))
+ #define XLAT_STR_61 STRINGIFY(KERN_IA64_UNALIGNED)
 #endif
 #if defined(KERN_COMPAT_LOG) || (defined(HAVE_DECL_KERN_COMPAT_LOG) && HAVE_DECL_KERN_COMPAT_LOG)
   XLAT(KERN_COMPAT_LOG),
+ #define XLAT_VAL_62 ((unsigned) (KERN_COMPAT_LOG))
+ #define XLAT_STR_62 STRINGIFY(KERN_COMPAT_LOG)
 #endif
 #if defined(KERN_MAX_LOCK_DEPTH) || (defined(HAVE_DECL_KERN_MAX_LOCK_DEPTH) && HAVE_DECL_KERN_MAX_LOCK_DEPTH)
   XLAT(KERN_MAX_LOCK_DEPTH),
+ #define XLAT_VAL_63 ((unsigned) (KERN_MAX_LOCK_DEPTH))
+ #define XLAT_STR_63 STRINGIFY(KERN_MAX_LOCK_DEPTH)
 #endif
 #if defined(KERN_NMI_WATCHDOG) || (defined(HAVE_DECL_KERN_NMI_WATCHDOG) && HAVE_DECL_KERN_NMI_WATCHDOG)
   XLAT(KERN_NMI_WATCHDOG),
+ #define XLAT_VAL_64 ((unsigned) (KERN_NMI_WATCHDOG))
+ #define XLAT_STR_64 STRINGIFY(KERN_NMI_WATCHDOG)
 #endif
 #if defined(KERN_PANIC_ON_NMI) || (defined(HAVE_DECL_KERN_PANIC_ON_NMI) && HAVE_DECL_KERN_PANIC_ON_NMI)
   XLAT(KERN_PANIC_ON_NMI),
+ #define XLAT_VAL_65 ((unsigned) (KERN_PANIC_ON_NMI))
+ #define XLAT_STR_65 STRINGIFY(KERN_PANIC_ON_NMI)
 #endif
 #if defined(KERN_PANIC_ON_WARN) || (defined(HAVE_DECL_KERN_PANIC_ON_WARN) && HAVE_DECL_KERN_PANIC_ON_WARN)
   XLAT(KERN_PANIC_ON_WARN),
+ #define XLAT_VAL_66 ((unsigned) (KERN_PANIC_ON_WARN))
+ #define XLAT_STR_66 STRINGIFY(KERN_PANIC_ON_WARN)
 #endif
 #if defined(KERN_PANIC_PRINT) || (defined(HAVE_DECL_KERN_PANIC_PRINT) && HAVE_DECL_KERN_PANIC_PRINT)
   XLAT(KERN_PANIC_PRINT),
+ #define XLAT_VAL_67 ((unsigned) (KERN_PANIC_PRINT))
+ #define XLAT_STR_67 STRINGIFY(KERN_PANIC_PRINT)
 #endif
 };
 static
@@ -125,8 +261,556 @@ const struct xlat sysctl_kern[1] = { {
  .data = sysctl_kern_xdata,
  .size = ARRAY_SIZE(sysctl_kern_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+#  ifdef XLAT_VAL_47
+  | XLAT_VAL_47
+#  endif
+#  ifdef XLAT_VAL_48
+  | XLAT_VAL_48
+#  endif
+#  ifdef XLAT_VAL_49
+  | XLAT_VAL_49
+#  endif
+#  ifdef XLAT_VAL_50
+  | XLAT_VAL_50
+#  endif
+#  ifdef XLAT_VAL_51
+  | XLAT_VAL_51
+#  endif
+#  ifdef XLAT_VAL_52
+  | XLAT_VAL_52
+#  endif
+#  ifdef XLAT_VAL_53
+  | XLAT_VAL_53
+#  endif
+#  ifdef XLAT_VAL_54
+  | XLAT_VAL_54
+#  endif
+#  ifdef XLAT_VAL_55
+  | XLAT_VAL_55
+#  endif
+#  ifdef XLAT_VAL_56
+  | XLAT_VAL_56
+#  endif
+#  ifdef XLAT_VAL_57
+  | XLAT_VAL_57
+#  endif
+#  ifdef XLAT_VAL_58
+  | XLAT_VAL_58
+#  endif
+#  ifdef XLAT_VAL_59
+  | XLAT_VAL_59
+#  endif
+#  ifdef XLAT_VAL_60
+  | XLAT_VAL_60
+#  endif
+#  ifdef XLAT_VAL_61
+  | XLAT_VAL_61
+#  endif
+#  ifdef XLAT_VAL_62
+  | XLAT_VAL_62
+#  endif
+#  ifdef XLAT_VAL_63
+  | XLAT_VAL_63
+#  endif
+#  ifdef XLAT_VAL_64
+  | XLAT_VAL_64
+#  endif
+#  ifdef XLAT_VAL_65
+  | XLAT_VAL_65
+#  endif
+#  ifdef XLAT_VAL_66
+  | XLAT_VAL_66
+#  endif
+#  ifdef XLAT_VAL_67
+  | XLAT_VAL_67
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+#  ifdef XLAT_STR_47
+  + sizeof(XLAT_STR_47)
+#  endif
+#  ifdef XLAT_STR_48
+  + sizeof(XLAT_STR_48)
+#  endif
+#  ifdef XLAT_STR_49
+  + sizeof(XLAT_STR_49)
+#  endif
+#  ifdef XLAT_STR_50
+  + sizeof(XLAT_STR_50)
+#  endif
+#  ifdef XLAT_STR_51
+  + sizeof(XLAT_STR_51)
+#  endif
+#  ifdef XLAT_STR_52
+  + sizeof(XLAT_STR_52)
+#  endif
+#  ifdef XLAT_STR_53
+  + sizeof(XLAT_STR_53)
+#  endif
+#  ifdef XLAT_STR_54
+  + sizeof(XLAT_STR_54)
+#  endif
+#  ifdef XLAT_STR_55
+  + sizeof(XLAT_STR_55)
+#  endif
+#  ifdef XLAT_STR_56
+  + sizeof(XLAT_STR_56)
+#  endif
+#  ifdef XLAT_STR_57
+  + sizeof(XLAT_STR_57)
+#  endif
+#  ifdef XLAT_STR_58
+  + sizeof(XLAT_STR_58)
+#  endif
+#  ifdef XLAT_STR_59
+  + sizeof(XLAT_STR_59)
+#  endif
+#  ifdef XLAT_STR_60
+  + sizeof(XLAT_STR_60)
+#  endif
+#  ifdef XLAT_STR_61
+  + sizeof(XLAT_STR_61)
+#  endif
+#  ifdef XLAT_STR_62
+  + sizeof(XLAT_STR_62)
+#  endif
+#  ifdef XLAT_STR_63
+  + sizeof(XLAT_STR_63)
+#  endif
+#  ifdef XLAT_STR_64
+  + sizeof(XLAT_STR_64)
+#  endif
+#  ifdef XLAT_STR_65
+  + sizeof(XLAT_STR_65)
+#  endif
+#  ifdef XLAT_STR_66
+  + sizeof(XLAT_STR_66)
+#  endif
+#  ifdef XLAT_STR_67
+  + sizeof(XLAT_STR_67)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
+#  undef XLAT_STR_47
+#  undef XLAT_VAL_47
+#  undef XLAT_STR_48
+#  undef XLAT_VAL_48
+#  undef XLAT_STR_49
+#  undef XLAT_VAL_49
+#  undef XLAT_STR_50
+#  undef XLAT_VAL_50
+#  undef XLAT_STR_51
+#  undef XLAT_VAL_51
+#  undef XLAT_STR_52
+#  undef XLAT_VAL_52
+#  undef XLAT_STR_53
+#  undef XLAT_VAL_53
+#  undef XLAT_STR_54
+#  undef XLAT_VAL_54
+#  undef XLAT_STR_55
+#  undef XLAT_VAL_55
+#  undef XLAT_STR_56
+#  undef XLAT_VAL_56
+#  undef XLAT_STR_57
+#  undef XLAT_VAL_57
+#  undef XLAT_STR_58
+#  undef XLAT_VAL_58
+#  undef XLAT_STR_59
+#  undef XLAT_VAL_59
+#  undef XLAT_STR_60
+#  undef XLAT_VAL_60
+#  undef XLAT_STR_61
+#  undef XLAT_VAL_61
+#  undef XLAT_STR_62
+#  undef XLAT_VAL_62
+#  undef XLAT_STR_63
+#  undef XLAT_VAL_63
+#  undef XLAT_STR_64
+#  undef XLAT_VAL_64
+#  undef XLAT_STR_65
+#  undef XLAT_VAL_65
+#  undef XLAT_STR_66
+#  undef XLAT_VAL_66
+#  undef XLAT_STR_67
+#  undef XLAT_VAL_67
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sysctl_kern.in 5.9-0ubuntu2/xlat/sysctl_kern.in
--- 5.5-3/xlat/sysctl_kern.in	2019-01-05 21:14:42.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_kern.in	2020-05-30 08:00:00.000000000 +0000
@@ -1,3 +1,6 @@
+#enum
+#include <sys/types.h>
+#include <linux/sysctl.h>
 #unconditional
 KERN_OSTYPE
 KERN_OSRELEASE
diff -pruN 5.5-3/xlat/sysctl_kern.m4 5.9-0ubuntu2/xlat/sysctl_kern.m4
--- 5.5-3/xlat/sysctl_kern.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_kern.m4	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,75 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/sysctl_kern.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_sysctl_kern],[
+AC_CHECK_DECLS(m4_normalize([
+KERN_OSTYPE,
+KERN_OSRELEASE,
+KERN_OSREV,
+KERN_VERSION,
+KERN_SECUREMASK,
+KERN_PROF,
+KERN_NODENAME,
+KERN_DOMAINNAME,
+KERN_PANIC,
+KERN_REALROOTDEV,
+KERN_SPARC_REBOOT,
+KERN_CTLALTDEL,
+KERN_PRINTK,
+KERN_NAMETRANS,
+KERN_PPC_HTABRECLAIM,
+KERN_PPC_ZEROPAGED,
+KERN_PPC_POWERSAVE_NAP,
+KERN_MODPROBE,
+KERN_SG_BIG_BUFF,
+KERN_ACCT,
+KERN_PPC_L2CR,
+KERN_RTSIGNR,
+KERN_RTSIGMAX,
+KERN_SHMMAX,
+KERN_MSGMAX,
+KERN_MSGMNB,
+KERN_MSGPOOL,
+KERN_SYSRQ,
+KERN_MAX_THREADS,
+KERN_RANDOM,
+KERN_SHMALL,
+KERN_MSGMNI,
+KERN_SEM,
+KERN_SPARC_STOP_A,
+KERN_SHMMNI,
+KERN_OVERFLOWUID,
+KERN_OVERFLOWGID,
+KERN_SHMPATH,
+KERN_HOTPLUG,
+KERN_IEEE_EMULATION_WARNINGS,
+KERN_S390_USER_DEBUG_LOGGING,
+KERN_CORE_USES_PID,
+KERN_TAINTED,
+KERN_CADPID,
+KERN_PIDMAX,
+KERN_CORE_PATTERN,
+KERN_PANIC_ON_OOPS,
+KERN_HPPA_PWRSW,
+KERN_HPPA_UNALIGNED,
+KERN_PRINTK_RATELIMIT,
+KERN_PRINTK_RATELIMIT_BURST,
+KERN_PTY,
+KERN_NGROUPS_MAX,
+KERN_SPARC_SCONS_PWROFF,
+KERN_HZ_TIMER,
+KERN_UNKNOWN_NMI_PANIC,
+KERN_BOOTLOADER_TYPE,
+KERN_RANDOMIZE,
+KERN_SETUID_DUMPABLE,
+KERN_SPIN_RETRY,
+KERN_ACPI_VIDEO_FLAGS,
+KERN_IA64_UNALIGNED,
+KERN_COMPAT_LOG,
+KERN_MAX_LOCK_DEPTH,
+KERN_NMI_WATCHDOG,
+KERN_PANIC_ON_NMI,
+KERN_PANIC_ON_WARN,
+KERN_PANIC_PRINT
+]),,, [
+#include <sys/types.h>
+#include <linux/sysctl.h>
+])])])
diff -pruN 5.5-3/xlat/sysctl_net_core.h 5.9-0ubuntu2/xlat/sysctl_net_core.h
--- 5.5-3/xlat/sysctl_net_core.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_net_core.h	2020-09-24 09:18:46.000000000 +0000
@@ -14,36 +14,80 @@
 
 static const struct xlat_data sysctl_net_core_xdata[] = {
  XLAT(NET_CORE_WMEM_MAX),
+ #define XLAT_VAL_0 ((unsigned) (NET_CORE_WMEM_MAX))
+ #define XLAT_STR_0 STRINGIFY(NET_CORE_WMEM_MAX)
  XLAT(NET_CORE_RMEM_MAX),
+ #define XLAT_VAL_1 ((unsigned) (NET_CORE_RMEM_MAX))
+ #define XLAT_STR_1 STRINGIFY(NET_CORE_RMEM_MAX)
  XLAT(NET_CORE_WMEM_DEFAULT),
+ #define XLAT_VAL_2 ((unsigned) (NET_CORE_WMEM_DEFAULT))
+ #define XLAT_STR_2 STRINGIFY(NET_CORE_WMEM_DEFAULT)
  XLAT(NET_CORE_RMEM_DEFAULT),
+ #define XLAT_VAL_3 ((unsigned) (NET_CORE_RMEM_DEFAULT))
+ #define XLAT_STR_3 STRINGIFY(NET_CORE_RMEM_DEFAULT)
  XLAT(NET_CORE_MAX_BACKLOG),
+ #define XLAT_VAL_4 ((unsigned) (NET_CORE_MAX_BACKLOG))
+ #define XLAT_STR_4 STRINGIFY(NET_CORE_MAX_BACKLOG)
  XLAT(NET_CORE_FASTROUTE),
+ #define XLAT_VAL_5 ((unsigned) (NET_CORE_FASTROUTE))
+ #define XLAT_STR_5 STRINGIFY(NET_CORE_FASTROUTE)
  XLAT(NET_CORE_MSG_COST),
+ #define XLAT_VAL_6 ((unsigned) (NET_CORE_MSG_COST))
+ #define XLAT_STR_6 STRINGIFY(NET_CORE_MSG_COST)
  XLAT(NET_CORE_MSG_BURST),
+ #define XLAT_VAL_7 ((unsigned) (NET_CORE_MSG_BURST))
+ #define XLAT_STR_7 STRINGIFY(NET_CORE_MSG_BURST)
  XLAT(NET_CORE_OPTMEM_MAX),
+ #define XLAT_VAL_8 ((unsigned) (NET_CORE_OPTMEM_MAX))
+ #define XLAT_STR_8 STRINGIFY(NET_CORE_OPTMEM_MAX)
  XLAT(NET_CORE_HOT_LIST_LENGTH),
+ #define XLAT_VAL_9 ((unsigned) (NET_CORE_HOT_LIST_LENGTH))
+ #define XLAT_STR_9 STRINGIFY(NET_CORE_HOT_LIST_LENGTH)
  XLAT(NET_CORE_DIVERT_VERSION),
+ #define XLAT_VAL_10 ((unsigned) (NET_CORE_DIVERT_VERSION))
+ #define XLAT_STR_10 STRINGIFY(NET_CORE_DIVERT_VERSION)
  XLAT(NET_CORE_NO_CONG_THRESH),
+ #define XLAT_VAL_11 ((unsigned) (NET_CORE_NO_CONG_THRESH))
+ #define XLAT_STR_11 STRINGIFY(NET_CORE_NO_CONG_THRESH)
  XLAT(NET_CORE_NO_CONG),
+ #define XLAT_VAL_12 ((unsigned) (NET_CORE_NO_CONG))
+ #define XLAT_STR_12 STRINGIFY(NET_CORE_NO_CONG)
  XLAT(NET_CORE_LO_CONG),
+ #define XLAT_VAL_13 ((unsigned) (NET_CORE_LO_CONG))
+ #define XLAT_STR_13 STRINGIFY(NET_CORE_LO_CONG)
  XLAT(NET_CORE_MOD_CONG),
+ #define XLAT_VAL_14 ((unsigned) (NET_CORE_MOD_CONG))
+ #define XLAT_STR_14 STRINGIFY(NET_CORE_MOD_CONG)
  XLAT(NET_CORE_DEV_WEIGHT),
+ #define XLAT_VAL_15 ((unsigned) (NET_CORE_DEV_WEIGHT))
+ #define XLAT_STR_15 STRINGIFY(NET_CORE_DEV_WEIGHT)
  XLAT(NET_CORE_SOMAXCONN),
+ #define XLAT_VAL_16 ((unsigned) (NET_CORE_SOMAXCONN))
+ #define XLAT_STR_16 STRINGIFY(NET_CORE_SOMAXCONN)
 #if defined(NET_CORE_DESTROY_DELAY) || (defined(HAVE_DECL_NET_CORE_DESTROY_DELAY) && HAVE_DECL_NET_CORE_DESTROY_DELAY)
   XLAT(NET_CORE_DESTROY_DELAY),
+ #define XLAT_VAL_17 ((unsigned) (NET_CORE_DESTROY_DELAY))
+ #define XLAT_STR_17 STRINGIFY(NET_CORE_DESTROY_DELAY)
 #endif
 #if defined(NET_CORE_BUDGET) || (defined(HAVE_DECL_NET_CORE_BUDGET) && HAVE_DECL_NET_CORE_BUDGET)
   XLAT(NET_CORE_BUDGET),
+ #define XLAT_VAL_18 ((unsigned) (NET_CORE_BUDGET))
+ #define XLAT_STR_18 STRINGIFY(NET_CORE_BUDGET)
 #endif
 #if defined(NET_CORE_AEVENT_ETIME) || (defined(HAVE_DECL_NET_CORE_AEVENT_ETIME) && HAVE_DECL_NET_CORE_AEVENT_ETIME)
   XLAT(NET_CORE_AEVENT_ETIME),
+ #define XLAT_VAL_19 ((unsigned) (NET_CORE_AEVENT_ETIME))
+ #define XLAT_STR_19 STRINGIFY(NET_CORE_AEVENT_ETIME)
 #endif
 #if defined(NET_CORE_AEVENT_RSEQTH) || (defined(HAVE_DECL_NET_CORE_AEVENT_RSEQTH) && HAVE_DECL_NET_CORE_AEVENT_RSEQTH)
   XLAT(NET_CORE_AEVENT_RSEQTH),
+ #define XLAT_VAL_20 ((unsigned) (NET_CORE_AEVENT_RSEQTH))
+ #define XLAT_STR_20 STRINGIFY(NET_CORE_AEVENT_RSEQTH)
 #endif
 #if defined(NET_CORE_WARNINGS) || (defined(HAVE_DECL_NET_CORE_WARNINGS) && HAVE_DECL_NET_CORE_WARNINGS)
   XLAT(NET_CORE_WARNINGS),
+ #define XLAT_VAL_21 ((unsigned) (NET_CORE_WARNINGS))
+ #define XLAT_STR_21 STRINGIFY(NET_CORE_WARNINGS)
 #endif
 };
 static
@@ -51,8 +95,188 @@ const struct xlat sysctl_net_core[1] = {
  .data = sysctl_net_core_xdata,
  .size = ARRAY_SIZE(sysctl_net_core_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sysctl_net_core.in 5.9-0ubuntu2/xlat/sysctl_net_core.in
--- 5.5-3/xlat/sysctl_net_core.in	2016-06-06 18:07:04.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_net_core.in	2020-05-30 08:00:00.000000000 +0000
@@ -1,3 +1,6 @@
+#enum
+#include <sys/types.h>
+#include <linux/sysctl.h>
 #unconditional
 NET_CORE_WMEM_MAX
 NET_CORE_RMEM_MAX
diff -pruN 5.5-3/xlat/sysctl_net_core.m4 5.9-0ubuntu2/xlat/sysctl_net_core.m4
--- 5.5-3/xlat/sysctl_net_core.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_net_core.m4	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,29 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/sysctl_net_core.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_sysctl_net_core],[
+AC_CHECK_DECLS(m4_normalize([
+NET_CORE_WMEM_MAX,
+NET_CORE_RMEM_MAX,
+NET_CORE_WMEM_DEFAULT,
+NET_CORE_RMEM_DEFAULT,
+NET_CORE_MAX_BACKLOG,
+NET_CORE_FASTROUTE,
+NET_CORE_MSG_COST,
+NET_CORE_MSG_BURST,
+NET_CORE_OPTMEM_MAX,
+NET_CORE_HOT_LIST_LENGTH,
+NET_CORE_DIVERT_VERSION,
+NET_CORE_NO_CONG_THRESH,
+NET_CORE_NO_CONG,
+NET_CORE_LO_CONG,
+NET_CORE_MOD_CONG,
+NET_CORE_DEV_WEIGHT,
+NET_CORE_SOMAXCONN,
+NET_CORE_DESTROY_DELAY,
+NET_CORE_BUDGET,
+NET_CORE_AEVENT_ETIME,
+NET_CORE_AEVENT_RSEQTH,
+NET_CORE_WARNINGS
+]),,, [
+#include <sys/types.h>
+#include <linux/sysctl.h>
+])])])
diff -pruN 5.5-3/xlat/sysctl_net.h 5.9-0ubuntu2/xlat/sysctl_net.h
--- 5.5-3/xlat/sysctl_net.h	2020-02-06 16:23:25.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_net.h	2020-09-24 09:18:46.000000000 +0000
@@ -14,33 +14,75 @@
 
 static const struct xlat_data sysctl_net_xdata[] = {
  XLAT(NET_CORE),
+ #define XLAT_VAL_0 ((unsigned) (NET_CORE))
+ #define XLAT_STR_0 STRINGIFY(NET_CORE)
  XLAT(NET_ETHER),
+ #define XLAT_VAL_1 ((unsigned) (NET_ETHER))
+ #define XLAT_STR_1 STRINGIFY(NET_ETHER)
  XLAT(NET_802),
+ #define XLAT_VAL_2 ((unsigned) (NET_802))
+ #define XLAT_STR_2 STRINGIFY(NET_802)
  XLAT(NET_UNIX),
+ #define XLAT_VAL_3 ((unsigned) (NET_UNIX))
+ #define XLAT_STR_3 STRINGIFY(NET_UNIX)
  XLAT(NET_IPV4),
+ #define XLAT_VAL_4 ((unsigned) (NET_IPV4))
+ #define XLAT_STR_4 STRINGIFY(NET_IPV4)
  XLAT(NET_IPX),
+ #define XLAT_VAL_5 ((unsigned) (NET_IPX))
+ #define XLAT_STR_5 STRINGIFY(NET_IPX)
  XLAT(NET_ATALK),
+ #define XLAT_VAL_6 ((unsigned) (NET_ATALK))
+ #define XLAT_STR_6 STRINGIFY(NET_ATALK)
  XLAT(NET_NETROM),
+ #define XLAT_VAL_7 ((unsigned) (NET_NETROM))
+ #define XLAT_STR_7 STRINGIFY(NET_NETROM)
  XLAT(NET_AX25),
+ #define XLAT_VAL_8 ((unsigned) (NET_AX25))
+ #define XLAT_STR_8 STRINGIFY(NET_AX25)
  XLAT(NET_BRIDGE),
+ #define XLAT_VAL_9 ((unsigned) (NET_BRIDGE))
+ #define XLAT_STR_9 STRINGIFY(NET_BRIDGE)
  XLAT(NET_ROSE),
+ #define XLAT_VAL_10 ((unsigned) (NET_ROSE))
+ #define XLAT_STR_10 STRINGIFY(NET_ROSE)
  XLAT(NET_IPV6),
+ #define XLAT_VAL_11 ((unsigned) (NET_IPV6))
+ #define XLAT_STR_11 STRINGIFY(NET_IPV6)
  XLAT(NET_X25),
+ #define XLAT_VAL_12 ((unsigned) (NET_X25))
+ #define XLAT_STR_12 STRINGIFY(NET_X25)
  XLAT(NET_TR),
+ #define XLAT_VAL_13 ((unsigned) (NET_TR))
+ #define XLAT_STR_13 STRINGIFY(NET_TR)
  XLAT(NET_DECNET),
+ #define XLAT_VAL_14 ((unsigned) (NET_DECNET))
+ #define XLAT_STR_14 STRINGIFY(NET_DECNET)
  XLAT(NET_ECONET),
+ #define XLAT_VAL_15 ((unsigned) (NET_ECONET))
+ #define XLAT_STR_15 STRINGIFY(NET_ECONET)
  XLAT(NET_SCTP),
+ #define XLAT_VAL_16 ((unsigned) (NET_SCTP))
+ #define XLAT_STR_16 STRINGIFY(NET_SCTP)
 #if defined(NET_LLC) || (defined(HAVE_DECL_NET_LLC) && HAVE_DECL_NET_LLC)
   XLAT(NET_LLC),
+ #define XLAT_VAL_17 ((unsigned) (NET_LLC))
+ #define XLAT_STR_17 STRINGIFY(NET_LLC)
 #endif
 #if defined(NET_NETFILTER) || (defined(HAVE_DECL_NET_NETFILTER) && HAVE_DECL_NET_NETFILTER)
   XLAT(NET_NETFILTER),
+ #define XLAT_VAL_18 ((unsigned) (NET_NETFILTER))
+ #define XLAT_STR_18 STRINGIFY(NET_NETFILTER)
 #endif
 #if defined(NET_DCCP) || (defined(HAVE_DECL_NET_DCCP) && HAVE_DECL_NET_DCCP)
   XLAT(NET_DCCP),
+ #define XLAT_VAL_19 ((unsigned) (NET_DCCP))
+ #define XLAT_STR_19 STRINGIFY(NET_DCCP)
 #endif
 #if defined(NET_IRDA) || (defined(HAVE_DECL_NET_IRDA) && HAVE_DECL_NET_IRDA)
   XLAT(NET_IRDA),
+ #define XLAT_VAL_20 ((unsigned) (NET_IRDA))
+ #define XLAT_STR_20 STRINGIFY(NET_IRDA)
 #endif
 };
 static
@@ -48,8 +90,180 @@ const struct xlat sysctl_net[1] = { {
  .data = sysctl_net_xdata,
  .size = ARRAY_SIZE(sysctl_net_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sysctl_net.in 5.9-0ubuntu2/xlat/sysctl_net.in
--- 5.5-3/xlat/sysctl_net.in	2016-06-06 18:07:04.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_net.in	2020-05-30 08:00:00.000000000 +0000
@@ -1,3 +1,6 @@
+#enum
+#include <sys/types.h>
+#include <linux/sysctl.h>
 #unconditional
 NET_CORE
 NET_ETHER
diff -pruN 5.5-3/xlat/sysctl_net_ipv4_conf.h 5.9-0ubuntu2/xlat/sysctl_net_ipv4_conf.h
--- 5.5-3/xlat/sysctl_net_ipv4_conf.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_net_ipv4_conf.h	2020-09-24 09:18:46.000000000 +0000
@@ -14,38 +14,82 @@
 
 static const struct xlat_data sysctl_net_ipv4_conf_xdata[] = {
  XLAT(NET_IPV4_CONF_FORWARDING),
+ #define XLAT_VAL_0 ((unsigned) (NET_IPV4_CONF_FORWARDING))
+ #define XLAT_STR_0 STRINGIFY(NET_IPV4_CONF_FORWARDING)
  XLAT(NET_IPV4_CONF_MC_FORWARDING),
+ #define XLAT_VAL_1 ((unsigned) (NET_IPV4_CONF_MC_FORWARDING))
+ #define XLAT_STR_1 STRINGIFY(NET_IPV4_CONF_MC_FORWARDING)
  XLAT(NET_IPV4_CONF_PROXY_ARP),
+ #define XLAT_VAL_2 ((unsigned) (NET_IPV4_CONF_PROXY_ARP))
+ #define XLAT_STR_2 STRINGIFY(NET_IPV4_CONF_PROXY_ARP)
  XLAT(NET_IPV4_CONF_ACCEPT_REDIRECTS),
+ #define XLAT_VAL_3 ((unsigned) (NET_IPV4_CONF_ACCEPT_REDIRECTS))
+ #define XLAT_STR_3 STRINGIFY(NET_IPV4_CONF_ACCEPT_REDIRECTS)
  XLAT(NET_IPV4_CONF_SECURE_REDIRECTS),
+ #define XLAT_VAL_4 ((unsigned) (NET_IPV4_CONF_SECURE_REDIRECTS))
+ #define XLAT_STR_4 STRINGIFY(NET_IPV4_CONF_SECURE_REDIRECTS)
  XLAT(NET_IPV4_CONF_SEND_REDIRECTS),
+ #define XLAT_VAL_5 ((unsigned) (NET_IPV4_CONF_SEND_REDIRECTS))
+ #define XLAT_STR_5 STRINGIFY(NET_IPV4_CONF_SEND_REDIRECTS)
  XLAT(NET_IPV4_CONF_SHARED_MEDIA),
+ #define XLAT_VAL_6 ((unsigned) (NET_IPV4_CONF_SHARED_MEDIA))
+ #define XLAT_STR_6 STRINGIFY(NET_IPV4_CONF_SHARED_MEDIA)
  XLAT(NET_IPV4_CONF_RP_FILTER),
+ #define XLAT_VAL_7 ((unsigned) (NET_IPV4_CONF_RP_FILTER))
+ #define XLAT_STR_7 STRINGIFY(NET_IPV4_CONF_RP_FILTER)
  XLAT(NET_IPV4_CONF_ACCEPT_SOURCE_ROUTE),
+ #define XLAT_VAL_8 ((unsigned) (NET_IPV4_CONF_ACCEPT_SOURCE_ROUTE))
+ #define XLAT_STR_8 STRINGIFY(NET_IPV4_CONF_ACCEPT_SOURCE_ROUTE)
  XLAT(NET_IPV4_CONF_BOOTP_RELAY),
+ #define XLAT_VAL_9 ((unsigned) (NET_IPV4_CONF_BOOTP_RELAY))
+ #define XLAT_STR_9 STRINGIFY(NET_IPV4_CONF_BOOTP_RELAY)
  XLAT(NET_IPV4_CONF_LOG_MARTIANS),
+ #define XLAT_VAL_10 ((unsigned) (NET_IPV4_CONF_LOG_MARTIANS))
+ #define XLAT_STR_10 STRINGIFY(NET_IPV4_CONF_LOG_MARTIANS)
  XLAT(NET_IPV4_CONF_TAG),
+ #define XLAT_VAL_11 ((unsigned) (NET_IPV4_CONF_TAG))
+ #define XLAT_STR_11 STRINGIFY(NET_IPV4_CONF_TAG)
  XLAT(NET_IPV4_CONF_ARPFILTER),
+ #define XLAT_VAL_12 ((unsigned) (NET_IPV4_CONF_ARPFILTER))
+ #define XLAT_STR_12 STRINGIFY(NET_IPV4_CONF_ARPFILTER)
  XLAT(NET_IPV4_CONF_MEDIUM_ID),
+ #define XLAT_VAL_13 ((unsigned) (NET_IPV4_CONF_MEDIUM_ID))
+ #define XLAT_STR_13 STRINGIFY(NET_IPV4_CONF_MEDIUM_ID)
  XLAT(NET_IPV4_CONF_NOXFRM),
+ #define XLAT_VAL_14 ((unsigned) (NET_IPV4_CONF_NOXFRM))
+ #define XLAT_STR_14 STRINGIFY(NET_IPV4_CONF_NOXFRM)
  XLAT(NET_IPV4_CONF_NOPOLICY),
+ #define XLAT_VAL_15 ((unsigned) (NET_IPV4_CONF_NOPOLICY))
+ #define XLAT_STR_15 STRINGIFY(NET_IPV4_CONF_NOPOLICY)
 #if defined(NET_IPV4_CONF_FORCE_IGMP_VERSION) || (defined(HAVE_DECL_NET_IPV4_CONF_FORCE_IGMP_VERSION) && HAVE_DECL_NET_IPV4_CONF_FORCE_IGMP_VERSION)
   XLAT(NET_IPV4_CONF_FORCE_IGMP_VERSION),
+ #define XLAT_VAL_16 ((unsigned) (NET_IPV4_CONF_FORCE_IGMP_VERSION))
+ #define XLAT_STR_16 STRINGIFY(NET_IPV4_CONF_FORCE_IGMP_VERSION)
 #endif
 #if defined(NET_IPV4_CONF_ARP_ANNOUNCE) || (defined(HAVE_DECL_NET_IPV4_CONF_ARP_ANNOUNCE) && HAVE_DECL_NET_IPV4_CONF_ARP_ANNOUNCE)
   XLAT(NET_IPV4_CONF_ARP_ANNOUNCE),
+ #define XLAT_VAL_17 ((unsigned) (NET_IPV4_CONF_ARP_ANNOUNCE))
+ #define XLAT_STR_17 STRINGIFY(NET_IPV4_CONF_ARP_ANNOUNCE)
 #endif
 #if defined(NET_IPV4_CONF_ARP_IGNORE) || (defined(HAVE_DECL_NET_IPV4_CONF_ARP_IGNORE) && HAVE_DECL_NET_IPV4_CONF_ARP_IGNORE)
   XLAT(NET_IPV4_CONF_ARP_IGNORE),
+ #define XLAT_VAL_18 ((unsigned) (NET_IPV4_CONF_ARP_IGNORE))
+ #define XLAT_STR_18 STRINGIFY(NET_IPV4_CONF_ARP_IGNORE)
 #endif
 #if defined(NET_IPV4_CONF_PROMOTE_SECONDARIES) || (defined(HAVE_DECL_NET_IPV4_CONF_PROMOTE_SECONDARIES) && HAVE_DECL_NET_IPV4_CONF_PROMOTE_SECONDARIES)
   XLAT(NET_IPV4_CONF_PROMOTE_SECONDARIES),
+ #define XLAT_VAL_19 ((unsigned) (NET_IPV4_CONF_PROMOTE_SECONDARIES))
+ #define XLAT_STR_19 STRINGIFY(NET_IPV4_CONF_PROMOTE_SECONDARIES)
 #endif
 #if defined(NET_IPV4_CONF_ARP_ACCEPT) || (defined(HAVE_DECL_NET_IPV4_CONF_ARP_ACCEPT) && HAVE_DECL_NET_IPV4_CONF_ARP_ACCEPT)
   XLAT(NET_IPV4_CONF_ARP_ACCEPT),
+ #define XLAT_VAL_20 ((unsigned) (NET_IPV4_CONF_ARP_ACCEPT))
+ #define XLAT_STR_20 STRINGIFY(NET_IPV4_CONF_ARP_ACCEPT)
 #endif
 #if defined(NET_IPV4_CONF_ARP_NOTIFY) || (defined(HAVE_DECL_NET_IPV4_CONF_ARP_NOTIFY) && HAVE_DECL_NET_IPV4_CONF_ARP_NOTIFY)
   XLAT(NET_IPV4_CONF_ARP_NOTIFY),
+ #define XLAT_VAL_21 ((unsigned) (NET_IPV4_CONF_ARP_NOTIFY))
+ #define XLAT_STR_21 STRINGIFY(NET_IPV4_CONF_ARP_NOTIFY)
 #endif
 };
 static
@@ -53,8 +97,188 @@ const struct xlat sysctl_net_ipv4_conf[1
  .data = sysctl_net_ipv4_conf_xdata,
  .size = ARRAY_SIZE(sysctl_net_ipv4_conf_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sysctl_net_ipv4_conf.in 5.9-0ubuntu2/xlat/sysctl_net_ipv4_conf.in
--- 5.5-3/xlat/sysctl_net_ipv4_conf.in	2016-06-06 18:07:04.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_net_ipv4_conf.in	2020-05-30 08:00:00.000000000 +0000
@@ -1,3 +1,6 @@
+#enum
+#include <sys/types.h>
+#include <linux/sysctl.h>
 #unconditional
 NET_IPV4_CONF_FORWARDING
 NET_IPV4_CONF_MC_FORWARDING
diff -pruN 5.5-3/xlat/sysctl_net_ipv4_conf.m4 5.9-0ubuntu2/xlat/sysctl_net_ipv4_conf.m4
--- 5.5-3/xlat/sysctl_net_ipv4_conf.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_net_ipv4_conf.m4	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,29 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/sysctl_net_ipv4_conf.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_sysctl_net_ipv4_conf],[
+AC_CHECK_DECLS(m4_normalize([
+NET_IPV4_CONF_FORWARDING,
+NET_IPV4_CONF_MC_FORWARDING,
+NET_IPV4_CONF_PROXY_ARP,
+NET_IPV4_CONF_ACCEPT_REDIRECTS,
+NET_IPV4_CONF_SECURE_REDIRECTS,
+NET_IPV4_CONF_SEND_REDIRECTS,
+NET_IPV4_CONF_SHARED_MEDIA,
+NET_IPV4_CONF_RP_FILTER,
+NET_IPV4_CONF_ACCEPT_SOURCE_ROUTE,
+NET_IPV4_CONF_BOOTP_RELAY,
+NET_IPV4_CONF_LOG_MARTIANS,
+NET_IPV4_CONF_TAG,
+NET_IPV4_CONF_ARPFILTER,
+NET_IPV4_CONF_MEDIUM_ID,
+NET_IPV4_CONF_NOXFRM,
+NET_IPV4_CONF_NOPOLICY,
+NET_IPV4_CONF_FORCE_IGMP_VERSION,
+NET_IPV4_CONF_ARP_ANNOUNCE,
+NET_IPV4_CONF_ARP_IGNORE,
+NET_IPV4_CONF_PROMOTE_SECONDARIES,
+NET_IPV4_CONF_ARP_ACCEPT,
+NET_IPV4_CONF_ARP_NOTIFY
+]),,, [
+#include <sys/types.h>
+#include <linux/sysctl.h>
+])])])
diff -pruN 5.5-3/xlat/sysctl_net_ipv4.h 5.9-0ubuntu2/xlat/sysctl_net_ipv4.h
--- 5.5-3/xlat/sysctl_net_ipv4.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_net_ipv4.h	2020-09-24 09:18:47.000000000 +0000
@@ -14,142 +14,326 @@
 
 static const struct xlat_data sysctl_net_ipv4_xdata[] = {
  XLAT(NET_IPV4_FORWARD),
+ #define XLAT_VAL_0 ((unsigned) (NET_IPV4_FORWARD))
+ #define XLAT_STR_0 STRINGIFY(NET_IPV4_FORWARD)
  XLAT(NET_IPV4_DYNADDR),
+ #define XLAT_VAL_1 ((unsigned) (NET_IPV4_DYNADDR))
+ #define XLAT_STR_1 STRINGIFY(NET_IPV4_DYNADDR)
  XLAT(NET_IPV4_CONF),
+ #define XLAT_VAL_2 ((unsigned) (NET_IPV4_CONF))
+ #define XLAT_STR_2 STRINGIFY(NET_IPV4_CONF)
  XLAT(NET_IPV4_NEIGH),
+ #define XLAT_VAL_3 ((unsigned) (NET_IPV4_NEIGH))
+ #define XLAT_STR_3 STRINGIFY(NET_IPV4_NEIGH)
  XLAT(NET_IPV4_ROUTE),
+ #define XLAT_VAL_4 ((unsigned) (NET_IPV4_ROUTE))
+ #define XLAT_STR_4 STRINGIFY(NET_IPV4_ROUTE)
  XLAT(NET_IPV4_FIB_HASH),
+ #define XLAT_VAL_5 ((unsigned) (NET_IPV4_FIB_HASH))
+ #define XLAT_STR_5 STRINGIFY(NET_IPV4_FIB_HASH)
  XLAT(NET_IPV4_NETFILTER),
+ #define XLAT_VAL_6 ((unsigned) (NET_IPV4_NETFILTER))
+ #define XLAT_STR_6 STRINGIFY(NET_IPV4_NETFILTER)
  XLAT(NET_IPV4_TCP_TIMESTAMPS),
+ #define XLAT_VAL_7 ((unsigned) (NET_IPV4_TCP_TIMESTAMPS))
+ #define XLAT_STR_7 STRINGIFY(NET_IPV4_TCP_TIMESTAMPS)
  XLAT(NET_IPV4_TCP_WINDOW_SCALING),
+ #define XLAT_VAL_8 ((unsigned) (NET_IPV4_TCP_WINDOW_SCALING))
+ #define XLAT_STR_8 STRINGIFY(NET_IPV4_TCP_WINDOW_SCALING)
  XLAT(NET_IPV4_TCP_SACK),
+ #define XLAT_VAL_9 ((unsigned) (NET_IPV4_TCP_SACK))
+ #define XLAT_STR_9 STRINGIFY(NET_IPV4_TCP_SACK)
  XLAT(NET_IPV4_TCP_RETRANS_COLLAPSE),
+ #define XLAT_VAL_10 ((unsigned) (NET_IPV4_TCP_RETRANS_COLLAPSE))
+ #define XLAT_STR_10 STRINGIFY(NET_IPV4_TCP_RETRANS_COLLAPSE)
  XLAT(NET_IPV4_DEFAULT_TTL),
+ #define XLAT_VAL_11 ((unsigned) (NET_IPV4_DEFAULT_TTL))
+ #define XLAT_STR_11 STRINGIFY(NET_IPV4_DEFAULT_TTL)
  XLAT(NET_IPV4_AUTOCONFIG),
+ #define XLAT_VAL_12 ((unsigned) (NET_IPV4_AUTOCONFIG))
+ #define XLAT_STR_12 STRINGIFY(NET_IPV4_AUTOCONFIG)
  XLAT(NET_IPV4_NO_PMTU_DISC),
+ #define XLAT_VAL_13 ((unsigned) (NET_IPV4_NO_PMTU_DISC))
+ #define XLAT_STR_13 STRINGIFY(NET_IPV4_NO_PMTU_DISC)
  XLAT(NET_IPV4_TCP_SYN_RETRIES),
+ #define XLAT_VAL_14 ((unsigned) (NET_IPV4_TCP_SYN_RETRIES))
+ #define XLAT_STR_14 STRINGIFY(NET_IPV4_TCP_SYN_RETRIES)
  XLAT(NET_IPV4_IPFRAG_HIGH_THRESH),
+ #define XLAT_VAL_15 ((unsigned) (NET_IPV4_IPFRAG_HIGH_THRESH))
+ #define XLAT_STR_15 STRINGIFY(NET_IPV4_IPFRAG_HIGH_THRESH)
  XLAT(NET_IPV4_IPFRAG_LOW_THRESH),
+ #define XLAT_VAL_16 ((unsigned) (NET_IPV4_IPFRAG_LOW_THRESH))
+ #define XLAT_STR_16 STRINGIFY(NET_IPV4_IPFRAG_LOW_THRESH)
  XLAT(NET_IPV4_IPFRAG_TIME),
+ #define XLAT_VAL_17 ((unsigned) (NET_IPV4_IPFRAG_TIME))
+ #define XLAT_STR_17 STRINGIFY(NET_IPV4_IPFRAG_TIME)
  XLAT(NET_IPV4_TCP_MAX_KA_PROBES),
+ #define XLAT_VAL_18 ((unsigned) (NET_IPV4_TCP_MAX_KA_PROBES))
+ #define XLAT_STR_18 STRINGIFY(NET_IPV4_TCP_MAX_KA_PROBES)
  XLAT(NET_IPV4_TCP_KEEPALIVE_TIME),
+ #define XLAT_VAL_19 ((unsigned) (NET_IPV4_TCP_KEEPALIVE_TIME))
+ #define XLAT_STR_19 STRINGIFY(NET_IPV4_TCP_KEEPALIVE_TIME)
  XLAT(NET_IPV4_TCP_KEEPALIVE_PROBES),
+ #define XLAT_VAL_20 ((unsigned) (NET_IPV4_TCP_KEEPALIVE_PROBES))
+ #define XLAT_STR_20 STRINGIFY(NET_IPV4_TCP_KEEPALIVE_PROBES)
  XLAT(NET_IPV4_TCP_RETRIES1),
+ #define XLAT_VAL_21 ((unsigned) (NET_IPV4_TCP_RETRIES1))
+ #define XLAT_STR_21 STRINGIFY(NET_IPV4_TCP_RETRIES1)
  XLAT(NET_IPV4_TCP_RETRIES2),
+ #define XLAT_VAL_22 ((unsigned) (NET_IPV4_TCP_RETRIES2))
+ #define XLAT_STR_22 STRINGIFY(NET_IPV4_TCP_RETRIES2)
  XLAT(NET_IPV4_TCP_FIN_TIMEOUT),
+ #define XLAT_VAL_23 ((unsigned) (NET_IPV4_TCP_FIN_TIMEOUT))
+ #define XLAT_STR_23 STRINGIFY(NET_IPV4_TCP_FIN_TIMEOUT)
  XLAT(NET_IPV4_IP_MASQ_DEBUG),
+ #define XLAT_VAL_24 ((unsigned) (NET_IPV4_IP_MASQ_DEBUG))
+ #define XLAT_STR_24 STRINGIFY(NET_IPV4_IP_MASQ_DEBUG)
  XLAT(NET_TCP_SYNCOOKIES),
+ #define XLAT_VAL_25 ((unsigned) (NET_TCP_SYNCOOKIES))
+ #define XLAT_STR_25 STRINGIFY(NET_TCP_SYNCOOKIES)
  XLAT(NET_TCP_STDURG),
+ #define XLAT_VAL_26 ((unsigned) (NET_TCP_STDURG))
+ #define XLAT_STR_26 STRINGIFY(NET_TCP_STDURG)
  XLAT(NET_TCP_RFC1337),
+ #define XLAT_VAL_27 ((unsigned) (NET_TCP_RFC1337))
+ #define XLAT_STR_27 STRINGIFY(NET_TCP_RFC1337)
  XLAT(NET_TCP_SYN_TAILDROP),
+ #define XLAT_VAL_28 ((unsigned) (NET_TCP_SYN_TAILDROP))
+ #define XLAT_STR_28 STRINGIFY(NET_TCP_SYN_TAILDROP)
  XLAT(NET_TCP_MAX_SYN_BACKLOG),
+ #define XLAT_VAL_29 ((unsigned) (NET_TCP_MAX_SYN_BACKLOG))
+ #define XLAT_STR_29 STRINGIFY(NET_TCP_MAX_SYN_BACKLOG)
  XLAT(NET_IPV4_LOCAL_PORT_RANGE),
+ #define XLAT_VAL_30 ((unsigned) (NET_IPV4_LOCAL_PORT_RANGE))
+ #define XLAT_STR_30 STRINGIFY(NET_IPV4_LOCAL_PORT_RANGE)
  XLAT(NET_IPV4_ICMP_ECHO_IGNORE_ALL),
+ #define XLAT_VAL_31 ((unsigned) (NET_IPV4_ICMP_ECHO_IGNORE_ALL))
+ #define XLAT_STR_31 STRINGIFY(NET_IPV4_ICMP_ECHO_IGNORE_ALL)
  XLAT(NET_IPV4_ICMP_ECHO_IGNORE_BROADCASTS),
+ #define XLAT_VAL_32 ((unsigned) (NET_IPV4_ICMP_ECHO_IGNORE_BROADCASTS))
+ #define XLAT_STR_32 STRINGIFY(NET_IPV4_ICMP_ECHO_IGNORE_BROADCASTS)
  XLAT(NET_IPV4_ICMP_SOURCEQUENCH_RATE),
+ #define XLAT_VAL_33 ((unsigned) (NET_IPV4_ICMP_SOURCEQUENCH_RATE))
+ #define XLAT_STR_33 STRINGIFY(NET_IPV4_ICMP_SOURCEQUENCH_RATE)
  XLAT(NET_IPV4_ICMP_DESTUNREACH_RATE),
+ #define XLAT_VAL_34 ((unsigned) (NET_IPV4_ICMP_DESTUNREACH_RATE))
+ #define XLAT_STR_34 STRINGIFY(NET_IPV4_ICMP_DESTUNREACH_RATE)
  XLAT(NET_IPV4_ICMP_TIMEEXCEED_RATE),
+ #define XLAT_VAL_35 ((unsigned) (NET_IPV4_ICMP_TIMEEXCEED_RATE))
+ #define XLAT_STR_35 STRINGIFY(NET_IPV4_ICMP_TIMEEXCEED_RATE)
  XLAT(NET_IPV4_ICMP_PARAMPROB_RATE),
+ #define XLAT_VAL_36 ((unsigned) (NET_IPV4_ICMP_PARAMPROB_RATE))
+ #define XLAT_STR_36 STRINGIFY(NET_IPV4_ICMP_PARAMPROB_RATE)
  XLAT(NET_IPV4_ICMP_ECHOREPLY_RATE),
+ #define XLAT_VAL_37 ((unsigned) (NET_IPV4_ICMP_ECHOREPLY_RATE))
+ #define XLAT_STR_37 STRINGIFY(NET_IPV4_ICMP_ECHOREPLY_RATE)
  XLAT(NET_IPV4_ICMP_IGNORE_BOGUS_ERROR_RESPONSES),
+ #define XLAT_VAL_38 ((unsigned) (NET_IPV4_ICMP_IGNORE_BOGUS_ERROR_RESPONSES))
+ #define XLAT_STR_38 STRINGIFY(NET_IPV4_ICMP_IGNORE_BOGUS_ERROR_RESPONSES)
  XLAT(NET_IPV4_IGMP_MAX_MEMBERSHIPS),
+ #define XLAT_VAL_39 ((unsigned) (NET_IPV4_IGMP_MAX_MEMBERSHIPS))
+ #define XLAT_STR_39 STRINGIFY(NET_IPV4_IGMP_MAX_MEMBERSHIPS)
  XLAT(NET_TCP_TW_RECYCLE),
+ #define XLAT_VAL_40 ((unsigned) (NET_TCP_TW_RECYCLE))
+ #define XLAT_STR_40 STRINGIFY(NET_TCP_TW_RECYCLE)
  XLAT(NET_IPV4_ALWAYS_DEFRAG),
+ #define XLAT_VAL_41 ((unsigned) (NET_IPV4_ALWAYS_DEFRAG))
+ #define XLAT_STR_41 STRINGIFY(NET_IPV4_ALWAYS_DEFRAG)
  XLAT(NET_IPV4_TCP_KEEPALIVE_INTVL),
+ #define XLAT_VAL_42 ((unsigned) (NET_IPV4_TCP_KEEPALIVE_INTVL))
+ #define XLAT_STR_42 STRINGIFY(NET_IPV4_TCP_KEEPALIVE_INTVL)
  XLAT(NET_IPV4_INET_PEER_THRESHOLD),
+ #define XLAT_VAL_43 ((unsigned) (NET_IPV4_INET_PEER_THRESHOLD))
+ #define XLAT_STR_43 STRINGIFY(NET_IPV4_INET_PEER_THRESHOLD)
  XLAT(NET_IPV4_INET_PEER_MINTTL),
+ #define XLAT_VAL_44 ((unsigned) (NET_IPV4_INET_PEER_MINTTL))
+ #define XLAT_STR_44 STRINGIFY(NET_IPV4_INET_PEER_MINTTL)
  XLAT(NET_IPV4_INET_PEER_MAXTTL),
+ #define XLAT_VAL_45 ((unsigned) (NET_IPV4_INET_PEER_MAXTTL))
+ #define XLAT_STR_45 STRINGIFY(NET_IPV4_INET_PEER_MAXTTL)
  XLAT(NET_IPV4_INET_PEER_GC_MINTIME),
+ #define XLAT_VAL_46 ((unsigned) (NET_IPV4_INET_PEER_GC_MINTIME))
+ #define XLAT_STR_46 STRINGIFY(NET_IPV4_INET_PEER_GC_MINTIME)
  XLAT(NET_IPV4_INET_PEER_GC_MAXTIME),
+ #define XLAT_VAL_47 ((unsigned) (NET_IPV4_INET_PEER_GC_MAXTIME))
+ #define XLAT_STR_47 STRINGIFY(NET_IPV4_INET_PEER_GC_MAXTIME)
  XLAT(NET_TCP_ORPHAN_RETRIES),
+ #define XLAT_VAL_48 ((unsigned) (NET_TCP_ORPHAN_RETRIES))
+ #define XLAT_STR_48 STRINGIFY(NET_TCP_ORPHAN_RETRIES)
  XLAT(NET_TCP_ABORT_ON_OVERFLOW),
+ #define XLAT_VAL_49 ((unsigned) (NET_TCP_ABORT_ON_OVERFLOW))
+ #define XLAT_STR_49 STRINGIFY(NET_TCP_ABORT_ON_OVERFLOW)
  XLAT(NET_TCP_SYNACK_RETRIES),
+ #define XLAT_VAL_50 ((unsigned) (NET_TCP_SYNACK_RETRIES))
+ #define XLAT_STR_50 STRINGIFY(NET_TCP_SYNACK_RETRIES)
  XLAT(NET_TCP_MAX_ORPHANS),
+ #define XLAT_VAL_51 ((unsigned) (NET_TCP_MAX_ORPHANS))
+ #define XLAT_STR_51 STRINGIFY(NET_TCP_MAX_ORPHANS)
  XLAT(NET_TCP_MAX_TW_BUCKETS),
+ #define XLAT_VAL_52 ((unsigned) (NET_TCP_MAX_TW_BUCKETS))
+ #define XLAT_STR_52 STRINGIFY(NET_TCP_MAX_TW_BUCKETS)
  XLAT(NET_TCP_FACK),
+ #define XLAT_VAL_53 ((unsigned) (NET_TCP_FACK))
+ #define XLAT_STR_53 STRINGIFY(NET_TCP_FACK)
  XLAT(NET_TCP_REORDERING),
+ #define XLAT_VAL_54 ((unsigned) (NET_TCP_REORDERING))
+ #define XLAT_STR_54 STRINGIFY(NET_TCP_REORDERING)
  XLAT(NET_TCP_ECN),
+ #define XLAT_VAL_55 ((unsigned) (NET_TCP_ECN))
+ #define XLAT_STR_55 STRINGIFY(NET_TCP_ECN)
  XLAT(NET_TCP_DSACK),
+ #define XLAT_VAL_56 ((unsigned) (NET_TCP_DSACK))
+ #define XLAT_STR_56 STRINGIFY(NET_TCP_DSACK)
  XLAT(NET_TCP_MEM),
+ #define XLAT_VAL_57 ((unsigned) (NET_TCP_MEM))
+ #define XLAT_STR_57 STRINGIFY(NET_TCP_MEM)
  XLAT(NET_TCP_WMEM),
+ #define XLAT_VAL_58 ((unsigned) (NET_TCP_WMEM))
+ #define XLAT_STR_58 STRINGIFY(NET_TCP_WMEM)
  XLAT(NET_TCP_RMEM),
+ #define XLAT_VAL_59 ((unsigned) (NET_TCP_RMEM))
+ #define XLAT_STR_59 STRINGIFY(NET_TCP_RMEM)
  XLAT(NET_TCP_APP_WIN),
+ #define XLAT_VAL_60 ((unsigned) (NET_TCP_APP_WIN))
+ #define XLAT_STR_60 STRINGIFY(NET_TCP_APP_WIN)
  XLAT(NET_TCP_ADV_WIN_SCALE),
+ #define XLAT_VAL_61 ((unsigned) (NET_TCP_ADV_WIN_SCALE))
+ #define XLAT_STR_61 STRINGIFY(NET_TCP_ADV_WIN_SCALE)
  XLAT(NET_IPV4_NONLOCAL_BIND),
+ #define XLAT_VAL_62 ((unsigned) (NET_IPV4_NONLOCAL_BIND))
+ #define XLAT_STR_62 STRINGIFY(NET_IPV4_NONLOCAL_BIND)
  XLAT(NET_IPV4_ICMP_RATELIMIT),
+ #define XLAT_VAL_63 ((unsigned) (NET_IPV4_ICMP_RATELIMIT))
+ #define XLAT_STR_63 STRINGIFY(NET_IPV4_ICMP_RATELIMIT)
  XLAT(NET_IPV4_ICMP_RATEMASK),
+ #define XLAT_VAL_64 ((unsigned) (NET_IPV4_ICMP_RATEMASK))
+ #define XLAT_STR_64 STRINGIFY(NET_IPV4_ICMP_RATEMASK)
  XLAT(NET_TCP_TW_REUSE),
+ #define XLAT_VAL_65 ((unsigned) (NET_TCP_TW_REUSE))
+ #define XLAT_STR_65 STRINGIFY(NET_TCP_TW_REUSE)
  XLAT(NET_TCP_FRTO),
+ #define XLAT_VAL_66 ((unsigned) (NET_TCP_FRTO))
+ #define XLAT_STR_66 STRINGIFY(NET_TCP_FRTO)
  XLAT(NET_TCP_LOW_LATENCY),
+ #define XLAT_VAL_67 ((unsigned) (NET_TCP_LOW_LATENCY))
+ #define XLAT_STR_67 STRINGIFY(NET_TCP_LOW_LATENCY)
  XLAT(NET_IPV4_IPFRAG_SECRET_INTERVAL),
+ #define XLAT_VAL_68 ((unsigned) (NET_IPV4_IPFRAG_SECRET_INTERVAL))
+ #define XLAT_STR_68 STRINGIFY(NET_IPV4_IPFRAG_SECRET_INTERVAL)
 #if defined(NET_IPV4_IGMP_MAX_MSF) || (defined(HAVE_DECL_NET_IPV4_IGMP_MAX_MSF) && HAVE_DECL_NET_IPV4_IGMP_MAX_MSF)
   XLAT(NET_IPV4_IGMP_MAX_MSF),
+ #define XLAT_VAL_69 ((unsigned) (NET_IPV4_IGMP_MAX_MSF))
+ #define XLAT_STR_69 STRINGIFY(NET_IPV4_IGMP_MAX_MSF)
 #endif
 #if defined(NET_TCP_NO_METRICS_SAVE) || (defined(HAVE_DECL_NET_TCP_NO_METRICS_SAVE) && HAVE_DECL_NET_TCP_NO_METRICS_SAVE)
   XLAT(NET_TCP_NO_METRICS_SAVE),
+ #define XLAT_VAL_70 ((unsigned) (NET_TCP_NO_METRICS_SAVE))
+ #define XLAT_STR_70 STRINGIFY(NET_TCP_NO_METRICS_SAVE)
 #endif
 #if defined(NET_TCP_DEFAULT_WIN_SCALE) || (defined(HAVE_DECL_NET_TCP_DEFAULT_WIN_SCALE) && HAVE_DECL_NET_TCP_DEFAULT_WIN_SCALE)
   XLAT(NET_TCP_DEFAULT_WIN_SCALE),
+ #define XLAT_VAL_71 ((unsigned) (NET_TCP_DEFAULT_WIN_SCALE))
+ #define XLAT_STR_71 STRINGIFY(NET_TCP_DEFAULT_WIN_SCALE)
 #endif
 #if defined(NET_TCP_MODERATE_RCVBUF) || (defined(HAVE_DECL_NET_TCP_MODERATE_RCVBUF) && HAVE_DECL_NET_TCP_MODERATE_RCVBUF)
   XLAT(NET_TCP_MODERATE_RCVBUF),
+ #define XLAT_VAL_72 ((unsigned) (NET_TCP_MODERATE_RCVBUF))
+ #define XLAT_STR_72 STRINGIFY(NET_TCP_MODERATE_RCVBUF)
 #endif
 #if defined(NET_TCP_TSO_WIN_DIVISOR) || (defined(HAVE_DECL_NET_TCP_TSO_WIN_DIVISOR) && HAVE_DECL_NET_TCP_TSO_WIN_DIVISOR)
   XLAT(NET_TCP_TSO_WIN_DIVISOR),
+ #define XLAT_VAL_73 ((unsigned) (NET_TCP_TSO_WIN_DIVISOR))
+ #define XLAT_STR_73 STRINGIFY(NET_TCP_TSO_WIN_DIVISOR)
 #endif
 #if defined(NET_TCP_BIC_BETA) || (defined(HAVE_DECL_NET_TCP_BIC_BETA) && HAVE_DECL_NET_TCP_BIC_BETA)
   XLAT(NET_TCP_BIC_BETA),
+ #define XLAT_VAL_74 ((unsigned) (NET_TCP_BIC_BETA))
+ #define XLAT_STR_74 STRINGIFY(NET_TCP_BIC_BETA)
 #endif
 #if defined(NET_IPV4_ICMP_ERRORS_USE_INBOUND_IFADDR) || (defined(HAVE_DECL_NET_IPV4_ICMP_ERRORS_USE_INBOUND_IFADDR) && HAVE_DECL_NET_IPV4_ICMP_ERRORS_USE_INBOUND_IFADDR)
   XLAT(NET_IPV4_ICMP_ERRORS_USE_INBOUND_IFADDR),
+ #define XLAT_VAL_75 ((unsigned) (NET_IPV4_ICMP_ERRORS_USE_INBOUND_IFADDR))
+ #define XLAT_STR_75 STRINGIFY(NET_IPV4_ICMP_ERRORS_USE_INBOUND_IFADDR)
 #endif
 #if defined(NET_TCP_CONG_CONTROL) || (defined(HAVE_DECL_NET_TCP_CONG_CONTROL) && HAVE_DECL_NET_TCP_CONG_CONTROL)
   XLAT(NET_TCP_CONG_CONTROL),
+ #define XLAT_VAL_76 ((unsigned) (NET_TCP_CONG_CONTROL))
+ #define XLAT_STR_76 STRINGIFY(NET_TCP_CONG_CONTROL)
 #endif
 #if defined(NET_TCP_ABC) || (defined(HAVE_DECL_NET_TCP_ABC) && HAVE_DECL_NET_TCP_ABC)
   XLAT(NET_TCP_ABC),
+ #define XLAT_VAL_77 ((unsigned) (NET_TCP_ABC))
+ #define XLAT_STR_77 STRINGIFY(NET_TCP_ABC)
 #endif
 #if defined(NET_IPV4_IPFRAG_MAX_DIST) || (defined(HAVE_DECL_NET_IPV4_IPFRAG_MAX_DIST) && HAVE_DECL_NET_IPV4_IPFRAG_MAX_DIST)
   XLAT(NET_IPV4_IPFRAG_MAX_DIST),
+ #define XLAT_VAL_78 ((unsigned) (NET_IPV4_IPFRAG_MAX_DIST))
+ #define XLAT_STR_78 STRINGIFY(NET_IPV4_IPFRAG_MAX_DIST)
 #endif
 #if defined(NET_TCP_MTU_PROBING) || (defined(HAVE_DECL_NET_TCP_MTU_PROBING) && HAVE_DECL_NET_TCP_MTU_PROBING)
   XLAT(NET_TCP_MTU_PROBING),
+ #define XLAT_VAL_79 ((unsigned) (NET_TCP_MTU_PROBING))
+ #define XLAT_STR_79 STRINGIFY(NET_TCP_MTU_PROBING)
 #endif
 #if defined(NET_TCP_BASE_MSS) || (defined(HAVE_DECL_NET_TCP_BASE_MSS) && HAVE_DECL_NET_TCP_BASE_MSS)
   XLAT(NET_TCP_BASE_MSS),
+ #define XLAT_VAL_80 ((unsigned) (NET_TCP_BASE_MSS))
+ #define XLAT_STR_80 STRINGIFY(NET_TCP_BASE_MSS)
 #endif
 #if defined(NET_IPV4_TCP_WORKAROUND_SIGNED_WINDOWS) || (defined(HAVE_DECL_NET_IPV4_TCP_WORKAROUND_SIGNED_WINDOWS) && HAVE_DECL_NET_IPV4_TCP_WORKAROUND_SIGNED_WINDOWS)
   XLAT(NET_IPV4_TCP_WORKAROUND_SIGNED_WINDOWS),
+ #define XLAT_VAL_81 ((unsigned) (NET_IPV4_TCP_WORKAROUND_SIGNED_WINDOWS))
+ #define XLAT_STR_81 STRINGIFY(NET_IPV4_TCP_WORKAROUND_SIGNED_WINDOWS)
 #endif
 #if defined(NET_TCP_DMA_COPYBREAK) || (defined(HAVE_DECL_NET_TCP_DMA_COPYBREAK) && HAVE_DECL_NET_TCP_DMA_COPYBREAK)
   XLAT(NET_TCP_DMA_COPYBREAK),
+ #define XLAT_VAL_82 ((unsigned) (NET_TCP_DMA_COPYBREAK))
+ #define XLAT_STR_82 STRINGIFY(NET_TCP_DMA_COPYBREAK)
 #endif
 #if defined(NET_TCP_SLOW_START_AFTER_IDLE) || (defined(HAVE_DECL_NET_TCP_SLOW_START_AFTER_IDLE) && HAVE_DECL_NET_TCP_SLOW_START_AFTER_IDLE)
   XLAT(NET_TCP_SLOW_START_AFTER_IDLE),
+ #define XLAT_VAL_83 ((unsigned) (NET_TCP_SLOW_START_AFTER_IDLE))
+ #define XLAT_STR_83 STRINGIFY(NET_TCP_SLOW_START_AFTER_IDLE)
 #endif
 #if defined(NET_CIPSOV4_CACHE_ENABLE) || (defined(HAVE_DECL_NET_CIPSOV4_CACHE_ENABLE) && HAVE_DECL_NET_CIPSOV4_CACHE_ENABLE)
   XLAT(NET_CIPSOV4_CACHE_ENABLE),
+ #define XLAT_VAL_84 ((unsigned) (NET_CIPSOV4_CACHE_ENABLE))
+ #define XLAT_STR_84 STRINGIFY(NET_CIPSOV4_CACHE_ENABLE)
 #endif
 #if defined(NET_CIPSOV4_CACHE_BUCKET_SIZE) || (defined(HAVE_DECL_NET_CIPSOV4_CACHE_BUCKET_SIZE) && HAVE_DECL_NET_CIPSOV4_CACHE_BUCKET_SIZE)
   XLAT(NET_CIPSOV4_CACHE_BUCKET_SIZE),
+ #define XLAT_VAL_85 ((unsigned) (NET_CIPSOV4_CACHE_BUCKET_SIZE))
+ #define XLAT_STR_85 STRINGIFY(NET_CIPSOV4_CACHE_BUCKET_SIZE)
 #endif
 #if defined(NET_CIPSOV4_RBM_OPTFMT) || (defined(HAVE_DECL_NET_CIPSOV4_RBM_OPTFMT) && HAVE_DECL_NET_CIPSOV4_RBM_OPTFMT)
   XLAT(NET_CIPSOV4_RBM_OPTFMT),
+ #define XLAT_VAL_86 ((unsigned) (NET_CIPSOV4_RBM_OPTFMT))
+ #define XLAT_STR_86 STRINGIFY(NET_CIPSOV4_RBM_OPTFMT)
 #endif
 #if defined(NET_CIPSOV4_RBM_STRICTVALID) || (defined(HAVE_DECL_NET_CIPSOV4_RBM_STRICTVALID) && HAVE_DECL_NET_CIPSOV4_RBM_STRICTVALID)
   XLAT(NET_CIPSOV4_RBM_STRICTVALID),
+ #define XLAT_VAL_87 ((unsigned) (NET_CIPSOV4_RBM_STRICTVALID))
+ #define XLAT_STR_87 STRINGIFY(NET_CIPSOV4_RBM_STRICTVALID)
 #endif
 #if defined(NET_TCP_AVAIL_CONG_CONTROL) || (defined(HAVE_DECL_NET_TCP_AVAIL_CONG_CONTROL) && HAVE_DECL_NET_TCP_AVAIL_CONG_CONTROL)
   XLAT(NET_TCP_AVAIL_CONG_CONTROL),
+ #define XLAT_VAL_88 ((unsigned) (NET_TCP_AVAIL_CONG_CONTROL))
+ #define XLAT_STR_88 STRINGIFY(NET_TCP_AVAIL_CONG_CONTROL)
 #endif
 #if defined(NET_TCP_ALLOWED_CONG_CONTROL) || (defined(HAVE_DECL_NET_TCP_ALLOWED_CONG_CONTROL) && HAVE_DECL_NET_TCP_ALLOWED_CONG_CONTROL)
   XLAT(NET_TCP_ALLOWED_CONG_CONTROL),
+ #define XLAT_VAL_89 ((unsigned) (NET_TCP_ALLOWED_CONG_CONTROL))
+ #define XLAT_STR_89 STRINGIFY(NET_TCP_ALLOWED_CONG_CONTROL)
 #endif
 #if defined(NET_TCP_MAX_SSTHRESH) || (defined(HAVE_DECL_NET_TCP_MAX_SSTHRESH) && HAVE_DECL_NET_TCP_MAX_SSTHRESH)
   XLAT(NET_TCP_MAX_SSTHRESH),
+ #define XLAT_VAL_90 ((unsigned) (NET_TCP_MAX_SSTHRESH))
+ #define XLAT_STR_90 STRINGIFY(NET_TCP_MAX_SSTHRESH)
 #endif
 #if defined(NET_TCP_FRTO_RESPONSE) || (defined(HAVE_DECL_NET_TCP_FRTO_RESPONSE) && HAVE_DECL_NET_TCP_FRTO_RESPONSE)
   XLAT(NET_TCP_FRTO_RESPONSE),
+ #define XLAT_VAL_91 ((unsigned) (NET_TCP_FRTO_RESPONSE))
+ #define XLAT_STR_91 STRINGIFY(NET_TCP_FRTO_RESPONSE)
 #endif
 };
 static
@@ -157,8 +341,748 @@ const struct xlat sysctl_net_ipv4[1] = {
  .data = sysctl_net_ipv4_xdata,
  .size = ARRAY_SIZE(sysctl_net_ipv4_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+#  ifdef XLAT_VAL_47
+  | XLAT_VAL_47
+#  endif
+#  ifdef XLAT_VAL_48
+  | XLAT_VAL_48
+#  endif
+#  ifdef XLAT_VAL_49
+  | XLAT_VAL_49
+#  endif
+#  ifdef XLAT_VAL_50
+  | XLAT_VAL_50
+#  endif
+#  ifdef XLAT_VAL_51
+  | XLAT_VAL_51
+#  endif
+#  ifdef XLAT_VAL_52
+  | XLAT_VAL_52
+#  endif
+#  ifdef XLAT_VAL_53
+  | XLAT_VAL_53
+#  endif
+#  ifdef XLAT_VAL_54
+  | XLAT_VAL_54
+#  endif
+#  ifdef XLAT_VAL_55
+  | XLAT_VAL_55
+#  endif
+#  ifdef XLAT_VAL_56
+  | XLAT_VAL_56
+#  endif
+#  ifdef XLAT_VAL_57
+  | XLAT_VAL_57
+#  endif
+#  ifdef XLAT_VAL_58
+  | XLAT_VAL_58
+#  endif
+#  ifdef XLAT_VAL_59
+  | XLAT_VAL_59
+#  endif
+#  ifdef XLAT_VAL_60
+  | XLAT_VAL_60
+#  endif
+#  ifdef XLAT_VAL_61
+  | XLAT_VAL_61
+#  endif
+#  ifdef XLAT_VAL_62
+  | XLAT_VAL_62
+#  endif
+#  ifdef XLAT_VAL_63
+  | XLAT_VAL_63
+#  endif
+#  ifdef XLAT_VAL_64
+  | XLAT_VAL_64
+#  endif
+#  ifdef XLAT_VAL_65
+  | XLAT_VAL_65
+#  endif
+#  ifdef XLAT_VAL_66
+  | XLAT_VAL_66
+#  endif
+#  ifdef XLAT_VAL_67
+  | XLAT_VAL_67
+#  endif
+#  ifdef XLAT_VAL_68
+  | XLAT_VAL_68
+#  endif
+#  ifdef XLAT_VAL_69
+  | XLAT_VAL_69
+#  endif
+#  ifdef XLAT_VAL_70
+  | XLAT_VAL_70
+#  endif
+#  ifdef XLAT_VAL_71
+  | XLAT_VAL_71
+#  endif
+#  ifdef XLAT_VAL_72
+  | XLAT_VAL_72
+#  endif
+#  ifdef XLAT_VAL_73
+  | XLAT_VAL_73
+#  endif
+#  ifdef XLAT_VAL_74
+  | XLAT_VAL_74
+#  endif
+#  ifdef XLAT_VAL_75
+  | XLAT_VAL_75
+#  endif
+#  ifdef XLAT_VAL_76
+  | XLAT_VAL_76
+#  endif
+#  ifdef XLAT_VAL_77
+  | XLAT_VAL_77
+#  endif
+#  ifdef XLAT_VAL_78
+  | XLAT_VAL_78
+#  endif
+#  ifdef XLAT_VAL_79
+  | XLAT_VAL_79
+#  endif
+#  ifdef XLAT_VAL_80
+  | XLAT_VAL_80
+#  endif
+#  ifdef XLAT_VAL_81
+  | XLAT_VAL_81
+#  endif
+#  ifdef XLAT_VAL_82
+  | XLAT_VAL_82
+#  endif
+#  ifdef XLAT_VAL_83
+  | XLAT_VAL_83
+#  endif
+#  ifdef XLAT_VAL_84
+  | XLAT_VAL_84
+#  endif
+#  ifdef XLAT_VAL_85
+  | XLAT_VAL_85
+#  endif
+#  ifdef XLAT_VAL_86
+  | XLAT_VAL_86
+#  endif
+#  ifdef XLAT_VAL_87
+  | XLAT_VAL_87
+#  endif
+#  ifdef XLAT_VAL_88
+  | XLAT_VAL_88
+#  endif
+#  ifdef XLAT_VAL_89
+  | XLAT_VAL_89
+#  endif
+#  ifdef XLAT_VAL_90
+  | XLAT_VAL_90
+#  endif
+#  ifdef XLAT_VAL_91
+  | XLAT_VAL_91
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+#  ifdef XLAT_STR_47
+  + sizeof(XLAT_STR_47)
+#  endif
+#  ifdef XLAT_STR_48
+  + sizeof(XLAT_STR_48)
+#  endif
+#  ifdef XLAT_STR_49
+  + sizeof(XLAT_STR_49)
+#  endif
+#  ifdef XLAT_STR_50
+  + sizeof(XLAT_STR_50)
+#  endif
+#  ifdef XLAT_STR_51
+  + sizeof(XLAT_STR_51)
+#  endif
+#  ifdef XLAT_STR_52
+  + sizeof(XLAT_STR_52)
+#  endif
+#  ifdef XLAT_STR_53
+  + sizeof(XLAT_STR_53)
+#  endif
+#  ifdef XLAT_STR_54
+  + sizeof(XLAT_STR_54)
+#  endif
+#  ifdef XLAT_STR_55
+  + sizeof(XLAT_STR_55)
+#  endif
+#  ifdef XLAT_STR_56
+  + sizeof(XLAT_STR_56)
+#  endif
+#  ifdef XLAT_STR_57
+  + sizeof(XLAT_STR_57)
+#  endif
+#  ifdef XLAT_STR_58
+  + sizeof(XLAT_STR_58)
+#  endif
+#  ifdef XLAT_STR_59
+  + sizeof(XLAT_STR_59)
+#  endif
+#  ifdef XLAT_STR_60
+  + sizeof(XLAT_STR_60)
+#  endif
+#  ifdef XLAT_STR_61
+  + sizeof(XLAT_STR_61)
+#  endif
+#  ifdef XLAT_STR_62
+  + sizeof(XLAT_STR_62)
+#  endif
+#  ifdef XLAT_STR_63
+  + sizeof(XLAT_STR_63)
+#  endif
+#  ifdef XLAT_STR_64
+  + sizeof(XLAT_STR_64)
+#  endif
+#  ifdef XLAT_STR_65
+  + sizeof(XLAT_STR_65)
+#  endif
+#  ifdef XLAT_STR_66
+  + sizeof(XLAT_STR_66)
+#  endif
+#  ifdef XLAT_STR_67
+  + sizeof(XLAT_STR_67)
+#  endif
+#  ifdef XLAT_STR_68
+  + sizeof(XLAT_STR_68)
+#  endif
+#  ifdef XLAT_STR_69
+  + sizeof(XLAT_STR_69)
+#  endif
+#  ifdef XLAT_STR_70
+  + sizeof(XLAT_STR_70)
+#  endif
+#  ifdef XLAT_STR_71
+  + sizeof(XLAT_STR_71)
+#  endif
+#  ifdef XLAT_STR_72
+  + sizeof(XLAT_STR_72)
+#  endif
+#  ifdef XLAT_STR_73
+  + sizeof(XLAT_STR_73)
+#  endif
+#  ifdef XLAT_STR_74
+  + sizeof(XLAT_STR_74)
+#  endif
+#  ifdef XLAT_STR_75
+  + sizeof(XLAT_STR_75)
+#  endif
+#  ifdef XLAT_STR_76
+  + sizeof(XLAT_STR_76)
+#  endif
+#  ifdef XLAT_STR_77
+  + sizeof(XLAT_STR_77)
+#  endif
+#  ifdef XLAT_STR_78
+  + sizeof(XLAT_STR_78)
+#  endif
+#  ifdef XLAT_STR_79
+  + sizeof(XLAT_STR_79)
+#  endif
+#  ifdef XLAT_STR_80
+  + sizeof(XLAT_STR_80)
+#  endif
+#  ifdef XLAT_STR_81
+  + sizeof(XLAT_STR_81)
+#  endif
+#  ifdef XLAT_STR_82
+  + sizeof(XLAT_STR_82)
+#  endif
+#  ifdef XLAT_STR_83
+  + sizeof(XLAT_STR_83)
+#  endif
+#  ifdef XLAT_STR_84
+  + sizeof(XLAT_STR_84)
+#  endif
+#  ifdef XLAT_STR_85
+  + sizeof(XLAT_STR_85)
+#  endif
+#  ifdef XLAT_STR_86
+  + sizeof(XLAT_STR_86)
+#  endif
+#  ifdef XLAT_STR_87
+  + sizeof(XLAT_STR_87)
+#  endif
+#  ifdef XLAT_STR_88
+  + sizeof(XLAT_STR_88)
+#  endif
+#  ifdef XLAT_STR_89
+  + sizeof(XLAT_STR_89)
+#  endif
+#  ifdef XLAT_STR_90
+  + sizeof(XLAT_STR_90)
+#  endif
+#  ifdef XLAT_STR_91
+  + sizeof(XLAT_STR_91)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
+#  undef XLAT_STR_47
+#  undef XLAT_VAL_47
+#  undef XLAT_STR_48
+#  undef XLAT_VAL_48
+#  undef XLAT_STR_49
+#  undef XLAT_VAL_49
+#  undef XLAT_STR_50
+#  undef XLAT_VAL_50
+#  undef XLAT_STR_51
+#  undef XLAT_VAL_51
+#  undef XLAT_STR_52
+#  undef XLAT_VAL_52
+#  undef XLAT_STR_53
+#  undef XLAT_VAL_53
+#  undef XLAT_STR_54
+#  undef XLAT_VAL_54
+#  undef XLAT_STR_55
+#  undef XLAT_VAL_55
+#  undef XLAT_STR_56
+#  undef XLAT_VAL_56
+#  undef XLAT_STR_57
+#  undef XLAT_VAL_57
+#  undef XLAT_STR_58
+#  undef XLAT_VAL_58
+#  undef XLAT_STR_59
+#  undef XLAT_VAL_59
+#  undef XLAT_STR_60
+#  undef XLAT_VAL_60
+#  undef XLAT_STR_61
+#  undef XLAT_VAL_61
+#  undef XLAT_STR_62
+#  undef XLAT_VAL_62
+#  undef XLAT_STR_63
+#  undef XLAT_VAL_63
+#  undef XLAT_STR_64
+#  undef XLAT_VAL_64
+#  undef XLAT_STR_65
+#  undef XLAT_VAL_65
+#  undef XLAT_STR_66
+#  undef XLAT_VAL_66
+#  undef XLAT_STR_67
+#  undef XLAT_VAL_67
+#  undef XLAT_STR_68
+#  undef XLAT_VAL_68
+#  undef XLAT_STR_69
+#  undef XLAT_VAL_69
+#  undef XLAT_STR_70
+#  undef XLAT_VAL_70
+#  undef XLAT_STR_71
+#  undef XLAT_VAL_71
+#  undef XLAT_STR_72
+#  undef XLAT_VAL_72
+#  undef XLAT_STR_73
+#  undef XLAT_VAL_73
+#  undef XLAT_STR_74
+#  undef XLAT_VAL_74
+#  undef XLAT_STR_75
+#  undef XLAT_VAL_75
+#  undef XLAT_STR_76
+#  undef XLAT_VAL_76
+#  undef XLAT_STR_77
+#  undef XLAT_VAL_77
+#  undef XLAT_STR_78
+#  undef XLAT_VAL_78
+#  undef XLAT_STR_79
+#  undef XLAT_VAL_79
+#  undef XLAT_STR_80
+#  undef XLAT_VAL_80
+#  undef XLAT_STR_81
+#  undef XLAT_VAL_81
+#  undef XLAT_STR_82
+#  undef XLAT_VAL_82
+#  undef XLAT_STR_83
+#  undef XLAT_VAL_83
+#  undef XLAT_STR_84
+#  undef XLAT_VAL_84
+#  undef XLAT_STR_85
+#  undef XLAT_VAL_85
+#  undef XLAT_STR_86
+#  undef XLAT_VAL_86
+#  undef XLAT_STR_87
+#  undef XLAT_VAL_87
+#  undef XLAT_STR_88
+#  undef XLAT_VAL_88
+#  undef XLAT_STR_89
+#  undef XLAT_VAL_89
+#  undef XLAT_STR_90
+#  undef XLAT_VAL_90
+#  undef XLAT_STR_91
+#  undef XLAT_VAL_91
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sysctl_net_ipv4.in 5.9-0ubuntu2/xlat/sysctl_net_ipv4.in
--- 5.5-3/xlat/sysctl_net_ipv4.in	2016-06-06 18:07:04.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_net_ipv4.in	2020-05-30 08:00:00.000000000 +0000
@@ -1,3 +1,6 @@
+#enum
+#include <sys/types.h>
+#include <linux/sysctl.h>
 #unconditional
 NET_IPV4_FORWARD
 NET_IPV4_DYNADDR
diff -pruN 5.5-3/xlat/sysctl_net_ipv4.m4 5.9-0ubuntu2/xlat/sysctl_net_ipv4.m4
--- 5.5-3/xlat/sysctl_net_ipv4.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_net_ipv4.m4	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,99 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/sysctl_net_ipv4.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_sysctl_net_ipv4],[
+AC_CHECK_DECLS(m4_normalize([
+NET_IPV4_FORWARD,
+NET_IPV4_DYNADDR,
+NET_IPV4_CONF,
+NET_IPV4_NEIGH,
+NET_IPV4_ROUTE,
+NET_IPV4_FIB_HASH,
+NET_IPV4_NETFILTER,
+NET_IPV4_TCP_TIMESTAMPS,
+NET_IPV4_TCP_WINDOW_SCALING,
+NET_IPV4_TCP_SACK,
+NET_IPV4_TCP_RETRANS_COLLAPSE,
+NET_IPV4_DEFAULT_TTL,
+NET_IPV4_AUTOCONFIG,
+NET_IPV4_NO_PMTU_DISC,
+NET_IPV4_TCP_SYN_RETRIES,
+NET_IPV4_IPFRAG_HIGH_THRESH,
+NET_IPV4_IPFRAG_LOW_THRESH,
+NET_IPV4_IPFRAG_TIME,
+NET_IPV4_TCP_MAX_KA_PROBES,
+NET_IPV4_TCP_KEEPALIVE_TIME,
+NET_IPV4_TCP_KEEPALIVE_PROBES,
+NET_IPV4_TCP_RETRIES1,
+NET_IPV4_TCP_RETRIES2,
+NET_IPV4_TCP_FIN_TIMEOUT,
+NET_IPV4_IP_MASQ_DEBUG,
+NET_TCP_SYNCOOKIES,
+NET_TCP_STDURG,
+NET_TCP_RFC1337,
+NET_TCP_SYN_TAILDROP,
+NET_TCP_MAX_SYN_BACKLOG,
+NET_IPV4_LOCAL_PORT_RANGE,
+NET_IPV4_ICMP_ECHO_IGNORE_ALL,
+NET_IPV4_ICMP_ECHO_IGNORE_BROADCASTS,
+NET_IPV4_ICMP_SOURCEQUENCH_RATE,
+NET_IPV4_ICMP_DESTUNREACH_RATE,
+NET_IPV4_ICMP_TIMEEXCEED_RATE,
+NET_IPV4_ICMP_PARAMPROB_RATE,
+NET_IPV4_ICMP_ECHOREPLY_RATE,
+NET_IPV4_ICMP_IGNORE_BOGUS_ERROR_RESPONSES,
+NET_IPV4_IGMP_MAX_MEMBERSHIPS,
+NET_TCP_TW_RECYCLE,
+NET_IPV4_ALWAYS_DEFRAG,
+NET_IPV4_TCP_KEEPALIVE_INTVL,
+NET_IPV4_INET_PEER_THRESHOLD,
+NET_IPV4_INET_PEER_MINTTL,
+NET_IPV4_INET_PEER_MAXTTL,
+NET_IPV4_INET_PEER_GC_MINTIME,
+NET_IPV4_INET_PEER_GC_MAXTIME,
+NET_TCP_ORPHAN_RETRIES,
+NET_TCP_ABORT_ON_OVERFLOW,
+NET_TCP_SYNACK_RETRIES,
+NET_TCP_MAX_ORPHANS,
+NET_TCP_MAX_TW_BUCKETS,
+NET_TCP_FACK,
+NET_TCP_REORDERING,
+NET_TCP_ECN,
+NET_TCP_DSACK,
+NET_TCP_MEM,
+NET_TCP_WMEM,
+NET_TCP_RMEM,
+NET_TCP_APP_WIN,
+NET_TCP_ADV_WIN_SCALE,
+NET_IPV4_NONLOCAL_BIND,
+NET_IPV4_ICMP_RATELIMIT,
+NET_IPV4_ICMP_RATEMASK,
+NET_TCP_TW_REUSE,
+NET_TCP_FRTO,
+NET_TCP_LOW_LATENCY,
+NET_IPV4_IPFRAG_SECRET_INTERVAL,
+NET_IPV4_IGMP_MAX_MSF,
+NET_TCP_NO_METRICS_SAVE,
+NET_TCP_DEFAULT_WIN_SCALE,
+NET_TCP_MODERATE_RCVBUF,
+NET_TCP_TSO_WIN_DIVISOR,
+NET_TCP_BIC_BETA,
+NET_IPV4_ICMP_ERRORS_USE_INBOUND_IFADDR,
+NET_TCP_CONG_CONTROL,
+NET_TCP_ABC,
+NET_IPV4_IPFRAG_MAX_DIST,
+NET_TCP_MTU_PROBING,
+NET_TCP_BASE_MSS,
+NET_IPV4_TCP_WORKAROUND_SIGNED_WINDOWS,
+NET_TCP_DMA_COPYBREAK,
+NET_TCP_SLOW_START_AFTER_IDLE,
+NET_CIPSOV4_CACHE_ENABLE,
+NET_CIPSOV4_CACHE_BUCKET_SIZE,
+NET_CIPSOV4_RBM_OPTFMT,
+NET_CIPSOV4_RBM_STRICTVALID,
+NET_TCP_AVAIL_CONG_CONTROL,
+NET_TCP_ALLOWED_CONG_CONTROL,
+NET_TCP_MAX_SSTHRESH,
+NET_TCP_FRTO_RESPONSE
+]),,, [
+#include <sys/types.h>
+#include <linux/sysctl.h>
+])])])
diff -pruN 5.5-3/xlat/sysctl_net_ipv4_route.h 5.9-0ubuntu2/xlat/sysctl_net_ipv4_route.h
--- 5.5-3/xlat/sysctl_net_ipv4_route.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_net_ipv4_route.h	2020-09-24 09:18:46.000000000 +0000
@@ -14,25 +14,63 @@
 
 static const struct xlat_data sysctl_net_ipv4_route_xdata[] = {
  XLAT(NET_IPV4_ROUTE_FLUSH),
+ #define XLAT_VAL_0 ((unsigned) (NET_IPV4_ROUTE_FLUSH))
+ #define XLAT_STR_0 STRINGIFY(NET_IPV4_ROUTE_FLUSH)
  XLAT(NET_IPV4_ROUTE_MIN_DELAY),
+ #define XLAT_VAL_1 ((unsigned) (NET_IPV4_ROUTE_MIN_DELAY))
+ #define XLAT_STR_1 STRINGIFY(NET_IPV4_ROUTE_MIN_DELAY)
  XLAT(NET_IPV4_ROUTE_MAX_DELAY),
+ #define XLAT_VAL_2 ((unsigned) (NET_IPV4_ROUTE_MAX_DELAY))
+ #define XLAT_STR_2 STRINGIFY(NET_IPV4_ROUTE_MAX_DELAY)
  XLAT(NET_IPV4_ROUTE_GC_THRESH),
+ #define XLAT_VAL_3 ((unsigned) (NET_IPV4_ROUTE_GC_THRESH))
+ #define XLAT_STR_3 STRINGIFY(NET_IPV4_ROUTE_GC_THRESH)
  XLAT(NET_IPV4_ROUTE_MAX_SIZE),
+ #define XLAT_VAL_4 ((unsigned) (NET_IPV4_ROUTE_MAX_SIZE))
+ #define XLAT_STR_4 STRINGIFY(NET_IPV4_ROUTE_MAX_SIZE)
  XLAT(NET_IPV4_ROUTE_GC_MIN_INTERVAL),
+ #define XLAT_VAL_5 ((unsigned) (NET_IPV4_ROUTE_GC_MIN_INTERVAL))
+ #define XLAT_STR_5 STRINGIFY(NET_IPV4_ROUTE_GC_MIN_INTERVAL)
  XLAT(NET_IPV4_ROUTE_GC_TIMEOUT),
+ #define XLAT_VAL_6 ((unsigned) (NET_IPV4_ROUTE_GC_TIMEOUT))
+ #define XLAT_STR_6 STRINGIFY(NET_IPV4_ROUTE_GC_TIMEOUT)
  XLAT(NET_IPV4_ROUTE_GC_INTERVAL),
+ #define XLAT_VAL_7 ((unsigned) (NET_IPV4_ROUTE_GC_INTERVAL))
+ #define XLAT_STR_7 STRINGIFY(NET_IPV4_ROUTE_GC_INTERVAL)
  XLAT(NET_IPV4_ROUTE_REDIRECT_LOAD),
+ #define XLAT_VAL_8 ((unsigned) (NET_IPV4_ROUTE_REDIRECT_LOAD))
+ #define XLAT_STR_8 STRINGIFY(NET_IPV4_ROUTE_REDIRECT_LOAD)
  XLAT(NET_IPV4_ROUTE_REDIRECT_NUMBER),
+ #define XLAT_VAL_9 ((unsigned) (NET_IPV4_ROUTE_REDIRECT_NUMBER))
+ #define XLAT_STR_9 STRINGIFY(NET_IPV4_ROUTE_REDIRECT_NUMBER)
  XLAT(NET_IPV4_ROUTE_REDIRECT_SILENCE),
+ #define XLAT_VAL_10 ((unsigned) (NET_IPV4_ROUTE_REDIRECT_SILENCE))
+ #define XLAT_STR_10 STRINGIFY(NET_IPV4_ROUTE_REDIRECT_SILENCE)
  XLAT(NET_IPV4_ROUTE_ERROR_COST),
+ #define XLAT_VAL_11 ((unsigned) (NET_IPV4_ROUTE_ERROR_COST))
+ #define XLAT_STR_11 STRINGIFY(NET_IPV4_ROUTE_ERROR_COST)
  XLAT(NET_IPV4_ROUTE_ERROR_BURST),
+ #define XLAT_VAL_12 ((unsigned) (NET_IPV4_ROUTE_ERROR_BURST))
+ #define XLAT_STR_12 STRINGIFY(NET_IPV4_ROUTE_ERROR_BURST)
  XLAT(NET_IPV4_ROUTE_GC_ELASTICITY),
+ #define XLAT_VAL_13 ((unsigned) (NET_IPV4_ROUTE_GC_ELASTICITY))
+ #define XLAT_STR_13 STRINGIFY(NET_IPV4_ROUTE_GC_ELASTICITY)
  XLAT(NET_IPV4_ROUTE_MTU_EXPIRES),
+ #define XLAT_VAL_14 ((unsigned) (NET_IPV4_ROUTE_MTU_EXPIRES))
+ #define XLAT_STR_14 STRINGIFY(NET_IPV4_ROUTE_MTU_EXPIRES)
  XLAT(NET_IPV4_ROUTE_MIN_PMTU),
+ #define XLAT_VAL_15 ((unsigned) (NET_IPV4_ROUTE_MIN_PMTU))
+ #define XLAT_STR_15 STRINGIFY(NET_IPV4_ROUTE_MIN_PMTU)
  XLAT(NET_IPV4_ROUTE_MIN_ADVMSS),
+ #define XLAT_VAL_16 ((unsigned) (NET_IPV4_ROUTE_MIN_ADVMSS))
+ #define XLAT_STR_16 STRINGIFY(NET_IPV4_ROUTE_MIN_ADVMSS)
  XLAT(NET_IPV4_ROUTE_SECRET_INTERVAL),
+ #define XLAT_VAL_17 ((unsigned) (NET_IPV4_ROUTE_SECRET_INTERVAL))
+ #define XLAT_STR_17 STRINGIFY(NET_IPV4_ROUTE_SECRET_INTERVAL)
 #if defined(NET_IPV4_ROUTE_GC_MIN_INTERVAL_MS) || (defined(HAVE_DECL_NET_IPV4_ROUTE_GC_MIN_INTERVAL_MS) && HAVE_DECL_NET_IPV4_ROUTE_GC_MIN_INTERVAL_MS)
   XLAT(NET_IPV4_ROUTE_GC_MIN_INTERVAL_MS),
+ #define XLAT_VAL_18 ((unsigned) (NET_IPV4_ROUTE_GC_MIN_INTERVAL_MS))
+ #define XLAT_STR_18 STRINGIFY(NET_IPV4_ROUTE_GC_MIN_INTERVAL_MS)
 #endif
 };
 static
@@ -40,8 +78,164 @@ const struct xlat sysctl_net_ipv4_route[
  .data = sysctl_net_ipv4_route_xdata,
  .size = ARRAY_SIZE(sysctl_net_ipv4_route_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sysctl_net_ipv4_route.in 5.9-0ubuntu2/xlat/sysctl_net_ipv4_route.in
--- 5.5-3/xlat/sysctl_net_ipv4_route.in	2016-06-06 18:07:04.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_net_ipv4_route.in	2020-05-30 08:00:00.000000000 +0000
@@ -1,3 +1,6 @@
+#enum
+#include <sys/types.h>
+#include <linux/sysctl.h>
 #unconditional
 NET_IPV4_ROUTE_FLUSH
 NET_IPV4_ROUTE_MIN_DELAY
diff -pruN 5.5-3/xlat/sysctl_net_ipv4_route.m4 5.9-0ubuntu2/xlat/sysctl_net_ipv4_route.m4
--- 5.5-3/xlat/sysctl_net_ipv4_route.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_net_ipv4_route.m4	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,26 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/sysctl_net_ipv4_route.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_sysctl_net_ipv4_route],[
+AC_CHECK_DECLS(m4_normalize([
+NET_IPV4_ROUTE_FLUSH,
+NET_IPV4_ROUTE_MIN_DELAY,
+NET_IPV4_ROUTE_MAX_DELAY,
+NET_IPV4_ROUTE_GC_THRESH,
+NET_IPV4_ROUTE_MAX_SIZE,
+NET_IPV4_ROUTE_GC_MIN_INTERVAL,
+NET_IPV4_ROUTE_GC_TIMEOUT,
+NET_IPV4_ROUTE_GC_INTERVAL,
+NET_IPV4_ROUTE_REDIRECT_LOAD,
+NET_IPV4_ROUTE_REDIRECT_NUMBER,
+NET_IPV4_ROUTE_REDIRECT_SILENCE,
+NET_IPV4_ROUTE_ERROR_COST,
+NET_IPV4_ROUTE_ERROR_BURST,
+NET_IPV4_ROUTE_GC_ELASTICITY,
+NET_IPV4_ROUTE_MTU_EXPIRES,
+NET_IPV4_ROUTE_MIN_PMTU,
+NET_IPV4_ROUTE_MIN_ADVMSS,
+NET_IPV4_ROUTE_SECRET_INTERVAL,
+NET_IPV4_ROUTE_GC_MIN_INTERVAL_MS
+]),,, [
+#include <sys/types.h>
+#include <linux/sysctl.h>
+])])])
diff -pruN 5.5-3/xlat/sysctl_net_ipv6.h 5.9-0ubuntu2/xlat/sysctl_net_ipv6.h
--- 5.5-3/xlat/sysctl_net_ipv6.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_net_ipv6.h	2020-09-24 09:18:46.000000000 +0000
@@ -14,16 +14,36 @@
 
 static const struct xlat_data sysctl_net_ipv6_xdata[] = {
  XLAT(NET_IPV6_CONF),
+ #define XLAT_VAL_0 ((unsigned) (NET_IPV6_CONF))
+ #define XLAT_STR_0 STRINGIFY(NET_IPV6_CONF)
  XLAT(NET_IPV6_NEIGH),
+ #define XLAT_VAL_1 ((unsigned) (NET_IPV6_NEIGH))
+ #define XLAT_STR_1 STRINGIFY(NET_IPV6_NEIGH)
  XLAT(NET_IPV6_ROUTE),
+ #define XLAT_VAL_2 ((unsigned) (NET_IPV6_ROUTE))
+ #define XLAT_STR_2 STRINGIFY(NET_IPV6_ROUTE)
  XLAT(NET_IPV6_ICMP),
+ #define XLAT_VAL_3 ((unsigned) (NET_IPV6_ICMP))
+ #define XLAT_STR_3 STRINGIFY(NET_IPV6_ICMP)
  XLAT(NET_IPV6_BINDV6ONLY),
+ #define XLAT_VAL_4 ((unsigned) (NET_IPV6_BINDV6ONLY))
+ #define XLAT_STR_4 STRINGIFY(NET_IPV6_BINDV6ONLY)
  XLAT(NET_IPV6_IP6FRAG_HIGH_THRESH),
+ #define XLAT_VAL_5 ((unsigned) (NET_IPV6_IP6FRAG_HIGH_THRESH))
+ #define XLAT_STR_5 STRINGIFY(NET_IPV6_IP6FRAG_HIGH_THRESH)
  XLAT(NET_IPV6_IP6FRAG_LOW_THRESH),
+ #define XLAT_VAL_6 ((unsigned) (NET_IPV6_IP6FRAG_LOW_THRESH))
+ #define XLAT_STR_6 STRINGIFY(NET_IPV6_IP6FRAG_LOW_THRESH)
  XLAT(NET_IPV6_IP6FRAG_TIME),
+ #define XLAT_VAL_7 ((unsigned) (NET_IPV6_IP6FRAG_TIME))
+ #define XLAT_STR_7 STRINGIFY(NET_IPV6_IP6FRAG_TIME)
  XLAT(NET_IPV6_IP6FRAG_SECRET_INTERVAL),
+ #define XLAT_VAL_8 ((unsigned) (NET_IPV6_IP6FRAG_SECRET_INTERVAL))
+ #define XLAT_STR_8 STRINGIFY(NET_IPV6_IP6FRAG_SECRET_INTERVAL)
 #if defined(NET_IPV6_MLD_MAX_MSF) || (defined(HAVE_DECL_NET_IPV6_MLD_MAX_MSF) && HAVE_DECL_NET_IPV6_MLD_MAX_MSF)
   XLAT(NET_IPV6_MLD_MAX_MSF),
+ #define XLAT_VAL_9 ((unsigned) (NET_IPV6_MLD_MAX_MSF))
+ #define XLAT_STR_9 STRINGIFY(NET_IPV6_MLD_MAX_MSF)
 #endif
 };
 static
@@ -31,8 +51,92 @@ const struct xlat sysctl_net_ipv6[1] = {
  .data = sysctl_net_ipv6_xdata,
  .size = ARRAY_SIZE(sysctl_net_ipv6_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sysctl_net_ipv6.in 5.9-0ubuntu2/xlat/sysctl_net_ipv6.in
--- 5.5-3/xlat/sysctl_net_ipv6.in	2016-06-06 18:07:04.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_net_ipv6.in	2020-05-30 08:00:00.000000000 +0000
@@ -1,3 +1,6 @@
+#enum
+#include <sys/types.h>
+#include <linux/sysctl.h>
 #unconditional
 NET_IPV6_CONF
 NET_IPV6_NEIGH
diff -pruN 5.5-3/xlat/sysctl_net_ipv6.m4 5.9-0ubuntu2/xlat/sysctl_net_ipv6.m4
--- 5.5-3/xlat/sysctl_net_ipv6.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_net_ipv6.m4	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,17 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/sysctl_net_ipv6.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_sysctl_net_ipv6],[
+AC_CHECK_DECLS(m4_normalize([
+NET_IPV6_CONF,
+NET_IPV6_NEIGH,
+NET_IPV6_ROUTE,
+NET_IPV6_ICMP,
+NET_IPV6_BINDV6ONLY,
+NET_IPV6_IP6FRAG_HIGH_THRESH,
+NET_IPV6_IP6FRAG_LOW_THRESH,
+NET_IPV6_IP6FRAG_TIME,
+NET_IPV6_IP6FRAG_SECRET_INTERVAL,
+NET_IPV6_MLD_MAX_MSF
+]),,, [
+#include <sys/types.h>
+#include <linux/sysctl.h>
+])])])
diff -pruN 5.5-3/xlat/sysctl_net_ipv6_route.h 5.9-0ubuntu2/xlat/sysctl_net_ipv6_route.h
--- 5.5-3/xlat/sysctl_net_ipv6_route.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_net_ipv6_route.h	2020-09-24 09:18:46.000000000 +0000
@@ -14,16 +14,36 @@
 
 static const struct xlat_data sysctl_net_ipv6_route_xdata[] = {
  XLAT(NET_IPV6_ROUTE_FLUSH),
+ #define XLAT_VAL_0 ((unsigned) (NET_IPV6_ROUTE_FLUSH))
+ #define XLAT_STR_0 STRINGIFY(NET_IPV6_ROUTE_FLUSH)
  XLAT(NET_IPV6_ROUTE_GC_THRESH),
+ #define XLAT_VAL_1 ((unsigned) (NET_IPV6_ROUTE_GC_THRESH))
+ #define XLAT_STR_1 STRINGIFY(NET_IPV6_ROUTE_GC_THRESH)
  XLAT(NET_IPV6_ROUTE_MAX_SIZE),
+ #define XLAT_VAL_2 ((unsigned) (NET_IPV6_ROUTE_MAX_SIZE))
+ #define XLAT_STR_2 STRINGIFY(NET_IPV6_ROUTE_MAX_SIZE)
  XLAT(NET_IPV6_ROUTE_GC_MIN_INTERVAL),
+ #define XLAT_VAL_3 ((unsigned) (NET_IPV6_ROUTE_GC_MIN_INTERVAL))
+ #define XLAT_STR_3 STRINGIFY(NET_IPV6_ROUTE_GC_MIN_INTERVAL)
  XLAT(NET_IPV6_ROUTE_GC_TIMEOUT),
+ #define XLAT_VAL_4 ((unsigned) (NET_IPV6_ROUTE_GC_TIMEOUT))
+ #define XLAT_STR_4 STRINGIFY(NET_IPV6_ROUTE_GC_TIMEOUT)
  XLAT(NET_IPV6_ROUTE_GC_INTERVAL),
+ #define XLAT_VAL_5 ((unsigned) (NET_IPV6_ROUTE_GC_INTERVAL))
+ #define XLAT_STR_5 STRINGIFY(NET_IPV6_ROUTE_GC_INTERVAL)
  XLAT(NET_IPV6_ROUTE_GC_ELASTICITY),
+ #define XLAT_VAL_6 ((unsigned) (NET_IPV6_ROUTE_GC_ELASTICITY))
+ #define XLAT_STR_6 STRINGIFY(NET_IPV6_ROUTE_GC_ELASTICITY)
  XLAT(NET_IPV6_ROUTE_MTU_EXPIRES),
+ #define XLAT_VAL_7 ((unsigned) (NET_IPV6_ROUTE_MTU_EXPIRES))
+ #define XLAT_STR_7 STRINGIFY(NET_IPV6_ROUTE_MTU_EXPIRES)
  XLAT(NET_IPV6_ROUTE_MIN_ADVMSS),
+ #define XLAT_VAL_8 ((unsigned) (NET_IPV6_ROUTE_MIN_ADVMSS))
+ #define XLAT_STR_8 STRINGIFY(NET_IPV6_ROUTE_MIN_ADVMSS)
 #if defined(NET_IPV6_ROUTE_GC_MIN_INTERVAL_MS) || (defined(HAVE_DECL_NET_IPV6_ROUTE_GC_MIN_INTERVAL_MS) && HAVE_DECL_NET_IPV6_ROUTE_GC_MIN_INTERVAL_MS)
   XLAT(NET_IPV6_ROUTE_GC_MIN_INTERVAL_MS),
+ #define XLAT_VAL_9 ((unsigned) (NET_IPV6_ROUTE_GC_MIN_INTERVAL_MS))
+ #define XLAT_STR_9 STRINGIFY(NET_IPV6_ROUTE_GC_MIN_INTERVAL_MS)
 #endif
 };
 static
@@ -31,8 +51,92 @@ const struct xlat sysctl_net_ipv6_route[
  .data = sysctl_net_ipv6_route_xdata,
  .size = ARRAY_SIZE(sysctl_net_ipv6_route_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sysctl_net_ipv6_route.in 5.9-0ubuntu2/xlat/sysctl_net_ipv6_route.in
--- 5.5-3/xlat/sysctl_net_ipv6_route.in	2016-06-06 18:07:04.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_net_ipv6_route.in	2020-05-30 08:00:00.000000000 +0000
@@ -1,3 +1,6 @@
+#enum
+#include <sys/types.h>
+#include <linux/sysctl.h>
 #unconditional
 NET_IPV6_ROUTE_FLUSH
 NET_IPV6_ROUTE_GC_THRESH
diff -pruN 5.5-3/xlat/sysctl_net_ipv6_route.m4 5.9-0ubuntu2/xlat/sysctl_net_ipv6_route.m4
--- 5.5-3/xlat/sysctl_net_ipv6_route.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_net_ipv6_route.m4	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,17 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/sysctl_net_ipv6_route.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_sysctl_net_ipv6_route],[
+AC_CHECK_DECLS(m4_normalize([
+NET_IPV6_ROUTE_FLUSH,
+NET_IPV6_ROUTE_GC_THRESH,
+NET_IPV6_ROUTE_MAX_SIZE,
+NET_IPV6_ROUTE_GC_MIN_INTERVAL,
+NET_IPV6_ROUTE_GC_TIMEOUT,
+NET_IPV6_ROUTE_GC_INTERVAL,
+NET_IPV6_ROUTE_GC_ELASTICITY,
+NET_IPV6_ROUTE_MTU_EXPIRES,
+NET_IPV6_ROUTE_MIN_ADVMSS,
+NET_IPV6_ROUTE_GC_MIN_INTERVAL_MS
+]),,, [
+#include <sys/types.h>
+#include <linux/sysctl.h>
+])])])
diff -pruN 5.5-3/xlat/sysctl_net.m4 5.9-0ubuntu2/xlat/sysctl_net.m4
--- 5.5-3/xlat/sysctl_net.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_net.m4	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,28 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/sysctl_net.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_sysctl_net],[
+AC_CHECK_DECLS(m4_normalize([
+NET_CORE,
+NET_ETHER,
+NET_802,
+NET_UNIX,
+NET_IPV4,
+NET_IPX,
+NET_ATALK,
+NET_NETROM,
+NET_AX25,
+NET_BRIDGE,
+NET_ROSE,
+NET_IPV6,
+NET_X25,
+NET_TR,
+NET_DECNET,
+NET_ECONET,
+NET_SCTP,
+NET_LLC,
+NET_NETFILTER,
+NET_DCCP,
+NET_IRDA
+]),,, [
+#include <sys/types.h>
+#include <linux/sysctl.h>
+])])])
diff -pruN 5.5-3/xlat/sysctl_net_unix.h 5.9-0ubuntu2/xlat/sysctl_net_unix.h
--- 5.5-3/xlat/sysctl_net_unix.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_net_unix.h	2020-09-24 09:18:46.000000000 +0000
@@ -14,16 +14,50 @@
 
 static const struct xlat_data sysctl_net_unix_xdata[] = {
  XLAT(NET_UNIX_DESTROY_DELAY),
+ #define XLAT_VAL_0 ((unsigned) (NET_UNIX_DESTROY_DELAY))
+ #define XLAT_STR_0 STRINGIFY(NET_UNIX_DESTROY_DELAY)
  XLAT(NET_UNIX_DELETE_DELAY),
+ #define XLAT_VAL_1 ((unsigned) (NET_UNIX_DELETE_DELAY))
+ #define XLAT_STR_1 STRINGIFY(NET_UNIX_DELETE_DELAY)
  XLAT(NET_UNIX_MAX_DGRAM_QLEN),
+ #define XLAT_VAL_2 ((unsigned) (NET_UNIX_MAX_DGRAM_QLEN))
+ #define XLAT_STR_2 STRINGIFY(NET_UNIX_MAX_DGRAM_QLEN)
 };
 static
 const struct xlat sysctl_net_unix[1] = { {
  .data = sysctl_net_unix_xdata,
  .size = ARRAY_SIZE(sysctl_net_unix_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sysctl_net_unix.in 5.9-0ubuntu2/xlat/sysctl_net_unix.in
--- 5.5-3/xlat/sysctl_net_unix.in	2016-06-06 18:07:04.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_net_unix.in	2020-05-30 08:00:00.000000000 +0000
@@ -1,3 +1,6 @@
+#enum
+#include <sys/types.h>
+#include <linux/sysctl.h>
 #unconditional
 NET_UNIX_DESTROY_DELAY
 NET_UNIX_DELETE_DELAY
diff -pruN 5.5-3/xlat/sysctl_net_unix.m4 5.9-0ubuntu2/xlat/sysctl_net_unix.m4
--- 5.5-3/xlat/sysctl_net_unix.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_net_unix.m4	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,10 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/sysctl_net_unix.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_sysctl_net_unix],[
+AC_CHECK_DECLS(m4_normalize([
+NET_UNIX_DESTROY_DELAY,
+NET_UNIX_DELETE_DELAY,
+NET_UNIX_MAX_DGRAM_QLEN
+]),,, [
+#include <sys/types.h>
+#include <linux/sysctl.h>
+])])])
diff -pruN 5.5-3/xlat/sysctl_root.h 5.9-0ubuntu2/xlat/sysctl_root.h
--- 5.5-3/xlat/sysctl_root.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_root.h	2020-09-24 09:18:46.000000000 +0000
@@ -14,31 +14,61 @@
 
 static const struct xlat_data sysctl_root_xdata[] = {
  XLAT(CTL_KERN),
+ #define XLAT_VAL_0 ((unsigned) (CTL_KERN))
+ #define XLAT_STR_0 STRINGIFY(CTL_KERN)
  XLAT(CTL_VM),
+ #define XLAT_VAL_1 ((unsigned) (CTL_VM))
+ #define XLAT_STR_1 STRINGIFY(CTL_VM)
  XLAT(CTL_NET),
+ #define XLAT_VAL_2 ((unsigned) (CTL_NET))
+ #define XLAT_STR_2 STRINGIFY(CTL_NET)
  XLAT(CTL_FS),
+ #define XLAT_VAL_3 ((unsigned) (CTL_FS))
+ #define XLAT_STR_3 STRINGIFY(CTL_FS)
  XLAT(CTL_DEBUG),
+ #define XLAT_VAL_4 ((unsigned) (CTL_DEBUG))
+ #define XLAT_STR_4 STRINGIFY(CTL_DEBUG)
  XLAT(CTL_DEV),
+ #define XLAT_VAL_5 ((unsigned) (CTL_DEV))
+ #define XLAT_STR_5 STRINGIFY(CTL_DEV)
  XLAT(CTL_BUS),
+ #define XLAT_VAL_6 ((unsigned) (CTL_BUS))
+ #define XLAT_STR_6 STRINGIFY(CTL_BUS)
  XLAT(CTL_ABI),
+ #define XLAT_VAL_7 ((unsigned) (CTL_ABI))
+ #define XLAT_STR_7 STRINGIFY(CTL_ABI)
  XLAT(CTL_CPU),
+ #define XLAT_VAL_8 ((unsigned) (CTL_CPU))
+ #define XLAT_STR_8 STRINGIFY(CTL_CPU)
 #if defined(CTL_PROC) || (defined(HAVE_DECL_CTL_PROC) && HAVE_DECL_CTL_PROC)
   XLAT(CTL_PROC),
+ #define XLAT_VAL_9 ((unsigned) (CTL_PROC))
+ #define XLAT_STR_9 STRINGIFY(CTL_PROC)
 #endif
 #if defined(CTL_ARLAN) || (defined(HAVE_DECL_CTL_ARLAN) && HAVE_DECL_CTL_ARLAN)
   XLAT(CTL_ARLAN),
+ #define XLAT_VAL_10 ((unsigned) (CTL_ARLAN))
+ #define XLAT_STR_10 STRINGIFY(CTL_ARLAN)
 #endif
 #if defined(CTL_S390DBF) || (defined(HAVE_DECL_CTL_S390DBF) && HAVE_DECL_CTL_S390DBF)
   XLAT(CTL_S390DBF),
+ #define XLAT_VAL_11 ((unsigned) (CTL_S390DBF))
+ #define XLAT_STR_11 STRINGIFY(CTL_S390DBF)
 #endif
 #if defined(CTL_SUNRPC) || (defined(HAVE_DECL_CTL_SUNRPC) && HAVE_DECL_CTL_SUNRPC)
   XLAT(CTL_SUNRPC),
+ #define XLAT_VAL_12 ((unsigned) (CTL_SUNRPC))
+ #define XLAT_STR_12 STRINGIFY(CTL_SUNRPC)
 #endif
 #if defined(CTL_PM) || (defined(HAVE_DECL_CTL_PM) && HAVE_DECL_CTL_PM)
   XLAT(CTL_PM),
+ #define XLAT_VAL_13 ((unsigned) (CTL_PM))
+ #define XLAT_STR_13 STRINGIFY(CTL_PM)
 #endif
 #if defined(CTL_FRV) || (defined(HAVE_DECL_CTL_FRV) && HAVE_DECL_CTL_FRV)
   XLAT(CTL_FRV),
+ #define XLAT_VAL_14 ((unsigned) (CTL_FRV))
+ #define XLAT_STR_14 STRINGIFY(CTL_FRV)
 #endif
 };
 static
@@ -46,8 +76,132 @@ const struct xlat sysctl_root[1] = { {
  .data = sysctl_root_xdata,
  .size = ARRAY_SIZE(sysctl_root_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sysctl_root.in 5.9-0ubuntu2/xlat/sysctl_root.in
--- 5.5-3/xlat/sysctl_root.in	2016-06-06 18:07:04.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_root.in	2020-05-30 08:00:00.000000000 +0000
@@ -1,3 +1,6 @@
+#enum
+#include <sys/types.h>
+#include <linux/sysctl.h>
 #unconditional
 CTL_KERN
 CTL_VM
diff -pruN 5.5-3/xlat/sysctl_root.m4 5.9-0ubuntu2/xlat/sysctl_root.m4
--- 5.5-3/xlat/sysctl_root.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_root.m4	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,22 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/sysctl_root.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_sysctl_root],[
+AC_CHECK_DECLS(m4_normalize([
+CTL_KERN,
+CTL_VM,
+CTL_NET,
+CTL_FS,
+CTL_DEBUG,
+CTL_DEV,
+CTL_BUS,
+CTL_ABI,
+CTL_CPU,
+CTL_PROC,
+CTL_ARLAN,
+CTL_S390DBF,
+CTL_SUNRPC,
+CTL_PM,
+CTL_FRV
+]),,, [
+#include <sys/types.h>
+#include <linux/sysctl.h>
+])])])
diff -pruN 5.5-3/xlat/sysctl_vm.h 5.9-0ubuntu2/xlat/sysctl_vm.h
--- 5.5-3/xlat/sysctl_vm.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_vm.h	2020-09-24 09:18:46.000000000 +0000
@@ -14,38 +14,78 @@
 
 static const struct xlat_data sysctl_vm_xdata[] = {
  XLAT(VM_OVERCOMMIT_MEMORY),
+ #define XLAT_VAL_0 ((unsigned) (VM_OVERCOMMIT_MEMORY))
+ #define XLAT_STR_0 STRINGIFY(VM_OVERCOMMIT_MEMORY)
  XLAT(VM_PAGE_CLUSTER),
+ #define XLAT_VAL_1 ((unsigned) (VM_PAGE_CLUSTER))
+ #define XLAT_STR_1 STRINGIFY(VM_PAGE_CLUSTER)
  XLAT(VM_DIRTY_BACKGROUND),
+ #define XLAT_VAL_2 ((unsigned) (VM_DIRTY_BACKGROUND))
+ #define XLAT_STR_2 STRINGIFY(VM_DIRTY_BACKGROUND)
  XLAT(VM_DIRTY_RATIO),
+ #define XLAT_VAL_3 ((unsigned) (VM_DIRTY_RATIO))
+ #define XLAT_STR_3 STRINGIFY(VM_DIRTY_RATIO)
  XLAT(VM_DIRTY_WB_CS),
+ #define XLAT_VAL_4 ((unsigned) (VM_DIRTY_WB_CS))
+ #define XLAT_STR_4 STRINGIFY(VM_DIRTY_WB_CS)
  XLAT(VM_DIRTY_EXPIRE_CS),
+ #define XLAT_VAL_5 ((unsigned) (VM_DIRTY_EXPIRE_CS))
+ #define XLAT_STR_5 STRINGIFY(VM_DIRTY_EXPIRE_CS)
  XLAT(VM_NR_PDFLUSH_THREADS),
+ #define XLAT_VAL_6 ((unsigned) (VM_NR_PDFLUSH_THREADS))
+ #define XLAT_STR_6 STRINGIFY(VM_NR_PDFLUSH_THREADS)
  XLAT(VM_OVERCOMMIT_RATIO),
+ #define XLAT_VAL_7 ((unsigned) (VM_OVERCOMMIT_RATIO))
+ #define XLAT_STR_7 STRINGIFY(VM_OVERCOMMIT_RATIO)
  XLAT(VM_PAGEBUF),
+ #define XLAT_VAL_8 ((unsigned) (VM_PAGEBUF))
+ #define XLAT_STR_8 STRINGIFY(VM_PAGEBUF)
  XLAT(VM_HUGETLB_PAGES),
+ #define XLAT_VAL_9 ((unsigned) (VM_HUGETLB_PAGES))
+ #define XLAT_STR_9 STRINGIFY(VM_HUGETLB_PAGES)
  XLAT(VM_SWAPPINESS),
+ #define XLAT_VAL_10 ((unsigned) (VM_SWAPPINESS))
+ #define XLAT_STR_10 STRINGIFY(VM_SWAPPINESS)
  XLAT(VM_LOWMEM_RESERVE_RATIO),
+ #define XLAT_VAL_11 ((unsigned) (VM_LOWMEM_RESERVE_RATIO))
+ #define XLAT_STR_11 STRINGIFY(VM_LOWMEM_RESERVE_RATIO)
  XLAT(VM_MIN_FREE_KBYTES),
+ #define XLAT_VAL_12 ((unsigned) (VM_MIN_FREE_KBYTES))
+ #define XLAT_STR_12 STRINGIFY(VM_MIN_FREE_KBYTES)
 #if defined(VM_MAX_MAP_COUNT) || (defined(HAVE_DECL_VM_MAX_MAP_COUNT) && HAVE_DECL_VM_MAX_MAP_COUNT)
   XLAT(VM_MAX_MAP_COUNT),
+ #define XLAT_VAL_13 ((unsigned) (VM_MAX_MAP_COUNT))
+ #define XLAT_STR_13 STRINGIFY(VM_MAX_MAP_COUNT)
 #endif
 #if defined(VM_LAPTOP_MODE) || (defined(HAVE_DECL_VM_LAPTOP_MODE) && HAVE_DECL_VM_LAPTOP_MODE)
   XLAT(VM_LAPTOP_MODE),
+ #define XLAT_VAL_14 ((unsigned) (VM_LAPTOP_MODE))
+ #define XLAT_STR_14 STRINGIFY(VM_LAPTOP_MODE)
 #endif
 #if defined(VM_BLOCK_DUMP) || (defined(HAVE_DECL_VM_BLOCK_DUMP) && HAVE_DECL_VM_BLOCK_DUMP)
   XLAT(VM_BLOCK_DUMP),
+ #define XLAT_VAL_15 ((unsigned) (VM_BLOCK_DUMP))
+ #define XLAT_STR_15 STRINGIFY(VM_BLOCK_DUMP)
 #endif
 #if defined(VM_HUGETLB_GROUP) || (defined(HAVE_DECL_VM_HUGETLB_GROUP) && HAVE_DECL_VM_HUGETLB_GROUP)
   XLAT(VM_HUGETLB_GROUP),
+ #define XLAT_VAL_16 ((unsigned) (VM_HUGETLB_GROUP))
+ #define XLAT_STR_16 STRINGIFY(VM_HUGETLB_GROUP)
 #endif
 #if defined(VM_VFS_CACHE_PRESSURE) || (defined(HAVE_DECL_VM_VFS_CACHE_PRESSURE) && HAVE_DECL_VM_VFS_CACHE_PRESSURE)
   XLAT(VM_VFS_CACHE_PRESSURE),
+ #define XLAT_VAL_17 ((unsigned) (VM_VFS_CACHE_PRESSURE))
+ #define XLAT_STR_17 STRINGIFY(VM_VFS_CACHE_PRESSURE)
 #endif
 #if defined(VM_LEGACY_VA_LAYOUT) || (defined(HAVE_DECL_VM_LEGACY_VA_LAYOUT) && HAVE_DECL_VM_LEGACY_VA_LAYOUT)
   XLAT(VM_LEGACY_VA_LAYOUT),
+ #define XLAT_VAL_18 ((unsigned) (VM_LEGACY_VA_LAYOUT))
+ #define XLAT_STR_18 STRINGIFY(VM_LEGACY_VA_LAYOUT)
 #endif
 #if defined(VM_SWAP_TOKEN_TIMEOUT) || (defined(HAVE_DECL_VM_SWAP_TOKEN_TIMEOUT) && HAVE_DECL_VM_SWAP_TOKEN_TIMEOUT)
   XLAT(VM_SWAP_TOKEN_TIMEOUT),
+ #define XLAT_VAL_19 ((unsigned) (VM_SWAP_TOKEN_TIMEOUT))
+ #define XLAT_STR_19 STRINGIFY(VM_SWAP_TOKEN_TIMEOUT)
 #endif
 };
 static
@@ -53,8 +93,172 @@ const struct xlat sysctl_vm[1] = { {
  .data = sysctl_vm_xdata,
  .size = ARRAY_SIZE(sysctl_vm_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sysctl_vm.in 5.9-0ubuntu2/xlat/sysctl_vm.in
--- 5.5-3/xlat/sysctl_vm.in	2016-06-06 18:07:04.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_vm.in	2020-05-30 08:00:00.000000000 +0000
@@ -1,3 +1,6 @@
+#enum
+#include <sys/types.h>
+#include <linux/sysctl.h>
 #unconditional
 VM_OVERCOMMIT_MEMORY
 VM_PAGE_CLUSTER
diff -pruN 5.5-3/xlat/sysctl_vm.m4 5.9-0ubuntu2/xlat/sysctl_vm.m4
--- 5.5-3/xlat/sysctl_vm.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysctl_vm.m4	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,27 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/sysctl_vm.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_sysctl_vm],[
+AC_CHECK_DECLS(m4_normalize([
+VM_OVERCOMMIT_MEMORY,
+VM_PAGE_CLUSTER,
+VM_DIRTY_BACKGROUND,
+VM_DIRTY_RATIO,
+VM_DIRTY_WB_CS,
+VM_DIRTY_EXPIRE_CS,
+VM_NR_PDFLUSH_THREADS,
+VM_OVERCOMMIT_RATIO,
+VM_PAGEBUF,
+VM_HUGETLB_PAGES,
+VM_SWAPPINESS,
+VM_LOWMEM_RESERVE_RATIO,
+VM_MIN_FREE_KBYTES,
+VM_MAX_MAP_COUNT,
+VM_LAPTOP_MODE,
+VM_BLOCK_DUMP,
+VM_HUGETLB_GROUP,
+VM_VFS_CACHE_PRESSURE,
+VM_LEGACY_VA_LAYOUT,
+VM_SWAP_TOKEN_TIMEOUT
+]),,, [
+#include <sys/types.h>
+#include <linux/sysctl.h>
+])])])
diff -pruN 5.5-3/xlat/syslog_action_type.h 5.9-0ubuntu2/xlat/syslog_action_type.h
--- 5.5-3/xlat/syslog_action_type.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/syslog_action_type.h	2020-09-24 09:18:46.000000000 +0000
@@ -91,24 +91,138 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data syslog_action_type_xdata[] = {
  [SYSLOG_ACTION_CLOSE] = XLAT(SYSLOG_ACTION_CLOSE),
+ #define XLAT_VAL_0 ((unsigned) (SYSLOG_ACTION_CLOSE))
+ #define XLAT_STR_0 STRINGIFY(SYSLOG_ACTION_CLOSE)
  [SYSLOG_ACTION_OPEN] = XLAT(SYSLOG_ACTION_OPEN),
+ #define XLAT_VAL_1 ((unsigned) (SYSLOG_ACTION_OPEN))
+ #define XLAT_STR_1 STRINGIFY(SYSLOG_ACTION_OPEN)
  [SYSLOG_ACTION_READ] = XLAT(SYSLOG_ACTION_READ),
+ #define XLAT_VAL_2 ((unsigned) (SYSLOG_ACTION_READ))
+ #define XLAT_STR_2 STRINGIFY(SYSLOG_ACTION_READ)
  [SYSLOG_ACTION_READ_ALL] = XLAT(SYSLOG_ACTION_READ_ALL),
+ #define XLAT_VAL_3 ((unsigned) (SYSLOG_ACTION_READ_ALL))
+ #define XLAT_STR_3 STRINGIFY(SYSLOG_ACTION_READ_ALL)
  [SYSLOG_ACTION_READ_CLEAR] = XLAT(SYSLOG_ACTION_READ_CLEAR),
+ #define XLAT_VAL_4 ((unsigned) (SYSLOG_ACTION_READ_CLEAR))
+ #define XLAT_STR_4 STRINGIFY(SYSLOG_ACTION_READ_CLEAR)
  [SYSLOG_ACTION_CLEAR] = XLAT(SYSLOG_ACTION_CLEAR),
+ #define XLAT_VAL_5 ((unsigned) (SYSLOG_ACTION_CLEAR))
+ #define XLAT_STR_5 STRINGIFY(SYSLOG_ACTION_CLEAR)
  [SYSLOG_ACTION_CONSOLE_OFF] = XLAT(SYSLOG_ACTION_CONSOLE_OFF),
+ #define XLAT_VAL_6 ((unsigned) (SYSLOG_ACTION_CONSOLE_OFF))
+ #define XLAT_STR_6 STRINGIFY(SYSLOG_ACTION_CONSOLE_OFF)
  [SYSLOG_ACTION_CONSOLE_ON] = XLAT(SYSLOG_ACTION_CONSOLE_ON),
+ #define XLAT_VAL_7 ((unsigned) (SYSLOG_ACTION_CONSOLE_ON))
+ #define XLAT_STR_7 STRINGIFY(SYSLOG_ACTION_CONSOLE_ON)
  [SYSLOG_ACTION_CONSOLE_LEVEL] = XLAT(SYSLOG_ACTION_CONSOLE_LEVEL),
+ #define XLAT_VAL_8 ((unsigned) (SYSLOG_ACTION_CONSOLE_LEVEL))
+ #define XLAT_STR_8 STRINGIFY(SYSLOG_ACTION_CONSOLE_LEVEL)
  [SYSLOG_ACTION_SIZE_UNREAD] = XLAT(SYSLOG_ACTION_SIZE_UNREAD),
+ #define XLAT_VAL_9 ((unsigned) (SYSLOG_ACTION_SIZE_UNREAD))
+ #define XLAT_STR_9 STRINGIFY(SYSLOG_ACTION_SIZE_UNREAD)
  [SYSLOG_ACTION_SIZE_BUFFER] = XLAT(SYSLOG_ACTION_SIZE_BUFFER),
+ #define XLAT_VAL_10 ((unsigned) (SYSLOG_ACTION_SIZE_BUFFER))
+ #define XLAT_STR_10 STRINGIFY(SYSLOG_ACTION_SIZE_BUFFER)
 };
 static
 const struct xlat syslog_action_type[1] = { {
  .data = syslog_action_type_xdata,
  .size = ARRAY_SIZE(syslog_action_type_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/syslog_console_levels.h 5.9-0ubuntu2/xlat/syslog_console_levels.h
--- 5.5-3/xlat/syslog_console_levels.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/syslog_console_levels.h	2020-09-24 09:18:46.000000000 +0000
@@ -78,22 +78,116 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 static const struct xlat_data syslog_console_levels_xdata[] = {
 
  [LOGLEVEL_EMERG] = XLAT(LOGLEVEL_EMERG),
+ #define XLAT_VAL_0 ((unsigned) (LOGLEVEL_EMERG))
+ #define XLAT_STR_0 STRINGIFY(LOGLEVEL_EMERG)
  [LOGLEVEL_ALERT] = XLAT(LOGLEVEL_ALERT),
+ #define XLAT_VAL_1 ((unsigned) (LOGLEVEL_ALERT))
+ #define XLAT_STR_1 STRINGIFY(LOGLEVEL_ALERT)
  [LOGLEVEL_CRIT] = XLAT(LOGLEVEL_CRIT),
+ #define XLAT_VAL_2 ((unsigned) (LOGLEVEL_CRIT))
+ #define XLAT_STR_2 STRINGIFY(LOGLEVEL_CRIT)
  [LOGLEVEL_ERR] = XLAT(LOGLEVEL_ERR),
+ #define XLAT_VAL_3 ((unsigned) (LOGLEVEL_ERR))
+ #define XLAT_STR_3 STRINGIFY(LOGLEVEL_ERR)
  [LOGLEVEL_WARNING] = XLAT(LOGLEVEL_WARNING),
+ #define XLAT_VAL_4 ((unsigned) (LOGLEVEL_WARNING))
+ #define XLAT_STR_4 STRINGIFY(LOGLEVEL_WARNING)
  [LOGLEVEL_NOTICE] = XLAT(LOGLEVEL_NOTICE),
+ #define XLAT_VAL_5 ((unsigned) (LOGLEVEL_NOTICE))
+ #define XLAT_STR_5 STRINGIFY(LOGLEVEL_NOTICE)
  [LOGLEVEL_INFO] = XLAT(LOGLEVEL_INFO),
+ #define XLAT_VAL_6 ((unsigned) (LOGLEVEL_INFO))
+ #define XLAT_STR_6 STRINGIFY(LOGLEVEL_INFO)
  [LOGLEVEL_DEBUG] = XLAT(LOGLEVEL_DEBUG),
+ #define XLAT_VAL_7 ((unsigned) (LOGLEVEL_DEBUG))
+ #define XLAT_STR_7 STRINGIFY(LOGLEVEL_DEBUG)
  [LOGLEVEL_DEBUG+1] = XLAT(LOGLEVEL_DEBUG+1),
+ #define XLAT_VAL_8 ((unsigned) (LOGLEVEL_DEBUG+1))
+ #define XLAT_STR_8 STRINGIFY(LOGLEVEL_DEBUG+1)
 };
 static
 const struct xlat syslog_console_levels[1] = { {
  .data = syslog_console_levels_xdata,
  .size = ARRAY_SIZE(syslog_console_levels_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/sysmips_operations.h 5.9-0ubuntu2/xlat/sysmips_operations.h
--- 5.5-3/xlat/sysmips_operations.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/sysmips_operations.h	2020-09-24 09:18:46.000000000 +0000
@@ -15,18 +15,28 @@
 static const struct xlat_data sysmips_operations_xdata[] = {
 #if defined(SETNAME) || (defined(HAVE_DECL_SETNAME) && HAVE_DECL_SETNAME)
   XLAT(SETNAME),
+ #define XLAT_VAL_0 ((unsigned) (SETNAME))
+ #define XLAT_STR_0 STRINGIFY(SETNAME)
 #endif
 #if defined(FLUSH_CACHE) || (defined(HAVE_DECL_FLUSH_CACHE) && HAVE_DECL_FLUSH_CACHE)
   XLAT(FLUSH_CACHE),
+ #define XLAT_VAL_1 ((unsigned) (FLUSH_CACHE))
+ #define XLAT_STR_1 STRINGIFY(FLUSH_CACHE)
 #endif
 #if defined(MIPS_FIXADE) || (defined(HAVE_DECL_MIPS_FIXADE) && HAVE_DECL_MIPS_FIXADE)
   XLAT(MIPS_FIXADE),
+ #define XLAT_VAL_2 ((unsigned) (MIPS_FIXADE))
+ #define XLAT_STR_2 STRINGIFY(MIPS_FIXADE)
 #endif
 #if defined(MIPS_RDNVRAM) || (defined(HAVE_DECL_MIPS_RDNVRAM) && HAVE_DECL_MIPS_RDNVRAM)
   XLAT(MIPS_RDNVRAM),
+ #define XLAT_VAL_3 ((unsigned) (MIPS_RDNVRAM))
+ #define XLAT_STR_3 STRINGIFY(MIPS_RDNVRAM)
 #endif
 #if defined(MIPS_ATOMIC_SET) || (defined(HAVE_DECL_MIPS_ATOMIC_SET) && HAVE_DECL_MIPS_ATOMIC_SET)
   XLAT(MIPS_ATOMIC_SET),
+ #define XLAT_VAL_4 ((unsigned) (MIPS_ATOMIC_SET))
+ #define XLAT_STR_4 STRINGIFY(MIPS_ATOMIC_SET)
 #endif
 };
 static
@@ -34,8 +44,52 @@ const struct xlat sysmips_operations[1]
  .data = sysmips_operations_xdata,
  .size = ARRAY_SIZE(sysmips_operations_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/tcflsh_options.h 5.9-0ubuntu2/xlat/tcflsh_options.h
--- 5.5-3/xlat/tcflsh_options.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/tcflsh_options.h	2020-09-24 09:18:46.000000000 +0000
@@ -15,12 +15,18 @@
 static const struct xlat_data tcflsh_options_xdata[] = {
 #if defined(TCIFLUSH) || (defined(HAVE_DECL_TCIFLUSH) && HAVE_DECL_TCIFLUSH)
   XLAT(TCIFLUSH),
+ #define XLAT_VAL_0 ((unsigned) (TCIFLUSH))
+ #define XLAT_STR_0 STRINGIFY(TCIFLUSH)
 #endif
 #if defined(TCOFLUSH) || (defined(HAVE_DECL_TCOFLUSH) && HAVE_DECL_TCOFLUSH)
   XLAT(TCOFLUSH),
+ #define XLAT_VAL_1 ((unsigned) (TCOFLUSH))
+ #define XLAT_STR_1 STRINGIFY(TCOFLUSH)
 #endif
 #if defined(TCIOFLUSH) || (defined(HAVE_DECL_TCIOFLUSH) && HAVE_DECL_TCIOFLUSH)
   XLAT(TCIOFLUSH),
+ #define XLAT_VAL_2 ((unsigned) (TCIOFLUSH))
+ #define XLAT_STR_2 STRINGIFY(TCIOFLUSH)
 #endif
 };
 static
@@ -28,8 +34,36 @@ const struct xlat tcflsh_options[1] = {
  .data = tcflsh_options_xdata,
  .size = ARRAY_SIZE(tcflsh_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/tcp_state_flags.h 5.9-0ubuntu2/xlat/tcp_state_flags.h
--- 5.5-3/xlat/tcp_state_flags.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/tcp_state_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -12,47 +12,171 @@ static const struct xlat_data tcp_state_
 
 #if defined(TCP_ESTABLISHED) || (defined(HAVE_DECL_TCP_ESTABLISHED) && HAVE_DECL_TCP_ESTABLISHED)
   XLAT_PAIR(1ULL<<TCP_ESTABLISHED, "1<<TCP_ESTABLISHED"),
+ #define XLAT_VAL_0 ((unsigned) (1ULL<<TCP_ESTABLISHED))
+ #define XLAT_STR_0 "1<<TCP_ESTABLISHED"
 #endif
 #if defined(TCP_SYN_SENT) || (defined(HAVE_DECL_TCP_SYN_SENT) && HAVE_DECL_TCP_SYN_SENT)
   XLAT_PAIR(1ULL<<TCP_SYN_SENT, "1<<TCP_SYN_SENT"),
+ #define XLAT_VAL_1 ((unsigned) (1ULL<<TCP_SYN_SENT))
+ #define XLAT_STR_1 "1<<TCP_SYN_SENT"
 #endif
 #if defined(TCP_SYN_RECV) || (defined(HAVE_DECL_TCP_SYN_RECV) && HAVE_DECL_TCP_SYN_RECV)
   XLAT_PAIR(1ULL<<TCP_SYN_RECV, "1<<TCP_SYN_RECV"),
+ #define XLAT_VAL_2 ((unsigned) (1ULL<<TCP_SYN_RECV))
+ #define XLAT_STR_2 "1<<TCP_SYN_RECV"
 #endif
 #if defined(TCP_FIN_WAIT1) || (defined(HAVE_DECL_TCP_FIN_WAIT1) && HAVE_DECL_TCP_FIN_WAIT1)
   XLAT_PAIR(1ULL<<TCP_FIN_WAIT1, "1<<TCP_FIN_WAIT1"),
+ #define XLAT_VAL_3 ((unsigned) (1ULL<<TCP_FIN_WAIT1))
+ #define XLAT_STR_3 "1<<TCP_FIN_WAIT1"
 #endif
 #if defined(TCP_FIN_WAIT2) || (defined(HAVE_DECL_TCP_FIN_WAIT2) && HAVE_DECL_TCP_FIN_WAIT2)
   XLAT_PAIR(1ULL<<TCP_FIN_WAIT2, "1<<TCP_FIN_WAIT2"),
+ #define XLAT_VAL_4 ((unsigned) (1ULL<<TCP_FIN_WAIT2))
+ #define XLAT_STR_4 "1<<TCP_FIN_WAIT2"
 #endif
 #if defined(TCP_TIME_WAIT) || (defined(HAVE_DECL_TCP_TIME_WAIT) && HAVE_DECL_TCP_TIME_WAIT)
   XLAT_PAIR(1ULL<<TCP_TIME_WAIT, "1<<TCP_TIME_WAIT"),
+ #define XLAT_VAL_5 ((unsigned) (1ULL<<TCP_TIME_WAIT))
+ #define XLAT_STR_5 "1<<TCP_TIME_WAIT"
 #endif
 #if defined(TCP_CLOSE) || (defined(HAVE_DECL_TCP_CLOSE) && HAVE_DECL_TCP_CLOSE)
   XLAT_PAIR(1ULL<<TCP_CLOSE, "1<<TCP_CLOSE"),
+ #define XLAT_VAL_6 ((unsigned) (1ULL<<TCP_CLOSE))
+ #define XLAT_STR_6 "1<<TCP_CLOSE"
 #endif
 #if defined(TCP_CLOSE_WAIT) || (defined(HAVE_DECL_TCP_CLOSE_WAIT) && HAVE_DECL_TCP_CLOSE_WAIT)
   XLAT_PAIR(1ULL<<TCP_CLOSE_WAIT, "1<<TCP_CLOSE_WAIT"),
+ #define XLAT_VAL_7 ((unsigned) (1ULL<<TCP_CLOSE_WAIT))
+ #define XLAT_STR_7 "1<<TCP_CLOSE_WAIT"
 #endif
 #if defined(TCP_LAST_ACK) || (defined(HAVE_DECL_TCP_LAST_ACK) && HAVE_DECL_TCP_LAST_ACK)
   XLAT_PAIR(1ULL<<TCP_LAST_ACK, "1<<TCP_LAST_ACK"),
+ #define XLAT_VAL_8 ((unsigned) (1ULL<<TCP_LAST_ACK))
+ #define XLAT_STR_8 "1<<TCP_LAST_ACK"
 #endif
 #if defined(TCP_LISTEN) || (defined(HAVE_DECL_TCP_LISTEN) && HAVE_DECL_TCP_LISTEN)
   XLAT_PAIR(1ULL<<TCP_LISTEN, "1<<TCP_LISTEN"),
+ #define XLAT_VAL_9 ((unsigned) (1ULL<<TCP_LISTEN))
+ #define XLAT_STR_9 "1<<TCP_LISTEN"
 #endif
 #if defined(TCP_CLOSING) || (defined(HAVE_DECL_TCP_CLOSING) && HAVE_DECL_TCP_CLOSING)
   XLAT_PAIR(1ULL<<TCP_CLOSING, "1<<TCP_CLOSING"),
+ #define XLAT_VAL_10 ((unsigned) (1ULL<<TCP_CLOSING))
+ #define XLAT_STR_10 "1<<TCP_CLOSING"
 #endif
 #if defined(TCP_NEW_SYN_RECV) || (defined(HAVE_DECL_TCP_NEW_SYN_RECV) && HAVE_DECL_TCP_NEW_SYN_RECV)
   XLAT_PAIR(1ULL<<TCP_NEW_SYN_RECV, "1<<TCP_NEW_SYN_RECV"),
+ #define XLAT_VAL_11 ((unsigned) (1ULL<<TCP_NEW_SYN_RECV))
+ #define XLAT_STR_11 "1<<TCP_NEW_SYN_RECV"
 #endif
 };
 const struct xlat tcp_state_flags[1] = { {
  .data = tcp_state_flags_xdata,
  .size = ARRAY_SIZE(tcp_state_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/tcp_states.h 5.9-0ubuntu2/xlat/tcp_states.h
--- 5.5-3/xlat/tcp_states.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/tcp_states.h	2020-09-24 09:18:46.000000000 +0000
@@ -94,24 +94,148 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data tcp_states_xdata[] = {
  [TCP_ESTABLISHED] = XLAT(TCP_ESTABLISHED),
+ #define XLAT_VAL_0 ((unsigned) (TCP_ESTABLISHED))
+ #define XLAT_STR_0 STRINGIFY(TCP_ESTABLISHED)
  [TCP_SYN_SENT] = XLAT(TCP_SYN_SENT),
+ #define XLAT_VAL_1 ((unsigned) (TCP_SYN_SENT))
+ #define XLAT_STR_1 STRINGIFY(TCP_SYN_SENT)
  [TCP_SYN_RECV] = XLAT(TCP_SYN_RECV),
+ #define XLAT_VAL_2 ((unsigned) (TCP_SYN_RECV))
+ #define XLAT_STR_2 STRINGIFY(TCP_SYN_RECV)
  [TCP_FIN_WAIT1] = XLAT(TCP_FIN_WAIT1),
+ #define XLAT_VAL_3 ((unsigned) (TCP_FIN_WAIT1))
+ #define XLAT_STR_3 STRINGIFY(TCP_FIN_WAIT1)
  [TCP_FIN_WAIT2] = XLAT(TCP_FIN_WAIT2),
+ #define XLAT_VAL_4 ((unsigned) (TCP_FIN_WAIT2))
+ #define XLAT_STR_4 STRINGIFY(TCP_FIN_WAIT2)
  [TCP_TIME_WAIT] = XLAT(TCP_TIME_WAIT),
+ #define XLAT_VAL_5 ((unsigned) (TCP_TIME_WAIT))
+ #define XLAT_STR_5 STRINGIFY(TCP_TIME_WAIT)
  [TCP_CLOSE] = XLAT(TCP_CLOSE),
+ #define XLAT_VAL_6 ((unsigned) (TCP_CLOSE))
+ #define XLAT_STR_6 STRINGIFY(TCP_CLOSE)
  [TCP_CLOSE_WAIT] = XLAT(TCP_CLOSE_WAIT),
+ #define XLAT_VAL_7 ((unsigned) (TCP_CLOSE_WAIT))
+ #define XLAT_STR_7 STRINGIFY(TCP_CLOSE_WAIT)
  [TCP_LAST_ACK] = XLAT(TCP_LAST_ACK),
+ #define XLAT_VAL_8 ((unsigned) (TCP_LAST_ACK))
+ #define XLAT_STR_8 STRINGIFY(TCP_LAST_ACK)
  [TCP_LISTEN] = XLAT(TCP_LISTEN),
+ #define XLAT_VAL_9 ((unsigned) (TCP_LISTEN))
+ #define XLAT_STR_9 STRINGIFY(TCP_LISTEN)
  [TCP_CLOSING] = XLAT(TCP_CLOSING),
+ #define XLAT_VAL_10 ((unsigned) (TCP_CLOSING))
+ #define XLAT_STR_10 STRINGIFY(TCP_CLOSING)
  [TCP_NEW_SYN_RECV] = XLAT(TCP_NEW_SYN_RECV),
+ #define XLAT_VAL_11 ((unsigned) (TCP_NEW_SYN_RECV))
+ #define XLAT_STR_11 STRINGIFY(TCP_NEW_SYN_RECV)
 };
 const struct xlat tcp_states[1] = { {
  .data = tcp_states_xdata,
  .size = ARRAY_SIZE(tcp_states_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/tcxonc_options.h 5.9-0ubuntu2/xlat/tcxonc_options.h
--- 5.5-3/xlat/tcxonc_options.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/tcxonc_options.h	2020-09-24 09:18:46.000000000 +0000
@@ -15,15 +15,23 @@
 static const struct xlat_data tcxonc_options_xdata[] = {
 #if defined(TCOOFF) || (defined(HAVE_DECL_TCOOFF) && HAVE_DECL_TCOOFF)
   XLAT(TCOOFF),
+ #define XLAT_VAL_0 ((unsigned) (TCOOFF))
+ #define XLAT_STR_0 STRINGIFY(TCOOFF)
 #endif
 #if defined(TCOON) || (defined(HAVE_DECL_TCOON) && HAVE_DECL_TCOON)
   XLAT(TCOON),
+ #define XLAT_VAL_1 ((unsigned) (TCOON))
+ #define XLAT_STR_1 STRINGIFY(TCOON)
 #endif
 #if defined(TCIOFF) || (defined(HAVE_DECL_TCIOFF) && HAVE_DECL_TCIOFF)
   XLAT(TCIOFF),
+ #define XLAT_VAL_2 ((unsigned) (TCIOFF))
+ #define XLAT_STR_2 STRINGIFY(TCIOFF)
 #endif
 #if defined(TCION) || (defined(HAVE_DECL_TCION) && HAVE_DECL_TCION)
   XLAT(TCION),
+ #define XLAT_VAL_3 ((unsigned) (TCION))
+ #define XLAT_STR_3 STRINGIFY(TCION)
 #endif
 };
 static
@@ -31,8 +39,44 @@ const struct xlat tcxonc_options[1] = {
  .data = tcxonc_options_xdata,
  .size = ARRAY_SIZE(tcxonc_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/tee_ioctl_cmds.h 5.9-0ubuntu2/xlat/tee_ioctl_cmds.h
--- 5.5-3/xlat/tee_ioctl_cmds.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/tee_ioctl_cmds.h	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,210 @@
+/* Generated by ./xlat/gen.sh from ./xlat/tee_ioctl_cmds.in; do not edit. */
+
+#include "gcc_compat.h"
+#include "static_assert.h"
+
+#if defined(TEE_IOC_VERSION) || (defined(HAVE_DECL_TEE_IOC_VERSION) && HAVE_DECL_TEE_IOC_VERSION)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOC_VERSION) == (_IOR (0xa4, 0, struct_tee_ioctl_version_data)), "TEE_IOC_VERSION != _IOR (0xa4, 0, struct_tee_ioctl_version_data)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOC_VERSION _IOR (0xa4, 0, struct_tee_ioctl_version_data)
+#endif
+#if defined(TEE_IOC_SHM_ALLOC) || (defined(HAVE_DECL_TEE_IOC_SHM_ALLOC) && HAVE_DECL_TEE_IOC_SHM_ALLOC)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOC_SHM_ALLOC) == (_IOWR(0xa4, 1, struct_tee_ioctl_shm_alloc_data)), "TEE_IOC_SHM_ALLOC != _IOWR(0xa4, 1, struct_tee_ioctl_shm_alloc_data)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOC_SHM_ALLOC _IOWR(0xa4, 1, struct_tee_ioctl_shm_alloc_data)
+#endif
+#if defined(TEE_IOC_OPEN_SESSION) || (defined(HAVE_DECL_TEE_IOC_OPEN_SESSION) && HAVE_DECL_TEE_IOC_OPEN_SESSION)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOC_OPEN_SESSION) == (_IOR (0xa4, 2, struct_tee_ioctl_buf_data)), "TEE_IOC_OPEN_SESSION != _IOR (0xa4, 2, struct_tee_ioctl_buf_data)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOC_OPEN_SESSION _IOR (0xa4, 2, struct_tee_ioctl_buf_data)
+#endif
+#if defined(TEE_IOC_INVOKE) || (defined(HAVE_DECL_TEE_IOC_INVOKE) && HAVE_DECL_TEE_IOC_INVOKE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOC_INVOKE) == (_IOR (0xa4, 3, struct_tee_ioctl_buf_data)), "TEE_IOC_INVOKE != _IOR (0xa4, 3, struct_tee_ioctl_buf_data)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOC_INVOKE _IOR (0xa4, 3, struct_tee_ioctl_buf_data)
+#endif
+#if defined(TEE_IOC_CANCEL) || (defined(HAVE_DECL_TEE_IOC_CANCEL) && HAVE_DECL_TEE_IOC_CANCEL)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOC_CANCEL) == (_IOR (0xa4, 4, struct_tee_ioctl_cancel_arg)), "TEE_IOC_CANCEL != _IOR (0xa4, 4, struct_tee_ioctl_cancel_arg)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOC_CANCEL _IOR (0xa4, 4, struct_tee_ioctl_cancel_arg)
+#endif
+#if defined(TEE_IOC_CLOSE_SESSION) || (defined(HAVE_DECL_TEE_IOC_CLOSE_SESSION) && HAVE_DECL_TEE_IOC_CLOSE_SESSION)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOC_CLOSE_SESSION) == (_IOR (0xa4, 5, struct_tee_ioctl_close_session_arg)), "TEE_IOC_CLOSE_SESSION != _IOR (0xa4, 5, struct_tee_ioctl_close_session_arg)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOC_CLOSE_SESSION _IOR (0xa4, 5, struct_tee_ioctl_close_session_arg)
+#endif
+#if defined(TEE_IOC_SUPPL_RECV) || (defined(HAVE_DECL_TEE_IOC_SUPPL_RECV) && HAVE_DECL_TEE_IOC_SUPPL_RECV)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOC_SUPPL_RECV) == (_IOR (0xa4, 6, struct_tee_ioctl_buf_data)), "TEE_IOC_SUPPL_RECV != _IOR (0xa4, 6, struct_tee_ioctl_buf_data)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOC_SUPPL_RECV _IOR (0xa4, 6, struct_tee_ioctl_buf_data)
+#endif
+#if defined(TEE_IOC_SUPPL_SEND) || (defined(HAVE_DECL_TEE_IOC_SUPPL_SEND) && HAVE_DECL_TEE_IOC_SUPPL_SEND)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOC_SUPPL_SEND) == (_IOR (0xa4, 7, struct_tee_ioctl_buf_data)), "TEE_IOC_SUPPL_SEND != _IOR (0xa4, 7, struct_tee_ioctl_buf_data)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOC_SUPPL_SEND _IOR (0xa4, 7, struct_tee_ioctl_buf_data)
+#endif
+#if defined(TEE_IOC_SHM_REGISTER_FD) || (defined(HAVE_DECL_TEE_IOC_SHM_REGISTER_FD) && HAVE_DECL_TEE_IOC_SHM_REGISTER_FD)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOC_SHM_REGISTER_FD) == (_IOWR(0xa4, 8, struct_tee_ioctl_shm_register_fd_data)), "TEE_IOC_SHM_REGISTER_FD != _IOWR(0xa4, 8, struct_tee_ioctl_shm_register_fd_data)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOC_SHM_REGISTER_FD _IOWR(0xa4, 8, struct_tee_ioctl_shm_register_fd_data)
+#endif
+#if defined(TEE_IOC_SHM_REGISTER) || (defined(HAVE_DECL_TEE_IOC_SHM_REGISTER) && HAVE_DECL_TEE_IOC_SHM_REGISTER)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOC_SHM_REGISTER) == (_IOWR(0xa4, 9, struct_tee_ioctl_shm_register_data)), "TEE_IOC_SHM_REGISTER != _IOWR(0xa4, 9, struct_tee_ioctl_shm_register_data)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOC_SHM_REGISTER _IOWR(0xa4, 9, struct_tee_ioctl_shm_register_data)
+#endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+#  error static const struct xlat tee_ioctl_cmds in mpers mode
+
+# else
+
+static const struct xlat_data tee_ioctl_cmds_xdata[] = {
+ XLAT(TEE_IOC_VERSION),
+ #define XLAT_VAL_0 ((unsigned) (TEE_IOC_VERSION))
+ #define XLAT_STR_0 STRINGIFY(TEE_IOC_VERSION)
+ XLAT(TEE_IOC_SHM_ALLOC),
+ #define XLAT_VAL_1 ((unsigned) (TEE_IOC_SHM_ALLOC))
+ #define XLAT_STR_1 STRINGIFY(TEE_IOC_SHM_ALLOC)
+ XLAT(TEE_IOC_OPEN_SESSION),
+ #define XLAT_VAL_2 ((unsigned) (TEE_IOC_OPEN_SESSION))
+ #define XLAT_STR_2 STRINGIFY(TEE_IOC_OPEN_SESSION)
+ XLAT(TEE_IOC_INVOKE),
+ #define XLAT_VAL_3 ((unsigned) (TEE_IOC_INVOKE))
+ #define XLAT_STR_3 STRINGIFY(TEE_IOC_INVOKE)
+ XLAT(TEE_IOC_CANCEL),
+ #define XLAT_VAL_4 ((unsigned) (TEE_IOC_CANCEL))
+ #define XLAT_STR_4 STRINGIFY(TEE_IOC_CANCEL)
+ XLAT(TEE_IOC_CLOSE_SESSION),
+ #define XLAT_VAL_5 ((unsigned) (TEE_IOC_CLOSE_SESSION))
+ #define XLAT_STR_5 STRINGIFY(TEE_IOC_CLOSE_SESSION)
+ XLAT(TEE_IOC_SUPPL_RECV),
+ #define XLAT_VAL_6 ((unsigned) (TEE_IOC_SUPPL_RECV))
+ #define XLAT_STR_6 STRINGIFY(TEE_IOC_SUPPL_RECV)
+ XLAT(TEE_IOC_SUPPL_SEND),
+ #define XLAT_VAL_7 ((unsigned) (TEE_IOC_SUPPL_SEND))
+ #define XLAT_STR_7 STRINGIFY(TEE_IOC_SUPPL_SEND)
+ XLAT(TEE_IOC_SHM_REGISTER_FD),
+ #define XLAT_VAL_8 ((unsigned) (TEE_IOC_SHM_REGISTER_FD))
+ #define XLAT_STR_8 STRINGIFY(TEE_IOC_SHM_REGISTER_FD)
+ XLAT(TEE_IOC_SHM_REGISTER),
+ #define XLAT_VAL_9 ((unsigned) (TEE_IOC_SHM_REGISTER))
+ #define XLAT_STR_9 STRINGIFY(TEE_IOC_SHM_REGISTER)
+};
+static
+const struct xlat tee_ioctl_cmds[1] = { {
+ .data = tee_ioctl_cmds_xdata,
+ .size = ARRAY_SIZE(tee_ioctl_cmds_xdata),
+ .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+  ,
+} };
+
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+# endif /* !IN_MPERS */
+
+#endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/tee_ioctl_cmds.in 5.9-0ubuntu2/xlat/tee_ioctl_cmds.in
--- 5.5-3/xlat/tee_ioctl_cmds.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/tee_ioctl_cmds.in	2020-09-23 16:28:11.000000000 +0000
@@ -0,0 +1,10 @@
+TEE_IOC_VERSION		_IOR (0xa4, 0, struct_tee_ioctl_version_data)
+TEE_IOC_SHM_ALLOC	_IOWR(0xa4, 1, struct_tee_ioctl_shm_alloc_data)
+TEE_IOC_OPEN_SESSION	_IOR (0xa4, 2, struct_tee_ioctl_buf_data)
+TEE_IOC_INVOKE		_IOR (0xa4, 3, struct_tee_ioctl_buf_data)
+TEE_IOC_CANCEL		_IOR (0xa4, 4, struct_tee_ioctl_cancel_arg)
+TEE_IOC_CLOSE_SESSION	_IOR (0xa4, 5, struct_tee_ioctl_close_session_arg)
+TEE_IOC_SUPPL_RECV	_IOR (0xa4, 6, struct_tee_ioctl_buf_data)
+TEE_IOC_SUPPL_SEND	_IOR (0xa4, 7, struct_tee_ioctl_buf_data)
+TEE_IOC_SHM_REGISTER_FD	_IOWR(0xa4, 8, struct_tee_ioctl_shm_register_fd_data) /* Not in mainline */
+TEE_IOC_SHM_REGISTER	_IOWR(0xa4, 9, struct_tee_ioctl_shm_register_data)
diff -pruN 5.5-3/xlat/tee_ioctl_gen_caps.h 5.9-0ubuntu2/xlat/tee_ioctl_gen_caps.h
--- 5.5-3/xlat/tee_ioctl_gen_caps.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/tee_ioctl_gen_caps.h	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,102 @@
+/* Generated by ./xlat/gen.sh from ./xlat/tee_ioctl_gen_caps.in; do not edit. */
+
+#include "gcc_compat.h"
+#include "static_assert.h"
+
+#if defined(TEE_GEN_CAP_GP) || (defined(HAVE_DECL_TEE_GEN_CAP_GP) && HAVE_DECL_TEE_GEN_CAP_GP)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_GEN_CAP_GP) == ((1 << 0)), "TEE_GEN_CAP_GP != (1 << 0)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_GEN_CAP_GP (1 << 0)
+#endif
+#if defined(TEE_GEN_CAP_PRIVILEGED) || (defined(HAVE_DECL_TEE_GEN_CAP_PRIVILEGED) && HAVE_DECL_TEE_GEN_CAP_PRIVILEGED)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_GEN_CAP_PRIVILEGED) == ((1 << 1)), "TEE_GEN_CAP_PRIVILEGED != (1 << 1)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_GEN_CAP_PRIVILEGED (1 << 1)
+#endif
+#if defined(TEE_GEN_CAP_REG_MEM) || (defined(HAVE_DECL_TEE_GEN_CAP_REG_MEM) && HAVE_DECL_TEE_GEN_CAP_REG_MEM)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_GEN_CAP_REG_MEM) == ((1 << 2)), "TEE_GEN_CAP_REG_MEM != (1 << 2)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_GEN_CAP_REG_MEM (1 << 2)
+#endif
+#if defined(TEE_GEN_CAP_MEMREF_NULL) || (defined(HAVE_DECL_TEE_GEN_CAP_MEMREF_NULL) && HAVE_DECL_TEE_GEN_CAP_MEMREF_NULL)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_GEN_CAP_MEMREF_NULL) == ((1 << 3)), "TEE_GEN_CAP_MEMREF_NULL != (1 << 3)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_GEN_CAP_MEMREF_NULL (1 << 3)
+#endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+#  error static const struct xlat tee_ioctl_gen_caps in mpers mode
+
+# else
+
+static const struct xlat_data tee_ioctl_gen_caps_xdata[] = {
+ XLAT(TEE_GEN_CAP_GP),
+ #define XLAT_VAL_0 ((unsigned) (TEE_GEN_CAP_GP))
+ #define XLAT_STR_0 STRINGIFY(TEE_GEN_CAP_GP)
+ XLAT(TEE_GEN_CAP_PRIVILEGED),
+ #define XLAT_VAL_1 ((unsigned) (TEE_GEN_CAP_PRIVILEGED))
+ #define XLAT_STR_1 STRINGIFY(TEE_GEN_CAP_PRIVILEGED)
+ XLAT(TEE_GEN_CAP_REG_MEM),
+ #define XLAT_VAL_2 ((unsigned) (TEE_GEN_CAP_REG_MEM))
+ #define XLAT_STR_2 STRINGIFY(TEE_GEN_CAP_REG_MEM)
+ XLAT(TEE_GEN_CAP_MEMREF_NULL),
+ #define XLAT_VAL_3 ((unsigned) (TEE_GEN_CAP_MEMREF_NULL))
+ #define XLAT_STR_3 STRINGIFY(TEE_GEN_CAP_MEMREF_NULL)
+};
+static
+const struct xlat tee_ioctl_gen_caps[1] = { {
+ .data = tee_ioctl_gen_caps_xdata,
+ .size = ARRAY_SIZE(tee_ioctl_gen_caps_xdata),
+ .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
+} };
+
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+# endif /* !IN_MPERS */
+
+#endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/tee_ioctl_gen_caps.in 5.9-0ubuntu2/xlat/tee_ioctl_gen_caps.in
--- 5.5-3/xlat/tee_ioctl_gen_caps.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/tee_ioctl_gen_caps.in	2020-09-23 12:56:26.000000000 +0000
@@ -0,0 +1,4 @@
+TEE_GEN_CAP_GP		(1 << 0)
+TEE_GEN_CAP_PRIVILEGED	(1 << 1)
+TEE_GEN_CAP_REG_MEM	(1 << 2)
+TEE_GEN_CAP_MEMREF_NULL	(1 << 3)
diff -pruN 5.5-3/xlat/tee_ioctl_impl_ids.h 5.9-0ubuntu2/xlat/tee_ioctl_impl_ids.h
--- 5.5-3/xlat/tee_ioctl_impl_ids.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/tee_ioctl_impl_ids.h	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,66 @@
+/* Generated by ./xlat/gen.sh from ./xlat/tee_ioctl_impl_ids.in; do not edit. */
+
+#include "gcc_compat.h"
+#include "static_assert.h"
+
+#if defined(TEE_IMPL_ID_OPTEE) || (defined(HAVE_DECL_TEE_IMPL_ID_OPTEE) && HAVE_DECL_TEE_IMPL_ID_OPTEE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IMPL_ID_OPTEE) == (1), "TEE_IMPL_ID_OPTEE != 1");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IMPL_ID_OPTEE 1
+#endif
+#if defined(TEE_IMPL_ID_AMDTEE) || (defined(HAVE_DECL_TEE_IMPL_ID_AMDTEE) && HAVE_DECL_TEE_IMPL_ID_AMDTEE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IMPL_ID_AMDTEE) == (2), "TEE_IMPL_ID_AMDTEE != 2");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IMPL_ID_AMDTEE 2
+#endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+#  error static const struct xlat tee_ioctl_impl_ids in mpers mode
+
+# else
+
+static const struct xlat_data tee_ioctl_impl_ids_xdata[] = {
+ XLAT(TEE_IMPL_ID_OPTEE),
+ #define XLAT_VAL_0 ((unsigned) (TEE_IMPL_ID_OPTEE))
+ #define XLAT_STR_0 STRINGIFY(TEE_IMPL_ID_OPTEE)
+ XLAT(TEE_IMPL_ID_AMDTEE),
+ #define XLAT_VAL_1 ((unsigned) (TEE_IMPL_ID_AMDTEE))
+ #define XLAT_STR_1 STRINGIFY(TEE_IMPL_ID_AMDTEE)
+};
+static
+const struct xlat tee_ioctl_impl_ids[1] = { {
+ .data = tee_ioctl_impl_ids_xdata,
+ .size = ARRAY_SIZE(tee_ioctl_impl_ids_xdata),
+ .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
+} };
+
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+# endif /* !IN_MPERS */
+
+#endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/tee_ioctl_impl_ids.in 5.9-0ubuntu2/xlat/tee_ioctl_impl_ids.in
--- 5.5-3/xlat/tee_ioctl_impl_ids.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/tee_ioctl_impl_ids.in	2020-09-23 12:56:26.000000000 +0000
@@ -0,0 +1,2 @@
+TEE_IMPL_ID_OPTEE	1
+TEE_IMPL_ID_AMDTEE	2
diff -pruN 5.5-3/xlat/tee_ioctl_login_types.h 5.9-0ubuntu2/xlat/tee_ioctl_login_types.h
--- 5.5-3/xlat/tee_ioctl_login_types.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/tee_ioctl_login_types.h	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,138 @@
+/* Generated by ./xlat/gen.sh from ./xlat/tee_ioctl_login_types.in; do not edit. */
+
+#include "gcc_compat.h"
+#include "static_assert.h"
+
+#if defined(TEE_IOCTL_LOGIN_PUBLIC) || (defined(HAVE_DECL_TEE_IOCTL_LOGIN_PUBLIC) && HAVE_DECL_TEE_IOCTL_LOGIN_PUBLIC)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOCTL_LOGIN_PUBLIC) == (0), "TEE_IOCTL_LOGIN_PUBLIC != 0");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOCTL_LOGIN_PUBLIC 0
+#endif
+#if defined(TEE_IOCTL_LOGIN_USER) || (defined(HAVE_DECL_TEE_IOCTL_LOGIN_USER) && HAVE_DECL_TEE_IOCTL_LOGIN_USER)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOCTL_LOGIN_USER) == (1), "TEE_IOCTL_LOGIN_USER != 1");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOCTL_LOGIN_USER 1
+#endif
+#if defined(TEE_IOCTL_LOGIN_GROUP) || (defined(HAVE_DECL_TEE_IOCTL_LOGIN_GROUP) && HAVE_DECL_TEE_IOCTL_LOGIN_GROUP)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOCTL_LOGIN_GROUP) == (2), "TEE_IOCTL_LOGIN_GROUP != 2");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOCTL_LOGIN_GROUP 2
+#endif
+#if defined(TEE_IOCTL_LOGIN_APPLICATION) || (defined(HAVE_DECL_TEE_IOCTL_LOGIN_APPLICATION) && HAVE_DECL_TEE_IOCTL_LOGIN_APPLICATION)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOCTL_LOGIN_APPLICATION) == (4), "TEE_IOCTL_LOGIN_APPLICATION != 4");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOCTL_LOGIN_APPLICATION 4
+#endif
+#if defined(TEE_IOCTL_LOGIN_USER_APPLICATION) || (defined(HAVE_DECL_TEE_IOCTL_LOGIN_USER_APPLICATION) && HAVE_DECL_TEE_IOCTL_LOGIN_USER_APPLICATION)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOCTL_LOGIN_USER_APPLICATION) == (5), "TEE_IOCTL_LOGIN_USER_APPLICATION != 5");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOCTL_LOGIN_USER_APPLICATION 5
+#endif
+#if defined(TEE_IOCTL_LOGIN_GROUP_APPLICATION) || (defined(HAVE_DECL_TEE_IOCTL_LOGIN_GROUP_APPLICATION) && HAVE_DECL_TEE_IOCTL_LOGIN_GROUP_APPLICATION)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOCTL_LOGIN_GROUP_APPLICATION) == (6), "TEE_IOCTL_LOGIN_GROUP_APPLICATION != 6");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOCTL_LOGIN_GROUP_APPLICATION 6
+#endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+#  error static const struct xlat tee_ioctl_login_types in mpers mode
+
+# else
+
+static const struct xlat_data tee_ioctl_login_types_xdata[] = {
+ [TEE_IOCTL_LOGIN_PUBLIC] = XLAT(TEE_IOCTL_LOGIN_PUBLIC),
+ #define XLAT_VAL_0 ((unsigned) (TEE_IOCTL_LOGIN_PUBLIC))
+ #define XLAT_STR_0 STRINGIFY(TEE_IOCTL_LOGIN_PUBLIC)
+ [TEE_IOCTL_LOGIN_USER] = XLAT(TEE_IOCTL_LOGIN_USER),
+ #define XLAT_VAL_1 ((unsigned) (TEE_IOCTL_LOGIN_USER))
+ #define XLAT_STR_1 STRINGIFY(TEE_IOCTL_LOGIN_USER)
+ [TEE_IOCTL_LOGIN_GROUP] = XLAT(TEE_IOCTL_LOGIN_GROUP),
+ #define XLAT_VAL_2 ((unsigned) (TEE_IOCTL_LOGIN_GROUP))
+ #define XLAT_STR_2 STRINGIFY(TEE_IOCTL_LOGIN_GROUP)
+ [TEE_IOCTL_LOGIN_APPLICATION] = XLAT(TEE_IOCTL_LOGIN_APPLICATION),
+ #define XLAT_VAL_3 ((unsigned) (TEE_IOCTL_LOGIN_APPLICATION))
+ #define XLAT_STR_3 STRINGIFY(TEE_IOCTL_LOGIN_APPLICATION)
+ [TEE_IOCTL_LOGIN_USER_APPLICATION] = XLAT(TEE_IOCTL_LOGIN_USER_APPLICATION),
+ #define XLAT_VAL_4 ((unsigned) (TEE_IOCTL_LOGIN_USER_APPLICATION))
+ #define XLAT_STR_4 STRINGIFY(TEE_IOCTL_LOGIN_USER_APPLICATION)
+ [TEE_IOCTL_LOGIN_GROUP_APPLICATION] = XLAT(TEE_IOCTL_LOGIN_GROUP_APPLICATION),
+ #define XLAT_VAL_5 ((unsigned) (TEE_IOCTL_LOGIN_GROUP_APPLICATION))
+ #define XLAT_STR_5 STRINGIFY(TEE_IOCTL_LOGIN_GROUP_APPLICATION)
+};
+static
+const struct xlat tee_ioctl_login_types[1] = { {
+ .data = tee_ioctl_login_types_xdata,
+ .size = ARRAY_SIZE(tee_ioctl_login_types_xdata),
+ .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
+} };
+
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+# endif /* !IN_MPERS */
+
+#endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/tee_ioctl_login_types.in 5.9-0ubuntu2/xlat/tee_ioctl_login_types.in
--- 5.5-3/xlat/tee_ioctl_login_types.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/tee_ioctl_login_types.in	2020-09-23 12:56:26.000000000 +0000
@@ -0,0 +1,7 @@
+#value_indexed
+TEE_IOCTL_LOGIN_PUBLIC			0
+TEE_IOCTL_LOGIN_USER			1
+TEE_IOCTL_LOGIN_GROUP			2
+TEE_IOCTL_LOGIN_APPLICATION		4
+TEE_IOCTL_LOGIN_USER_APPLICATION	5
+TEE_IOCTL_LOGIN_GROUP_APPLICATION	6
diff -pruN 5.5-3/xlat/tee_ioctl_max_arg_size.h 5.9-0ubuntu2/xlat/tee_ioctl_max_arg_size.h
--- 5.5-3/xlat/tee_ioctl_max_arg_size.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/tee_ioctl_max_arg_size.h	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,48 @@
+/* Generated by ./xlat/gen.sh from ./xlat/tee_ioctl_max_arg_size.in; do not edit. */
+
+#include "gcc_compat.h"
+#include "static_assert.h"
+
+#if defined(TEE_MAX_ARG_SIZE) || (defined(HAVE_DECL_TEE_MAX_ARG_SIZE) && HAVE_DECL_TEE_MAX_ARG_SIZE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_MAX_ARG_SIZE) == (1024), "TEE_MAX_ARG_SIZE != 1024");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_MAX_ARG_SIZE 1024
+#endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+#  error static const struct xlat tee_ioctl_max_arg_size in mpers mode
+
+# else
+
+static const struct xlat_data tee_ioctl_max_arg_size_xdata[] = {
+ XLAT(TEE_MAX_ARG_SIZE),
+ #define XLAT_VAL_0 ((unsigned) (TEE_MAX_ARG_SIZE))
+ #define XLAT_STR_0 STRINGIFY(TEE_MAX_ARG_SIZE)
+};
+static
+const struct xlat tee_ioctl_max_arg_size[1] = { {
+ .data = tee_ioctl_max_arg_size_xdata,
+ .size = ARRAY_SIZE(tee_ioctl_max_arg_size_xdata),
+ .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
+} };
+
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+# endif /* !IN_MPERS */
+
+#endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/tee_ioctl_max_arg_size.in 5.9-0ubuntu2/xlat/tee_ioctl_max_arg_size.in
--- 5.5-3/xlat/tee_ioctl_max_arg_size.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/tee_ioctl_max_arg_size.in	2020-09-23 12:56:26.000000000 +0000
@@ -0,0 +1 @@
+TEE_MAX_ARG_SIZE	1024
diff -pruN 5.5-3/xlat/tee_ioctl_optee_caps.h 5.9-0ubuntu2/xlat/tee_ioctl_optee_caps.h
--- 5.5-3/xlat/tee_ioctl_optee_caps.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/tee_ioctl_optee_caps.h	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,48 @@
+/* Generated by ./xlat/gen.sh from ./xlat/tee_ioctl_optee_caps.in; do not edit. */
+
+#include "gcc_compat.h"
+#include "static_assert.h"
+
+#if defined(TEE_OPTEE_CAP_TZ) || (defined(HAVE_DECL_TEE_OPTEE_CAP_TZ) && HAVE_DECL_TEE_OPTEE_CAP_TZ)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_OPTEE_CAP_TZ) == ((1 << 0)), "TEE_OPTEE_CAP_TZ != (1 << 0)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_OPTEE_CAP_TZ (1 << 0)
+#endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+#  error static const struct xlat tee_ioctl_optee_caps in mpers mode
+
+# else
+
+static const struct xlat_data tee_ioctl_optee_caps_xdata[] = {
+ XLAT(TEE_OPTEE_CAP_TZ),
+ #define XLAT_VAL_0 ((unsigned) (TEE_OPTEE_CAP_TZ))
+ #define XLAT_STR_0 STRINGIFY(TEE_OPTEE_CAP_TZ)
+};
+static
+const struct xlat tee_ioctl_optee_caps[1] = { {
+ .data = tee_ioctl_optee_caps_xdata,
+ .size = ARRAY_SIZE(tee_ioctl_optee_caps_xdata),
+ .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
+} };
+
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+# endif /* !IN_MPERS */
+
+#endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/tee_ioctl_optee_caps.in 5.9-0ubuntu2/xlat/tee_ioctl_optee_caps.in
--- 5.5-3/xlat/tee_ioctl_optee_caps.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/tee_ioctl_optee_caps.in	2020-09-23 12:56:26.000000000 +0000
@@ -0,0 +1 @@
+TEE_OPTEE_CAP_TZ	(1 << 0)
diff -pruN 5.5-3/xlat/tee_ioctl_origins.h 5.9-0ubuntu2/xlat/tee_ioctl_origins.h
--- 5.5-3/xlat/tee_ioctl_origins.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/tee_ioctl_origins.h	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,102 @@
+/* Generated by ./xlat/gen.sh from ./xlat/tee_ioctl_origins.in; do not edit. */
+
+#include "gcc_compat.h"
+#include "static_assert.h"
+
+#if defined(TEEC_ORIGIN_API) || (defined(HAVE_DECL_TEEC_ORIGIN_API) && HAVE_DECL_TEEC_ORIGIN_API)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEEC_ORIGIN_API) == (0x00000001), "TEEC_ORIGIN_API != 0x00000001");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEEC_ORIGIN_API 0x00000001
+#endif
+#if defined(TEEC_ORIGIN_COMMS) || (defined(HAVE_DECL_TEEC_ORIGIN_COMMS) && HAVE_DECL_TEEC_ORIGIN_COMMS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEEC_ORIGIN_COMMS) == (0x00000002), "TEEC_ORIGIN_COMMS != 0x00000002");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEEC_ORIGIN_COMMS 0x00000002
+#endif
+#if defined(TEEC_ORIGIN_TEE) || (defined(HAVE_DECL_TEEC_ORIGIN_TEE) && HAVE_DECL_TEEC_ORIGIN_TEE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEEC_ORIGIN_TEE) == (0x00000003), "TEEC_ORIGIN_TEE != 0x00000003");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEEC_ORIGIN_TEE 0x00000003
+#endif
+#if defined(TEEC_ORIGIN_TRUSTED_APP) || (defined(HAVE_DECL_TEEC_ORIGIN_TRUSTED_APP) && HAVE_DECL_TEEC_ORIGIN_TRUSTED_APP)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEEC_ORIGIN_TRUSTED_APP) == (0x00000004), "TEEC_ORIGIN_TRUSTED_APP != 0x00000004");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEEC_ORIGIN_TRUSTED_APP 0x00000004
+#endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+#  error static const struct xlat tee_ioctl_origins in mpers mode
+
+# else
+
+static const struct xlat_data tee_ioctl_origins_xdata[] = {
+ XLAT(TEEC_ORIGIN_API),
+ #define XLAT_VAL_0 ((unsigned) (TEEC_ORIGIN_API))
+ #define XLAT_STR_0 STRINGIFY(TEEC_ORIGIN_API)
+ XLAT(TEEC_ORIGIN_COMMS),
+ #define XLAT_VAL_1 ((unsigned) (TEEC_ORIGIN_COMMS))
+ #define XLAT_STR_1 STRINGIFY(TEEC_ORIGIN_COMMS)
+ XLAT(TEEC_ORIGIN_TEE),
+ #define XLAT_VAL_2 ((unsigned) (TEEC_ORIGIN_TEE))
+ #define XLAT_STR_2 STRINGIFY(TEEC_ORIGIN_TEE)
+ XLAT(TEEC_ORIGIN_TRUSTED_APP),
+ #define XLAT_VAL_3 ((unsigned) (TEEC_ORIGIN_TRUSTED_APP))
+ #define XLAT_STR_3 STRINGIFY(TEEC_ORIGIN_TRUSTED_APP)
+};
+static
+const struct xlat tee_ioctl_origins[1] = { {
+ .data = tee_ioctl_origins_xdata,
+ .size = ARRAY_SIZE(tee_ioctl_origins_xdata),
+ .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
+} };
+
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+# endif /* !IN_MPERS */
+
+#endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/tee_ioctl_origins.in 5.9-0ubuntu2/xlat/tee_ioctl_origins.in
--- 5.5-3/xlat/tee_ioctl_origins.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/tee_ioctl_origins.in	2020-09-23 12:56:26.000000000 +0000
@@ -0,0 +1,4 @@
+TEEC_ORIGIN_API		0x00000001
+TEEC_ORIGIN_COMMS	0x00000002
+TEEC_ORIGIN_TEE		0x00000003
+TEEC_ORIGIN_TRUSTED_APP	0x00000004
diff -pruN 5.5-3/xlat/tee_ioctl_param_attr_types.h 5.9-0ubuntu2/xlat/tee_ioctl_param_attr_types.h
--- 5.5-3/xlat/tee_ioctl_param_attr_types.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/tee_ioctl_param_attr_types.h	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,174 @@
+/* Generated by ./xlat/gen.sh from ./xlat/tee_ioctl_param_attr_types.in; do not edit. */
+
+#include "gcc_compat.h"
+#include "static_assert.h"
+
+#if defined(TEE_IOCTL_PARAM_ATTR_TYPE_NONE) || (defined(HAVE_DECL_TEE_IOCTL_PARAM_ATTR_TYPE_NONE) && HAVE_DECL_TEE_IOCTL_PARAM_ATTR_TYPE_NONE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOCTL_PARAM_ATTR_TYPE_NONE) == (0), "TEE_IOCTL_PARAM_ATTR_TYPE_NONE != 0");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOCTL_PARAM_ATTR_TYPE_NONE 0
+#endif
+#if defined(TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INPUT) || (defined(HAVE_DECL_TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INPUT) && HAVE_DECL_TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INPUT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INPUT) == (1), "TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INPUT != 1");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INPUT 1
+#endif
+#if defined(TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_OUTPUT) || (defined(HAVE_DECL_TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_OUTPUT) && HAVE_DECL_TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_OUTPUT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_OUTPUT) == (2), "TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_OUTPUT != 2");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_OUTPUT 2
+#endif
+#if defined(TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INOUT) || (defined(HAVE_DECL_TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INOUT) && HAVE_DECL_TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INOUT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INOUT) == (3), "TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INOUT != 3");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INOUT 3
+#endif
+#if defined(TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INPUT) || (defined(HAVE_DECL_TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INPUT) && HAVE_DECL_TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INPUT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INPUT) == (5), "TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INPUT != 5");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INPUT 5
+#endif
+#if defined(TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_OUTPUT) || (defined(HAVE_DECL_TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_OUTPUT) && HAVE_DECL_TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_OUTPUT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_OUTPUT) == (6), "TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_OUTPUT != 6");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_OUTPUT 6
+#endif
+#if defined(TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INOUT) || (defined(HAVE_DECL_TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INOUT) && HAVE_DECL_TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INOUT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INOUT) == (7), "TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INOUT != 7");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INOUT 7
+#endif
+#if defined(TEE_IOCTL_PARAM_ATTR_META) || (defined(HAVE_DECL_TEE_IOCTL_PARAM_ATTR_META) && HAVE_DECL_TEE_IOCTL_PARAM_ATTR_META)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOCTL_PARAM_ATTR_META) == (0x100), "TEE_IOCTL_PARAM_ATTR_META != 0x100");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOCTL_PARAM_ATTR_META 0x100
+#endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+#  error static const struct xlat tee_ioctl_param_attr_types in mpers mode
+
+# else
+
+static const struct xlat_data tee_ioctl_param_attr_types_xdata[] = {
+ XLAT(TEE_IOCTL_PARAM_ATTR_TYPE_NONE),
+ #define XLAT_VAL_0 ((unsigned) (TEE_IOCTL_PARAM_ATTR_TYPE_NONE))
+ #define XLAT_STR_0 STRINGIFY(TEE_IOCTL_PARAM_ATTR_TYPE_NONE)
+ XLAT(TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INPUT),
+ #define XLAT_VAL_1 ((unsigned) (TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INPUT))
+ #define XLAT_STR_1 STRINGIFY(TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INPUT)
+ XLAT(TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_OUTPUT),
+ #define XLAT_VAL_2 ((unsigned) (TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_OUTPUT))
+ #define XLAT_STR_2 STRINGIFY(TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_OUTPUT)
+ XLAT(TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INOUT),
+ #define XLAT_VAL_3 ((unsigned) (TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INOUT))
+ #define XLAT_STR_3 STRINGIFY(TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INOUT)
+ XLAT(TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INPUT),
+ #define XLAT_VAL_4 ((unsigned) (TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INPUT))
+ #define XLAT_STR_4 STRINGIFY(TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INPUT)
+ XLAT(TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_OUTPUT),
+ #define XLAT_VAL_5 ((unsigned) (TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_OUTPUT))
+ #define XLAT_STR_5 STRINGIFY(TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_OUTPUT)
+ XLAT(TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INOUT),
+ #define XLAT_VAL_6 ((unsigned) (TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INOUT))
+ #define XLAT_STR_6 STRINGIFY(TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INOUT)
+ XLAT(TEE_IOCTL_PARAM_ATTR_META),
+ #define XLAT_VAL_7 ((unsigned) (TEE_IOCTL_PARAM_ATTR_META))
+ #define XLAT_STR_7 STRINGIFY(TEE_IOCTL_PARAM_ATTR_META)
+};
+static
+const struct xlat tee_ioctl_param_attr_types[1] = { {
+ .data = tee_ioctl_param_attr_types_xdata,
+ .size = ARRAY_SIZE(tee_ioctl_param_attr_types_xdata),
+ .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
+} };
+
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+# endif /* !IN_MPERS */
+
+#endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/tee_ioctl_param_attr_types.in 5.9-0ubuntu2/xlat/tee_ioctl_param_attr_types.in
--- 5.5-3/xlat/tee_ioctl_param_attr_types.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/tee_ioctl_param_attr_types.in	2020-09-23 12:56:26.000000000 +0000
@@ -0,0 +1,8 @@
+TEE_IOCTL_PARAM_ATTR_TYPE_NONE		0
+TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INPUT	1
+TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_OUTPUT	2
+TEE_IOCTL_PARAM_ATTR_TYPE_VALUE_INOUT	3
+TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INPUT	5
+TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_OUTPUT	6
+TEE_IOCTL_PARAM_ATTR_TYPE_MEMREF_INOUT	7
+TEE_IOCTL_PARAM_ATTR_META		0x100
diff -pruN 5.5-3/xlat/tee_ioctl_shm_flags.h 5.9-0ubuntu2/xlat/tee_ioctl_shm_flags.h
--- 5.5-3/xlat/tee_ioctl_shm_flags.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/tee_ioctl_shm_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,157 @@
+/* Generated by ./xlat/gen.sh from ./xlat/tee_ioctl_shm_flags.in; do not edit. */
+
+#include "gcc_compat.h"
+#include "static_assert.h"
+
+#if defined(TEE_IOCTL_SHM_MAPPED) || (defined(HAVE_DECL_TEE_IOCTL_SHM_MAPPED) && HAVE_DECL_TEE_IOCTL_SHM_MAPPED)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOCTL_SHM_MAPPED) == (0x1), "TEE_IOCTL_SHM_MAPPED != 0x1");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOCTL_SHM_MAPPED 0x1
+#endif
+#if defined(TEE_IOCTL_SHM_DMA_BUF) || (defined(HAVE_DECL_TEE_IOCTL_SHM_DMA_BUF) && HAVE_DECL_TEE_IOCTL_SHM_DMA_BUF)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOCTL_SHM_DMA_BUF) == (0x2), "TEE_IOCTL_SHM_DMA_BUF != 0x2");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOCTL_SHM_DMA_BUF 0x2
+#endif
+#if defined(TEE_IOCTL_SHM_EXT_DMA_BUF) || (defined(HAVE_DECL_TEE_IOCTL_SHM_EXT_DMA_BUF) && HAVE_DECL_TEE_IOCTL_SHM_EXT_DMA_BUF)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOCTL_SHM_EXT_DMA_BUF) == (0x4), "TEE_IOCTL_SHM_EXT_DMA_BUF != 0x4");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOCTL_SHM_EXT_DMA_BUF 0x4
+#endif
+#if defined(TEE_IOCTL_SHM_REGISTER) || (defined(HAVE_DECL_TEE_IOCTL_SHM_REGISTER) && HAVE_DECL_TEE_IOCTL_SHM_REGISTER)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOCTL_SHM_REGISTER) == (0x8), "TEE_IOCTL_SHM_REGISTER != 0x8");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOCTL_SHM_REGISTER 0x8
+#endif
+#if defined(TEE_IOCTL_SHM_USER_MAPPED) || (defined(HAVE_DECL_TEE_IOCTL_SHM_USER_MAPPED) && HAVE_DECL_TEE_IOCTL_SHM_USER_MAPPED)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOCTL_SHM_USER_MAPPED) == (0x10), "TEE_IOCTL_SHM_USER_MAPPED != 0x10");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOCTL_SHM_USER_MAPPED 0x10
+#endif
+#if defined(TEE_IOCTL_SHM_POOL) || (defined(HAVE_DECL_TEE_IOCTL_SHM_POOL) && HAVE_DECL_TEE_IOCTL_SHM_POOL)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOCTL_SHM_POOL) == (0x20), "TEE_IOCTL_SHM_POOL != 0x20");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOCTL_SHM_POOL 0x20
+#endif
+#if defined(TEE_IOCTL_SHM_KERNEL_MAPPED) || (defined(HAVE_DECL_TEE_IOCTL_SHM_KERNEL_MAPPED) && HAVE_DECL_TEE_IOCTL_SHM_KERNEL_MAPPED)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((TEE_IOCTL_SHM_KERNEL_MAPPED) == (0x40), "TEE_IOCTL_SHM_KERNEL_MAPPED != 0x40");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define TEE_IOCTL_SHM_KERNEL_MAPPED 0x40
+#endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+#  error static const struct xlat tee_ioctl_shm_flags in mpers mode
+
+# else
+
+static const struct xlat_data tee_ioctl_shm_flags_xdata[] = {
+ XLAT(TEE_IOCTL_SHM_MAPPED),
+ #define XLAT_VAL_0 ((unsigned) (TEE_IOCTL_SHM_MAPPED))
+ #define XLAT_STR_0 STRINGIFY(TEE_IOCTL_SHM_MAPPED)
+ XLAT(TEE_IOCTL_SHM_DMA_BUF),
+ #define XLAT_VAL_1 ((unsigned) (TEE_IOCTL_SHM_DMA_BUF))
+ #define XLAT_STR_1 STRINGIFY(TEE_IOCTL_SHM_DMA_BUF)
+
+ XLAT(TEE_IOCTL_SHM_EXT_DMA_BUF),
+ #define XLAT_VAL_2 ((unsigned) (TEE_IOCTL_SHM_EXT_DMA_BUF))
+ #define XLAT_STR_2 STRINGIFY(TEE_IOCTL_SHM_EXT_DMA_BUF)
+ XLAT(TEE_IOCTL_SHM_REGISTER),
+ #define XLAT_VAL_3 ((unsigned) (TEE_IOCTL_SHM_REGISTER))
+ #define XLAT_STR_3 STRINGIFY(TEE_IOCTL_SHM_REGISTER)
+ XLAT(TEE_IOCTL_SHM_USER_MAPPED),
+ #define XLAT_VAL_4 ((unsigned) (TEE_IOCTL_SHM_USER_MAPPED))
+ #define XLAT_STR_4 STRINGIFY(TEE_IOCTL_SHM_USER_MAPPED)
+ XLAT(TEE_IOCTL_SHM_POOL),
+ #define XLAT_VAL_5 ((unsigned) (TEE_IOCTL_SHM_POOL))
+ #define XLAT_STR_5 STRINGIFY(TEE_IOCTL_SHM_POOL)
+ XLAT(TEE_IOCTL_SHM_KERNEL_MAPPED),
+ #define XLAT_VAL_6 ((unsigned) (TEE_IOCTL_SHM_KERNEL_MAPPED))
+ #define XLAT_STR_6 STRINGIFY(TEE_IOCTL_SHM_KERNEL_MAPPED)
+};
+static
+const struct xlat tee_ioctl_shm_flags[1] = { {
+ .data = tee_ioctl_shm_flags_xdata,
+ .size = ARRAY_SIZE(tee_ioctl_shm_flags_xdata),
+ .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+  ,
+} };
+
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+# endif /* !IN_MPERS */
+
+#endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/tee_ioctl_shm_flags.in 5.9-0ubuntu2/xlat/tee_ioctl_shm_flags.in
--- 5.5-3/xlat/tee_ioctl_shm_flags.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/tee_ioctl_shm_flags.in	2020-09-23 12:56:26.000000000 +0000
@@ -0,0 +1,8 @@
+TEE_IOCTL_SHM_MAPPED		0x1
+TEE_IOCTL_SHM_DMA_BUF		0x2
+/* These ones aren't in uapi */
+TEE_IOCTL_SHM_EXT_DMA_BUF	0x4
+TEE_IOCTL_SHM_REGISTER		0x8
+TEE_IOCTL_SHM_USER_MAPPED	0x10
+TEE_IOCTL_SHM_POOL		0x20
+TEE_IOCTL_SHM_KERNEL_MAPPED	0x40
diff -pruN 5.5-3/xlat/timerfdflags.h 5.9-0ubuntu2/xlat/timerfdflags.h
--- 5.5-3/xlat/timerfdflags.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/timerfdflags.h	2020-09-24 09:18:46.000000000 +0000
@@ -46,19 +46,63 @@ static const struct xlat_data timerfdfla
 
 
  XLAT(TFD_TIMER_ABSTIME),
+ #define XLAT_VAL_0 ((unsigned) (TFD_TIMER_ABSTIME))
+ #define XLAT_STR_0 STRINGIFY(TFD_TIMER_ABSTIME)
  XLAT(TFD_TIMER_CANCEL_ON_SET),
+ #define XLAT_VAL_1 ((unsigned) (TFD_TIMER_CANCEL_ON_SET))
+ #define XLAT_STR_1 STRINGIFY(TFD_TIMER_CANCEL_ON_SET)
 #if defined TFD_CLOEXEC || defined O_CLOEXEC
  XLAT(TFD_CLOEXEC),
+ #define XLAT_VAL_2 ((unsigned) (TFD_CLOEXEC))
+ #define XLAT_STR_2 STRINGIFY(TFD_CLOEXEC)
 #endif
  XLAT(TFD_NONBLOCK),
+ #define XLAT_VAL_3 ((unsigned) (TFD_NONBLOCK))
+ #define XLAT_STR_3 STRINGIFY(TFD_NONBLOCK)
 };
 static
 const struct xlat timerfdflags[1] = { {
  .data = timerfdflags_xdata,
  .size = ARRAY_SIZE(timerfdflags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/tun_device_types.h 5.9-0ubuntu2/xlat/tun_device_types.h
--- 5.5-3/xlat/tun_device_types.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/tun_device_types.h	2020-09-24 09:18:46.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data tun_device_types_xdata[] = {
  [IFF_TUN] = XLAT(IFF_TUN),
+ #define XLAT_VAL_0 ((unsigned) (IFF_TUN))
+ #define XLAT_STR_0 STRINGIFY(IFF_TUN)
  [IFF_TAP] = XLAT(IFF_TAP),
+ #define XLAT_VAL_1 ((unsigned) (IFF_TAP))
+ #define XLAT_STR_1 STRINGIFY(IFF_TAP)
 };
 static
 const struct xlat tun_device_types[1] = { {
  .data = tun_device_types_xdata,
  .size = ARRAY_SIZE(tun_device_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ubi_volume_props.h 5.9-0ubuntu2/xlat/ubi_volume_props.h
--- 5.5-3/xlat/ubi_volume_props.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ubi_volume_props.h	2020-09-24 09:18:46.000000000 +0000
@@ -14,14 +14,28 @@
 
 static const struct xlat_data ubi_volume_props_xdata[] = {
  XLAT(UBI_VOL_PROP_DIRECT_WRITE),
+ #define XLAT_VAL_0 ((unsigned) (UBI_VOL_PROP_DIRECT_WRITE))
+ #define XLAT_STR_0 STRINGIFY(UBI_VOL_PROP_DIRECT_WRITE)
 };
 static
 const struct xlat ubi_volume_props[1] = { {
  .data = ubi_volume_props_xdata,
  .size = ARRAY_SIZE(ubi_volume_props_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/ubi_volume_types.h 5.9-0ubuntu2/xlat/ubi_volume_types.h
--- 5.5-3/xlat/ubi_volume_types.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/ubi_volume_types.h	2020-09-24 09:18:46.000000000 +0000
@@ -14,15 +14,39 @@
 
 static const struct xlat_data ubi_volume_types_xdata[] = {
  XLAT(UBI_DYNAMIC_VOLUME),
+ #define XLAT_VAL_0 ((unsigned) (UBI_DYNAMIC_VOLUME))
+ #define XLAT_STR_0 STRINGIFY(UBI_DYNAMIC_VOLUME)
  XLAT(UBI_STATIC_VOLUME),
+ #define XLAT_VAL_1 ((unsigned) (UBI_STATIC_VOLUME))
+ #define XLAT_STR_1 STRINGIFY(UBI_STATIC_VOLUME)
 };
 static
 const struct xlat ubi_volume_types[1] = { {
  .data = ubi_volume_types_xdata,
  .size = ARRAY_SIZE(ubi_volume_types_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/uffd_api_features.h 5.9-0ubuntu2/xlat/uffd_api_features.h
--- 5.5-3/xlat/uffd_api_features.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/uffd_api_features.h	2020-09-24 09:18:46.000000000 +0000
@@ -77,22 +77,116 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data uffd_api_features_xdata[] = {
  XLAT_TYPE(uint64_t, UFFD_FEATURE_PAGEFAULT_FLAG_WP),
+ #define XLAT_VAL_0 ((uint64_t) (UFFD_FEATURE_PAGEFAULT_FLAG_WP))
+ #define XLAT_STR_0 STRINGIFY(UFFD_FEATURE_PAGEFAULT_FLAG_WP)
  XLAT_TYPE(uint64_t, UFFD_FEATURE_EVENT_FORK),
+ #define XLAT_VAL_1 ((uint64_t) (UFFD_FEATURE_EVENT_FORK))
+ #define XLAT_STR_1 STRINGIFY(UFFD_FEATURE_EVENT_FORK)
  XLAT_TYPE(uint64_t, UFFD_FEATURE_EVENT_REMAP),
+ #define XLAT_VAL_2 ((uint64_t) (UFFD_FEATURE_EVENT_REMAP))
+ #define XLAT_STR_2 STRINGIFY(UFFD_FEATURE_EVENT_REMAP)
  XLAT_TYPE(uint64_t, UFFD_FEATURE_EVENT_REMOVE),
+ #define XLAT_VAL_3 ((uint64_t) (UFFD_FEATURE_EVENT_REMOVE))
+ #define XLAT_STR_3 STRINGIFY(UFFD_FEATURE_EVENT_REMOVE)
  XLAT_TYPE(uint64_t, UFFD_FEATURE_MISSING_HUGETLBFS),
+ #define XLAT_VAL_4 ((uint64_t) (UFFD_FEATURE_MISSING_HUGETLBFS))
+ #define XLAT_STR_4 STRINGIFY(UFFD_FEATURE_MISSING_HUGETLBFS)
  XLAT_TYPE(uint64_t, UFFD_FEATURE_MISSING_SHMEM),
+ #define XLAT_VAL_5 ((uint64_t) (UFFD_FEATURE_MISSING_SHMEM))
+ #define XLAT_STR_5 STRINGIFY(UFFD_FEATURE_MISSING_SHMEM)
  XLAT_TYPE(uint64_t, UFFD_FEATURE_EVENT_UNMAP),
+ #define XLAT_VAL_6 ((uint64_t) (UFFD_FEATURE_EVENT_UNMAP))
+ #define XLAT_STR_6 STRINGIFY(UFFD_FEATURE_EVENT_UNMAP)
  XLAT_TYPE(uint64_t, UFFD_FEATURE_SIGBUS),
+ #define XLAT_VAL_7 ((uint64_t) (UFFD_FEATURE_SIGBUS))
+ #define XLAT_STR_7 STRINGIFY(UFFD_FEATURE_SIGBUS)
  XLAT_TYPE(uint64_t, UFFD_FEATURE_THREAD_ID),
+ #define XLAT_VAL_8 ((uint64_t) (UFFD_FEATURE_THREAD_ID))
+ #define XLAT_STR_8 STRINGIFY(UFFD_FEATURE_THREAD_ID)
 };
 static
 const struct xlat uffd_api_features[1] = { {
  .data = uffd_api_features_xdata,
  .size = ARRAY_SIZE(uffd_api_features_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/uffd_api_flags.h 5.9-0ubuntu2/xlat/uffd_api_flags.h
--- 5.5-3/xlat/uffd_api_flags.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/uffd_api_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -15,12 +15,18 @@
 static const struct xlat_data uffd_api_flags_xdata[] = {
 #if defined(_UFFDIO_REGISTER) || (defined(HAVE_DECL__UFFDIO_REGISTER) && HAVE_DECL__UFFDIO_REGISTER)
   XLAT_TYPE_PAIR(uint64_t, 1ULL<<_UFFDIO_REGISTER, "1<<_UFFDIO_REGISTER"),
+ #define XLAT_VAL_0 ((uint64_t) (1ULL<<_UFFDIO_REGISTER))
+ #define XLAT_STR_0 "1<<_UFFDIO_REGISTER"
 #endif
 #if defined(_UFFDIO_UNREGISTER) || (defined(HAVE_DECL__UFFDIO_UNREGISTER) && HAVE_DECL__UFFDIO_UNREGISTER)
   XLAT_TYPE_PAIR(uint64_t, 1ULL<<_UFFDIO_UNREGISTER, "1<<_UFFDIO_UNREGISTER"),
+ #define XLAT_VAL_1 ((uint64_t) (1ULL<<_UFFDIO_UNREGISTER))
+ #define XLAT_STR_1 "1<<_UFFDIO_UNREGISTER"
 #endif
 #if defined(_UFFDIO_API) || (defined(HAVE_DECL__UFFDIO_API) && HAVE_DECL__UFFDIO_API)
   XLAT_TYPE_PAIR(uint64_t, 1ULL<<_UFFDIO_API, "1<<_UFFDIO_API"),
+ #define XLAT_VAL_2 ((uint64_t) (1ULL<<_UFFDIO_API))
+ #define XLAT_STR_2 "1<<_UFFDIO_API"
 #endif
 };
 static
@@ -28,8 +34,36 @@ const struct xlat uffd_api_flags[1] = {
  .data = uffd_api_flags_xdata,
  .size = ARRAY_SIZE(uffd_api_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/uffd_copy_flags.h 5.9-0ubuntu2/xlat/uffd_copy_flags.h
--- 5.5-3/xlat/uffd_copy_flags.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/uffd_copy_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -3,6 +3,20 @@
 #include "gcc_compat.h"
 #include "static_assert.h"
 
+#if defined(UFFDIO_COPY_MODE_DONTWAKE) || (defined(HAVE_DECL_UFFDIO_COPY_MODE_DONTWAKE) && HAVE_DECL_UFFDIO_COPY_MODE_DONTWAKE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((UFFDIO_COPY_MODE_DONTWAKE) == ((1ULL<<0)), "UFFDIO_COPY_MODE_DONTWAKE != (1ULL<<0)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define UFFDIO_COPY_MODE_DONTWAKE (1ULL<<0)
+#endif
+#if defined(UFFDIO_COPY_MODE_WP) || (defined(HAVE_DECL_UFFDIO_COPY_MODE_WP) && HAVE_DECL_UFFDIO_COPY_MODE_WP)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((UFFDIO_COPY_MODE_WP) == ((1ULL<<1)), "UFFDIO_COPY_MODE_WP != (1ULL<<1)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define UFFDIO_COPY_MODE_WP (1ULL<<1)
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -13,17 +27,40 @@
 # else
 
 static const struct xlat_data uffd_copy_flags_xdata[] = {
-#if defined(UFFDIO_COPY_MODE_DONTWAKE) || (defined(HAVE_DECL_UFFDIO_COPY_MODE_DONTWAKE) && HAVE_DECL_UFFDIO_COPY_MODE_DONTWAKE)
-  XLAT_TYPE(uint64_t, UFFDIO_COPY_MODE_DONTWAKE),
-#endif
+ XLAT_TYPE(uint64_t, UFFDIO_COPY_MODE_DONTWAKE),
+ #define XLAT_VAL_0 ((uint64_t) (UFFDIO_COPY_MODE_DONTWAKE))
+ #define XLAT_STR_0 STRINGIFY(UFFDIO_COPY_MODE_DONTWAKE)
+ XLAT_TYPE(uint64_t, UFFDIO_COPY_MODE_WP),
+ #define XLAT_VAL_1 ((uint64_t) (UFFDIO_COPY_MODE_WP))
+ #define XLAT_STR_1 STRINGIFY(UFFDIO_COPY_MODE_WP)
 };
 static
 const struct xlat uffd_copy_flags[1] = { {
  .data = uffd_copy_flags_xdata,
  .size = ARRAY_SIZE(uffd_copy_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/uffd_copy_flags.in 5.9-0ubuntu2/xlat/uffd_copy_flags.in
--- 5.5-3/xlat/uffd_copy_flags.in	2016-05-10 10:54:54.000000000 +0000
+++ 5.9-0ubuntu2/xlat/uffd_copy_flags.in	2020-04-15 13:39:57.000000000 +0000
@@ -1,2 +1,3 @@
 #val_type uint64_t
-UFFDIO_COPY_MODE_DONTWAKE
+UFFDIO_COPY_MODE_DONTWAKE	(1ULL<<0)
+UFFDIO_COPY_MODE_WP		(1ULL<<1)
diff -pruN 5.5-3/xlat/uffd_flags.h 5.9-0ubuntu2/xlat/uffd_flags.h
--- 5.5-3/xlat/uffd_flags.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/uffd_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -15,9 +15,13 @@
 static const struct xlat_data uffd_flags_xdata[] = {
 #if defined(O_NONBLOCK) || (defined(HAVE_DECL_O_NONBLOCK) && HAVE_DECL_O_NONBLOCK)
   XLAT(O_NONBLOCK),
+ #define XLAT_VAL_0 ((unsigned) (O_NONBLOCK))
+ #define XLAT_STR_0 STRINGIFY(O_NONBLOCK)
 #endif
 #if defined(O_CLOEXEC) || (defined(HAVE_DECL_O_CLOEXEC) && HAVE_DECL_O_CLOEXEC)
   XLAT(O_CLOEXEC),
+ #define XLAT_VAL_1 ((unsigned) (O_CLOEXEC))
+ #define XLAT_STR_1 STRINGIFY(O_CLOEXEC)
 #endif
 };
 static
@@ -25,8 +29,28 @@ const struct xlat uffd_flags[1] = { {
  .data = uffd_flags_xdata,
  .size = ARRAY_SIZE(uffd_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/uffd_register_ioctl_flags.h 5.9-0ubuntu2/xlat/uffd_register_ioctl_flags.h
--- 5.5-3/xlat/uffd_register_ioctl_flags.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/uffd_register_ioctl_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -15,12 +15,23 @@
 static const struct xlat_data uffd_register_ioctl_flags_xdata[] = {
 #if defined(_UFFDIO_WAKE) || (defined(HAVE_DECL__UFFDIO_WAKE) && HAVE_DECL__UFFDIO_WAKE)
   XLAT_TYPE_PAIR(uint64_t, 1ULL<<_UFFDIO_WAKE, "1<<_UFFDIO_WAKE"),
+ #define XLAT_VAL_0 ((uint64_t) (1ULL<<_UFFDIO_WAKE))
+ #define XLAT_STR_0 "1<<_UFFDIO_WAKE"
 #endif
 #if defined(_UFFDIO_COPY) || (defined(HAVE_DECL__UFFDIO_COPY) && HAVE_DECL__UFFDIO_COPY)
   XLAT_TYPE_PAIR(uint64_t, 1ULL<<_UFFDIO_COPY, "1<<_UFFDIO_COPY"),
+ #define XLAT_VAL_1 ((uint64_t) (1ULL<<_UFFDIO_COPY))
+ #define XLAT_STR_1 "1<<_UFFDIO_COPY"
 #endif
 #if defined(_UFFDIO_ZEROPAGE) || (defined(HAVE_DECL__UFFDIO_ZEROPAGE) && HAVE_DECL__UFFDIO_ZEROPAGE)
   XLAT_TYPE_PAIR(uint64_t, 1ULL<<_UFFDIO_ZEROPAGE, "1<<_UFFDIO_ZEROPAGE"),
+ #define XLAT_VAL_2 ((uint64_t) (1ULL<<_UFFDIO_ZEROPAGE))
+ #define XLAT_STR_2 "1<<_UFFDIO_ZEROPAGE"
+#endif
+#if defined(_UFFDIO_WRITEPROTECT) || (defined(HAVE_DECL__UFFDIO_WRITEPROTECT) && HAVE_DECL__UFFDIO_WRITEPROTECT)
+  XLAT_TYPE_PAIR(uint64_t, 1ULL<<_UFFDIO_WRITEPROTECT, "1<<_UFFDIO_WRITEPROTECT"),
+ #define XLAT_VAL_3 ((uint64_t) (1ULL<<_UFFDIO_WRITEPROTECT))
+ #define XLAT_STR_3 "1<<_UFFDIO_WRITEPROTECT"
 #endif
 };
 static
@@ -28,8 +39,44 @@ const struct xlat uffd_register_ioctl_fl
  .data = uffd_register_ioctl_flags_xdata,
  .size = ARRAY_SIZE(uffd_register_ioctl_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/uffd_register_ioctl_flags.in 5.9-0ubuntu2/xlat/uffd_register_ioctl_flags.in
--- 5.5-3/xlat/uffd_register_ioctl_flags.in	2016-05-10 10:54:54.000000000 +0000
+++ 5.9-0ubuntu2/xlat/uffd_register_ioctl_flags.in	2020-05-29 08:00:00.000000000 +0000
@@ -2,3 +2,4 @@
 1<<_UFFDIO_WAKE
 1<<_UFFDIO_COPY
 1<<_UFFDIO_ZEROPAGE
+1<<_UFFDIO_WRITEPROTECT
diff -pruN 5.5-3/xlat/uffd_register_mode_flags.h 5.9-0ubuntu2/xlat/uffd_register_mode_flags.h
--- 5.5-3/xlat/uffd_register_mode_flags.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/uffd_register_mode_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -15,9 +15,13 @@
 static const struct xlat_data uffd_register_mode_flags_xdata[] = {
 #if defined(UFFDIO_REGISTER_MODE_MISSING) || (defined(HAVE_DECL_UFFDIO_REGISTER_MODE_MISSING) && HAVE_DECL_UFFDIO_REGISTER_MODE_MISSING)
   XLAT_TYPE(uint64_t, UFFDIO_REGISTER_MODE_MISSING),
+ #define XLAT_VAL_0 ((uint64_t) (UFFDIO_REGISTER_MODE_MISSING))
+ #define XLAT_STR_0 STRINGIFY(UFFDIO_REGISTER_MODE_MISSING)
 #endif
 #if defined(UFFDIO_REGISTER_MODE_WP) || (defined(HAVE_DECL_UFFDIO_REGISTER_MODE_WP) && HAVE_DECL_UFFDIO_REGISTER_MODE_WP)
   XLAT_TYPE(uint64_t, UFFDIO_REGISTER_MODE_WP),
+ #define XLAT_VAL_1 ((uint64_t) (UFFDIO_REGISTER_MODE_WP))
+ #define XLAT_STR_1 STRINGIFY(UFFDIO_REGISTER_MODE_WP)
 #endif
 };
 static
@@ -25,8 +29,28 @@ const struct xlat uffd_register_mode_fla
  .data = uffd_register_mode_flags_xdata,
  .size = ARRAY_SIZE(uffd_register_mode_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/uffd_zeropage_flags.h 5.9-0ubuntu2/xlat/uffd_zeropage_flags.h
--- 5.5-3/xlat/uffd_zeropage_flags.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/uffd_zeropage_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -15,6 +15,8 @@
 static const struct xlat_data uffd_zeropage_flags_xdata[] = {
 #if defined(UFFDIO_ZEROPAGE_MODE_DONTWAKE) || (defined(HAVE_DECL_UFFDIO_ZEROPAGE_MODE_DONTWAKE) && HAVE_DECL_UFFDIO_ZEROPAGE_MODE_DONTWAKE)
   XLAT_TYPE(uint64_t, UFFDIO_ZEROPAGE_MODE_DONTWAKE),
+ #define XLAT_VAL_0 ((uint64_t) (UFFDIO_ZEROPAGE_MODE_DONTWAKE))
+ #define XLAT_STR_0 STRINGIFY(UFFDIO_ZEROPAGE_MODE_DONTWAKE)
 #endif
 };
 static
@@ -22,8 +24,20 @@ const struct xlat uffd_zeropage_flags[1]
  .data = uffd_zeropage_flags_xdata,
  .size = ARRAY_SIZE(uffd_zeropage_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/umount_flags.h 5.9-0ubuntu2/xlat/umount_flags.h
--- 5.5-3/xlat/umount_flags.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/umount_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data umount_flags_xdata[] = {
  XLAT(MNT_FORCE),
+ #define XLAT_VAL_0 ((unsigned) (MNT_FORCE))
+ #define XLAT_STR_0 STRINGIFY(MNT_FORCE)
  XLAT(MNT_DETACH),
+ #define XLAT_VAL_1 ((unsigned) (MNT_DETACH))
+ #define XLAT_STR_1 STRINGIFY(MNT_DETACH)
  XLAT(MNT_EXPIRE),
+ #define XLAT_VAL_2 ((unsigned) (MNT_EXPIRE))
+ #define XLAT_STR_2 STRINGIFY(MNT_EXPIRE)
  XLAT(UMOUNT_NOFOLLOW),
+ #define XLAT_VAL_3 ((unsigned) (UMOUNT_NOFOLLOW))
+ #define XLAT_STR_3 STRINGIFY(UMOUNT_NOFOLLOW)
 };
 static
 const struct xlat umount_flags[1] = { {
  .data = umount_flags_xdata,
  .size = ARRAY_SIZE(umount_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/unix_diag_attrs.h 5.9-0ubuntu2/xlat/unix_diag_attrs.h
--- 5.5-3/xlat/unix_diag_attrs.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/unix_diag_attrs.h	2020-09-24 09:18:46.000000000 +0000
@@ -14,21 +14,105 @@
 
 static const struct xlat_data unix_diag_attrs_xdata[] = {
  XLAT(UNIX_DIAG_NAME),
+ #define XLAT_VAL_0 ((unsigned) (UNIX_DIAG_NAME))
+ #define XLAT_STR_0 STRINGIFY(UNIX_DIAG_NAME)
  XLAT(UNIX_DIAG_VFS),
+ #define XLAT_VAL_1 ((unsigned) (UNIX_DIAG_VFS))
+ #define XLAT_STR_1 STRINGIFY(UNIX_DIAG_VFS)
  XLAT(UNIX_DIAG_PEER),
+ #define XLAT_VAL_2 ((unsigned) (UNIX_DIAG_PEER))
+ #define XLAT_STR_2 STRINGIFY(UNIX_DIAG_PEER)
  XLAT(UNIX_DIAG_ICONS),
+ #define XLAT_VAL_3 ((unsigned) (UNIX_DIAG_ICONS))
+ #define XLAT_STR_3 STRINGIFY(UNIX_DIAG_ICONS)
  XLAT(UNIX_DIAG_RQLEN),
+ #define XLAT_VAL_4 ((unsigned) (UNIX_DIAG_RQLEN))
+ #define XLAT_STR_4 STRINGIFY(UNIX_DIAG_RQLEN)
  XLAT(UNIX_DIAG_MEMINFO),
+ #define XLAT_VAL_5 ((unsigned) (UNIX_DIAG_MEMINFO))
+ #define XLAT_STR_5 STRINGIFY(UNIX_DIAG_MEMINFO)
  XLAT(UNIX_DIAG_SHUTDOWN),
+ #define XLAT_VAL_6 ((unsigned) (UNIX_DIAG_SHUTDOWN))
+ #define XLAT_STR_6 STRINGIFY(UNIX_DIAG_SHUTDOWN)
  XLAT(UNIX_DIAG_UID),
+ #define XLAT_VAL_7 ((unsigned) (UNIX_DIAG_UID))
+ #define XLAT_STR_7 STRINGIFY(UNIX_DIAG_UID)
 };
 static
 const struct xlat unix_diag_attrs[1] = { {
  .data = unix_diag_attrs_xdata,
  .size = ARRAY_SIZE(unix_diag_attrs_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/unix_diag_show.h 5.9-0ubuntu2/xlat/unix_diag_show.h
--- 5.5-3/xlat/unix_diag_show.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/unix_diag_show.h	2020-09-24 09:18:46.000000000 +0000
@@ -15,24 +15,38 @@
 static const struct xlat_data unix_diag_show_xdata[] = {
 #if defined(UDIAG_SHOW_NAME) || (defined(HAVE_DECL_UDIAG_SHOW_NAME) && HAVE_DECL_UDIAG_SHOW_NAME)
   XLAT(UDIAG_SHOW_NAME),
+ #define XLAT_VAL_0 ((unsigned) (UDIAG_SHOW_NAME))
+ #define XLAT_STR_0 STRINGIFY(UDIAG_SHOW_NAME)
 #endif
 #if defined(UDIAG_SHOW_VFS) || (defined(HAVE_DECL_UDIAG_SHOW_VFS) && HAVE_DECL_UDIAG_SHOW_VFS)
   XLAT(UDIAG_SHOW_VFS),
+ #define XLAT_VAL_1 ((unsigned) (UDIAG_SHOW_VFS))
+ #define XLAT_STR_1 STRINGIFY(UDIAG_SHOW_VFS)
 #endif
 #if defined(UDIAG_SHOW_PEER) || (defined(HAVE_DECL_UDIAG_SHOW_PEER) && HAVE_DECL_UDIAG_SHOW_PEER)
   XLAT(UDIAG_SHOW_PEER),
+ #define XLAT_VAL_2 ((unsigned) (UDIAG_SHOW_PEER))
+ #define XLAT_STR_2 STRINGIFY(UDIAG_SHOW_PEER)
 #endif
 #if defined(UDIAG_SHOW_ICONS) || (defined(HAVE_DECL_UDIAG_SHOW_ICONS) && HAVE_DECL_UDIAG_SHOW_ICONS)
   XLAT(UDIAG_SHOW_ICONS),
+ #define XLAT_VAL_3 ((unsigned) (UDIAG_SHOW_ICONS))
+ #define XLAT_STR_3 STRINGIFY(UDIAG_SHOW_ICONS)
 #endif
 #if defined(UDIAG_SHOW_RQLEN) || (defined(HAVE_DECL_UDIAG_SHOW_RQLEN) && HAVE_DECL_UDIAG_SHOW_RQLEN)
   XLAT(UDIAG_SHOW_RQLEN),
+ #define XLAT_VAL_4 ((unsigned) (UDIAG_SHOW_RQLEN))
+ #define XLAT_STR_4 STRINGIFY(UDIAG_SHOW_RQLEN)
 #endif
 #if defined(UDIAG_SHOW_MEMINFO) || (defined(HAVE_DECL_UDIAG_SHOW_MEMINFO) && HAVE_DECL_UDIAG_SHOW_MEMINFO)
   XLAT(UDIAG_SHOW_MEMINFO),
+ #define XLAT_VAL_5 ((unsigned) (UDIAG_SHOW_MEMINFO))
+ #define XLAT_STR_5 STRINGIFY(UDIAG_SHOW_MEMINFO)
 #endif
 #if defined(UDIAG_SHOW_UID) || (defined(HAVE_DECL_UDIAG_SHOW_UID) && HAVE_DECL_UDIAG_SHOW_UID)
   XLAT(UDIAG_SHOW_UID),
+ #define XLAT_VAL_6 ((unsigned) (UDIAG_SHOW_UID))
+ #define XLAT_STR_6 STRINGIFY(UDIAG_SHOW_UID)
 #endif
 };
 static
@@ -40,8 +54,68 @@ const struct xlat unix_diag_show[1] = {
  .data = unix_diag_show_xdata,
  .size = ARRAY_SIZE(unix_diag_show_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/unshare_flags.h 5.9-0ubuntu2/xlat/unshare_flags.h
--- 5.5-3/xlat/unshare_flags.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/unshare_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -3,63 +3,280 @@
 #include "gcc_compat.h"
 #include "static_assert.h"
 
-
-#ifndef XLAT_MACROS_ONLY
-
-# ifdef IN_MPERS
-
-#  error static const struct xlat unshare_flags in mpers mode
-
-# else
-
-static const struct xlat_data unshare_flags_xdata[] = {
-#if defined(CLONE_THREAD) || (defined(HAVE_DECL_CLONE_THREAD) && HAVE_DECL_CLONE_THREAD)
-  XLAT(CLONE_THREAD),
+#if defined(CLONE_NEWTIME) || (defined(HAVE_DECL_CLONE_NEWTIME) && HAVE_DECL_CLONE_NEWTIME)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((CLONE_NEWTIME) == (0x00000080), "CLONE_NEWTIME != 0x00000080");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define CLONE_NEWTIME 0x00000080
+#endif
+#if defined(CLONE_VM) || (defined(HAVE_DECL_CLONE_VM) && HAVE_DECL_CLONE_VM)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((CLONE_VM) == (0x00000100), "CLONE_VM != 0x00000100");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define CLONE_VM 0x00000100
 #endif
 #if defined(CLONE_FS) || (defined(HAVE_DECL_CLONE_FS) && HAVE_DECL_CLONE_FS)
-  XLAT(CLONE_FS),
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((CLONE_FS) == (0x00000200), "CLONE_FS != 0x00000200");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define CLONE_FS 0x00000200
 #endif
-#if defined(CLONE_NEWNS) || (defined(HAVE_DECL_CLONE_NEWNS) && HAVE_DECL_CLONE_NEWNS)
-  XLAT(CLONE_NEWNS),
+#if defined(CLONE_FILES) || (defined(HAVE_DECL_CLONE_FILES) && HAVE_DECL_CLONE_FILES)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((CLONE_FILES) == (0x00000400), "CLONE_FILES != 0x00000400");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define CLONE_FILES 0x00000400
 #endif
 #if defined(CLONE_SIGHAND) || (defined(HAVE_DECL_CLONE_SIGHAND) && HAVE_DECL_CLONE_SIGHAND)
-  XLAT(CLONE_SIGHAND),
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((CLONE_SIGHAND) == (0x00000800), "CLONE_SIGHAND != 0x00000800");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define CLONE_SIGHAND 0x00000800
 #endif
-#if defined(CLONE_VM) || (defined(HAVE_DECL_CLONE_VM) && HAVE_DECL_CLONE_VM)
-  XLAT(CLONE_VM),
+#if defined(CLONE_THREAD) || (defined(HAVE_DECL_CLONE_THREAD) && HAVE_DECL_CLONE_THREAD)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((CLONE_THREAD) == (0x00010000), "CLONE_THREAD != 0x00010000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define CLONE_THREAD 0x00010000
 #endif
-#if defined(CLONE_FILES) || (defined(HAVE_DECL_CLONE_FILES) && HAVE_DECL_CLONE_FILES)
-  XLAT(CLONE_FILES),
+#if defined(CLONE_NEWNS) || (defined(HAVE_DECL_CLONE_NEWNS) && HAVE_DECL_CLONE_NEWNS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((CLONE_NEWNS) == (0x00020000), "CLONE_NEWNS != 0x00020000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define CLONE_NEWNS 0x00020000
 #endif
 #if defined(CLONE_SYSVSEM) || (defined(HAVE_DECL_CLONE_SYSVSEM) && HAVE_DECL_CLONE_SYSVSEM)
-  XLAT(CLONE_SYSVSEM),
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((CLONE_SYSVSEM) == (0x00040000), "CLONE_SYSVSEM != 0x00040000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define CLONE_SYSVSEM 0x00040000
+#endif
+#if defined(CLONE_NEWCGROUP) || (defined(HAVE_DECL_CLONE_NEWCGROUP) && HAVE_DECL_CLONE_NEWCGROUP)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((CLONE_NEWCGROUP) == (0x02000000), "CLONE_NEWCGROUP != 0x02000000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define CLONE_NEWCGROUP 0x02000000
 #endif
 #if defined(CLONE_NEWUTS) || (defined(HAVE_DECL_CLONE_NEWUTS) && HAVE_DECL_CLONE_NEWUTS)
-  XLAT(CLONE_NEWUTS),
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((CLONE_NEWUTS) == (0x04000000), "CLONE_NEWUTS != 0x04000000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define CLONE_NEWUTS 0x04000000
 #endif
 #if defined(CLONE_NEWIPC) || (defined(HAVE_DECL_CLONE_NEWIPC) && HAVE_DECL_CLONE_NEWIPC)
-  XLAT(CLONE_NEWIPC),
-#endif
-#if defined(CLONE_NEWNET) || (defined(HAVE_DECL_CLONE_NEWNET) && HAVE_DECL_CLONE_NEWNET)
-  XLAT(CLONE_NEWNET),
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((CLONE_NEWIPC) == (0x08000000), "CLONE_NEWIPC != 0x08000000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define CLONE_NEWIPC 0x08000000
 #endif
 #if defined(CLONE_NEWUSER) || (defined(HAVE_DECL_CLONE_NEWUSER) && HAVE_DECL_CLONE_NEWUSER)
-  XLAT(CLONE_NEWUSER),
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((CLONE_NEWUSER) == (0x10000000), "CLONE_NEWUSER != 0x10000000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define CLONE_NEWUSER 0x10000000
 #endif
 #if defined(CLONE_NEWPID) || (defined(HAVE_DECL_CLONE_NEWPID) && HAVE_DECL_CLONE_NEWPID)
-  XLAT(CLONE_NEWPID),
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((CLONE_NEWPID) == (0x20000000), "CLONE_NEWPID != 0x20000000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define CLONE_NEWPID 0x20000000
 #endif
-#if defined(CLONE_NEWCGROUP) || (defined(HAVE_DECL_CLONE_NEWCGROUP) && HAVE_DECL_CLONE_NEWCGROUP)
-  XLAT(CLONE_NEWCGROUP),
+#if defined(CLONE_NEWNET) || (defined(HAVE_DECL_CLONE_NEWNET) && HAVE_DECL_CLONE_NEWNET)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((CLONE_NEWNET) == (0x40000000), "CLONE_NEWNET != 0x40000000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define CLONE_NEWNET 0x40000000
 #endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+#  error static const struct xlat unshare_flags in mpers mode
+
+# else
+
+static const struct xlat_data unshare_flags_xdata[] = {
+ XLAT(CLONE_NEWTIME),
+ #define XLAT_VAL_0 ((unsigned) (CLONE_NEWTIME))
+ #define XLAT_STR_0 STRINGIFY(CLONE_NEWTIME)
+ XLAT(CLONE_VM),
+ #define XLAT_VAL_1 ((unsigned) (CLONE_VM))
+ #define XLAT_STR_1 STRINGIFY(CLONE_VM)
+ XLAT(CLONE_FS),
+ #define XLAT_VAL_2 ((unsigned) (CLONE_FS))
+ #define XLAT_STR_2 STRINGIFY(CLONE_FS)
+ XLAT(CLONE_FILES),
+ #define XLAT_VAL_3 ((unsigned) (CLONE_FILES))
+ #define XLAT_STR_3 STRINGIFY(CLONE_FILES)
+ XLAT(CLONE_SIGHAND),
+ #define XLAT_VAL_4 ((unsigned) (CLONE_SIGHAND))
+ #define XLAT_STR_4 STRINGIFY(CLONE_SIGHAND)
+ XLAT(CLONE_THREAD),
+ #define XLAT_VAL_5 ((unsigned) (CLONE_THREAD))
+ #define XLAT_STR_5 STRINGIFY(CLONE_THREAD)
+ XLAT(CLONE_NEWNS),
+ #define XLAT_VAL_6 ((unsigned) (CLONE_NEWNS))
+ #define XLAT_STR_6 STRINGIFY(CLONE_NEWNS)
+ XLAT(CLONE_SYSVSEM),
+ #define XLAT_VAL_7 ((unsigned) (CLONE_SYSVSEM))
+ #define XLAT_STR_7 STRINGIFY(CLONE_SYSVSEM)
+ XLAT(CLONE_NEWCGROUP),
+ #define XLAT_VAL_8 ((unsigned) (CLONE_NEWCGROUP))
+ #define XLAT_STR_8 STRINGIFY(CLONE_NEWCGROUP)
+ XLAT(CLONE_NEWUTS),
+ #define XLAT_VAL_9 ((unsigned) (CLONE_NEWUTS))
+ #define XLAT_STR_9 STRINGIFY(CLONE_NEWUTS)
+ XLAT(CLONE_NEWIPC),
+ #define XLAT_VAL_10 ((unsigned) (CLONE_NEWIPC))
+ #define XLAT_STR_10 STRINGIFY(CLONE_NEWIPC)
+ XLAT(CLONE_NEWUSER),
+ #define XLAT_VAL_11 ((unsigned) (CLONE_NEWUSER))
+ #define XLAT_STR_11 STRINGIFY(CLONE_NEWUSER)
+ XLAT(CLONE_NEWPID),
+ #define XLAT_VAL_12 ((unsigned) (CLONE_NEWPID))
+ #define XLAT_STR_12 STRINGIFY(CLONE_NEWPID)
+ XLAT(CLONE_NEWNET),
+ #define XLAT_VAL_13 ((unsigned) (CLONE_NEWNET))
+ #define XLAT_STR_13 STRINGIFY(CLONE_NEWNET)
 };
 static
 const struct xlat unshare_flags[1] = { {
  .data = unshare_flags_xdata,
  .size = ARRAY_SIZE(unshare_flags_xdata),
- .type = XT_NORMAL,
+ .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/unshare_flags.in 5.9-0ubuntu2/xlat/unshare_flags.in
--- 5.5-3/xlat/unshare_flags.in	2016-10-28 23:54:01.000000000 +0000
+++ 5.9-0ubuntu2/xlat/unshare_flags.in	2020-03-01 23:25:39.000000000 +0000
@@ -1,13 +1,15 @@
-CLONE_THREAD
-CLONE_FS
-CLONE_NEWNS
-CLONE_SIGHAND
-CLONE_VM
-CLONE_FILES
-CLONE_SYSVSEM
-CLONE_NEWUTS
-CLONE_NEWIPC
-CLONE_NEWNET
-CLONE_NEWUSER
-CLONE_NEWPID
-CLONE_NEWCGROUP
+#sorted sort -k2,2g
+CLONE_NEWTIME	0x00000080
+CLONE_VM	0x00000100
+CLONE_FS	0x00000200
+CLONE_FILES	0x00000400
+CLONE_SIGHAND	0x00000800
+CLONE_THREAD	0x00010000
+CLONE_NEWNS	0x00020000
+CLONE_SYSVSEM	0x00040000
+CLONE_NEWCGROUP	0x02000000
+CLONE_NEWUTS	0x04000000
+CLONE_NEWIPC	0x08000000
+CLONE_NEWUSER	0x10000000
+CLONE_NEWPID	0x20000000
+CLONE_NEWNET	0x40000000
diff -pruN 5.5-3/xlat/uring_cqring_flags.h 5.9-0ubuntu2/xlat/uring_cqring_flags.h
--- 5.5-3/xlat/uring_cqring_flags.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/uring_cqring_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,48 @@
+/* Generated by ./xlat/gen.sh from ./xlat/uring_cqring_flags.in; do not edit. */
+
+#include "gcc_compat.h"
+#include "static_assert.h"
+
+#if defined(IORING_CQ_EVENTFD_DISABLED) || (defined(HAVE_DECL_IORING_CQ_EVENTFD_DISABLED) && HAVE_DECL_IORING_CQ_EVENTFD_DISABLED)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_CQ_EVENTFD_DISABLED) == (1U), "IORING_CQ_EVENTFD_DISABLED != 1U");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_CQ_EVENTFD_DISABLED 1U
+#endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+#  error static const struct xlat uring_cqring_flags in mpers mode
+
+# else
+
+static const struct xlat_data uring_cqring_flags_xdata[] = {
+ XLAT(IORING_CQ_EVENTFD_DISABLED),
+ #define XLAT_VAL_0 ((unsigned) (IORING_CQ_EVENTFD_DISABLED))
+ #define XLAT_STR_0 STRINGIFY(IORING_CQ_EVENTFD_DISABLED)
+};
+static
+const struct xlat uring_cqring_flags[1] = { {
+ .data = uring_cqring_flags_xdata,
+ .size = ARRAY_SIZE(uring_cqring_flags_xdata),
+ .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
+} };
+
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+# endif /* !IN_MPERS */
+
+#endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/uring_cqring_flags.in 5.9-0ubuntu2/xlat/uring_cqring_flags.in
--- 5.5-3/xlat/uring_cqring_flags.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/uring_cqring_flags.in	2020-06-16 08:00:00.000000000 +0000
@@ -0,0 +1 @@
+IORING_CQ_EVENTFD_DISABLED	1U
diff -pruN 5.5-3/xlat/uring_enter_flags.h 5.9-0ubuntu2/xlat/uring_enter_flags.h
--- 5.5-3/xlat/uring_enter_flags.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/uring_enter_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data uring_enter_flags_xdata[] = {
  XLAT(IORING_ENTER_GETEVENTS),
+ #define XLAT_VAL_0 ((unsigned) (IORING_ENTER_GETEVENTS))
+ #define XLAT_STR_0 STRINGIFY(IORING_ENTER_GETEVENTS)
  XLAT(IORING_ENTER_SQ_WAKEUP),
+ #define XLAT_VAL_1 ((unsigned) (IORING_ENTER_SQ_WAKEUP))
+ #define XLAT_STR_1 STRINGIFY(IORING_ENTER_SQ_WAKEUP)
 };
 static
 const struct xlat uring_enter_flags[1] = { {
  .data = uring_enter_flags_xdata,
  .size = ARRAY_SIZE(uring_enter_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/uring_op_flags.h 5.9-0ubuntu2/xlat/uring_op_flags.h
--- 5.5-3/xlat/uring_op_flags.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/uring_op_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,48 @@
+/* Generated by ./xlat/gen.sh from ./xlat/uring_op_flags.in; do not edit. */
+
+#include "gcc_compat.h"
+#include "static_assert.h"
+
+#if defined(IO_URING_OP_SUPPORTED) || (defined(HAVE_DECL_IO_URING_OP_SUPPORTED) && HAVE_DECL_IO_URING_OP_SUPPORTED)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IO_URING_OP_SUPPORTED) == ((1U << 0)), "IO_URING_OP_SUPPORTED != (1U << 0)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IO_URING_OP_SUPPORTED (1U << 0)
+#endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+#  error static const struct xlat uring_op_flags in mpers mode
+
+# else
+
+static const struct xlat_data uring_op_flags_xdata[] = {
+ XLAT(IO_URING_OP_SUPPORTED),
+ #define XLAT_VAL_0 ((unsigned) (IO_URING_OP_SUPPORTED))
+ #define XLAT_STR_0 STRINGIFY(IO_URING_OP_SUPPORTED)
+};
+static
+const struct xlat uring_op_flags[1] = { {
+ .data = uring_op_flags_xdata,
+ .size = ARRAY_SIZE(uring_op_flags_xdata),
+ .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
+} };
+
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+# endif /* !IN_MPERS */
+
+#endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/uring_op_flags.in 5.9-0ubuntu2/xlat/uring_op_flags.in
--- 5.5-3/xlat/uring_op_flags.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/uring_op_flags.in	2020-03-28 22:52:52.000000000 +0000
@@ -0,0 +1 @@
+IO_URING_OP_SUPPORTED (1U << 0)
diff -pruN 5.5-3/xlat/uring_ops.h 5.9-0ubuntu2/xlat/uring_ops.h
--- 5.5-3/xlat/uring_ops.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/uring_ops.h	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,642 @@
+/* Generated by ./xlat/gen.sh from ./xlat/uring_ops.in; do not edit. */
+
+#include "gcc_compat.h"
+#include "static_assert.h"
+
+#if defined(IORING_OP_NOP) || (defined(HAVE_DECL_IORING_OP_NOP) && HAVE_DECL_IORING_OP_NOP)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_NOP) == (0), "IORING_OP_NOP != 0");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_NOP 0
+#endif
+#if defined(IORING_OP_READV) || (defined(HAVE_DECL_IORING_OP_READV) && HAVE_DECL_IORING_OP_READV)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_READV) == (1), "IORING_OP_READV != 1");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_READV 1
+#endif
+#if defined(IORING_OP_WRITEV) || (defined(HAVE_DECL_IORING_OP_WRITEV) && HAVE_DECL_IORING_OP_WRITEV)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_WRITEV) == (2), "IORING_OP_WRITEV != 2");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_WRITEV 2
+#endif
+#if defined(IORING_OP_FSYNC) || (defined(HAVE_DECL_IORING_OP_FSYNC) && HAVE_DECL_IORING_OP_FSYNC)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_FSYNC) == (3), "IORING_OP_FSYNC != 3");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_FSYNC 3
+#endif
+#if defined(IORING_OP_READ_FIXED) || (defined(HAVE_DECL_IORING_OP_READ_FIXED) && HAVE_DECL_IORING_OP_READ_FIXED)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_READ_FIXED) == (4), "IORING_OP_READ_FIXED != 4");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_READ_FIXED 4
+#endif
+#if defined(IORING_OP_WRITE_FIXED) || (defined(HAVE_DECL_IORING_OP_WRITE_FIXED) && HAVE_DECL_IORING_OP_WRITE_FIXED)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_WRITE_FIXED) == (5), "IORING_OP_WRITE_FIXED != 5");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_WRITE_FIXED 5
+#endif
+#if defined(IORING_OP_POLL_ADD) || (defined(HAVE_DECL_IORING_OP_POLL_ADD) && HAVE_DECL_IORING_OP_POLL_ADD)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_POLL_ADD) == (6), "IORING_OP_POLL_ADD != 6");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_POLL_ADD 6
+#endif
+#if defined(IORING_OP_POLL_REMOVE) || (defined(HAVE_DECL_IORING_OP_POLL_REMOVE) && HAVE_DECL_IORING_OP_POLL_REMOVE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_POLL_REMOVE) == (7), "IORING_OP_POLL_REMOVE != 7");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_POLL_REMOVE 7
+#endif
+#if defined(IORING_OP_SYNC_FILE_RANGE) || (defined(HAVE_DECL_IORING_OP_SYNC_FILE_RANGE) && HAVE_DECL_IORING_OP_SYNC_FILE_RANGE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_SYNC_FILE_RANGE) == (8), "IORING_OP_SYNC_FILE_RANGE != 8");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_SYNC_FILE_RANGE 8
+#endif
+#if defined(IORING_OP_SENDMSG) || (defined(HAVE_DECL_IORING_OP_SENDMSG) && HAVE_DECL_IORING_OP_SENDMSG)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_SENDMSG) == (9), "IORING_OP_SENDMSG != 9");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_SENDMSG 9
+#endif
+#if defined(IORING_OP_RECVMSG) || (defined(HAVE_DECL_IORING_OP_RECVMSG) && HAVE_DECL_IORING_OP_RECVMSG)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_RECVMSG) == (10), "IORING_OP_RECVMSG != 10");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_RECVMSG 10
+#endif
+#if defined(IORING_OP_TIMEOUT) || (defined(HAVE_DECL_IORING_OP_TIMEOUT) && HAVE_DECL_IORING_OP_TIMEOUT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_TIMEOUT) == (11), "IORING_OP_TIMEOUT != 11");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_TIMEOUT 11
+#endif
+#if defined(IORING_OP_TIMEOUT_REMOVE) || (defined(HAVE_DECL_IORING_OP_TIMEOUT_REMOVE) && HAVE_DECL_IORING_OP_TIMEOUT_REMOVE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_TIMEOUT_REMOVE) == (12), "IORING_OP_TIMEOUT_REMOVE != 12");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_TIMEOUT_REMOVE 12
+#endif
+#if defined(IORING_OP_ACCEPT) || (defined(HAVE_DECL_IORING_OP_ACCEPT) && HAVE_DECL_IORING_OP_ACCEPT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_ACCEPT) == (13), "IORING_OP_ACCEPT != 13");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_ACCEPT 13
+#endif
+#if defined(IORING_OP_ASYNC_CANCEL) || (defined(HAVE_DECL_IORING_OP_ASYNC_CANCEL) && HAVE_DECL_IORING_OP_ASYNC_CANCEL)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_ASYNC_CANCEL) == (14), "IORING_OP_ASYNC_CANCEL != 14");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_ASYNC_CANCEL 14
+#endif
+#if defined(IORING_OP_LINK_TIMEOUT) || (defined(HAVE_DECL_IORING_OP_LINK_TIMEOUT) && HAVE_DECL_IORING_OP_LINK_TIMEOUT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_LINK_TIMEOUT) == (15), "IORING_OP_LINK_TIMEOUT != 15");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_LINK_TIMEOUT 15
+#endif
+#if defined(IORING_OP_CONNECT) || (defined(HAVE_DECL_IORING_OP_CONNECT) && HAVE_DECL_IORING_OP_CONNECT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_CONNECT) == (16), "IORING_OP_CONNECT != 16");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_CONNECT 16
+#endif
+#if defined(IORING_OP_FALLOCATE) || (defined(HAVE_DECL_IORING_OP_FALLOCATE) && HAVE_DECL_IORING_OP_FALLOCATE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_FALLOCATE) == (17), "IORING_OP_FALLOCATE != 17");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_FALLOCATE 17
+#endif
+#if defined(IORING_OP_OPENAT) || (defined(HAVE_DECL_IORING_OP_OPENAT) && HAVE_DECL_IORING_OP_OPENAT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_OPENAT) == (18), "IORING_OP_OPENAT != 18");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_OPENAT 18
+#endif
+#if defined(IORING_OP_CLOSE) || (defined(HAVE_DECL_IORING_OP_CLOSE) && HAVE_DECL_IORING_OP_CLOSE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_CLOSE) == (19), "IORING_OP_CLOSE != 19");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_CLOSE 19
+#endif
+#if defined(IORING_OP_FILES_UPDATE) || (defined(HAVE_DECL_IORING_OP_FILES_UPDATE) && HAVE_DECL_IORING_OP_FILES_UPDATE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_FILES_UPDATE) == (20), "IORING_OP_FILES_UPDATE != 20");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_FILES_UPDATE 20
+#endif
+#if defined(IORING_OP_STATX) || (defined(HAVE_DECL_IORING_OP_STATX) && HAVE_DECL_IORING_OP_STATX)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_STATX) == (21), "IORING_OP_STATX != 21");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_STATX 21
+#endif
+#if defined(IORING_OP_READ) || (defined(HAVE_DECL_IORING_OP_READ) && HAVE_DECL_IORING_OP_READ)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_READ) == (22), "IORING_OP_READ != 22");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_READ 22
+#endif
+#if defined(IORING_OP_WRITE) || (defined(HAVE_DECL_IORING_OP_WRITE) && HAVE_DECL_IORING_OP_WRITE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_WRITE) == (23), "IORING_OP_WRITE != 23");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_WRITE 23
+#endif
+#if defined(IORING_OP_FADVISE) || (defined(HAVE_DECL_IORING_OP_FADVISE) && HAVE_DECL_IORING_OP_FADVISE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_FADVISE) == (24), "IORING_OP_FADVISE != 24");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_FADVISE 24
+#endif
+#if defined(IORING_OP_MADVISE) || (defined(HAVE_DECL_IORING_OP_MADVISE) && HAVE_DECL_IORING_OP_MADVISE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_MADVISE) == (25), "IORING_OP_MADVISE != 25");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_MADVISE 25
+#endif
+#if defined(IORING_OP_SEND) || (defined(HAVE_DECL_IORING_OP_SEND) && HAVE_DECL_IORING_OP_SEND)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_SEND) == (26), "IORING_OP_SEND != 26");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_SEND 26
+#endif
+#if defined(IORING_OP_RECV) || (defined(HAVE_DECL_IORING_OP_RECV) && HAVE_DECL_IORING_OP_RECV)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_RECV) == (27), "IORING_OP_RECV != 27");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_RECV 27
+#endif
+#if defined(IORING_OP_OPENAT2) || (defined(HAVE_DECL_IORING_OP_OPENAT2) && HAVE_DECL_IORING_OP_OPENAT2)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_OPENAT2) == (28), "IORING_OP_OPENAT2 != 28");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_OPENAT2 28
+#endif
+#if defined(IORING_OP_EPOLL_CTL) || (defined(HAVE_DECL_IORING_OP_EPOLL_CTL) && HAVE_DECL_IORING_OP_EPOLL_CTL)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_EPOLL_CTL) == (29), "IORING_OP_EPOLL_CTL != 29");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_EPOLL_CTL 29
+#endif
+#if defined(IORING_OP_SPLICE) || (defined(HAVE_DECL_IORING_OP_SPLICE) && HAVE_DECL_IORING_OP_SPLICE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_SPLICE) == (30), "IORING_OP_SPLICE != 30");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_SPLICE 30
+#endif
+#if defined(IORING_OP_PROVIDE_BUFFERS) || (defined(HAVE_DECL_IORING_OP_PROVIDE_BUFFERS) && HAVE_DECL_IORING_OP_PROVIDE_BUFFERS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_PROVIDE_BUFFERS) == (31), "IORING_OP_PROVIDE_BUFFERS != 31");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_PROVIDE_BUFFERS 31
+#endif
+#if defined(IORING_OP_REMOVE_BUFFERS) || (defined(HAVE_DECL_IORING_OP_REMOVE_BUFFERS) && HAVE_DECL_IORING_OP_REMOVE_BUFFERS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_REMOVE_BUFFERS) == (32), "IORING_OP_REMOVE_BUFFERS != 32");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_REMOVE_BUFFERS 32
+#endif
+#if defined(IORING_OP_TEE) || (defined(HAVE_DECL_IORING_OP_TEE) && HAVE_DECL_IORING_OP_TEE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_OP_TEE) == (33), "IORING_OP_TEE != 33");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_OP_TEE 33
+#endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+#  error static const struct xlat uring_ops in mpers mode
+
+# else
+
+static const struct xlat_data uring_ops_xdata[] = {
+ [IORING_OP_NOP] = XLAT(IORING_OP_NOP),
+ #define XLAT_VAL_0 ((unsigned) (IORING_OP_NOP))
+ #define XLAT_STR_0 STRINGIFY(IORING_OP_NOP)
+ [IORING_OP_READV] = XLAT(IORING_OP_READV),
+ #define XLAT_VAL_1 ((unsigned) (IORING_OP_READV))
+ #define XLAT_STR_1 STRINGIFY(IORING_OP_READV)
+ [IORING_OP_WRITEV] = XLAT(IORING_OP_WRITEV),
+ #define XLAT_VAL_2 ((unsigned) (IORING_OP_WRITEV))
+ #define XLAT_STR_2 STRINGIFY(IORING_OP_WRITEV)
+ [IORING_OP_FSYNC] = XLAT(IORING_OP_FSYNC),
+ #define XLAT_VAL_3 ((unsigned) (IORING_OP_FSYNC))
+ #define XLAT_STR_3 STRINGIFY(IORING_OP_FSYNC)
+ [IORING_OP_READ_FIXED] = XLAT(IORING_OP_READ_FIXED),
+ #define XLAT_VAL_4 ((unsigned) (IORING_OP_READ_FIXED))
+ #define XLAT_STR_4 STRINGIFY(IORING_OP_READ_FIXED)
+ [IORING_OP_WRITE_FIXED] = XLAT(IORING_OP_WRITE_FIXED),
+ #define XLAT_VAL_5 ((unsigned) (IORING_OP_WRITE_FIXED))
+ #define XLAT_STR_5 STRINGIFY(IORING_OP_WRITE_FIXED)
+ [IORING_OP_POLL_ADD] = XLAT(IORING_OP_POLL_ADD),
+ #define XLAT_VAL_6 ((unsigned) (IORING_OP_POLL_ADD))
+ #define XLAT_STR_6 STRINGIFY(IORING_OP_POLL_ADD)
+ [IORING_OP_POLL_REMOVE] = XLAT(IORING_OP_POLL_REMOVE),
+ #define XLAT_VAL_7 ((unsigned) (IORING_OP_POLL_REMOVE))
+ #define XLAT_STR_7 STRINGIFY(IORING_OP_POLL_REMOVE)
+ [IORING_OP_SYNC_FILE_RANGE] = XLAT(IORING_OP_SYNC_FILE_RANGE),
+ #define XLAT_VAL_8 ((unsigned) (IORING_OP_SYNC_FILE_RANGE))
+ #define XLAT_STR_8 STRINGIFY(IORING_OP_SYNC_FILE_RANGE)
+ [IORING_OP_SENDMSG] = XLAT(IORING_OP_SENDMSG),
+ #define XLAT_VAL_9 ((unsigned) (IORING_OP_SENDMSG))
+ #define XLAT_STR_9 STRINGIFY(IORING_OP_SENDMSG)
+ [IORING_OP_RECVMSG] = XLAT(IORING_OP_RECVMSG),
+ #define XLAT_VAL_10 ((unsigned) (IORING_OP_RECVMSG))
+ #define XLAT_STR_10 STRINGIFY(IORING_OP_RECVMSG)
+ [IORING_OP_TIMEOUT] = XLAT(IORING_OP_TIMEOUT),
+ #define XLAT_VAL_11 ((unsigned) (IORING_OP_TIMEOUT))
+ #define XLAT_STR_11 STRINGIFY(IORING_OP_TIMEOUT)
+ [IORING_OP_TIMEOUT_REMOVE] = XLAT(IORING_OP_TIMEOUT_REMOVE),
+ #define XLAT_VAL_12 ((unsigned) (IORING_OP_TIMEOUT_REMOVE))
+ #define XLAT_STR_12 STRINGIFY(IORING_OP_TIMEOUT_REMOVE)
+ [IORING_OP_ACCEPT] = XLAT(IORING_OP_ACCEPT),
+ #define XLAT_VAL_13 ((unsigned) (IORING_OP_ACCEPT))
+ #define XLAT_STR_13 STRINGIFY(IORING_OP_ACCEPT)
+ [IORING_OP_ASYNC_CANCEL] = XLAT(IORING_OP_ASYNC_CANCEL),
+ #define XLAT_VAL_14 ((unsigned) (IORING_OP_ASYNC_CANCEL))
+ #define XLAT_STR_14 STRINGIFY(IORING_OP_ASYNC_CANCEL)
+ [IORING_OP_LINK_TIMEOUT] = XLAT(IORING_OP_LINK_TIMEOUT),
+ #define XLAT_VAL_15 ((unsigned) (IORING_OP_LINK_TIMEOUT))
+ #define XLAT_STR_15 STRINGIFY(IORING_OP_LINK_TIMEOUT)
+ [IORING_OP_CONNECT] = XLAT(IORING_OP_CONNECT),
+ #define XLAT_VAL_16 ((unsigned) (IORING_OP_CONNECT))
+ #define XLAT_STR_16 STRINGIFY(IORING_OP_CONNECT)
+ [IORING_OP_FALLOCATE] = XLAT(IORING_OP_FALLOCATE),
+ #define XLAT_VAL_17 ((unsigned) (IORING_OP_FALLOCATE))
+ #define XLAT_STR_17 STRINGIFY(IORING_OP_FALLOCATE)
+ [IORING_OP_OPENAT] = XLAT(IORING_OP_OPENAT),
+ #define XLAT_VAL_18 ((unsigned) (IORING_OP_OPENAT))
+ #define XLAT_STR_18 STRINGIFY(IORING_OP_OPENAT)
+ [IORING_OP_CLOSE] = XLAT(IORING_OP_CLOSE),
+ #define XLAT_VAL_19 ((unsigned) (IORING_OP_CLOSE))
+ #define XLAT_STR_19 STRINGIFY(IORING_OP_CLOSE)
+ [IORING_OP_FILES_UPDATE] = XLAT(IORING_OP_FILES_UPDATE),
+ #define XLAT_VAL_20 ((unsigned) (IORING_OP_FILES_UPDATE))
+ #define XLAT_STR_20 STRINGIFY(IORING_OP_FILES_UPDATE)
+ [IORING_OP_STATX] = XLAT(IORING_OP_STATX),
+ #define XLAT_VAL_21 ((unsigned) (IORING_OP_STATX))
+ #define XLAT_STR_21 STRINGIFY(IORING_OP_STATX)
+ [IORING_OP_READ] = XLAT(IORING_OP_READ),
+ #define XLAT_VAL_22 ((unsigned) (IORING_OP_READ))
+ #define XLAT_STR_22 STRINGIFY(IORING_OP_READ)
+ [IORING_OP_WRITE] = XLAT(IORING_OP_WRITE),
+ #define XLAT_VAL_23 ((unsigned) (IORING_OP_WRITE))
+ #define XLAT_STR_23 STRINGIFY(IORING_OP_WRITE)
+ [IORING_OP_FADVISE] = XLAT(IORING_OP_FADVISE),
+ #define XLAT_VAL_24 ((unsigned) (IORING_OP_FADVISE))
+ #define XLAT_STR_24 STRINGIFY(IORING_OP_FADVISE)
+ [IORING_OP_MADVISE] = XLAT(IORING_OP_MADVISE),
+ #define XLAT_VAL_25 ((unsigned) (IORING_OP_MADVISE))
+ #define XLAT_STR_25 STRINGIFY(IORING_OP_MADVISE)
+ [IORING_OP_SEND] = XLAT(IORING_OP_SEND),
+ #define XLAT_VAL_26 ((unsigned) (IORING_OP_SEND))
+ #define XLAT_STR_26 STRINGIFY(IORING_OP_SEND)
+ [IORING_OP_RECV] = XLAT(IORING_OP_RECV),
+ #define XLAT_VAL_27 ((unsigned) (IORING_OP_RECV))
+ #define XLAT_STR_27 STRINGIFY(IORING_OP_RECV)
+ [IORING_OP_OPENAT2] = XLAT(IORING_OP_OPENAT2),
+ #define XLAT_VAL_28 ((unsigned) (IORING_OP_OPENAT2))
+ #define XLAT_STR_28 STRINGIFY(IORING_OP_OPENAT2)
+ [IORING_OP_EPOLL_CTL] = XLAT(IORING_OP_EPOLL_CTL),
+ #define XLAT_VAL_29 ((unsigned) (IORING_OP_EPOLL_CTL))
+ #define XLAT_STR_29 STRINGIFY(IORING_OP_EPOLL_CTL)
+ [IORING_OP_SPLICE] = XLAT(IORING_OP_SPLICE),
+ #define XLAT_VAL_30 ((unsigned) (IORING_OP_SPLICE))
+ #define XLAT_STR_30 STRINGIFY(IORING_OP_SPLICE)
+ [IORING_OP_PROVIDE_BUFFERS] = XLAT(IORING_OP_PROVIDE_BUFFERS),
+ #define XLAT_VAL_31 ((unsigned) (IORING_OP_PROVIDE_BUFFERS))
+ #define XLAT_STR_31 STRINGIFY(IORING_OP_PROVIDE_BUFFERS)
+ [IORING_OP_REMOVE_BUFFERS] = XLAT(IORING_OP_REMOVE_BUFFERS),
+ #define XLAT_VAL_32 ((unsigned) (IORING_OP_REMOVE_BUFFERS))
+ #define XLAT_STR_32 STRINGIFY(IORING_OP_REMOVE_BUFFERS)
+ [IORING_OP_TEE] = XLAT(IORING_OP_TEE),
+ #define XLAT_VAL_33 ((unsigned) (IORING_OP_TEE))
+ #define XLAT_STR_33 STRINGIFY(IORING_OP_TEE)
+};
+static
+const struct xlat uring_ops[1] = { {
+ .data = uring_ops_xdata,
+ .size = ARRAY_SIZE(uring_ops_xdata),
+ .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+  ,
+} };
+
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+# endif /* !IN_MPERS */
+
+#endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/uring_ops.in 5.9-0ubuntu2/xlat/uring_ops.in
--- 5.5-3/xlat/uring_ops.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/uring_ops.in	2020-06-28 08:00:00.000000000 +0000
@@ -0,0 +1,35 @@
+#value_indexed
+IORING_OP_NOP			0
+IORING_OP_READV			1
+IORING_OP_WRITEV		2
+IORING_OP_FSYNC			3
+IORING_OP_READ_FIXED		4
+IORING_OP_WRITE_FIXED		5
+IORING_OP_POLL_ADD		6
+IORING_OP_POLL_REMOVE		7
+IORING_OP_SYNC_FILE_RANGE	8
+IORING_OP_SENDMSG		9
+IORING_OP_RECVMSG		10
+IORING_OP_TIMEOUT		11
+IORING_OP_TIMEOUT_REMOVE	12
+IORING_OP_ACCEPT		13
+IORING_OP_ASYNC_CANCEL		14
+IORING_OP_LINK_TIMEOUT		15
+IORING_OP_CONNECT		16
+IORING_OP_FALLOCATE		17
+IORING_OP_OPENAT		18
+IORING_OP_CLOSE			19
+IORING_OP_FILES_UPDATE		20
+IORING_OP_STATX			21
+IORING_OP_READ			22
+IORING_OP_WRITE			23
+IORING_OP_FADVISE		24
+IORING_OP_MADVISE		25
+IORING_OP_SEND			26
+IORING_OP_RECV			27
+IORING_OP_OPENAT2		28
+IORING_OP_EPOLL_CTL		29
+IORING_OP_SPLICE		30
+IORING_OP_PROVIDE_BUFFERS	31
+IORING_OP_REMOVE_BUFFERS	32
+IORING_OP_TEE			33
diff -pruN 5.5-3/xlat/uring_register_opcodes.h 5.9-0ubuntu2/xlat/uring_register_opcodes.h
--- 5.5-3/xlat/uring_register_opcodes.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/uring_register_opcodes.h	2020-09-24 09:18:46.000000000 +0000
@@ -52,6 +52,34 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define IORING_REGISTER_FILES_UPDATE 6U
 #endif
+#if defined(IORING_REGISTER_EVENTFD_ASYNC) || (defined(HAVE_DECL_IORING_REGISTER_EVENTFD_ASYNC) && HAVE_DECL_IORING_REGISTER_EVENTFD_ASYNC)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_REGISTER_EVENTFD_ASYNC) == (7U), "IORING_REGISTER_EVENTFD_ASYNC != 7U");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_REGISTER_EVENTFD_ASYNC 7U
+#endif
+#if defined(IORING_REGISTER_PROBE) || (defined(HAVE_DECL_IORING_REGISTER_PROBE) && HAVE_DECL_IORING_REGISTER_PROBE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_REGISTER_PROBE) == (8U), "IORING_REGISTER_PROBE != 8U");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_REGISTER_PROBE 8U
+#endif
+#if defined(IORING_REGISTER_PERSONALITY) || (defined(HAVE_DECL_IORING_REGISTER_PERSONALITY) && HAVE_DECL_IORING_REGISTER_PERSONALITY)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_REGISTER_PERSONALITY) == (9U), "IORING_REGISTER_PERSONALITY != 9U");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_REGISTER_PERSONALITY 9U
+#endif
+#if defined(IORING_UNREGISTER_PERSONALITY) || (defined(HAVE_DECL_IORING_UNREGISTER_PERSONALITY) && HAVE_DECL_IORING_UNREGISTER_PERSONALITY)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_UNREGISTER_PERSONALITY) == (10U), "IORING_UNREGISTER_PERSONALITY != 10U");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_UNREGISTER_PERSONALITY 10U
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -63,20 +91,138 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data uring_register_opcodes_xdata[] = {
  [IORING_REGISTER_BUFFERS] = XLAT(IORING_REGISTER_BUFFERS),
+ #define XLAT_VAL_0 ((unsigned) (IORING_REGISTER_BUFFERS))
+ #define XLAT_STR_0 STRINGIFY(IORING_REGISTER_BUFFERS)
  [IORING_UNREGISTER_BUFFERS] = XLAT(IORING_UNREGISTER_BUFFERS),
+ #define XLAT_VAL_1 ((unsigned) (IORING_UNREGISTER_BUFFERS))
+ #define XLAT_STR_1 STRINGIFY(IORING_UNREGISTER_BUFFERS)
  [IORING_REGISTER_FILES] = XLAT(IORING_REGISTER_FILES),
+ #define XLAT_VAL_2 ((unsigned) (IORING_REGISTER_FILES))
+ #define XLAT_STR_2 STRINGIFY(IORING_REGISTER_FILES)
  [IORING_UNREGISTER_FILES] = XLAT(IORING_UNREGISTER_FILES),
+ #define XLAT_VAL_3 ((unsigned) (IORING_UNREGISTER_FILES))
+ #define XLAT_STR_3 STRINGIFY(IORING_UNREGISTER_FILES)
  [IORING_REGISTER_EVENTFD] = XLAT(IORING_REGISTER_EVENTFD),
+ #define XLAT_VAL_4 ((unsigned) (IORING_REGISTER_EVENTFD))
+ #define XLAT_STR_4 STRINGIFY(IORING_REGISTER_EVENTFD)
  [IORING_UNREGISTER_EVENTFD] = XLAT(IORING_UNREGISTER_EVENTFD),
+ #define XLAT_VAL_5 ((unsigned) (IORING_UNREGISTER_EVENTFD))
+ #define XLAT_STR_5 STRINGIFY(IORING_UNREGISTER_EVENTFD)
  [IORING_REGISTER_FILES_UPDATE] = XLAT(IORING_REGISTER_FILES_UPDATE),
+ #define XLAT_VAL_6 ((unsigned) (IORING_REGISTER_FILES_UPDATE))
+ #define XLAT_STR_6 STRINGIFY(IORING_REGISTER_FILES_UPDATE)
+ [IORING_REGISTER_EVENTFD_ASYNC] = XLAT(IORING_REGISTER_EVENTFD_ASYNC),
+ #define XLAT_VAL_7 ((unsigned) (IORING_REGISTER_EVENTFD_ASYNC))
+ #define XLAT_STR_7 STRINGIFY(IORING_REGISTER_EVENTFD_ASYNC)
+ [IORING_REGISTER_PROBE] = XLAT(IORING_REGISTER_PROBE),
+ #define XLAT_VAL_8 ((unsigned) (IORING_REGISTER_PROBE))
+ #define XLAT_STR_8 STRINGIFY(IORING_REGISTER_PROBE)
+ [IORING_REGISTER_PERSONALITY] = XLAT(IORING_REGISTER_PERSONALITY),
+ #define XLAT_VAL_9 ((unsigned) (IORING_REGISTER_PERSONALITY))
+ #define XLAT_STR_9 STRINGIFY(IORING_REGISTER_PERSONALITY)
+ [IORING_UNREGISTER_PERSONALITY] = XLAT(IORING_UNREGISTER_PERSONALITY),
+ #define XLAT_VAL_10 ((unsigned) (IORING_UNREGISTER_PERSONALITY))
+ #define XLAT_STR_10 STRINGIFY(IORING_UNREGISTER_PERSONALITY)
 };
 static
 const struct xlat uring_register_opcodes[1] = { {
  .data = uring_register_opcodes_xdata,
  .size = ARRAY_SIZE(uring_register_opcodes_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/uring_register_opcodes.in 5.9-0ubuntu2/xlat/uring_register_opcodes.in
--- 5.5-3/xlat/uring_register_opcodes.in	2020-01-27 13:21:44.000000000 +0000
+++ 5.9-0ubuntu2/xlat/uring_register_opcodes.in	2020-03-28 22:52:52.000000000 +0000
@@ -6,3 +6,7 @@ IORING_UNREGISTER_FILES		3U
 IORING_REGISTER_EVENTFD		4U
 IORING_UNREGISTER_EVENTFD	5U
 IORING_REGISTER_FILES_UPDATE	6U
+IORING_REGISTER_EVENTFD_ASYNC	7U
+IORING_REGISTER_PROBE		8U
+IORING_REGISTER_PERSONALITY	9U
+IORING_UNREGISTER_PERSONALITY	10U
diff -pruN 5.5-3/xlat/uring_setup_features.h 5.9-0ubuntu2/xlat/uring_setup_features.h
--- 5.5-3/xlat/uring_setup_features.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/uring_setup_features.h	2020-09-24 09:18:46.000000000 +0000
@@ -38,6 +38,20 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define IORING_FEAT_CUR_PERSONALITY (1<<4)
 #endif
+#if defined(IORING_FEAT_FAST_POLL) || (defined(HAVE_DECL_IORING_FEAT_FAST_POLL) && HAVE_DECL_IORING_FEAT_FAST_POLL)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_FEAT_FAST_POLL) == ((1<<5)), "IORING_FEAT_FAST_POLL != (1<<5)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_FEAT_FAST_POLL (1<<5)
+#endif
+#if defined(IORING_FEAT_POLL_32BITS) || (defined(HAVE_DECL_IORING_FEAT_POLL_32BITS) && HAVE_DECL_IORING_FEAT_POLL_32BITS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((IORING_FEAT_POLL_32BITS) == ((1<<6)), "IORING_FEAT_POLL_32BITS != (1<<6)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define IORING_FEAT_POLL_32BITS (1<<6)
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -49,18 +63,94 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data uring_setup_features_xdata[] = {
  XLAT(IORING_FEAT_SINGLE_MMAP),
+ #define XLAT_VAL_0 ((unsigned) (IORING_FEAT_SINGLE_MMAP))
+ #define XLAT_STR_0 STRINGIFY(IORING_FEAT_SINGLE_MMAP)
  XLAT(IORING_FEAT_NODROP),
+ #define XLAT_VAL_1 ((unsigned) (IORING_FEAT_NODROP))
+ #define XLAT_STR_1 STRINGIFY(IORING_FEAT_NODROP)
  XLAT(IORING_FEAT_SUBMIT_STABLE),
+ #define XLAT_VAL_2 ((unsigned) (IORING_FEAT_SUBMIT_STABLE))
+ #define XLAT_STR_2 STRINGIFY(IORING_FEAT_SUBMIT_STABLE)
  XLAT(IORING_FEAT_RW_CUR_POS),
+ #define XLAT_VAL_3 ((unsigned) (IORING_FEAT_RW_CUR_POS))
+ #define XLAT_STR_3 STRINGIFY(IORING_FEAT_RW_CUR_POS)
  XLAT(IORING_FEAT_CUR_PERSONALITY),
+ #define XLAT_VAL_4 ((unsigned) (IORING_FEAT_CUR_PERSONALITY))
+ #define XLAT_STR_4 STRINGIFY(IORING_FEAT_CUR_PERSONALITY)
+ XLAT(IORING_FEAT_FAST_POLL),
+ #define XLAT_VAL_5 ((unsigned) (IORING_FEAT_FAST_POLL))
+ #define XLAT_STR_5 STRINGIFY(IORING_FEAT_FAST_POLL)
+ XLAT(IORING_FEAT_POLL_32BITS),
+ #define XLAT_VAL_6 ((unsigned) (IORING_FEAT_POLL_32BITS))
+ #define XLAT_STR_6 STRINGIFY(IORING_FEAT_POLL_32BITS)
 };
 static
 const struct xlat uring_setup_features[1] = { {
  .data = uring_setup_features_xdata,
  .size = ARRAY_SIZE(uring_setup_features_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/uring_setup_features.in 5.9-0ubuntu2/xlat/uring_setup_features.in
--- 5.5-3/xlat/uring_setup_features.in	2020-02-02 00:05:02.000000000 +0000
+++ 5.9-0ubuntu2/xlat/uring_setup_features.in	2020-09-06 08:00:00.000000000 +0000
@@ -3,3 +3,5 @@ IORING_FEAT_NODROP		(1<<1)
 IORING_FEAT_SUBMIT_STABLE	(1<<2)
 IORING_FEAT_RW_CUR_POS		(1<<3)
 IORING_FEAT_CUR_PERSONALITY	(1<<4)
+IORING_FEAT_FAST_POLL		(1<<5)
+IORING_FEAT_POLL_32BITS		(1<<6)
diff -pruN 5.5-3/xlat/uring_setup_flags.h 5.9-0ubuntu2/xlat/uring_setup_flags.h
--- 5.5-3/xlat/uring_setup_flags.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/uring_setup_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -56,19 +56,83 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data uring_setup_flags_xdata[] = {
  XLAT(IORING_SETUP_IOPOLL),
+ #define XLAT_VAL_0 ((unsigned) (IORING_SETUP_IOPOLL))
+ #define XLAT_STR_0 STRINGIFY(IORING_SETUP_IOPOLL)
  XLAT(IORING_SETUP_SQPOLL),
+ #define XLAT_VAL_1 ((unsigned) (IORING_SETUP_SQPOLL))
+ #define XLAT_STR_1 STRINGIFY(IORING_SETUP_SQPOLL)
  XLAT(IORING_SETUP_SQ_AFF),
+ #define XLAT_VAL_2 ((unsigned) (IORING_SETUP_SQ_AFF))
+ #define XLAT_STR_2 STRINGIFY(IORING_SETUP_SQ_AFF)
  XLAT(IORING_SETUP_CQSIZE),
+ #define XLAT_VAL_3 ((unsigned) (IORING_SETUP_CQSIZE))
+ #define XLAT_STR_3 STRINGIFY(IORING_SETUP_CQSIZE)
  XLAT(IORING_SETUP_CLAMP),
+ #define XLAT_VAL_4 ((unsigned) (IORING_SETUP_CLAMP))
+ #define XLAT_STR_4 STRINGIFY(IORING_SETUP_CLAMP)
  XLAT(IORING_SETUP_ATTACH_WQ),
+ #define XLAT_VAL_5 ((unsigned) (IORING_SETUP_ATTACH_WQ))
+ #define XLAT_STR_5 STRINGIFY(IORING_SETUP_ATTACH_WQ)
 };
 static
 const struct xlat uring_setup_flags[1] = { {
  .data = uring_setup_flags_xdata,
  .size = ARRAY_SIZE(uring_setup_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/usagewho.h 5.9-0ubuntu2/xlat/usagewho.h
--- 5.5-3/xlat/usagewho.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/usagewho.h	2020-09-24 09:18:46.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data usagewho_xdata[] = {
  XLAT(RUSAGE_SELF),
+ #define XLAT_VAL_0 ((unsigned) (RUSAGE_SELF))
+ #define XLAT_STR_0 STRINGIFY(RUSAGE_SELF)
  XLAT(RUSAGE_CHILDREN),
+ #define XLAT_VAL_1 ((unsigned) (RUSAGE_CHILDREN))
+ #define XLAT_STR_1 STRINGIFY(RUSAGE_CHILDREN)
  XLAT(RUSAGE_BOTH),
+ #define XLAT_VAL_2 ((unsigned) (RUSAGE_BOTH))
+ #define XLAT_STR_2 STRINGIFY(RUSAGE_BOTH)
  XLAT(RUSAGE_THREAD),
+ #define XLAT_VAL_3 ((unsigned) (RUSAGE_THREAD))
+ #define XLAT_STR_3 STRINGIFY(RUSAGE_THREAD)
 };
 static
 const struct xlat usagewho[1] = { {
  .data = usagewho_xdata,
  .size = ARRAY_SIZE(usagewho_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_buf_flags.h 5.9-0ubuntu2/xlat/v4l2_buf_flags.h
--- 5.5-3/xlat/v4l2_buf_flags.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_buf_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -3,73 +3,166 @@
 #include "gcc_compat.h"
 #include "static_assert.h"
 
-
-#ifndef XLAT_MACROS_ONLY
-
-# ifdef IN_MPERS
-
-extern const struct xlat v4l2_buf_flags[];
-
-# else
-
-static const struct xlat_data v4l2_buf_flags_xdata[] = {
 #if defined(V4L2_BUF_FLAG_MAPPED) || (defined(HAVE_DECL_V4L2_BUF_FLAG_MAPPED) && HAVE_DECL_V4L2_BUF_FLAG_MAPPED)
-  XLAT(V4L2_BUF_FLAG_MAPPED),
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_BUF_FLAG_MAPPED) == (0x00000001), "V4L2_BUF_FLAG_MAPPED != 0x00000001");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_BUF_FLAG_MAPPED 0x00000001
 #endif
 #if defined(V4L2_BUF_FLAG_QUEUED) || (defined(HAVE_DECL_V4L2_BUF_FLAG_QUEUED) && HAVE_DECL_V4L2_BUF_FLAG_QUEUED)
-  XLAT(V4L2_BUF_FLAG_QUEUED),
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_BUF_FLAG_QUEUED) == (0x00000002), "V4L2_BUF_FLAG_QUEUED != 0x00000002");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_BUF_FLAG_QUEUED 0x00000002
 #endif
 #if defined(V4L2_BUF_FLAG_DONE) || (defined(HAVE_DECL_V4L2_BUF_FLAG_DONE) && HAVE_DECL_V4L2_BUF_FLAG_DONE)
-  XLAT(V4L2_BUF_FLAG_DONE),
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_BUF_FLAG_DONE) == (0x00000004), "V4L2_BUF_FLAG_DONE != 0x00000004");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_BUF_FLAG_DONE 0x00000004
 #endif
 #if defined(V4L2_BUF_FLAG_KEYFRAME) || (defined(HAVE_DECL_V4L2_BUF_FLAG_KEYFRAME) && HAVE_DECL_V4L2_BUF_FLAG_KEYFRAME)
-  XLAT(V4L2_BUF_FLAG_KEYFRAME),
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_BUF_FLAG_KEYFRAME) == (0x00000008), "V4L2_BUF_FLAG_KEYFRAME != 0x00000008");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_BUF_FLAG_KEYFRAME 0x00000008
 #endif
 #if defined(V4L2_BUF_FLAG_PFRAME) || (defined(HAVE_DECL_V4L2_BUF_FLAG_PFRAME) && HAVE_DECL_V4L2_BUF_FLAG_PFRAME)
-  XLAT(V4L2_BUF_FLAG_PFRAME),
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_BUF_FLAG_PFRAME) == (0x00000010), "V4L2_BUF_FLAG_PFRAME != 0x00000010");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_BUF_FLAG_PFRAME 0x00000010
 #endif
 #if defined(V4L2_BUF_FLAG_BFRAME) || (defined(HAVE_DECL_V4L2_BUF_FLAG_BFRAME) && HAVE_DECL_V4L2_BUF_FLAG_BFRAME)
-  XLAT(V4L2_BUF_FLAG_BFRAME),
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_BUF_FLAG_BFRAME) == (0x00000020), "V4L2_BUF_FLAG_BFRAME != 0x00000020");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_BUF_FLAG_BFRAME 0x00000020
+#endif
+#if defined(V4L2_BUF_FLAG_ERROR) || (defined(HAVE_DECL_V4L2_BUF_FLAG_ERROR) && HAVE_DECL_V4L2_BUF_FLAG_ERROR)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_BUF_FLAG_ERROR) == (0x00000040), "V4L2_BUF_FLAG_ERROR != 0x00000040");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_BUF_FLAG_ERROR 0x00000040
+#endif
+#if defined(V4L2_BUF_FLAG_IN_REQUEST) || (defined(HAVE_DECL_V4L2_BUF_FLAG_IN_REQUEST) && HAVE_DECL_V4L2_BUF_FLAG_IN_REQUEST)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_BUF_FLAG_IN_REQUEST) == (0x00000080), "V4L2_BUF_FLAG_IN_REQUEST != 0x00000080");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_BUF_FLAG_IN_REQUEST 0x00000080
 #endif
 #if defined(V4L2_BUF_FLAG_TIMECODE) || (defined(HAVE_DECL_V4L2_BUF_FLAG_TIMECODE) && HAVE_DECL_V4L2_BUF_FLAG_TIMECODE)
-  XLAT(V4L2_BUF_FLAG_TIMECODE),
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_BUF_FLAG_TIMECODE) == (0x00000100), "V4L2_BUF_FLAG_TIMECODE != 0x00000100");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_BUF_FLAG_TIMECODE 0x00000100
 #endif
 #if defined(V4L2_BUF_FLAG_INPUT) || (defined(HAVE_DECL_V4L2_BUF_FLAG_INPUT) && HAVE_DECL_V4L2_BUF_FLAG_INPUT)
-  XLAT(V4L2_BUF_FLAG_INPUT),
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_BUF_FLAG_INPUT) == (0x00000200), "V4L2_BUF_FLAG_INPUT != 0x00000200");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_BUF_FLAG_INPUT 0x00000200
 #endif
 #if defined(V4L2_BUF_FLAG_PREPARED) || (defined(HAVE_DECL_V4L2_BUF_FLAG_PREPARED) && HAVE_DECL_V4L2_BUF_FLAG_PREPARED)
-  XLAT(V4L2_BUF_FLAG_PREPARED),
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_BUF_FLAG_PREPARED) == (0x00000400), "V4L2_BUF_FLAG_PREPARED != 0x00000400");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_BUF_FLAG_PREPARED 0x00000400
 #endif
 #if defined(V4L2_BUF_FLAG_NO_CACHE_INVALIDATE) || (defined(HAVE_DECL_V4L2_BUF_FLAG_NO_CACHE_INVALIDATE) && HAVE_DECL_V4L2_BUF_FLAG_NO_CACHE_INVALIDATE)
-  XLAT(V4L2_BUF_FLAG_NO_CACHE_INVALIDATE),
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_BUF_FLAG_NO_CACHE_INVALIDATE) == (0x00000800), "V4L2_BUF_FLAG_NO_CACHE_INVALIDATE != 0x00000800");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_BUF_FLAG_NO_CACHE_INVALIDATE 0x00000800
 #endif
 #if defined(V4L2_BUF_FLAG_NO_CACHE_CLEAN) || (defined(HAVE_DECL_V4L2_BUF_FLAG_NO_CACHE_CLEAN) && HAVE_DECL_V4L2_BUF_FLAG_NO_CACHE_CLEAN)
-  XLAT(V4L2_BUF_FLAG_NO_CACHE_CLEAN),
-#endif
-#if defined(V4L2_BUF_FLAG_TIMESTAMP_MASK) || (defined(HAVE_DECL_V4L2_BUF_FLAG_TIMESTAMP_MASK) && HAVE_DECL_V4L2_BUF_FLAG_TIMESTAMP_MASK)
-  XLAT(V4L2_BUF_FLAG_TIMESTAMP_MASK),
-#endif
-#if defined(V4L2_BUF_FLAG_TIMESTAMP_UNKNOWN) || (defined(HAVE_DECL_V4L2_BUF_FLAG_TIMESTAMP_UNKNOWN) && HAVE_DECL_V4L2_BUF_FLAG_TIMESTAMP_UNKNOWN)
-  XLAT(V4L2_BUF_FLAG_TIMESTAMP_UNKNOWN),
-#endif
-#if defined(V4L2_BUF_FLAG_TIMESTAMP_MONOTONIC) || (defined(HAVE_DECL_V4L2_BUF_FLAG_TIMESTAMP_MONOTONIC) && HAVE_DECL_V4L2_BUF_FLAG_TIMESTAMP_MONOTONIC)
-  XLAT(V4L2_BUF_FLAG_TIMESTAMP_MONOTONIC),
-#endif
-#if defined(V4L2_BUF_FLAG_TIMESTAMP_COPY) || (defined(HAVE_DECL_V4L2_BUF_FLAG_TIMESTAMP_COPY) && HAVE_DECL_V4L2_BUF_FLAG_TIMESTAMP_COPY)
-  XLAT(V4L2_BUF_FLAG_TIMESTAMP_COPY),
-#endif
-#if defined(V4L2_BUF_FLAG_TSTAMP_SRC_MASK) || (defined(HAVE_DECL_V4L2_BUF_FLAG_TSTAMP_SRC_MASK) && HAVE_DECL_V4L2_BUF_FLAG_TSTAMP_SRC_MASK)
-  XLAT(V4L2_BUF_FLAG_TSTAMP_SRC_MASK),
-#endif
-#if defined(V4L2_BUF_FLAG_TSTAMP_SRC_EOF) || (defined(HAVE_DECL_V4L2_BUF_FLAG_TSTAMP_SRC_EOF) && HAVE_DECL_V4L2_BUF_FLAG_TSTAMP_SRC_EOF)
-  XLAT(V4L2_BUF_FLAG_TSTAMP_SRC_EOF),
-#endif
-#if defined(V4L2_BUF_FLAG_TSTAMP_SRC_SOE) || (defined(HAVE_DECL_V4L2_BUF_FLAG_TSTAMP_SRC_SOE) && HAVE_DECL_V4L2_BUF_FLAG_TSTAMP_SRC_SOE)
-  XLAT(V4L2_BUF_FLAG_TSTAMP_SRC_SOE),
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_BUF_FLAG_NO_CACHE_CLEAN) == (0x00001000), "V4L2_BUF_FLAG_NO_CACHE_CLEAN != 0x00001000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_BUF_FLAG_NO_CACHE_CLEAN 0x00001000
 #endif
 #if defined(V4L2_BUF_FLAG_LAST) || (defined(HAVE_DECL_V4L2_BUF_FLAG_LAST) && HAVE_DECL_V4L2_BUF_FLAG_LAST)
-  XLAT(V4L2_BUF_FLAG_LAST),
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_BUF_FLAG_LAST) == (0x00100000), "V4L2_BUF_FLAG_LAST != 0x00100000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_BUF_FLAG_LAST 0x00100000
+#endif
+#if defined(V4L2_BUF_FLAG_REQUEST_FD) || (defined(HAVE_DECL_V4L2_BUF_FLAG_REQUEST_FD) && HAVE_DECL_V4L2_BUF_FLAG_REQUEST_FD)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_BUF_FLAG_REQUEST_FD) == (0x00800000), "V4L2_BUF_FLAG_REQUEST_FD != 0x00800000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_BUF_FLAG_REQUEST_FD 0x00800000
 #endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+extern const struct xlat v4l2_buf_flags[];
+
+# else
+
+static const struct xlat_data v4l2_buf_flags_xdata[] = {
+ XLAT(V4L2_BUF_FLAG_MAPPED),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_BUF_FLAG_MAPPED))
+ #define XLAT_STR_0 STRINGIFY(V4L2_BUF_FLAG_MAPPED)
+ XLAT(V4L2_BUF_FLAG_QUEUED),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_BUF_FLAG_QUEUED))
+ #define XLAT_STR_1 STRINGIFY(V4L2_BUF_FLAG_QUEUED)
+ XLAT(V4L2_BUF_FLAG_DONE),
+ #define XLAT_VAL_2 ((unsigned) (V4L2_BUF_FLAG_DONE))
+ #define XLAT_STR_2 STRINGIFY(V4L2_BUF_FLAG_DONE)
+ XLAT(V4L2_BUF_FLAG_KEYFRAME),
+ #define XLAT_VAL_3 ((unsigned) (V4L2_BUF_FLAG_KEYFRAME))
+ #define XLAT_STR_3 STRINGIFY(V4L2_BUF_FLAG_KEYFRAME)
+ XLAT(V4L2_BUF_FLAG_PFRAME),
+ #define XLAT_VAL_4 ((unsigned) (V4L2_BUF_FLAG_PFRAME))
+ #define XLAT_STR_4 STRINGIFY(V4L2_BUF_FLAG_PFRAME)
+ XLAT(V4L2_BUF_FLAG_BFRAME),
+ #define XLAT_VAL_5 ((unsigned) (V4L2_BUF_FLAG_BFRAME))
+ #define XLAT_STR_5 STRINGIFY(V4L2_BUF_FLAG_BFRAME)
+ XLAT(V4L2_BUF_FLAG_ERROR),
+ #define XLAT_VAL_6 ((unsigned) (V4L2_BUF_FLAG_ERROR))
+ #define XLAT_STR_6 STRINGIFY(V4L2_BUF_FLAG_ERROR)
+ XLAT(V4L2_BUF_FLAG_IN_REQUEST),
+ #define XLAT_VAL_7 ((unsigned) (V4L2_BUF_FLAG_IN_REQUEST))
+ #define XLAT_STR_7 STRINGIFY(V4L2_BUF_FLAG_IN_REQUEST)
+ XLAT(V4L2_BUF_FLAG_TIMECODE),
+ #define XLAT_VAL_8 ((unsigned) (V4L2_BUF_FLAG_TIMECODE))
+ #define XLAT_STR_8 STRINGIFY(V4L2_BUF_FLAG_TIMECODE)
+ XLAT(V4L2_BUF_FLAG_INPUT),
+ #define XLAT_VAL_9 ((unsigned) (V4L2_BUF_FLAG_INPUT))
+ #define XLAT_STR_9 STRINGIFY(V4L2_BUF_FLAG_INPUT)
+ XLAT(V4L2_BUF_FLAG_PREPARED),
+ #define XLAT_VAL_10 ((unsigned) (V4L2_BUF_FLAG_PREPARED))
+ #define XLAT_STR_10 STRINGIFY(V4L2_BUF_FLAG_PREPARED)
+ XLAT(V4L2_BUF_FLAG_NO_CACHE_INVALIDATE),
+ #define XLAT_VAL_11 ((unsigned) (V4L2_BUF_FLAG_NO_CACHE_INVALIDATE))
+ #define XLAT_STR_11 STRINGIFY(V4L2_BUF_FLAG_NO_CACHE_INVALIDATE)
+ XLAT(V4L2_BUF_FLAG_NO_CACHE_CLEAN),
+ #define XLAT_VAL_12 ((unsigned) (V4L2_BUF_FLAG_NO_CACHE_CLEAN))
+ #define XLAT_STR_12 STRINGIFY(V4L2_BUF_FLAG_NO_CACHE_CLEAN)
+ XLAT(V4L2_BUF_FLAG_LAST),
+ #define XLAT_VAL_13 ((unsigned) (V4L2_BUF_FLAG_LAST))
+ #define XLAT_STR_13 STRINGIFY(V4L2_BUF_FLAG_LAST)
+ XLAT(V4L2_BUF_FLAG_REQUEST_FD),
+ #define XLAT_VAL_14 ((unsigned) (V4L2_BUF_FLAG_REQUEST_FD))
+ #define XLAT_STR_14 STRINGIFY(V4L2_BUF_FLAG_REQUEST_FD)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -78,8 +171,132 @@ const struct xlat v4l2_buf_flags[1] = {
  .data = v4l2_buf_flags_xdata,
  .size = ARRAY_SIZE(v4l2_buf_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_buf_flags.in 5.9-0ubuntu2/xlat/v4l2_buf_flags.in
--- 5.5-3/xlat/v4l2_buf_flags.in	2017-04-07 01:21:36.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_buf_flags.in	2020-03-30 21:14:23.000000000 +0000
@@ -1,19 +1,15 @@
-V4L2_BUF_FLAG_MAPPED
-V4L2_BUF_FLAG_QUEUED
-V4L2_BUF_FLAG_DONE
-V4L2_BUF_FLAG_KEYFRAME
-V4L2_BUF_FLAG_PFRAME
-V4L2_BUF_FLAG_BFRAME
-V4L2_BUF_FLAG_TIMECODE
-V4L2_BUF_FLAG_INPUT
-V4L2_BUF_FLAG_PREPARED
-V4L2_BUF_FLAG_NO_CACHE_INVALIDATE
-V4L2_BUF_FLAG_NO_CACHE_CLEAN
-V4L2_BUF_FLAG_TIMESTAMP_MASK
-V4L2_BUF_FLAG_TIMESTAMP_UNKNOWN
-V4L2_BUF_FLAG_TIMESTAMP_MONOTONIC
-V4L2_BUF_FLAG_TIMESTAMP_COPY
-V4L2_BUF_FLAG_TSTAMP_SRC_MASK
-V4L2_BUF_FLAG_TSTAMP_SRC_EOF
-V4L2_BUF_FLAG_TSTAMP_SRC_SOE
-V4L2_BUF_FLAG_LAST
+V4L2_BUF_FLAG_MAPPED			0x00000001
+V4L2_BUF_FLAG_QUEUED			0x00000002
+V4L2_BUF_FLAG_DONE			0x00000004
+V4L2_BUF_FLAG_KEYFRAME			0x00000008
+V4L2_BUF_FLAG_PFRAME			0x00000010
+V4L2_BUF_FLAG_BFRAME			0x00000020
+V4L2_BUF_FLAG_ERROR			0x00000040
+V4L2_BUF_FLAG_IN_REQUEST		0x00000080
+V4L2_BUF_FLAG_TIMECODE			0x00000100
+V4L2_BUF_FLAG_INPUT			0x00000200
+V4L2_BUF_FLAG_PREPARED			0x00000400
+V4L2_BUF_FLAG_NO_CACHE_INVALIDATE	0x00000800
+V4L2_BUF_FLAG_NO_CACHE_CLEAN		0x00001000
+V4L2_BUF_FLAG_LAST			0x00100000
+V4L2_BUF_FLAG_REQUEST_FD		0x00800000
diff -pruN 5.5-3/xlat/v4l2_buf_flags_masks.h 5.9-0ubuntu2/xlat/v4l2_buf_flags_masks.h
--- 5.5-3/xlat/v4l2_buf_flags_masks.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_buf_flags_masks.h	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,68 @@
+/* Generated by ./xlat/gen.sh from ./xlat/v4l2_buf_flags_masks.in; do not edit. */
+
+#include "gcc_compat.h"
+#include "static_assert.h"
+
+#if defined(V4L2_BUF_FLAG_TIMESTAMP_MASK) || (defined(HAVE_DECL_V4L2_BUF_FLAG_TIMESTAMP_MASK) && HAVE_DECL_V4L2_BUF_FLAG_TIMESTAMP_MASK)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_BUF_FLAG_TIMESTAMP_MASK) == (0x0000e000), "V4L2_BUF_FLAG_TIMESTAMP_MASK != 0x0000e000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_BUF_FLAG_TIMESTAMP_MASK 0x0000e000
+#endif
+#if defined(V4L2_BUF_FLAG_TSTAMP_SRC_MASK) || (defined(HAVE_DECL_V4L2_BUF_FLAG_TSTAMP_SRC_MASK) && HAVE_DECL_V4L2_BUF_FLAG_TSTAMP_SRC_MASK)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_BUF_FLAG_TSTAMP_SRC_MASK) == (0x00070000), "V4L2_BUF_FLAG_TSTAMP_SRC_MASK != 0x00070000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_BUF_FLAG_TSTAMP_SRC_MASK 0x00070000
+#endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+extern const struct xlat v4l2_buf_flags_masks[];
+
+# else
+
+static const struct xlat_data v4l2_buf_flags_masks_xdata[] = {
+ XLAT(V4L2_BUF_FLAG_TIMESTAMP_MASK),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_BUF_FLAG_TIMESTAMP_MASK))
+ #define XLAT_STR_0 STRINGIFY(V4L2_BUF_FLAG_TIMESTAMP_MASK)
+ XLAT(V4L2_BUF_FLAG_TSTAMP_SRC_MASK),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_BUF_FLAG_TSTAMP_SRC_MASK))
+ #define XLAT_STR_1 STRINGIFY(V4L2_BUF_FLAG_TSTAMP_SRC_MASK)
+};
+#  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
+static
+#  endif
+const struct xlat v4l2_buf_flags_masks[1] = { {
+ .data = v4l2_buf_flags_masks_xdata,
+ .size = ARRAY_SIZE(v4l2_buf_flags_masks_xdata),
+ .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
+} };
+
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+# endif /* !IN_MPERS */
+
+#endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_buf_flags_masks.in 5.9-0ubuntu2/xlat/v4l2_buf_flags_masks.in
--- 5.5-3/xlat/v4l2_buf_flags_masks.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_buf_flags_masks.in	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,2 @@
+V4L2_BUF_FLAG_TIMESTAMP_MASK	0x0000e000
+V4L2_BUF_FLAG_TSTAMP_SRC_MASK	0x00070000
diff -pruN 5.5-3/xlat/v4l2_buf_flags_ts_src.h 5.9-0ubuntu2/xlat/v4l2_buf_flags_ts_src.h
--- 5.5-3/xlat/v4l2_buf_flags_ts_src.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_buf_flags_ts_src.h	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,69 @@
+/* Generated by ./xlat/gen.sh from ./xlat/v4l2_buf_flags_ts_src.in; do not edit. */
+
+#include "gcc_compat.h"
+#include "static_assert.h"
+
+#if defined(V4L2_BUF_FLAG_TSTAMP_SRC_EOF) || (defined(HAVE_DECL_V4L2_BUF_FLAG_TSTAMP_SRC_EOF) && HAVE_DECL_V4L2_BUF_FLAG_TSTAMP_SRC_EOF)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_BUF_FLAG_TSTAMP_SRC_EOF) == (0x00000000), "V4L2_BUF_FLAG_TSTAMP_SRC_EOF != 0x00000000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_BUF_FLAG_TSTAMP_SRC_EOF 0x00000000
+#endif
+#if defined(V4L2_BUF_FLAG_TSTAMP_SRC_SOE) || (defined(HAVE_DECL_V4L2_BUF_FLAG_TSTAMP_SRC_SOE) && HAVE_DECL_V4L2_BUF_FLAG_TSTAMP_SRC_SOE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_BUF_FLAG_TSTAMP_SRC_SOE) == (0x00010000), "V4L2_BUF_FLAG_TSTAMP_SRC_SOE != 0x00010000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_BUF_FLAG_TSTAMP_SRC_SOE 0x00010000
+#endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+extern const struct xlat v4l2_buf_flags_ts_src[];
+
+# else
+
+static const struct xlat_data v4l2_buf_flags_ts_src_xdata[] = {
+
+ XLAT(V4L2_BUF_FLAG_TSTAMP_SRC_EOF),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_BUF_FLAG_TSTAMP_SRC_EOF))
+ #define XLAT_STR_0 STRINGIFY(V4L2_BUF_FLAG_TSTAMP_SRC_EOF)
+ XLAT(V4L2_BUF_FLAG_TSTAMP_SRC_SOE),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_BUF_FLAG_TSTAMP_SRC_SOE))
+ #define XLAT_STR_1 STRINGIFY(V4L2_BUF_FLAG_TSTAMP_SRC_SOE)
+};
+#  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
+static
+#  endif
+const struct xlat v4l2_buf_flags_ts_src[1] = { {
+ .data = v4l2_buf_flags_ts_src_xdata,
+ .size = ARRAY_SIZE(v4l2_buf_flags_ts_src_xdata),
+ .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
+} };
+
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+# endif /* !IN_MPERS */
+
+#endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_buf_flags_ts_src.in 5.9-0ubuntu2/xlat/v4l2_buf_flags_ts_src.in
--- 5.5-3/xlat/v4l2_buf_flags_ts_src.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_buf_flags_ts_src.in	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,3 @@
+/* V4L2_BUF_FLAG_TSTAMP_SRC_MASK	0x00070000 */
+V4L2_BUF_FLAG_TSTAMP_SRC_EOF		0x00000000
+V4L2_BUF_FLAG_TSTAMP_SRC_SOE		0x00010000
diff -pruN 5.5-3/xlat/v4l2_buf_flags_ts_type.h 5.9-0ubuntu2/xlat/v4l2_buf_flags_ts_type.h
--- 5.5-3/xlat/v4l2_buf_flags_ts_type.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_buf_flags_ts_type.h	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,87 @@
+/* Generated by ./xlat/gen.sh from ./xlat/v4l2_buf_flags_ts_type.in; do not edit. */
+
+#include "gcc_compat.h"
+#include "static_assert.h"
+
+#if defined(V4L2_BUF_FLAG_TIMESTAMP_UNKNOWN) || (defined(HAVE_DECL_V4L2_BUF_FLAG_TIMESTAMP_UNKNOWN) && HAVE_DECL_V4L2_BUF_FLAG_TIMESTAMP_UNKNOWN)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_BUF_FLAG_TIMESTAMP_UNKNOWN) == (0x00000000), "V4L2_BUF_FLAG_TIMESTAMP_UNKNOWN != 0x00000000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_BUF_FLAG_TIMESTAMP_UNKNOWN 0x00000000
+#endif
+#if defined(V4L2_BUF_FLAG_TIMESTAMP_MONOTONIC) || (defined(HAVE_DECL_V4L2_BUF_FLAG_TIMESTAMP_MONOTONIC) && HAVE_DECL_V4L2_BUF_FLAG_TIMESTAMP_MONOTONIC)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_BUF_FLAG_TIMESTAMP_MONOTONIC) == (0x00002000), "V4L2_BUF_FLAG_TIMESTAMP_MONOTONIC != 0x00002000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_BUF_FLAG_TIMESTAMP_MONOTONIC 0x00002000
+#endif
+#if defined(V4L2_BUF_FLAG_TIMESTAMP_COPY) || (defined(HAVE_DECL_V4L2_BUF_FLAG_TIMESTAMP_COPY) && HAVE_DECL_V4L2_BUF_FLAG_TIMESTAMP_COPY)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_BUF_FLAG_TIMESTAMP_COPY) == (0x00004000), "V4L2_BUF_FLAG_TIMESTAMP_COPY != 0x00004000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_BUF_FLAG_TIMESTAMP_COPY 0x00004000
+#endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+extern const struct xlat v4l2_buf_flags_ts_type[];
+
+# else
+
+static const struct xlat_data v4l2_buf_flags_ts_type_xdata[] = {
+
+ XLAT(V4L2_BUF_FLAG_TIMESTAMP_UNKNOWN),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_BUF_FLAG_TIMESTAMP_UNKNOWN))
+ #define XLAT_STR_0 STRINGIFY(V4L2_BUF_FLAG_TIMESTAMP_UNKNOWN)
+ XLAT(V4L2_BUF_FLAG_TIMESTAMP_MONOTONIC),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_BUF_FLAG_TIMESTAMP_MONOTONIC))
+ #define XLAT_STR_1 STRINGIFY(V4L2_BUF_FLAG_TIMESTAMP_MONOTONIC)
+ XLAT(V4L2_BUF_FLAG_TIMESTAMP_COPY),
+ #define XLAT_VAL_2 ((unsigned) (V4L2_BUF_FLAG_TIMESTAMP_COPY))
+ #define XLAT_STR_2 STRINGIFY(V4L2_BUF_FLAG_TIMESTAMP_COPY)
+};
+#  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
+static
+#  endif
+const struct xlat v4l2_buf_flags_ts_type[1] = { {
+ .data = v4l2_buf_flags_ts_type_xdata,
+ .size = ARRAY_SIZE(v4l2_buf_flags_ts_type_xdata),
+ .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
+} };
+
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+# endif /* !IN_MPERS */
+
+#endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_buf_flags_ts_type.in 5.9-0ubuntu2/xlat/v4l2_buf_flags_ts_type.in
--- 5.5-3/xlat/v4l2_buf_flags_ts_type.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_buf_flags_ts_type.in	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,4 @@
+/* V4L2_BUF_FLAG_TIMESTAMP_MASK		0x0000e000 */
+V4L2_BUF_FLAG_TIMESTAMP_UNKNOWN		0x00000000
+V4L2_BUF_FLAG_TIMESTAMP_MONOTONIC	0x00002000
+V4L2_BUF_FLAG_TIMESTAMP_COPY		0x00004000
diff -pruN 5.5-3/xlat/v4l2_buf_types.h 5.9-0ubuntu2/xlat/v4l2_buf_types.h
--- 5.5-3/xlat/v4l2_buf_types.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_buf_types.h	2020-09-24 09:18:46.000000000 +0000
@@ -112,19 +112,47 @@ extern const struct xlat v4l2_buf_types[
 
 static const struct xlat_data v4l2_buf_types_xdata[] = {
  [V4L2_BUF_TYPE_VIDEO_CAPTURE] = XLAT(V4L2_BUF_TYPE_VIDEO_CAPTURE),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_BUF_TYPE_VIDEO_CAPTURE))
+ #define XLAT_STR_0 STRINGIFY(V4L2_BUF_TYPE_VIDEO_CAPTURE)
  [V4L2_BUF_TYPE_VIDEO_OUTPUT] = XLAT(V4L2_BUF_TYPE_VIDEO_OUTPUT),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_BUF_TYPE_VIDEO_OUTPUT))
+ #define XLAT_STR_1 STRINGIFY(V4L2_BUF_TYPE_VIDEO_OUTPUT)
  [V4L2_BUF_TYPE_VIDEO_OVERLAY] = XLAT(V4L2_BUF_TYPE_VIDEO_OVERLAY),
+ #define XLAT_VAL_2 ((unsigned) (V4L2_BUF_TYPE_VIDEO_OVERLAY))
+ #define XLAT_STR_2 STRINGIFY(V4L2_BUF_TYPE_VIDEO_OVERLAY)
  [V4L2_BUF_TYPE_VBI_CAPTURE] = XLAT(V4L2_BUF_TYPE_VBI_CAPTURE),
+ #define XLAT_VAL_3 ((unsigned) (V4L2_BUF_TYPE_VBI_CAPTURE))
+ #define XLAT_STR_3 STRINGIFY(V4L2_BUF_TYPE_VBI_CAPTURE)
  [V4L2_BUF_TYPE_VBI_OUTPUT] = XLAT(V4L2_BUF_TYPE_VBI_OUTPUT),
+ #define XLAT_VAL_4 ((unsigned) (V4L2_BUF_TYPE_VBI_OUTPUT))
+ #define XLAT_STR_4 STRINGIFY(V4L2_BUF_TYPE_VBI_OUTPUT)
  [V4L2_BUF_TYPE_SLICED_VBI_CAPTURE] = XLAT(V4L2_BUF_TYPE_SLICED_VBI_CAPTURE),
+ #define XLAT_VAL_5 ((unsigned) (V4L2_BUF_TYPE_SLICED_VBI_CAPTURE))
+ #define XLAT_STR_5 STRINGIFY(V4L2_BUF_TYPE_SLICED_VBI_CAPTURE)
  [V4L2_BUF_TYPE_SLICED_VBI_OUTPUT] = XLAT(V4L2_BUF_TYPE_SLICED_VBI_OUTPUT),
+ #define XLAT_VAL_6 ((unsigned) (V4L2_BUF_TYPE_SLICED_VBI_OUTPUT))
+ #define XLAT_STR_6 STRINGIFY(V4L2_BUF_TYPE_SLICED_VBI_OUTPUT)
  [V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY] = XLAT(V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY),
+ #define XLAT_VAL_7 ((unsigned) (V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY))
+ #define XLAT_STR_7 STRINGIFY(V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY)
  [V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE] = XLAT(V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE),
+ #define XLAT_VAL_8 ((unsigned) (V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE))
+ #define XLAT_STR_8 STRINGIFY(V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE)
  [V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE] = XLAT(V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE),
+ #define XLAT_VAL_9 ((unsigned) (V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE))
+ #define XLAT_STR_9 STRINGIFY(V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE)
  [V4L2_BUF_TYPE_SDR_CAPTURE] = XLAT(V4L2_BUF_TYPE_SDR_CAPTURE),
+ #define XLAT_VAL_10 ((unsigned) (V4L2_BUF_TYPE_SDR_CAPTURE))
+ #define XLAT_STR_10 STRINGIFY(V4L2_BUF_TYPE_SDR_CAPTURE)
  [V4L2_BUF_TYPE_SDR_OUTPUT] = XLAT(V4L2_BUF_TYPE_SDR_OUTPUT),
+ #define XLAT_VAL_11 ((unsigned) (V4L2_BUF_TYPE_SDR_OUTPUT))
+ #define XLAT_STR_11 STRINGIFY(V4L2_BUF_TYPE_SDR_OUTPUT)
  [V4L2_BUF_TYPE_META_CAPTURE] = XLAT(V4L2_BUF_TYPE_META_CAPTURE),
+ #define XLAT_VAL_12 ((unsigned) (V4L2_BUF_TYPE_META_CAPTURE))
+ #define XLAT_STR_12 STRINGIFY(V4L2_BUF_TYPE_META_CAPTURE)
  [V4L2_BUF_TYPE_META_OUTPUT] = XLAT(V4L2_BUF_TYPE_META_OUTPUT),
+ #define XLAT_VAL_13 ((unsigned) (V4L2_BUF_TYPE_META_OUTPUT))
+ #define XLAT_STR_13 STRINGIFY(V4L2_BUF_TYPE_META_OUTPUT)
 
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
@@ -134,8 +162,124 @@ const struct xlat v4l2_buf_types[1] = {
  .data = v4l2_buf_types_xdata,
  .size = ARRAY_SIZE(v4l2_buf_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_buf_types.in 5.9-0ubuntu2/xlat/v4l2_buf_types.in
--- 5.5-3/xlat/v4l2_buf_types.in	2019-10-22 17:44:08.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_buf_types.in	2020-05-30 08:00:00.000000000 +0000
@@ -1,4 +1,9 @@
 #value_indexed
+#enum
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 V4L2_BUF_TYPE_VIDEO_CAPTURE		1
 V4L2_BUF_TYPE_VIDEO_OUTPUT		2
 V4L2_BUF_TYPE_VIDEO_OVERLAY		3
diff -pruN 5.5-3/xlat/v4l2_buf_types.m4 5.9-0ubuntu2/xlat/v4l2_buf_types.m4
--- 5.5-3/xlat/v4l2_buf_types.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_buf_types.m4	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,23 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/v4l2_buf_types.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_v4l2_buf_types],[
+AC_CHECK_DECLS(m4_normalize([
+V4L2_BUF_TYPE_VIDEO_CAPTURE,
+V4L2_BUF_TYPE_VIDEO_OUTPUT,
+V4L2_BUF_TYPE_VIDEO_OVERLAY,
+V4L2_BUF_TYPE_VBI_CAPTURE,
+V4L2_BUF_TYPE_VBI_OUTPUT,
+V4L2_BUF_TYPE_SLICED_VBI_CAPTURE,
+V4L2_BUF_TYPE_SLICED_VBI_OUTPUT,
+V4L2_BUF_TYPE_VIDEO_OUTPUT_OVERLAY,
+V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE,
+V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE,
+V4L2_BUF_TYPE_SDR_CAPTURE,
+V4L2_BUF_TYPE_SDR_OUTPUT,
+V4L2_BUF_TYPE_META_CAPTURE,
+V4L2_BUF_TYPE_META_OUTPUT
+]),,, [
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+])])])
diff -pruN 5.5-3/xlat/v4l2_capture_modes.h 5.9-0ubuntu2/xlat/v4l2_capture_modes.h
--- 5.5-3/xlat/v4l2_capture_modes.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_capture_modes.h	2020-09-24 09:18:46.000000000 +0000
@@ -21,6 +21,8 @@ extern const struct xlat v4l2_capture_mo
 
 static const struct xlat_data v4l2_capture_modes_xdata[] = {
  XLAT(V4L2_MODE_HIGHQUALITY),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_MODE_HIGHQUALITY))
+ #define XLAT_STR_0 STRINGIFY(V4L2_MODE_HIGHQUALITY)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -29,8 +31,20 @@ const struct xlat v4l2_capture_modes[1]
  .data = v4l2_capture_modes_xdata,
  .size = ARRAY_SIZE(v4l2_capture_modes_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_colorspaces.h 5.9-0ubuntu2/xlat/v4l2_colorspaces.h
--- 5.5-3/xlat/v4l2_colorspaces.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_colorspaces.h	2020-09-24 09:18:46.000000000 +0000
@@ -105,18 +105,44 @@ extern const struct xlat v4l2_colorspace
 
 static const struct xlat_data v4l2_colorspaces_xdata[] = {
  [V4L2_COLORSPACE_DEFAULT] = XLAT(V4L2_COLORSPACE_DEFAULT),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_COLORSPACE_DEFAULT))
+ #define XLAT_STR_0 STRINGIFY(V4L2_COLORSPACE_DEFAULT)
  [V4L2_COLORSPACE_SMPTE170M] = XLAT(V4L2_COLORSPACE_SMPTE170M),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_COLORSPACE_SMPTE170M))
+ #define XLAT_STR_1 STRINGIFY(V4L2_COLORSPACE_SMPTE170M)
  [V4L2_COLORSPACE_SMPTE240M] = XLAT(V4L2_COLORSPACE_SMPTE240M),
+ #define XLAT_VAL_2 ((unsigned) (V4L2_COLORSPACE_SMPTE240M))
+ #define XLAT_STR_2 STRINGIFY(V4L2_COLORSPACE_SMPTE240M)
  [V4L2_COLORSPACE_REC709] = XLAT(V4L2_COLORSPACE_REC709),
+ #define XLAT_VAL_3 ((unsigned) (V4L2_COLORSPACE_REC709))
+ #define XLAT_STR_3 STRINGIFY(V4L2_COLORSPACE_REC709)
  [V4L2_COLORSPACE_BT878] = XLAT(V4L2_COLORSPACE_BT878),
+ #define XLAT_VAL_4 ((unsigned) (V4L2_COLORSPACE_BT878))
+ #define XLAT_STR_4 STRINGIFY(V4L2_COLORSPACE_BT878)
  [V4L2_COLORSPACE_470_SYSTEM_M] = XLAT(V4L2_COLORSPACE_470_SYSTEM_M),
+ #define XLAT_VAL_5 ((unsigned) (V4L2_COLORSPACE_470_SYSTEM_M))
+ #define XLAT_STR_5 STRINGIFY(V4L2_COLORSPACE_470_SYSTEM_M)
  [V4L2_COLORSPACE_470_SYSTEM_BG] = XLAT(V4L2_COLORSPACE_470_SYSTEM_BG),
+ #define XLAT_VAL_6 ((unsigned) (V4L2_COLORSPACE_470_SYSTEM_BG))
+ #define XLAT_STR_6 STRINGIFY(V4L2_COLORSPACE_470_SYSTEM_BG)
  [V4L2_COLORSPACE_JPEG] = XLAT(V4L2_COLORSPACE_JPEG),
+ #define XLAT_VAL_7 ((unsigned) (V4L2_COLORSPACE_JPEG))
+ #define XLAT_STR_7 STRINGIFY(V4L2_COLORSPACE_JPEG)
  [V4L2_COLORSPACE_SRGB] = XLAT(V4L2_COLORSPACE_SRGB),
+ #define XLAT_VAL_8 ((unsigned) (V4L2_COLORSPACE_SRGB))
+ #define XLAT_STR_8 STRINGIFY(V4L2_COLORSPACE_SRGB)
  [V4L2_COLORSPACE_OPRGB] = XLAT(V4L2_COLORSPACE_OPRGB),
+ #define XLAT_VAL_9 ((unsigned) (V4L2_COLORSPACE_OPRGB))
+ #define XLAT_STR_9 STRINGIFY(V4L2_COLORSPACE_OPRGB)
  [V4L2_COLORSPACE_BT2020] = XLAT(V4L2_COLORSPACE_BT2020),
+ #define XLAT_VAL_10 ((unsigned) (V4L2_COLORSPACE_BT2020))
+ #define XLAT_STR_10 STRINGIFY(V4L2_COLORSPACE_BT2020)
  [V4L2_COLORSPACE_RAW] = XLAT(V4L2_COLORSPACE_RAW),
+ #define XLAT_VAL_11 ((unsigned) (V4L2_COLORSPACE_RAW))
+ #define XLAT_STR_11 STRINGIFY(V4L2_COLORSPACE_RAW)
  [V4L2_COLORSPACE_DCI_P3] = XLAT(V4L2_COLORSPACE_DCI_P3),
+ #define XLAT_VAL_12 ((unsigned) (V4L2_COLORSPACE_DCI_P3))
+ #define XLAT_STR_12 STRINGIFY(V4L2_COLORSPACE_DCI_P3)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -125,8 +151,116 @@ const struct xlat v4l2_colorspaces[1] =
  .data = v4l2_colorspaces_xdata,
  .size = ARRAY_SIZE(v4l2_colorspaces_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_colorspaces.in 5.9-0ubuntu2/xlat/v4l2_colorspaces.in
--- 5.5-3/xlat/v4l2_colorspaces.in	2019-10-22 17:44:08.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_colorspaces.in	2020-05-30 08:00:00.000000000 +0000
@@ -1,4 +1,9 @@
 #value_indexed
+#enum
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 V4L2_COLORSPACE_DEFAULT		0
 V4L2_COLORSPACE_SMPTE170M	1
 V4L2_COLORSPACE_SMPTE240M	2
diff -pruN 5.5-3/xlat/v4l2_colorspaces.m4 5.9-0ubuntu2/xlat/v4l2_colorspaces.m4
--- 5.5-3/xlat/v4l2_colorspaces.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_colorspaces.m4	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,22 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/v4l2_colorspaces.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_v4l2_colorspaces],[
+AC_CHECK_DECLS(m4_normalize([
+V4L2_COLORSPACE_DEFAULT,
+V4L2_COLORSPACE_SMPTE170M,
+V4L2_COLORSPACE_SMPTE240M,
+V4L2_COLORSPACE_REC709,
+V4L2_COLORSPACE_BT878,
+V4L2_COLORSPACE_470_SYSTEM_M,
+V4L2_COLORSPACE_470_SYSTEM_BG,
+V4L2_COLORSPACE_JPEG,
+V4L2_COLORSPACE_SRGB,
+V4L2_COLORSPACE_OPRGB,
+V4L2_COLORSPACE_BT2020,
+V4L2_COLORSPACE_RAW,
+V4L2_COLORSPACE_DCI_P3
+]),,, [
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+])])])
diff -pruN 5.5-3/xlat/v4l2_control_classes.h 5.9-0ubuntu2/xlat/v4l2_control_classes.h
--- 5.5-3/xlat/v4l2_control_classes.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_control_classes.h	2020-09-24 09:18:46.000000000 +0000
@@ -98,17 +98,41 @@ extern const struct xlat v4l2_control_cl
 
 static const struct xlat_data v4l2_control_classes_xdata[] = {
  XLAT(V4L2_CTRL_CLASS_USER),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_CTRL_CLASS_USER))
+ #define XLAT_STR_0 STRINGIFY(V4L2_CTRL_CLASS_USER)
  XLAT(V4L2_CTRL_CLASS_MPEG),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_CTRL_CLASS_MPEG))
+ #define XLAT_STR_1 STRINGIFY(V4L2_CTRL_CLASS_MPEG)
  XLAT(V4L2_CTRL_CLASS_CAMERA),
+ #define XLAT_VAL_2 ((unsigned) (V4L2_CTRL_CLASS_CAMERA))
+ #define XLAT_STR_2 STRINGIFY(V4L2_CTRL_CLASS_CAMERA)
  XLAT(V4L2_CTRL_CLASS_FM_TX),
+ #define XLAT_VAL_3 ((unsigned) (V4L2_CTRL_CLASS_FM_TX))
+ #define XLAT_STR_3 STRINGIFY(V4L2_CTRL_CLASS_FM_TX)
  XLAT(V4L2_CTRL_CLASS_FLASH),
+ #define XLAT_VAL_4 ((unsigned) (V4L2_CTRL_CLASS_FLASH))
+ #define XLAT_STR_4 STRINGIFY(V4L2_CTRL_CLASS_FLASH)
  XLAT(V4L2_CTRL_CLASS_JPEG),
+ #define XLAT_VAL_5 ((unsigned) (V4L2_CTRL_CLASS_JPEG))
+ #define XLAT_STR_5 STRINGIFY(V4L2_CTRL_CLASS_JPEG)
  XLAT(V4L2_CTRL_CLASS_IMAGE_SOURCE),
+ #define XLAT_VAL_6 ((unsigned) (V4L2_CTRL_CLASS_IMAGE_SOURCE))
+ #define XLAT_STR_6 STRINGIFY(V4L2_CTRL_CLASS_IMAGE_SOURCE)
  XLAT(V4L2_CTRL_CLASS_IMAGE_PROC),
+ #define XLAT_VAL_7 ((unsigned) (V4L2_CTRL_CLASS_IMAGE_PROC))
+ #define XLAT_STR_7 STRINGIFY(V4L2_CTRL_CLASS_IMAGE_PROC)
  XLAT(V4L2_CTRL_CLASS_DV),
+ #define XLAT_VAL_8 ((unsigned) (V4L2_CTRL_CLASS_DV))
+ #define XLAT_STR_8 STRINGIFY(V4L2_CTRL_CLASS_DV)
  XLAT(V4L2_CTRL_CLASS_FM_RX),
+ #define XLAT_VAL_9 ((unsigned) (V4L2_CTRL_CLASS_FM_RX))
+ #define XLAT_STR_9 STRINGIFY(V4L2_CTRL_CLASS_FM_RX)
  XLAT(V4L2_CTRL_CLASS_RF_TUNER),
+ #define XLAT_VAL_10 ((unsigned) (V4L2_CTRL_CLASS_RF_TUNER))
+ #define XLAT_STR_10 STRINGIFY(V4L2_CTRL_CLASS_RF_TUNER)
  XLAT(V4L2_CTRL_CLASS_DETECT),
+ #define XLAT_VAL_11 ((unsigned) (V4L2_CTRL_CLASS_DETECT))
+ #define XLAT_STR_11 STRINGIFY(V4L2_CTRL_CLASS_DETECT)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -117,8 +141,108 @@ const struct xlat v4l2_control_classes[1
  .data = v4l2_control_classes_xdata,
  .size = ARRAY_SIZE(v4l2_control_classes_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_control_flags.h 5.9-0ubuntu2/xlat/v4l2_control_flags.h
--- 5.5-3/xlat/v4l2_control_flags.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_control_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -91,16 +91,38 @@ extern const struct xlat v4l2_control_fl
 
 static const struct xlat_data v4l2_control_flags_xdata[] = {
  XLAT(V4L2_CTRL_FLAG_DISABLED),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_CTRL_FLAG_DISABLED))
+ #define XLAT_STR_0 STRINGIFY(V4L2_CTRL_FLAG_DISABLED)
  XLAT(V4L2_CTRL_FLAG_GRABBED),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_CTRL_FLAG_GRABBED))
+ #define XLAT_STR_1 STRINGIFY(V4L2_CTRL_FLAG_GRABBED)
  XLAT(V4L2_CTRL_FLAG_READ_ONLY),
+ #define XLAT_VAL_2 ((unsigned) (V4L2_CTRL_FLAG_READ_ONLY))
+ #define XLAT_STR_2 STRINGIFY(V4L2_CTRL_FLAG_READ_ONLY)
  XLAT(V4L2_CTRL_FLAG_UPDATE),
+ #define XLAT_VAL_3 ((unsigned) (V4L2_CTRL_FLAG_UPDATE))
+ #define XLAT_STR_3 STRINGIFY(V4L2_CTRL_FLAG_UPDATE)
  XLAT(V4L2_CTRL_FLAG_INACTIVE),
+ #define XLAT_VAL_4 ((unsigned) (V4L2_CTRL_FLAG_INACTIVE))
+ #define XLAT_STR_4 STRINGIFY(V4L2_CTRL_FLAG_INACTIVE)
  XLAT(V4L2_CTRL_FLAG_SLIDER),
+ #define XLAT_VAL_5 ((unsigned) (V4L2_CTRL_FLAG_SLIDER))
+ #define XLAT_STR_5 STRINGIFY(V4L2_CTRL_FLAG_SLIDER)
  XLAT(V4L2_CTRL_FLAG_WRITE_ONLY),
+ #define XLAT_VAL_6 ((unsigned) (V4L2_CTRL_FLAG_WRITE_ONLY))
+ #define XLAT_STR_6 STRINGIFY(V4L2_CTRL_FLAG_WRITE_ONLY)
  XLAT(V4L2_CTRL_FLAG_VOLATILE),
+ #define XLAT_VAL_7 ((unsigned) (V4L2_CTRL_FLAG_VOLATILE))
+ #define XLAT_STR_7 STRINGIFY(V4L2_CTRL_FLAG_VOLATILE)
  XLAT(V4L2_CTRL_FLAG_HAS_PAYLOAD),
+ #define XLAT_VAL_8 ((unsigned) (V4L2_CTRL_FLAG_HAS_PAYLOAD))
+ #define XLAT_STR_8 STRINGIFY(V4L2_CTRL_FLAG_HAS_PAYLOAD)
  XLAT(V4L2_CTRL_FLAG_EXECUTE_ON_WRITE),
+ #define XLAT_VAL_9 ((unsigned) (V4L2_CTRL_FLAG_EXECUTE_ON_WRITE))
+ #define XLAT_STR_9 STRINGIFY(V4L2_CTRL_FLAG_EXECUTE_ON_WRITE)
  XLAT(V4L2_CTRL_FLAG_MODIFY_LAYOUT),
+ #define XLAT_VAL_10 ((unsigned) (V4L2_CTRL_FLAG_MODIFY_LAYOUT))
+ #define XLAT_STR_10 STRINGIFY(V4L2_CTRL_FLAG_MODIFY_LAYOUT)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -109,8 +131,100 @@ const struct xlat v4l2_control_flags[1]
  .data = v4l2_control_flags_xdata,
  .size = ARRAY_SIZE(v4l2_control_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_control_id_bases.h 5.9-0ubuntu2/xlat/v4l2_control_id_bases.h
--- 5.5-3/xlat/v4l2_control_id_bases.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_control_id_bases.h	2020-09-24 09:18:46.000000000 +0000
@@ -84,6 +84,13 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define V4L2_CID_USER_IMX_BASE (V4L2_CID_BASE | 0x10b0)
 #endif
+#if defined(V4L2_CID_USER_ATMEL_ISC_BASE) || (defined(HAVE_DECL_V4L2_CID_USER_ATMEL_ISC_BASE) && HAVE_DECL_V4L2_CID_USER_ATMEL_ISC_BASE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_CID_USER_ATMEL_ISC_BASE) == ((V4L2_CID_BASE | 0x10c0)), "V4L2_CID_USER_ATMEL_ISC_BASE != (V4L2_CID_BASE | 0x10c0)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_CID_USER_ATMEL_ISC_BASE (V4L2_CID_BASE | 0x10c0)
+#endif
 #if defined(V4L2_CID_MPEG_BASE) || (defined(HAVE_DECL_V4L2_CID_MPEG_BASE) && HAVE_DECL_V4L2_CID_MPEG_BASE)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
 static_assert((V4L2_CID_MPEG_BASE) == ((V4L2_CTRL_CLASS_MPEG | 0x900)), "V4L2_CID_MPEG_BASE != (V4L2_CTRL_CLASS_MPEG | 0x900)");
@@ -186,15 +193,35 @@ extern const struct xlat v4l2_control_id
 
 static const struct xlat_data v4l2_control_id_bases_xdata[] = {
  XLAT(V4L2_CID_BASE),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_CID_BASE))
+ #define XLAT_STR_0 STRINGIFY(V4L2_CID_BASE)
  XLAT(V4L2_CID_USER_MEYE_BASE),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_CID_USER_MEYE_BASE))
+ #define XLAT_STR_1 STRINGIFY(V4L2_CID_USER_MEYE_BASE)
  XLAT(V4L2_CID_USER_BTTV_BASE),
+ #define XLAT_VAL_2 ((unsigned) (V4L2_CID_USER_BTTV_BASE))
+ #define XLAT_STR_2 STRINGIFY(V4L2_CID_USER_BTTV_BASE)
  XLAT(V4L2_CID_USER_S2255_BASE),
+ #define XLAT_VAL_3 ((unsigned) (V4L2_CID_USER_S2255_BASE))
+ #define XLAT_STR_3 STRINGIFY(V4L2_CID_USER_S2255_BASE)
  XLAT(V4L2_CID_USER_SI476X_BASE),
+ #define XLAT_VAL_4 ((unsigned) (V4L2_CID_USER_SI476X_BASE))
+ #define XLAT_STR_4 STRINGIFY(V4L2_CID_USER_SI476X_BASE)
  XLAT(V4L2_CID_USER_TI_VPE_BASE),
+ #define XLAT_VAL_5 ((unsigned) (V4L2_CID_USER_TI_VPE_BASE))
+ #define XLAT_STR_5 STRINGIFY(V4L2_CID_USER_TI_VPE_BASE)
  XLAT(V4L2_CID_USER_SAA7134_BASE),
+ #define XLAT_VAL_6 ((unsigned) (V4L2_CID_USER_SAA7134_BASE))
+ #define XLAT_STR_6 STRINGIFY(V4L2_CID_USER_SAA7134_BASE)
  XLAT(V4L2_CID_USER_ADV7180_BASE),
+ #define XLAT_VAL_7 ((unsigned) (V4L2_CID_USER_ADV7180_BASE))
+ #define XLAT_STR_7 STRINGIFY(V4L2_CID_USER_ADV7180_BASE)
  XLAT(V4L2_CID_USER_TC358743_BASE),
+ #define XLAT_VAL_8 ((unsigned) (V4L2_CID_USER_TC358743_BASE))
+ #define XLAT_STR_8 STRINGIFY(V4L2_CID_USER_TC358743_BASE)
  XLAT(V4L2_CID_USER_MAX217X_BASE),
+ #define XLAT_VAL_9 ((unsigned) (V4L2_CID_USER_MAX217X_BASE))
+ #define XLAT_STR_9 STRINGIFY(V4L2_CID_USER_MAX217X_BASE)
 #ifndef STRACE_WORKAROUND_FOR_V4L2_CID_USER_IMX_BASE
 # define STRACE_WORKAROUND_FOR_V4L2_CID_USER_IMX_BASE
 /*
@@ -211,19 +238,50 @@ static const struct xlat_data v4l2_contr
 # undef V4L2_CID_USER_IMX_BASE
 #endif
  XLAT(V4L2_CID_USER_IMX_BASE),
+ #define XLAT_VAL_10 ((unsigned) (V4L2_CID_USER_IMX_BASE))
+ #define XLAT_STR_10 STRINGIFY(V4L2_CID_USER_IMX_BASE)
+ XLAT(V4L2_CID_USER_ATMEL_ISC_BASE),
+ #define XLAT_VAL_11 ((unsigned) (V4L2_CID_USER_ATMEL_ISC_BASE))
+ #define XLAT_STR_11 STRINGIFY(V4L2_CID_USER_ATMEL_ISC_BASE)
  XLAT(V4L2_CID_MPEG_BASE),
+ #define XLAT_VAL_12 ((unsigned) (V4L2_CID_MPEG_BASE))
+ #define XLAT_STR_12 STRINGIFY(V4L2_CID_MPEG_BASE)
  XLAT(V4L2_CID_MPEG_CX2341X_BASE),
+ #define XLAT_VAL_13 ((unsigned) (V4L2_CID_MPEG_CX2341X_BASE))
+ #define XLAT_STR_13 STRINGIFY(V4L2_CID_MPEG_CX2341X_BASE)
  XLAT(V4L2_CID_MPEG_MFC51_BASE),
+ #define XLAT_VAL_14 ((unsigned) (V4L2_CID_MPEG_MFC51_BASE))
+ #define XLAT_STR_14 STRINGIFY(V4L2_CID_MPEG_MFC51_BASE)
  XLAT(V4L2_CID_CAMERA_CLASS_BASE),
+ #define XLAT_VAL_15 ((unsigned) (V4L2_CID_CAMERA_CLASS_BASE))
+ #define XLAT_STR_15 STRINGIFY(V4L2_CID_CAMERA_CLASS_BASE)
  XLAT(V4L2_CID_FM_TX_CLASS_BASE),
+ #define XLAT_VAL_16 ((unsigned) (V4L2_CID_FM_TX_CLASS_BASE))
+ #define XLAT_STR_16 STRINGIFY(V4L2_CID_FM_TX_CLASS_BASE)
  XLAT(V4L2_CID_FLASH_CLASS_BASE),
+ #define XLAT_VAL_17 ((unsigned) (V4L2_CID_FLASH_CLASS_BASE))
+ #define XLAT_STR_17 STRINGIFY(V4L2_CID_FLASH_CLASS_BASE)
  XLAT(V4L2_CID_JPEG_CLASS_BASE),
+ #define XLAT_VAL_18 ((unsigned) (V4L2_CID_JPEG_CLASS_BASE))
+ #define XLAT_STR_18 STRINGIFY(V4L2_CID_JPEG_CLASS_BASE)
  XLAT(V4L2_CID_IMAGE_SOURCE_CLASS_BASE),
+ #define XLAT_VAL_19 ((unsigned) (V4L2_CID_IMAGE_SOURCE_CLASS_BASE))
+ #define XLAT_STR_19 STRINGIFY(V4L2_CID_IMAGE_SOURCE_CLASS_BASE)
  XLAT(V4L2_CID_IMAGE_PROC_CLASS_BASE),
+ #define XLAT_VAL_20 ((unsigned) (V4L2_CID_IMAGE_PROC_CLASS_BASE))
+ #define XLAT_STR_20 STRINGIFY(V4L2_CID_IMAGE_PROC_CLASS_BASE)
  XLAT(V4L2_CID_DV_CLASS_BASE),
+ #define XLAT_VAL_21 ((unsigned) (V4L2_CID_DV_CLASS_BASE))
+ #define XLAT_STR_21 STRINGIFY(V4L2_CID_DV_CLASS_BASE)
  XLAT(V4L2_CID_FM_RX_CLASS_BASE),
+ #define XLAT_VAL_22 ((unsigned) (V4L2_CID_FM_RX_CLASS_BASE))
+ #define XLAT_STR_22 STRINGIFY(V4L2_CID_FM_RX_CLASS_BASE)
  XLAT(V4L2_CID_RF_TUNER_CLASS_BASE),
+ #define XLAT_VAL_23 ((unsigned) (V4L2_CID_RF_TUNER_CLASS_BASE))
+ #define XLAT_STR_23 STRINGIFY(V4L2_CID_RF_TUNER_CLASS_BASE)
  XLAT(V4L2_CID_DETECT_CLASS_BASE),
+ #define XLAT_VAL_24 ((unsigned) (V4L2_CID_DETECT_CLASS_BASE))
+ #define XLAT_STR_24 STRINGIFY(V4L2_CID_DETECT_CLASS_BASE)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -232,8 +290,212 @@ const struct xlat v4l2_control_id_bases[
  .data = v4l2_control_id_bases_xdata,
  .size = ARRAY_SIZE(v4l2_control_id_bases_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_control_id_bases.in 5.9-0ubuntu2/xlat/v4l2_control_id_bases.in
--- 5.5-3/xlat/v4l2_control_id_bases.in	2018-08-19 10:26:18.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_control_id_bases.in	2020-04-15 13:39:57.000000000 +0000
@@ -24,6 +24,7 @@ V4L2_CID_USER_MAX217X_BASE		(V4L2_CID_BA
 # undef V4L2_CID_USER_IMX_BASE
 #endif
 V4L2_CID_USER_IMX_BASE			(V4L2_CID_BASE | 0x10b0)
+V4L2_CID_USER_ATMEL_ISC_BASE		(V4L2_CID_BASE | 0x10c0)
 V4L2_CID_MPEG_BASE			(V4L2_CTRL_CLASS_MPEG | 0x900)
 V4L2_CID_MPEG_CX2341X_BASE		(V4L2_CTRL_CLASS_MPEG | 0x1000)
 V4L2_CID_MPEG_MFC51_BASE		(V4L2_CTRL_CLASS_MPEG | 0x1100)
diff -pruN 5.5-3/xlat/v4l2_control_ids.h 5.9-0ubuntu2/xlat/v4l2_control_ids.h
--- 5.5-3/xlat/v4l2_control_ids.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_control_ids.h	2020-09-24 09:18:48.000000000 +0000
@@ -2430,365 +2430,1055 @@ extern const struct xlat v4l2_control_id
 static const struct xlat_data v4l2_control_ids_xdata[] = {
 
  XLAT(V4L2_CID_BRIGHTNESS),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_CID_BRIGHTNESS))
+ #define XLAT_STR_0 STRINGIFY(V4L2_CID_BRIGHTNESS)
  XLAT(V4L2_CID_CONTRAST),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_CID_CONTRAST))
+ #define XLAT_STR_1 STRINGIFY(V4L2_CID_CONTRAST)
  XLAT(V4L2_CID_SATURATION),
+ #define XLAT_VAL_2 ((unsigned) (V4L2_CID_SATURATION))
+ #define XLAT_STR_2 STRINGIFY(V4L2_CID_SATURATION)
  XLAT(V4L2_CID_HUE),
+ #define XLAT_VAL_3 ((unsigned) (V4L2_CID_HUE))
+ #define XLAT_STR_3 STRINGIFY(V4L2_CID_HUE)
  XLAT(V4L2_CID_AUDIO_VOLUME),
+ #define XLAT_VAL_4 ((unsigned) (V4L2_CID_AUDIO_VOLUME))
+ #define XLAT_STR_4 STRINGIFY(V4L2_CID_AUDIO_VOLUME)
  XLAT(V4L2_CID_AUDIO_BALANCE),
+ #define XLAT_VAL_5 ((unsigned) (V4L2_CID_AUDIO_BALANCE))
+ #define XLAT_STR_5 STRINGIFY(V4L2_CID_AUDIO_BALANCE)
  XLAT(V4L2_CID_AUDIO_BASS),
+ #define XLAT_VAL_6 ((unsigned) (V4L2_CID_AUDIO_BASS))
+ #define XLAT_STR_6 STRINGIFY(V4L2_CID_AUDIO_BASS)
  XLAT(V4L2_CID_AUDIO_TREBLE),
+ #define XLAT_VAL_7 ((unsigned) (V4L2_CID_AUDIO_TREBLE))
+ #define XLAT_STR_7 STRINGIFY(V4L2_CID_AUDIO_TREBLE)
  XLAT(V4L2_CID_AUDIO_MUTE),
+ #define XLAT_VAL_8 ((unsigned) (V4L2_CID_AUDIO_MUTE))
+ #define XLAT_STR_8 STRINGIFY(V4L2_CID_AUDIO_MUTE)
  XLAT(V4L2_CID_AUDIO_LOUDNESS),
+ #define XLAT_VAL_9 ((unsigned) (V4L2_CID_AUDIO_LOUDNESS))
+ #define XLAT_STR_9 STRINGIFY(V4L2_CID_AUDIO_LOUDNESS)
  XLAT(V4L2_CID_BLACK_LEVEL),
+ #define XLAT_VAL_10 ((unsigned) (V4L2_CID_BLACK_LEVEL))
+ #define XLAT_STR_10 STRINGIFY(V4L2_CID_BLACK_LEVEL)
  XLAT(V4L2_CID_AUTO_WHITE_BALANCE),
+ #define XLAT_VAL_11 ((unsigned) (V4L2_CID_AUTO_WHITE_BALANCE))
+ #define XLAT_STR_11 STRINGIFY(V4L2_CID_AUTO_WHITE_BALANCE)
  XLAT(V4L2_CID_DO_WHITE_BALANCE),
+ #define XLAT_VAL_12 ((unsigned) (V4L2_CID_DO_WHITE_BALANCE))
+ #define XLAT_STR_12 STRINGIFY(V4L2_CID_DO_WHITE_BALANCE)
  XLAT(V4L2_CID_RED_BALANCE),
+ #define XLAT_VAL_13 ((unsigned) (V4L2_CID_RED_BALANCE))
+ #define XLAT_STR_13 STRINGIFY(V4L2_CID_RED_BALANCE)
  XLAT(V4L2_CID_BLUE_BALANCE),
+ #define XLAT_VAL_14 ((unsigned) (V4L2_CID_BLUE_BALANCE))
+ #define XLAT_STR_14 STRINGIFY(V4L2_CID_BLUE_BALANCE)
  XLAT(V4L2_CID_GAMMA),
+ #define XLAT_VAL_15 ((unsigned) (V4L2_CID_GAMMA))
+ #define XLAT_STR_15 STRINGIFY(V4L2_CID_GAMMA)
  XLAT(V4L2_CID_EXPOSURE),
+ #define XLAT_VAL_16 ((unsigned) (V4L2_CID_EXPOSURE))
+ #define XLAT_STR_16 STRINGIFY(V4L2_CID_EXPOSURE)
  XLAT(V4L2_CID_AUTOGAIN),
+ #define XLAT_VAL_17 ((unsigned) (V4L2_CID_AUTOGAIN))
+ #define XLAT_STR_17 STRINGIFY(V4L2_CID_AUTOGAIN)
  XLAT(V4L2_CID_GAIN),
+ #define XLAT_VAL_18 ((unsigned) (V4L2_CID_GAIN))
+ #define XLAT_STR_18 STRINGIFY(V4L2_CID_GAIN)
  XLAT(V4L2_CID_HFLIP),
+ #define XLAT_VAL_19 ((unsigned) (V4L2_CID_HFLIP))
+ #define XLAT_STR_19 STRINGIFY(V4L2_CID_HFLIP)
  XLAT(V4L2_CID_VFLIP),
+ #define XLAT_VAL_20 ((unsigned) (V4L2_CID_VFLIP))
+ #define XLAT_STR_20 STRINGIFY(V4L2_CID_VFLIP)
  XLAT(V4L2_CID_HCENTER),
+ #define XLAT_VAL_21 ((unsigned) (V4L2_CID_HCENTER))
+ #define XLAT_STR_21 STRINGIFY(V4L2_CID_HCENTER)
  XLAT(V4L2_CID_VCENTER),
+ #define XLAT_VAL_22 ((unsigned) (V4L2_CID_VCENTER))
+ #define XLAT_STR_22 STRINGIFY(V4L2_CID_VCENTER)
  XLAT(V4L2_CID_POWER_LINE_FREQUENCY),
+ #define XLAT_VAL_23 ((unsigned) (V4L2_CID_POWER_LINE_FREQUENCY))
+ #define XLAT_STR_23 STRINGIFY(V4L2_CID_POWER_LINE_FREQUENCY)
  XLAT(V4L2_CID_HUE_AUTO),
+ #define XLAT_VAL_24 ((unsigned) (V4L2_CID_HUE_AUTO))
+ #define XLAT_STR_24 STRINGIFY(V4L2_CID_HUE_AUTO)
  XLAT(V4L2_CID_WHITE_BALANCE_TEMPERATURE),
+ #define XLAT_VAL_25 ((unsigned) (V4L2_CID_WHITE_BALANCE_TEMPERATURE))
+ #define XLAT_STR_25 STRINGIFY(V4L2_CID_WHITE_BALANCE_TEMPERATURE)
  XLAT(V4L2_CID_SHARPNESS),
+ #define XLAT_VAL_26 ((unsigned) (V4L2_CID_SHARPNESS))
+ #define XLAT_STR_26 STRINGIFY(V4L2_CID_SHARPNESS)
  XLAT(V4L2_CID_BACKLIGHT_COMPENSATION),
+ #define XLAT_VAL_27 ((unsigned) (V4L2_CID_BACKLIGHT_COMPENSATION))
+ #define XLAT_STR_27 STRINGIFY(V4L2_CID_BACKLIGHT_COMPENSATION)
  XLAT(V4L2_CID_CHROMA_AGC),
+ #define XLAT_VAL_28 ((unsigned) (V4L2_CID_CHROMA_AGC))
+ #define XLAT_STR_28 STRINGIFY(V4L2_CID_CHROMA_AGC)
  XLAT(V4L2_CID_COLOR_KILLER),
+ #define XLAT_VAL_29 ((unsigned) (V4L2_CID_COLOR_KILLER))
+ #define XLAT_STR_29 STRINGIFY(V4L2_CID_COLOR_KILLER)
  XLAT(V4L2_CID_COLORFX),
+ #define XLAT_VAL_30 ((unsigned) (V4L2_CID_COLORFX))
+ #define XLAT_STR_30 STRINGIFY(V4L2_CID_COLORFX)
  XLAT(V4L2_CID_AUTOBRIGHTNESS),
+ #define XLAT_VAL_31 ((unsigned) (V4L2_CID_AUTOBRIGHTNESS))
+ #define XLAT_STR_31 STRINGIFY(V4L2_CID_AUTOBRIGHTNESS)
  XLAT(V4L2_CID_BAND_STOP_FILTER),
+ #define XLAT_VAL_32 ((unsigned) (V4L2_CID_BAND_STOP_FILTER))
+ #define XLAT_STR_32 STRINGIFY(V4L2_CID_BAND_STOP_FILTER)
  XLAT(V4L2_CID_ROTATE),
+ #define XLAT_VAL_33 ((unsigned) (V4L2_CID_ROTATE))
+ #define XLAT_STR_33 STRINGIFY(V4L2_CID_ROTATE)
  XLAT(V4L2_CID_BG_COLOR),
+ #define XLAT_VAL_34 ((unsigned) (V4L2_CID_BG_COLOR))
+ #define XLAT_STR_34 STRINGIFY(V4L2_CID_BG_COLOR)
  XLAT(V4L2_CID_CHROMA_GAIN),
+ #define XLAT_VAL_35 ((unsigned) (V4L2_CID_CHROMA_GAIN))
+ #define XLAT_STR_35 STRINGIFY(V4L2_CID_CHROMA_GAIN)
  XLAT(V4L2_CID_ILLUMINATORS_1),
+ #define XLAT_VAL_36 ((unsigned) (V4L2_CID_ILLUMINATORS_1))
+ #define XLAT_STR_36 STRINGIFY(V4L2_CID_ILLUMINATORS_1)
  XLAT(V4L2_CID_ILLUMINATORS_2),
+ #define XLAT_VAL_37 ((unsigned) (V4L2_CID_ILLUMINATORS_2))
+ #define XLAT_STR_37 STRINGIFY(V4L2_CID_ILLUMINATORS_2)
  XLAT(V4L2_CID_MIN_BUFFERS_FOR_CAPTURE),
+ #define XLAT_VAL_38 ((unsigned) (V4L2_CID_MIN_BUFFERS_FOR_CAPTURE))
+ #define XLAT_STR_38 STRINGIFY(V4L2_CID_MIN_BUFFERS_FOR_CAPTURE)
  XLAT(V4L2_CID_MIN_BUFFERS_FOR_OUTPUT),
+ #define XLAT_VAL_39 ((unsigned) (V4L2_CID_MIN_BUFFERS_FOR_OUTPUT))
+ #define XLAT_STR_39 STRINGIFY(V4L2_CID_MIN_BUFFERS_FOR_OUTPUT)
  XLAT(V4L2_CID_ALPHA_COMPONENT),
+ #define XLAT_VAL_40 ((unsigned) (V4L2_CID_ALPHA_COMPONENT))
+ #define XLAT_STR_40 STRINGIFY(V4L2_CID_ALPHA_COMPONENT)
  XLAT(V4L2_CID_COLORFX_CBCR),
+ #define XLAT_VAL_41 ((unsigned) (V4L2_CID_COLORFX_CBCR))
+ #define XLAT_STR_41 STRINGIFY(V4L2_CID_COLORFX_CBCR)
 
 
  XLAT(V4L2_CID_MPEG_STREAM_TYPE),
+ #define XLAT_VAL_42 ((unsigned) (V4L2_CID_MPEG_STREAM_TYPE))
+ #define XLAT_STR_42 STRINGIFY(V4L2_CID_MPEG_STREAM_TYPE)
  XLAT(V4L2_CID_MPEG_STREAM_PID_PMT),
+ #define XLAT_VAL_43 ((unsigned) (V4L2_CID_MPEG_STREAM_PID_PMT))
+ #define XLAT_STR_43 STRINGIFY(V4L2_CID_MPEG_STREAM_PID_PMT)
  XLAT(V4L2_CID_MPEG_STREAM_PID_AUDIO),
+ #define XLAT_VAL_44 ((unsigned) (V4L2_CID_MPEG_STREAM_PID_AUDIO))
+ #define XLAT_STR_44 STRINGIFY(V4L2_CID_MPEG_STREAM_PID_AUDIO)
  XLAT(V4L2_CID_MPEG_STREAM_PID_VIDEO),
+ #define XLAT_VAL_45 ((unsigned) (V4L2_CID_MPEG_STREAM_PID_VIDEO))
+ #define XLAT_STR_45 STRINGIFY(V4L2_CID_MPEG_STREAM_PID_VIDEO)
  XLAT(V4L2_CID_MPEG_STREAM_PID_PCR),
+ #define XLAT_VAL_46 ((unsigned) (V4L2_CID_MPEG_STREAM_PID_PCR))
+ #define XLAT_STR_46 STRINGIFY(V4L2_CID_MPEG_STREAM_PID_PCR)
  XLAT(V4L2_CID_MPEG_STREAM_PES_ID_AUDIO),
+ #define XLAT_VAL_47 ((unsigned) (V4L2_CID_MPEG_STREAM_PES_ID_AUDIO))
+ #define XLAT_STR_47 STRINGIFY(V4L2_CID_MPEG_STREAM_PES_ID_AUDIO)
  XLAT(V4L2_CID_MPEG_STREAM_PES_ID_VIDEO),
+ #define XLAT_VAL_48 ((unsigned) (V4L2_CID_MPEG_STREAM_PES_ID_VIDEO))
+ #define XLAT_STR_48 STRINGIFY(V4L2_CID_MPEG_STREAM_PES_ID_VIDEO)
  XLAT(V4L2_CID_MPEG_STREAM_VBI_FMT),
+ #define XLAT_VAL_49 ((unsigned) (V4L2_CID_MPEG_STREAM_VBI_FMT))
+ #define XLAT_STR_49 STRINGIFY(V4L2_CID_MPEG_STREAM_VBI_FMT)
 
  XLAT(V4L2_CID_MPEG_AUDIO_SAMPLING_FREQ),
+ #define XLAT_VAL_50 ((unsigned) (V4L2_CID_MPEG_AUDIO_SAMPLING_FREQ))
+ #define XLAT_STR_50 STRINGIFY(V4L2_CID_MPEG_AUDIO_SAMPLING_FREQ)
  XLAT(V4L2_CID_MPEG_AUDIO_ENCODING),
+ #define XLAT_VAL_51 ((unsigned) (V4L2_CID_MPEG_AUDIO_ENCODING))
+ #define XLAT_STR_51 STRINGIFY(V4L2_CID_MPEG_AUDIO_ENCODING)
  XLAT(V4L2_CID_MPEG_AUDIO_L1_BITRATE),
+ #define XLAT_VAL_52 ((unsigned) (V4L2_CID_MPEG_AUDIO_L1_BITRATE))
+ #define XLAT_STR_52 STRINGIFY(V4L2_CID_MPEG_AUDIO_L1_BITRATE)
  XLAT(V4L2_CID_MPEG_AUDIO_L2_BITRATE),
+ #define XLAT_VAL_53 ((unsigned) (V4L2_CID_MPEG_AUDIO_L2_BITRATE))
+ #define XLAT_STR_53 STRINGIFY(V4L2_CID_MPEG_AUDIO_L2_BITRATE)
  XLAT(V4L2_CID_MPEG_AUDIO_L3_BITRATE),
+ #define XLAT_VAL_54 ((unsigned) (V4L2_CID_MPEG_AUDIO_L3_BITRATE))
+ #define XLAT_STR_54 STRINGIFY(V4L2_CID_MPEG_AUDIO_L3_BITRATE)
  XLAT(V4L2_CID_MPEG_AUDIO_MODE),
+ #define XLAT_VAL_55 ((unsigned) (V4L2_CID_MPEG_AUDIO_MODE))
+ #define XLAT_STR_55 STRINGIFY(V4L2_CID_MPEG_AUDIO_MODE)
  XLAT(V4L2_CID_MPEG_AUDIO_MODE_EXTENSION),
+ #define XLAT_VAL_56 ((unsigned) (V4L2_CID_MPEG_AUDIO_MODE_EXTENSION))
+ #define XLAT_STR_56 STRINGIFY(V4L2_CID_MPEG_AUDIO_MODE_EXTENSION)
  XLAT(V4L2_CID_MPEG_AUDIO_EMPHASIS),
+ #define XLAT_VAL_57 ((unsigned) (V4L2_CID_MPEG_AUDIO_EMPHASIS))
+ #define XLAT_STR_57 STRINGIFY(V4L2_CID_MPEG_AUDIO_EMPHASIS)
  XLAT(V4L2_CID_MPEG_AUDIO_CRC),
+ #define XLAT_VAL_58 ((unsigned) (V4L2_CID_MPEG_AUDIO_CRC))
+ #define XLAT_STR_58 STRINGIFY(V4L2_CID_MPEG_AUDIO_CRC)
  XLAT(V4L2_CID_MPEG_AUDIO_MUTE),
+ #define XLAT_VAL_59 ((unsigned) (V4L2_CID_MPEG_AUDIO_MUTE))
+ #define XLAT_STR_59 STRINGIFY(V4L2_CID_MPEG_AUDIO_MUTE)
  XLAT(V4L2_CID_MPEG_AUDIO_AAC_BITRATE),
+ #define XLAT_VAL_60 ((unsigned) (V4L2_CID_MPEG_AUDIO_AAC_BITRATE))
+ #define XLAT_STR_60 STRINGIFY(V4L2_CID_MPEG_AUDIO_AAC_BITRATE)
  XLAT(V4L2_CID_MPEG_AUDIO_AC3_BITRATE),
+ #define XLAT_VAL_61 ((unsigned) (V4L2_CID_MPEG_AUDIO_AC3_BITRATE))
+ #define XLAT_STR_61 STRINGIFY(V4L2_CID_MPEG_AUDIO_AC3_BITRATE)
  XLAT(V4L2_CID_MPEG_AUDIO_DEC_PLAYBACK),
+ #define XLAT_VAL_62 ((unsigned) (V4L2_CID_MPEG_AUDIO_DEC_PLAYBACK))
+ #define XLAT_STR_62 STRINGIFY(V4L2_CID_MPEG_AUDIO_DEC_PLAYBACK)
  XLAT(V4L2_CID_MPEG_AUDIO_DEC_MULTILINGUAL_PLAYBACK),
+ #define XLAT_VAL_63 ((unsigned) (V4L2_CID_MPEG_AUDIO_DEC_MULTILINGUAL_PLAYBACK))
+ #define XLAT_STR_63 STRINGIFY(V4L2_CID_MPEG_AUDIO_DEC_MULTILINGUAL_PLAYBACK)
 
  XLAT(V4L2_CID_MPEG_VIDEO_ENCODING),
+ #define XLAT_VAL_64 ((unsigned) (V4L2_CID_MPEG_VIDEO_ENCODING))
+ #define XLAT_STR_64 STRINGIFY(V4L2_CID_MPEG_VIDEO_ENCODING)
  XLAT(V4L2_CID_MPEG_VIDEO_ASPECT),
+ #define XLAT_VAL_65 ((unsigned) (V4L2_CID_MPEG_VIDEO_ASPECT))
+ #define XLAT_STR_65 STRINGIFY(V4L2_CID_MPEG_VIDEO_ASPECT)
  XLAT(V4L2_CID_MPEG_VIDEO_B_FRAMES),
+ #define XLAT_VAL_66 ((unsigned) (V4L2_CID_MPEG_VIDEO_B_FRAMES))
+ #define XLAT_STR_66 STRINGIFY(V4L2_CID_MPEG_VIDEO_B_FRAMES)
  XLAT(V4L2_CID_MPEG_VIDEO_GOP_SIZE),
+ #define XLAT_VAL_67 ((unsigned) (V4L2_CID_MPEG_VIDEO_GOP_SIZE))
+ #define XLAT_STR_67 STRINGIFY(V4L2_CID_MPEG_VIDEO_GOP_SIZE)
  XLAT(V4L2_CID_MPEG_VIDEO_GOP_CLOSURE),
+ #define XLAT_VAL_68 ((unsigned) (V4L2_CID_MPEG_VIDEO_GOP_CLOSURE))
+ #define XLAT_STR_68 STRINGIFY(V4L2_CID_MPEG_VIDEO_GOP_CLOSURE)
  XLAT(V4L2_CID_MPEG_VIDEO_PULLDOWN),
+ #define XLAT_VAL_69 ((unsigned) (V4L2_CID_MPEG_VIDEO_PULLDOWN))
+ #define XLAT_STR_69 STRINGIFY(V4L2_CID_MPEG_VIDEO_PULLDOWN)
  XLAT(V4L2_CID_MPEG_VIDEO_BITRATE_MODE),
+ #define XLAT_VAL_70 ((unsigned) (V4L2_CID_MPEG_VIDEO_BITRATE_MODE))
+ #define XLAT_STR_70 STRINGIFY(V4L2_CID_MPEG_VIDEO_BITRATE_MODE)
  XLAT(V4L2_CID_MPEG_VIDEO_BITRATE),
+ #define XLAT_VAL_71 ((unsigned) (V4L2_CID_MPEG_VIDEO_BITRATE))
+ #define XLAT_STR_71 STRINGIFY(V4L2_CID_MPEG_VIDEO_BITRATE)
  XLAT(V4L2_CID_MPEG_VIDEO_BITRATE_PEAK),
+ #define XLAT_VAL_72 ((unsigned) (V4L2_CID_MPEG_VIDEO_BITRATE_PEAK))
+ #define XLAT_STR_72 STRINGIFY(V4L2_CID_MPEG_VIDEO_BITRATE_PEAK)
  XLAT(V4L2_CID_MPEG_VIDEO_TEMPORAL_DECIMATION),
+ #define XLAT_VAL_73 ((unsigned) (V4L2_CID_MPEG_VIDEO_TEMPORAL_DECIMATION))
+ #define XLAT_STR_73 STRINGIFY(V4L2_CID_MPEG_VIDEO_TEMPORAL_DECIMATION)
  XLAT(V4L2_CID_MPEG_VIDEO_MUTE),
+ #define XLAT_VAL_74 ((unsigned) (V4L2_CID_MPEG_VIDEO_MUTE))
+ #define XLAT_STR_74 STRINGIFY(V4L2_CID_MPEG_VIDEO_MUTE)
  XLAT(V4L2_CID_MPEG_VIDEO_MUTE_YUV),
+ #define XLAT_VAL_75 ((unsigned) (V4L2_CID_MPEG_VIDEO_MUTE_YUV))
+ #define XLAT_STR_75 STRINGIFY(V4L2_CID_MPEG_VIDEO_MUTE_YUV)
  XLAT(V4L2_CID_MPEG_VIDEO_DECODER_SLICE_INTERFACE),
+ #define XLAT_VAL_76 ((unsigned) (V4L2_CID_MPEG_VIDEO_DECODER_SLICE_INTERFACE))
+ #define XLAT_STR_76 STRINGIFY(V4L2_CID_MPEG_VIDEO_DECODER_SLICE_INTERFACE)
  XLAT(V4L2_CID_MPEG_VIDEO_DECODER_MPEG4_DEBLOCK_FILTER),
+ #define XLAT_VAL_77 ((unsigned) (V4L2_CID_MPEG_VIDEO_DECODER_MPEG4_DEBLOCK_FILTER))
+ #define XLAT_STR_77 STRINGIFY(V4L2_CID_MPEG_VIDEO_DECODER_MPEG4_DEBLOCK_FILTER)
  XLAT(V4L2_CID_MPEG_VIDEO_CYCLIC_INTRA_REFRESH_MB),
+ #define XLAT_VAL_78 ((unsigned) (V4L2_CID_MPEG_VIDEO_CYCLIC_INTRA_REFRESH_MB))
+ #define XLAT_STR_78 STRINGIFY(V4L2_CID_MPEG_VIDEO_CYCLIC_INTRA_REFRESH_MB)
  XLAT(V4L2_CID_MPEG_VIDEO_FRAME_RC_ENABLE),
+ #define XLAT_VAL_79 ((unsigned) (V4L2_CID_MPEG_VIDEO_FRAME_RC_ENABLE))
+ #define XLAT_STR_79 STRINGIFY(V4L2_CID_MPEG_VIDEO_FRAME_RC_ENABLE)
  XLAT(V4L2_CID_MPEG_VIDEO_HEADER_MODE),
+ #define XLAT_VAL_80 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEADER_MODE))
+ #define XLAT_STR_80 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEADER_MODE)
  XLAT(V4L2_CID_MPEG_VIDEO_MAX_REF_PIC),
+ #define XLAT_VAL_81 ((unsigned) (V4L2_CID_MPEG_VIDEO_MAX_REF_PIC))
+ #define XLAT_STR_81 STRINGIFY(V4L2_CID_MPEG_VIDEO_MAX_REF_PIC)
  XLAT(V4L2_CID_MPEG_VIDEO_MB_RC_ENABLE),
+ #define XLAT_VAL_82 ((unsigned) (V4L2_CID_MPEG_VIDEO_MB_RC_ENABLE))
+ #define XLAT_STR_82 STRINGIFY(V4L2_CID_MPEG_VIDEO_MB_RC_ENABLE)
  XLAT(V4L2_CID_MPEG_VIDEO_MULTI_SLICE_MAX_BYTES),
+ #define XLAT_VAL_83 ((unsigned) (V4L2_CID_MPEG_VIDEO_MULTI_SLICE_MAX_BYTES))
+ #define XLAT_STR_83 STRINGIFY(V4L2_CID_MPEG_VIDEO_MULTI_SLICE_MAX_BYTES)
  XLAT(V4L2_CID_MPEG_VIDEO_MULTI_SLICE_MAX_MB),
+ #define XLAT_VAL_84 ((unsigned) (V4L2_CID_MPEG_VIDEO_MULTI_SLICE_MAX_MB))
+ #define XLAT_STR_84 STRINGIFY(V4L2_CID_MPEG_VIDEO_MULTI_SLICE_MAX_MB)
  XLAT(V4L2_CID_MPEG_VIDEO_MULTI_SLICE_MODE),
+ #define XLAT_VAL_85 ((unsigned) (V4L2_CID_MPEG_VIDEO_MULTI_SLICE_MODE))
+ #define XLAT_STR_85 STRINGIFY(V4L2_CID_MPEG_VIDEO_MULTI_SLICE_MODE)
  XLAT(V4L2_CID_MPEG_VIDEO_VBV_SIZE),
+ #define XLAT_VAL_86 ((unsigned) (V4L2_CID_MPEG_VIDEO_VBV_SIZE))
+ #define XLAT_STR_86 STRINGIFY(V4L2_CID_MPEG_VIDEO_VBV_SIZE)
  XLAT(V4L2_CID_MPEG_VIDEO_DEC_PTS),
+ #define XLAT_VAL_87 ((unsigned) (V4L2_CID_MPEG_VIDEO_DEC_PTS))
+ #define XLAT_STR_87 STRINGIFY(V4L2_CID_MPEG_VIDEO_DEC_PTS)
  XLAT(V4L2_CID_MPEG_VIDEO_DEC_FRAME),
+ #define XLAT_VAL_88 ((unsigned) (V4L2_CID_MPEG_VIDEO_DEC_FRAME))
+ #define XLAT_STR_88 STRINGIFY(V4L2_CID_MPEG_VIDEO_DEC_FRAME)
  XLAT(V4L2_CID_MPEG_VIDEO_VBV_DELAY),
+ #define XLAT_VAL_89 ((unsigned) (V4L2_CID_MPEG_VIDEO_VBV_DELAY))
+ #define XLAT_STR_89 STRINGIFY(V4L2_CID_MPEG_VIDEO_VBV_DELAY)
  XLAT(V4L2_CID_MPEG_VIDEO_REPEAT_SEQ_HEADER),
+ #define XLAT_VAL_90 ((unsigned) (V4L2_CID_MPEG_VIDEO_REPEAT_SEQ_HEADER))
+ #define XLAT_STR_90 STRINGIFY(V4L2_CID_MPEG_VIDEO_REPEAT_SEQ_HEADER)
  XLAT(V4L2_CID_MPEG_VIDEO_MV_H_SEARCH_RANGE),
+ #define XLAT_VAL_91 ((unsigned) (V4L2_CID_MPEG_VIDEO_MV_H_SEARCH_RANGE))
+ #define XLAT_STR_91 STRINGIFY(V4L2_CID_MPEG_VIDEO_MV_H_SEARCH_RANGE)
  XLAT(V4L2_CID_MPEG_VIDEO_MV_V_SEARCH_RANGE),
+ #define XLAT_VAL_92 ((unsigned) (V4L2_CID_MPEG_VIDEO_MV_V_SEARCH_RANGE))
+ #define XLAT_STR_92 STRINGIFY(V4L2_CID_MPEG_VIDEO_MV_V_SEARCH_RANGE)
  XLAT(V4L2_CID_MPEG_VIDEO_FORCE_KEY_FRAME),
+ #define XLAT_VAL_93 ((unsigned) (V4L2_CID_MPEG_VIDEO_FORCE_KEY_FRAME))
+ #define XLAT_STR_93 STRINGIFY(V4L2_CID_MPEG_VIDEO_FORCE_KEY_FRAME)
  XLAT(V4L2_CID_MPEG_VIDEO_MPEG2_SLICE_PARAMS),
+ #define XLAT_VAL_94 ((unsigned) (V4L2_CID_MPEG_VIDEO_MPEG2_SLICE_PARAMS))
+ #define XLAT_STR_94 STRINGIFY(V4L2_CID_MPEG_VIDEO_MPEG2_SLICE_PARAMS)
  XLAT(V4L2_CID_MPEG_VIDEO_MPEG2_QUANTIZATION),
+ #define XLAT_VAL_95 ((unsigned) (V4L2_CID_MPEG_VIDEO_MPEG2_QUANTIZATION))
+ #define XLAT_STR_95 STRINGIFY(V4L2_CID_MPEG_VIDEO_MPEG2_QUANTIZATION)
  XLAT(V4L2_CID_FWHT_I_FRAME_QP),
+ #define XLAT_VAL_96 ((unsigned) (V4L2_CID_FWHT_I_FRAME_QP))
+ #define XLAT_STR_96 STRINGIFY(V4L2_CID_FWHT_I_FRAME_QP)
  XLAT(V4L2_CID_FWHT_P_FRAME_QP),
+ #define XLAT_VAL_97 ((unsigned) (V4L2_CID_FWHT_P_FRAME_QP))
+ #define XLAT_STR_97 STRINGIFY(V4L2_CID_FWHT_P_FRAME_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_H263_I_FRAME_QP),
+ #define XLAT_VAL_98 ((unsigned) (V4L2_CID_MPEG_VIDEO_H263_I_FRAME_QP))
+ #define XLAT_STR_98 STRINGIFY(V4L2_CID_MPEG_VIDEO_H263_I_FRAME_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_H263_P_FRAME_QP),
+ #define XLAT_VAL_99 ((unsigned) (V4L2_CID_MPEG_VIDEO_H263_P_FRAME_QP))
+ #define XLAT_STR_99 STRINGIFY(V4L2_CID_MPEG_VIDEO_H263_P_FRAME_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_H263_B_FRAME_QP),
+ #define XLAT_VAL_100 ((unsigned) (V4L2_CID_MPEG_VIDEO_H263_B_FRAME_QP))
+ #define XLAT_STR_100 STRINGIFY(V4L2_CID_MPEG_VIDEO_H263_B_FRAME_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_H263_MIN_QP),
+ #define XLAT_VAL_101 ((unsigned) (V4L2_CID_MPEG_VIDEO_H263_MIN_QP))
+ #define XLAT_STR_101 STRINGIFY(V4L2_CID_MPEG_VIDEO_H263_MIN_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_H263_MAX_QP),
+ #define XLAT_VAL_102 ((unsigned) (V4L2_CID_MPEG_VIDEO_H263_MAX_QP))
+ #define XLAT_STR_102 STRINGIFY(V4L2_CID_MPEG_VIDEO_H263_MAX_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_I_FRAME_QP),
+ #define XLAT_VAL_103 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_I_FRAME_QP))
+ #define XLAT_STR_103 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_I_FRAME_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_P_FRAME_QP),
+ #define XLAT_VAL_104 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_P_FRAME_QP))
+ #define XLAT_STR_104 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_P_FRAME_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_B_FRAME_QP),
+ #define XLAT_VAL_105 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_B_FRAME_QP))
+ #define XLAT_STR_105 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_B_FRAME_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_MIN_QP),
+ #define XLAT_VAL_106 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_MIN_QP))
+ #define XLAT_STR_106 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_MIN_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_MAX_QP),
+ #define XLAT_VAL_107 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_MAX_QP))
+ #define XLAT_STR_107 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_MAX_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_8X8_TRANSFORM),
+ #define XLAT_VAL_108 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_8X8_TRANSFORM))
+ #define XLAT_STR_108 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_8X8_TRANSFORM)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_CPB_SIZE),
+ #define XLAT_VAL_109 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_CPB_SIZE))
+ #define XLAT_STR_109 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_CPB_SIZE)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_ENTROPY_MODE),
+ #define XLAT_VAL_110 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_ENTROPY_MODE))
+ #define XLAT_STR_110 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_ENTROPY_MODE)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_I_PERIOD),
+ #define XLAT_VAL_111 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_I_PERIOD))
+ #define XLAT_STR_111 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_I_PERIOD)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_LEVEL),
+ #define XLAT_VAL_112 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_LEVEL))
+ #define XLAT_STR_112 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_LEVEL)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_LOOP_FILTER_ALPHA),
+ #define XLAT_VAL_113 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_LOOP_FILTER_ALPHA))
+ #define XLAT_STR_113 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_LOOP_FILTER_ALPHA)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_LOOP_FILTER_BETA),
+ #define XLAT_VAL_114 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_LOOP_FILTER_BETA))
+ #define XLAT_STR_114 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_LOOP_FILTER_BETA)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_LOOP_FILTER_MODE),
+ #define XLAT_VAL_115 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_LOOP_FILTER_MODE))
+ #define XLAT_STR_115 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_LOOP_FILTER_MODE)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_PROFILE),
+ #define XLAT_VAL_116 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_PROFILE))
+ #define XLAT_STR_116 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_PROFILE)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_VUI_EXT_SAR_HEIGHT),
+ #define XLAT_VAL_117 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_VUI_EXT_SAR_HEIGHT))
+ #define XLAT_STR_117 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_VUI_EXT_SAR_HEIGHT)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_VUI_EXT_SAR_WIDTH),
+ #define XLAT_VAL_118 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_VUI_EXT_SAR_WIDTH))
+ #define XLAT_STR_118 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_VUI_EXT_SAR_WIDTH)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_VUI_SAR_ENABLE),
+ #define XLAT_VAL_119 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_VUI_SAR_ENABLE))
+ #define XLAT_STR_119 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_VUI_SAR_ENABLE)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_VUI_SAR_IDC),
+ #define XLAT_VAL_120 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_VUI_SAR_IDC))
+ #define XLAT_STR_120 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_VUI_SAR_IDC)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_SEI_FRAME_PACKING),
+ #define XLAT_VAL_121 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_SEI_FRAME_PACKING))
+ #define XLAT_STR_121 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_SEI_FRAME_PACKING)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_SEI_FP_CURRENT_FRAME_0),
+ #define XLAT_VAL_122 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_SEI_FP_CURRENT_FRAME_0))
+ #define XLAT_STR_122 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_SEI_FP_CURRENT_FRAME_0)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_SEI_FP_ARRANGEMENT_TYPE),
+ #define XLAT_VAL_123 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_SEI_FP_ARRANGEMENT_TYPE))
+ #define XLAT_STR_123 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_SEI_FP_ARRANGEMENT_TYPE)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_FMO),
+ #define XLAT_VAL_124 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_FMO))
+ #define XLAT_STR_124 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_FMO)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_FMO_MAP_TYPE),
+ #define XLAT_VAL_125 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_FMO_MAP_TYPE))
+ #define XLAT_STR_125 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_FMO_MAP_TYPE)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_FMO_SLICE_GROUP),
+ #define XLAT_VAL_126 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_FMO_SLICE_GROUP))
+ #define XLAT_STR_126 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_FMO_SLICE_GROUP)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_FMO_CHANGE_DIRECTION),
+ #define XLAT_VAL_127 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_FMO_CHANGE_DIRECTION))
+ #define XLAT_STR_127 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_FMO_CHANGE_DIRECTION)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_FMO_CHANGE_RATE),
+ #define XLAT_VAL_128 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_FMO_CHANGE_RATE))
+ #define XLAT_STR_128 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_FMO_CHANGE_RATE)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_FMO_RUN_LENGTH),
+ #define XLAT_VAL_129 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_FMO_RUN_LENGTH))
+ #define XLAT_STR_129 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_FMO_RUN_LENGTH)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_ASO),
+ #define XLAT_VAL_130 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_ASO))
+ #define XLAT_STR_130 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_ASO)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_ASO_SLICE_ORDER),
+ #define XLAT_VAL_131 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_ASO_SLICE_ORDER))
+ #define XLAT_STR_131 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_ASO_SLICE_ORDER)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_HIERARCHICAL_CODING),
+ #define XLAT_VAL_132 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_HIERARCHICAL_CODING))
+ #define XLAT_STR_132 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_HIERARCHICAL_CODING)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_HIERARCHICAL_CODING_TYPE),
+ #define XLAT_VAL_133 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_HIERARCHICAL_CODING_TYPE))
+ #define XLAT_STR_133 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_HIERARCHICAL_CODING_TYPE)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_HIERARCHICAL_CODING_LAYER),
+ #define XLAT_VAL_134 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_HIERARCHICAL_CODING_LAYER))
+ #define XLAT_STR_134 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_HIERARCHICAL_CODING_LAYER)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_HIERARCHICAL_CODING_LAYER_QP),
+ #define XLAT_VAL_135 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_HIERARCHICAL_CODING_LAYER_QP))
+ #define XLAT_STR_135 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_HIERARCHICAL_CODING_LAYER_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_CONSTRAINED_INTRA_PREDICTION),
+ #define XLAT_VAL_136 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_CONSTRAINED_INTRA_PREDICTION))
+ #define XLAT_STR_136 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_CONSTRAINED_INTRA_PREDICTION)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_CHROMA_QP_INDEX_OFFSET),
+ #define XLAT_VAL_137 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_CHROMA_QP_INDEX_OFFSET))
+ #define XLAT_STR_137 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_CHROMA_QP_INDEX_OFFSET)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_I_FRAME_MIN_QP),
+ #define XLAT_VAL_138 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_I_FRAME_MIN_QP))
+ #define XLAT_STR_138 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_I_FRAME_MIN_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_I_FRAME_MAX_QP),
+ #define XLAT_VAL_139 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_I_FRAME_MAX_QP))
+ #define XLAT_STR_139 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_I_FRAME_MAX_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_P_FRAME_MIN_QP),
+ #define XLAT_VAL_140 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_P_FRAME_MIN_QP))
+ #define XLAT_STR_140 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_P_FRAME_MIN_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_H264_P_FRAME_MAX_QP),
+ #define XLAT_VAL_141 ((unsigned) (V4L2_CID_MPEG_VIDEO_H264_P_FRAME_MAX_QP))
+ #define XLAT_STR_141 STRINGIFY(V4L2_CID_MPEG_VIDEO_H264_P_FRAME_MAX_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_MPEG4_I_FRAME_QP),
+ #define XLAT_VAL_142 ((unsigned) (V4L2_CID_MPEG_VIDEO_MPEG4_I_FRAME_QP))
+ #define XLAT_STR_142 STRINGIFY(V4L2_CID_MPEG_VIDEO_MPEG4_I_FRAME_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_MPEG4_P_FRAME_QP),
+ #define XLAT_VAL_143 ((unsigned) (V4L2_CID_MPEG_VIDEO_MPEG4_P_FRAME_QP))
+ #define XLAT_STR_143 STRINGIFY(V4L2_CID_MPEG_VIDEO_MPEG4_P_FRAME_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_MPEG4_B_FRAME_QP),
+ #define XLAT_VAL_144 ((unsigned) (V4L2_CID_MPEG_VIDEO_MPEG4_B_FRAME_QP))
+ #define XLAT_STR_144 STRINGIFY(V4L2_CID_MPEG_VIDEO_MPEG4_B_FRAME_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_MPEG4_MIN_QP),
+ #define XLAT_VAL_145 ((unsigned) (V4L2_CID_MPEG_VIDEO_MPEG4_MIN_QP))
+ #define XLAT_STR_145 STRINGIFY(V4L2_CID_MPEG_VIDEO_MPEG4_MIN_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_MPEG4_MAX_QP),
+ #define XLAT_VAL_146 ((unsigned) (V4L2_CID_MPEG_VIDEO_MPEG4_MAX_QP))
+ #define XLAT_STR_146 STRINGIFY(V4L2_CID_MPEG_VIDEO_MPEG4_MAX_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_MPEG4_LEVEL),
+ #define XLAT_VAL_147 ((unsigned) (V4L2_CID_MPEG_VIDEO_MPEG4_LEVEL))
+ #define XLAT_STR_147 STRINGIFY(V4L2_CID_MPEG_VIDEO_MPEG4_LEVEL)
  XLAT(V4L2_CID_MPEG_VIDEO_MPEG4_PROFILE),
+ #define XLAT_VAL_148 ((unsigned) (V4L2_CID_MPEG_VIDEO_MPEG4_PROFILE))
+ #define XLAT_STR_148 STRINGIFY(V4L2_CID_MPEG_VIDEO_MPEG4_PROFILE)
  XLAT(V4L2_CID_MPEG_VIDEO_MPEG4_QPEL),
+ #define XLAT_VAL_149 ((unsigned) (V4L2_CID_MPEG_VIDEO_MPEG4_QPEL))
+ #define XLAT_STR_149 STRINGIFY(V4L2_CID_MPEG_VIDEO_MPEG4_QPEL)
 
  XLAT(V4L2_CID_MPEG_VIDEO_VPX_NUM_PARTITIONS),
+ #define XLAT_VAL_150 ((unsigned) (V4L2_CID_MPEG_VIDEO_VPX_NUM_PARTITIONS))
+ #define XLAT_STR_150 STRINGIFY(V4L2_CID_MPEG_VIDEO_VPX_NUM_PARTITIONS)
  XLAT(V4L2_CID_MPEG_VIDEO_VPX_IMD_DISABLE_4X4),
+ #define XLAT_VAL_151 ((unsigned) (V4L2_CID_MPEG_VIDEO_VPX_IMD_DISABLE_4X4))
+ #define XLAT_STR_151 STRINGIFY(V4L2_CID_MPEG_VIDEO_VPX_IMD_DISABLE_4X4)
  XLAT(V4L2_CID_MPEG_VIDEO_VPX_NUM_REF_FRAMES),
+ #define XLAT_VAL_152 ((unsigned) (V4L2_CID_MPEG_VIDEO_VPX_NUM_REF_FRAMES))
+ #define XLAT_STR_152 STRINGIFY(V4L2_CID_MPEG_VIDEO_VPX_NUM_REF_FRAMES)
  XLAT(V4L2_CID_MPEG_VIDEO_VPX_FILTER_LEVEL),
+ #define XLAT_VAL_153 ((unsigned) (V4L2_CID_MPEG_VIDEO_VPX_FILTER_LEVEL))
+ #define XLAT_STR_153 STRINGIFY(V4L2_CID_MPEG_VIDEO_VPX_FILTER_LEVEL)
  XLAT(V4L2_CID_MPEG_VIDEO_VPX_FILTER_SHARPNESS),
+ #define XLAT_VAL_154 ((unsigned) (V4L2_CID_MPEG_VIDEO_VPX_FILTER_SHARPNESS))
+ #define XLAT_STR_154 STRINGIFY(V4L2_CID_MPEG_VIDEO_VPX_FILTER_SHARPNESS)
  XLAT(V4L2_CID_MPEG_VIDEO_VPX_GOLDEN_FRAME_REF_PERIOD),
+ #define XLAT_VAL_155 ((unsigned) (V4L2_CID_MPEG_VIDEO_VPX_GOLDEN_FRAME_REF_PERIOD))
+ #define XLAT_STR_155 STRINGIFY(V4L2_CID_MPEG_VIDEO_VPX_GOLDEN_FRAME_REF_PERIOD)
  XLAT(V4L2_CID_MPEG_VIDEO_VPX_GOLDEN_FRAME_SEL),
+ #define XLAT_VAL_156 ((unsigned) (V4L2_CID_MPEG_VIDEO_VPX_GOLDEN_FRAME_SEL))
+ #define XLAT_STR_156 STRINGIFY(V4L2_CID_MPEG_VIDEO_VPX_GOLDEN_FRAME_SEL)
  XLAT(V4L2_CID_MPEG_VIDEO_VPX_MIN_QP),
+ #define XLAT_VAL_157 ((unsigned) (V4L2_CID_MPEG_VIDEO_VPX_MIN_QP))
+ #define XLAT_STR_157 STRINGIFY(V4L2_CID_MPEG_VIDEO_VPX_MIN_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_VPX_MAX_QP),
+ #define XLAT_VAL_158 ((unsigned) (V4L2_CID_MPEG_VIDEO_VPX_MAX_QP))
+ #define XLAT_STR_158 STRINGIFY(V4L2_CID_MPEG_VIDEO_VPX_MAX_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_VPX_I_FRAME_QP),
+ #define XLAT_VAL_159 ((unsigned) (V4L2_CID_MPEG_VIDEO_VPX_I_FRAME_QP))
+ #define XLAT_STR_159 STRINGIFY(V4L2_CID_MPEG_VIDEO_VPX_I_FRAME_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_VPX_P_FRAME_QP),
+ #define XLAT_VAL_160 ((unsigned) (V4L2_CID_MPEG_VIDEO_VPX_P_FRAME_QP))
+ #define XLAT_STR_160 STRINGIFY(V4L2_CID_MPEG_VIDEO_VPX_P_FRAME_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_VP8_PROFILE),
+ #define XLAT_VAL_161 ((unsigned) (V4L2_CID_MPEG_VIDEO_VP8_PROFILE))
+ #define XLAT_STR_161 STRINGIFY(V4L2_CID_MPEG_VIDEO_VP8_PROFILE)
  XLAT(V4L2_CID_MPEG_VIDEO_VP9_PROFILE),
+ #define XLAT_VAL_162 ((unsigned) (V4L2_CID_MPEG_VIDEO_VP9_PROFILE))
+ #define XLAT_STR_162 STRINGIFY(V4L2_CID_MPEG_VIDEO_VP9_PROFILE)
 
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_MIN_QP),
+ #define XLAT_VAL_163 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_MIN_QP))
+ #define XLAT_STR_163 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_MIN_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_MAX_QP),
+ #define XLAT_VAL_164 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_MAX_QP))
+ #define XLAT_STR_164 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_MAX_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_I_FRAME_QP),
+ #define XLAT_VAL_165 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_I_FRAME_QP))
+ #define XLAT_STR_165 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_I_FRAME_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_P_FRAME_QP),
+ #define XLAT_VAL_166 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_P_FRAME_QP))
+ #define XLAT_STR_166 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_P_FRAME_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_B_FRAME_QP),
+ #define XLAT_VAL_167 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_B_FRAME_QP))
+ #define XLAT_STR_167 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_B_FRAME_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_HIER_QP),
+ #define XLAT_VAL_168 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_HIER_QP))
+ #define XLAT_STR_168 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_HIER_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_TYPE),
+ #define XLAT_VAL_169 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_TYPE))
+ #define XLAT_STR_169 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_TYPE)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_LAYER),
+ #define XLAT_VAL_170 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_LAYER))
+ #define XLAT_STR_170 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_LAYER)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L0_QP),
+ #define XLAT_VAL_171 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L0_QP))
+ #define XLAT_STR_171 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L0_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L1_QP),
+ #define XLAT_VAL_172 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L1_QP))
+ #define XLAT_STR_172 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L1_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L2_QP),
+ #define XLAT_VAL_173 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L2_QP))
+ #define XLAT_STR_173 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L2_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L3_QP),
+ #define XLAT_VAL_174 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L3_QP))
+ #define XLAT_STR_174 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L3_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L4_QP),
+ #define XLAT_VAL_175 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L4_QP))
+ #define XLAT_STR_175 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L4_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L5_QP),
+ #define XLAT_VAL_176 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L5_QP))
+ #define XLAT_STR_176 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L5_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L6_QP),
+ #define XLAT_VAL_177 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L6_QP))
+ #define XLAT_STR_177 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L6_QP)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_PROFILE),
+ #define XLAT_VAL_178 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_PROFILE))
+ #define XLAT_STR_178 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_PROFILE)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_LEVEL),
+ #define XLAT_VAL_179 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_LEVEL))
+ #define XLAT_STR_179 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_LEVEL)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_FRAME_RATE_RESOLUTION),
+ #define XLAT_VAL_180 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_FRAME_RATE_RESOLUTION))
+ #define XLAT_STR_180 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_FRAME_RATE_RESOLUTION)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_TIER),
+ #define XLAT_VAL_181 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_TIER))
+ #define XLAT_STR_181 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_TIER)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_MAX_PARTITION_DEPTH),
+ #define XLAT_VAL_182 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_MAX_PARTITION_DEPTH))
+ #define XLAT_STR_182 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_MAX_PARTITION_DEPTH)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_LOOP_FILTER_MODE),
+ #define XLAT_VAL_183 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_LOOP_FILTER_MODE))
+ #define XLAT_STR_183 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_LOOP_FILTER_MODE)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_LF_BETA_OFFSET_DIV2),
+ #define XLAT_VAL_184 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_LF_BETA_OFFSET_DIV2))
+ #define XLAT_STR_184 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_LF_BETA_OFFSET_DIV2)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_LF_TC_OFFSET_DIV2),
+ #define XLAT_VAL_185 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_LF_TC_OFFSET_DIV2))
+ #define XLAT_STR_185 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_LF_TC_OFFSET_DIV2)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_REFRESH_TYPE),
+ #define XLAT_VAL_186 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_REFRESH_TYPE))
+ #define XLAT_STR_186 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_REFRESH_TYPE)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_REFRESH_PERIOD),
+ #define XLAT_VAL_187 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_REFRESH_PERIOD))
+ #define XLAT_STR_187 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_REFRESH_PERIOD)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_LOSSLESS_CU),
+ #define XLAT_VAL_188 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_LOSSLESS_CU))
+ #define XLAT_STR_188 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_LOSSLESS_CU)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_CONST_INTRA_PRED),
+ #define XLAT_VAL_189 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_CONST_INTRA_PRED))
+ #define XLAT_STR_189 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_CONST_INTRA_PRED)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_WAVEFRONT),
+ #define XLAT_VAL_190 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_WAVEFRONT))
+ #define XLAT_STR_190 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_WAVEFRONT)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_GENERAL_PB),
+ #define XLAT_VAL_191 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_GENERAL_PB))
+ #define XLAT_STR_191 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_GENERAL_PB)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_TEMPORAL_ID),
+ #define XLAT_VAL_192 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_TEMPORAL_ID))
+ #define XLAT_STR_192 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_TEMPORAL_ID)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_STRONG_SMOOTHING),
+ #define XLAT_VAL_193 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_STRONG_SMOOTHING))
+ #define XLAT_STR_193 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_STRONG_SMOOTHING)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_MAX_NUM_MERGE_MV_MINUS1),
+ #define XLAT_VAL_194 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_MAX_NUM_MERGE_MV_MINUS1))
+ #define XLAT_STR_194 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_MAX_NUM_MERGE_MV_MINUS1)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_INTRA_PU_SPLIT),
+ #define XLAT_VAL_195 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_INTRA_PU_SPLIT))
+ #define XLAT_STR_195 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_INTRA_PU_SPLIT)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_TMV_PREDICTION),
+ #define XLAT_VAL_196 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_TMV_PREDICTION))
+ #define XLAT_STR_196 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_TMV_PREDICTION)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_WITHOUT_STARTCODE),
+ #define XLAT_VAL_197 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_WITHOUT_STARTCODE))
+ #define XLAT_STR_197 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_WITHOUT_STARTCODE)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_SIZE_OF_LENGTH_FIELD),
+ #define XLAT_VAL_198 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_SIZE_OF_LENGTH_FIELD))
+ #define XLAT_STR_198 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_SIZE_OF_LENGTH_FIELD)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L0_BR),
+ #define XLAT_VAL_199 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L0_BR))
+ #define XLAT_STR_199 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L0_BR)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L1_BR),
+ #define XLAT_VAL_200 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L1_BR))
+ #define XLAT_STR_200 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L1_BR)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L2_BR),
+ #define XLAT_VAL_201 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L2_BR))
+ #define XLAT_STR_201 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L2_BR)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L3_BR),
+ #define XLAT_VAL_202 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L3_BR))
+ #define XLAT_STR_202 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L3_BR)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L4_BR),
+ #define XLAT_VAL_203 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L4_BR))
+ #define XLAT_STR_203 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L4_BR)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L5_BR),
+ #define XLAT_VAL_204 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L5_BR))
+ #define XLAT_STR_204 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L5_BR)
  XLAT(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L6_BR),
+ #define XLAT_VAL_205 ((unsigned) (V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L6_BR))
+ #define XLAT_STR_205 STRINGIFY(V4L2_CID_MPEG_VIDEO_HEVC_HIER_CODING_L6_BR)
  XLAT(V4L2_CID_MPEG_VIDEO_REF_NUMBER_FOR_PFRAMES),
+ #define XLAT_VAL_206 ((unsigned) (V4L2_CID_MPEG_VIDEO_REF_NUMBER_FOR_PFRAMES))
+ #define XLAT_STR_206 STRINGIFY(V4L2_CID_MPEG_VIDEO_REF_NUMBER_FOR_PFRAMES)
  XLAT(V4L2_CID_MPEG_VIDEO_PREPEND_SPSPPS_TO_IDR),
+ #define XLAT_VAL_207 ((unsigned) (V4L2_CID_MPEG_VIDEO_PREPEND_SPSPPS_TO_IDR))
+ #define XLAT_STR_207 STRINGIFY(V4L2_CID_MPEG_VIDEO_PREPEND_SPSPPS_TO_IDR)
 
  XLAT(V4L2_CID_MPEG_CX2341X_VIDEO_SPATIAL_FILTER_MODE),
+ #define XLAT_VAL_208 ((unsigned) (V4L2_CID_MPEG_CX2341X_VIDEO_SPATIAL_FILTER_MODE))
+ #define XLAT_STR_208 STRINGIFY(V4L2_CID_MPEG_CX2341X_VIDEO_SPATIAL_FILTER_MODE)
  XLAT(V4L2_CID_MPEG_CX2341X_VIDEO_SPATIAL_FILTER),
+ #define XLAT_VAL_209 ((unsigned) (V4L2_CID_MPEG_CX2341X_VIDEO_SPATIAL_FILTER))
+ #define XLAT_STR_209 STRINGIFY(V4L2_CID_MPEG_CX2341X_VIDEO_SPATIAL_FILTER)
  XLAT(V4L2_CID_MPEG_CX2341X_VIDEO_LUMA_SPATIAL_FILTER_TYPE),
+ #define XLAT_VAL_210 ((unsigned) (V4L2_CID_MPEG_CX2341X_VIDEO_LUMA_SPATIAL_FILTER_TYPE))
+ #define XLAT_STR_210 STRINGIFY(V4L2_CID_MPEG_CX2341X_VIDEO_LUMA_SPATIAL_FILTER_TYPE)
  XLAT(V4L2_CID_MPEG_CX2341X_VIDEO_CHROMA_SPATIAL_FILTER_TYPE),
+ #define XLAT_VAL_211 ((unsigned) (V4L2_CID_MPEG_CX2341X_VIDEO_CHROMA_SPATIAL_FILTER_TYPE))
+ #define XLAT_STR_211 STRINGIFY(V4L2_CID_MPEG_CX2341X_VIDEO_CHROMA_SPATIAL_FILTER_TYPE)
  XLAT(V4L2_CID_MPEG_CX2341X_VIDEO_TEMPORAL_FILTER_MODE),
+ #define XLAT_VAL_212 ((unsigned) (V4L2_CID_MPEG_CX2341X_VIDEO_TEMPORAL_FILTER_MODE))
+ #define XLAT_STR_212 STRINGIFY(V4L2_CID_MPEG_CX2341X_VIDEO_TEMPORAL_FILTER_MODE)
  XLAT(V4L2_CID_MPEG_CX2341X_VIDEO_TEMPORAL_FILTER),
+ #define XLAT_VAL_213 ((unsigned) (V4L2_CID_MPEG_CX2341X_VIDEO_TEMPORAL_FILTER))
+ #define XLAT_STR_213 STRINGIFY(V4L2_CID_MPEG_CX2341X_VIDEO_TEMPORAL_FILTER)
  XLAT(V4L2_CID_MPEG_CX2341X_VIDEO_MEDIAN_FILTER_TYPE),
+ #define XLAT_VAL_214 ((unsigned) (V4L2_CID_MPEG_CX2341X_VIDEO_MEDIAN_FILTER_TYPE))
+ #define XLAT_STR_214 STRINGIFY(V4L2_CID_MPEG_CX2341X_VIDEO_MEDIAN_FILTER_TYPE)
  XLAT(V4L2_CID_MPEG_CX2341X_VIDEO_LUMA_MEDIAN_FILTER_BOTTOM),
+ #define XLAT_VAL_215 ((unsigned) (V4L2_CID_MPEG_CX2341X_VIDEO_LUMA_MEDIAN_FILTER_BOTTOM))
+ #define XLAT_STR_215 STRINGIFY(V4L2_CID_MPEG_CX2341X_VIDEO_LUMA_MEDIAN_FILTER_BOTTOM)
  XLAT(V4L2_CID_MPEG_CX2341X_VIDEO_LUMA_MEDIAN_FILTER_TOP),
+ #define XLAT_VAL_216 ((unsigned) (V4L2_CID_MPEG_CX2341X_VIDEO_LUMA_MEDIAN_FILTER_TOP))
+ #define XLAT_STR_216 STRINGIFY(V4L2_CID_MPEG_CX2341X_VIDEO_LUMA_MEDIAN_FILTER_TOP)
  XLAT(V4L2_CID_MPEG_CX2341X_VIDEO_CHROMA_MEDIAN_FILTER_BOTTOM),
+ #define XLAT_VAL_217 ((unsigned) (V4L2_CID_MPEG_CX2341X_VIDEO_CHROMA_MEDIAN_FILTER_BOTTOM))
+ #define XLAT_STR_217 STRINGIFY(V4L2_CID_MPEG_CX2341X_VIDEO_CHROMA_MEDIAN_FILTER_BOTTOM)
  XLAT(V4L2_CID_MPEG_CX2341X_VIDEO_CHROMA_MEDIAN_FILTER_TOP),
+ #define XLAT_VAL_218 ((unsigned) (V4L2_CID_MPEG_CX2341X_VIDEO_CHROMA_MEDIAN_FILTER_TOP))
+ #define XLAT_STR_218 STRINGIFY(V4L2_CID_MPEG_CX2341X_VIDEO_CHROMA_MEDIAN_FILTER_TOP)
  XLAT(V4L2_CID_MPEG_CX2341X_STREAM_INSERT_NAV_PACKETS),
+ #define XLAT_VAL_219 ((unsigned) (V4L2_CID_MPEG_CX2341X_STREAM_INSERT_NAV_PACKETS))
+ #define XLAT_STR_219 STRINGIFY(V4L2_CID_MPEG_CX2341X_STREAM_INSERT_NAV_PACKETS)
 
  XLAT(V4L2_CID_MPEG_MFC51_VIDEO_DECODER_H264_DISPLAY_DELAY),
+ #define XLAT_VAL_220 ((unsigned) (V4L2_CID_MPEG_MFC51_VIDEO_DECODER_H264_DISPLAY_DELAY))
+ #define XLAT_STR_220 STRINGIFY(V4L2_CID_MPEG_MFC51_VIDEO_DECODER_H264_DISPLAY_DELAY)
  XLAT(V4L2_CID_MPEG_MFC51_VIDEO_DECODER_H264_DISPLAY_DELAY_ENABLE),
+ #define XLAT_VAL_221 ((unsigned) (V4L2_CID_MPEG_MFC51_VIDEO_DECODER_H264_DISPLAY_DELAY_ENABLE))
+ #define XLAT_STR_221 STRINGIFY(V4L2_CID_MPEG_MFC51_VIDEO_DECODER_H264_DISPLAY_DELAY_ENABLE)
  XLAT(V4L2_CID_MPEG_MFC51_VIDEO_FRAME_SKIP_MODE),
+ #define XLAT_VAL_222 ((unsigned) (V4L2_CID_MPEG_MFC51_VIDEO_FRAME_SKIP_MODE))
+ #define XLAT_STR_222 STRINGIFY(V4L2_CID_MPEG_MFC51_VIDEO_FRAME_SKIP_MODE)
  XLAT(V4L2_CID_MPEG_MFC51_VIDEO_FORCE_FRAME_TYPE),
+ #define XLAT_VAL_223 ((unsigned) (V4L2_CID_MPEG_MFC51_VIDEO_FORCE_FRAME_TYPE))
+ #define XLAT_STR_223 STRINGIFY(V4L2_CID_MPEG_MFC51_VIDEO_FORCE_FRAME_TYPE)
  XLAT(V4L2_CID_MPEG_MFC51_VIDEO_PADDING),
+ #define XLAT_VAL_224 ((unsigned) (V4L2_CID_MPEG_MFC51_VIDEO_PADDING))
+ #define XLAT_STR_224 STRINGIFY(V4L2_CID_MPEG_MFC51_VIDEO_PADDING)
  XLAT(V4L2_CID_MPEG_MFC51_VIDEO_PADDING_YUV),
+ #define XLAT_VAL_225 ((unsigned) (V4L2_CID_MPEG_MFC51_VIDEO_PADDING_YUV))
+ #define XLAT_STR_225 STRINGIFY(V4L2_CID_MPEG_MFC51_VIDEO_PADDING_YUV)
  XLAT(V4L2_CID_MPEG_MFC51_VIDEO_RC_FIXED_TARGET_BIT),
+ #define XLAT_VAL_226 ((unsigned) (V4L2_CID_MPEG_MFC51_VIDEO_RC_FIXED_TARGET_BIT))
+ #define XLAT_STR_226 STRINGIFY(V4L2_CID_MPEG_MFC51_VIDEO_RC_FIXED_TARGET_BIT)
  XLAT(V4L2_CID_MPEG_MFC51_VIDEO_RC_REACTION_COEFF),
+ #define XLAT_VAL_227 ((unsigned) (V4L2_CID_MPEG_MFC51_VIDEO_RC_REACTION_COEFF))
+ #define XLAT_STR_227 STRINGIFY(V4L2_CID_MPEG_MFC51_VIDEO_RC_REACTION_COEFF)
  XLAT(V4L2_CID_MPEG_MFC51_VIDEO_H264_ADAPTIVE_RC_ACTIVITY),
+ #define XLAT_VAL_228 ((unsigned) (V4L2_CID_MPEG_MFC51_VIDEO_H264_ADAPTIVE_RC_ACTIVITY))
+ #define XLAT_STR_228 STRINGIFY(V4L2_CID_MPEG_MFC51_VIDEO_H264_ADAPTIVE_RC_ACTIVITY)
  XLAT(V4L2_CID_MPEG_MFC51_VIDEO_H264_ADAPTIVE_RC_DARK),
+ #define XLAT_VAL_229 ((unsigned) (V4L2_CID_MPEG_MFC51_VIDEO_H264_ADAPTIVE_RC_DARK))
+ #define XLAT_STR_229 STRINGIFY(V4L2_CID_MPEG_MFC51_VIDEO_H264_ADAPTIVE_RC_DARK)
  XLAT(V4L2_CID_MPEG_MFC51_VIDEO_H264_ADAPTIVE_RC_SMOOTH),
+ #define XLAT_VAL_230 ((unsigned) (V4L2_CID_MPEG_MFC51_VIDEO_H264_ADAPTIVE_RC_SMOOTH))
+ #define XLAT_STR_230 STRINGIFY(V4L2_CID_MPEG_MFC51_VIDEO_H264_ADAPTIVE_RC_SMOOTH)
  XLAT(V4L2_CID_MPEG_MFC51_VIDEO_H264_ADAPTIVE_RC_STATIC),
+ #define XLAT_VAL_231 ((unsigned) (V4L2_CID_MPEG_MFC51_VIDEO_H264_ADAPTIVE_RC_STATIC))
+ #define XLAT_STR_231 STRINGIFY(V4L2_CID_MPEG_MFC51_VIDEO_H264_ADAPTIVE_RC_STATIC)
  XLAT(V4L2_CID_MPEG_MFC51_VIDEO_H264_NUM_REF_PIC_FOR_P),
+ #define XLAT_VAL_232 ((unsigned) (V4L2_CID_MPEG_MFC51_VIDEO_H264_NUM_REF_PIC_FOR_P))
+ #define XLAT_STR_232 STRINGIFY(V4L2_CID_MPEG_MFC51_VIDEO_H264_NUM_REF_PIC_FOR_P)
 
  XLAT(V4L2_CID_EXPOSURE_AUTO),
+ #define XLAT_VAL_233 ((unsigned) (V4L2_CID_EXPOSURE_AUTO))
+ #define XLAT_STR_233 STRINGIFY(V4L2_CID_EXPOSURE_AUTO)
  XLAT(V4L2_CID_EXPOSURE_ABSOLUTE),
+ #define XLAT_VAL_234 ((unsigned) (V4L2_CID_EXPOSURE_ABSOLUTE))
+ #define XLAT_STR_234 STRINGIFY(V4L2_CID_EXPOSURE_ABSOLUTE)
  XLAT(V4L2_CID_EXPOSURE_AUTO_PRIORITY),
+ #define XLAT_VAL_235 ((unsigned) (V4L2_CID_EXPOSURE_AUTO_PRIORITY))
+ #define XLAT_STR_235 STRINGIFY(V4L2_CID_EXPOSURE_AUTO_PRIORITY)
  XLAT(V4L2_CID_PAN_RELATIVE),
+ #define XLAT_VAL_236 ((unsigned) (V4L2_CID_PAN_RELATIVE))
+ #define XLAT_STR_236 STRINGIFY(V4L2_CID_PAN_RELATIVE)
  XLAT(V4L2_CID_TILT_RELATIVE),
+ #define XLAT_VAL_237 ((unsigned) (V4L2_CID_TILT_RELATIVE))
+ #define XLAT_STR_237 STRINGIFY(V4L2_CID_TILT_RELATIVE)
  XLAT(V4L2_CID_PAN_RESET),
+ #define XLAT_VAL_238 ((unsigned) (V4L2_CID_PAN_RESET))
+ #define XLAT_STR_238 STRINGIFY(V4L2_CID_PAN_RESET)
  XLAT(V4L2_CID_TILT_RESET),
+ #define XLAT_VAL_239 ((unsigned) (V4L2_CID_TILT_RESET))
+ #define XLAT_STR_239 STRINGIFY(V4L2_CID_TILT_RESET)
  XLAT(V4L2_CID_PAN_ABSOLUTE),
+ #define XLAT_VAL_240 ((unsigned) (V4L2_CID_PAN_ABSOLUTE))
+ #define XLAT_STR_240 STRINGIFY(V4L2_CID_PAN_ABSOLUTE)
  XLAT(V4L2_CID_TILT_ABSOLUTE),
+ #define XLAT_VAL_241 ((unsigned) (V4L2_CID_TILT_ABSOLUTE))
+ #define XLAT_STR_241 STRINGIFY(V4L2_CID_TILT_ABSOLUTE)
  XLAT(V4L2_CID_FOCUS_ABSOLUTE),
+ #define XLAT_VAL_242 ((unsigned) (V4L2_CID_FOCUS_ABSOLUTE))
+ #define XLAT_STR_242 STRINGIFY(V4L2_CID_FOCUS_ABSOLUTE)
  XLAT(V4L2_CID_FOCUS_RELATIVE),
+ #define XLAT_VAL_243 ((unsigned) (V4L2_CID_FOCUS_RELATIVE))
+ #define XLAT_STR_243 STRINGIFY(V4L2_CID_FOCUS_RELATIVE)
  XLAT(V4L2_CID_FOCUS_AUTO),
+ #define XLAT_VAL_244 ((unsigned) (V4L2_CID_FOCUS_AUTO))
+ #define XLAT_STR_244 STRINGIFY(V4L2_CID_FOCUS_AUTO)
  XLAT(V4L2_CID_ZOOM_ABSOLUTE),
+ #define XLAT_VAL_245 ((unsigned) (V4L2_CID_ZOOM_ABSOLUTE))
+ #define XLAT_STR_245 STRINGIFY(V4L2_CID_ZOOM_ABSOLUTE)
  XLAT(V4L2_CID_ZOOM_RELATIVE),
+ #define XLAT_VAL_246 ((unsigned) (V4L2_CID_ZOOM_RELATIVE))
+ #define XLAT_STR_246 STRINGIFY(V4L2_CID_ZOOM_RELATIVE)
  XLAT(V4L2_CID_ZOOM_CONTINUOUS),
+ #define XLAT_VAL_247 ((unsigned) (V4L2_CID_ZOOM_CONTINUOUS))
+ #define XLAT_STR_247 STRINGIFY(V4L2_CID_ZOOM_CONTINUOUS)
  XLAT(V4L2_CID_PRIVACY),
+ #define XLAT_VAL_248 ((unsigned) (V4L2_CID_PRIVACY))
+ #define XLAT_STR_248 STRINGIFY(V4L2_CID_PRIVACY)
  XLAT(V4L2_CID_IRIS_ABSOLUTE),
+ #define XLAT_VAL_249 ((unsigned) (V4L2_CID_IRIS_ABSOLUTE))
+ #define XLAT_STR_249 STRINGIFY(V4L2_CID_IRIS_ABSOLUTE)
  XLAT(V4L2_CID_IRIS_RELATIVE),
+ #define XLAT_VAL_250 ((unsigned) (V4L2_CID_IRIS_RELATIVE))
+ #define XLAT_STR_250 STRINGIFY(V4L2_CID_IRIS_RELATIVE)
  XLAT(V4L2_CID_AUTO_EXPOSURE_BIAS),
+ #define XLAT_VAL_251 ((unsigned) (V4L2_CID_AUTO_EXPOSURE_BIAS))
+ #define XLAT_STR_251 STRINGIFY(V4L2_CID_AUTO_EXPOSURE_BIAS)
  XLAT(V4L2_CID_AUTO_N_PRESET_WHITE_BALANCE),
+ #define XLAT_VAL_252 ((unsigned) (V4L2_CID_AUTO_N_PRESET_WHITE_BALANCE))
+ #define XLAT_STR_252 STRINGIFY(V4L2_CID_AUTO_N_PRESET_WHITE_BALANCE)
  XLAT(V4L2_CID_WIDE_DYNAMIC_RANGE),
+ #define XLAT_VAL_253 ((unsigned) (V4L2_CID_WIDE_DYNAMIC_RANGE))
+ #define XLAT_STR_253 STRINGIFY(V4L2_CID_WIDE_DYNAMIC_RANGE)
  XLAT(V4L2_CID_IMAGE_STABILIZATION),
+ #define XLAT_VAL_254 ((unsigned) (V4L2_CID_IMAGE_STABILIZATION))
+ #define XLAT_STR_254 STRINGIFY(V4L2_CID_IMAGE_STABILIZATION)
  XLAT(V4L2_CID_ISO_SENSITIVITY),
+ #define XLAT_VAL_255 ((unsigned) (V4L2_CID_ISO_SENSITIVITY))
+ #define XLAT_STR_255 STRINGIFY(V4L2_CID_ISO_SENSITIVITY)
  XLAT(V4L2_CID_ISO_SENSITIVITY_AUTO),
+ #define XLAT_VAL_256 ((unsigned) (V4L2_CID_ISO_SENSITIVITY_AUTO))
+ #define XLAT_STR_256 STRINGIFY(V4L2_CID_ISO_SENSITIVITY_AUTO)
  XLAT(V4L2_CID_EXPOSURE_METERING),
+ #define XLAT_VAL_257 ((unsigned) (V4L2_CID_EXPOSURE_METERING))
+ #define XLAT_STR_257 STRINGIFY(V4L2_CID_EXPOSURE_METERING)
  XLAT(V4L2_CID_SCENE_MODE),
+ #define XLAT_VAL_258 ((unsigned) (V4L2_CID_SCENE_MODE))
+ #define XLAT_STR_258 STRINGIFY(V4L2_CID_SCENE_MODE)
  XLAT(V4L2_CID_3A_LOCK),
+ #define XLAT_VAL_259 ((unsigned) (V4L2_CID_3A_LOCK))
+ #define XLAT_STR_259 STRINGIFY(V4L2_CID_3A_LOCK)
  XLAT(V4L2_CID_AUTO_FOCUS_START),
+ #define XLAT_VAL_260 ((unsigned) (V4L2_CID_AUTO_FOCUS_START))
+ #define XLAT_STR_260 STRINGIFY(V4L2_CID_AUTO_FOCUS_START)
  XLAT(V4L2_CID_AUTO_FOCUS_STOP),
+ #define XLAT_VAL_261 ((unsigned) (V4L2_CID_AUTO_FOCUS_STOP))
+ #define XLAT_STR_261 STRINGIFY(V4L2_CID_AUTO_FOCUS_STOP)
  XLAT(V4L2_CID_AUTO_FOCUS_STATUS),
+ #define XLAT_VAL_262 ((unsigned) (V4L2_CID_AUTO_FOCUS_STATUS))
+ #define XLAT_STR_262 STRINGIFY(V4L2_CID_AUTO_FOCUS_STATUS)
  XLAT(V4L2_CID_AUTO_FOCUS_RANGE),
+ #define XLAT_VAL_263 ((unsigned) (V4L2_CID_AUTO_FOCUS_RANGE))
+ #define XLAT_STR_263 STRINGIFY(V4L2_CID_AUTO_FOCUS_RANGE)
  XLAT(V4L2_CID_PAN_SPEED),
+ #define XLAT_VAL_264 ((unsigned) (V4L2_CID_PAN_SPEED))
+ #define XLAT_STR_264 STRINGIFY(V4L2_CID_PAN_SPEED)
  XLAT(V4L2_CID_TILT_SPEED),
+ #define XLAT_VAL_265 ((unsigned) (V4L2_CID_TILT_SPEED))
+ #define XLAT_STR_265 STRINGIFY(V4L2_CID_TILT_SPEED)
 
  XLAT(V4L2_CID_RDS_TX_DEVIATION),
+ #define XLAT_VAL_266 ((unsigned) (V4L2_CID_RDS_TX_DEVIATION))
+ #define XLAT_STR_266 STRINGIFY(V4L2_CID_RDS_TX_DEVIATION)
  XLAT(V4L2_CID_RDS_TX_PI),
+ #define XLAT_VAL_267 ((unsigned) (V4L2_CID_RDS_TX_PI))
+ #define XLAT_STR_267 STRINGIFY(V4L2_CID_RDS_TX_PI)
  XLAT(V4L2_CID_RDS_TX_PTY),
+ #define XLAT_VAL_268 ((unsigned) (V4L2_CID_RDS_TX_PTY))
+ #define XLAT_STR_268 STRINGIFY(V4L2_CID_RDS_TX_PTY)
  XLAT(V4L2_CID_RDS_TX_PS_NAME),
+ #define XLAT_VAL_269 ((unsigned) (V4L2_CID_RDS_TX_PS_NAME))
+ #define XLAT_STR_269 STRINGIFY(V4L2_CID_RDS_TX_PS_NAME)
  XLAT(V4L2_CID_RDS_TX_RADIO_TEXT),
+ #define XLAT_VAL_270 ((unsigned) (V4L2_CID_RDS_TX_RADIO_TEXT))
+ #define XLAT_STR_270 STRINGIFY(V4L2_CID_RDS_TX_RADIO_TEXT)
  XLAT(V4L2_CID_RDS_TX_MONO_STEREO),
+ #define XLAT_VAL_271 ((unsigned) (V4L2_CID_RDS_TX_MONO_STEREO))
+ #define XLAT_STR_271 STRINGIFY(V4L2_CID_RDS_TX_MONO_STEREO)
  XLAT(V4L2_CID_RDS_TX_ARTIFICIAL_HEAD),
+ #define XLAT_VAL_272 ((unsigned) (V4L2_CID_RDS_TX_ARTIFICIAL_HEAD))
+ #define XLAT_STR_272 STRINGIFY(V4L2_CID_RDS_TX_ARTIFICIAL_HEAD)
  XLAT(V4L2_CID_RDS_TX_COMPRESSED),
+ #define XLAT_VAL_273 ((unsigned) (V4L2_CID_RDS_TX_COMPRESSED))
+ #define XLAT_STR_273 STRINGIFY(V4L2_CID_RDS_TX_COMPRESSED)
  XLAT(V4L2_CID_RDS_TX_DYNAMIC_PTY),
+ #define XLAT_VAL_274 ((unsigned) (V4L2_CID_RDS_TX_DYNAMIC_PTY))
+ #define XLAT_STR_274 STRINGIFY(V4L2_CID_RDS_TX_DYNAMIC_PTY)
  XLAT(V4L2_CID_RDS_TX_TRAFFIC_ANNOUNCEMENT),
+ #define XLAT_VAL_275 ((unsigned) (V4L2_CID_RDS_TX_TRAFFIC_ANNOUNCEMENT))
+ #define XLAT_STR_275 STRINGIFY(V4L2_CID_RDS_TX_TRAFFIC_ANNOUNCEMENT)
  XLAT(V4L2_CID_RDS_TX_TRAFFIC_PROGRAM),
+ #define XLAT_VAL_276 ((unsigned) (V4L2_CID_RDS_TX_TRAFFIC_PROGRAM))
+ #define XLAT_STR_276 STRINGIFY(V4L2_CID_RDS_TX_TRAFFIC_PROGRAM)
  XLAT(V4L2_CID_RDS_TX_MUSIC_SPEECH),
+ #define XLAT_VAL_277 ((unsigned) (V4L2_CID_RDS_TX_MUSIC_SPEECH))
+ #define XLAT_STR_277 STRINGIFY(V4L2_CID_RDS_TX_MUSIC_SPEECH)
  XLAT(V4L2_CID_RDS_TX_ALT_FREQS_ENABLE),
+ #define XLAT_VAL_278 ((unsigned) (V4L2_CID_RDS_TX_ALT_FREQS_ENABLE))
+ #define XLAT_STR_278 STRINGIFY(V4L2_CID_RDS_TX_ALT_FREQS_ENABLE)
  XLAT(V4L2_CID_RDS_TX_ALT_FREQS),
+ #define XLAT_VAL_279 ((unsigned) (V4L2_CID_RDS_TX_ALT_FREQS))
+ #define XLAT_STR_279 STRINGIFY(V4L2_CID_RDS_TX_ALT_FREQS)
  XLAT(V4L2_CID_AUDIO_LIMITER_ENABLED),
+ #define XLAT_VAL_280 ((unsigned) (V4L2_CID_AUDIO_LIMITER_ENABLED))
+ #define XLAT_STR_280 STRINGIFY(V4L2_CID_AUDIO_LIMITER_ENABLED)
  XLAT(V4L2_CID_AUDIO_LIMITER_RELEASE_TIME),
+ #define XLAT_VAL_281 ((unsigned) (V4L2_CID_AUDIO_LIMITER_RELEASE_TIME))
+ #define XLAT_STR_281 STRINGIFY(V4L2_CID_AUDIO_LIMITER_RELEASE_TIME)
  XLAT(V4L2_CID_AUDIO_LIMITER_DEVIATION),
+ #define XLAT_VAL_282 ((unsigned) (V4L2_CID_AUDIO_LIMITER_DEVIATION))
+ #define XLAT_STR_282 STRINGIFY(V4L2_CID_AUDIO_LIMITER_DEVIATION)
  XLAT(V4L2_CID_AUDIO_COMPRESSION_ENABLED),
+ #define XLAT_VAL_283 ((unsigned) (V4L2_CID_AUDIO_COMPRESSION_ENABLED))
+ #define XLAT_STR_283 STRINGIFY(V4L2_CID_AUDIO_COMPRESSION_ENABLED)
  XLAT(V4L2_CID_AUDIO_COMPRESSION_GAIN),
+ #define XLAT_VAL_284 ((unsigned) (V4L2_CID_AUDIO_COMPRESSION_GAIN))
+ #define XLAT_STR_284 STRINGIFY(V4L2_CID_AUDIO_COMPRESSION_GAIN)
  XLAT(V4L2_CID_AUDIO_COMPRESSION_THRESHOLD),
+ #define XLAT_VAL_285 ((unsigned) (V4L2_CID_AUDIO_COMPRESSION_THRESHOLD))
+ #define XLAT_STR_285 STRINGIFY(V4L2_CID_AUDIO_COMPRESSION_THRESHOLD)
  XLAT(V4L2_CID_AUDIO_COMPRESSION_ATTACK_TIME),
+ #define XLAT_VAL_286 ((unsigned) (V4L2_CID_AUDIO_COMPRESSION_ATTACK_TIME))
+ #define XLAT_STR_286 STRINGIFY(V4L2_CID_AUDIO_COMPRESSION_ATTACK_TIME)
  XLAT(V4L2_CID_AUDIO_COMPRESSION_RELEASE_TIME),
+ #define XLAT_VAL_287 ((unsigned) (V4L2_CID_AUDIO_COMPRESSION_RELEASE_TIME))
+ #define XLAT_STR_287 STRINGIFY(V4L2_CID_AUDIO_COMPRESSION_RELEASE_TIME)
  XLAT(V4L2_CID_PILOT_TONE_ENABLED),
+ #define XLAT_VAL_288 ((unsigned) (V4L2_CID_PILOT_TONE_ENABLED))
+ #define XLAT_STR_288 STRINGIFY(V4L2_CID_PILOT_TONE_ENABLED)
  XLAT(V4L2_CID_PILOT_TONE_DEVIATION),
+ #define XLAT_VAL_289 ((unsigned) (V4L2_CID_PILOT_TONE_DEVIATION))
+ #define XLAT_STR_289 STRINGIFY(V4L2_CID_PILOT_TONE_DEVIATION)
  XLAT(V4L2_CID_PILOT_TONE_FREQUENCY),
+ #define XLAT_VAL_290 ((unsigned) (V4L2_CID_PILOT_TONE_FREQUENCY))
+ #define XLAT_STR_290 STRINGIFY(V4L2_CID_PILOT_TONE_FREQUENCY)
  XLAT(V4L2_CID_TUNE_PREEMPHASIS),
+ #define XLAT_VAL_291 ((unsigned) (V4L2_CID_TUNE_PREEMPHASIS))
+ #define XLAT_STR_291 STRINGIFY(V4L2_CID_TUNE_PREEMPHASIS)
  XLAT(V4L2_CID_TUNE_POWER_LEVEL),
+ #define XLAT_VAL_292 ((unsigned) (V4L2_CID_TUNE_POWER_LEVEL))
+ #define XLAT_STR_292 STRINGIFY(V4L2_CID_TUNE_POWER_LEVEL)
  XLAT(V4L2_CID_TUNE_ANTENNA_CAPACITOR),
+ #define XLAT_VAL_293 ((unsigned) (V4L2_CID_TUNE_ANTENNA_CAPACITOR))
+ #define XLAT_STR_293 STRINGIFY(V4L2_CID_TUNE_ANTENNA_CAPACITOR)
 
  XLAT(V4L2_CID_FLASH_LED_MODE),
+ #define XLAT_VAL_294 ((unsigned) (V4L2_CID_FLASH_LED_MODE))
+ #define XLAT_STR_294 STRINGIFY(V4L2_CID_FLASH_LED_MODE)
  XLAT(V4L2_CID_FLASH_STROBE_SOURCE),
+ #define XLAT_VAL_295 ((unsigned) (V4L2_CID_FLASH_STROBE_SOURCE))
+ #define XLAT_STR_295 STRINGIFY(V4L2_CID_FLASH_STROBE_SOURCE)
  XLAT(V4L2_CID_FLASH_STROBE),
+ #define XLAT_VAL_296 ((unsigned) (V4L2_CID_FLASH_STROBE))
+ #define XLAT_STR_296 STRINGIFY(V4L2_CID_FLASH_STROBE)
  XLAT(V4L2_CID_FLASH_STROBE_STOP),
+ #define XLAT_VAL_297 ((unsigned) (V4L2_CID_FLASH_STROBE_STOP))
+ #define XLAT_STR_297 STRINGIFY(V4L2_CID_FLASH_STROBE_STOP)
  XLAT(V4L2_CID_FLASH_STROBE_STATUS),
+ #define XLAT_VAL_298 ((unsigned) (V4L2_CID_FLASH_STROBE_STATUS))
+ #define XLAT_STR_298 STRINGIFY(V4L2_CID_FLASH_STROBE_STATUS)
  XLAT(V4L2_CID_FLASH_TIMEOUT),
+ #define XLAT_VAL_299 ((unsigned) (V4L2_CID_FLASH_TIMEOUT))
+ #define XLAT_STR_299 STRINGIFY(V4L2_CID_FLASH_TIMEOUT)
  XLAT(V4L2_CID_FLASH_INTENSITY),
+ #define XLAT_VAL_300 ((unsigned) (V4L2_CID_FLASH_INTENSITY))
+ #define XLAT_STR_300 STRINGIFY(V4L2_CID_FLASH_INTENSITY)
  XLAT(V4L2_CID_FLASH_TORCH_INTENSITY),
+ #define XLAT_VAL_301 ((unsigned) (V4L2_CID_FLASH_TORCH_INTENSITY))
+ #define XLAT_STR_301 STRINGIFY(V4L2_CID_FLASH_TORCH_INTENSITY)
  XLAT(V4L2_CID_FLASH_INDICATOR_INTENSITY),
+ #define XLAT_VAL_302 ((unsigned) (V4L2_CID_FLASH_INDICATOR_INTENSITY))
+ #define XLAT_STR_302 STRINGIFY(V4L2_CID_FLASH_INDICATOR_INTENSITY)
  XLAT(V4L2_CID_FLASH_FAULT),
+ #define XLAT_VAL_303 ((unsigned) (V4L2_CID_FLASH_FAULT))
+ #define XLAT_STR_303 STRINGIFY(V4L2_CID_FLASH_FAULT)
  XLAT(V4L2_CID_FLASH_CHARGE),
+ #define XLAT_VAL_304 ((unsigned) (V4L2_CID_FLASH_CHARGE))
+ #define XLAT_STR_304 STRINGIFY(V4L2_CID_FLASH_CHARGE)
  XLAT(V4L2_CID_FLASH_READY),
+ #define XLAT_VAL_305 ((unsigned) (V4L2_CID_FLASH_READY))
+ #define XLAT_STR_305 STRINGIFY(V4L2_CID_FLASH_READY)
 
  XLAT(V4L2_CID_VBLANK),
+ #define XLAT_VAL_306 ((unsigned) (V4L2_CID_VBLANK))
+ #define XLAT_STR_306 STRINGIFY(V4L2_CID_VBLANK)
  XLAT(V4L2_CID_HBLANK),
+ #define XLAT_VAL_307 ((unsigned) (V4L2_CID_HBLANK))
+ #define XLAT_STR_307 STRINGIFY(V4L2_CID_HBLANK)
  XLAT(V4L2_CID_ANALOGUE_GAIN),
+ #define XLAT_VAL_308 ((unsigned) (V4L2_CID_ANALOGUE_GAIN))
+ #define XLAT_STR_308 STRINGIFY(V4L2_CID_ANALOGUE_GAIN)
  XLAT(V4L2_CID_TEST_PATTERN_RED),
+ #define XLAT_VAL_309 ((unsigned) (V4L2_CID_TEST_PATTERN_RED))
+ #define XLAT_STR_309 STRINGIFY(V4L2_CID_TEST_PATTERN_RED)
  XLAT(V4L2_CID_TEST_PATTERN_GREENR),
+ #define XLAT_VAL_310 ((unsigned) (V4L2_CID_TEST_PATTERN_GREENR))
+ #define XLAT_STR_310 STRINGIFY(V4L2_CID_TEST_PATTERN_GREENR)
  XLAT(V4L2_CID_TEST_PATTERN_BLUE),
+ #define XLAT_VAL_311 ((unsigned) (V4L2_CID_TEST_PATTERN_BLUE))
+ #define XLAT_STR_311 STRINGIFY(V4L2_CID_TEST_PATTERN_BLUE)
  XLAT(V4L2_CID_TEST_PATTERN_GREENB),
+ #define XLAT_VAL_312 ((unsigned) (V4L2_CID_TEST_PATTERN_GREENB))
+ #define XLAT_STR_312 STRINGIFY(V4L2_CID_TEST_PATTERN_GREENB)
  XLAT(V4L2_CID_UNIT_CELL_SIZE),
+ #define XLAT_VAL_313 ((unsigned) (V4L2_CID_UNIT_CELL_SIZE))
+ #define XLAT_STR_313 STRINGIFY(V4L2_CID_UNIT_CELL_SIZE)
 
  XLAT(V4L2_CID_LINK_FREQ),
+ #define XLAT_VAL_314 ((unsigned) (V4L2_CID_LINK_FREQ))
+ #define XLAT_STR_314 STRINGIFY(V4L2_CID_LINK_FREQ)
  XLAT(V4L2_CID_PIXEL_RATE),
+ #define XLAT_VAL_315 ((unsigned) (V4L2_CID_PIXEL_RATE))
+ #define XLAT_STR_315 STRINGIFY(V4L2_CID_PIXEL_RATE)
  XLAT(V4L2_CID_TEST_PATTERN),
+ #define XLAT_VAL_316 ((unsigned) (V4L2_CID_TEST_PATTERN))
+ #define XLAT_STR_316 STRINGIFY(V4L2_CID_TEST_PATTERN)
  XLAT(V4L2_CID_DEINTERLACING_MODE),
+ #define XLAT_VAL_317 ((unsigned) (V4L2_CID_DEINTERLACING_MODE))
+ #define XLAT_STR_317 STRINGIFY(V4L2_CID_DEINTERLACING_MODE)
  XLAT(V4L2_CID_DIGITAL_GAIN),
+ #define XLAT_VAL_318 ((unsigned) (V4L2_CID_DIGITAL_GAIN))
+ #define XLAT_STR_318 STRINGIFY(V4L2_CID_DIGITAL_GAIN)
 
  XLAT(V4L2_CID_DV_TX_RGB_RANGE),
+ #define XLAT_VAL_319 ((unsigned) (V4L2_CID_DV_TX_RGB_RANGE))
+ #define XLAT_STR_319 STRINGIFY(V4L2_CID_DV_TX_RGB_RANGE)
  XLAT(V4L2_CID_DV_TX_IT_CONTENT_TYPE),
+ #define XLAT_VAL_320 ((unsigned) (V4L2_CID_DV_TX_IT_CONTENT_TYPE))
+ #define XLAT_STR_320 STRINGIFY(V4L2_CID_DV_TX_IT_CONTENT_TYPE)
  XLAT(V4L2_CID_DV_RX_RGB_RANGE),
+ #define XLAT_VAL_321 ((unsigned) (V4L2_CID_DV_RX_RGB_RANGE))
+ #define XLAT_STR_321 STRINGIFY(V4L2_CID_DV_RX_RGB_RANGE)
  XLAT(V4L2_CID_DV_RX_IT_CONTENT_TYPE),
+ #define XLAT_VAL_322 ((unsigned) (V4L2_CID_DV_RX_IT_CONTENT_TYPE))
+ #define XLAT_STR_322 STRINGIFY(V4L2_CID_DV_RX_IT_CONTENT_TYPE)
  XLAT(V4L2_CID_TUNE_DEEMPHASIS),
+ #define XLAT_VAL_323 ((unsigned) (V4L2_CID_TUNE_DEEMPHASIS))
+ #define XLAT_STR_323 STRINGIFY(V4L2_CID_TUNE_DEEMPHASIS)
  XLAT(V4L2_CID_RDS_RECEPTION),
+ #define XLAT_VAL_324 ((unsigned) (V4L2_CID_RDS_RECEPTION))
+ #define XLAT_STR_324 STRINGIFY(V4L2_CID_RDS_RECEPTION)
  XLAT(V4L2_CID_RDS_RX_PTY),
+ #define XLAT_VAL_325 ((unsigned) (V4L2_CID_RDS_RX_PTY))
+ #define XLAT_STR_325 STRINGIFY(V4L2_CID_RDS_RX_PTY)
  XLAT(V4L2_CID_RDS_RX_PS_NAME),
+ #define XLAT_VAL_326 ((unsigned) (V4L2_CID_RDS_RX_PS_NAME))
+ #define XLAT_STR_326 STRINGIFY(V4L2_CID_RDS_RX_PS_NAME)
  XLAT(V4L2_CID_RDS_RX_RADIO_TEXT),
+ #define XLAT_VAL_327 ((unsigned) (V4L2_CID_RDS_RX_RADIO_TEXT))
+ #define XLAT_STR_327 STRINGIFY(V4L2_CID_RDS_RX_RADIO_TEXT)
  XLAT(V4L2_CID_RDS_RX_TRAFFIC_ANNOUNCEMENT),
+ #define XLAT_VAL_328 ((unsigned) (V4L2_CID_RDS_RX_TRAFFIC_ANNOUNCEMENT))
+ #define XLAT_STR_328 STRINGIFY(V4L2_CID_RDS_RX_TRAFFIC_ANNOUNCEMENT)
  XLAT(V4L2_CID_RDS_RX_TRAFFIC_PROGRAM),
+ #define XLAT_VAL_329 ((unsigned) (V4L2_CID_RDS_RX_TRAFFIC_PROGRAM))
+ #define XLAT_STR_329 STRINGIFY(V4L2_CID_RDS_RX_TRAFFIC_PROGRAM)
  XLAT(V4L2_CID_RDS_RX_MUSIC_SPEECH),
+ #define XLAT_VAL_330 ((unsigned) (V4L2_CID_RDS_RX_MUSIC_SPEECH))
+ #define XLAT_STR_330 STRINGIFY(V4L2_CID_RDS_RX_MUSIC_SPEECH)
  XLAT(V4L2_CID_RF_TUNER_BANDWIDTH_AUTO),
+ #define XLAT_VAL_331 ((unsigned) (V4L2_CID_RF_TUNER_BANDWIDTH_AUTO))
+ #define XLAT_STR_331 STRINGIFY(V4L2_CID_RF_TUNER_BANDWIDTH_AUTO)
  XLAT(V4L2_CID_RF_TUNER_BANDWIDTH),
+ #define XLAT_VAL_332 ((unsigned) (V4L2_CID_RF_TUNER_BANDWIDTH))
+ #define XLAT_STR_332 STRINGIFY(V4L2_CID_RF_TUNER_BANDWIDTH)
  XLAT(V4L2_CID_RF_TUNER_RF_GAIN),
+ #define XLAT_VAL_333 ((unsigned) (V4L2_CID_RF_TUNER_RF_GAIN))
+ #define XLAT_STR_333 STRINGIFY(V4L2_CID_RF_TUNER_RF_GAIN)
  XLAT(V4L2_CID_RF_TUNER_LNA_GAIN_AUTO),
+ #define XLAT_VAL_334 ((unsigned) (V4L2_CID_RF_TUNER_LNA_GAIN_AUTO))
+ #define XLAT_STR_334 STRINGIFY(V4L2_CID_RF_TUNER_LNA_GAIN_AUTO)
  XLAT(V4L2_CID_RF_TUNER_LNA_GAIN),
+ #define XLAT_VAL_335 ((unsigned) (V4L2_CID_RF_TUNER_LNA_GAIN))
+ #define XLAT_STR_335 STRINGIFY(V4L2_CID_RF_TUNER_LNA_GAIN)
  XLAT(V4L2_CID_RF_TUNER_MIXER_GAIN_AUTO),
+ #define XLAT_VAL_336 ((unsigned) (V4L2_CID_RF_TUNER_MIXER_GAIN_AUTO))
+ #define XLAT_STR_336 STRINGIFY(V4L2_CID_RF_TUNER_MIXER_GAIN_AUTO)
  XLAT(V4L2_CID_RF_TUNER_MIXER_GAIN),
+ #define XLAT_VAL_337 ((unsigned) (V4L2_CID_RF_TUNER_MIXER_GAIN))
+ #define XLAT_STR_337 STRINGIFY(V4L2_CID_RF_TUNER_MIXER_GAIN)
  XLAT(V4L2_CID_RF_TUNER_IF_GAIN_AUTO),
+ #define XLAT_VAL_338 ((unsigned) (V4L2_CID_RF_TUNER_IF_GAIN_AUTO))
+ #define XLAT_STR_338 STRINGIFY(V4L2_CID_RF_TUNER_IF_GAIN_AUTO)
  XLAT(V4L2_CID_RF_TUNER_IF_GAIN),
+ #define XLAT_VAL_339 ((unsigned) (V4L2_CID_RF_TUNER_IF_GAIN))
+ #define XLAT_STR_339 STRINGIFY(V4L2_CID_RF_TUNER_IF_GAIN)
  XLAT(V4L2_CID_RF_TUNER_PLL_LOCK),
+ #define XLAT_VAL_340 ((unsigned) (V4L2_CID_RF_TUNER_PLL_LOCK))
+ #define XLAT_STR_340 STRINGIFY(V4L2_CID_RF_TUNER_PLL_LOCK)
 
  XLAT(V4L2_CID_DETECT_MD_MODE),
+ #define XLAT_VAL_341 ((unsigned) (V4L2_CID_DETECT_MD_MODE))
+ #define XLAT_STR_341 STRINGIFY(V4L2_CID_DETECT_MD_MODE)
  XLAT(V4L2_CID_DETECT_MD_GLOBAL_THRESHOLD),
+ #define XLAT_VAL_342 ((unsigned) (V4L2_CID_DETECT_MD_GLOBAL_THRESHOLD))
+ #define XLAT_STR_342 STRINGIFY(V4L2_CID_DETECT_MD_GLOBAL_THRESHOLD)
  XLAT(V4L2_CID_DETECT_MD_THRESHOLD_GRID),
+ #define XLAT_VAL_343 ((unsigned) (V4L2_CID_DETECT_MD_THRESHOLD_GRID))
+ #define XLAT_STR_343 STRINGIFY(V4L2_CID_DETECT_MD_THRESHOLD_GRID)
  XLAT(V4L2_CID_DETECT_MD_REGION_GRID),
+ #define XLAT_VAL_344 ((unsigned) (V4L2_CID_DETECT_MD_REGION_GRID))
+ #define XLAT_STR_344 STRINGIFY(V4L2_CID_DETECT_MD_REGION_GRID)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -2797,8 +3487,2772 @@ const struct xlat v4l2_control_ids[1] =
  .data = v4l2_control_ids_xdata,
  .size = ARRAY_SIZE(v4l2_control_ids_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+#  ifdef XLAT_VAL_47
+  | XLAT_VAL_47
+#  endif
+#  ifdef XLAT_VAL_48
+  | XLAT_VAL_48
+#  endif
+#  ifdef XLAT_VAL_49
+  | XLAT_VAL_49
+#  endif
+#  ifdef XLAT_VAL_50
+  | XLAT_VAL_50
+#  endif
+#  ifdef XLAT_VAL_51
+  | XLAT_VAL_51
+#  endif
+#  ifdef XLAT_VAL_52
+  | XLAT_VAL_52
+#  endif
+#  ifdef XLAT_VAL_53
+  | XLAT_VAL_53
+#  endif
+#  ifdef XLAT_VAL_54
+  | XLAT_VAL_54
+#  endif
+#  ifdef XLAT_VAL_55
+  | XLAT_VAL_55
+#  endif
+#  ifdef XLAT_VAL_56
+  | XLAT_VAL_56
+#  endif
+#  ifdef XLAT_VAL_57
+  | XLAT_VAL_57
+#  endif
+#  ifdef XLAT_VAL_58
+  | XLAT_VAL_58
+#  endif
+#  ifdef XLAT_VAL_59
+  | XLAT_VAL_59
+#  endif
+#  ifdef XLAT_VAL_60
+  | XLAT_VAL_60
+#  endif
+#  ifdef XLAT_VAL_61
+  | XLAT_VAL_61
+#  endif
+#  ifdef XLAT_VAL_62
+  | XLAT_VAL_62
+#  endif
+#  ifdef XLAT_VAL_63
+  | XLAT_VAL_63
+#  endif
+#  ifdef XLAT_VAL_64
+  | XLAT_VAL_64
+#  endif
+#  ifdef XLAT_VAL_65
+  | XLAT_VAL_65
+#  endif
+#  ifdef XLAT_VAL_66
+  | XLAT_VAL_66
+#  endif
+#  ifdef XLAT_VAL_67
+  | XLAT_VAL_67
+#  endif
+#  ifdef XLAT_VAL_68
+  | XLAT_VAL_68
+#  endif
+#  ifdef XLAT_VAL_69
+  | XLAT_VAL_69
+#  endif
+#  ifdef XLAT_VAL_70
+  | XLAT_VAL_70
+#  endif
+#  ifdef XLAT_VAL_71
+  | XLAT_VAL_71
+#  endif
+#  ifdef XLAT_VAL_72
+  | XLAT_VAL_72
+#  endif
+#  ifdef XLAT_VAL_73
+  | XLAT_VAL_73
+#  endif
+#  ifdef XLAT_VAL_74
+  | XLAT_VAL_74
+#  endif
+#  ifdef XLAT_VAL_75
+  | XLAT_VAL_75
+#  endif
+#  ifdef XLAT_VAL_76
+  | XLAT_VAL_76
+#  endif
+#  ifdef XLAT_VAL_77
+  | XLAT_VAL_77
+#  endif
+#  ifdef XLAT_VAL_78
+  | XLAT_VAL_78
+#  endif
+#  ifdef XLAT_VAL_79
+  | XLAT_VAL_79
+#  endif
+#  ifdef XLAT_VAL_80
+  | XLAT_VAL_80
+#  endif
+#  ifdef XLAT_VAL_81
+  | XLAT_VAL_81
+#  endif
+#  ifdef XLAT_VAL_82
+  | XLAT_VAL_82
+#  endif
+#  ifdef XLAT_VAL_83
+  | XLAT_VAL_83
+#  endif
+#  ifdef XLAT_VAL_84
+  | XLAT_VAL_84
+#  endif
+#  ifdef XLAT_VAL_85
+  | XLAT_VAL_85
+#  endif
+#  ifdef XLAT_VAL_86
+  | XLAT_VAL_86
+#  endif
+#  ifdef XLAT_VAL_87
+  | XLAT_VAL_87
+#  endif
+#  ifdef XLAT_VAL_88
+  | XLAT_VAL_88
+#  endif
+#  ifdef XLAT_VAL_89
+  | XLAT_VAL_89
+#  endif
+#  ifdef XLAT_VAL_90
+  | XLAT_VAL_90
+#  endif
+#  ifdef XLAT_VAL_91
+  | XLAT_VAL_91
+#  endif
+#  ifdef XLAT_VAL_92
+  | XLAT_VAL_92
+#  endif
+#  ifdef XLAT_VAL_93
+  | XLAT_VAL_93
+#  endif
+#  ifdef XLAT_VAL_94
+  | XLAT_VAL_94
+#  endif
+#  ifdef XLAT_VAL_95
+  | XLAT_VAL_95
+#  endif
+#  ifdef XLAT_VAL_96
+  | XLAT_VAL_96
+#  endif
+#  ifdef XLAT_VAL_97
+  | XLAT_VAL_97
+#  endif
+#  ifdef XLAT_VAL_98
+  | XLAT_VAL_98
+#  endif
+#  ifdef XLAT_VAL_99
+  | XLAT_VAL_99
+#  endif
+#  ifdef XLAT_VAL_100
+  | XLAT_VAL_100
+#  endif
+#  ifdef XLAT_VAL_101
+  | XLAT_VAL_101
+#  endif
+#  ifdef XLAT_VAL_102
+  | XLAT_VAL_102
+#  endif
+#  ifdef XLAT_VAL_103
+  | XLAT_VAL_103
+#  endif
+#  ifdef XLAT_VAL_104
+  | XLAT_VAL_104
+#  endif
+#  ifdef XLAT_VAL_105
+  | XLAT_VAL_105
+#  endif
+#  ifdef XLAT_VAL_106
+  | XLAT_VAL_106
+#  endif
+#  ifdef XLAT_VAL_107
+  | XLAT_VAL_107
+#  endif
+#  ifdef XLAT_VAL_108
+  | XLAT_VAL_108
+#  endif
+#  ifdef XLAT_VAL_109
+  | XLAT_VAL_109
+#  endif
+#  ifdef XLAT_VAL_110
+  | XLAT_VAL_110
+#  endif
+#  ifdef XLAT_VAL_111
+  | XLAT_VAL_111
+#  endif
+#  ifdef XLAT_VAL_112
+  | XLAT_VAL_112
+#  endif
+#  ifdef XLAT_VAL_113
+  | XLAT_VAL_113
+#  endif
+#  ifdef XLAT_VAL_114
+  | XLAT_VAL_114
+#  endif
+#  ifdef XLAT_VAL_115
+  | XLAT_VAL_115
+#  endif
+#  ifdef XLAT_VAL_116
+  | XLAT_VAL_116
+#  endif
+#  ifdef XLAT_VAL_117
+  | XLAT_VAL_117
+#  endif
+#  ifdef XLAT_VAL_118
+  | XLAT_VAL_118
+#  endif
+#  ifdef XLAT_VAL_119
+  | XLAT_VAL_119
+#  endif
+#  ifdef XLAT_VAL_120
+  | XLAT_VAL_120
+#  endif
+#  ifdef XLAT_VAL_121
+  | XLAT_VAL_121
+#  endif
+#  ifdef XLAT_VAL_122
+  | XLAT_VAL_122
+#  endif
+#  ifdef XLAT_VAL_123
+  | XLAT_VAL_123
+#  endif
+#  ifdef XLAT_VAL_124
+  | XLAT_VAL_124
+#  endif
+#  ifdef XLAT_VAL_125
+  | XLAT_VAL_125
+#  endif
+#  ifdef XLAT_VAL_126
+  | XLAT_VAL_126
+#  endif
+#  ifdef XLAT_VAL_127
+  | XLAT_VAL_127
+#  endif
+#  ifdef XLAT_VAL_128
+  | XLAT_VAL_128
+#  endif
+#  ifdef XLAT_VAL_129
+  | XLAT_VAL_129
+#  endif
+#  ifdef XLAT_VAL_130
+  | XLAT_VAL_130
+#  endif
+#  ifdef XLAT_VAL_131
+  | XLAT_VAL_131
+#  endif
+#  ifdef XLAT_VAL_132
+  | XLAT_VAL_132
+#  endif
+#  ifdef XLAT_VAL_133
+  | XLAT_VAL_133
+#  endif
+#  ifdef XLAT_VAL_134
+  | XLAT_VAL_134
+#  endif
+#  ifdef XLAT_VAL_135
+  | XLAT_VAL_135
+#  endif
+#  ifdef XLAT_VAL_136
+  | XLAT_VAL_136
+#  endif
+#  ifdef XLAT_VAL_137
+  | XLAT_VAL_137
+#  endif
+#  ifdef XLAT_VAL_138
+  | XLAT_VAL_138
+#  endif
+#  ifdef XLAT_VAL_139
+  | XLAT_VAL_139
+#  endif
+#  ifdef XLAT_VAL_140
+  | XLAT_VAL_140
+#  endif
+#  ifdef XLAT_VAL_141
+  | XLAT_VAL_141
+#  endif
+#  ifdef XLAT_VAL_142
+  | XLAT_VAL_142
+#  endif
+#  ifdef XLAT_VAL_143
+  | XLAT_VAL_143
+#  endif
+#  ifdef XLAT_VAL_144
+  | XLAT_VAL_144
+#  endif
+#  ifdef XLAT_VAL_145
+  | XLAT_VAL_145
+#  endif
+#  ifdef XLAT_VAL_146
+  | XLAT_VAL_146
+#  endif
+#  ifdef XLAT_VAL_147
+  | XLAT_VAL_147
+#  endif
+#  ifdef XLAT_VAL_148
+  | XLAT_VAL_148
+#  endif
+#  ifdef XLAT_VAL_149
+  | XLAT_VAL_149
+#  endif
+#  ifdef XLAT_VAL_150
+  | XLAT_VAL_150
+#  endif
+#  ifdef XLAT_VAL_151
+  | XLAT_VAL_151
+#  endif
+#  ifdef XLAT_VAL_152
+  | XLAT_VAL_152
+#  endif
+#  ifdef XLAT_VAL_153
+  | XLAT_VAL_153
+#  endif
+#  ifdef XLAT_VAL_154
+  | XLAT_VAL_154
+#  endif
+#  ifdef XLAT_VAL_155
+  | XLAT_VAL_155
+#  endif
+#  ifdef XLAT_VAL_156
+  | XLAT_VAL_156
+#  endif
+#  ifdef XLAT_VAL_157
+  | XLAT_VAL_157
+#  endif
+#  ifdef XLAT_VAL_158
+  | XLAT_VAL_158
+#  endif
+#  ifdef XLAT_VAL_159
+  | XLAT_VAL_159
+#  endif
+#  ifdef XLAT_VAL_160
+  | XLAT_VAL_160
+#  endif
+#  ifdef XLAT_VAL_161
+  | XLAT_VAL_161
+#  endif
+#  ifdef XLAT_VAL_162
+  | XLAT_VAL_162
+#  endif
+#  ifdef XLAT_VAL_163
+  | XLAT_VAL_163
+#  endif
+#  ifdef XLAT_VAL_164
+  | XLAT_VAL_164
+#  endif
+#  ifdef XLAT_VAL_165
+  | XLAT_VAL_165
+#  endif
+#  ifdef XLAT_VAL_166
+  | XLAT_VAL_166
+#  endif
+#  ifdef XLAT_VAL_167
+  | XLAT_VAL_167
+#  endif
+#  ifdef XLAT_VAL_168
+  | XLAT_VAL_168
+#  endif
+#  ifdef XLAT_VAL_169
+  | XLAT_VAL_169
+#  endif
+#  ifdef XLAT_VAL_170
+  | XLAT_VAL_170
+#  endif
+#  ifdef XLAT_VAL_171
+  | XLAT_VAL_171
+#  endif
+#  ifdef XLAT_VAL_172
+  | XLAT_VAL_172
+#  endif
+#  ifdef XLAT_VAL_173
+  | XLAT_VAL_173
+#  endif
+#  ifdef XLAT_VAL_174
+  | XLAT_VAL_174
+#  endif
+#  ifdef XLAT_VAL_175
+  | XLAT_VAL_175
+#  endif
+#  ifdef XLAT_VAL_176
+  | XLAT_VAL_176
+#  endif
+#  ifdef XLAT_VAL_177
+  | XLAT_VAL_177
+#  endif
+#  ifdef XLAT_VAL_178
+  | XLAT_VAL_178
+#  endif
+#  ifdef XLAT_VAL_179
+  | XLAT_VAL_179
+#  endif
+#  ifdef XLAT_VAL_180
+  | XLAT_VAL_180
+#  endif
+#  ifdef XLAT_VAL_181
+  | XLAT_VAL_181
+#  endif
+#  ifdef XLAT_VAL_182
+  | XLAT_VAL_182
+#  endif
+#  ifdef XLAT_VAL_183
+  | XLAT_VAL_183
+#  endif
+#  ifdef XLAT_VAL_184
+  | XLAT_VAL_184
+#  endif
+#  ifdef XLAT_VAL_185
+  | XLAT_VAL_185
+#  endif
+#  ifdef XLAT_VAL_186
+  | XLAT_VAL_186
+#  endif
+#  ifdef XLAT_VAL_187
+  | XLAT_VAL_187
+#  endif
+#  ifdef XLAT_VAL_188
+  | XLAT_VAL_188
+#  endif
+#  ifdef XLAT_VAL_189
+  | XLAT_VAL_189
+#  endif
+#  ifdef XLAT_VAL_190
+  | XLAT_VAL_190
+#  endif
+#  ifdef XLAT_VAL_191
+  | XLAT_VAL_191
+#  endif
+#  ifdef XLAT_VAL_192
+  | XLAT_VAL_192
+#  endif
+#  ifdef XLAT_VAL_193
+  | XLAT_VAL_193
+#  endif
+#  ifdef XLAT_VAL_194
+  | XLAT_VAL_194
+#  endif
+#  ifdef XLAT_VAL_195
+  | XLAT_VAL_195
+#  endif
+#  ifdef XLAT_VAL_196
+  | XLAT_VAL_196
+#  endif
+#  ifdef XLAT_VAL_197
+  | XLAT_VAL_197
+#  endif
+#  ifdef XLAT_VAL_198
+  | XLAT_VAL_198
+#  endif
+#  ifdef XLAT_VAL_199
+  | XLAT_VAL_199
+#  endif
+#  ifdef XLAT_VAL_200
+  | XLAT_VAL_200
+#  endif
+#  ifdef XLAT_VAL_201
+  | XLAT_VAL_201
+#  endif
+#  ifdef XLAT_VAL_202
+  | XLAT_VAL_202
+#  endif
+#  ifdef XLAT_VAL_203
+  | XLAT_VAL_203
+#  endif
+#  ifdef XLAT_VAL_204
+  | XLAT_VAL_204
+#  endif
+#  ifdef XLAT_VAL_205
+  | XLAT_VAL_205
+#  endif
+#  ifdef XLAT_VAL_206
+  | XLAT_VAL_206
+#  endif
+#  ifdef XLAT_VAL_207
+  | XLAT_VAL_207
+#  endif
+#  ifdef XLAT_VAL_208
+  | XLAT_VAL_208
+#  endif
+#  ifdef XLAT_VAL_209
+  | XLAT_VAL_209
+#  endif
+#  ifdef XLAT_VAL_210
+  | XLAT_VAL_210
+#  endif
+#  ifdef XLAT_VAL_211
+  | XLAT_VAL_211
+#  endif
+#  ifdef XLAT_VAL_212
+  | XLAT_VAL_212
+#  endif
+#  ifdef XLAT_VAL_213
+  | XLAT_VAL_213
+#  endif
+#  ifdef XLAT_VAL_214
+  | XLAT_VAL_214
+#  endif
+#  ifdef XLAT_VAL_215
+  | XLAT_VAL_215
+#  endif
+#  ifdef XLAT_VAL_216
+  | XLAT_VAL_216
+#  endif
+#  ifdef XLAT_VAL_217
+  | XLAT_VAL_217
+#  endif
+#  ifdef XLAT_VAL_218
+  | XLAT_VAL_218
+#  endif
+#  ifdef XLAT_VAL_219
+  | XLAT_VAL_219
+#  endif
+#  ifdef XLAT_VAL_220
+  | XLAT_VAL_220
+#  endif
+#  ifdef XLAT_VAL_221
+  | XLAT_VAL_221
+#  endif
+#  ifdef XLAT_VAL_222
+  | XLAT_VAL_222
+#  endif
+#  ifdef XLAT_VAL_223
+  | XLAT_VAL_223
+#  endif
+#  ifdef XLAT_VAL_224
+  | XLAT_VAL_224
+#  endif
+#  ifdef XLAT_VAL_225
+  | XLAT_VAL_225
+#  endif
+#  ifdef XLAT_VAL_226
+  | XLAT_VAL_226
+#  endif
+#  ifdef XLAT_VAL_227
+  | XLAT_VAL_227
+#  endif
+#  ifdef XLAT_VAL_228
+  | XLAT_VAL_228
+#  endif
+#  ifdef XLAT_VAL_229
+  | XLAT_VAL_229
+#  endif
+#  ifdef XLAT_VAL_230
+  | XLAT_VAL_230
+#  endif
+#  ifdef XLAT_VAL_231
+  | XLAT_VAL_231
+#  endif
+#  ifdef XLAT_VAL_232
+  | XLAT_VAL_232
+#  endif
+#  ifdef XLAT_VAL_233
+  | XLAT_VAL_233
+#  endif
+#  ifdef XLAT_VAL_234
+  | XLAT_VAL_234
+#  endif
+#  ifdef XLAT_VAL_235
+  | XLAT_VAL_235
+#  endif
+#  ifdef XLAT_VAL_236
+  | XLAT_VAL_236
+#  endif
+#  ifdef XLAT_VAL_237
+  | XLAT_VAL_237
+#  endif
+#  ifdef XLAT_VAL_238
+  | XLAT_VAL_238
+#  endif
+#  ifdef XLAT_VAL_239
+  | XLAT_VAL_239
+#  endif
+#  ifdef XLAT_VAL_240
+  | XLAT_VAL_240
+#  endif
+#  ifdef XLAT_VAL_241
+  | XLAT_VAL_241
+#  endif
+#  ifdef XLAT_VAL_242
+  | XLAT_VAL_242
+#  endif
+#  ifdef XLAT_VAL_243
+  | XLAT_VAL_243
+#  endif
+#  ifdef XLAT_VAL_244
+  | XLAT_VAL_244
+#  endif
+#  ifdef XLAT_VAL_245
+  | XLAT_VAL_245
+#  endif
+#  ifdef XLAT_VAL_246
+  | XLAT_VAL_246
+#  endif
+#  ifdef XLAT_VAL_247
+  | XLAT_VAL_247
+#  endif
+#  ifdef XLAT_VAL_248
+  | XLAT_VAL_248
+#  endif
+#  ifdef XLAT_VAL_249
+  | XLAT_VAL_249
+#  endif
+#  ifdef XLAT_VAL_250
+  | XLAT_VAL_250
+#  endif
+#  ifdef XLAT_VAL_251
+  | XLAT_VAL_251
+#  endif
+#  ifdef XLAT_VAL_252
+  | XLAT_VAL_252
+#  endif
+#  ifdef XLAT_VAL_253
+  | XLAT_VAL_253
+#  endif
+#  ifdef XLAT_VAL_254
+  | XLAT_VAL_254
+#  endif
+#  ifdef XLAT_VAL_255
+  | XLAT_VAL_255
+#  endif
+#  ifdef XLAT_VAL_256
+  | XLAT_VAL_256
+#  endif
+#  ifdef XLAT_VAL_257
+  | XLAT_VAL_257
+#  endif
+#  ifdef XLAT_VAL_258
+  | XLAT_VAL_258
+#  endif
+#  ifdef XLAT_VAL_259
+  | XLAT_VAL_259
+#  endif
+#  ifdef XLAT_VAL_260
+  | XLAT_VAL_260
+#  endif
+#  ifdef XLAT_VAL_261
+  | XLAT_VAL_261
+#  endif
+#  ifdef XLAT_VAL_262
+  | XLAT_VAL_262
+#  endif
+#  ifdef XLAT_VAL_263
+  | XLAT_VAL_263
+#  endif
+#  ifdef XLAT_VAL_264
+  | XLAT_VAL_264
+#  endif
+#  ifdef XLAT_VAL_265
+  | XLAT_VAL_265
+#  endif
+#  ifdef XLAT_VAL_266
+  | XLAT_VAL_266
+#  endif
+#  ifdef XLAT_VAL_267
+  | XLAT_VAL_267
+#  endif
+#  ifdef XLAT_VAL_268
+  | XLAT_VAL_268
+#  endif
+#  ifdef XLAT_VAL_269
+  | XLAT_VAL_269
+#  endif
+#  ifdef XLAT_VAL_270
+  | XLAT_VAL_270
+#  endif
+#  ifdef XLAT_VAL_271
+  | XLAT_VAL_271
+#  endif
+#  ifdef XLAT_VAL_272
+  | XLAT_VAL_272
+#  endif
+#  ifdef XLAT_VAL_273
+  | XLAT_VAL_273
+#  endif
+#  ifdef XLAT_VAL_274
+  | XLAT_VAL_274
+#  endif
+#  ifdef XLAT_VAL_275
+  | XLAT_VAL_275
+#  endif
+#  ifdef XLAT_VAL_276
+  | XLAT_VAL_276
+#  endif
+#  ifdef XLAT_VAL_277
+  | XLAT_VAL_277
+#  endif
+#  ifdef XLAT_VAL_278
+  | XLAT_VAL_278
+#  endif
+#  ifdef XLAT_VAL_279
+  | XLAT_VAL_279
+#  endif
+#  ifdef XLAT_VAL_280
+  | XLAT_VAL_280
+#  endif
+#  ifdef XLAT_VAL_281
+  | XLAT_VAL_281
+#  endif
+#  ifdef XLAT_VAL_282
+  | XLAT_VAL_282
+#  endif
+#  ifdef XLAT_VAL_283
+  | XLAT_VAL_283
+#  endif
+#  ifdef XLAT_VAL_284
+  | XLAT_VAL_284
+#  endif
+#  ifdef XLAT_VAL_285
+  | XLAT_VAL_285
+#  endif
+#  ifdef XLAT_VAL_286
+  | XLAT_VAL_286
+#  endif
+#  ifdef XLAT_VAL_287
+  | XLAT_VAL_287
+#  endif
+#  ifdef XLAT_VAL_288
+  | XLAT_VAL_288
+#  endif
+#  ifdef XLAT_VAL_289
+  | XLAT_VAL_289
+#  endif
+#  ifdef XLAT_VAL_290
+  | XLAT_VAL_290
+#  endif
+#  ifdef XLAT_VAL_291
+  | XLAT_VAL_291
+#  endif
+#  ifdef XLAT_VAL_292
+  | XLAT_VAL_292
+#  endif
+#  ifdef XLAT_VAL_293
+  | XLAT_VAL_293
+#  endif
+#  ifdef XLAT_VAL_294
+  | XLAT_VAL_294
+#  endif
+#  ifdef XLAT_VAL_295
+  | XLAT_VAL_295
+#  endif
+#  ifdef XLAT_VAL_296
+  | XLAT_VAL_296
+#  endif
+#  ifdef XLAT_VAL_297
+  | XLAT_VAL_297
+#  endif
+#  ifdef XLAT_VAL_298
+  | XLAT_VAL_298
+#  endif
+#  ifdef XLAT_VAL_299
+  | XLAT_VAL_299
+#  endif
+#  ifdef XLAT_VAL_300
+  | XLAT_VAL_300
+#  endif
+#  ifdef XLAT_VAL_301
+  | XLAT_VAL_301
+#  endif
+#  ifdef XLAT_VAL_302
+  | XLAT_VAL_302
+#  endif
+#  ifdef XLAT_VAL_303
+  | XLAT_VAL_303
+#  endif
+#  ifdef XLAT_VAL_304
+  | XLAT_VAL_304
+#  endif
+#  ifdef XLAT_VAL_305
+  | XLAT_VAL_305
+#  endif
+#  ifdef XLAT_VAL_306
+  | XLAT_VAL_306
+#  endif
+#  ifdef XLAT_VAL_307
+  | XLAT_VAL_307
+#  endif
+#  ifdef XLAT_VAL_308
+  | XLAT_VAL_308
+#  endif
+#  ifdef XLAT_VAL_309
+  | XLAT_VAL_309
+#  endif
+#  ifdef XLAT_VAL_310
+  | XLAT_VAL_310
+#  endif
+#  ifdef XLAT_VAL_311
+  | XLAT_VAL_311
+#  endif
+#  ifdef XLAT_VAL_312
+  | XLAT_VAL_312
+#  endif
+#  ifdef XLAT_VAL_313
+  | XLAT_VAL_313
+#  endif
+#  ifdef XLAT_VAL_314
+  | XLAT_VAL_314
+#  endif
+#  ifdef XLAT_VAL_315
+  | XLAT_VAL_315
+#  endif
+#  ifdef XLAT_VAL_316
+  | XLAT_VAL_316
+#  endif
+#  ifdef XLAT_VAL_317
+  | XLAT_VAL_317
+#  endif
+#  ifdef XLAT_VAL_318
+  | XLAT_VAL_318
+#  endif
+#  ifdef XLAT_VAL_319
+  | XLAT_VAL_319
+#  endif
+#  ifdef XLAT_VAL_320
+  | XLAT_VAL_320
+#  endif
+#  ifdef XLAT_VAL_321
+  | XLAT_VAL_321
+#  endif
+#  ifdef XLAT_VAL_322
+  | XLAT_VAL_322
+#  endif
+#  ifdef XLAT_VAL_323
+  | XLAT_VAL_323
+#  endif
+#  ifdef XLAT_VAL_324
+  | XLAT_VAL_324
+#  endif
+#  ifdef XLAT_VAL_325
+  | XLAT_VAL_325
+#  endif
+#  ifdef XLAT_VAL_326
+  | XLAT_VAL_326
+#  endif
+#  ifdef XLAT_VAL_327
+  | XLAT_VAL_327
+#  endif
+#  ifdef XLAT_VAL_328
+  | XLAT_VAL_328
+#  endif
+#  ifdef XLAT_VAL_329
+  | XLAT_VAL_329
+#  endif
+#  ifdef XLAT_VAL_330
+  | XLAT_VAL_330
+#  endif
+#  ifdef XLAT_VAL_331
+  | XLAT_VAL_331
+#  endif
+#  ifdef XLAT_VAL_332
+  | XLAT_VAL_332
+#  endif
+#  ifdef XLAT_VAL_333
+  | XLAT_VAL_333
+#  endif
+#  ifdef XLAT_VAL_334
+  | XLAT_VAL_334
+#  endif
+#  ifdef XLAT_VAL_335
+  | XLAT_VAL_335
+#  endif
+#  ifdef XLAT_VAL_336
+  | XLAT_VAL_336
+#  endif
+#  ifdef XLAT_VAL_337
+  | XLAT_VAL_337
+#  endif
+#  ifdef XLAT_VAL_338
+  | XLAT_VAL_338
+#  endif
+#  ifdef XLAT_VAL_339
+  | XLAT_VAL_339
+#  endif
+#  ifdef XLAT_VAL_340
+  | XLAT_VAL_340
+#  endif
+#  ifdef XLAT_VAL_341
+  | XLAT_VAL_341
+#  endif
+#  ifdef XLAT_VAL_342
+  | XLAT_VAL_342
+#  endif
+#  ifdef XLAT_VAL_343
+  | XLAT_VAL_343
+#  endif
+#  ifdef XLAT_VAL_344
+  | XLAT_VAL_344
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+#  ifdef XLAT_STR_47
+  + sizeof(XLAT_STR_47)
+#  endif
+#  ifdef XLAT_STR_48
+  + sizeof(XLAT_STR_48)
+#  endif
+#  ifdef XLAT_STR_49
+  + sizeof(XLAT_STR_49)
+#  endif
+#  ifdef XLAT_STR_50
+  + sizeof(XLAT_STR_50)
+#  endif
+#  ifdef XLAT_STR_51
+  + sizeof(XLAT_STR_51)
+#  endif
+#  ifdef XLAT_STR_52
+  + sizeof(XLAT_STR_52)
+#  endif
+#  ifdef XLAT_STR_53
+  + sizeof(XLAT_STR_53)
+#  endif
+#  ifdef XLAT_STR_54
+  + sizeof(XLAT_STR_54)
+#  endif
+#  ifdef XLAT_STR_55
+  + sizeof(XLAT_STR_55)
+#  endif
+#  ifdef XLAT_STR_56
+  + sizeof(XLAT_STR_56)
+#  endif
+#  ifdef XLAT_STR_57
+  + sizeof(XLAT_STR_57)
+#  endif
+#  ifdef XLAT_STR_58
+  + sizeof(XLAT_STR_58)
+#  endif
+#  ifdef XLAT_STR_59
+  + sizeof(XLAT_STR_59)
+#  endif
+#  ifdef XLAT_STR_60
+  + sizeof(XLAT_STR_60)
+#  endif
+#  ifdef XLAT_STR_61
+  + sizeof(XLAT_STR_61)
+#  endif
+#  ifdef XLAT_STR_62
+  + sizeof(XLAT_STR_62)
+#  endif
+#  ifdef XLAT_STR_63
+  + sizeof(XLAT_STR_63)
+#  endif
+#  ifdef XLAT_STR_64
+  + sizeof(XLAT_STR_64)
+#  endif
+#  ifdef XLAT_STR_65
+  + sizeof(XLAT_STR_65)
+#  endif
+#  ifdef XLAT_STR_66
+  + sizeof(XLAT_STR_66)
+#  endif
+#  ifdef XLAT_STR_67
+  + sizeof(XLAT_STR_67)
+#  endif
+#  ifdef XLAT_STR_68
+  + sizeof(XLAT_STR_68)
+#  endif
+#  ifdef XLAT_STR_69
+  + sizeof(XLAT_STR_69)
+#  endif
+#  ifdef XLAT_STR_70
+  + sizeof(XLAT_STR_70)
+#  endif
+#  ifdef XLAT_STR_71
+  + sizeof(XLAT_STR_71)
+#  endif
+#  ifdef XLAT_STR_72
+  + sizeof(XLAT_STR_72)
+#  endif
+#  ifdef XLAT_STR_73
+  + sizeof(XLAT_STR_73)
+#  endif
+#  ifdef XLAT_STR_74
+  + sizeof(XLAT_STR_74)
+#  endif
+#  ifdef XLAT_STR_75
+  + sizeof(XLAT_STR_75)
+#  endif
+#  ifdef XLAT_STR_76
+  + sizeof(XLAT_STR_76)
+#  endif
+#  ifdef XLAT_STR_77
+  + sizeof(XLAT_STR_77)
+#  endif
+#  ifdef XLAT_STR_78
+  + sizeof(XLAT_STR_78)
+#  endif
+#  ifdef XLAT_STR_79
+  + sizeof(XLAT_STR_79)
+#  endif
+#  ifdef XLAT_STR_80
+  + sizeof(XLAT_STR_80)
+#  endif
+#  ifdef XLAT_STR_81
+  + sizeof(XLAT_STR_81)
+#  endif
+#  ifdef XLAT_STR_82
+  + sizeof(XLAT_STR_82)
+#  endif
+#  ifdef XLAT_STR_83
+  + sizeof(XLAT_STR_83)
+#  endif
+#  ifdef XLAT_STR_84
+  + sizeof(XLAT_STR_84)
+#  endif
+#  ifdef XLAT_STR_85
+  + sizeof(XLAT_STR_85)
+#  endif
+#  ifdef XLAT_STR_86
+  + sizeof(XLAT_STR_86)
+#  endif
+#  ifdef XLAT_STR_87
+  + sizeof(XLAT_STR_87)
+#  endif
+#  ifdef XLAT_STR_88
+  + sizeof(XLAT_STR_88)
+#  endif
+#  ifdef XLAT_STR_89
+  + sizeof(XLAT_STR_89)
+#  endif
+#  ifdef XLAT_STR_90
+  + sizeof(XLAT_STR_90)
+#  endif
+#  ifdef XLAT_STR_91
+  + sizeof(XLAT_STR_91)
+#  endif
+#  ifdef XLAT_STR_92
+  + sizeof(XLAT_STR_92)
+#  endif
+#  ifdef XLAT_STR_93
+  + sizeof(XLAT_STR_93)
+#  endif
+#  ifdef XLAT_STR_94
+  + sizeof(XLAT_STR_94)
+#  endif
+#  ifdef XLAT_STR_95
+  + sizeof(XLAT_STR_95)
+#  endif
+#  ifdef XLAT_STR_96
+  + sizeof(XLAT_STR_96)
+#  endif
+#  ifdef XLAT_STR_97
+  + sizeof(XLAT_STR_97)
+#  endif
+#  ifdef XLAT_STR_98
+  + sizeof(XLAT_STR_98)
+#  endif
+#  ifdef XLAT_STR_99
+  + sizeof(XLAT_STR_99)
+#  endif
+#  ifdef XLAT_STR_100
+  + sizeof(XLAT_STR_100)
+#  endif
+#  ifdef XLAT_STR_101
+  + sizeof(XLAT_STR_101)
+#  endif
+#  ifdef XLAT_STR_102
+  + sizeof(XLAT_STR_102)
+#  endif
+#  ifdef XLAT_STR_103
+  + sizeof(XLAT_STR_103)
+#  endif
+#  ifdef XLAT_STR_104
+  + sizeof(XLAT_STR_104)
+#  endif
+#  ifdef XLAT_STR_105
+  + sizeof(XLAT_STR_105)
+#  endif
+#  ifdef XLAT_STR_106
+  + sizeof(XLAT_STR_106)
+#  endif
+#  ifdef XLAT_STR_107
+  + sizeof(XLAT_STR_107)
+#  endif
+#  ifdef XLAT_STR_108
+  + sizeof(XLAT_STR_108)
+#  endif
+#  ifdef XLAT_STR_109
+  + sizeof(XLAT_STR_109)
+#  endif
+#  ifdef XLAT_STR_110
+  + sizeof(XLAT_STR_110)
+#  endif
+#  ifdef XLAT_STR_111
+  + sizeof(XLAT_STR_111)
+#  endif
+#  ifdef XLAT_STR_112
+  + sizeof(XLAT_STR_112)
+#  endif
+#  ifdef XLAT_STR_113
+  + sizeof(XLAT_STR_113)
+#  endif
+#  ifdef XLAT_STR_114
+  + sizeof(XLAT_STR_114)
+#  endif
+#  ifdef XLAT_STR_115
+  + sizeof(XLAT_STR_115)
+#  endif
+#  ifdef XLAT_STR_116
+  + sizeof(XLAT_STR_116)
+#  endif
+#  ifdef XLAT_STR_117
+  + sizeof(XLAT_STR_117)
+#  endif
+#  ifdef XLAT_STR_118
+  + sizeof(XLAT_STR_118)
+#  endif
+#  ifdef XLAT_STR_119
+  + sizeof(XLAT_STR_119)
+#  endif
+#  ifdef XLAT_STR_120
+  + sizeof(XLAT_STR_120)
+#  endif
+#  ifdef XLAT_STR_121
+  + sizeof(XLAT_STR_121)
+#  endif
+#  ifdef XLAT_STR_122
+  + sizeof(XLAT_STR_122)
+#  endif
+#  ifdef XLAT_STR_123
+  + sizeof(XLAT_STR_123)
+#  endif
+#  ifdef XLAT_STR_124
+  + sizeof(XLAT_STR_124)
+#  endif
+#  ifdef XLAT_STR_125
+  + sizeof(XLAT_STR_125)
+#  endif
+#  ifdef XLAT_STR_126
+  + sizeof(XLAT_STR_126)
+#  endif
+#  ifdef XLAT_STR_127
+  + sizeof(XLAT_STR_127)
+#  endif
+#  ifdef XLAT_STR_128
+  + sizeof(XLAT_STR_128)
+#  endif
+#  ifdef XLAT_STR_129
+  + sizeof(XLAT_STR_129)
+#  endif
+#  ifdef XLAT_STR_130
+  + sizeof(XLAT_STR_130)
+#  endif
+#  ifdef XLAT_STR_131
+  + sizeof(XLAT_STR_131)
+#  endif
+#  ifdef XLAT_STR_132
+  + sizeof(XLAT_STR_132)
+#  endif
+#  ifdef XLAT_STR_133
+  + sizeof(XLAT_STR_133)
+#  endif
+#  ifdef XLAT_STR_134
+  + sizeof(XLAT_STR_134)
+#  endif
+#  ifdef XLAT_STR_135
+  + sizeof(XLAT_STR_135)
+#  endif
+#  ifdef XLAT_STR_136
+  + sizeof(XLAT_STR_136)
+#  endif
+#  ifdef XLAT_STR_137
+  + sizeof(XLAT_STR_137)
+#  endif
+#  ifdef XLAT_STR_138
+  + sizeof(XLAT_STR_138)
+#  endif
+#  ifdef XLAT_STR_139
+  + sizeof(XLAT_STR_139)
+#  endif
+#  ifdef XLAT_STR_140
+  + sizeof(XLAT_STR_140)
+#  endif
+#  ifdef XLAT_STR_141
+  + sizeof(XLAT_STR_141)
+#  endif
+#  ifdef XLAT_STR_142
+  + sizeof(XLAT_STR_142)
+#  endif
+#  ifdef XLAT_STR_143
+  + sizeof(XLAT_STR_143)
+#  endif
+#  ifdef XLAT_STR_144
+  + sizeof(XLAT_STR_144)
+#  endif
+#  ifdef XLAT_STR_145
+  + sizeof(XLAT_STR_145)
+#  endif
+#  ifdef XLAT_STR_146
+  + sizeof(XLAT_STR_146)
+#  endif
+#  ifdef XLAT_STR_147
+  + sizeof(XLAT_STR_147)
+#  endif
+#  ifdef XLAT_STR_148
+  + sizeof(XLAT_STR_148)
+#  endif
+#  ifdef XLAT_STR_149
+  + sizeof(XLAT_STR_149)
+#  endif
+#  ifdef XLAT_STR_150
+  + sizeof(XLAT_STR_150)
+#  endif
+#  ifdef XLAT_STR_151
+  + sizeof(XLAT_STR_151)
+#  endif
+#  ifdef XLAT_STR_152
+  + sizeof(XLAT_STR_152)
+#  endif
+#  ifdef XLAT_STR_153
+  + sizeof(XLAT_STR_153)
+#  endif
+#  ifdef XLAT_STR_154
+  + sizeof(XLAT_STR_154)
+#  endif
+#  ifdef XLAT_STR_155
+  + sizeof(XLAT_STR_155)
+#  endif
+#  ifdef XLAT_STR_156
+  + sizeof(XLAT_STR_156)
+#  endif
+#  ifdef XLAT_STR_157
+  + sizeof(XLAT_STR_157)
+#  endif
+#  ifdef XLAT_STR_158
+  + sizeof(XLAT_STR_158)
+#  endif
+#  ifdef XLAT_STR_159
+  + sizeof(XLAT_STR_159)
+#  endif
+#  ifdef XLAT_STR_160
+  + sizeof(XLAT_STR_160)
+#  endif
+#  ifdef XLAT_STR_161
+  + sizeof(XLAT_STR_161)
+#  endif
+#  ifdef XLAT_STR_162
+  + sizeof(XLAT_STR_162)
+#  endif
+#  ifdef XLAT_STR_163
+  + sizeof(XLAT_STR_163)
+#  endif
+#  ifdef XLAT_STR_164
+  + sizeof(XLAT_STR_164)
+#  endif
+#  ifdef XLAT_STR_165
+  + sizeof(XLAT_STR_165)
+#  endif
+#  ifdef XLAT_STR_166
+  + sizeof(XLAT_STR_166)
+#  endif
+#  ifdef XLAT_STR_167
+  + sizeof(XLAT_STR_167)
+#  endif
+#  ifdef XLAT_STR_168
+  + sizeof(XLAT_STR_168)
+#  endif
+#  ifdef XLAT_STR_169
+  + sizeof(XLAT_STR_169)
+#  endif
+#  ifdef XLAT_STR_170
+  + sizeof(XLAT_STR_170)
+#  endif
+#  ifdef XLAT_STR_171
+  + sizeof(XLAT_STR_171)
+#  endif
+#  ifdef XLAT_STR_172
+  + sizeof(XLAT_STR_172)
+#  endif
+#  ifdef XLAT_STR_173
+  + sizeof(XLAT_STR_173)
+#  endif
+#  ifdef XLAT_STR_174
+  + sizeof(XLAT_STR_174)
+#  endif
+#  ifdef XLAT_STR_175
+  + sizeof(XLAT_STR_175)
+#  endif
+#  ifdef XLAT_STR_176
+  + sizeof(XLAT_STR_176)
+#  endif
+#  ifdef XLAT_STR_177
+  + sizeof(XLAT_STR_177)
+#  endif
+#  ifdef XLAT_STR_178
+  + sizeof(XLAT_STR_178)
+#  endif
+#  ifdef XLAT_STR_179
+  + sizeof(XLAT_STR_179)
+#  endif
+#  ifdef XLAT_STR_180
+  + sizeof(XLAT_STR_180)
+#  endif
+#  ifdef XLAT_STR_181
+  + sizeof(XLAT_STR_181)
+#  endif
+#  ifdef XLAT_STR_182
+  + sizeof(XLAT_STR_182)
+#  endif
+#  ifdef XLAT_STR_183
+  + sizeof(XLAT_STR_183)
+#  endif
+#  ifdef XLAT_STR_184
+  + sizeof(XLAT_STR_184)
+#  endif
+#  ifdef XLAT_STR_185
+  + sizeof(XLAT_STR_185)
+#  endif
+#  ifdef XLAT_STR_186
+  + sizeof(XLAT_STR_186)
+#  endif
+#  ifdef XLAT_STR_187
+  + sizeof(XLAT_STR_187)
+#  endif
+#  ifdef XLAT_STR_188
+  + sizeof(XLAT_STR_188)
+#  endif
+#  ifdef XLAT_STR_189
+  + sizeof(XLAT_STR_189)
+#  endif
+#  ifdef XLAT_STR_190
+  + sizeof(XLAT_STR_190)
+#  endif
+#  ifdef XLAT_STR_191
+  + sizeof(XLAT_STR_191)
+#  endif
+#  ifdef XLAT_STR_192
+  + sizeof(XLAT_STR_192)
+#  endif
+#  ifdef XLAT_STR_193
+  + sizeof(XLAT_STR_193)
+#  endif
+#  ifdef XLAT_STR_194
+  + sizeof(XLAT_STR_194)
+#  endif
+#  ifdef XLAT_STR_195
+  + sizeof(XLAT_STR_195)
+#  endif
+#  ifdef XLAT_STR_196
+  + sizeof(XLAT_STR_196)
+#  endif
+#  ifdef XLAT_STR_197
+  + sizeof(XLAT_STR_197)
+#  endif
+#  ifdef XLAT_STR_198
+  + sizeof(XLAT_STR_198)
+#  endif
+#  ifdef XLAT_STR_199
+  + sizeof(XLAT_STR_199)
+#  endif
+#  ifdef XLAT_STR_200
+  + sizeof(XLAT_STR_200)
+#  endif
+#  ifdef XLAT_STR_201
+  + sizeof(XLAT_STR_201)
+#  endif
+#  ifdef XLAT_STR_202
+  + sizeof(XLAT_STR_202)
+#  endif
+#  ifdef XLAT_STR_203
+  + sizeof(XLAT_STR_203)
+#  endif
+#  ifdef XLAT_STR_204
+  + sizeof(XLAT_STR_204)
+#  endif
+#  ifdef XLAT_STR_205
+  + sizeof(XLAT_STR_205)
+#  endif
+#  ifdef XLAT_STR_206
+  + sizeof(XLAT_STR_206)
+#  endif
+#  ifdef XLAT_STR_207
+  + sizeof(XLAT_STR_207)
+#  endif
+#  ifdef XLAT_STR_208
+  + sizeof(XLAT_STR_208)
+#  endif
+#  ifdef XLAT_STR_209
+  + sizeof(XLAT_STR_209)
+#  endif
+#  ifdef XLAT_STR_210
+  + sizeof(XLAT_STR_210)
+#  endif
+#  ifdef XLAT_STR_211
+  + sizeof(XLAT_STR_211)
+#  endif
+#  ifdef XLAT_STR_212
+  + sizeof(XLAT_STR_212)
+#  endif
+#  ifdef XLAT_STR_213
+  + sizeof(XLAT_STR_213)
+#  endif
+#  ifdef XLAT_STR_214
+  + sizeof(XLAT_STR_214)
+#  endif
+#  ifdef XLAT_STR_215
+  + sizeof(XLAT_STR_215)
+#  endif
+#  ifdef XLAT_STR_216
+  + sizeof(XLAT_STR_216)
+#  endif
+#  ifdef XLAT_STR_217
+  + sizeof(XLAT_STR_217)
+#  endif
+#  ifdef XLAT_STR_218
+  + sizeof(XLAT_STR_218)
+#  endif
+#  ifdef XLAT_STR_219
+  + sizeof(XLAT_STR_219)
+#  endif
+#  ifdef XLAT_STR_220
+  + sizeof(XLAT_STR_220)
+#  endif
+#  ifdef XLAT_STR_221
+  + sizeof(XLAT_STR_221)
+#  endif
+#  ifdef XLAT_STR_222
+  + sizeof(XLAT_STR_222)
+#  endif
+#  ifdef XLAT_STR_223
+  + sizeof(XLAT_STR_223)
+#  endif
+#  ifdef XLAT_STR_224
+  + sizeof(XLAT_STR_224)
+#  endif
+#  ifdef XLAT_STR_225
+  + sizeof(XLAT_STR_225)
+#  endif
+#  ifdef XLAT_STR_226
+  + sizeof(XLAT_STR_226)
+#  endif
+#  ifdef XLAT_STR_227
+  + sizeof(XLAT_STR_227)
+#  endif
+#  ifdef XLAT_STR_228
+  + sizeof(XLAT_STR_228)
+#  endif
+#  ifdef XLAT_STR_229
+  + sizeof(XLAT_STR_229)
+#  endif
+#  ifdef XLAT_STR_230
+  + sizeof(XLAT_STR_230)
+#  endif
+#  ifdef XLAT_STR_231
+  + sizeof(XLAT_STR_231)
+#  endif
+#  ifdef XLAT_STR_232
+  + sizeof(XLAT_STR_232)
+#  endif
+#  ifdef XLAT_STR_233
+  + sizeof(XLAT_STR_233)
+#  endif
+#  ifdef XLAT_STR_234
+  + sizeof(XLAT_STR_234)
+#  endif
+#  ifdef XLAT_STR_235
+  + sizeof(XLAT_STR_235)
+#  endif
+#  ifdef XLAT_STR_236
+  + sizeof(XLAT_STR_236)
+#  endif
+#  ifdef XLAT_STR_237
+  + sizeof(XLAT_STR_237)
+#  endif
+#  ifdef XLAT_STR_238
+  + sizeof(XLAT_STR_238)
+#  endif
+#  ifdef XLAT_STR_239
+  + sizeof(XLAT_STR_239)
+#  endif
+#  ifdef XLAT_STR_240
+  + sizeof(XLAT_STR_240)
+#  endif
+#  ifdef XLAT_STR_241
+  + sizeof(XLAT_STR_241)
+#  endif
+#  ifdef XLAT_STR_242
+  + sizeof(XLAT_STR_242)
+#  endif
+#  ifdef XLAT_STR_243
+  + sizeof(XLAT_STR_243)
+#  endif
+#  ifdef XLAT_STR_244
+  + sizeof(XLAT_STR_244)
+#  endif
+#  ifdef XLAT_STR_245
+  + sizeof(XLAT_STR_245)
+#  endif
+#  ifdef XLAT_STR_246
+  + sizeof(XLAT_STR_246)
+#  endif
+#  ifdef XLAT_STR_247
+  + sizeof(XLAT_STR_247)
+#  endif
+#  ifdef XLAT_STR_248
+  + sizeof(XLAT_STR_248)
+#  endif
+#  ifdef XLAT_STR_249
+  + sizeof(XLAT_STR_249)
+#  endif
+#  ifdef XLAT_STR_250
+  + sizeof(XLAT_STR_250)
+#  endif
+#  ifdef XLAT_STR_251
+  + sizeof(XLAT_STR_251)
+#  endif
+#  ifdef XLAT_STR_252
+  + sizeof(XLAT_STR_252)
+#  endif
+#  ifdef XLAT_STR_253
+  + sizeof(XLAT_STR_253)
+#  endif
+#  ifdef XLAT_STR_254
+  + sizeof(XLAT_STR_254)
+#  endif
+#  ifdef XLAT_STR_255
+  + sizeof(XLAT_STR_255)
+#  endif
+#  ifdef XLAT_STR_256
+  + sizeof(XLAT_STR_256)
+#  endif
+#  ifdef XLAT_STR_257
+  + sizeof(XLAT_STR_257)
+#  endif
+#  ifdef XLAT_STR_258
+  + sizeof(XLAT_STR_258)
+#  endif
+#  ifdef XLAT_STR_259
+  + sizeof(XLAT_STR_259)
+#  endif
+#  ifdef XLAT_STR_260
+  + sizeof(XLAT_STR_260)
+#  endif
+#  ifdef XLAT_STR_261
+  + sizeof(XLAT_STR_261)
+#  endif
+#  ifdef XLAT_STR_262
+  + sizeof(XLAT_STR_262)
+#  endif
+#  ifdef XLAT_STR_263
+  + sizeof(XLAT_STR_263)
+#  endif
+#  ifdef XLAT_STR_264
+  + sizeof(XLAT_STR_264)
+#  endif
+#  ifdef XLAT_STR_265
+  + sizeof(XLAT_STR_265)
+#  endif
+#  ifdef XLAT_STR_266
+  + sizeof(XLAT_STR_266)
+#  endif
+#  ifdef XLAT_STR_267
+  + sizeof(XLAT_STR_267)
+#  endif
+#  ifdef XLAT_STR_268
+  + sizeof(XLAT_STR_268)
+#  endif
+#  ifdef XLAT_STR_269
+  + sizeof(XLAT_STR_269)
+#  endif
+#  ifdef XLAT_STR_270
+  + sizeof(XLAT_STR_270)
+#  endif
+#  ifdef XLAT_STR_271
+  + sizeof(XLAT_STR_271)
+#  endif
+#  ifdef XLAT_STR_272
+  + sizeof(XLAT_STR_272)
+#  endif
+#  ifdef XLAT_STR_273
+  + sizeof(XLAT_STR_273)
+#  endif
+#  ifdef XLAT_STR_274
+  + sizeof(XLAT_STR_274)
+#  endif
+#  ifdef XLAT_STR_275
+  + sizeof(XLAT_STR_275)
+#  endif
+#  ifdef XLAT_STR_276
+  + sizeof(XLAT_STR_276)
+#  endif
+#  ifdef XLAT_STR_277
+  + sizeof(XLAT_STR_277)
+#  endif
+#  ifdef XLAT_STR_278
+  + sizeof(XLAT_STR_278)
+#  endif
+#  ifdef XLAT_STR_279
+  + sizeof(XLAT_STR_279)
+#  endif
+#  ifdef XLAT_STR_280
+  + sizeof(XLAT_STR_280)
+#  endif
+#  ifdef XLAT_STR_281
+  + sizeof(XLAT_STR_281)
+#  endif
+#  ifdef XLAT_STR_282
+  + sizeof(XLAT_STR_282)
+#  endif
+#  ifdef XLAT_STR_283
+  + sizeof(XLAT_STR_283)
+#  endif
+#  ifdef XLAT_STR_284
+  + sizeof(XLAT_STR_284)
+#  endif
+#  ifdef XLAT_STR_285
+  + sizeof(XLAT_STR_285)
+#  endif
+#  ifdef XLAT_STR_286
+  + sizeof(XLAT_STR_286)
+#  endif
+#  ifdef XLAT_STR_287
+  + sizeof(XLAT_STR_287)
+#  endif
+#  ifdef XLAT_STR_288
+  + sizeof(XLAT_STR_288)
+#  endif
+#  ifdef XLAT_STR_289
+  + sizeof(XLAT_STR_289)
+#  endif
+#  ifdef XLAT_STR_290
+  + sizeof(XLAT_STR_290)
+#  endif
+#  ifdef XLAT_STR_291
+  + sizeof(XLAT_STR_291)
+#  endif
+#  ifdef XLAT_STR_292
+  + sizeof(XLAT_STR_292)
+#  endif
+#  ifdef XLAT_STR_293
+  + sizeof(XLAT_STR_293)
+#  endif
+#  ifdef XLAT_STR_294
+  + sizeof(XLAT_STR_294)
+#  endif
+#  ifdef XLAT_STR_295
+  + sizeof(XLAT_STR_295)
+#  endif
+#  ifdef XLAT_STR_296
+  + sizeof(XLAT_STR_296)
+#  endif
+#  ifdef XLAT_STR_297
+  + sizeof(XLAT_STR_297)
+#  endif
+#  ifdef XLAT_STR_298
+  + sizeof(XLAT_STR_298)
+#  endif
+#  ifdef XLAT_STR_299
+  + sizeof(XLAT_STR_299)
+#  endif
+#  ifdef XLAT_STR_300
+  + sizeof(XLAT_STR_300)
+#  endif
+#  ifdef XLAT_STR_301
+  + sizeof(XLAT_STR_301)
+#  endif
+#  ifdef XLAT_STR_302
+  + sizeof(XLAT_STR_302)
+#  endif
+#  ifdef XLAT_STR_303
+  + sizeof(XLAT_STR_303)
+#  endif
+#  ifdef XLAT_STR_304
+  + sizeof(XLAT_STR_304)
+#  endif
+#  ifdef XLAT_STR_305
+  + sizeof(XLAT_STR_305)
+#  endif
+#  ifdef XLAT_STR_306
+  + sizeof(XLAT_STR_306)
+#  endif
+#  ifdef XLAT_STR_307
+  + sizeof(XLAT_STR_307)
+#  endif
+#  ifdef XLAT_STR_308
+  + sizeof(XLAT_STR_308)
+#  endif
+#  ifdef XLAT_STR_309
+  + sizeof(XLAT_STR_309)
+#  endif
+#  ifdef XLAT_STR_310
+  + sizeof(XLAT_STR_310)
+#  endif
+#  ifdef XLAT_STR_311
+  + sizeof(XLAT_STR_311)
+#  endif
+#  ifdef XLAT_STR_312
+  + sizeof(XLAT_STR_312)
+#  endif
+#  ifdef XLAT_STR_313
+  + sizeof(XLAT_STR_313)
+#  endif
+#  ifdef XLAT_STR_314
+  + sizeof(XLAT_STR_314)
+#  endif
+#  ifdef XLAT_STR_315
+  + sizeof(XLAT_STR_315)
+#  endif
+#  ifdef XLAT_STR_316
+  + sizeof(XLAT_STR_316)
+#  endif
+#  ifdef XLAT_STR_317
+  + sizeof(XLAT_STR_317)
+#  endif
+#  ifdef XLAT_STR_318
+  + sizeof(XLAT_STR_318)
+#  endif
+#  ifdef XLAT_STR_319
+  + sizeof(XLAT_STR_319)
+#  endif
+#  ifdef XLAT_STR_320
+  + sizeof(XLAT_STR_320)
+#  endif
+#  ifdef XLAT_STR_321
+  + sizeof(XLAT_STR_321)
+#  endif
+#  ifdef XLAT_STR_322
+  + sizeof(XLAT_STR_322)
+#  endif
+#  ifdef XLAT_STR_323
+  + sizeof(XLAT_STR_323)
+#  endif
+#  ifdef XLAT_STR_324
+  + sizeof(XLAT_STR_324)
+#  endif
+#  ifdef XLAT_STR_325
+  + sizeof(XLAT_STR_325)
+#  endif
+#  ifdef XLAT_STR_326
+  + sizeof(XLAT_STR_326)
+#  endif
+#  ifdef XLAT_STR_327
+  + sizeof(XLAT_STR_327)
+#  endif
+#  ifdef XLAT_STR_328
+  + sizeof(XLAT_STR_328)
+#  endif
+#  ifdef XLAT_STR_329
+  + sizeof(XLAT_STR_329)
+#  endif
+#  ifdef XLAT_STR_330
+  + sizeof(XLAT_STR_330)
+#  endif
+#  ifdef XLAT_STR_331
+  + sizeof(XLAT_STR_331)
+#  endif
+#  ifdef XLAT_STR_332
+  + sizeof(XLAT_STR_332)
+#  endif
+#  ifdef XLAT_STR_333
+  + sizeof(XLAT_STR_333)
+#  endif
+#  ifdef XLAT_STR_334
+  + sizeof(XLAT_STR_334)
+#  endif
+#  ifdef XLAT_STR_335
+  + sizeof(XLAT_STR_335)
+#  endif
+#  ifdef XLAT_STR_336
+  + sizeof(XLAT_STR_336)
+#  endif
+#  ifdef XLAT_STR_337
+  + sizeof(XLAT_STR_337)
+#  endif
+#  ifdef XLAT_STR_338
+  + sizeof(XLAT_STR_338)
+#  endif
+#  ifdef XLAT_STR_339
+  + sizeof(XLAT_STR_339)
+#  endif
+#  ifdef XLAT_STR_340
+  + sizeof(XLAT_STR_340)
+#  endif
+#  ifdef XLAT_STR_341
+  + sizeof(XLAT_STR_341)
+#  endif
+#  ifdef XLAT_STR_342
+  + sizeof(XLAT_STR_342)
+#  endif
+#  ifdef XLAT_STR_343
+  + sizeof(XLAT_STR_343)
+#  endif
+#  ifdef XLAT_STR_344
+  + sizeof(XLAT_STR_344)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
+#  undef XLAT_STR_47
+#  undef XLAT_VAL_47
+#  undef XLAT_STR_48
+#  undef XLAT_VAL_48
+#  undef XLAT_STR_49
+#  undef XLAT_VAL_49
+#  undef XLAT_STR_50
+#  undef XLAT_VAL_50
+#  undef XLAT_STR_51
+#  undef XLAT_VAL_51
+#  undef XLAT_STR_52
+#  undef XLAT_VAL_52
+#  undef XLAT_STR_53
+#  undef XLAT_VAL_53
+#  undef XLAT_STR_54
+#  undef XLAT_VAL_54
+#  undef XLAT_STR_55
+#  undef XLAT_VAL_55
+#  undef XLAT_STR_56
+#  undef XLAT_VAL_56
+#  undef XLAT_STR_57
+#  undef XLAT_VAL_57
+#  undef XLAT_STR_58
+#  undef XLAT_VAL_58
+#  undef XLAT_STR_59
+#  undef XLAT_VAL_59
+#  undef XLAT_STR_60
+#  undef XLAT_VAL_60
+#  undef XLAT_STR_61
+#  undef XLAT_VAL_61
+#  undef XLAT_STR_62
+#  undef XLAT_VAL_62
+#  undef XLAT_STR_63
+#  undef XLAT_VAL_63
+#  undef XLAT_STR_64
+#  undef XLAT_VAL_64
+#  undef XLAT_STR_65
+#  undef XLAT_VAL_65
+#  undef XLAT_STR_66
+#  undef XLAT_VAL_66
+#  undef XLAT_STR_67
+#  undef XLAT_VAL_67
+#  undef XLAT_STR_68
+#  undef XLAT_VAL_68
+#  undef XLAT_STR_69
+#  undef XLAT_VAL_69
+#  undef XLAT_STR_70
+#  undef XLAT_VAL_70
+#  undef XLAT_STR_71
+#  undef XLAT_VAL_71
+#  undef XLAT_STR_72
+#  undef XLAT_VAL_72
+#  undef XLAT_STR_73
+#  undef XLAT_VAL_73
+#  undef XLAT_STR_74
+#  undef XLAT_VAL_74
+#  undef XLAT_STR_75
+#  undef XLAT_VAL_75
+#  undef XLAT_STR_76
+#  undef XLAT_VAL_76
+#  undef XLAT_STR_77
+#  undef XLAT_VAL_77
+#  undef XLAT_STR_78
+#  undef XLAT_VAL_78
+#  undef XLAT_STR_79
+#  undef XLAT_VAL_79
+#  undef XLAT_STR_80
+#  undef XLAT_VAL_80
+#  undef XLAT_STR_81
+#  undef XLAT_VAL_81
+#  undef XLAT_STR_82
+#  undef XLAT_VAL_82
+#  undef XLAT_STR_83
+#  undef XLAT_VAL_83
+#  undef XLAT_STR_84
+#  undef XLAT_VAL_84
+#  undef XLAT_STR_85
+#  undef XLAT_VAL_85
+#  undef XLAT_STR_86
+#  undef XLAT_VAL_86
+#  undef XLAT_STR_87
+#  undef XLAT_VAL_87
+#  undef XLAT_STR_88
+#  undef XLAT_VAL_88
+#  undef XLAT_STR_89
+#  undef XLAT_VAL_89
+#  undef XLAT_STR_90
+#  undef XLAT_VAL_90
+#  undef XLAT_STR_91
+#  undef XLAT_VAL_91
+#  undef XLAT_STR_92
+#  undef XLAT_VAL_92
+#  undef XLAT_STR_93
+#  undef XLAT_VAL_93
+#  undef XLAT_STR_94
+#  undef XLAT_VAL_94
+#  undef XLAT_STR_95
+#  undef XLAT_VAL_95
+#  undef XLAT_STR_96
+#  undef XLAT_VAL_96
+#  undef XLAT_STR_97
+#  undef XLAT_VAL_97
+#  undef XLAT_STR_98
+#  undef XLAT_VAL_98
+#  undef XLAT_STR_99
+#  undef XLAT_VAL_99
+#  undef XLAT_STR_100
+#  undef XLAT_VAL_100
+#  undef XLAT_STR_101
+#  undef XLAT_VAL_101
+#  undef XLAT_STR_102
+#  undef XLAT_VAL_102
+#  undef XLAT_STR_103
+#  undef XLAT_VAL_103
+#  undef XLAT_STR_104
+#  undef XLAT_VAL_104
+#  undef XLAT_STR_105
+#  undef XLAT_VAL_105
+#  undef XLAT_STR_106
+#  undef XLAT_VAL_106
+#  undef XLAT_STR_107
+#  undef XLAT_VAL_107
+#  undef XLAT_STR_108
+#  undef XLAT_VAL_108
+#  undef XLAT_STR_109
+#  undef XLAT_VAL_109
+#  undef XLAT_STR_110
+#  undef XLAT_VAL_110
+#  undef XLAT_STR_111
+#  undef XLAT_VAL_111
+#  undef XLAT_STR_112
+#  undef XLAT_VAL_112
+#  undef XLAT_STR_113
+#  undef XLAT_VAL_113
+#  undef XLAT_STR_114
+#  undef XLAT_VAL_114
+#  undef XLAT_STR_115
+#  undef XLAT_VAL_115
+#  undef XLAT_STR_116
+#  undef XLAT_VAL_116
+#  undef XLAT_STR_117
+#  undef XLAT_VAL_117
+#  undef XLAT_STR_118
+#  undef XLAT_VAL_118
+#  undef XLAT_STR_119
+#  undef XLAT_VAL_119
+#  undef XLAT_STR_120
+#  undef XLAT_VAL_120
+#  undef XLAT_STR_121
+#  undef XLAT_VAL_121
+#  undef XLAT_STR_122
+#  undef XLAT_VAL_122
+#  undef XLAT_STR_123
+#  undef XLAT_VAL_123
+#  undef XLAT_STR_124
+#  undef XLAT_VAL_124
+#  undef XLAT_STR_125
+#  undef XLAT_VAL_125
+#  undef XLAT_STR_126
+#  undef XLAT_VAL_126
+#  undef XLAT_STR_127
+#  undef XLAT_VAL_127
+#  undef XLAT_STR_128
+#  undef XLAT_VAL_128
+#  undef XLAT_STR_129
+#  undef XLAT_VAL_129
+#  undef XLAT_STR_130
+#  undef XLAT_VAL_130
+#  undef XLAT_STR_131
+#  undef XLAT_VAL_131
+#  undef XLAT_STR_132
+#  undef XLAT_VAL_132
+#  undef XLAT_STR_133
+#  undef XLAT_VAL_133
+#  undef XLAT_STR_134
+#  undef XLAT_VAL_134
+#  undef XLAT_STR_135
+#  undef XLAT_VAL_135
+#  undef XLAT_STR_136
+#  undef XLAT_VAL_136
+#  undef XLAT_STR_137
+#  undef XLAT_VAL_137
+#  undef XLAT_STR_138
+#  undef XLAT_VAL_138
+#  undef XLAT_STR_139
+#  undef XLAT_VAL_139
+#  undef XLAT_STR_140
+#  undef XLAT_VAL_140
+#  undef XLAT_STR_141
+#  undef XLAT_VAL_141
+#  undef XLAT_STR_142
+#  undef XLAT_VAL_142
+#  undef XLAT_STR_143
+#  undef XLAT_VAL_143
+#  undef XLAT_STR_144
+#  undef XLAT_VAL_144
+#  undef XLAT_STR_145
+#  undef XLAT_VAL_145
+#  undef XLAT_STR_146
+#  undef XLAT_VAL_146
+#  undef XLAT_STR_147
+#  undef XLAT_VAL_147
+#  undef XLAT_STR_148
+#  undef XLAT_VAL_148
+#  undef XLAT_STR_149
+#  undef XLAT_VAL_149
+#  undef XLAT_STR_150
+#  undef XLAT_VAL_150
+#  undef XLAT_STR_151
+#  undef XLAT_VAL_151
+#  undef XLAT_STR_152
+#  undef XLAT_VAL_152
+#  undef XLAT_STR_153
+#  undef XLAT_VAL_153
+#  undef XLAT_STR_154
+#  undef XLAT_VAL_154
+#  undef XLAT_STR_155
+#  undef XLAT_VAL_155
+#  undef XLAT_STR_156
+#  undef XLAT_VAL_156
+#  undef XLAT_STR_157
+#  undef XLAT_VAL_157
+#  undef XLAT_STR_158
+#  undef XLAT_VAL_158
+#  undef XLAT_STR_159
+#  undef XLAT_VAL_159
+#  undef XLAT_STR_160
+#  undef XLAT_VAL_160
+#  undef XLAT_STR_161
+#  undef XLAT_VAL_161
+#  undef XLAT_STR_162
+#  undef XLAT_VAL_162
+#  undef XLAT_STR_163
+#  undef XLAT_VAL_163
+#  undef XLAT_STR_164
+#  undef XLAT_VAL_164
+#  undef XLAT_STR_165
+#  undef XLAT_VAL_165
+#  undef XLAT_STR_166
+#  undef XLAT_VAL_166
+#  undef XLAT_STR_167
+#  undef XLAT_VAL_167
+#  undef XLAT_STR_168
+#  undef XLAT_VAL_168
+#  undef XLAT_STR_169
+#  undef XLAT_VAL_169
+#  undef XLAT_STR_170
+#  undef XLAT_VAL_170
+#  undef XLAT_STR_171
+#  undef XLAT_VAL_171
+#  undef XLAT_STR_172
+#  undef XLAT_VAL_172
+#  undef XLAT_STR_173
+#  undef XLAT_VAL_173
+#  undef XLAT_STR_174
+#  undef XLAT_VAL_174
+#  undef XLAT_STR_175
+#  undef XLAT_VAL_175
+#  undef XLAT_STR_176
+#  undef XLAT_VAL_176
+#  undef XLAT_STR_177
+#  undef XLAT_VAL_177
+#  undef XLAT_STR_178
+#  undef XLAT_VAL_178
+#  undef XLAT_STR_179
+#  undef XLAT_VAL_179
+#  undef XLAT_STR_180
+#  undef XLAT_VAL_180
+#  undef XLAT_STR_181
+#  undef XLAT_VAL_181
+#  undef XLAT_STR_182
+#  undef XLAT_VAL_182
+#  undef XLAT_STR_183
+#  undef XLAT_VAL_183
+#  undef XLAT_STR_184
+#  undef XLAT_VAL_184
+#  undef XLAT_STR_185
+#  undef XLAT_VAL_185
+#  undef XLAT_STR_186
+#  undef XLAT_VAL_186
+#  undef XLAT_STR_187
+#  undef XLAT_VAL_187
+#  undef XLAT_STR_188
+#  undef XLAT_VAL_188
+#  undef XLAT_STR_189
+#  undef XLAT_VAL_189
+#  undef XLAT_STR_190
+#  undef XLAT_VAL_190
+#  undef XLAT_STR_191
+#  undef XLAT_VAL_191
+#  undef XLAT_STR_192
+#  undef XLAT_VAL_192
+#  undef XLAT_STR_193
+#  undef XLAT_VAL_193
+#  undef XLAT_STR_194
+#  undef XLAT_VAL_194
+#  undef XLAT_STR_195
+#  undef XLAT_VAL_195
+#  undef XLAT_STR_196
+#  undef XLAT_VAL_196
+#  undef XLAT_STR_197
+#  undef XLAT_VAL_197
+#  undef XLAT_STR_198
+#  undef XLAT_VAL_198
+#  undef XLAT_STR_199
+#  undef XLAT_VAL_199
+#  undef XLAT_STR_200
+#  undef XLAT_VAL_200
+#  undef XLAT_STR_201
+#  undef XLAT_VAL_201
+#  undef XLAT_STR_202
+#  undef XLAT_VAL_202
+#  undef XLAT_STR_203
+#  undef XLAT_VAL_203
+#  undef XLAT_STR_204
+#  undef XLAT_VAL_204
+#  undef XLAT_STR_205
+#  undef XLAT_VAL_205
+#  undef XLAT_STR_206
+#  undef XLAT_VAL_206
+#  undef XLAT_STR_207
+#  undef XLAT_VAL_207
+#  undef XLAT_STR_208
+#  undef XLAT_VAL_208
+#  undef XLAT_STR_209
+#  undef XLAT_VAL_209
+#  undef XLAT_STR_210
+#  undef XLAT_VAL_210
+#  undef XLAT_STR_211
+#  undef XLAT_VAL_211
+#  undef XLAT_STR_212
+#  undef XLAT_VAL_212
+#  undef XLAT_STR_213
+#  undef XLAT_VAL_213
+#  undef XLAT_STR_214
+#  undef XLAT_VAL_214
+#  undef XLAT_STR_215
+#  undef XLAT_VAL_215
+#  undef XLAT_STR_216
+#  undef XLAT_VAL_216
+#  undef XLAT_STR_217
+#  undef XLAT_VAL_217
+#  undef XLAT_STR_218
+#  undef XLAT_VAL_218
+#  undef XLAT_STR_219
+#  undef XLAT_VAL_219
+#  undef XLAT_STR_220
+#  undef XLAT_VAL_220
+#  undef XLAT_STR_221
+#  undef XLAT_VAL_221
+#  undef XLAT_STR_222
+#  undef XLAT_VAL_222
+#  undef XLAT_STR_223
+#  undef XLAT_VAL_223
+#  undef XLAT_STR_224
+#  undef XLAT_VAL_224
+#  undef XLAT_STR_225
+#  undef XLAT_VAL_225
+#  undef XLAT_STR_226
+#  undef XLAT_VAL_226
+#  undef XLAT_STR_227
+#  undef XLAT_VAL_227
+#  undef XLAT_STR_228
+#  undef XLAT_VAL_228
+#  undef XLAT_STR_229
+#  undef XLAT_VAL_229
+#  undef XLAT_STR_230
+#  undef XLAT_VAL_230
+#  undef XLAT_STR_231
+#  undef XLAT_VAL_231
+#  undef XLAT_STR_232
+#  undef XLAT_VAL_232
+#  undef XLAT_STR_233
+#  undef XLAT_VAL_233
+#  undef XLAT_STR_234
+#  undef XLAT_VAL_234
+#  undef XLAT_STR_235
+#  undef XLAT_VAL_235
+#  undef XLAT_STR_236
+#  undef XLAT_VAL_236
+#  undef XLAT_STR_237
+#  undef XLAT_VAL_237
+#  undef XLAT_STR_238
+#  undef XLAT_VAL_238
+#  undef XLAT_STR_239
+#  undef XLAT_VAL_239
+#  undef XLAT_STR_240
+#  undef XLAT_VAL_240
+#  undef XLAT_STR_241
+#  undef XLAT_VAL_241
+#  undef XLAT_STR_242
+#  undef XLAT_VAL_242
+#  undef XLAT_STR_243
+#  undef XLAT_VAL_243
+#  undef XLAT_STR_244
+#  undef XLAT_VAL_244
+#  undef XLAT_STR_245
+#  undef XLAT_VAL_245
+#  undef XLAT_STR_246
+#  undef XLAT_VAL_246
+#  undef XLAT_STR_247
+#  undef XLAT_VAL_247
+#  undef XLAT_STR_248
+#  undef XLAT_VAL_248
+#  undef XLAT_STR_249
+#  undef XLAT_VAL_249
+#  undef XLAT_STR_250
+#  undef XLAT_VAL_250
+#  undef XLAT_STR_251
+#  undef XLAT_VAL_251
+#  undef XLAT_STR_252
+#  undef XLAT_VAL_252
+#  undef XLAT_STR_253
+#  undef XLAT_VAL_253
+#  undef XLAT_STR_254
+#  undef XLAT_VAL_254
+#  undef XLAT_STR_255
+#  undef XLAT_VAL_255
+#  undef XLAT_STR_256
+#  undef XLAT_VAL_256
+#  undef XLAT_STR_257
+#  undef XLAT_VAL_257
+#  undef XLAT_STR_258
+#  undef XLAT_VAL_258
+#  undef XLAT_STR_259
+#  undef XLAT_VAL_259
+#  undef XLAT_STR_260
+#  undef XLAT_VAL_260
+#  undef XLAT_STR_261
+#  undef XLAT_VAL_261
+#  undef XLAT_STR_262
+#  undef XLAT_VAL_262
+#  undef XLAT_STR_263
+#  undef XLAT_VAL_263
+#  undef XLAT_STR_264
+#  undef XLAT_VAL_264
+#  undef XLAT_STR_265
+#  undef XLAT_VAL_265
+#  undef XLAT_STR_266
+#  undef XLAT_VAL_266
+#  undef XLAT_STR_267
+#  undef XLAT_VAL_267
+#  undef XLAT_STR_268
+#  undef XLAT_VAL_268
+#  undef XLAT_STR_269
+#  undef XLAT_VAL_269
+#  undef XLAT_STR_270
+#  undef XLAT_VAL_270
+#  undef XLAT_STR_271
+#  undef XLAT_VAL_271
+#  undef XLAT_STR_272
+#  undef XLAT_VAL_272
+#  undef XLAT_STR_273
+#  undef XLAT_VAL_273
+#  undef XLAT_STR_274
+#  undef XLAT_VAL_274
+#  undef XLAT_STR_275
+#  undef XLAT_VAL_275
+#  undef XLAT_STR_276
+#  undef XLAT_VAL_276
+#  undef XLAT_STR_277
+#  undef XLAT_VAL_277
+#  undef XLAT_STR_278
+#  undef XLAT_VAL_278
+#  undef XLAT_STR_279
+#  undef XLAT_VAL_279
+#  undef XLAT_STR_280
+#  undef XLAT_VAL_280
+#  undef XLAT_STR_281
+#  undef XLAT_VAL_281
+#  undef XLAT_STR_282
+#  undef XLAT_VAL_282
+#  undef XLAT_STR_283
+#  undef XLAT_VAL_283
+#  undef XLAT_STR_284
+#  undef XLAT_VAL_284
+#  undef XLAT_STR_285
+#  undef XLAT_VAL_285
+#  undef XLAT_STR_286
+#  undef XLAT_VAL_286
+#  undef XLAT_STR_287
+#  undef XLAT_VAL_287
+#  undef XLAT_STR_288
+#  undef XLAT_VAL_288
+#  undef XLAT_STR_289
+#  undef XLAT_VAL_289
+#  undef XLAT_STR_290
+#  undef XLAT_VAL_290
+#  undef XLAT_STR_291
+#  undef XLAT_VAL_291
+#  undef XLAT_STR_292
+#  undef XLAT_VAL_292
+#  undef XLAT_STR_293
+#  undef XLAT_VAL_293
+#  undef XLAT_STR_294
+#  undef XLAT_VAL_294
+#  undef XLAT_STR_295
+#  undef XLAT_VAL_295
+#  undef XLAT_STR_296
+#  undef XLAT_VAL_296
+#  undef XLAT_STR_297
+#  undef XLAT_VAL_297
+#  undef XLAT_STR_298
+#  undef XLAT_VAL_298
+#  undef XLAT_STR_299
+#  undef XLAT_VAL_299
+#  undef XLAT_STR_300
+#  undef XLAT_VAL_300
+#  undef XLAT_STR_301
+#  undef XLAT_VAL_301
+#  undef XLAT_STR_302
+#  undef XLAT_VAL_302
+#  undef XLAT_STR_303
+#  undef XLAT_VAL_303
+#  undef XLAT_STR_304
+#  undef XLAT_VAL_304
+#  undef XLAT_STR_305
+#  undef XLAT_VAL_305
+#  undef XLAT_STR_306
+#  undef XLAT_VAL_306
+#  undef XLAT_STR_307
+#  undef XLAT_VAL_307
+#  undef XLAT_STR_308
+#  undef XLAT_VAL_308
+#  undef XLAT_STR_309
+#  undef XLAT_VAL_309
+#  undef XLAT_STR_310
+#  undef XLAT_VAL_310
+#  undef XLAT_STR_311
+#  undef XLAT_VAL_311
+#  undef XLAT_STR_312
+#  undef XLAT_VAL_312
+#  undef XLAT_STR_313
+#  undef XLAT_VAL_313
+#  undef XLAT_STR_314
+#  undef XLAT_VAL_314
+#  undef XLAT_STR_315
+#  undef XLAT_VAL_315
+#  undef XLAT_STR_316
+#  undef XLAT_VAL_316
+#  undef XLAT_STR_317
+#  undef XLAT_VAL_317
+#  undef XLAT_STR_318
+#  undef XLAT_VAL_318
+#  undef XLAT_STR_319
+#  undef XLAT_VAL_319
+#  undef XLAT_STR_320
+#  undef XLAT_VAL_320
+#  undef XLAT_STR_321
+#  undef XLAT_VAL_321
+#  undef XLAT_STR_322
+#  undef XLAT_VAL_322
+#  undef XLAT_STR_323
+#  undef XLAT_VAL_323
+#  undef XLAT_STR_324
+#  undef XLAT_VAL_324
+#  undef XLAT_STR_325
+#  undef XLAT_VAL_325
+#  undef XLAT_STR_326
+#  undef XLAT_VAL_326
+#  undef XLAT_STR_327
+#  undef XLAT_VAL_327
+#  undef XLAT_STR_328
+#  undef XLAT_VAL_328
+#  undef XLAT_STR_329
+#  undef XLAT_VAL_329
+#  undef XLAT_STR_330
+#  undef XLAT_VAL_330
+#  undef XLAT_STR_331
+#  undef XLAT_VAL_331
+#  undef XLAT_STR_332
+#  undef XLAT_VAL_332
+#  undef XLAT_STR_333
+#  undef XLAT_VAL_333
+#  undef XLAT_STR_334
+#  undef XLAT_VAL_334
+#  undef XLAT_STR_335
+#  undef XLAT_VAL_335
+#  undef XLAT_STR_336
+#  undef XLAT_VAL_336
+#  undef XLAT_STR_337
+#  undef XLAT_VAL_337
+#  undef XLAT_STR_338
+#  undef XLAT_VAL_338
+#  undef XLAT_STR_339
+#  undef XLAT_VAL_339
+#  undef XLAT_STR_340
+#  undef XLAT_VAL_340
+#  undef XLAT_STR_341
+#  undef XLAT_VAL_341
+#  undef XLAT_STR_342
+#  undef XLAT_VAL_342
+#  undef XLAT_STR_343
+#  undef XLAT_VAL_343
+#  undef XLAT_STR_344
+#  undef XLAT_VAL_344
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_control_query_flags.h 5.9-0ubuntu2/xlat/v4l2_control_query_flags.h
--- 5.5-3/xlat/v4l2_control_query_flags.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_control_query_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,68 @@
+/* Generated by ./xlat/gen.sh from ./xlat/v4l2_control_query_flags.in; do not edit. */
+
+#include "gcc_compat.h"
+#include "static_assert.h"
+
+#if defined(V4L2_CTRL_FLAG_NEXT_CTRL) || (defined(HAVE_DECL_V4L2_CTRL_FLAG_NEXT_CTRL) && HAVE_DECL_V4L2_CTRL_FLAG_NEXT_CTRL)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_CTRL_FLAG_NEXT_CTRL) == (0x80000000), "V4L2_CTRL_FLAG_NEXT_CTRL != 0x80000000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_CTRL_FLAG_NEXT_CTRL 0x80000000
+#endif
+#if defined(V4L2_CTRL_FLAG_NEXT_COMPOUND) || (defined(HAVE_DECL_V4L2_CTRL_FLAG_NEXT_COMPOUND) && HAVE_DECL_V4L2_CTRL_FLAG_NEXT_COMPOUND)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_CTRL_FLAG_NEXT_COMPOUND) == (0x40000000), "V4L2_CTRL_FLAG_NEXT_COMPOUND != 0x40000000");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_CTRL_FLAG_NEXT_COMPOUND 0x40000000
+#endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+extern const struct xlat v4l2_control_query_flags[];
+
+# else
+
+static const struct xlat_data v4l2_control_query_flags_xdata[] = {
+ XLAT(V4L2_CTRL_FLAG_NEXT_CTRL),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_CTRL_FLAG_NEXT_CTRL))
+ #define XLAT_STR_0 STRINGIFY(V4L2_CTRL_FLAG_NEXT_CTRL)
+ XLAT(V4L2_CTRL_FLAG_NEXT_COMPOUND),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_CTRL_FLAG_NEXT_COMPOUND))
+ #define XLAT_STR_1 STRINGIFY(V4L2_CTRL_FLAG_NEXT_COMPOUND)
+};
+#  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
+static
+#  endif
+const struct xlat v4l2_control_query_flags[1] = { {
+ .data = v4l2_control_query_flags_xdata,
+ .size = ARRAY_SIZE(v4l2_control_query_flags_xdata),
+ .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
+} };
+
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+# endif /* !IN_MPERS */
+
+#endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_control_query_flags.in 5.9-0ubuntu2/xlat/v4l2_control_query_flags.in
--- 5.5-3/xlat/v4l2_control_query_flags.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_control_query_flags.in	2020-03-30 21:14:23.000000000 +0000
@@ -0,0 +1,2 @@
+V4L2_CTRL_FLAG_NEXT_CTRL	0x80000000
+V4L2_CTRL_FLAG_NEXT_COMPOUND	0x40000000
diff -pruN 5.5-3/xlat/v4l2_control_types.h 5.9-0ubuntu2/xlat/v4l2_control_types.h
--- 5.5-3/xlat/v4l2_control_types.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_control_types.h	2020-09-24 09:18:46.000000000 +0000
@@ -105,18 +105,44 @@ extern const struct xlat v4l2_control_ty
 
 static const struct xlat_data v4l2_control_types_xdata[] = {
  XLAT(V4L2_CTRL_TYPE_INTEGER),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_CTRL_TYPE_INTEGER))
+ #define XLAT_STR_0 STRINGIFY(V4L2_CTRL_TYPE_INTEGER)
  XLAT(V4L2_CTRL_TYPE_BOOLEAN),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_CTRL_TYPE_BOOLEAN))
+ #define XLAT_STR_1 STRINGIFY(V4L2_CTRL_TYPE_BOOLEAN)
  XLAT(V4L2_CTRL_TYPE_MENU),
+ #define XLAT_VAL_2 ((unsigned) (V4L2_CTRL_TYPE_MENU))
+ #define XLAT_STR_2 STRINGIFY(V4L2_CTRL_TYPE_MENU)
  XLAT(V4L2_CTRL_TYPE_BUTTON),
+ #define XLAT_VAL_3 ((unsigned) (V4L2_CTRL_TYPE_BUTTON))
+ #define XLAT_STR_3 STRINGIFY(V4L2_CTRL_TYPE_BUTTON)
  XLAT(V4L2_CTRL_TYPE_INTEGER64),
+ #define XLAT_VAL_4 ((unsigned) (V4L2_CTRL_TYPE_INTEGER64))
+ #define XLAT_STR_4 STRINGIFY(V4L2_CTRL_TYPE_INTEGER64)
  XLAT(V4L2_CTRL_TYPE_CTRL_CLASS),
+ #define XLAT_VAL_5 ((unsigned) (V4L2_CTRL_TYPE_CTRL_CLASS))
+ #define XLAT_STR_5 STRINGIFY(V4L2_CTRL_TYPE_CTRL_CLASS)
  XLAT(V4L2_CTRL_TYPE_STRING),
+ #define XLAT_VAL_6 ((unsigned) (V4L2_CTRL_TYPE_STRING))
+ #define XLAT_STR_6 STRINGIFY(V4L2_CTRL_TYPE_STRING)
  XLAT(V4L2_CTRL_TYPE_BITMASK),
+ #define XLAT_VAL_7 ((unsigned) (V4L2_CTRL_TYPE_BITMASK))
+ #define XLAT_STR_7 STRINGIFY(V4L2_CTRL_TYPE_BITMASK)
  XLAT(V4L2_CTRL_TYPE_INTEGER_MENU),
+ #define XLAT_VAL_8 ((unsigned) (V4L2_CTRL_TYPE_INTEGER_MENU))
+ #define XLAT_STR_8 STRINGIFY(V4L2_CTRL_TYPE_INTEGER_MENU)
  XLAT(V4L2_CTRL_TYPE_U8),
+ #define XLAT_VAL_9 ((unsigned) (V4L2_CTRL_TYPE_U8))
+ #define XLAT_STR_9 STRINGIFY(V4L2_CTRL_TYPE_U8)
  XLAT(V4L2_CTRL_TYPE_U16),
+ #define XLAT_VAL_10 ((unsigned) (V4L2_CTRL_TYPE_U16))
+ #define XLAT_STR_10 STRINGIFY(V4L2_CTRL_TYPE_U16)
  XLAT(V4L2_CTRL_TYPE_U32),
+ #define XLAT_VAL_11 ((unsigned) (V4L2_CTRL_TYPE_U32))
+ #define XLAT_STR_11 STRINGIFY(V4L2_CTRL_TYPE_U32)
  XLAT(V4L2_CTRL_TYPE_AREA),
+ #define XLAT_VAL_12 ((unsigned) (V4L2_CTRL_TYPE_AREA))
+ #define XLAT_STR_12 STRINGIFY(V4L2_CTRL_TYPE_AREA)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -125,8 +151,116 @@ const struct xlat v4l2_control_types[1]
  .data = v4l2_control_types_xdata,
  .size = ARRAY_SIZE(v4l2_control_types_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_control_types.in 5.9-0ubuntu2/xlat/v4l2_control_types.in
--- 5.5-3/xlat/v4l2_control_types.in	2020-01-07 23:31:49.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_control_types.in	2020-05-30 08:00:00.000000000 +0000
@@ -1,4 +1,9 @@
 #sorted
+#enum
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 V4L2_CTRL_TYPE_INTEGER			1
 V4L2_CTRL_TYPE_BOOLEAN			2
 V4L2_CTRL_TYPE_MENU			3
diff -pruN 5.5-3/xlat/v4l2_control_types.m4 5.9-0ubuntu2/xlat/v4l2_control_types.m4
--- 5.5-3/xlat/v4l2_control_types.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_control_types.m4	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,22 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/v4l2_control_types.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_v4l2_control_types],[
+AC_CHECK_DECLS(m4_normalize([
+V4L2_CTRL_TYPE_INTEGER,
+V4L2_CTRL_TYPE_BOOLEAN,
+V4L2_CTRL_TYPE_MENU,
+V4L2_CTRL_TYPE_BUTTON,
+V4L2_CTRL_TYPE_INTEGER64,
+V4L2_CTRL_TYPE_CTRL_CLASS,
+V4L2_CTRL_TYPE_STRING,
+V4L2_CTRL_TYPE_BITMASK,
+V4L2_CTRL_TYPE_INTEGER_MENU,
+V4L2_CTRL_TYPE_U8,
+V4L2_CTRL_TYPE_U16,
+V4L2_CTRL_TYPE_U32,
+V4L2_CTRL_TYPE_AREA
+]),,, [
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+])])])
diff -pruN 5.5-3/xlat/v4l2_device_capabilities_flags.h 5.9-0ubuntu2/xlat/v4l2_device_capabilities_flags.h
--- 5.5-3/xlat/v4l2_device_capabilities_flags.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_device_capabilities_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -217,34 +217,92 @@ extern const struct xlat v4l2_device_cap
 
 static const struct xlat_data v4l2_device_capabilities_flags_xdata[] = {
  XLAT(V4L2_CAP_VIDEO_CAPTURE),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_CAP_VIDEO_CAPTURE))
+ #define XLAT_STR_0 STRINGIFY(V4L2_CAP_VIDEO_CAPTURE)
  XLAT(V4L2_CAP_VIDEO_OUTPUT),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_CAP_VIDEO_OUTPUT))
+ #define XLAT_STR_1 STRINGIFY(V4L2_CAP_VIDEO_OUTPUT)
  XLAT(V4L2_CAP_VIDEO_OVERLAY),
+ #define XLAT_VAL_2 ((unsigned) (V4L2_CAP_VIDEO_OVERLAY))
+ #define XLAT_STR_2 STRINGIFY(V4L2_CAP_VIDEO_OVERLAY)
  XLAT(V4L2_CAP_VBI_CAPTURE),
+ #define XLAT_VAL_3 ((unsigned) (V4L2_CAP_VBI_CAPTURE))
+ #define XLAT_STR_3 STRINGIFY(V4L2_CAP_VBI_CAPTURE)
  XLAT(V4L2_CAP_VBI_OUTPUT),
+ #define XLAT_VAL_4 ((unsigned) (V4L2_CAP_VBI_OUTPUT))
+ #define XLAT_STR_4 STRINGIFY(V4L2_CAP_VBI_OUTPUT)
  XLAT(V4L2_CAP_SLICED_VBI_CAPTURE),
+ #define XLAT_VAL_5 ((unsigned) (V4L2_CAP_SLICED_VBI_CAPTURE))
+ #define XLAT_STR_5 STRINGIFY(V4L2_CAP_SLICED_VBI_CAPTURE)
  XLAT(V4L2_CAP_SLICED_VBI_OUTPUT),
+ #define XLAT_VAL_6 ((unsigned) (V4L2_CAP_SLICED_VBI_OUTPUT))
+ #define XLAT_STR_6 STRINGIFY(V4L2_CAP_SLICED_VBI_OUTPUT)
  XLAT(V4L2_CAP_RDS_CAPTURE),
+ #define XLAT_VAL_7 ((unsigned) (V4L2_CAP_RDS_CAPTURE))
+ #define XLAT_STR_7 STRINGIFY(V4L2_CAP_RDS_CAPTURE)
  XLAT(V4L2_CAP_VIDEO_OUTPUT_OVERLAY),
+ #define XLAT_VAL_8 ((unsigned) (V4L2_CAP_VIDEO_OUTPUT_OVERLAY))
+ #define XLAT_STR_8 STRINGIFY(V4L2_CAP_VIDEO_OUTPUT_OVERLAY)
  XLAT(V4L2_CAP_HW_FREQ_SEEK),
+ #define XLAT_VAL_9 ((unsigned) (V4L2_CAP_HW_FREQ_SEEK))
+ #define XLAT_STR_9 STRINGIFY(V4L2_CAP_HW_FREQ_SEEK)
  XLAT(V4L2_CAP_RDS_OUTPUT),
+ #define XLAT_VAL_10 ((unsigned) (V4L2_CAP_RDS_OUTPUT))
+ #define XLAT_STR_10 STRINGIFY(V4L2_CAP_RDS_OUTPUT)
  XLAT(V4L2_CAP_VIDEO_CAPTURE_MPLANE),
+ #define XLAT_VAL_11 ((unsigned) (V4L2_CAP_VIDEO_CAPTURE_MPLANE))
+ #define XLAT_STR_11 STRINGIFY(V4L2_CAP_VIDEO_CAPTURE_MPLANE)
  XLAT(V4L2_CAP_VIDEO_OUTPUT_MPLANE),
+ #define XLAT_VAL_12 ((unsigned) (V4L2_CAP_VIDEO_OUTPUT_MPLANE))
+ #define XLAT_STR_12 STRINGIFY(V4L2_CAP_VIDEO_OUTPUT_MPLANE)
  XLAT(V4L2_CAP_VIDEO_M2M_MPLANE),
+ #define XLAT_VAL_13 ((unsigned) (V4L2_CAP_VIDEO_M2M_MPLANE))
+ #define XLAT_STR_13 STRINGIFY(V4L2_CAP_VIDEO_M2M_MPLANE)
  XLAT(V4L2_CAP_VIDEO_M2M),
+ #define XLAT_VAL_14 ((unsigned) (V4L2_CAP_VIDEO_M2M))
+ #define XLAT_STR_14 STRINGIFY(V4L2_CAP_VIDEO_M2M)
  XLAT(V4L2_CAP_TUNER),
+ #define XLAT_VAL_15 ((unsigned) (V4L2_CAP_TUNER))
+ #define XLAT_STR_15 STRINGIFY(V4L2_CAP_TUNER)
  XLAT(V4L2_CAP_AUDIO),
+ #define XLAT_VAL_16 ((unsigned) (V4L2_CAP_AUDIO))
+ #define XLAT_STR_16 STRINGIFY(V4L2_CAP_AUDIO)
  XLAT(V4L2_CAP_RADIO),
+ #define XLAT_VAL_17 ((unsigned) (V4L2_CAP_RADIO))
+ #define XLAT_STR_17 STRINGIFY(V4L2_CAP_RADIO)
  XLAT(V4L2_CAP_MODULATOR),
+ #define XLAT_VAL_18 ((unsigned) (V4L2_CAP_MODULATOR))
+ #define XLAT_STR_18 STRINGIFY(V4L2_CAP_MODULATOR)
  XLAT(V4L2_CAP_SDR_CAPTURE),
+ #define XLAT_VAL_19 ((unsigned) (V4L2_CAP_SDR_CAPTURE))
+ #define XLAT_STR_19 STRINGIFY(V4L2_CAP_SDR_CAPTURE)
  XLAT(V4L2_CAP_EXT_PIX_FORMAT),
+ #define XLAT_VAL_20 ((unsigned) (V4L2_CAP_EXT_PIX_FORMAT))
+ #define XLAT_STR_20 STRINGIFY(V4L2_CAP_EXT_PIX_FORMAT)
  XLAT(V4L2_CAP_SDR_OUTPUT),
+ #define XLAT_VAL_21 ((unsigned) (V4L2_CAP_SDR_OUTPUT))
+ #define XLAT_STR_21 STRINGIFY(V4L2_CAP_SDR_OUTPUT)
  XLAT(V4L2_CAP_META_CAPTURE),
+ #define XLAT_VAL_22 ((unsigned) (V4L2_CAP_META_CAPTURE))
+ #define XLAT_STR_22 STRINGIFY(V4L2_CAP_META_CAPTURE)
  XLAT(V4L2_CAP_READWRITE),
+ #define XLAT_VAL_23 ((unsigned) (V4L2_CAP_READWRITE))
+ #define XLAT_STR_23 STRINGIFY(V4L2_CAP_READWRITE)
  XLAT(V4L2_CAP_ASYNCIO),
+ #define XLAT_VAL_24 ((unsigned) (V4L2_CAP_ASYNCIO))
+ #define XLAT_STR_24 STRINGIFY(V4L2_CAP_ASYNCIO)
  XLAT(V4L2_CAP_STREAMING),
+ #define XLAT_VAL_25 ((unsigned) (V4L2_CAP_STREAMING))
+ #define XLAT_STR_25 STRINGIFY(V4L2_CAP_STREAMING)
  XLAT(V4L2_CAP_META_OUTPUT),
+ #define XLAT_VAL_26 ((unsigned) (V4L2_CAP_META_OUTPUT))
+ #define XLAT_STR_26 STRINGIFY(V4L2_CAP_META_OUTPUT)
  XLAT(V4L2_CAP_TOUCH),
+ #define XLAT_VAL_27 ((unsigned) (V4L2_CAP_TOUCH))
+ #define XLAT_STR_27 STRINGIFY(V4L2_CAP_TOUCH)
  XLAT(V4L2_CAP_DEVICE_CAPS),
+ #define XLAT_VAL_28 ((unsigned) (V4L2_CAP_DEVICE_CAPS))
+ #define XLAT_STR_28 STRINGIFY(V4L2_CAP_DEVICE_CAPS)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -253,8 +311,244 @@ const struct xlat v4l2_device_capabiliti
  .data = v4l2_device_capabilities_flags_xdata,
  .size = ARRAY_SIZE(v4l2_device_capabilities_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_fields.h 5.9-0ubuntu2/xlat/v4l2_fields.h
--- 5.5-3/xlat/v4l2_fields.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_fields.h	2020-09-24 09:18:46.000000000 +0000
@@ -84,15 +84,35 @@ extern const struct xlat v4l2_fields[];
 
 static const struct xlat_data v4l2_fields_xdata[] = {
  [V4L2_FIELD_ANY] = XLAT(V4L2_FIELD_ANY),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_FIELD_ANY))
+ #define XLAT_STR_0 STRINGIFY(V4L2_FIELD_ANY)
  [V4L2_FIELD_NONE] = XLAT(V4L2_FIELD_NONE),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_FIELD_NONE))
+ #define XLAT_STR_1 STRINGIFY(V4L2_FIELD_NONE)
  [V4L2_FIELD_TOP] = XLAT(V4L2_FIELD_TOP),
+ #define XLAT_VAL_2 ((unsigned) (V4L2_FIELD_TOP))
+ #define XLAT_STR_2 STRINGIFY(V4L2_FIELD_TOP)
  [V4L2_FIELD_BOTTOM] = XLAT(V4L2_FIELD_BOTTOM),
+ #define XLAT_VAL_3 ((unsigned) (V4L2_FIELD_BOTTOM))
+ #define XLAT_STR_3 STRINGIFY(V4L2_FIELD_BOTTOM)
  [V4L2_FIELD_INTERLACED] = XLAT(V4L2_FIELD_INTERLACED),
+ #define XLAT_VAL_4 ((unsigned) (V4L2_FIELD_INTERLACED))
+ #define XLAT_STR_4 STRINGIFY(V4L2_FIELD_INTERLACED)
  [V4L2_FIELD_SEQ_TB] = XLAT(V4L2_FIELD_SEQ_TB),
+ #define XLAT_VAL_5 ((unsigned) (V4L2_FIELD_SEQ_TB))
+ #define XLAT_STR_5 STRINGIFY(V4L2_FIELD_SEQ_TB)
  [V4L2_FIELD_SEQ_BT] = XLAT(V4L2_FIELD_SEQ_BT),
+ #define XLAT_VAL_6 ((unsigned) (V4L2_FIELD_SEQ_BT))
+ #define XLAT_STR_6 STRINGIFY(V4L2_FIELD_SEQ_BT)
  [V4L2_FIELD_ALTERNATE] = XLAT(V4L2_FIELD_ALTERNATE),
+ #define XLAT_VAL_7 ((unsigned) (V4L2_FIELD_ALTERNATE))
+ #define XLAT_STR_7 STRINGIFY(V4L2_FIELD_ALTERNATE)
  [V4L2_FIELD_INTERLACED_TB] = XLAT(V4L2_FIELD_INTERLACED_TB),
+ #define XLAT_VAL_8 ((unsigned) (V4L2_FIELD_INTERLACED_TB))
+ #define XLAT_STR_8 STRINGIFY(V4L2_FIELD_INTERLACED_TB)
  [V4L2_FIELD_INTERLACED_BT] = XLAT(V4L2_FIELD_INTERLACED_BT),
+ #define XLAT_VAL_9 ((unsigned) (V4L2_FIELD_INTERLACED_BT))
+ #define XLAT_STR_9 STRINGIFY(V4L2_FIELD_INTERLACED_BT)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -101,8 +121,92 @@ const struct xlat v4l2_fields[1] = { {
  .data = v4l2_fields_xdata,
  .size = ARRAY_SIZE(v4l2_fields_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_fields.in 5.9-0ubuntu2/xlat/v4l2_fields.in
--- 5.5-3/xlat/v4l2_fields.in	2019-10-22 17:44:08.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_fields.in	2020-05-30 08:00:00.000000000 +0000
@@ -1,4 +1,9 @@
 #value_indexed
+#enum
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 V4L2_FIELD_ANY			0
 V4L2_FIELD_NONE			1
 V4L2_FIELD_TOP			2
diff -pruN 5.5-3/xlat/v4l2_fields.m4 5.9-0ubuntu2/xlat/v4l2_fields.m4
--- 5.5-3/xlat/v4l2_fields.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_fields.m4	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,19 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/v4l2_fields.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_v4l2_fields],[
+AC_CHECK_DECLS(m4_normalize([
+V4L2_FIELD_ANY,
+V4L2_FIELD_NONE,
+V4L2_FIELD_TOP,
+V4L2_FIELD_BOTTOM,
+V4L2_FIELD_INTERLACED,
+V4L2_FIELD_SEQ_TB,
+V4L2_FIELD_SEQ_BT,
+V4L2_FIELD_ALTERNATE,
+V4L2_FIELD_INTERLACED_TB,
+V4L2_FIELD_INTERLACED_BT
+]),,, [
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+])])])
diff -pruN 5.5-3/xlat/v4l2_format_description_flags.h 5.9-0ubuntu2/xlat/v4l2_format_description_flags.h
--- 5.5-3/xlat/v4l2_format_description_flags.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_format_description_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -31,6 +31,13 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define V4L2_FMT_FLAG_DYN_RESOLUTION 0x0008
 #endif
+#if defined(V4L2_FMT_FLAG_ENC_CAP_FRAME_INTERVAL) || (defined(HAVE_DECL_V4L2_FMT_FLAG_ENC_CAP_FRAME_INTERVAL) && HAVE_DECL_V4L2_FMT_FLAG_ENC_CAP_FRAME_INTERVAL)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_FMT_FLAG_ENC_CAP_FRAME_INTERVAL) == (0x0010), "V4L2_FMT_FLAG_ENC_CAP_FRAME_INTERVAL != 0x0010");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_FMT_FLAG_ENC_CAP_FRAME_INTERVAL 0x0010
+#endif
 
 #ifndef XLAT_MACROS_ONLY
 
@@ -42,9 +49,20 @@ extern const struct xlat v4l2_format_des
 
 static const struct xlat_data v4l2_format_description_flags_xdata[] = {
  XLAT(V4L2_FMT_FLAG_COMPRESSED),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_FMT_FLAG_COMPRESSED))
+ #define XLAT_STR_0 STRINGIFY(V4L2_FMT_FLAG_COMPRESSED)
  XLAT(V4L2_FMT_FLAG_EMULATED),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_FMT_FLAG_EMULATED))
+ #define XLAT_STR_1 STRINGIFY(V4L2_FMT_FLAG_EMULATED)
  XLAT(V4L2_FMT_FLAG_CONTINUOUS_BYTESTREAM),
+ #define XLAT_VAL_2 ((unsigned) (V4L2_FMT_FLAG_CONTINUOUS_BYTESTREAM))
+ #define XLAT_STR_2 STRINGIFY(V4L2_FMT_FLAG_CONTINUOUS_BYTESTREAM)
  XLAT(V4L2_FMT_FLAG_DYN_RESOLUTION),
+ #define XLAT_VAL_3 ((unsigned) (V4L2_FMT_FLAG_DYN_RESOLUTION))
+ #define XLAT_STR_3 STRINGIFY(V4L2_FMT_FLAG_DYN_RESOLUTION)
+ XLAT(V4L2_FMT_FLAG_ENC_CAP_FRAME_INTERVAL),
+ #define XLAT_VAL_4 ((unsigned) (V4L2_FMT_FLAG_ENC_CAP_FRAME_INTERVAL))
+ #define XLAT_STR_4 STRINGIFY(V4L2_FMT_FLAG_ENC_CAP_FRAME_INTERVAL)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -53,8 +71,52 @@ const struct xlat v4l2_format_descriptio
  .data = v4l2_format_description_flags_xdata,
  .size = ARRAY_SIZE(v4l2_format_description_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_format_description_flags.in 5.9-0ubuntu2/xlat/v4l2_format_description_flags.in
--- 5.5-3/xlat/v4l2_format_description_flags.in	2019-10-20 18:12:10.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_format_description_flags.in	2020-09-06 08:00:00.000000000 +0000
@@ -2,3 +2,4 @@ V4L2_FMT_FLAG_COMPRESSED		0x0001
 V4L2_FMT_FLAG_EMULATED			0x0002
 V4L2_FMT_FLAG_CONTINUOUS_BYTESTREAM	0x0004
 V4L2_FMT_FLAG_DYN_RESOLUTION		0x0008
+V4L2_FMT_FLAG_ENC_CAP_FRAME_INTERVAL	0x0010
diff -pruN 5.5-3/xlat/v4l2_frameinterval_types.h 5.9-0ubuntu2/xlat/v4l2_frameinterval_types.h
--- 5.5-3/xlat/v4l2_frameinterval_types.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_frameinterval_types.h	2020-09-24 09:18:46.000000000 +0000
@@ -35,8 +35,14 @@ extern const struct xlat v4l2_frameinter
 
 static const struct xlat_data v4l2_frameinterval_types_xdata[] = {
  [V4L2_FRMIVAL_TYPE_DISCRETE] = XLAT(V4L2_FRMIVAL_TYPE_DISCRETE),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_FRMIVAL_TYPE_DISCRETE))
+ #define XLAT_STR_0 STRINGIFY(V4L2_FRMIVAL_TYPE_DISCRETE)
  [V4L2_FRMIVAL_TYPE_CONTINUOUS] = XLAT(V4L2_FRMIVAL_TYPE_CONTINUOUS),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_FRMIVAL_TYPE_CONTINUOUS))
+ #define XLAT_STR_1 STRINGIFY(V4L2_FRMIVAL_TYPE_CONTINUOUS)
  [V4L2_FRMIVAL_TYPE_STEPWISE] = XLAT(V4L2_FRMIVAL_TYPE_STEPWISE),
+ #define XLAT_VAL_2 ((unsigned) (V4L2_FRMIVAL_TYPE_STEPWISE))
+ #define XLAT_STR_2 STRINGIFY(V4L2_FRMIVAL_TYPE_STEPWISE)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -45,8 +51,36 @@ const struct xlat v4l2_frameinterval_typ
  .data = v4l2_frameinterval_types_xdata,
  .size = ARRAY_SIZE(v4l2_frameinterval_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_framesize_types.h 5.9-0ubuntu2/xlat/v4l2_framesize_types.h
--- 5.5-3/xlat/v4l2_framesize_types.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_framesize_types.h	2020-09-24 09:18:46.000000000 +0000
@@ -35,8 +35,14 @@ extern const struct xlat v4l2_framesize_
 
 static const struct xlat_data v4l2_framesize_types_xdata[] = {
  [V4L2_FRMSIZE_TYPE_DISCRETE] = XLAT(V4L2_FRMSIZE_TYPE_DISCRETE),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_FRMSIZE_TYPE_DISCRETE))
+ #define XLAT_STR_0 STRINGIFY(V4L2_FRMSIZE_TYPE_DISCRETE)
  [V4L2_FRMSIZE_TYPE_CONTINUOUS] = XLAT(V4L2_FRMSIZE_TYPE_CONTINUOUS),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_FRMSIZE_TYPE_CONTINUOUS))
+ #define XLAT_STR_1 STRINGIFY(V4L2_FRMSIZE_TYPE_CONTINUOUS)
  [V4L2_FRMSIZE_TYPE_STEPWISE] = XLAT(V4L2_FRMSIZE_TYPE_STEPWISE),
+ #define XLAT_VAL_2 ((unsigned) (V4L2_FRMSIZE_TYPE_STEPWISE))
+ #define XLAT_STR_2 STRINGIFY(V4L2_FRMSIZE_TYPE_STEPWISE)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -45,8 +51,36 @@ const struct xlat v4l2_framesize_types[1
  .data = v4l2_framesize_types_xdata,
  .size = ARRAY_SIZE(v4l2_framesize_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_framesize_types.in 5.9-0ubuntu2/xlat/v4l2_framesize_types.in
--- 5.5-3/xlat/v4l2_framesize_types.in	2019-10-28 19:52:59.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_framesize_types.in	2020-05-30 08:00:00.000000000 +0000
@@ -1,4 +1,9 @@
 #value_indexed
+#enum
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 V4L2_FRMSIZE_TYPE_DISCRETE	1
 V4L2_FRMSIZE_TYPE_CONTINUOUS	2
 V4L2_FRMSIZE_TYPE_STEPWISE	3
diff -pruN 5.5-3/xlat/v4l2_framesize_types.m4 5.9-0ubuntu2/xlat/v4l2_framesize_types.m4
--- 5.5-3/xlat/v4l2_framesize_types.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_framesize_types.m4	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,12 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/v4l2_framesize_types.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_v4l2_framesize_types],[
+AC_CHECK_DECLS(m4_normalize([
+V4L2_FRMSIZE_TYPE_DISCRETE,
+V4L2_FRMSIZE_TYPE_CONTINUOUS,
+V4L2_FRMSIZE_TYPE_STEPWISE
+]),,, [
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+])])])
diff -pruN 5.5-3/xlat/v4l2_input_types.h 5.9-0ubuntu2/xlat/v4l2_input_types.h
--- 5.5-3/xlat/v4l2_input_types.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_input_types.h	2020-09-24 09:18:46.000000000 +0000
@@ -35,8 +35,14 @@ extern const struct xlat v4l2_input_type
 
 static const struct xlat_data v4l2_input_types_xdata[] = {
  [V4L2_INPUT_TYPE_TUNER] = XLAT(V4L2_INPUT_TYPE_TUNER),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_INPUT_TYPE_TUNER))
+ #define XLAT_STR_0 STRINGIFY(V4L2_INPUT_TYPE_TUNER)
  [V4L2_INPUT_TYPE_CAMERA] = XLAT(V4L2_INPUT_TYPE_CAMERA),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_INPUT_TYPE_CAMERA))
+ #define XLAT_STR_1 STRINGIFY(V4L2_INPUT_TYPE_CAMERA)
  [V4L2_INPUT_TYPE_TOUCH] = XLAT(V4L2_INPUT_TYPE_TOUCH),
+ #define XLAT_VAL_2 ((unsigned) (V4L2_INPUT_TYPE_TOUCH))
+ #define XLAT_STR_2 STRINGIFY(V4L2_INPUT_TYPE_TOUCH)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -45,8 +51,36 @@ const struct xlat v4l2_input_types[1] =
  .data = v4l2_input_types_xdata,
  .size = ARRAY_SIZE(v4l2_input_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_ioctl_cmds.h 5.9-0ubuntu2/xlat/v4l2_ioctl_cmds.h
--- 5.5-3/xlat/v4l2_ioctl_cmds.h	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_ioctl_cmds.h	2020-09-24 09:18:47.000000000 +0000
@@ -0,0 +1,783 @@
+/* Generated by ./xlat/gen.sh from ./xlat/v4l2_ioctl_cmds.in; do not edit. */
+
+#include "gcc_compat.h"
+#include "static_assert.h"
+
+#ifndef STRACE_WORKAROUND_V4L2_TIME64
+# define STRACE_WORKAROUND_V4L2_TIME64
+# undef VIDIOC_QUERYBUF
+# undef VIDIOC_QBUF
+# undef VIDIOC_DQBUF
+# undef VIDIOC_PREPARE_BUF
+# undef VIDIOC_DQEVENT
+#endif
+#if defined(VIDIOC_QUERYCAP) || (defined(HAVE_DECL_VIDIOC_QUERYCAP) && HAVE_DECL_VIDIOC_QUERYCAP)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_QUERYCAP) == (_IOR ('V',   0, struct_v4l2_capability)), "VIDIOC_QUERYCAP != _IOR ('V',   0, struct_v4l2_capability)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_QUERYCAP _IOR ('V',   0, struct_v4l2_capability)
+#endif
+#if defined(VIDIOC_ENUM_FMT) || (defined(HAVE_DECL_VIDIOC_ENUM_FMT) && HAVE_DECL_VIDIOC_ENUM_FMT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_ENUM_FMT) == (_IOWR('V',   2, struct v4l2_fmtdesc)), "VIDIOC_ENUM_FMT != _IOWR('V',   2, struct v4l2_fmtdesc)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_ENUM_FMT _IOWR('V',   2, struct v4l2_fmtdesc)
+#endif
+#if defined(VIDIOC_G_FMT) || (defined(HAVE_DECL_VIDIOC_G_FMT) && HAVE_DECL_VIDIOC_G_FMT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_G_FMT) == (_IOWR('V',   4, struct_v4l2_format)), "VIDIOC_G_FMT != _IOWR('V',   4, struct_v4l2_format)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_G_FMT _IOWR('V',   4, struct_v4l2_format)
+#endif
+#if defined(VIDIOC_S_FMT) || (defined(HAVE_DECL_VIDIOC_S_FMT) && HAVE_DECL_VIDIOC_S_FMT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_S_FMT) == (_IOWR('V',   5, struct_v4l2_format)), "VIDIOC_S_FMT != _IOWR('V',   5, struct_v4l2_format)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_S_FMT _IOWR('V',   5, struct_v4l2_format)
+#endif
+#if defined(VIDIOC_REQBUFS) || (defined(HAVE_DECL_VIDIOC_REQBUFS) && HAVE_DECL_VIDIOC_REQBUFS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_REQBUFS) == (_IOWR('V',   8, struct v4l2_requestbuffers)), "VIDIOC_REQBUFS != _IOWR('V',   8, struct v4l2_requestbuffers)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_REQBUFS _IOWR('V',   8, struct v4l2_requestbuffers)
+#endif
+#if defined(VIDIOC_QUERYBUF) || (defined(HAVE_DECL_VIDIOC_QUERYBUF) && HAVE_DECL_VIDIOC_QUERYBUF)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_QUERYBUF) == (_IOWR('V',   9, kernel_v4l2_buffer_t)), "VIDIOC_QUERYBUF != _IOWR('V',   9, kernel_v4l2_buffer_t)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_QUERYBUF _IOWR('V',   9, kernel_v4l2_buffer_t)
+#endif
+#if defined(VIDIOC_G_FBUF) || (defined(HAVE_DECL_VIDIOC_G_FBUF) && HAVE_DECL_VIDIOC_G_FBUF)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_G_FBUF) == (_IOR ('V',  10, struct_v4l2_framebuffer)), "VIDIOC_G_FBUF != _IOR ('V',  10, struct_v4l2_framebuffer)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_G_FBUF _IOR ('V',  10, struct_v4l2_framebuffer)
+#endif
+#if defined(VIDIOC_S_FBUF) || (defined(HAVE_DECL_VIDIOC_S_FBUF) && HAVE_DECL_VIDIOC_S_FBUF)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_S_FBUF) == (_IOW ('V',  11, struct_v4l2_framebuffer)), "VIDIOC_S_FBUF != _IOW ('V',  11, struct_v4l2_framebuffer)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_S_FBUF _IOW ('V',  11, struct_v4l2_framebuffer)
+#endif
+#if defined(VIDIOC_QBUF) || (defined(HAVE_DECL_VIDIOC_QBUF) && HAVE_DECL_VIDIOC_QBUF)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_QBUF) == (_IOWR('V',  15, kernel_v4l2_buffer_t)), "VIDIOC_QBUF != _IOWR('V',  15, kernel_v4l2_buffer_t)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_QBUF _IOWR('V',  15, kernel_v4l2_buffer_t)
+#endif
+#if defined(VIDIOC_DQBUF) || (defined(HAVE_DECL_VIDIOC_DQBUF) && HAVE_DECL_VIDIOC_DQBUF)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_DQBUF) == (_IOWR('V',  17, kernel_v4l2_buffer_t)), "VIDIOC_DQBUF != _IOWR('V',  17, kernel_v4l2_buffer_t)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_DQBUF _IOWR('V',  17, kernel_v4l2_buffer_t)
+#endif
+#if defined(VIDIOC_STREAMON) || (defined(HAVE_DECL_VIDIOC_STREAMON) && HAVE_DECL_VIDIOC_STREAMON)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_STREAMON) == (_IOW ('V',  18, int)), "VIDIOC_STREAMON != _IOW ('V',  18, int)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_STREAMON _IOW ('V',  18, int)
+#endif
+#if defined(VIDIOC_STREAMOFF) || (defined(HAVE_DECL_VIDIOC_STREAMOFF) && HAVE_DECL_VIDIOC_STREAMOFF)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_STREAMOFF) == (_IOW ('V',  19, int)), "VIDIOC_STREAMOFF != _IOW ('V',  19, int)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_STREAMOFF _IOW ('V',  19, int)
+#endif
+#if defined(VIDIOC_G_PARM) || (defined(HAVE_DECL_VIDIOC_G_PARM) && HAVE_DECL_VIDIOC_G_PARM)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_G_PARM) == (_IOWR('V',  21, struct v4l2_streamparm)), "VIDIOC_G_PARM != _IOWR('V',  21, struct v4l2_streamparm)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_G_PARM _IOWR('V',  21, struct v4l2_streamparm)
+#endif
+#if defined(VIDIOC_S_PARM) || (defined(HAVE_DECL_VIDIOC_S_PARM) && HAVE_DECL_VIDIOC_S_PARM)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_S_PARM) == (_IOWR('V',  22, struct v4l2_streamparm)), "VIDIOC_S_PARM != _IOWR('V',  22, struct v4l2_streamparm)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_S_PARM _IOWR('V',  22, struct v4l2_streamparm)
+#endif
+#if defined(VIDIOC_G_STD) || (defined(HAVE_DECL_VIDIOC_G_STD) && HAVE_DECL_VIDIOC_G_STD)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_G_STD) == (_IOR ('V',  23, uint64_t)), "VIDIOC_G_STD != _IOR ('V',  23, uint64_t)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_G_STD _IOR ('V',  23, uint64_t)
+#endif
+#if defined(VIDIOC_S_STD) || (defined(HAVE_DECL_VIDIOC_S_STD) && HAVE_DECL_VIDIOC_S_STD)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_S_STD) == (_IOW ('V',  24, uint64_t)), "VIDIOC_S_STD != _IOW ('V',  24, uint64_t)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_S_STD _IOW ('V',  24, uint64_t)
+#endif
+#if defined(VIDIOC_ENUMSTD) || (defined(HAVE_DECL_VIDIOC_ENUMSTD) && HAVE_DECL_VIDIOC_ENUMSTD)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_ENUMSTD) == (_IOWR('V',  25, struct_v4l2_standard)), "VIDIOC_ENUMSTD != _IOWR('V',  25, struct_v4l2_standard)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_ENUMSTD _IOWR('V',  25, struct_v4l2_standard)
+#endif
+#if defined(VIDIOC_ENUMINPUT) || (defined(HAVE_DECL_VIDIOC_ENUMINPUT) && HAVE_DECL_VIDIOC_ENUMINPUT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_ENUMINPUT) == (_IOWR('V',  26, struct_v4l2_input)), "VIDIOC_ENUMINPUT != _IOWR('V',  26, struct_v4l2_input)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_ENUMINPUT _IOWR('V',  26, struct_v4l2_input)
+#endif
+#if defined(VIDIOC_G_CTRL) || (defined(HAVE_DECL_VIDIOC_G_CTRL) && HAVE_DECL_VIDIOC_G_CTRL)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_G_CTRL) == (_IOWR('V',  27, struct v4l2_control)), "VIDIOC_G_CTRL != _IOWR('V',  27, struct v4l2_control)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_G_CTRL _IOWR('V',  27, struct v4l2_control)
+#endif
+#if defined(VIDIOC_S_CTRL) || (defined(HAVE_DECL_VIDIOC_S_CTRL) && HAVE_DECL_VIDIOC_S_CTRL)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_S_CTRL) == (_IOWR('V',  28, struct v4l2_control)), "VIDIOC_S_CTRL != _IOWR('V',  28, struct v4l2_control)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_S_CTRL _IOWR('V',  28, struct v4l2_control)
+#endif
+#if defined(VIDIOC_G_TUNER) || (defined(HAVE_DECL_VIDIOC_G_TUNER) && HAVE_DECL_VIDIOC_G_TUNER)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_G_TUNER) == (_IOWR('V',  29, struct v4l2_tuner)), "VIDIOC_G_TUNER != _IOWR('V',  29, struct v4l2_tuner)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_G_TUNER _IOWR('V',  29, struct v4l2_tuner)
+#endif
+#if defined(VIDIOC_S_TUNER) || (defined(HAVE_DECL_VIDIOC_S_TUNER) && HAVE_DECL_VIDIOC_S_TUNER)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_S_TUNER) == (_IOW ('V',  30, struct v4l2_tuner)), "VIDIOC_S_TUNER != _IOW ('V',  30, struct v4l2_tuner)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_S_TUNER _IOW ('V',  30, struct v4l2_tuner)
+#endif
+#if defined(VIDIOC_QUERYCTRL) || (defined(HAVE_DECL_VIDIOC_QUERYCTRL) && HAVE_DECL_VIDIOC_QUERYCTRL)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_QUERYCTRL) == (_IOWR('V',  36, struct v4l2_queryctrl)), "VIDIOC_QUERYCTRL != _IOWR('V',  36, struct v4l2_queryctrl)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_QUERYCTRL _IOWR('V',  36, struct v4l2_queryctrl)
+#endif
+#if defined(VIDIOC_G_INPUT) || (defined(HAVE_DECL_VIDIOC_G_INPUT) && HAVE_DECL_VIDIOC_G_INPUT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_G_INPUT) == (_IOR ('V',  38, int)), "VIDIOC_G_INPUT != _IOR ('V',  38, int)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_G_INPUT _IOR ('V',  38, int)
+#endif
+#if defined(VIDIOC_S_INPUT) || (defined(HAVE_DECL_VIDIOC_S_INPUT) && HAVE_DECL_VIDIOC_S_INPUT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_S_INPUT) == (_IOWR('V',  39, int)), "VIDIOC_S_INPUT != _IOWR('V',  39, int)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_S_INPUT _IOWR('V',  39, int)
+#endif
+#if defined(VIDIOC_CROPCAP) || (defined(HAVE_DECL_VIDIOC_CROPCAP) && HAVE_DECL_VIDIOC_CROPCAP)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_CROPCAP) == (_IOWR('V',  58, struct v4l2_cropcap)), "VIDIOC_CROPCAP != _IOWR('V',  58, struct v4l2_cropcap)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_CROPCAP _IOWR('V',  58, struct v4l2_cropcap)
+#endif
+#if defined(VIDIOC_G_CROP) || (defined(HAVE_DECL_VIDIOC_G_CROP) && HAVE_DECL_VIDIOC_G_CROP)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_G_CROP) == (_IOWR('V',  59, struct v4l2_crop)), "VIDIOC_G_CROP != _IOWR('V',  59, struct v4l2_crop)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_G_CROP _IOWR('V',  59, struct v4l2_crop)
+#endif
+#if defined(VIDIOC_S_CROP) || (defined(HAVE_DECL_VIDIOC_S_CROP) && HAVE_DECL_VIDIOC_S_CROP)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_S_CROP) == (_IOW ('V',  60, struct v4l2_crop)), "VIDIOC_S_CROP != _IOW ('V',  60, struct v4l2_crop)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_S_CROP _IOW ('V',  60, struct v4l2_crop)
+#endif
+#if defined(VIDIOC_TRY_FMT) || (defined(HAVE_DECL_VIDIOC_TRY_FMT) && HAVE_DECL_VIDIOC_TRY_FMT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_TRY_FMT) == (_IOWR('V',  64, struct_v4l2_format)), "VIDIOC_TRY_FMT != _IOWR('V',  64, struct_v4l2_format)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_TRY_FMT _IOWR('V',  64, struct_v4l2_format)
+#endif
+#if defined(VIDIOC_G_EXT_CTRLS) || (defined(HAVE_DECL_VIDIOC_G_EXT_CTRLS) && HAVE_DECL_VIDIOC_G_EXT_CTRLS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_G_EXT_CTRLS) == (_IOWR('V',  71, struct_v4l2_ext_controls)), "VIDIOC_G_EXT_CTRLS != _IOWR('V',  71, struct_v4l2_ext_controls)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_G_EXT_CTRLS _IOWR('V',  71, struct_v4l2_ext_controls)
+#endif
+#if defined(VIDIOC_S_EXT_CTRLS) || (defined(HAVE_DECL_VIDIOC_S_EXT_CTRLS) && HAVE_DECL_VIDIOC_S_EXT_CTRLS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_S_EXT_CTRLS) == (_IOWR('V',  72, struct_v4l2_ext_controls)), "VIDIOC_S_EXT_CTRLS != _IOWR('V',  72, struct_v4l2_ext_controls)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_S_EXT_CTRLS _IOWR('V',  72, struct_v4l2_ext_controls)
+#endif
+#if defined(VIDIOC_TRY_EXT_CTRLS) || (defined(HAVE_DECL_VIDIOC_TRY_EXT_CTRLS) && HAVE_DECL_VIDIOC_TRY_EXT_CTRLS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_TRY_EXT_CTRLS) == (_IOWR('V',  73, struct_v4l2_ext_controls)), "VIDIOC_TRY_EXT_CTRLS != _IOWR('V',  73, struct_v4l2_ext_controls)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_TRY_EXT_CTRLS _IOWR('V',  73, struct_v4l2_ext_controls)
+#endif
+#if defined(VIDIOC_ENUM_FRAMESIZES) || (defined(HAVE_DECL_VIDIOC_ENUM_FRAMESIZES) && HAVE_DECL_VIDIOC_ENUM_FRAMESIZES)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_ENUM_FRAMESIZES) == (_IOWR('V',  74, struct_v4l2_frmsizeenum)), "VIDIOC_ENUM_FRAMESIZES != _IOWR('V',  74, struct_v4l2_frmsizeenum)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_ENUM_FRAMESIZES _IOWR('V',  74, struct_v4l2_frmsizeenum)
+#endif
+#if defined(VIDIOC_ENUM_FRAMEINTERVALS) || (defined(HAVE_DECL_VIDIOC_ENUM_FRAMEINTERVALS) && HAVE_DECL_VIDIOC_ENUM_FRAMEINTERVALS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_ENUM_FRAMEINTERVALS) == (_IOWR('V',  75, struct_v4l2_frmivalenum)), "VIDIOC_ENUM_FRAMEINTERVALS != _IOWR('V',  75, struct_v4l2_frmivalenum)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_ENUM_FRAMEINTERVALS _IOWR('V',  75, struct_v4l2_frmivalenum)
+#endif
+#if defined(VIDIOC_DQEVENT) || (defined(HAVE_DECL_VIDIOC_DQEVENT) && HAVE_DECL_VIDIOC_DQEVENT)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_DQEVENT) == (_IOR ('V',  89, kernel_v4l2_event_t)), "VIDIOC_DQEVENT != _IOR ('V',  89, kernel_v4l2_event_t)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_DQEVENT _IOR ('V',  89, kernel_v4l2_event_t)
+#endif
+#if defined(VIDIOC_CREATE_BUFS) || (defined(HAVE_DECL_VIDIOC_CREATE_BUFS) && HAVE_DECL_VIDIOC_CREATE_BUFS)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_CREATE_BUFS) == (_IOWR('V',  92, struct_v4l2_create_buffers)), "VIDIOC_CREATE_BUFS != _IOWR('V',  92, struct_v4l2_create_buffers)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_CREATE_BUFS _IOWR('V',  92, struct_v4l2_create_buffers)
+#endif
+#if defined(VIDIOC_PREPARE_BUF) || (defined(HAVE_DECL_VIDIOC_PREPARE_BUF) && HAVE_DECL_VIDIOC_PREPARE_BUF)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((VIDIOC_PREPARE_BUF) == (_IOWR('V',  93, kernel_v4l2_buffer_t)), "VIDIOC_PREPARE_BUF != _IOWR('V',  93, kernel_v4l2_buffer_t)");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define VIDIOC_PREPARE_BUF _IOWR('V',  93, kernel_v4l2_buffer_t)
+#endif
+
+#ifndef XLAT_MACROS_ONLY
+
+# ifdef IN_MPERS
+
+extern const struct xlat v4l2_ioctl_cmds[];
+
+# else
+
+static const struct xlat_data v4l2_ioctl_cmds_xdata[] = {
+#ifndef STRACE_WORKAROUND_V4L2_TIME64
+# define STRACE_WORKAROUND_V4L2_TIME64
+
+# undef VIDIOC_QUERYBUF
+# undef VIDIOC_QBUF
+# undef VIDIOC_DQBUF
+# undef VIDIOC_PREPARE_BUF
+
+# undef VIDIOC_DQEVENT
+#endif
+
+ XLAT(VIDIOC_QUERYCAP),
+ #define XLAT_VAL_0 ((unsigned) (VIDIOC_QUERYCAP))
+ #define XLAT_STR_0 STRINGIFY(VIDIOC_QUERYCAP)
+ XLAT(VIDIOC_ENUM_FMT),
+ #define XLAT_VAL_1 ((unsigned) (VIDIOC_ENUM_FMT))
+ #define XLAT_STR_1 STRINGIFY(VIDIOC_ENUM_FMT)
+ XLAT(VIDIOC_G_FMT),
+ #define XLAT_VAL_2 ((unsigned) (VIDIOC_G_FMT))
+ #define XLAT_STR_2 STRINGIFY(VIDIOC_G_FMT)
+ XLAT(VIDIOC_S_FMT),
+ #define XLAT_VAL_3 ((unsigned) (VIDIOC_S_FMT))
+ #define XLAT_STR_3 STRINGIFY(VIDIOC_S_FMT)
+
+
+ XLAT(VIDIOC_REQBUFS),
+ #define XLAT_VAL_4 ((unsigned) (VIDIOC_REQBUFS))
+ #define XLAT_STR_4 STRINGIFY(VIDIOC_REQBUFS)
+ XLAT(VIDIOC_QUERYBUF),
+ #define XLAT_VAL_5 ((unsigned) (VIDIOC_QUERYBUF))
+ #define XLAT_STR_5 STRINGIFY(VIDIOC_QUERYBUF)
+ XLAT(VIDIOC_G_FBUF),
+ #define XLAT_VAL_6 ((unsigned) (VIDIOC_G_FBUF))
+ #define XLAT_STR_6 STRINGIFY(VIDIOC_G_FBUF)
+ XLAT(VIDIOC_S_FBUF),
+ #define XLAT_VAL_7 ((unsigned) (VIDIOC_S_FBUF))
+ #define XLAT_STR_7 STRINGIFY(VIDIOC_S_FBUF)
+
+ XLAT(VIDIOC_QBUF),
+ #define XLAT_VAL_8 ((unsigned) (VIDIOC_QBUF))
+ #define XLAT_STR_8 STRINGIFY(VIDIOC_QBUF)
+
+ XLAT(VIDIOC_DQBUF),
+ #define XLAT_VAL_9 ((unsigned) (VIDIOC_DQBUF))
+ #define XLAT_STR_9 STRINGIFY(VIDIOC_DQBUF)
+ XLAT(VIDIOC_STREAMON),
+ #define XLAT_VAL_10 ((unsigned) (VIDIOC_STREAMON))
+ #define XLAT_STR_10 STRINGIFY(VIDIOC_STREAMON)
+ XLAT(VIDIOC_STREAMOFF),
+ #define XLAT_VAL_11 ((unsigned) (VIDIOC_STREAMOFF))
+ #define XLAT_STR_11 STRINGIFY(VIDIOC_STREAMOFF)
+ XLAT(VIDIOC_G_PARM),
+ #define XLAT_VAL_12 ((unsigned) (VIDIOC_G_PARM))
+ #define XLAT_STR_12 STRINGIFY(VIDIOC_G_PARM)
+ XLAT(VIDIOC_S_PARM),
+ #define XLAT_VAL_13 ((unsigned) (VIDIOC_S_PARM))
+ #define XLAT_STR_13 STRINGIFY(VIDIOC_S_PARM)
+ XLAT(VIDIOC_G_STD),
+ #define XLAT_VAL_14 ((unsigned) (VIDIOC_G_STD))
+ #define XLAT_STR_14 STRINGIFY(VIDIOC_G_STD)
+ XLAT(VIDIOC_S_STD),
+ #define XLAT_VAL_15 ((unsigned) (VIDIOC_S_STD))
+ #define XLAT_STR_15 STRINGIFY(VIDIOC_S_STD)
+ XLAT(VIDIOC_ENUMSTD),
+ #define XLAT_VAL_16 ((unsigned) (VIDIOC_ENUMSTD))
+ #define XLAT_STR_16 STRINGIFY(VIDIOC_ENUMSTD)
+ XLAT(VIDIOC_ENUMINPUT),
+ #define XLAT_VAL_17 ((unsigned) (VIDIOC_ENUMINPUT))
+ #define XLAT_STR_17 STRINGIFY(VIDIOC_ENUMINPUT)
+ XLAT(VIDIOC_G_CTRL),
+ #define XLAT_VAL_18 ((unsigned) (VIDIOC_G_CTRL))
+ #define XLAT_STR_18 STRINGIFY(VIDIOC_G_CTRL)
+ XLAT(VIDIOC_S_CTRL),
+ #define XLAT_VAL_19 ((unsigned) (VIDIOC_S_CTRL))
+ #define XLAT_STR_19 STRINGIFY(VIDIOC_S_CTRL)
+ XLAT(VIDIOC_G_TUNER),
+ #define XLAT_VAL_20 ((unsigned) (VIDIOC_G_TUNER))
+ #define XLAT_STR_20 STRINGIFY(VIDIOC_G_TUNER)
+ XLAT(VIDIOC_S_TUNER),
+ #define XLAT_VAL_21 ((unsigned) (VIDIOC_S_TUNER))
+ #define XLAT_STR_21 STRINGIFY(VIDIOC_S_TUNER)
+
+
+ XLAT(VIDIOC_QUERYCTRL),
+ #define XLAT_VAL_22 ((unsigned) (VIDIOC_QUERYCTRL))
+ #define XLAT_STR_22 STRINGIFY(VIDIOC_QUERYCTRL)
+
+ XLAT(VIDIOC_G_INPUT),
+ #define XLAT_VAL_23 ((unsigned) (VIDIOC_G_INPUT))
+ #define XLAT_STR_23 STRINGIFY(VIDIOC_G_INPUT)
+ XLAT(VIDIOC_S_INPUT),
+ #define XLAT_VAL_24 ((unsigned) (VIDIOC_S_INPUT))
+ #define XLAT_STR_24 STRINGIFY(VIDIOC_S_INPUT)
+
+
+
+
+
+
+
+
+
+
+
+ XLAT(VIDIOC_CROPCAP),
+ #define XLAT_VAL_25 ((unsigned) (VIDIOC_CROPCAP))
+ #define XLAT_STR_25 STRINGIFY(VIDIOC_CROPCAP)
+ XLAT(VIDIOC_G_CROP),
+ #define XLAT_VAL_26 ((unsigned) (VIDIOC_G_CROP))
+ #define XLAT_STR_26 STRINGIFY(VIDIOC_G_CROP)
+ XLAT(VIDIOC_S_CROP),
+ #define XLAT_VAL_27 ((unsigned) (VIDIOC_S_CROP))
+ #define XLAT_STR_27 STRINGIFY(VIDIOC_S_CROP)
+
+
+
+ XLAT(VIDIOC_TRY_FMT),
+ #define XLAT_VAL_28 ((unsigned) (VIDIOC_TRY_FMT))
+ #define XLAT_STR_28 STRINGIFY(VIDIOC_TRY_FMT)
+
+
+
+
+
+
+ XLAT(VIDIOC_G_EXT_CTRLS),
+ #define XLAT_VAL_29 ((unsigned) (VIDIOC_G_EXT_CTRLS))
+ #define XLAT_STR_29 STRINGIFY(VIDIOC_G_EXT_CTRLS)
+ XLAT(VIDIOC_S_EXT_CTRLS),
+ #define XLAT_VAL_30 ((unsigned) (VIDIOC_S_EXT_CTRLS))
+ #define XLAT_STR_30 STRINGIFY(VIDIOC_S_EXT_CTRLS)
+ XLAT(VIDIOC_TRY_EXT_CTRLS),
+ #define XLAT_VAL_31 ((unsigned) (VIDIOC_TRY_EXT_CTRLS))
+ #define XLAT_STR_31 STRINGIFY(VIDIOC_TRY_EXT_CTRLS)
+ XLAT(VIDIOC_ENUM_FRAMESIZES),
+ #define XLAT_VAL_32 ((unsigned) (VIDIOC_ENUM_FRAMESIZES))
+ #define XLAT_STR_32 STRINGIFY(VIDIOC_ENUM_FRAMESIZES)
+ XLAT(VIDIOC_ENUM_FRAMEINTERVALS),
+ #define XLAT_VAL_33 ((unsigned) (VIDIOC_ENUM_FRAMEINTERVALS))
+ #define XLAT_STR_33 STRINGIFY(VIDIOC_ENUM_FRAMEINTERVALS)
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ XLAT(VIDIOC_DQEVENT),
+ #define XLAT_VAL_34 ((unsigned) (VIDIOC_DQEVENT))
+ #define XLAT_STR_34 STRINGIFY(VIDIOC_DQEVENT)
+
+
+ XLAT(VIDIOC_CREATE_BUFS),
+ #define XLAT_VAL_35 ((unsigned) (VIDIOC_CREATE_BUFS))
+ #define XLAT_STR_35 STRINGIFY(VIDIOC_CREATE_BUFS)
+ XLAT(VIDIOC_PREPARE_BUF),
+ #define XLAT_VAL_36 ((unsigned) (VIDIOC_PREPARE_BUF))
+ #define XLAT_STR_36 STRINGIFY(VIDIOC_PREPARE_BUF)
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+};
+#  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
+static
+#  endif
+const struct xlat v4l2_ioctl_cmds[1] = { {
+ .data = v4l2_ioctl_cmds_xdata,
+ .size = ARRAY_SIZE(v4l2_ioctl_cmds_xdata),
+ .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+  ,
+} };
+
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+# endif /* !IN_MPERS */
+
+#endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_ioctl_cmds.in 5.9-0ubuntu2/xlat/v4l2_ioctl_cmds.in
--- 5.5-3/xlat/v4l2_ioctl_cmds.in	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_ioctl_cmds.in	2020-05-28 08:00:00.000000000 +0000
@@ -0,0 +1,114 @@
+#ifndef STRACE_WORKAROUND_V4L2_TIME64
+# define STRACE_WORKAROUND_V4L2_TIME64
+/* Constants based on struct v4l2_buffer are unreliable as the latter uses struct timeval. */
+# undef VIDIOC_QUERYBUF
+# undef VIDIOC_QBUF
+# undef VIDIOC_DQBUF
+# undef VIDIOC_PREPARE_BUF
+/* Constants based on struct v4l2_event are unreliable as the latter uses struct timespec. */
+# undef VIDIOC_DQEVENT
+#endif
+
+VIDIOC_QUERYCAP			_IOR ('V',   0, struct_v4l2_capability)
+VIDIOC_ENUM_FMT			_IOWR('V',   2, struct v4l2_fmtdesc)
+VIDIOC_G_FMT			_IOWR('V',   4, struct_v4l2_format)
+VIDIOC_S_FMT			_IOWR('V',   5, struct_v4l2_format)
+/* VIDIOC_G_MPEGCOMP		_IOR  ('V',  6, struct v4l2_mpeg_compression) - removed in v2.6.24-rc1~66^2~32 */
+/* VIDIOC_S_MPEGCOMP		_IOW  ('V',  7, struct v4l2_mpeg_compression) - removed in v2.6.24-rc1~66^2~32 */
+VIDIOC_REQBUFS			_IOWR('V',   8, struct v4l2_requestbuffers)
+VIDIOC_QUERYBUF			_IOWR('V',   9, kernel_v4l2_buffer_t)
+VIDIOC_G_FBUF			_IOR ('V',  10, struct_v4l2_framebuffer)
+VIDIOC_S_FBUF			_IOW ('V',  11, struct_v4l2_framebuffer)
+/* VIDIOC_OVERLAY			_IOW ('V',  14, int) */
+VIDIOC_QBUF			_IOWR('V',  15, kernel_v4l2_buffer_t)
+/* VIDIOC_EXPBUF			_IOWR('V',  16, struct v4l2_exportbuffer) - added in v3.8-rc1~115^2^2~34 */
+VIDIOC_DQBUF			_IOWR('V',  17, kernel_v4l2_buffer_t)
+VIDIOC_STREAMON			_IOW ('V',  18, int)
+VIDIOC_STREAMOFF		_IOW ('V',  19, int)
+VIDIOC_G_PARM			_IOWR('V',  21, struct v4l2_streamparm)
+VIDIOC_S_PARM			_IOWR('V',  22, struct v4l2_streamparm)
+VIDIOC_G_STD			_IOR ('V',  23, uint64_t) /* v4l2_std_id */
+VIDIOC_S_STD			_IOW ('V',  24, uint64_t) /* v4l2_std_id */
+VIDIOC_ENUMSTD			_IOWR('V',  25, struct_v4l2_standard)
+VIDIOC_ENUMINPUT		_IOWR('V',  26, struct_v4l2_input)
+VIDIOC_G_CTRL			_IOWR('V',  27, struct v4l2_control)
+VIDIOC_S_CTRL			_IOWR('V',  28, struct v4l2_control)
+VIDIOC_G_TUNER			_IOWR('V',  29, struct v4l2_tuner)
+VIDIOC_S_TUNER			_IOW ('V',  30, struct v4l2_tuner)
+/* VIDIOC_G_AUDIO			_IOR ('V',  33, struct v4l2_audio) */
+/* VIDIOC_S_AUDIO			_IOW ('V',  34, struct v4l2_audio) */
+VIDIOC_QUERYCTRL		_IOWR('V',  36, struct v4l2_queryctrl)
+/* VIDIOC_QUERYMENU		_IOWR('V',  37, struct_v4l2_querymenu) */
+VIDIOC_G_INPUT			_IOR ('V',  38, int)
+VIDIOC_S_INPUT			_IOWR('V',  39, int)
+/* VIDIOC_G_EDID			_IOWR('V',  40, struct v4l2_edid) - renamed from VIDIOC_SUBDEV_G_EDID in v3.15-rc1~85^2~113 */
+/* VIDIOC_S_EDID			_IOWR('V',  41, struct v4l2_edid) - renamed from VIDIOC_SUBDEV_G_EDID in v3.15-rc1~85^2~113 */
+/* VIDIOC_G_OUTPUT			_IOR ('V',  46, int) */
+/* VIDIOC_S_OUTPUT			_IOWR('V',  47, int) */
+/* VIDIOC_ENUMOUTPUT		_IOWR('V',  48, struct_v4l2_output) */
+/* VIDIOC_G_AUDOUT			_IOR ('V',  49, struct v4l2_audioout) */
+/* VIDIOC_S_AUDOUT			_IOW ('V',  50, struct v4l2_audioout) */
+/* VIDIOC_G_MODULATOR		_IOWR('V',  54, struct_v4l2_modulator) */
+/* VIDIOC_S_MODULATOR		_IOW ('V',  55, struct_v4l2_modulator) */
+/* VIDIOC_G_FREQUENCY		_IOWR('V',  56, struct v4l2_frequency) */
+/* VIDIOC_S_FREQUENCY		_IOW ('V',  57, struct v4l2_frequency) */
+VIDIOC_CROPCAP			_IOWR('V',  58, struct v4l2_cropcap)
+VIDIOC_G_CROP			_IOWR('V',  59, struct v4l2_crop)
+VIDIOC_S_CROP			_IOW ('V',  60, struct v4l2_crop)
+/* VIDIOC_G_JPEGCOMP		_IOR ('V',  61, struct v4l2_jpegcompression) */
+/* VIDIOC_S_JPEGCOMP		_IOW ('V',  62, struct v4l2_jpegcompression) */
+/* VIDIOC_QUERYSTD			_IOR ('V',  63, uint64_t) */ /* v4l2_std_id */
+VIDIOC_TRY_FMT			_IOWR('V',  64, struct_v4l2_format)
+/* VIDIOC_ENUMAUDIO		_IOWR('V',  65, struct v4l2_audio) */
+/* VIDIOC_ENUMAUDOUT		_IOWR('V',  66, struct v4l2_audioout) */
+/* VIDIOC_G_PRIORITY		_IOR ('V',  67, uint32_t) */ /* enum v4l2_priority */
+/* VIDIOC_S_PRIORITY		_IOW ('V',  68, uint32_t) */ /* enum v4l2_priority */
+/* VIDIOC_G_SLICED_VBI_CAP		_IOWR('V',  69, struct_v4l2_sliced_vbi_cap) - added in v2.6.16.28-rc1~3732 */
+/* VIDIOC_LOG_STATUS		_IO  ('V',  70) - added in v2.6.16.28-rc1~2961 */
+VIDIOC_G_EXT_CTRLS		_IOWR('V',  71, struct_v4l2_ext_controls) /* added in v2.6.18-rc1~862^2~18 */
+VIDIOC_S_EXT_CTRLS		_IOWR('V',  72, struct_v4l2_ext_controls) /* added in v2.6.18-rc1~862^2~18 */
+VIDIOC_TRY_EXT_CTRLS		_IOWR('V',  73, struct_v4l2_ext_controls) /* added in v2.6.18-rc1~862^2~18 */
+VIDIOC_ENUM_FRAMESIZES		_IOWR('V',  74, struct_v4l2_frmsizeenum) /* added in v2.6.19-rc1~183 */
+VIDIOC_ENUM_FRAMEINTERVALS	_IOWR('V',  75, struct_v4l2_frmivalenum) /* added in v2.6.19-rc1~183 */
+/* VIDIOC_G_ENC_INDEX		_IOR ('V',  76, struct v4l2_enc_idx) - added in v2.6.21-rc3~150^2~2*/
+/* VIDIOC_ENCODER_CMD		_IOWR('V',  77, struct v4l2_encoder_cmd) - added in v2.6.21-rc3~150^2~1 */
+/* VIDIOC_TRY_ENCODER_CMD		_IOWR('V',  78, struct v4l2_encoder_cmd) - added in v2.6.21-rc3~150^2~1 */
+/* VIDIOC_DBG_S_REGISTER		_IOW ('V',  79, struct v4l2_dbg_register) - added in v2.6.29-rc1~523^2~24 */
+/* VIDIOC_DBG_G_REGISTER		_IOWR('V',  80, struct v4l2_dbg_register) - added in v2.6.29-rc1~523^2~24 */
+/* VIDIOC_G_CHIP_IDENT_OLD	_IOWR('V', 81, struct v4l2_chip_ident_old) - added in v2.6.22-rc1~1118^2~172, renamed in v2.6.29-rc1~523^2~24, removed in v2.6.30-rc1~621^2~278 */
+/* VIDIOC_DBG_G_CHIP_IDENT	_IOWR('V', 81, struct v4l2_dbg_chip_ident) - added in v2.6.29-rc1~523^2~24, removed in v3.11-rc1~17^2~99 */
+/* VIDIOC_S_HW_FREQ_SEEK		_IOW ('V',  82, struct v4l2_hw_freq_seek) - added in v2.6.27-rc1~966^2~258 */
+/* VIDIOC_ENUM_DV_PRESETS	_IOWR('V', 83, struct v4l2_dv_enum_preset) - added in v2.6.33-rc1~70^2~91, removed in v3.10-rc1~136^2~239 */
+/* VIDIOC_S_DV_PRESET		_IOWR('V', 84, struct v4l2_dv_preset) - added in v2.6.33-rc1~70^2~91, removed in v3.10-rc1~136^2~239 */
+/* VIDIOC_G_DV_PRESET		_IOWR('V', 85, struct v4l2_dv_preset) - added in v2.6.33-rc1~70^2~91, removed in v3.10-rc1~136^2~239 */
+/* VIDIOC_QUERY_DV_PRESET	_IOR('V',  86, struct v4l2_dv_preset) - added in v2.6.33-rc1~70^2~91, removed in v3.10-rc1~136^2~239 */
+/* VIDIOC_S_DV_TIMINGS		_IOWR('V',  87, struct v4l2_dv_timings) - added in v2.6.33-rc1~70^2~91 */
+/* VIDIOC_G_DV_TIMINGS		_IOWR('V',  88, struct v4l2_dv_timings) - added in v2.6.33-rc1~70^2~91 */
+VIDIOC_DQEVENT			_IOR ('V',  89, kernel_v4l2_event_t) /* added in v2.6.35-rc1~480^2~121 */
+/* VIDIOC_SUBSCRIBE_EVENT		_IOW ('V',  90, struct v4l2_event_subscription) - added in v2.6.35-rc1~480^2~121 */
+/* VIDIOC_UNSUBSCRIBE_EVENT	_IOW ('V',  91, struct v4l2_event_subscription) - added in v2.6.35-rc1~480^2~121 */
+VIDIOC_CREATE_BUFS		_IOWR('V',  92, struct_v4l2_create_buffers) /* added in v3.2-rc1~63^2~55 */
+VIDIOC_PREPARE_BUF		_IOWR('V',  93, kernel_v4l2_buffer_t) /* added in v3.2-rc1~63^2~55 */
+/* VIDIOC_G_SELECTION		_IOWR('V',  94, struct v4l2_selection) - added in v3.3-rc1~48^2~18 */
+/* VIDIOC_S_SELECTION		_IOWR('V',  95, struct v4l2_selection) - added in v3.3-rc1~48^2~18 */
+/* VIDIOC_DECODER_CMD		_IOWR('V',  96, struct v4l2_decoder_cmd) - added in v3.4-rc1~110^2^2~239 */
+/* VIDIOC_TRY_DECODER_CMD		_IOWR('V',  97, struct v4l2_decoder_cmd) - added in v3.4-rc1~110^2^2~239 */
+/* VIDIOC_ENUM_DV_TIMINGS		_IOWR('V',  98, struct v4l2_enum_dv_timings) - added in v3.5-rc1~104^2~100, changed in v3.5-rc5~26^2~41 */
+/* VIDIOC_QUERY_DV_TIMINGS		_IOR ('V',  99, struct v4l2_dv_timings) - added in v3.5-rc1~104^2~100, changed in v3.5-rc5~26^2~41 */
+/* VIDIOC_DV_TIMINGS_CAP		_IOWR('V', 100, struct v4l2_dv_timings_cap) - added in v3.5-rc1~104^2~100, changed in v3.5-rc5~26^2~41 */
+/* VIDIOC_ENUM_FREQ_BANDS		_IOWR('V', 101, struct v4l2_frequency_band) - added in v3.6-rc1~28^2~46 */
+/* VIDIOC_DBG_G_CHIP_INFO		_IOWR('V', 102, struct v4l2_dbg_chip_info) - added in v3.10-rc1~136^2~200 as VIDIOC_DBG_G_CHIP_NAME, renamed in v3.10-rc1~136^2~42 */
+/* VIDIOC_QUERY_EXT_CTRL		_IOWR('V', 103, struct v4l2_query_ext_ctrl) - added in v3.17-rc1~112^2~362 */
+
+/* subdev ioctls */
+/* VIDIOC_SUBDEV_ENUM_MBUS_CODE	_IOWR('V',  2, struct v4l2_subdev_mbus_code_enum) */
+/* VIDIOC_SUBDEV_G_FMT		_IOWR('V',  4, struct v4l2_subdev_format) */
+/* VIDIOC_SUBDEV_S_FMT		_IOWR('V',  5, struct v4l2_subdev_format) */
+/* VIDIOC_SUBDEV_G_FRAME_INTERVAL	_IOWR('V', 21, struct v4l2_subdev_frame_interval) - added in v2.6.39-rc1~86^2~163 */
+/* VIDIOC_SUBDEV_S_FRAME_INTERVAL	_IOWR('V', 22, struct v4l2_subdev_frame_interval) - added in v2.6.39-rc1~86^2~163 */
+/* VIDIOC_SUBDEV_G_CROP		_IOWR('V', 59, struct v4l2_subdev_crop) - added in v2.6.39-rc1~86^2~162 */
+/* VIDIOC_SUBDEV_S_CROP		_IOWR('V', 60, struct v4l2_subdev_crop) - added in v2.6.39-rc1~86^2~162 */
+/* VIDIOC_SUBDEV_G_SELECTION	_IOWR('V', 61, struct v4l2_subdev_selection) - added in v3.5-rc1~104^2~443  */
+/* VIDIOC_SUBDEV_S_SELECTION	_IOWR('V', 62, struct v4l2_subdev_selection) - added in v3.5-rc1~104^2~443 */
+/* VIDIOC_SUBDEV_ENUM_FRAME_SIZE	_IOWR('V', 74, struct v4l2_subdev_frame_size_enum) */
+/* VIDIOC_SUBDEV_ENUM_FRAME_INTERVAL	_IOWR('V', 75, struct v4l2_subdev_frame_interval_enum) - added in v2.6.39-rc1~86^2~163 */
diff -pruN 5.5-3/xlat/v4l2_memories.h 5.9-0ubuntu2/xlat/v4l2_memories.h
--- 5.5-3/xlat/v4l2_memories.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_memories.h	2020-09-24 09:18:46.000000000 +0000
@@ -42,9 +42,17 @@ extern const struct xlat v4l2_memories[]
 
 static const struct xlat_data v4l2_memories_xdata[] = {
  [V4L2_MEMORY_MMAP] = XLAT(V4L2_MEMORY_MMAP),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_MEMORY_MMAP))
+ #define XLAT_STR_0 STRINGIFY(V4L2_MEMORY_MMAP)
  [V4L2_MEMORY_USERPTR] = XLAT(V4L2_MEMORY_USERPTR),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_MEMORY_USERPTR))
+ #define XLAT_STR_1 STRINGIFY(V4L2_MEMORY_USERPTR)
  [V4L2_MEMORY_OVERLAY] = XLAT(V4L2_MEMORY_OVERLAY),
+ #define XLAT_VAL_2 ((unsigned) (V4L2_MEMORY_OVERLAY))
+ #define XLAT_STR_2 STRINGIFY(V4L2_MEMORY_OVERLAY)
  [V4L2_MEMORY_DMABUF] = XLAT(V4L2_MEMORY_DMABUF),
+ #define XLAT_VAL_3 ((unsigned) (V4L2_MEMORY_DMABUF))
+ #define XLAT_STR_3 STRINGIFY(V4L2_MEMORY_DMABUF)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -53,8 +61,44 @@ const struct xlat v4l2_memories[1] = { {
  .data = v4l2_memories_xdata,
  .size = ARRAY_SIZE(v4l2_memories_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_memories.in 5.9-0ubuntu2/xlat/v4l2_memories.in
--- 5.5-3/xlat/v4l2_memories.in	2019-10-28 19:52:59.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_memories.in	2020-05-30 08:00:00.000000000 +0000
@@ -1,4 +1,9 @@
 #value_indexed
+#enum
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 V4L2_MEMORY_MMAP	1
 V4L2_MEMORY_USERPTR	2
 V4L2_MEMORY_OVERLAY	3
diff -pruN 5.5-3/xlat/v4l2_memories.m4 5.9-0ubuntu2/xlat/v4l2_memories.m4
--- 5.5-3/xlat/v4l2_memories.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_memories.m4	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,13 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/v4l2_memories.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_v4l2_memories],[
+AC_CHECK_DECLS(m4_normalize([
+V4L2_MEMORY_MMAP,
+V4L2_MEMORY_USERPTR,
+V4L2_MEMORY_OVERLAY,
+V4L2_MEMORY_DMABUF
+]),,, [
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+])])])
diff -pruN 5.5-3/xlat/v4l2_pix_fmts.h 5.9-0ubuntu2/xlat/v4l2_pix_fmts.h
--- 5.5-3/xlat/v4l2_pix_fmts.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_pix_fmts.h	2020-09-24 09:18:48.000000000 +0000
@@ -24,6 +24,13 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define V4L2_PIX_FMT_Y4 v4l2_fourcc('Y', '0', '4', ' ')
 #endif
+#if defined(V4L2_PIX_FMT_Y14) || (defined(HAVE_DECL_V4L2_PIX_FMT_Y14) && HAVE_DECL_V4L2_PIX_FMT_Y14)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_PIX_FMT_Y14) == (v4l2_fourcc('Y', '1', '4', ' ')), "V4L2_PIX_FMT_Y14 != v4l2_fourcc('Y', '1', '4', ' ')");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_PIX_FMT_Y14 v4l2_fourcc('Y', '1', '4', ' ')
+#endif
 #if defined(V4L2_PIX_FMT_Y6) || (defined(HAVE_DECL_V4L2_PIX_FMT_Y6) && HAVE_DECL_V4L2_PIX_FMT_Y6)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
 static_assert((V4L2_PIX_FMT_Y6) == (v4l2_fourcc('Y', '0', '6', ' ')), "V4L2_PIX_FMT_Y6 != v4l2_fourcc('Y', '0', '6', ' ')");
@@ -483,6 +490,34 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
 # define V4L2_PIX_FMT_HSV24 v4l2_fourcc('H', 'S', 'V', '3')
 #endif
+#if defined(V4L2_PIX_FMT_SGBRG14) || (defined(HAVE_DECL_V4L2_PIX_FMT_SGBRG14) && HAVE_DECL_V4L2_PIX_FMT_SGBRG14)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_PIX_FMT_SGBRG14) == (v4l2_fourcc('G', 'B', '1', '4')), "V4L2_PIX_FMT_SGBRG14 != v4l2_fourcc('G', 'B', '1', '4')");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_PIX_FMT_SGBRG14 v4l2_fourcc('G', 'B', '1', '4')
+#endif
+#if defined(V4L2_PIX_FMT_SBGGR14) || (defined(HAVE_DECL_V4L2_PIX_FMT_SBGGR14) && HAVE_DECL_V4L2_PIX_FMT_SBGGR14)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_PIX_FMT_SBGGR14) == (v4l2_fourcc('B', 'G', '1', '4')), "V4L2_PIX_FMT_SBGGR14 != v4l2_fourcc('B', 'G', '1', '4')");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_PIX_FMT_SBGGR14 v4l2_fourcc('B', 'G', '1', '4')
+#endif
+#if defined(V4L2_PIX_FMT_SRGGB14) || (defined(HAVE_DECL_V4L2_PIX_FMT_SRGGB14) && HAVE_DECL_V4L2_PIX_FMT_SRGGB14)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_PIX_FMT_SRGGB14) == (v4l2_fourcc('R', 'G', '1', '4')), "V4L2_PIX_FMT_SRGGB14 != v4l2_fourcc('R', 'G', '1', '4')");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_PIX_FMT_SRGGB14 v4l2_fourcc('R', 'G', '1', '4')
+#endif
+#if defined(V4L2_PIX_FMT_SGRBG14) || (defined(HAVE_DECL_V4L2_PIX_FMT_SGRBG14) && HAVE_DECL_V4L2_PIX_FMT_SGRBG14)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((V4L2_PIX_FMT_SGRBG14) == (v4l2_fourcc('G', 'R', '1', '4')), "V4L2_PIX_FMT_SGRBG14 != v4l2_fourcc('G', 'R', '1', '4')");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define V4L2_PIX_FMT_SGRBG14 v4l2_fourcc('G', 'R', '1', '4')
+#endif
 #if defined(V4L2_PIX_FMT_ARGB32) || (defined(HAVE_DECL_V4L2_PIX_FMT_ARGB32) && HAVE_DECL_V4L2_PIX_FMT_ARGB32)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
 static_assert((V4L2_PIX_FMT_ARGB32) == (v4l2_fourcc('B', 'A', '2', '4')), "V4L2_PIX_FMT_ARGB32 != v4l2_fourcc('B', 'A', '2', '4')");
@@ -1306,44 +1341,125 @@ extern const struct xlat v4l2_pix_fmts[]
 
 static const struct xlat_data v4l2_pix_fmts_xdata[] = {
  XLAT(V4L2_PIX_FMT_Y10),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_PIX_FMT_Y10))
+ #define XLAT_STR_0 STRINGIFY(V4L2_PIX_FMT_Y10)
  XLAT(V4L2_PIX_FMT_Y12),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_PIX_FMT_Y12))
+ #define XLAT_STR_1 STRINGIFY(V4L2_PIX_FMT_Y12)
  XLAT(V4L2_PIX_FMT_Y4),
+ #define XLAT_VAL_2 ((unsigned) (V4L2_PIX_FMT_Y4))
+ #define XLAT_STR_2 STRINGIFY(V4L2_PIX_FMT_Y4)
+ XLAT(V4L2_PIX_FMT_Y14),
+ #define XLAT_VAL_3 ((unsigned) (V4L2_PIX_FMT_Y14))
+ #define XLAT_STR_3 STRINGIFY(V4L2_PIX_FMT_Y14)
  XLAT(V4L2_PIX_FMT_Y6),
+ #define XLAT_VAL_4 ((unsigned) (V4L2_PIX_FMT_Y6))
+ #define XLAT_STR_4 STRINGIFY(V4L2_PIX_FMT_Y6)
  XLAT(V4L2_PIX_FMT_Y16),
+ #define XLAT_VAL_5 ((unsigned) (V4L2_PIX_FMT_Y16))
+ #define XLAT_STR_5 STRINGIFY(V4L2_PIX_FMT_Y16)
  XLAT(V4L2_PIX_FMT_Z16),
+ #define XLAT_VAL_6 ((unsigned) (V4L2_PIX_FMT_Z16))
+ #define XLAT_STR_6 STRINGIFY(V4L2_PIX_FMT_Z16)
  XLAT(V4L2_PIX_FMT_UV8),
+ #define XLAT_VAL_7 ((unsigned) (V4L2_PIX_FMT_UV8))
+ #define XLAT_STR_7 STRINGIFY(V4L2_PIX_FMT_UV8)
  XLAT(V4L2_PIX_FMT_Y8I),
+ #define XLAT_VAL_8 ((unsigned) (V4L2_PIX_FMT_Y8I))
+ #define XLAT_STR_8 STRINGIFY(V4L2_PIX_FMT_Y8I)
  XLAT(V4L2_PIX_FMT_MR97310A),
+ #define XLAT_VAL_9 ((unsigned) (V4L2_PIX_FMT_MR97310A))
+ #define XLAT_STR_9 STRINGIFY(V4L2_PIX_FMT_MR97310A)
  XLAT(V4L2_PIX_FMT_SN9C10X),
+ #define XLAT_VAL_10 ((unsigned) (V4L2_PIX_FMT_SN9C10X))
+ #define XLAT_STR_10 STRINGIFY(V4L2_PIX_FMT_SN9C10X)
  XLAT(V4L2_PIX_FMT_SGRBG10),
+ #define XLAT_VAL_11 ((unsigned) (V4L2_PIX_FMT_SGRBG10))
+ #define XLAT_STR_11 STRINGIFY(V4L2_PIX_FMT_SGRBG10)
  XLAT(V4L2_PIX_FMT_SGBRG10),
+ #define XLAT_VAL_12 ((unsigned) (V4L2_PIX_FMT_SGBRG10))
+ #define XLAT_STR_12 STRINGIFY(V4L2_PIX_FMT_SGBRG10)
  XLAT(V4L2_PIX_FMT_SGRBG10DPCM8),
+ #define XLAT_VAL_13 ((unsigned) (V4L2_PIX_FMT_SGRBG10DPCM8))
+ #define XLAT_STR_13 STRINGIFY(V4L2_PIX_FMT_SGRBG10DPCM8)
  XLAT(V4L2_PIX_FMT_SBGGR10),
+ #define XLAT_VAL_14 ((unsigned) (V4L2_PIX_FMT_SBGGR10))
+ #define XLAT_STR_14 STRINGIFY(V4L2_PIX_FMT_SBGGR10)
  XLAT(V4L2_PIX_FMT_SRGGB10),
+ #define XLAT_VAL_15 ((unsigned) (V4L2_PIX_FMT_SRGGB10))
+ #define XLAT_STR_15 STRINGIFY(V4L2_PIX_FMT_SRGGB10)
  XLAT(V4L2_PIX_FMT_M420),
+ #define XLAT_VAL_16 ((unsigned) (V4L2_PIX_FMT_M420))
+ #define XLAT_STR_16 STRINGIFY(V4L2_PIX_FMT_M420)
  XLAT(V4L2_PIX_FMT_SN9C20X_I420),
+ #define XLAT_VAL_17 ((unsigned) (V4L2_PIX_FMT_SN9C20X_I420))
+ #define XLAT_STR_17 STRINGIFY(V4L2_PIX_FMT_SN9C20X_I420)
  XLAT(V4L2_PIX_FMT_JL2005BCD),
+ #define XLAT_VAL_18 ((unsigned) (V4L2_PIX_FMT_JL2005BCD))
+ #define XLAT_STR_18 STRINGIFY(V4L2_PIX_FMT_JL2005BCD)
  XLAT(V4L2_PIX_FMT_TM6000),
+ #define XLAT_VAL_19 ((unsigned) (V4L2_PIX_FMT_TM6000))
+ #define XLAT_STR_19 STRINGIFY(V4L2_PIX_FMT_TM6000)
  XLAT(V4L2_PIX_FMT_STV0680),
+ #define XLAT_VAL_20 ((unsigned) (V4L2_PIX_FMT_STV0680))
+ #define XLAT_STR_20 STRINGIFY(V4L2_PIX_FMT_STV0680)
  XLAT(V4L2_PIX_FMT_VP8),
+ #define XLAT_VAL_21 ((unsigned) (V4L2_PIX_FMT_VP8))
+ #define XLAT_STR_21 STRINGIFY(V4L2_PIX_FMT_VP8)
  XLAT(V4L2_PIX_FMT_VP9),
+ #define XLAT_VAL_22 ((unsigned) (V4L2_PIX_FMT_VP9))
+ #define XLAT_STR_22 STRINGIFY(V4L2_PIX_FMT_VP9)
  XLAT(V4L2_PIX_FMT_SE401),
+ #define XLAT_VAL_23 ((unsigned) (V4L2_PIX_FMT_SE401))
+ #define XLAT_STR_23 STRINGIFY(V4L2_PIX_FMT_SE401)
  XLAT(V4L2_PIX_FMT_SPCA501),
+ #define XLAT_VAL_24 ((unsigned) (V4L2_PIX_FMT_SPCA501))
+ #define XLAT_STR_24 STRINGIFY(V4L2_PIX_FMT_SPCA501)
  XLAT(V4L2_PIX_FMT_OV511),
+ #define XLAT_VAL_25 ((unsigned) (V4L2_PIX_FMT_OV511))
+ #define XLAT_STR_25 STRINGIFY(V4L2_PIX_FMT_OV511)
  XLAT(V4L2_PIX_FMT_NV21M),
+ #define XLAT_VAL_26 ((unsigned) (V4L2_PIX_FMT_NV21M))
+ #define XLAT_STR_26 STRINGIFY(V4L2_PIX_FMT_NV21M)
  XLAT(V4L2_PIX_FMT_YVU420M),
+ #define XLAT_VAL_27 ((unsigned) (V4L2_PIX_FMT_YVU420M))
+ #define XLAT_STR_27 STRINGIFY(V4L2_PIX_FMT_YVU420M)
  XLAT(V4L2_PIX_FMT_MT21C),
+ #define XLAT_VAL_28 ((unsigned) (V4L2_PIX_FMT_MT21C))
+ #define XLAT_STR_28 STRINGIFY(V4L2_PIX_FMT_MT21C)
  XLAT(V4L2_PIX_FMT_NV21),
+ #define XLAT_VAL_29 ((unsigned) (V4L2_PIX_FMT_NV21))
+ #define XLAT_STR_29 STRINGIFY(V4L2_PIX_FMT_NV21)
  XLAT(V4L2_PIX_FMT_SPCA561),
+ #define XLAT_VAL_30 ((unsigned) (V4L2_PIX_FMT_SPCA561))
+ #define XLAT_STR_30 STRINGIFY(V4L2_PIX_FMT_SPCA561)
  XLAT(V4L2_PIX_FMT_NV61M),
+ #define XLAT_VAL_31 ((unsigned) (V4L2_PIX_FMT_NV61M))
+ #define XLAT_STR_31 STRINGIFY(V4L2_PIX_FMT_NV61M)
  XLAT(V4L2_PIX_FMT_YVU422M),
+ #define XLAT_VAL_32 ((unsigned) (V4L2_PIX_FMT_YVU422M))
+ #define XLAT_STR_32 STRINGIFY(V4L2_PIX_FMT_YVU422M)
  XLAT(V4L2_PIX_FMT_NV61),
+ #define XLAT_VAL_33 ((unsigned) (V4L2_PIX_FMT_NV61))
+ #define XLAT_STR_33 STRINGIFY(V4L2_PIX_FMT_NV61)
  XLAT(V4L2_PIX_FMT_SBGGR8),
+ #define XLAT_VAL_34 ((unsigned) (V4L2_PIX_FMT_SBGGR8))
+ #define XLAT_STR_34 STRINGIFY(V4L2_PIX_FMT_SBGGR8)
  XLAT(V4L2_PIX_FMT_RGB332),
+ #define XLAT_VAL_35 ((unsigned) (V4L2_PIX_FMT_RGB332))
+ #define XLAT_STR_35 STRINGIFY(V4L2_PIX_FMT_RGB332)
  XLAT(V4L2_PIX_FMT_H264_NO_SC),
+ #define XLAT_VAL_36 ((unsigned) (V4L2_PIX_FMT_H264_NO_SC))
+ #define XLAT_STR_36 STRINGIFY(V4L2_PIX_FMT_H264_NO_SC)
  XLAT(V4L2_PIX_FMT_PWC1),
+ #define XLAT_VAL_37 ((unsigned) (V4L2_PIX_FMT_PWC1))
+ #define XLAT_STR_37 STRINGIFY(V4L2_PIX_FMT_PWC1)
  XLAT(V4L2_PIX_FMT_MPEG1),
+ #define XLAT_VAL_38 ((unsigned) (V4L2_PIX_FMT_MPEG1))
+ #define XLAT_STR_38 STRINGIFY(V4L2_PIX_FMT_MPEG1)
  XLAT(V4L2_PIX_FMT_SGRBG12),
+ #define XLAT_VAL_39 ((unsigned) (V4L2_PIX_FMT_SGRBG12))
+ #define XLAT_STR_39 STRINGIFY(V4L2_PIX_FMT_SGRBG12)
 #ifndef STRACE_WORKAROUND_FOR_V4L2_PIX_FMT_BGRA444
 # define STRACE_WORKAROUND_FOR_V4L2_PIX_FMT_BGRA444
 /*
@@ -1354,150 +1470,452 @@ static const struct xlat_data v4l2_pix_f
 # undef V4L2_PIX_FMT_BGRA444
 #endif
  XLAT(V4L2_PIX_FMT_BGRA444),
+ #define XLAT_VAL_40 ((unsigned) (V4L2_PIX_FMT_BGRA444))
+ #define XLAT_STR_40 STRINGIFY(V4L2_PIX_FMT_BGRA444)
  XLAT(V4L2_PIX_FMT_RGBA444),
+ #define XLAT_VAL_41 ((unsigned) (V4L2_PIX_FMT_RGBA444))
+ #define XLAT_STR_41 STRINGIFY(V4L2_PIX_FMT_RGBA444)
  XLAT(V4L2_PIX_FMT_ABGR444),
+ #define XLAT_VAL_42 ((unsigned) (V4L2_PIX_FMT_ABGR444))
+ #define XLAT_STR_42 STRINGIFY(V4L2_PIX_FMT_ABGR444)
  XLAT(V4L2_PIX_FMT_SGBRG12),
+ #define XLAT_VAL_43 ((unsigned) (V4L2_PIX_FMT_SGBRG12))
+ #define XLAT_STR_43 STRINGIFY(V4L2_PIX_FMT_SGBRG12)
  XLAT(V4L2_PIX_FMT_XBGR444),
+ #define XLAT_VAL_44 ((unsigned) (V4L2_PIX_FMT_XBGR444))
+ #define XLAT_STR_44 STRINGIFY(V4L2_PIX_FMT_XBGR444)
  XLAT(V4L2_PIX_FMT_SBGGR12),
+ #define XLAT_VAL_45 ((unsigned) (V4L2_PIX_FMT_SBGGR12))
+ #define XLAT_STR_45 STRINGIFY(V4L2_PIX_FMT_SBGGR12)
  XLAT(V4L2_PIX_FMT_SRGGB12),
+ #define XLAT_VAL_46 ((unsigned) (V4L2_PIX_FMT_SRGGB12))
+ #define XLAT_STR_46 STRINGIFY(V4L2_PIX_FMT_SRGGB12)
  XLAT(V4L2_PIX_FMT_HM12),
+ #define XLAT_VAL_47 ((unsigned) (V4L2_PIX_FMT_HM12))
+ #define XLAT_STR_47 STRINGIFY(V4L2_PIX_FMT_HM12)
  XLAT(V4L2_PIX_FMT_NV12M),
+ #define XLAT_VAL_48 ((unsigned) (V4L2_PIX_FMT_NV12M))
+ #define XLAT_STR_48 STRINGIFY(V4L2_PIX_FMT_NV12M)
  XLAT(V4L2_PIX_FMT_NV12MT),
+ #define XLAT_VAL_49 ((unsigned) (V4L2_PIX_FMT_NV12MT))
+ #define XLAT_STR_49 STRINGIFY(V4L2_PIX_FMT_NV12MT)
  XLAT(V4L2_PIX_FMT_NV12MT_16X16),
+ #define XLAT_VAL_50 ((unsigned) (V4L2_PIX_FMT_NV12MT_16X16))
+ #define XLAT_STR_50 STRINGIFY(V4L2_PIX_FMT_NV12MT_16X16)
  XLAT(V4L2_PIX_FMT_YUV420M),
+ #define XLAT_VAL_51 ((unsigned) (V4L2_PIX_FMT_YUV420M))
+ #define XLAT_STR_51 STRINGIFY(V4L2_PIX_FMT_YUV420M)
  XLAT(V4L2_PIX_FMT_ARGB444),
+ #define XLAT_VAL_52 ((unsigned) (V4L2_PIX_FMT_ARGB444))
+ #define XLAT_STR_52 STRINGIFY(V4L2_PIX_FMT_ARGB444)
  XLAT(V4L2_PIX_FMT_XRGB444),
+ #define XLAT_VAL_53 ((unsigned) (V4L2_PIX_FMT_XRGB444))
+ #define XLAT_STR_53 STRINGIFY(V4L2_PIX_FMT_XRGB444)
  XLAT(V4L2_PIX_FMT_SUNXI_TILED_NV12),
+ #define XLAT_VAL_54 ((unsigned) (V4L2_PIX_FMT_SUNXI_TILED_NV12))
+ #define XLAT_STR_54 STRINGIFY(V4L2_PIX_FMT_SUNXI_TILED_NV12)
  XLAT(V4L2_PIX_FMT_YUV420),
+ #define XLAT_VAL_55 ((unsigned) (V4L2_PIX_FMT_YUV420))
+ #define XLAT_STR_55 STRINGIFY(V4L2_PIX_FMT_YUV420)
  XLAT(V4L2_PIX_FMT_NV12),
+ #define XLAT_VAL_56 ((unsigned) (V4L2_PIX_FMT_NV12))
+ #define XLAT_STR_56 STRINGIFY(V4L2_PIX_FMT_NV12)
  XLAT(V4L2_PIX_FMT_YVU420),
+ #define XLAT_VAL_57 ((unsigned) (V4L2_PIX_FMT_YVU420))
+ #define XLAT_STR_57 STRINGIFY(V4L2_PIX_FMT_YVU420)
  XLAT(V4L2_PIX_FMT_BGRX444),
+ #define XLAT_VAL_58 ((unsigned) (V4L2_PIX_FMT_BGRX444))
+ #define XLAT_STR_58 STRINGIFY(V4L2_PIX_FMT_BGRX444)
  XLAT(V4L2_PIX_FMT_RGBX444),
+ #define XLAT_VAL_59 ((unsigned) (V4L2_PIX_FMT_RGBX444))
+ #define XLAT_STR_59 STRINGIFY(V4L2_PIX_FMT_RGBX444)
  XLAT(V4L2_PIX_FMT_YVU444M),
+ #define XLAT_VAL_60 ((unsigned) (V4L2_PIX_FMT_YVU444M))
+ #define XLAT_STR_60 STRINGIFY(V4L2_PIX_FMT_YVU444M)
  XLAT(V4L2_PIX_FMT_NV42),
+ #define XLAT_VAL_61 ((unsigned) (V4L2_PIX_FMT_NV42))
+ #define XLAT_STR_61 STRINGIFY(V4L2_PIX_FMT_NV42)
  XLAT(V4L2_PIX_FMT_PWC2),
+ #define XLAT_VAL_62 ((unsigned) (V4L2_PIX_FMT_PWC2))
+ #define XLAT_STR_62 STRINGIFY(V4L2_PIX_FMT_PWC2)
  XLAT(V4L2_PIX_FMT_MPEG2),
+ #define XLAT_VAL_63 ((unsigned) (V4L2_PIX_FMT_MPEG2))
+ #define XLAT_STR_63 STRINGIFY(V4L2_PIX_FMT_MPEG2)
  XLAT(V4L2_PIX_FMT_SBGGR16),
+ #define XLAT_VAL_64 ((unsigned) (V4L2_PIX_FMT_SBGGR16))
+ #define XLAT_STR_64 STRINGIFY(V4L2_PIX_FMT_SBGGR16)
  XLAT(V4L2_PIX_FMT_H263),
+ #define XLAT_VAL_65 ((unsigned) (V4L2_PIX_FMT_H263))
+ #define XLAT_STR_65 STRINGIFY(V4L2_PIX_FMT_H263)
  XLAT(V4L2_PIX_FMT_RGB24),
+ #define XLAT_VAL_66 ((unsigned) (V4L2_PIX_FMT_RGB24))
+ #define XLAT_STR_66 STRINGIFY(V4L2_PIX_FMT_RGB24)
  XLAT(V4L2_PIX_FMT_BGR24),
+ #define XLAT_VAL_67 ((unsigned) (V4L2_PIX_FMT_BGR24))
+ #define XLAT_STR_67 STRINGIFY(V4L2_PIX_FMT_BGR24)
  XLAT(V4L2_PIX_FMT_HSV24),
+ #define XLAT_VAL_68 ((unsigned) (V4L2_PIX_FMT_HSV24))
+ #define XLAT_STR_68 STRINGIFY(V4L2_PIX_FMT_HSV24)
+ XLAT(V4L2_PIX_FMT_SGBRG14),
+ #define XLAT_VAL_69 ((unsigned) (V4L2_PIX_FMT_SGBRG14))
+ #define XLAT_STR_69 STRINGIFY(V4L2_PIX_FMT_SGBRG14)
+ XLAT(V4L2_PIX_FMT_SBGGR14),
+ #define XLAT_VAL_70 ((unsigned) (V4L2_PIX_FMT_SBGGR14))
+ #define XLAT_STR_70 STRINGIFY(V4L2_PIX_FMT_SBGGR14)
+ XLAT(V4L2_PIX_FMT_SRGGB14),
+ #define XLAT_VAL_71 ((unsigned) (V4L2_PIX_FMT_SRGGB14))
+ #define XLAT_STR_71 STRINGIFY(V4L2_PIX_FMT_SRGGB14)
+ XLAT(V4L2_PIX_FMT_SGRBG14),
+ #define XLAT_VAL_72 ((unsigned) (V4L2_PIX_FMT_SGRBG14))
+ #define XLAT_STR_72 STRINGIFY(V4L2_PIX_FMT_SGRBG14)
  XLAT(V4L2_PIX_FMT_ARGB32),
+ #define XLAT_VAL_73 ((unsigned) (V4L2_PIX_FMT_ARGB32))
+ #define XLAT_STR_73 STRINGIFY(V4L2_PIX_FMT_ARGB32)
  XLAT(V4L2_PIX_FMT_BGRA32),
+ #define XLAT_VAL_74 ((unsigned) (V4L2_PIX_FMT_BGRA32))
+ #define XLAT_STR_74 STRINGIFY(V4L2_PIX_FMT_BGRA32)
  XLAT(V4L2_PIX_FMT_RGBA32),
+ #define XLAT_VAL_75 ((unsigned) (V4L2_PIX_FMT_RGBA32))
+ #define XLAT_STR_75 STRINGIFY(V4L2_PIX_FMT_RGBA32)
  XLAT(V4L2_PIX_FMT_RGBX32),
+ #define XLAT_VAL_76 ((unsigned) (V4L2_PIX_FMT_RGBX32))
+ #define XLAT_STR_76 STRINGIFY(V4L2_PIX_FMT_RGBX32)
  XLAT(V4L2_PIX_FMT_HI240),
+ #define XLAT_VAL_77 ((unsigned) (V4L2_PIX_FMT_HI240))
+ #define XLAT_STR_77 STRINGIFY(V4L2_PIX_FMT_HI240)
  XLAT(V4L2_PIX_FMT_YUV444M),
+ #define XLAT_VAL_78 ((unsigned) (V4L2_PIX_FMT_YUV444M))
+ #define XLAT_STR_78 STRINGIFY(V4L2_PIX_FMT_YUV444M)
  XLAT(V4L2_PIX_FMT_ABGR32),
+ #define XLAT_VAL_79 ((unsigned) (V4L2_PIX_FMT_ABGR32))
+ #define XLAT_STR_79 STRINGIFY(V4L2_PIX_FMT_ABGR32)
  XLAT(V4L2_PIX_FMT_XBGR32),
+ #define XLAT_VAL_80 ((unsigned) (V4L2_PIX_FMT_XBGR32))
+ #define XLAT_STR_80 STRINGIFY(V4L2_PIX_FMT_XBGR32)
  XLAT(V4L2_PIX_FMT_NV24),
+ #define XLAT_VAL_81 ((unsigned) (V4L2_PIX_FMT_NV24))
+ #define XLAT_STR_81 STRINGIFY(V4L2_PIX_FMT_NV24)
  XLAT(V4L2_PIX_FMT_XRGB32),
+ #define XLAT_VAL_82 ((unsigned) (V4L2_PIX_FMT_XRGB32))
+ #define XLAT_STR_82 STRINGIFY(V4L2_PIX_FMT_XRGB32)
  XLAT(V4L2_PIX_FMT_BGRX32),
+ #define XLAT_VAL_83 ((unsigned) (V4L2_PIX_FMT_BGRX32))
+ #define XLAT_STR_83 STRINGIFY(V4L2_PIX_FMT_BGRX32)
  XLAT(V4L2_PIX_FMT_RGB444),
+ #define XLAT_VAL_84 ((unsigned) (V4L2_PIX_FMT_RGB444))
+ #define XLAT_STR_84 STRINGIFY(V4L2_PIX_FMT_RGB444)
  XLAT(V4L2_PIX_FMT_YUV444),
+ #define XLAT_VAL_85 ((unsigned) (V4L2_PIX_FMT_YUV444))
+ #define XLAT_STR_85 STRINGIFY(V4L2_PIX_FMT_YUV444)
  XLAT(V4L2_PIX_FMT_H264),
+ #define XLAT_VAL_86 ((unsigned) (V4L2_PIX_FMT_H264))
+ #define XLAT_STR_86 STRINGIFY(V4L2_PIX_FMT_H264)
  XLAT(V4L2_PIX_FMT_H264_MVC),
+ #define XLAT_VAL_87 ((unsigned) (V4L2_PIX_FMT_H264_MVC))
+ #define XLAT_STR_87 STRINGIFY(V4L2_PIX_FMT_H264_MVC)
  XLAT(V4L2_PIX_FMT_RGB32),
+ #define XLAT_VAL_88 ((unsigned) (V4L2_PIX_FMT_RGB32))
+ #define XLAT_STR_88 STRINGIFY(V4L2_PIX_FMT_RGB32)
  XLAT(V4L2_PIX_FMT_CNF4),
+ #define XLAT_VAL_89 ((unsigned) (V4L2_PIX_FMT_CNF4))
+ #define XLAT_STR_89 STRINGIFY(V4L2_PIX_FMT_CNF4)
  XLAT(V4L2_PIX_FMT_MPEG4),
+ #define XLAT_VAL_90 ((unsigned) (V4L2_PIX_FMT_MPEG4))
+ #define XLAT_STR_90 STRINGIFY(V4L2_PIX_FMT_MPEG4)
  XLAT(V4L2_PIX_FMT_BGR32),
+ #define XLAT_VAL_91 ((unsigned) (V4L2_PIX_FMT_BGR32))
+ #define XLAT_STR_91 STRINGIFY(V4L2_PIX_FMT_BGR32)
  XLAT(V4L2_PIX_FMT_HSV32),
+ #define XLAT_VAL_92 ((unsigned) (V4L2_PIX_FMT_HSV32))
+ #define XLAT_STR_92 STRINGIFY(V4L2_PIX_FMT_HSV32)
  XLAT(V4L2_PIX_FMT_YUV32),
+ #define XLAT_VAL_93 ((unsigned) (V4L2_PIX_FMT_YUV32))
+ #define XLAT_STR_93 STRINGIFY(V4L2_PIX_FMT_YUV32)
  XLAT(V4L2_PIX_FMT_SPCA505),
+ #define XLAT_VAL_94 ((unsigned) (V4L2_PIX_FMT_SPCA505))
+ #define XLAT_STR_94 STRINGIFY(V4L2_PIX_FMT_SPCA505)
  XLAT(V4L2_PIX_FMT_BGRA555),
+ #define XLAT_VAL_95 ((unsigned) (V4L2_PIX_FMT_BGRA555))
+ #define XLAT_STR_95 STRINGIFY(V4L2_PIX_FMT_BGRA555)
  XLAT(V4L2_PIX_FMT_RGBA555),
+ #define XLAT_VAL_96 ((unsigned) (V4L2_PIX_FMT_RGBA555))
+ #define XLAT_STR_96 STRINGIFY(V4L2_PIX_FMT_RGBA555)
  XLAT(V4L2_PIX_FMT_ABGR555),
+ #define XLAT_VAL_97 ((unsigned) (V4L2_PIX_FMT_ABGR555))
+ #define XLAT_STR_97 STRINGIFY(V4L2_PIX_FMT_ABGR555)
  XLAT(V4L2_PIX_FMT_XBGR555),
+ #define XLAT_VAL_98 ((unsigned) (V4L2_PIX_FMT_XBGR555))
+ #define XLAT_STR_98 STRINGIFY(V4L2_PIX_FMT_XBGR555)
  XLAT(V4L2_PIX_FMT_ARGB555),
+ #define XLAT_VAL_99 ((unsigned) (V4L2_PIX_FMT_ARGB555))
+ #define XLAT_STR_99 STRINGIFY(V4L2_PIX_FMT_ARGB555)
  XLAT(V4L2_PIX_FMT_XRGB555),
+ #define XLAT_VAL_100 ((unsigned) (V4L2_PIX_FMT_XRGB555))
+ #define XLAT_STR_100 STRINGIFY(V4L2_PIX_FMT_XRGB555)
  XLAT(V4L2_PIX_FMT_BGRX555),
+ #define XLAT_VAL_101 ((unsigned) (V4L2_PIX_FMT_BGRX555))
+ #define XLAT_STR_101 STRINGIFY(V4L2_PIX_FMT_BGRX555)
  XLAT(V4L2_PIX_FMT_RGBX555),
+ #define XLAT_VAL_102 ((unsigned) (V4L2_PIX_FMT_RGBX555))
+ #define XLAT_STR_102 STRINGIFY(V4L2_PIX_FMT_RGBX555)
  XLAT(V4L2_PIX_FMT_ET61X251),
+ #define XLAT_VAL_103 ((unsigned) (V4L2_PIX_FMT_ET61X251))
+ #define XLAT_STR_103 STRINGIFY(V4L2_PIX_FMT_ET61X251)
  XLAT(V4L2_PIX_FMT_SGBRG16),
+ #define XLAT_VAL_104 ((unsigned) (V4L2_PIX_FMT_SGBRG16))
+ #define XLAT_STR_104 STRINGIFY(V4L2_PIX_FMT_SGBRG16)
  XLAT(V4L2_PIX_FMT_SRGGB16),
+ #define XLAT_VAL_105 ((unsigned) (V4L2_PIX_FMT_SRGGB16))
+ #define XLAT_STR_105 STRINGIFY(V4L2_PIX_FMT_SRGGB16)
  XLAT(V4L2_PIX_FMT_NV16M),
+ #define XLAT_VAL_106 ((unsigned) (V4L2_PIX_FMT_NV16M))
+ #define XLAT_STR_106 STRINGIFY(V4L2_PIX_FMT_NV16M)
  XLAT(V4L2_PIX_FMT_YUV422M),
+ #define XLAT_VAL_107 ((unsigned) (V4L2_PIX_FMT_YUV422M))
+ #define XLAT_STR_107 STRINGIFY(V4L2_PIX_FMT_YUV422M)
  XLAT(V4L2_PIX_FMT_SGRBG16),
+ #define XLAT_VAL_108 ((unsigned) (V4L2_PIX_FMT_SGRBG16))
+ #define XLAT_STR_108 STRINGIFY(V4L2_PIX_FMT_SGRBG16)
  XLAT(V4L2_PIX_FMT_NV16),
+ #define XLAT_VAL_109 ((unsigned) (V4L2_PIX_FMT_NV16))
+ #define XLAT_STR_109 STRINGIFY(V4L2_PIX_FMT_NV16)
  XLAT(V4L2_PIX_FMT_PAC207),
+ #define XLAT_VAL_110 ((unsigned) (V4L2_PIX_FMT_PAC207))
+ #define XLAT_STR_110 STRINGIFY(V4L2_PIX_FMT_PAC207)
  XLAT(V4L2_PIX_FMT_SPCA508),
+ #define XLAT_VAL_111 ((unsigned) (V4L2_PIX_FMT_SPCA508))
+ #define XLAT_STR_111 STRINGIFY(V4L2_PIX_FMT_SPCA508)
  XLAT(V4L2_PIX_FMT_OV518),
+ #define XLAT_VAL_112 ((unsigned) (V4L2_PIX_FMT_OV518))
+ #define XLAT_STR_112 STRINGIFY(V4L2_PIX_FMT_OV518)
  XLAT(V4L2_PIX_FMT_SBGGR10ALAW8),
+ #define XLAT_VAL_113 ((unsigned) (V4L2_PIX_FMT_SBGGR10ALAW8))
+ #define XLAT_STR_113 STRINGIFY(V4L2_PIX_FMT_SBGGR10ALAW8)
  XLAT(V4L2_PIX_FMT_SBGGR10DPCM8),
+ #define XLAT_VAL_114 ((unsigned) (V4L2_PIX_FMT_SBGGR10DPCM8))
+ #define XLAT_STR_114 STRINGIFY(V4L2_PIX_FMT_SBGGR10DPCM8)
  XLAT(V4L2_PIX_FMT_SGBRG10ALAW8),
+ #define XLAT_VAL_115 ((unsigned) (V4L2_PIX_FMT_SGBRG10ALAW8))
+ #define XLAT_STR_115 STRINGIFY(V4L2_PIX_FMT_SGBRG10ALAW8)
  XLAT(V4L2_PIX_FMT_SGBRG10DPCM8),
+ #define XLAT_VAL_116 ((unsigned) (V4L2_PIX_FMT_SGBRG10DPCM8))
+ #define XLAT_STR_116 STRINGIFY(V4L2_PIX_FMT_SGBRG10DPCM8)
  XLAT(V4L2_PIX_FMT_SRGGB10ALAW8),
+ #define XLAT_VAL_117 ((unsigned) (V4L2_PIX_FMT_SRGGB10ALAW8))
+ #define XLAT_STR_117 STRINGIFY(V4L2_PIX_FMT_SRGGB10ALAW8)
  XLAT(V4L2_PIX_FMT_SRGGB10DPCM8),
+ #define XLAT_VAL_118 ((unsigned) (V4L2_PIX_FMT_SRGGB10DPCM8))
+ #define XLAT_STR_118 STRINGIFY(V4L2_PIX_FMT_SRGGB10DPCM8)
  XLAT(V4L2_PIX_FMT_SGRBG10ALAW8),
+ #define XLAT_VAL_119 ((unsigned) (V4L2_PIX_FMT_SGRBG10ALAW8))
+ #define XLAT_STR_119 STRINGIFY(V4L2_PIX_FMT_SGRBG10ALAW8)
  XLAT(V4L2_PIX_FMT_PAL8),
+ #define XLAT_VAL_120 ((unsigned) (V4L2_PIX_FMT_PAL8))
+ #define XLAT_STR_120 STRINGIFY(V4L2_PIX_FMT_PAL8)
  XLAT(V4L2_PIX_FMT_YVU410),
+ #define XLAT_VAL_121 ((unsigned) (V4L2_PIX_FMT_YVU410))
+ #define XLAT_STR_121 STRINGIFY(V4L2_PIX_FMT_YVU410)
  XLAT(V4L2_PIX_FMT_YUV410),
+ #define XLAT_VAL_122 ((unsigned) (V4L2_PIX_FMT_YUV410))
+ #define XLAT_STR_122 STRINGIFY(V4L2_PIX_FMT_YUV410)
  XLAT(V4L2_PIX_FMT_SBGGR10P),
+ #define XLAT_VAL_123 ((unsigned) (V4L2_PIX_FMT_SBGGR10P))
+ #define XLAT_STR_123 STRINGIFY(V4L2_PIX_FMT_SBGGR10P)
  XLAT(V4L2_PIX_FMT_SGBRG10P),
+ #define XLAT_VAL_124 ((unsigned) (V4L2_PIX_FMT_SGBRG10P))
+ #define XLAT_STR_124 STRINGIFY(V4L2_PIX_FMT_SGBRG10P)
  XLAT(V4L2_PIX_FMT_SRGGB10P),
+ #define XLAT_VAL_125 ((unsigned) (V4L2_PIX_FMT_SRGGB10P))
+ #define XLAT_STR_125 STRINGIFY(V4L2_PIX_FMT_SRGGB10P)
  XLAT(V4L2_PIX_FMT_SGRBG10P),
+ #define XLAT_VAL_126 ((unsigned) (V4L2_PIX_FMT_SGRBG10P))
+ #define XLAT_STR_126 STRINGIFY(V4L2_PIX_FMT_SGRBG10P)
  XLAT(V4L2_PIX_FMT_CPIA1),
+ #define XLAT_VAL_127 ((unsigned) (V4L2_PIX_FMT_CPIA1))
+ #define XLAT_STR_127 STRINGIFY(V4L2_PIX_FMT_CPIA1)
  XLAT(V4L2_PIX_FMT_WNVA),
+ #define XLAT_VAL_128 ((unsigned) (V4L2_PIX_FMT_WNVA))
+ #define XLAT_STR_128 STRINGIFY(V4L2_PIX_FMT_WNVA)
  XLAT(V4L2_PIX_FMT_VUYA32),
+ #define XLAT_VAL_129 ((unsigned) (V4L2_PIX_FMT_VUYA32))
+ #define XLAT_STR_129 STRINGIFY(V4L2_PIX_FMT_VUYA32)
  XLAT(V4L2_PIX_FMT_Y10BPACK),
+ #define XLAT_VAL_130 ((unsigned) (V4L2_PIX_FMT_Y10BPACK))
+ #define XLAT_STR_130 STRINGIFY(V4L2_PIX_FMT_Y10BPACK)
  XLAT(V4L2_PIX_FMT_SRGGB8),
+ #define XLAT_VAL_131 ((unsigned) (V4L2_PIX_FMT_SRGGB8))
+ #define XLAT_STR_131 STRINGIFY(V4L2_PIX_FMT_SRGGB8)
  XLAT(V4L2_PIX_FMT_SQ905C),
+ #define XLAT_VAL_132 ((unsigned) (V4L2_PIX_FMT_SQ905C))
+ #define XLAT_STR_132 STRINGIFY(V4L2_PIX_FMT_SQ905C)
  XLAT(V4L2_PIX_FMT_SBGGR12P),
+ #define XLAT_VAL_133 ((unsigned) (V4L2_PIX_FMT_SBGGR12P))
+ #define XLAT_STR_133 STRINGIFY(V4L2_PIX_FMT_SBGGR12P)
  XLAT(V4L2_PIX_FMT_SGBRG12P),
+ #define XLAT_VAL_134 ((unsigned) (V4L2_PIX_FMT_SGBRG12P))
+ #define XLAT_STR_134 STRINGIFY(V4L2_PIX_FMT_SGBRG12P)
  XLAT(V4L2_PIX_FMT_SRGGB12P),
+ #define XLAT_VAL_135 ((unsigned) (V4L2_PIX_FMT_SRGGB12P))
+ #define XLAT_STR_135 STRINGIFY(V4L2_PIX_FMT_SRGGB12P)
  XLAT(V4L2_PIX_FMT_SGRBG12P),
+ #define XLAT_VAL_136 ((unsigned) (V4L2_PIX_FMT_SGRBG12P))
+ #define XLAT_STR_136 STRINGIFY(V4L2_PIX_FMT_SGRBG12P)
  XLAT(V4L2_PIX_FMT_HEVC),
+ #define XLAT_VAL_137 ((unsigned) (V4L2_PIX_FMT_HEVC))
+ #define XLAT_STR_137 STRINGIFY(V4L2_PIX_FMT_HEVC)
  XLAT(V4L2_PIX_FMT_XVID),
+ #define XLAT_VAL_138 ((unsigned) (V4L2_PIX_FMT_XVID))
+ #define XLAT_STR_138 STRINGIFY(V4L2_PIX_FMT_XVID)
  XLAT(V4L2_PIX_FMT_SBGGR14P),
+ #define XLAT_VAL_139 ((unsigned) (V4L2_PIX_FMT_SBGGR14P))
+ #define XLAT_STR_139 STRINGIFY(V4L2_PIX_FMT_SBGGR14P)
  XLAT(V4L2_PIX_FMT_SGBRG14P),
+ #define XLAT_VAL_140 ((unsigned) (V4L2_PIX_FMT_SGBRG14P))
+ #define XLAT_STR_140 STRINGIFY(V4L2_PIX_FMT_SGBRG14P)
  XLAT(V4L2_PIX_FMT_SRGGB14P),
+ #define XLAT_VAL_141 ((unsigned) (V4L2_PIX_FMT_SRGGB14P))
+ #define XLAT_STR_141 STRINGIFY(V4L2_PIX_FMT_SRGGB14P)
  XLAT(V4L2_PIX_FMT_SGRBG14P),
+ #define XLAT_VAL_142 ((unsigned) (V4L2_PIX_FMT_SGRBG14P))
+ #define XLAT_STR_142 STRINGIFY(V4L2_PIX_FMT_SGRBG14P)
  XLAT(V4L2_PIX_FMT_VC1_ANNEX_G),
+ #define XLAT_VAL_143 ((unsigned) (V4L2_PIX_FMT_VC1_ANNEX_G))
+ #define XLAT_STR_143 STRINGIFY(V4L2_PIX_FMT_VC1_ANNEX_G)
  XLAT(V4L2_PIX_FMT_IPU3_SGRBG10),
+ #define XLAT_VAL_144 ((unsigned) (V4L2_PIX_FMT_IPU3_SGRBG10))
+ #define XLAT_STR_144 STRINGIFY(V4L2_PIX_FMT_IPU3_SGRBG10)
  XLAT(V4L2_PIX_FMT_SGRBG8),
+ #define XLAT_VAL_145 ((unsigned) (V4L2_PIX_FMT_SGRBG8))
+ #define XLAT_STR_145 STRINGIFY(V4L2_PIX_FMT_SGRBG8)
  XLAT(V4L2_PIX_FMT_JPEG),
+ #define XLAT_VAL_146 ((unsigned) (V4L2_PIX_FMT_JPEG))
+ #define XLAT_STR_146 STRINGIFY(V4L2_PIX_FMT_JPEG)
  XLAT(V4L2_PIX_FMT_MPEG),
+ #define XLAT_VAL_147 ((unsigned) (V4L2_PIX_FMT_MPEG))
+ #define XLAT_STR_147 STRINGIFY(V4L2_PIX_FMT_MPEG)
  XLAT(V4L2_PIX_FMT_MJPEG),
+ #define XLAT_VAL_148 ((unsigned) (V4L2_PIX_FMT_MJPEG))
+ #define XLAT_STR_148 STRINGIFY(V4L2_PIX_FMT_MJPEG)
  XLAT(V4L2_PIX_FMT_PJPG),
+ #define XLAT_VAL_149 ((unsigned) (V4L2_PIX_FMT_PJPG))
+ #define XLAT_STR_149 STRINGIFY(V4L2_PIX_FMT_PJPG)
  XLAT(V4L2_PIX_FMT_SGBRG8),
+ #define XLAT_VAL_150 ((unsigned) (V4L2_PIX_FMT_SGBRG8))
+ #define XLAT_STR_150 STRINGIFY(V4L2_PIX_FMT_SGBRG8)
  XLAT(V4L2_PIX_FMT_BGR666),
+ #define XLAT_VAL_151 ((unsigned) (V4L2_PIX_FMT_BGR666))
+ #define XLAT_STR_151 STRINGIFY(V4L2_PIX_FMT_BGR666)
  XLAT(V4L2_PIX_FMT_FWHT_STATELESS),
+ #define XLAT_VAL_152 ((unsigned) (V4L2_PIX_FMT_FWHT_STATELESS))
+ #define XLAT_STR_152 STRINGIFY(V4L2_PIX_FMT_FWHT_STATELESS)
  XLAT(V4L2_PIX_FMT_Y12I),
+ #define XLAT_VAL_153 ((unsigned) (V4L2_PIX_FMT_Y12I))
+ #define XLAT_STR_153 STRINGIFY(V4L2_PIX_FMT_Y12I)
  XLAT(V4L2_PIX_FMT_S5C_UYVY_JPG),
+ #define XLAT_VAL_154 ((unsigned) (V4L2_PIX_FMT_S5C_UYVY_JPG))
+ #define XLAT_STR_154 STRINGIFY(V4L2_PIX_FMT_S5C_UYVY_JPG)
  XLAT(V4L2_PIX_FMT_KONICA420),
+ #define XLAT_VAL_155 ((unsigned) (V4L2_PIX_FMT_KONICA420))
+ #define XLAT_STR_155 STRINGIFY(V4L2_PIX_FMT_KONICA420)
  XLAT(V4L2_PIX_FMT_INZI),
+ #define XLAT_VAL_156 ((unsigned) (V4L2_PIX_FMT_INZI))
+ #define XLAT_STR_156 STRINGIFY(V4L2_PIX_FMT_INZI)
  XLAT(V4L2_PIX_FMT_VC1_ANNEX_L),
+ #define XLAT_VAL_157 ((unsigned) (V4L2_PIX_FMT_VC1_ANNEX_L))
+ #define XLAT_STR_157 STRINGIFY(V4L2_PIX_FMT_VC1_ANNEX_L)
  XLAT(V4L2_PIX_FMT_JPGL),
+ #define XLAT_VAL_158 ((unsigned) (V4L2_PIX_FMT_JPGL))
+ #define XLAT_STR_158 STRINGIFY(V4L2_PIX_FMT_JPGL)
  XLAT(V4L2_PIX_FMT_RGB555),
+ #define XLAT_VAL_159 ((unsigned) (V4L2_PIX_FMT_RGB555))
+ #define XLAT_STR_159 STRINGIFY(V4L2_PIX_FMT_RGB555)
  XLAT(V4L2_PIX_FMT_YUV555),
+ #define XLAT_VAL_160 ((unsigned) (V4L2_PIX_FMT_YUV555))
+ #define XLAT_STR_160 STRINGIFY(V4L2_PIX_FMT_YUV555)
  XLAT(V4L2_PIX_FMT_Y10P),
+ #define XLAT_VAL_161 ((unsigned) (V4L2_PIX_FMT_Y10P))
+ #define XLAT_STR_161 STRINGIFY(V4L2_PIX_FMT_Y10P)
  XLAT(V4L2_PIX_FMT_YUV411P),
+ #define XLAT_VAL_162 ((unsigned) (V4L2_PIX_FMT_YUV411P))
+ #define XLAT_STR_162 STRINGIFY(V4L2_PIX_FMT_YUV411P)
  XLAT(V4L2_PIX_FMT_Y41P),
+ #define XLAT_VAL_163 ((unsigned) (V4L2_PIX_FMT_Y41P))
+ #define XLAT_STR_163 STRINGIFY(V4L2_PIX_FMT_Y41P)
  XLAT(V4L2_PIX_FMT_YUV422P),
+ #define XLAT_VAL_164 ((unsigned) (V4L2_PIX_FMT_YUV422P))
+ #define XLAT_STR_164 STRINGIFY(V4L2_PIX_FMT_YUV422P)
  XLAT(V4L2_PIX_FMT_RGB565),
+ #define XLAT_VAL_165 ((unsigned) (V4L2_PIX_FMT_RGB565))
+ #define XLAT_STR_165 STRINGIFY(V4L2_PIX_FMT_RGB565)
  XLAT(V4L2_PIX_FMT_YUV565),
+ #define XLAT_VAL_166 ((unsigned) (V4L2_PIX_FMT_YUV565))
+ #define XLAT_STR_166 STRINGIFY(V4L2_PIX_FMT_YUV565)
  XLAT(V4L2_PIX_FMT_RGB555X),
+ #define XLAT_VAL_167 ((unsigned) (V4L2_PIX_FMT_RGB555X))
+ #define XLAT_STR_167 STRINGIFY(V4L2_PIX_FMT_RGB555X)
  XLAT(V4L2_PIX_FMT_RGB565X),
+ #define XLAT_VAL_168 ((unsigned) (V4L2_PIX_FMT_RGB565X))
+ #define XLAT_STR_168 STRINGIFY(V4L2_PIX_FMT_RGB565X)
  XLAT(V4L2_PIX_FMT_MPEG2_SLICE),
+ #define XLAT_VAL_169 ((unsigned) (V4L2_PIX_FMT_MPEG2_SLICE))
+ #define XLAT_STR_169 STRINGIFY(V4L2_PIX_FMT_MPEG2_SLICE)
  XLAT(V4L2_PIX_FMT_FWHT),
+ #define XLAT_VAL_170 ((unsigned) (V4L2_PIX_FMT_FWHT))
+ #define XLAT_STR_170 STRINGIFY(V4L2_PIX_FMT_FWHT)
  XLAT(V4L2_PIX_FMT_YVYU),
+ #define XLAT_VAL_171 ((unsigned) (V4L2_PIX_FMT_YVYU))
+ #define XLAT_STR_171 STRINGIFY(V4L2_PIX_FMT_YVYU)
  XLAT(V4L2_PIX_FMT_CIT_YYVYUY),
+ #define XLAT_VAL_172 ((unsigned) (V4L2_PIX_FMT_CIT_YYVYUY))
+ #define XLAT_STR_172 STRINGIFY(V4L2_PIX_FMT_CIT_YYVYUY)
  XLAT(V4L2_PIX_FMT_AYUV32),
+ #define XLAT_VAL_173 ((unsigned) (V4L2_PIX_FMT_AYUV32))
+ #define XLAT_STR_173 STRINGIFY(V4L2_PIX_FMT_AYUV32)
  XLAT(V4L2_PIX_FMT_XYUV32),
+ #define XLAT_VAL_174 ((unsigned) (V4L2_PIX_FMT_XYUV32))
+ #define XLAT_STR_174 STRINGIFY(V4L2_PIX_FMT_XYUV32)
  XLAT(V4L2_PIX_FMT_YYUV),
+ #define XLAT_VAL_175 ((unsigned) (V4L2_PIX_FMT_YYUV))
+ #define XLAT_STR_175 STRINGIFY(V4L2_PIX_FMT_YYUV)
  XLAT(V4L2_PIX_FMT_YUYV),
+ #define XLAT_VAL_176 ((unsigned) (V4L2_PIX_FMT_YUYV))
+ #define XLAT_STR_176 STRINGIFY(V4L2_PIX_FMT_YUYV)
  XLAT(V4L2_PIX_FMT_SN9C2028),
+ #define XLAT_VAL_177 ((unsigned) (V4L2_PIX_FMT_SN9C2028))
+ #define XLAT_STR_177 STRINGIFY(V4L2_PIX_FMT_SN9C2028)
  XLAT(V4L2_PIX_FMT_VUYX32),
+ #define XLAT_VAL_178 ((unsigned) (V4L2_PIX_FMT_VUYX32))
+ #define XLAT_STR_178 STRINGIFY(V4L2_PIX_FMT_VUYX32)
  XLAT(V4L2_PIX_FMT_GREY),
+ #define XLAT_VAL_179 ((unsigned) (V4L2_PIX_FMT_GREY))
+ #define XLAT_STR_179 STRINGIFY(V4L2_PIX_FMT_GREY)
  XLAT(V4L2_PIX_FMT_VYUY),
+ #define XLAT_VAL_180 ((unsigned) (V4L2_PIX_FMT_VYUY))
+ #define XLAT_STR_180 STRINGIFY(V4L2_PIX_FMT_VYUY)
  XLAT(V4L2_PIX_FMT_UYVY),
+ #define XLAT_VAL_181 ((unsigned) (V4L2_PIX_FMT_UYVY))
+ #define XLAT_STR_181 STRINGIFY(V4L2_PIX_FMT_UYVY)
  XLAT(V4L2_PIX_FMT_IPU3_SBGGR10),
+ #define XLAT_VAL_182 ((unsigned) (V4L2_PIX_FMT_IPU3_SBGGR10))
+ #define XLAT_STR_182 STRINGIFY(V4L2_PIX_FMT_IPU3_SBGGR10)
  XLAT(V4L2_PIX_FMT_DV),
+ #define XLAT_VAL_183 ((unsigned) (V4L2_PIX_FMT_DV))
+ #define XLAT_STR_183 STRINGIFY(V4L2_PIX_FMT_DV)
  XLAT(V4L2_PIX_FMT_IPU3_SGBRG10),
+ #define XLAT_VAL_184 ((unsigned) (V4L2_PIX_FMT_IPU3_SGBRG10))
+ #define XLAT_STR_184 STRINGIFY(V4L2_PIX_FMT_IPU3_SGBRG10)
  XLAT(V4L2_PIX_FMT_IPU3_SRGGB10),
+ #define XLAT_VAL_185 ((unsigned) (V4L2_PIX_FMT_IPU3_SRGGB10))
+ #define XLAT_STR_185 STRINGIFY(V4L2_PIX_FMT_IPU3_SRGGB10)
  XLAT(V4L2_PIX_FMT_Y16_BE),
+ #define XLAT_VAL_186 ((unsigned) (V4L2_PIX_FMT_Y16_BE))
+ #define XLAT_STR_186 STRINGIFY(V4L2_PIX_FMT_Y16_BE)
  XLAT(V4L2_PIX_FMT_ARGB555X),
+ #define XLAT_VAL_187 ((unsigned) (V4L2_PIX_FMT_ARGB555X))
+ #define XLAT_STR_187 STRINGIFY(V4L2_PIX_FMT_ARGB555X)
  XLAT(V4L2_PIX_FMT_XRGB555X),
+ #define XLAT_VAL_188 ((unsigned) (V4L2_PIX_FMT_XRGB555X))
+ #define XLAT_STR_188 STRINGIFY(V4L2_PIX_FMT_XRGB555X)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -1506,8 +1924,1524 @@ const struct xlat v4l2_pix_fmts[1] = { {
  .data = v4l2_pix_fmts_xdata,
  .size = ARRAY_SIZE(v4l2_pix_fmts_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+#  ifdef XLAT_VAL_13
+  | XLAT_VAL_13
+#  endif
+#  ifdef XLAT_VAL_14
+  | XLAT_VAL_14
+#  endif
+#  ifdef XLAT_VAL_15
+  | XLAT_VAL_15
+#  endif
+#  ifdef XLAT_VAL_16
+  | XLAT_VAL_16
+#  endif
+#  ifdef XLAT_VAL_17
+  | XLAT_VAL_17
+#  endif
+#  ifdef XLAT_VAL_18
+  | XLAT_VAL_18
+#  endif
+#  ifdef XLAT_VAL_19
+  | XLAT_VAL_19
+#  endif
+#  ifdef XLAT_VAL_20
+  | XLAT_VAL_20
+#  endif
+#  ifdef XLAT_VAL_21
+  | XLAT_VAL_21
+#  endif
+#  ifdef XLAT_VAL_22
+  | XLAT_VAL_22
+#  endif
+#  ifdef XLAT_VAL_23
+  | XLAT_VAL_23
+#  endif
+#  ifdef XLAT_VAL_24
+  | XLAT_VAL_24
+#  endif
+#  ifdef XLAT_VAL_25
+  | XLAT_VAL_25
+#  endif
+#  ifdef XLAT_VAL_26
+  | XLAT_VAL_26
+#  endif
+#  ifdef XLAT_VAL_27
+  | XLAT_VAL_27
+#  endif
+#  ifdef XLAT_VAL_28
+  | XLAT_VAL_28
+#  endif
+#  ifdef XLAT_VAL_29
+  | XLAT_VAL_29
+#  endif
+#  ifdef XLAT_VAL_30
+  | XLAT_VAL_30
+#  endif
+#  ifdef XLAT_VAL_31
+  | XLAT_VAL_31
+#  endif
+#  ifdef XLAT_VAL_32
+  | XLAT_VAL_32
+#  endif
+#  ifdef XLAT_VAL_33
+  | XLAT_VAL_33
+#  endif
+#  ifdef XLAT_VAL_34
+  | XLAT_VAL_34
+#  endif
+#  ifdef XLAT_VAL_35
+  | XLAT_VAL_35
+#  endif
+#  ifdef XLAT_VAL_36
+  | XLAT_VAL_36
+#  endif
+#  ifdef XLAT_VAL_37
+  | XLAT_VAL_37
+#  endif
+#  ifdef XLAT_VAL_38
+  | XLAT_VAL_38
+#  endif
+#  ifdef XLAT_VAL_39
+  | XLAT_VAL_39
+#  endif
+#  ifdef XLAT_VAL_40
+  | XLAT_VAL_40
+#  endif
+#  ifdef XLAT_VAL_41
+  | XLAT_VAL_41
+#  endif
+#  ifdef XLAT_VAL_42
+  | XLAT_VAL_42
+#  endif
+#  ifdef XLAT_VAL_43
+  | XLAT_VAL_43
+#  endif
+#  ifdef XLAT_VAL_44
+  | XLAT_VAL_44
+#  endif
+#  ifdef XLAT_VAL_45
+  | XLAT_VAL_45
+#  endif
+#  ifdef XLAT_VAL_46
+  | XLAT_VAL_46
+#  endif
+#  ifdef XLAT_VAL_47
+  | XLAT_VAL_47
+#  endif
+#  ifdef XLAT_VAL_48
+  | XLAT_VAL_48
+#  endif
+#  ifdef XLAT_VAL_49
+  | XLAT_VAL_49
+#  endif
+#  ifdef XLAT_VAL_50
+  | XLAT_VAL_50
+#  endif
+#  ifdef XLAT_VAL_51
+  | XLAT_VAL_51
+#  endif
+#  ifdef XLAT_VAL_52
+  | XLAT_VAL_52
+#  endif
+#  ifdef XLAT_VAL_53
+  | XLAT_VAL_53
+#  endif
+#  ifdef XLAT_VAL_54
+  | XLAT_VAL_54
+#  endif
+#  ifdef XLAT_VAL_55
+  | XLAT_VAL_55
+#  endif
+#  ifdef XLAT_VAL_56
+  | XLAT_VAL_56
+#  endif
+#  ifdef XLAT_VAL_57
+  | XLAT_VAL_57
+#  endif
+#  ifdef XLAT_VAL_58
+  | XLAT_VAL_58
+#  endif
+#  ifdef XLAT_VAL_59
+  | XLAT_VAL_59
+#  endif
+#  ifdef XLAT_VAL_60
+  | XLAT_VAL_60
+#  endif
+#  ifdef XLAT_VAL_61
+  | XLAT_VAL_61
+#  endif
+#  ifdef XLAT_VAL_62
+  | XLAT_VAL_62
+#  endif
+#  ifdef XLAT_VAL_63
+  | XLAT_VAL_63
+#  endif
+#  ifdef XLAT_VAL_64
+  | XLAT_VAL_64
+#  endif
+#  ifdef XLAT_VAL_65
+  | XLAT_VAL_65
+#  endif
+#  ifdef XLAT_VAL_66
+  | XLAT_VAL_66
+#  endif
+#  ifdef XLAT_VAL_67
+  | XLAT_VAL_67
+#  endif
+#  ifdef XLAT_VAL_68
+  | XLAT_VAL_68
+#  endif
+#  ifdef XLAT_VAL_69
+  | XLAT_VAL_69
+#  endif
+#  ifdef XLAT_VAL_70
+  | XLAT_VAL_70
+#  endif
+#  ifdef XLAT_VAL_71
+  | XLAT_VAL_71
+#  endif
+#  ifdef XLAT_VAL_72
+  | XLAT_VAL_72
+#  endif
+#  ifdef XLAT_VAL_73
+  | XLAT_VAL_73
+#  endif
+#  ifdef XLAT_VAL_74
+  | XLAT_VAL_74
+#  endif
+#  ifdef XLAT_VAL_75
+  | XLAT_VAL_75
+#  endif
+#  ifdef XLAT_VAL_76
+  | XLAT_VAL_76
+#  endif
+#  ifdef XLAT_VAL_77
+  | XLAT_VAL_77
+#  endif
+#  ifdef XLAT_VAL_78
+  | XLAT_VAL_78
+#  endif
+#  ifdef XLAT_VAL_79
+  | XLAT_VAL_79
+#  endif
+#  ifdef XLAT_VAL_80
+  | XLAT_VAL_80
+#  endif
+#  ifdef XLAT_VAL_81
+  | XLAT_VAL_81
+#  endif
+#  ifdef XLAT_VAL_82
+  | XLAT_VAL_82
+#  endif
+#  ifdef XLAT_VAL_83
+  | XLAT_VAL_83
+#  endif
+#  ifdef XLAT_VAL_84
+  | XLAT_VAL_84
+#  endif
+#  ifdef XLAT_VAL_85
+  | XLAT_VAL_85
+#  endif
+#  ifdef XLAT_VAL_86
+  | XLAT_VAL_86
+#  endif
+#  ifdef XLAT_VAL_87
+  | XLAT_VAL_87
+#  endif
+#  ifdef XLAT_VAL_88
+  | XLAT_VAL_88
+#  endif
+#  ifdef XLAT_VAL_89
+  | XLAT_VAL_89
+#  endif
+#  ifdef XLAT_VAL_90
+  | XLAT_VAL_90
+#  endif
+#  ifdef XLAT_VAL_91
+  | XLAT_VAL_91
+#  endif
+#  ifdef XLAT_VAL_92
+  | XLAT_VAL_92
+#  endif
+#  ifdef XLAT_VAL_93
+  | XLAT_VAL_93
+#  endif
+#  ifdef XLAT_VAL_94
+  | XLAT_VAL_94
+#  endif
+#  ifdef XLAT_VAL_95
+  | XLAT_VAL_95
+#  endif
+#  ifdef XLAT_VAL_96
+  | XLAT_VAL_96
+#  endif
+#  ifdef XLAT_VAL_97
+  | XLAT_VAL_97
+#  endif
+#  ifdef XLAT_VAL_98
+  | XLAT_VAL_98
+#  endif
+#  ifdef XLAT_VAL_99
+  | XLAT_VAL_99
+#  endif
+#  ifdef XLAT_VAL_100
+  | XLAT_VAL_100
+#  endif
+#  ifdef XLAT_VAL_101
+  | XLAT_VAL_101
+#  endif
+#  ifdef XLAT_VAL_102
+  | XLAT_VAL_102
+#  endif
+#  ifdef XLAT_VAL_103
+  | XLAT_VAL_103
+#  endif
+#  ifdef XLAT_VAL_104
+  | XLAT_VAL_104
+#  endif
+#  ifdef XLAT_VAL_105
+  | XLAT_VAL_105
+#  endif
+#  ifdef XLAT_VAL_106
+  | XLAT_VAL_106
+#  endif
+#  ifdef XLAT_VAL_107
+  | XLAT_VAL_107
+#  endif
+#  ifdef XLAT_VAL_108
+  | XLAT_VAL_108
+#  endif
+#  ifdef XLAT_VAL_109
+  | XLAT_VAL_109
+#  endif
+#  ifdef XLAT_VAL_110
+  | XLAT_VAL_110
+#  endif
+#  ifdef XLAT_VAL_111
+  | XLAT_VAL_111
+#  endif
+#  ifdef XLAT_VAL_112
+  | XLAT_VAL_112
+#  endif
+#  ifdef XLAT_VAL_113
+  | XLAT_VAL_113
+#  endif
+#  ifdef XLAT_VAL_114
+  | XLAT_VAL_114
+#  endif
+#  ifdef XLAT_VAL_115
+  | XLAT_VAL_115
+#  endif
+#  ifdef XLAT_VAL_116
+  | XLAT_VAL_116
+#  endif
+#  ifdef XLAT_VAL_117
+  | XLAT_VAL_117
+#  endif
+#  ifdef XLAT_VAL_118
+  | XLAT_VAL_118
+#  endif
+#  ifdef XLAT_VAL_119
+  | XLAT_VAL_119
+#  endif
+#  ifdef XLAT_VAL_120
+  | XLAT_VAL_120
+#  endif
+#  ifdef XLAT_VAL_121
+  | XLAT_VAL_121
+#  endif
+#  ifdef XLAT_VAL_122
+  | XLAT_VAL_122
+#  endif
+#  ifdef XLAT_VAL_123
+  | XLAT_VAL_123
+#  endif
+#  ifdef XLAT_VAL_124
+  | XLAT_VAL_124
+#  endif
+#  ifdef XLAT_VAL_125
+  | XLAT_VAL_125
+#  endif
+#  ifdef XLAT_VAL_126
+  | XLAT_VAL_126
+#  endif
+#  ifdef XLAT_VAL_127
+  | XLAT_VAL_127
+#  endif
+#  ifdef XLAT_VAL_128
+  | XLAT_VAL_128
+#  endif
+#  ifdef XLAT_VAL_129
+  | XLAT_VAL_129
+#  endif
+#  ifdef XLAT_VAL_130
+  | XLAT_VAL_130
+#  endif
+#  ifdef XLAT_VAL_131
+  | XLAT_VAL_131
+#  endif
+#  ifdef XLAT_VAL_132
+  | XLAT_VAL_132
+#  endif
+#  ifdef XLAT_VAL_133
+  | XLAT_VAL_133
+#  endif
+#  ifdef XLAT_VAL_134
+  | XLAT_VAL_134
+#  endif
+#  ifdef XLAT_VAL_135
+  | XLAT_VAL_135
+#  endif
+#  ifdef XLAT_VAL_136
+  | XLAT_VAL_136
+#  endif
+#  ifdef XLAT_VAL_137
+  | XLAT_VAL_137
+#  endif
+#  ifdef XLAT_VAL_138
+  | XLAT_VAL_138
+#  endif
+#  ifdef XLAT_VAL_139
+  | XLAT_VAL_139
+#  endif
+#  ifdef XLAT_VAL_140
+  | XLAT_VAL_140
+#  endif
+#  ifdef XLAT_VAL_141
+  | XLAT_VAL_141
+#  endif
+#  ifdef XLAT_VAL_142
+  | XLAT_VAL_142
+#  endif
+#  ifdef XLAT_VAL_143
+  | XLAT_VAL_143
+#  endif
+#  ifdef XLAT_VAL_144
+  | XLAT_VAL_144
+#  endif
+#  ifdef XLAT_VAL_145
+  | XLAT_VAL_145
+#  endif
+#  ifdef XLAT_VAL_146
+  | XLAT_VAL_146
+#  endif
+#  ifdef XLAT_VAL_147
+  | XLAT_VAL_147
+#  endif
+#  ifdef XLAT_VAL_148
+  | XLAT_VAL_148
+#  endif
+#  ifdef XLAT_VAL_149
+  | XLAT_VAL_149
+#  endif
+#  ifdef XLAT_VAL_150
+  | XLAT_VAL_150
+#  endif
+#  ifdef XLAT_VAL_151
+  | XLAT_VAL_151
+#  endif
+#  ifdef XLAT_VAL_152
+  | XLAT_VAL_152
+#  endif
+#  ifdef XLAT_VAL_153
+  | XLAT_VAL_153
+#  endif
+#  ifdef XLAT_VAL_154
+  | XLAT_VAL_154
+#  endif
+#  ifdef XLAT_VAL_155
+  | XLAT_VAL_155
+#  endif
+#  ifdef XLAT_VAL_156
+  | XLAT_VAL_156
+#  endif
+#  ifdef XLAT_VAL_157
+  | XLAT_VAL_157
+#  endif
+#  ifdef XLAT_VAL_158
+  | XLAT_VAL_158
+#  endif
+#  ifdef XLAT_VAL_159
+  | XLAT_VAL_159
+#  endif
+#  ifdef XLAT_VAL_160
+  | XLAT_VAL_160
+#  endif
+#  ifdef XLAT_VAL_161
+  | XLAT_VAL_161
+#  endif
+#  ifdef XLAT_VAL_162
+  | XLAT_VAL_162
+#  endif
+#  ifdef XLAT_VAL_163
+  | XLAT_VAL_163
+#  endif
+#  ifdef XLAT_VAL_164
+  | XLAT_VAL_164
+#  endif
+#  ifdef XLAT_VAL_165
+  | XLAT_VAL_165
+#  endif
+#  ifdef XLAT_VAL_166
+  | XLAT_VAL_166
+#  endif
+#  ifdef XLAT_VAL_167
+  | XLAT_VAL_167
+#  endif
+#  ifdef XLAT_VAL_168
+  | XLAT_VAL_168
+#  endif
+#  ifdef XLAT_VAL_169
+  | XLAT_VAL_169
+#  endif
+#  ifdef XLAT_VAL_170
+  | XLAT_VAL_170
+#  endif
+#  ifdef XLAT_VAL_171
+  | XLAT_VAL_171
+#  endif
+#  ifdef XLAT_VAL_172
+  | XLAT_VAL_172
+#  endif
+#  ifdef XLAT_VAL_173
+  | XLAT_VAL_173
+#  endif
+#  ifdef XLAT_VAL_174
+  | XLAT_VAL_174
+#  endif
+#  ifdef XLAT_VAL_175
+  | XLAT_VAL_175
+#  endif
+#  ifdef XLAT_VAL_176
+  | XLAT_VAL_176
+#  endif
+#  ifdef XLAT_VAL_177
+  | XLAT_VAL_177
+#  endif
+#  ifdef XLAT_VAL_178
+  | XLAT_VAL_178
+#  endif
+#  ifdef XLAT_VAL_179
+  | XLAT_VAL_179
+#  endif
+#  ifdef XLAT_VAL_180
+  | XLAT_VAL_180
+#  endif
+#  ifdef XLAT_VAL_181
+  | XLAT_VAL_181
+#  endif
+#  ifdef XLAT_VAL_182
+  | XLAT_VAL_182
+#  endif
+#  ifdef XLAT_VAL_183
+  | XLAT_VAL_183
+#  endif
+#  ifdef XLAT_VAL_184
+  | XLAT_VAL_184
+#  endif
+#  ifdef XLAT_VAL_185
+  | XLAT_VAL_185
+#  endif
+#  ifdef XLAT_VAL_186
+  | XLAT_VAL_186
+#  endif
+#  ifdef XLAT_VAL_187
+  | XLAT_VAL_187
+#  endif
+#  ifdef XLAT_VAL_188
+  | XLAT_VAL_188
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+#  ifdef XLAT_STR_13
+  + sizeof(XLAT_STR_13)
+#  endif
+#  ifdef XLAT_STR_14
+  + sizeof(XLAT_STR_14)
+#  endif
+#  ifdef XLAT_STR_15
+  + sizeof(XLAT_STR_15)
+#  endif
+#  ifdef XLAT_STR_16
+  + sizeof(XLAT_STR_16)
+#  endif
+#  ifdef XLAT_STR_17
+  + sizeof(XLAT_STR_17)
+#  endif
+#  ifdef XLAT_STR_18
+  + sizeof(XLAT_STR_18)
+#  endif
+#  ifdef XLAT_STR_19
+  + sizeof(XLAT_STR_19)
+#  endif
+#  ifdef XLAT_STR_20
+  + sizeof(XLAT_STR_20)
+#  endif
+#  ifdef XLAT_STR_21
+  + sizeof(XLAT_STR_21)
+#  endif
+#  ifdef XLAT_STR_22
+  + sizeof(XLAT_STR_22)
+#  endif
+#  ifdef XLAT_STR_23
+  + sizeof(XLAT_STR_23)
+#  endif
+#  ifdef XLAT_STR_24
+  + sizeof(XLAT_STR_24)
+#  endif
+#  ifdef XLAT_STR_25
+  + sizeof(XLAT_STR_25)
+#  endif
+#  ifdef XLAT_STR_26
+  + sizeof(XLAT_STR_26)
+#  endif
+#  ifdef XLAT_STR_27
+  + sizeof(XLAT_STR_27)
+#  endif
+#  ifdef XLAT_STR_28
+  + sizeof(XLAT_STR_28)
+#  endif
+#  ifdef XLAT_STR_29
+  + sizeof(XLAT_STR_29)
+#  endif
+#  ifdef XLAT_STR_30
+  + sizeof(XLAT_STR_30)
+#  endif
+#  ifdef XLAT_STR_31
+  + sizeof(XLAT_STR_31)
+#  endif
+#  ifdef XLAT_STR_32
+  + sizeof(XLAT_STR_32)
+#  endif
+#  ifdef XLAT_STR_33
+  + sizeof(XLAT_STR_33)
+#  endif
+#  ifdef XLAT_STR_34
+  + sizeof(XLAT_STR_34)
+#  endif
+#  ifdef XLAT_STR_35
+  + sizeof(XLAT_STR_35)
+#  endif
+#  ifdef XLAT_STR_36
+  + sizeof(XLAT_STR_36)
+#  endif
+#  ifdef XLAT_STR_37
+  + sizeof(XLAT_STR_37)
+#  endif
+#  ifdef XLAT_STR_38
+  + sizeof(XLAT_STR_38)
+#  endif
+#  ifdef XLAT_STR_39
+  + sizeof(XLAT_STR_39)
+#  endif
+#  ifdef XLAT_STR_40
+  + sizeof(XLAT_STR_40)
+#  endif
+#  ifdef XLAT_STR_41
+  + sizeof(XLAT_STR_41)
+#  endif
+#  ifdef XLAT_STR_42
+  + sizeof(XLAT_STR_42)
+#  endif
+#  ifdef XLAT_STR_43
+  + sizeof(XLAT_STR_43)
+#  endif
+#  ifdef XLAT_STR_44
+  + sizeof(XLAT_STR_44)
+#  endif
+#  ifdef XLAT_STR_45
+  + sizeof(XLAT_STR_45)
+#  endif
+#  ifdef XLAT_STR_46
+  + sizeof(XLAT_STR_46)
+#  endif
+#  ifdef XLAT_STR_47
+  + sizeof(XLAT_STR_47)
+#  endif
+#  ifdef XLAT_STR_48
+  + sizeof(XLAT_STR_48)
+#  endif
+#  ifdef XLAT_STR_49
+  + sizeof(XLAT_STR_49)
+#  endif
+#  ifdef XLAT_STR_50
+  + sizeof(XLAT_STR_50)
+#  endif
+#  ifdef XLAT_STR_51
+  + sizeof(XLAT_STR_51)
+#  endif
+#  ifdef XLAT_STR_52
+  + sizeof(XLAT_STR_52)
+#  endif
+#  ifdef XLAT_STR_53
+  + sizeof(XLAT_STR_53)
+#  endif
+#  ifdef XLAT_STR_54
+  + sizeof(XLAT_STR_54)
+#  endif
+#  ifdef XLAT_STR_55
+  + sizeof(XLAT_STR_55)
+#  endif
+#  ifdef XLAT_STR_56
+  + sizeof(XLAT_STR_56)
+#  endif
+#  ifdef XLAT_STR_57
+  + sizeof(XLAT_STR_57)
+#  endif
+#  ifdef XLAT_STR_58
+  + sizeof(XLAT_STR_58)
+#  endif
+#  ifdef XLAT_STR_59
+  + sizeof(XLAT_STR_59)
+#  endif
+#  ifdef XLAT_STR_60
+  + sizeof(XLAT_STR_60)
+#  endif
+#  ifdef XLAT_STR_61
+  + sizeof(XLAT_STR_61)
+#  endif
+#  ifdef XLAT_STR_62
+  + sizeof(XLAT_STR_62)
+#  endif
+#  ifdef XLAT_STR_63
+  + sizeof(XLAT_STR_63)
+#  endif
+#  ifdef XLAT_STR_64
+  + sizeof(XLAT_STR_64)
+#  endif
+#  ifdef XLAT_STR_65
+  + sizeof(XLAT_STR_65)
+#  endif
+#  ifdef XLAT_STR_66
+  + sizeof(XLAT_STR_66)
+#  endif
+#  ifdef XLAT_STR_67
+  + sizeof(XLAT_STR_67)
+#  endif
+#  ifdef XLAT_STR_68
+  + sizeof(XLAT_STR_68)
+#  endif
+#  ifdef XLAT_STR_69
+  + sizeof(XLAT_STR_69)
+#  endif
+#  ifdef XLAT_STR_70
+  + sizeof(XLAT_STR_70)
+#  endif
+#  ifdef XLAT_STR_71
+  + sizeof(XLAT_STR_71)
+#  endif
+#  ifdef XLAT_STR_72
+  + sizeof(XLAT_STR_72)
+#  endif
+#  ifdef XLAT_STR_73
+  + sizeof(XLAT_STR_73)
+#  endif
+#  ifdef XLAT_STR_74
+  + sizeof(XLAT_STR_74)
+#  endif
+#  ifdef XLAT_STR_75
+  + sizeof(XLAT_STR_75)
+#  endif
+#  ifdef XLAT_STR_76
+  + sizeof(XLAT_STR_76)
+#  endif
+#  ifdef XLAT_STR_77
+  + sizeof(XLAT_STR_77)
+#  endif
+#  ifdef XLAT_STR_78
+  + sizeof(XLAT_STR_78)
+#  endif
+#  ifdef XLAT_STR_79
+  + sizeof(XLAT_STR_79)
+#  endif
+#  ifdef XLAT_STR_80
+  + sizeof(XLAT_STR_80)
+#  endif
+#  ifdef XLAT_STR_81
+  + sizeof(XLAT_STR_81)
+#  endif
+#  ifdef XLAT_STR_82
+  + sizeof(XLAT_STR_82)
+#  endif
+#  ifdef XLAT_STR_83
+  + sizeof(XLAT_STR_83)
+#  endif
+#  ifdef XLAT_STR_84
+  + sizeof(XLAT_STR_84)
+#  endif
+#  ifdef XLAT_STR_85
+  + sizeof(XLAT_STR_85)
+#  endif
+#  ifdef XLAT_STR_86
+  + sizeof(XLAT_STR_86)
+#  endif
+#  ifdef XLAT_STR_87
+  + sizeof(XLAT_STR_87)
+#  endif
+#  ifdef XLAT_STR_88
+  + sizeof(XLAT_STR_88)
+#  endif
+#  ifdef XLAT_STR_89
+  + sizeof(XLAT_STR_89)
+#  endif
+#  ifdef XLAT_STR_90
+  + sizeof(XLAT_STR_90)
+#  endif
+#  ifdef XLAT_STR_91
+  + sizeof(XLAT_STR_91)
+#  endif
+#  ifdef XLAT_STR_92
+  + sizeof(XLAT_STR_92)
+#  endif
+#  ifdef XLAT_STR_93
+  + sizeof(XLAT_STR_93)
+#  endif
+#  ifdef XLAT_STR_94
+  + sizeof(XLAT_STR_94)
+#  endif
+#  ifdef XLAT_STR_95
+  + sizeof(XLAT_STR_95)
+#  endif
+#  ifdef XLAT_STR_96
+  + sizeof(XLAT_STR_96)
+#  endif
+#  ifdef XLAT_STR_97
+  + sizeof(XLAT_STR_97)
+#  endif
+#  ifdef XLAT_STR_98
+  + sizeof(XLAT_STR_98)
+#  endif
+#  ifdef XLAT_STR_99
+  + sizeof(XLAT_STR_99)
+#  endif
+#  ifdef XLAT_STR_100
+  + sizeof(XLAT_STR_100)
+#  endif
+#  ifdef XLAT_STR_101
+  + sizeof(XLAT_STR_101)
+#  endif
+#  ifdef XLAT_STR_102
+  + sizeof(XLAT_STR_102)
+#  endif
+#  ifdef XLAT_STR_103
+  + sizeof(XLAT_STR_103)
+#  endif
+#  ifdef XLAT_STR_104
+  + sizeof(XLAT_STR_104)
+#  endif
+#  ifdef XLAT_STR_105
+  + sizeof(XLAT_STR_105)
+#  endif
+#  ifdef XLAT_STR_106
+  + sizeof(XLAT_STR_106)
+#  endif
+#  ifdef XLAT_STR_107
+  + sizeof(XLAT_STR_107)
+#  endif
+#  ifdef XLAT_STR_108
+  + sizeof(XLAT_STR_108)
+#  endif
+#  ifdef XLAT_STR_109
+  + sizeof(XLAT_STR_109)
+#  endif
+#  ifdef XLAT_STR_110
+  + sizeof(XLAT_STR_110)
+#  endif
+#  ifdef XLAT_STR_111
+  + sizeof(XLAT_STR_111)
+#  endif
+#  ifdef XLAT_STR_112
+  + sizeof(XLAT_STR_112)
+#  endif
+#  ifdef XLAT_STR_113
+  + sizeof(XLAT_STR_113)
+#  endif
+#  ifdef XLAT_STR_114
+  + sizeof(XLAT_STR_114)
+#  endif
+#  ifdef XLAT_STR_115
+  + sizeof(XLAT_STR_115)
+#  endif
+#  ifdef XLAT_STR_116
+  + sizeof(XLAT_STR_116)
+#  endif
+#  ifdef XLAT_STR_117
+  + sizeof(XLAT_STR_117)
+#  endif
+#  ifdef XLAT_STR_118
+  + sizeof(XLAT_STR_118)
+#  endif
+#  ifdef XLAT_STR_119
+  + sizeof(XLAT_STR_119)
+#  endif
+#  ifdef XLAT_STR_120
+  + sizeof(XLAT_STR_120)
+#  endif
+#  ifdef XLAT_STR_121
+  + sizeof(XLAT_STR_121)
+#  endif
+#  ifdef XLAT_STR_122
+  + sizeof(XLAT_STR_122)
+#  endif
+#  ifdef XLAT_STR_123
+  + sizeof(XLAT_STR_123)
+#  endif
+#  ifdef XLAT_STR_124
+  + sizeof(XLAT_STR_124)
+#  endif
+#  ifdef XLAT_STR_125
+  + sizeof(XLAT_STR_125)
+#  endif
+#  ifdef XLAT_STR_126
+  + sizeof(XLAT_STR_126)
+#  endif
+#  ifdef XLAT_STR_127
+  + sizeof(XLAT_STR_127)
+#  endif
+#  ifdef XLAT_STR_128
+  + sizeof(XLAT_STR_128)
+#  endif
+#  ifdef XLAT_STR_129
+  + sizeof(XLAT_STR_129)
+#  endif
+#  ifdef XLAT_STR_130
+  + sizeof(XLAT_STR_130)
+#  endif
+#  ifdef XLAT_STR_131
+  + sizeof(XLAT_STR_131)
+#  endif
+#  ifdef XLAT_STR_132
+  + sizeof(XLAT_STR_132)
+#  endif
+#  ifdef XLAT_STR_133
+  + sizeof(XLAT_STR_133)
+#  endif
+#  ifdef XLAT_STR_134
+  + sizeof(XLAT_STR_134)
+#  endif
+#  ifdef XLAT_STR_135
+  + sizeof(XLAT_STR_135)
+#  endif
+#  ifdef XLAT_STR_136
+  + sizeof(XLAT_STR_136)
+#  endif
+#  ifdef XLAT_STR_137
+  + sizeof(XLAT_STR_137)
+#  endif
+#  ifdef XLAT_STR_138
+  + sizeof(XLAT_STR_138)
+#  endif
+#  ifdef XLAT_STR_139
+  + sizeof(XLAT_STR_139)
+#  endif
+#  ifdef XLAT_STR_140
+  + sizeof(XLAT_STR_140)
+#  endif
+#  ifdef XLAT_STR_141
+  + sizeof(XLAT_STR_141)
+#  endif
+#  ifdef XLAT_STR_142
+  + sizeof(XLAT_STR_142)
+#  endif
+#  ifdef XLAT_STR_143
+  + sizeof(XLAT_STR_143)
+#  endif
+#  ifdef XLAT_STR_144
+  + sizeof(XLAT_STR_144)
+#  endif
+#  ifdef XLAT_STR_145
+  + sizeof(XLAT_STR_145)
+#  endif
+#  ifdef XLAT_STR_146
+  + sizeof(XLAT_STR_146)
+#  endif
+#  ifdef XLAT_STR_147
+  + sizeof(XLAT_STR_147)
+#  endif
+#  ifdef XLAT_STR_148
+  + sizeof(XLAT_STR_148)
+#  endif
+#  ifdef XLAT_STR_149
+  + sizeof(XLAT_STR_149)
+#  endif
+#  ifdef XLAT_STR_150
+  + sizeof(XLAT_STR_150)
+#  endif
+#  ifdef XLAT_STR_151
+  + sizeof(XLAT_STR_151)
+#  endif
+#  ifdef XLAT_STR_152
+  + sizeof(XLAT_STR_152)
+#  endif
+#  ifdef XLAT_STR_153
+  + sizeof(XLAT_STR_153)
+#  endif
+#  ifdef XLAT_STR_154
+  + sizeof(XLAT_STR_154)
+#  endif
+#  ifdef XLAT_STR_155
+  + sizeof(XLAT_STR_155)
+#  endif
+#  ifdef XLAT_STR_156
+  + sizeof(XLAT_STR_156)
+#  endif
+#  ifdef XLAT_STR_157
+  + sizeof(XLAT_STR_157)
+#  endif
+#  ifdef XLAT_STR_158
+  + sizeof(XLAT_STR_158)
+#  endif
+#  ifdef XLAT_STR_159
+  + sizeof(XLAT_STR_159)
+#  endif
+#  ifdef XLAT_STR_160
+  + sizeof(XLAT_STR_160)
+#  endif
+#  ifdef XLAT_STR_161
+  + sizeof(XLAT_STR_161)
+#  endif
+#  ifdef XLAT_STR_162
+  + sizeof(XLAT_STR_162)
+#  endif
+#  ifdef XLAT_STR_163
+  + sizeof(XLAT_STR_163)
+#  endif
+#  ifdef XLAT_STR_164
+  + sizeof(XLAT_STR_164)
+#  endif
+#  ifdef XLAT_STR_165
+  + sizeof(XLAT_STR_165)
+#  endif
+#  ifdef XLAT_STR_166
+  + sizeof(XLAT_STR_166)
+#  endif
+#  ifdef XLAT_STR_167
+  + sizeof(XLAT_STR_167)
+#  endif
+#  ifdef XLAT_STR_168
+  + sizeof(XLAT_STR_168)
+#  endif
+#  ifdef XLAT_STR_169
+  + sizeof(XLAT_STR_169)
+#  endif
+#  ifdef XLAT_STR_170
+  + sizeof(XLAT_STR_170)
+#  endif
+#  ifdef XLAT_STR_171
+  + sizeof(XLAT_STR_171)
+#  endif
+#  ifdef XLAT_STR_172
+  + sizeof(XLAT_STR_172)
+#  endif
+#  ifdef XLAT_STR_173
+  + sizeof(XLAT_STR_173)
+#  endif
+#  ifdef XLAT_STR_174
+  + sizeof(XLAT_STR_174)
+#  endif
+#  ifdef XLAT_STR_175
+  + sizeof(XLAT_STR_175)
+#  endif
+#  ifdef XLAT_STR_176
+  + sizeof(XLAT_STR_176)
+#  endif
+#  ifdef XLAT_STR_177
+  + sizeof(XLAT_STR_177)
+#  endif
+#  ifdef XLAT_STR_178
+  + sizeof(XLAT_STR_178)
+#  endif
+#  ifdef XLAT_STR_179
+  + sizeof(XLAT_STR_179)
+#  endif
+#  ifdef XLAT_STR_180
+  + sizeof(XLAT_STR_180)
+#  endif
+#  ifdef XLAT_STR_181
+  + sizeof(XLAT_STR_181)
+#  endif
+#  ifdef XLAT_STR_182
+  + sizeof(XLAT_STR_182)
+#  endif
+#  ifdef XLAT_STR_183
+  + sizeof(XLAT_STR_183)
+#  endif
+#  ifdef XLAT_STR_184
+  + sizeof(XLAT_STR_184)
+#  endif
+#  ifdef XLAT_STR_185
+  + sizeof(XLAT_STR_185)
+#  endif
+#  ifdef XLAT_STR_186
+  + sizeof(XLAT_STR_186)
+#  endif
+#  ifdef XLAT_STR_187
+  + sizeof(XLAT_STR_187)
+#  endif
+#  ifdef XLAT_STR_188
+  + sizeof(XLAT_STR_188)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
+#  undef XLAT_STR_13
+#  undef XLAT_VAL_13
+#  undef XLAT_STR_14
+#  undef XLAT_VAL_14
+#  undef XLAT_STR_15
+#  undef XLAT_VAL_15
+#  undef XLAT_STR_16
+#  undef XLAT_VAL_16
+#  undef XLAT_STR_17
+#  undef XLAT_VAL_17
+#  undef XLAT_STR_18
+#  undef XLAT_VAL_18
+#  undef XLAT_STR_19
+#  undef XLAT_VAL_19
+#  undef XLAT_STR_20
+#  undef XLAT_VAL_20
+#  undef XLAT_STR_21
+#  undef XLAT_VAL_21
+#  undef XLAT_STR_22
+#  undef XLAT_VAL_22
+#  undef XLAT_STR_23
+#  undef XLAT_VAL_23
+#  undef XLAT_STR_24
+#  undef XLAT_VAL_24
+#  undef XLAT_STR_25
+#  undef XLAT_VAL_25
+#  undef XLAT_STR_26
+#  undef XLAT_VAL_26
+#  undef XLAT_STR_27
+#  undef XLAT_VAL_27
+#  undef XLAT_STR_28
+#  undef XLAT_VAL_28
+#  undef XLAT_STR_29
+#  undef XLAT_VAL_29
+#  undef XLAT_STR_30
+#  undef XLAT_VAL_30
+#  undef XLAT_STR_31
+#  undef XLAT_VAL_31
+#  undef XLAT_STR_32
+#  undef XLAT_VAL_32
+#  undef XLAT_STR_33
+#  undef XLAT_VAL_33
+#  undef XLAT_STR_34
+#  undef XLAT_VAL_34
+#  undef XLAT_STR_35
+#  undef XLAT_VAL_35
+#  undef XLAT_STR_36
+#  undef XLAT_VAL_36
+#  undef XLAT_STR_37
+#  undef XLAT_VAL_37
+#  undef XLAT_STR_38
+#  undef XLAT_VAL_38
+#  undef XLAT_STR_39
+#  undef XLAT_VAL_39
+#  undef XLAT_STR_40
+#  undef XLAT_VAL_40
+#  undef XLAT_STR_41
+#  undef XLAT_VAL_41
+#  undef XLAT_STR_42
+#  undef XLAT_VAL_42
+#  undef XLAT_STR_43
+#  undef XLAT_VAL_43
+#  undef XLAT_STR_44
+#  undef XLAT_VAL_44
+#  undef XLAT_STR_45
+#  undef XLAT_VAL_45
+#  undef XLAT_STR_46
+#  undef XLAT_VAL_46
+#  undef XLAT_STR_47
+#  undef XLAT_VAL_47
+#  undef XLAT_STR_48
+#  undef XLAT_VAL_48
+#  undef XLAT_STR_49
+#  undef XLAT_VAL_49
+#  undef XLAT_STR_50
+#  undef XLAT_VAL_50
+#  undef XLAT_STR_51
+#  undef XLAT_VAL_51
+#  undef XLAT_STR_52
+#  undef XLAT_VAL_52
+#  undef XLAT_STR_53
+#  undef XLAT_VAL_53
+#  undef XLAT_STR_54
+#  undef XLAT_VAL_54
+#  undef XLAT_STR_55
+#  undef XLAT_VAL_55
+#  undef XLAT_STR_56
+#  undef XLAT_VAL_56
+#  undef XLAT_STR_57
+#  undef XLAT_VAL_57
+#  undef XLAT_STR_58
+#  undef XLAT_VAL_58
+#  undef XLAT_STR_59
+#  undef XLAT_VAL_59
+#  undef XLAT_STR_60
+#  undef XLAT_VAL_60
+#  undef XLAT_STR_61
+#  undef XLAT_VAL_61
+#  undef XLAT_STR_62
+#  undef XLAT_VAL_62
+#  undef XLAT_STR_63
+#  undef XLAT_VAL_63
+#  undef XLAT_STR_64
+#  undef XLAT_VAL_64
+#  undef XLAT_STR_65
+#  undef XLAT_VAL_65
+#  undef XLAT_STR_66
+#  undef XLAT_VAL_66
+#  undef XLAT_STR_67
+#  undef XLAT_VAL_67
+#  undef XLAT_STR_68
+#  undef XLAT_VAL_68
+#  undef XLAT_STR_69
+#  undef XLAT_VAL_69
+#  undef XLAT_STR_70
+#  undef XLAT_VAL_70
+#  undef XLAT_STR_71
+#  undef XLAT_VAL_71
+#  undef XLAT_STR_72
+#  undef XLAT_VAL_72
+#  undef XLAT_STR_73
+#  undef XLAT_VAL_73
+#  undef XLAT_STR_74
+#  undef XLAT_VAL_74
+#  undef XLAT_STR_75
+#  undef XLAT_VAL_75
+#  undef XLAT_STR_76
+#  undef XLAT_VAL_76
+#  undef XLAT_STR_77
+#  undef XLAT_VAL_77
+#  undef XLAT_STR_78
+#  undef XLAT_VAL_78
+#  undef XLAT_STR_79
+#  undef XLAT_VAL_79
+#  undef XLAT_STR_80
+#  undef XLAT_VAL_80
+#  undef XLAT_STR_81
+#  undef XLAT_VAL_81
+#  undef XLAT_STR_82
+#  undef XLAT_VAL_82
+#  undef XLAT_STR_83
+#  undef XLAT_VAL_83
+#  undef XLAT_STR_84
+#  undef XLAT_VAL_84
+#  undef XLAT_STR_85
+#  undef XLAT_VAL_85
+#  undef XLAT_STR_86
+#  undef XLAT_VAL_86
+#  undef XLAT_STR_87
+#  undef XLAT_VAL_87
+#  undef XLAT_STR_88
+#  undef XLAT_VAL_88
+#  undef XLAT_STR_89
+#  undef XLAT_VAL_89
+#  undef XLAT_STR_90
+#  undef XLAT_VAL_90
+#  undef XLAT_STR_91
+#  undef XLAT_VAL_91
+#  undef XLAT_STR_92
+#  undef XLAT_VAL_92
+#  undef XLAT_STR_93
+#  undef XLAT_VAL_93
+#  undef XLAT_STR_94
+#  undef XLAT_VAL_94
+#  undef XLAT_STR_95
+#  undef XLAT_VAL_95
+#  undef XLAT_STR_96
+#  undef XLAT_VAL_96
+#  undef XLAT_STR_97
+#  undef XLAT_VAL_97
+#  undef XLAT_STR_98
+#  undef XLAT_VAL_98
+#  undef XLAT_STR_99
+#  undef XLAT_VAL_99
+#  undef XLAT_STR_100
+#  undef XLAT_VAL_100
+#  undef XLAT_STR_101
+#  undef XLAT_VAL_101
+#  undef XLAT_STR_102
+#  undef XLAT_VAL_102
+#  undef XLAT_STR_103
+#  undef XLAT_VAL_103
+#  undef XLAT_STR_104
+#  undef XLAT_VAL_104
+#  undef XLAT_STR_105
+#  undef XLAT_VAL_105
+#  undef XLAT_STR_106
+#  undef XLAT_VAL_106
+#  undef XLAT_STR_107
+#  undef XLAT_VAL_107
+#  undef XLAT_STR_108
+#  undef XLAT_VAL_108
+#  undef XLAT_STR_109
+#  undef XLAT_VAL_109
+#  undef XLAT_STR_110
+#  undef XLAT_VAL_110
+#  undef XLAT_STR_111
+#  undef XLAT_VAL_111
+#  undef XLAT_STR_112
+#  undef XLAT_VAL_112
+#  undef XLAT_STR_113
+#  undef XLAT_VAL_113
+#  undef XLAT_STR_114
+#  undef XLAT_VAL_114
+#  undef XLAT_STR_115
+#  undef XLAT_VAL_115
+#  undef XLAT_STR_116
+#  undef XLAT_VAL_116
+#  undef XLAT_STR_117
+#  undef XLAT_VAL_117
+#  undef XLAT_STR_118
+#  undef XLAT_VAL_118
+#  undef XLAT_STR_119
+#  undef XLAT_VAL_119
+#  undef XLAT_STR_120
+#  undef XLAT_VAL_120
+#  undef XLAT_STR_121
+#  undef XLAT_VAL_121
+#  undef XLAT_STR_122
+#  undef XLAT_VAL_122
+#  undef XLAT_STR_123
+#  undef XLAT_VAL_123
+#  undef XLAT_STR_124
+#  undef XLAT_VAL_124
+#  undef XLAT_STR_125
+#  undef XLAT_VAL_125
+#  undef XLAT_STR_126
+#  undef XLAT_VAL_126
+#  undef XLAT_STR_127
+#  undef XLAT_VAL_127
+#  undef XLAT_STR_128
+#  undef XLAT_VAL_128
+#  undef XLAT_STR_129
+#  undef XLAT_VAL_129
+#  undef XLAT_STR_130
+#  undef XLAT_VAL_130
+#  undef XLAT_STR_131
+#  undef XLAT_VAL_131
+#  undef XLAT_STR_132
+#  undef XLAT_VAL_132
+#  undef XLAT_STR_133
+#  undef XLAT_VAL_133
+#  undef XLAT_STR_134
+#  undef XLAT_VAL_134
+#  undef XLAT_STR_135
+#  undef XLAT_VAL_135
+#  undef XLAT_STR_136
+#  undef XLAT_VAL_136
+#  undef XLAT_STR_137
+#  undef XLAT_VAL_137
+#  undef XLAT_STR_138
+#  undef XLAT_VAL_138
+#  undef XLAT_STR_139
+#  undef XLAT_VAL_139
+#  undef XLAT_STR_140
+#  undef XLAT_VAL_140
+#  undef XLAT_STR_141
+#  undef XLAT_VAL_141
+#  undef XLAT_STR_142
+#  undef XLAT_VAL_142
+#  undef XLAT_STR_143
+#  undef XLAT_VAL_143
+#  undef XLAT_STR_144
+#  undef XLAT_VAL_144
+#  undef XLAT_STR_145
+#  undef XLAT_VAL_145
+#  undef XLAT_STR_146
+#  undef XLAT_VAL_146
+#  undef XLAT_STR_147
+#  undef XLAT_VAL_147
+#  undef XLAT_STR_148
+#  undef XLAT_VAL_148
+#  undef XLAT_STR_149
+#  undef XLAT_VAL_149
+#  undef XLAT_STR_150
+#  undef XLAT_VAL_150
+#  undef XLAT_STR_151
+#  undef XLAT_VAL_151
+#  undef XLAT_STR_152
+#  undef XLAT_VAL_152
+#  undef XLAT_STR_153
+#  undef XLAT_VAL_153
+#  undef XLAT_STR_154
+#  undef XLAT_VAL_154
+#  undef XLAT_STR_155
+#  undef XLAT_VAL_155
+#  undef XLAT_STR_156
+#  undef XLAT_VAL_156
+#  undef XLAT_STR_157
+#  undef XLAT_VAL_157
+#  undef XLAT_STR_158
+#  undef XLAT_VAL_158
+#  undef XLAT_STR_159
+#  undef XLAT_VAL_159
+#  undef XLAT_STR_160
+#  undef XLAT_VAL_160
+#  undef XLAT_STR_161
+#  undef XLAT_VAL_161
+#  undef XLAT_STR_162
+#  undef XLAT_VAL_162
+#  undef XLAT_STR_163
+#  undef XLAT_VAL_163
+#  undef XLAT_STR_164
+#  undef XLAT_VAL_164
+#  undef XLAT_STR_165
+#  undef XLAT_VAL_165
+#  undef XLAT_STR_166
+#  undef XLAT_VAL_166
+#  undef XLAT_STR_167
+#  undef XLAT_VAL_167
+#  undef XLAT_STR_168
+#  undef XLAT_VAL_168
+#  undef XLAT_STR_169
+#  undef XLAT_VAL_169
+#  undef XLAT_STR_170
+#  undef XLAT_VAL_170
+#  undef XLAT_STR_171
+#  undef XLAT_VAL_171
+#  undef XLAT_STR_172
+#  undef XLAT_VAL_172
+#  undef XLAT_STR_173
+#  undef XLAT_VAL_173
+#  undef XLAT_STR_174
+#  undef XLAT_VAL_174
+#  undef XLAT_STR_175
+#  undef XLAT_VAL_175
+#  undef XLAT_STR_176
+#  undef XLAT_VAL_176
+#  undef XLAT_STR_177
+#  undef XLAT_VAL_177
+#  undef XLAT_STR_178
+#  undef XLAT_VAL_178
+#  undef XLAT_STR_179
+#  undef XLAT_VAL_179
+#  undef XLAT_STR_180
+#  undef XLAT_VAL_180
+#  undef XLAT_STR_181
+#  undef XLAT_VAL_181
+#  undef XLAT_STR_182
+#  undef XLAT_VAL_182
+#  undef XLAT_STR_183
+#  undef XLAT_VAL_183
+#  undef XLAT_STR_184
+#  undef XLAT_VAL_184
+#  undef XLAT_STR_185
+#  undef XLAT_VAL_185
+#  undef XLAT_STR_186
+#  undef XLAT_VAL_186
+#  undef XLAT_STR_187
+#  undef XLAT_VAL_187
+#  undef XLAT_STR_188
+#  undef XLAT_VAL_188
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_pix_fmts.in 5.9-0ubuntu2/xlat/v4l2_pix_fmts.in
--- 5.5-3/xlat/v4l2_pix_fmts.in	2019-07-24 17:12:18.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_pix_fmts.in	2020-04-15 13:39:57.000000000 +0000
@@ -2,6 +2,7 @@
 V4L2_PIX_FMT_Y10     v4l2_fourcc('Y', '1', '0', ' ') /* 10  Greyscale     */
 V4L2_PIX_FMT_Y12     v4l2_fourcc('Y', '1', '2', ' ') /* 12  Greyscale     */
 V4L2_PIX_FMT_Y4      v4l2_fourcc('Y', '0', '4', ' ') /*  4  Greyscale     */
+V4L2_PIX_FMT_Y14     v4l2_fourcc('Y', '1', '4', ' ') /* 14  Greyscale     */
 V4L2_PIX_FMT_Y6      v4l2_fourcc('Y', '0', '6', ' ') /*  6  Greyscale     */
 V4L2_PIX_FMT_Y16     v4l2_fourcc('Y', '1', '6', ' ') /* 16  Greyscale     */
 V4L2_PIX_FMT_Z16      v4l2_fourcc('Z', '1', '6', ' ') /* Depth data 16-bit */
@@ -76,6 +77,10 @@ V4L2_PIX_FMT_H263     v4l2_fourcc('H', '
 V4L2_PIX_FMT_RGB24   v4l2_fourcc('R', 'G', 'B', '3') /* 24  RGB-8-8-8     */
 V4L2_PIX_FMT_BGR24   v4l2_fourcc('B', 'G', 'R', '3') /* 24  BGR-8-8-8     */
 V4L2_PIX_FMT_HSV24 v4l2_fourcc('H', 'S', 'V', '3')
+V4L2_PIX_FMT_SGBRG14 v4l2_fourcc('G', 'B', '1', '4') /* 14  GBGB.. RGRG.. */
+V4L2_PIX_FMT_SBGGR14 v4l2_fourcc('B', 'G', '1', '4') /* 14  BGBG.. GRGR.. */
+V4L2_PIX_FMT_SRGGB14 v4l2_fourcc('R', 'G', '1', '4') /* 14  RGRG.. GBGB.. */
+V4L2_PIX_FMT_SGRBG14 v4l2_fourcc('G', 'R', '1', '4') /* 14  GRGR.. BGBG.. */
 V4L2_PIX_FMT_ARGB32  v4l2_fourcc('B', 'A', '2', '4') /* 32  ARGB-8-8-8-8  */
 V4L2_PIX_FMT_BGRA32  v4l2_fourcc('R', 'A', '2', '4') /* 32  ABGR-8-8-8-8  */
 V4L2_PIX_FMT_RGBA32  v4l2_fourcc('A', 'B', '2', '4') /* 32  RGBA-8-8-8-8  */
diff -pruN 5.5-3/xlat/v4l2_sdr_fmts.h 5.9-0ubuntu2/xlat/v4l2_sdr_fmts.h
--- 5.5-3/xlat/v4l2_sdr_fmts.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_sdr_fmts.h	2020-09-24 09:18:46.000000000 +0000
@@ -70,13 +70,29 @@ extern const struct xlat v4l2_sdr_fmts[]
 
 static const struct xlat_data v4l2_sdr_fmts_xdata[] = {
  XLAT(V4L2_SDR_FMT_PCU20BE),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_SDR_FMT_PCU20BE))
+ #define XLAT_STR_0 STRINGIFY(V4L2_SDR_FMT_PCU20BE)
  XLAT(V4L2_SDR_FMT_RU12LE),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_SDR_FMT_RU12LE))
+ #define XLAT_STR_1 STRINGIFY(V4L2_SDR_FMT_RU12LE)
  XLAT(V4L2_SDR_FMT_CS14LE),
+ #define XLAT_VAL_2 ((unsigned) (V4L2_SDR_FMT_CS14LE))
+ #define XLAT_STR_2 STRINGIFY(V4L2_SDR_FMT_CS14LE)
  XLAT(V4L2_SDR_FMT_PCU16BE),
+ #define XLAT_VAL_3 ((unsigned) (V4L2_SDR_FMT_PCU16BE))
+ #define XLAT_STR_3 STRINGIFY(V4L2_SDR_FMT_PCU16BE)
  XLAT(V4L2_SDR_FMT_CU16LE),
+ #define XLAT_VAL_4 ((unsigned) (V4L2_SDR_FMT_CU16LE))
+ #define XLAT_STR_4 STRINGIFY(V4L2_SDR_FMT_CU16LE)
  XLAT(V4L2_SDR_FMT_CS8),
+ #define XLAT_VAL_5 ((unsigned) (V4L2_SDR_FMT_CS8))
+ #define XLAT_STR_5 STRINGIFY(V4L2_SDR_FMT_CS8)
  XLAT(V4L2_SDR_FMT_CU8),
+ #define XLAT_VAL_6 ((unsigned) (V4L2_SDR_FMT_CU8))
+ #define XLAT_STR_6 STRINGIFY(V4L2_SDR_FMT_CU8)
  XLAT(V4L2_SDR_FMT_PCU18BE),
+ #define XLAT_VAL_7 ((unsigned) (V4L2_SDR_FMT_PCU18BE))
+ #define XLAT_STR_7 STRINGIFY(V4L2_SDR_FMT_PCU18BE)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -85,8 +101,76 @@ const struct xlat v4l2_sdr_fmts[1] = { {
  .data = v4l2_sdr_fmts_xdata,
  .size = ARRAY_SIZE(v4l2_sdr_fmts_xdata),
  .type = XT_SORTED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_sliced_flags.h 5.9-0ubuntu2/xlat/v4l2_sliced_flags.h
--- 5.5-3/xlat/v4l2_sliced_flags.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_sliced_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -49,10 +49,20 @@ extern const struct xlat v4l2_sliced_fla
 
 static const struct xlat_data v4l2_sliced_flags_xdata[] = {
  XLAT(V4L2_SLICED_VBI_625),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_SLICED_VBI_625))
+ #define XLAT_STR_0 STRINGIFY(V4L2_SLICED_VBI_625)
  XLAT(V4L2_SLICED_TELETEXT_B),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_SLICED_TELETEXT_B))
+ #define XLAT_STR_1 STRINGIFY(V4L2_SLICED_TELETEXT_B)
  XLAT(V4L2_SLICED_VPS),
+ #define XLAT_VAL_2 ((unsigned) (V4L2_SLICED_VPS))
+ #define XLAT_STR_2 STRINGIFY(V4L2_SLICED_VPS)
  XLAT(V4L2_SLICED_CAPTION_525),
+ #define XLAT_VAL_3 ((unsigned) (V4L2_SLICED_CAPTION_525))
+ #define XLAT_STR_3 STRINGIFY(V4L2_SLICED_CAPTION_525)
  XLAT(V4L2_SLICED_WSS_625),
+ #define XLAT_VAL_4 ((unsigned) (V4L2_SLICED_WSS_625))
+ #define XLAT_STR_4 STRINGIFY(V4L2_SLICED_WSS_625)
 
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
@@ -62,8 +72,52 @@ const struct xlat v4l2_sliced_flags[1] =
  .data = v4l2_sliced_flags_xdata,
  .size = ARRAY_SIZE(v4l2_sliced_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_streaming_capabilities.h 5.9-0ubuntu2/xlat/v4l2_streaming_capabilities.h
--- 5.5-3/xlat/v4l2_streaming_capabilities.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_streaming_capabilities.h	2020-09-24 09:18:46.000000000 +0000
@@ -21,6 +21,8 @@ extern const struct xlat v4l2_streaming_
 
 static const struct xlat_data v4l2_streaming_capabilities_xdata[] = {
  XLAT(V4L2_CAP_TIMEPERFRAME),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_CAP_TIMEPERFRAME))
+ #define XLAT_STR_0 STRINGIFY(V4L2_CAP_TIMEPERFRAME)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -29,8 +31,20 @@ const struct xlat v4l2_streaming_capabil
  .data = v4l2_streaming_capabilities_xdata,
  .size = ARRAY_SIZE(v4l2_streaming_capabilities_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_tuner_audmodes.h 5.9-0ubuntu2/xlat/v4l2_tuner_audmodes.h
--- 5.5-3/xlat/v4l2_tuner_audmodes.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_tuner_audmodes.h	2020-09-24 09:18:46.000000000 +0000
@@ -49,11 +49,21 @@ extern const struct xlat v4l2_tuner_audm
 
 static const struct xlat_data v4l2_tuner_audmodes_xdata[] = {
  [V4L2_TUNER_MODE_MONO] = XLAT(V4L2_TUNER_MODE_MONO),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_TUNER_MODE_MONO))
+ #define XLAT_STR_0 STRINGIFY(V4L2_TUNER_MODE_MONO)
  [V4L2_TUNER_MODE_STEREO] = XLAT(V4L2_TUNER_MODE_STEREO),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_TUNER_MODE_STEREO))
+ #define XLAT_STR_1 STRINGIFY(V4L2_TUNER_MODE_STEREO)
  [V4L2_TUNER_MODE_LANG2] = XLAT(V4L2_TUNER_MODE_LANG2),
+ #define XLAT_VAL_2 ((unsigned) (V4L2_TUNER_MODE_LANG2))
+ #define XLAT_STR_2 STRINGIFY(V4L2_TUNER_MODE_LANG2)
 
  [V4L2_TUNER_MODE_LANG1] = XLAT(V4L2_TUNER_MODE_LANG1),
+ #define XLAT_VAL_3 ((unsigned) (V4L2_TUNER_MODE_LANG1))
+ #define XLAT_STR_3 STRINGIFY(V4L2_TUNER_MODE_LANG1)
  [V4L2_TUNER_MODE_LANG1_LANG2] = XLAT(V4L2_TUNER_MODE_LANG1_LANG2),
+ #define XLAT_VAL_4 ((unsigned) (V4L2_TUNER_MODE_LANG1_LANG2))
+ #define XLAT_STR_4 STRINGIFY(V4L2_TUNER_MODE_LANG1_LANG2)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -62,8 +72,52 @@ const struct xlat v4l2_tuner_audmodes[1]
  .data = v4l2_tuner_audmodes_xdata,
  .size = ARRAY_SIZE(v4l2_tuner_audmodes_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_tuner_capabilities.h 5.9-0ubuntu2/xlat/v4l2_tuner_capabilities.h
--- 5.5-3/xlat/v4l2_tuner_capabilities.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_tuner_capabilities.h	2020-09-24 09:18:46.000000000 +0000
@@ -105,19 +105,45 @@ extern const struct xlat v4l2_tuner_capa
 
 static const struct xlat_data v4l2_tuner_capabilities_xdata[] = {
  XLAT(V4L2_TUNER_CAP_LOW),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_TUNER_CAP_LOW))
+ #define XLAT_STR_0 STRINGIFY(V4L2_TUNER_CAP_LOW)
  XLAT(V4L2_TUNER_CAP_NORM),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_TUNER_CAP_NORM))
+ #define XLAT_STR_1 STRINGIFY(V4L2_TUNER_CAP_NORM)
  XLAT(V4L2_TUNER_CAP_HWSEEK_BOUNDED),
+ #define XLAT_VAL_2 ((unsigned) (V4L2_TUNER_CAP_HWSEEK_BOUNDED))
+ #define XLAT_STR_2 STRINGIFY(V4L2_TUNER_CAP_HWSEEK_BOUNDED)
  XLAT(V4L2_TUNER_CAP_HWSEEK_WRAP),
+ #define XLAT_VAL_3 ((unsigned) (V4L2_TUNER_CAP_HWSEEK_WRAP))
+ #define XLAT_STR_3 STRINGIFY(V4L2_TUNER_CAP_HWSEEK_WRAP)
  XLAT(V4L2_TUNER_CAP_STEREO),
+ #define XLAT_VAL_4 ((unsigned) (V4L2_TUNER_CAP_STEREO))
+ #define XLAT_STR_4 STRINGIFY(V4L2_TUNER_CAP_STEREO)
  XLAT(V4L2_TUNER_CAP_LANG2),
+ #define XLAT_VAL_5 ((unsigned) (V4L2_TUNER_CAP_LANG2))
+ #define XLAT_STR_5 STRINGIFY(V4L2_TUNER_CAP_LANG2)
 
  XLAT(V4L2_TUNER_CAP_LANG1),
+ #define XLAT_VAL_6 ((unsigned) (V4L2_TUNER_CAP_LANG1))
+ #define XLAT_STR_6 STRINGIFY(V4L2_TUNER_CAP_LANG1)
  XLAT(V4L2_TUNER_CAP_RDS),
+ #define XLAT_VAL_7 ((unsigned) (V4L2_TUNER_CAP_RDS))
+ #define XLAT_STR_7 STRINGIFY(V4L2_TUNER_CAP_RDS)
  XLAT(V4L2_TUNER_CAP_RDS_BLOCK_IO),
+ #define XLAT_VAL_8 ((unsigned) (V4L2_TUNER_CAP_RDS_BLOCK_IO))
+ #define XLAT_STR_8 STRINGIFY(V4L2_TUNER_CAP_RDS_BLOCK_IO)
  XLAT(V4L2_TUNER_CAP_RDS_CONTROLS),
+ #define XLAT_VAL_9 ((unsigned) (V4L2_TUNER_CAP_RDS_CONTROLS))
+ #define XLAT_STR_9 STRINGIFY(V4L2_TUNER_CAP_RDS_CONTROLS)
  XLAT(V4L2_TUNER_CAP_FREQ_BANDS),
+ #define XLAT_VAL_10 ((unsigned) (V4L2_TUNER_CAP_FREQ_BANDS))
+ #define XLAT_STR_10 STRINGIFY(V4L2_TUNER_CAP_FREQ_BANDS)
  XLAT(V4L2_TUNER_CAP_HWSEEK_PROG_LIM),
+ #define XLAT_VAL_11 ((unsigned) (V4L2_TUNER_CAP_HWSEEK_PROG_LIM))
+ #define XLAT_STR_11 STRINGIFY(V4L2_TUNER_CAP_HWSEEK_PROG_LIM)
  XLAT(V4L2_TUNER_CAP_1HZ),
+ #define XLAT_VAL_12 ((unsigned) (V4L2_TUNER_CAP_1HZ))
+ #define XLAT_STR_12 STRINGIFY(V4L2_TUNER_CAP_1HZ)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -126,8 +152,116 @@ const struct xlat v4l2_tuner_capabilitie
  .data = v4l2_tuner_capabilities_xdata,
  .size = ARRAY_SIZE(v4l2_tuner_capabilities_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+#  ifdef XLAT_VAL_10
+  | XLAT_VAL_10
+#  endif
+#  ifdef XLAT_VAL_11
+  | XLAT_VAL_11
+#  endif
+#  ifdef XLAT_VAL_12
+  | XLAT_VAL_12
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+#  ifdef XLAT_STR_10
+  + sizeof(XLAT_STR_10)
+#  endif
+#  ifdef XLAT_STR_11
+  + sizeof(XLAT_STR_11)
+#  endif
+#  ifdef XLAT_STR_12
+  + sizeof(XLAT_STR_12)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
+#  undef XLAT_STR_10
+#  undef XLAT_VAL_10
+#  undef XLAT_STR_11
+#  undef XLAT_VAL_11
+#  undef XLAT_STR_12
+#  undef XLAT_VAL_12
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_tuner_rxsubchanses.h 5.9-0ubuntu2/xlat/v4l2_tuner_rxsubchanses.h
--- 5.5-3/xlat/v4l2_tuner_rxsubchanses.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_tuner_rxsubchanses.h	2020-09-24 09:18:46.000000000 +0000
@@ -49,11 +49,21 @@ extern const struct xlat v4l2_tuner_rxsu
 
 static const struct xlat_data v4l2_tuner_rxsubchanses_xdata[] = {
  XLAT(V4L2_TUNER_SUB_MONO),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_TUNER_SUB_MONO))
+ #define XLAT_STR_0 STRINGIFY(V4L2_TUNER_SUB_MONO)
  XLAT(V4L2_TUNER_SUB_STEREO),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_TUNER_SUB_STEREO))
+ #define XLAT_STR_1 STRINGIFY(V4L2_TUNER_SUB_STEREO)
  XLAT(V4L2_TUNER_SUB_LANG2),
+ #define XLAT_VAL_2 ((unsigned) (V4L2_TUNER_SUB_LANG2))
+ #define XLAT_STR_2 STRINGIFY(V4L2_TUNER_SUB_LANG2)
 
  XLAT(V4L2_TUNER_SUB_LANG1),
+ #define XLAT_VAL_3 ((unsigned) (V4L2_TUNER_SUB_LANG1))
+ #define XLAT_STR_3 STRINGIFY(V4L2_TUNER_SUB_LANG1)
  XLAT(V4L2_TUNER_SUB_RDS),
+ #define XLAT_VAL_4 ((unsigned) (V4L2_TUNER_SUB_RDS))
+ #define XLAT_STR_4 STRINGIFY(V4L2_TUNER_SUB_RDS)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -62,8 +72,52 @@ const struct xlat v4l2_tuner_rxsubchanse
  .data = v4l2_tuner_rxsubchanses_xdata,
  .size = ARRAY_SIZE(v4l2_tuner_rxsubchanses_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_tuner_types.h 5.9-0ubuntu2/xlat/v4l2_tuner_types.h
--- 5.5-3/xlat/v4l2_tuner_types.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_tuner_types.h	2020-09-24 09:18:46.000000000 +0000
@@ -49,10 +49,20 @@ extern const struct xlat v4l2_tuner_type
 
 static const struct xlat_data v4l2_tuner_types_xdata[] = {
  [V4L2_TUNER_RADIO] = XLAT(V4L2_TUNER_RADIO),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_TUNER_RADIO))
+ #define XLAT_STR_0 STRINGIFY(V4L2_TUNER_RADIO)
  [V4L2_TUNER_ANALOG_TV] = XLAT(V4L2_TUNER_ANALOG_TV),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_TUNER_ANALOG_TV))
+ #define XLAT_STR_1 STRINGIFY(V4L2_TUNER_ANALOG_TV)
  [V4L2_TUNER_DIGITAL_TV] = XLAT(V4L2_TUNER_DIGITAL_TV),
+ #define XLAT_VAL_2 ((unsigned) (V4L2_TUNER_DIGITAL_TV))
+ #define XLAT_STR_2 STRINGIFY(V4L2_TUNER_DIGITAL_TV)
  [V4L2_TUNER_SDR] = XLAT(V4L2_TUNER_SDR),
+ #define XLAT_VAL_3 ((unsigned) (V4L2_TUNER_SDR))
+ #define XLAT_STR_3 STRINGIFY(V4L2_TUNER_SDR)
  [V4L2_TUNER_RF] = XLAT(V4L2_TUNER_RF),
+ #define XLAT_VAL_4 ((unsigned) (V4L2_TUNER_RF))
+ #define XLAT_STR_4 STRINGIFY(V4L2_TUNER_RF)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -61,8 +71,52 @@ const struct xlat v4l2_tuner_types[1] =
  .data = v4l2_tuner_types_xdata,
  .size = ARRAY_SIZE(v4l2_tuner_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/v4l2_tuner_types.in 5.9-0ubuntu2/xlat/v4l2_tuner_types.in
--- 5.5-3/xlat/v4l2_tuner_types.in	2019-10-28 19:52:59.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_tuner_types.in	2020-05-30 08:00:00.000000000 +0000
@@ -1,4 +1,9 @@
 #value_indexed
+#enum
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
 V4L2_TUNER_RADIO	1
 V4L2_TUNER_ANALOG_TV	2
 V4L2_TUNER_DIGITAL_TV	3
diff -pruN 5.5-3/xlat/v4l2_tuner_types.m4 5.9-0ubuntu2/xlat/v4l2_tuner_types.m4
--- 5.5-3/xlat/v4l2_tuner_types.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_tuner_types.m4	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,14 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/v4l2_tuner_types.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_v4l2_tuner_types],[
+AC_CHECK_DECLS(m4_normalize([
+V4L2_TUNER_RADIO,
+V4L2_TUNER_ANALOG_TV,
+V4L2_TUNER_DIGITAL_TV,
+V4L2_TUNER_SDR,
+V4L2_TUNER_RF
+]),,, [
+#include <sys/time.h>
+#include <linux/ioctl.h>
+#include <linux/types.h>
+#include <linux/videodev2.h>
+])])])
diff -pruN 5.5-3/xlat/v4l2_vbi_flags.h 5.9-0ubuntu2/xlat/v4l2_vbi_flags.h
--- 5.5-3/xlat/v4l2_vbi_flags.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/v4l2_vbi_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -28,7 +28,11 @@ extern const struct xlat v4l2_vbi_flags[
 
 static const struct xlat_data v4l2_vbi_flags_xdata[] = {
  XLAT(V4L2_VBI_UNSYNC),
+ #define XLAT_VAL_0 ((unsigned) (V4L2_VBI_UNSYNC))
+ #define XLAT_STR_0 STRINGIFY(V4L2_VBI_UNSYNC)
  XLAT(V4L2_VBI_INTERLACED),
+ #define XLAT_VAL_1 ((unsigned) (V4L2_VBI_INTERLACED))
+ #define XLAT_STR_1 STRINGIFY(V4L2_VBI_INTERLACED)
 };
 #  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
 static
@@ -37,8 +41,28 @@ const struct xlat v4l2_vbi_flags[1] = {
  .data = v4l2_vbi_flags_xdata,
  .size = ARRAY_SIZE(v4l2_vbi_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/wait4_options.h 5.9-0ubuntu2/xlat/wait4_options.h
--- 5.5-3/xlat/wait4_options.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/wait4_options.h	2020-09-24 09:18:46.000000000 +0000
@@ -38,38 +38,142 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 static const struct xlat_data wait4_options_xdata[] = {
 #if defined(WNOHANG) || (defined(HAVE_DECL_WNOHANG) && HAVE_DECL_WNOHANG)
   XLAT(WNOHANG),
+ #define XLAT_VAL_0 ((unsigned) (WNOHANG))
+ #define XLAT_STR_0 STRINGIFY(WNOHANG)
 #endif
 #ifndef WSTOPPED
 #if defined(WUNTRACED) || (defined(HAVE_DECL_WUNTRACED) && HAVE_DECL_WUNTRACED)
   XLAT(WUNTRACED),
+ #define XLAT_VAL_1 ((unsigned) (WUNTRACED))
+ #define XLAT_STR_1 STRINGIFY(WUNTRACED)
 #endif
 #endif
 #if defined(WEXITED) || (defined(HAVE_DECL_WEXITED) && HAVE_DECL_WEXITED)
   XLAT(WEXITED),
+ #define XLAT_VAL_2 ((unsigned) (WEXITED))
+ #define XLAT_STR_2 STRINGIFY(WEXITED)
 #endif
 #if defined(WTRAPPED) || (defined(HAVE_DECL_WTRAPPED) && HAVE_DECL_WTRAPPED)
   XLAT(WTRAPPED),
+ #define XLAT_VAL_3 ((unsigned) (WTRAPPED))
+ #define XLAT_STR_3 STRINGIFY(WTRAPPED)
 #endif
 #if defined(WSTOPPED) || (defined(HAVE_DECL_WSTOPPED) && HAVE_DECL_WSTOPPED)
   XLAT(WSTOPPED),
+ #define XLAT_VAL_4 ((unsigned) (WSTOPPED))
+ #define XLAT_STR_4 STRINGIFY(WSTOPPED)
 #endif
 #if defined(WCONTINUED) || (defined(HAVE_DECL_WCONTINUED) && HAVE_DECL_WCONTINUED)
   XLAT(WCONTINUED),
+ #define XLAT_VAL_5 ((unsigned) (WCONTINUED))
+ #define XLAT_STR_5 STRINGIFY(WCONTINUED)
 #endif
 #if defined(WNOWAIT) || (defined(HAVE_DECL_WNOWAIT) && HAVE_DECL_WNOWAIT)
   XLAT(WNOWAIT),
+ #define XLAT_VAL_6 ((unsigned) (WNOWAIT))
+ #define XLAT_STR_6 STRINGIFY(WNOWAIT)
 #endif
  XLAT(__WCLONE),
+ #define XLAT_VAL_7 ((unsigned) (__WCLONE))
+ #define XLAT_STR_7 STRINGIFY(__WCLONE)
  XLAT(__WALL),
+ #define XLAT_VAL_8 ((unsigned) (__WALL))
+ #define XLAT_STR_8 STRINGIFY(__WALL)
  XLAT(__WNOTHREAD),
+ #define XLAT_VAL_9 ((unsigned) (__WNOTHREAD))
+ #define XLAT_STR_9 STRINGIFY(__WNOTHREAD)
 };
 static
 const struct xlat wait4_options[1] = { {
  .data = wait4_options_xdata,
  .size = ARRAY_SIZE(wait4_options_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/waitid_types.h 5.9-0ubuntu2/xlat/waitid_types.h
--- 5.5-3/xlat/waitid_types.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/waitid_types.h	2020-09-24 09:18:46.000000000 +0000
@@ -42,17 +42,61 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data waitid_types_xdata[] = {
  [P_ALL] = XLAT(P_ALL),
+ #define XLAT_VAL_0 ((unsigned) (P_ALL))
+ #define XLAT_STR_0 STRINGIFY(P_ALL)
  [P_PID] = XLAT(P_PID),
+ #define XLAT_VAL_1 ((unsigned) (P_PID))
+ #define XLAT_STR_1 STRINGIFY(P_PID)
  [P_PGID] = XLAT(P_PGID),
+ #define XLAT_VAL_2 ((unsigned) (P_PGID))
+ #define XLAT_STR_2 STRINGIFY(P_PGID)
  [P_PIDFD] = XLAT(P_PIDFD),
+ #define XLAT_VAL_3 ((unsigned) (P_PIDFD))
+ #define XLAT_STR_3 STRINGIFY(P_PIDFD)
 };
 static
 const struct xlat waitid_types[1] = { {
  .data = waitid_types_xdata,
  .size = ARRAY_SIZE(waitid_types_xdata),
  .type = XT_INDEXED,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/waitid_types.in 5.9-0ubuntu2/xlat/waitid_types.in
--- 5.5-3/xlat/waitid_types.in	2019-10-20 18:12:10.000000000 +0000
+++ 5.9-0ubuntu2/xlat/waitid_types.in	2020-05-30 08:00:00.000000000 +0000
@@ -1,4 +1,7 @@
 #value_indexed
+#enum
+#include <sys/types.h>
+#include <sys/wait.h>
 P_ALL	0
 P_PID	1
 P_PGID	2
diff -pruN 5.5-3/xlat/waitid_types.m4 5.9-0ubuntu2/xlat/waitid_types.m4
--- 5.5-3/xlat/waitid_types.m4	1970-01-01 00:00:00.000000000 +0000
+++ 5.9-0ubuntu2/xlat/waitid_types.m4	2020-09-24 09:18:46.000000000 +0000
@@ -0,0 +1,11 @@
+dnl Generated by ./xlat/gen.sh from ./xlat/waitid_types.in; do not edit.
+AC_DEFUN([st_CHECK_ENUMS_waitid_types],[
+AC_CHECK_DECLS(m4_normalize([
+P_ALL,
+P_PID,
+P_PGID,
+P_PIDFD
+]),,, [
+#include <sys/types.h>
+#include <sys/wait.h>
+])])])
diff -pruN 5.5-3/xlat/watchdog_ioctl_cmds.h 5.9-0ubuntu2/xlat/watchdog_ioctl_cmds.h
--- 5.5-3/xlat/watchdog_ioctl_cmds.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/watchdog_ioctl_cmds.h	2020-09-24 09:18:46.000000000 +0000
@@ -84,23 +84,127 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data watchdog_ioctl_cmds_xdata[] = {
  XLAT(WDIOC_GETSTATUS),
+ #define XLAT_VAL_0 ((unsigned) (WDIOC_GETSTATUS))
+ #define XLAT_STR_0 STRINGIFY(WDIOC_GETSTATUS)
  XLAT(WDIOC_GETBOOTSTATUS),
+ #define XLAT_VAL_1 ((unsigned) (WDIOC_GETBOOTSTATUS))
+ #define XLAT_STR_1 STRINGIFY(WDIOC_GETBOOTSTATUS)
  XLAT(WDIOC_GETTEMP),
+ #define XLAT_VAL_2 ((unsigned) (WDIOC_GETTEMP))
+ #define XLAT_STR_2 STRINGIFY(WDIOC_GETTEMP)
  XLAT(WDIOC_GETTIMEOUT),
+ #define XLAT_VAL_3 ((unsigned) (WDIOC_GETTIMEOUT))
+ #define XLAT_STR_3 STRINGIFY(WDIOC_GETTIMEOUT)
  XLAT(WDIOC_GETPRETIMEOUT),
+ #define XLAT_VAL_4 ((unsigned) (WDIOC_GETPRETIMEOUT))
+ #define XLAT_STR_4 STRINGIFY(WDIOC_GETPRETIMEOUT)
  XLAT(WDIOC_GETTIMELEFT),
+ #define XLAT_VAL_5 ((unsigned) (WDIOC_GETTIMELEFT))
+ #define XLAT_STR_5 STRINGIFY(WDIOC_GETTIMELEFT)
  XLAT(WDIOC_SETOPTIONS),
+ #define XLAT_VAL_6 ((unsigned) (WDIOC_SETOPTIONS))
+ #define XLAT_STR_6 STRINGIFY(WDIOC_SETOPTIONS)
  XLAT(WDIOC_KEEPALIVE),
+ #define XLAT_VAL_7 ((unsigned) (WDIOC_KEEPALIVE))
+ #define XLAT_STR_7 STRINGIFY(WDIOC_KEEPALIVE)
  XLAT(WDIOC_SETTIMEOUT),
+ #define XLAT_VAL_8 ((unsigned) (WDIOC_SETTIMEOUT))
+ #define XLAT_STR_8 STRINGIFY(WDIOC_SETTIMEOUT)
  XLAT(WDIOC_SETPRETIMEOUT),
+ #define XLAT_VAL_9 ((unsigned) (WDIOC_SETPRETIMEOUT))
+ #define XLAT_STR_9 STRINGIFY(WDIOC_SETPRETIMEOUT)
 };
 static
 const struct xlat watchdog_ioctl_cmds[1] = { {
  .data = watchdog_ioctl_cmds_xdata,
  .size = ARRAY_SIZE(watchdog_ioctl_cmds_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+#  ifdef XLAT_VAL_6
+  | XLAT_VAL_6
+#  endif
+#  ifdef XLAT_VAL_7
+  | XLAT_VAL_7
+#  endif
+#  ifdef XLAT_VAL_8
+  | XLAT_VAL_8
+#  endif
+#  ifdef XLAT_VAL_9
+  | XLAT_VAL_9
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+#  ifdef XLAT_STR_6
+  + sizeof(XLAT_STR_6)
+#  endif
+#  ifdef XLAT_STR_7
+  + sizeof(XLAT_STR_7)
+#  endif
+#  ifdef XLAT_STR_8
+  + sizeof(XLAT_STR_8)
+#  endif
+#  ifdef XLAT_STR_9
+  + sizeof(XLAT_STR_9)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
+#  undef XLAT_STR_6
+#  undef XLAT_VAL_6
+#  undef XLAT_STR_7
+#  undef XLAT_VAL_7
+#  undef XLAT_STR_8
+#  undef XLAT_VAL_8
+#  undef XLAT_STR_9
+#  undef XLAT_VAL_9
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/whence_codes.h 5.9-0ubuntu2/xlat/whence_codes.h
--- 5.5-3/xlat/whence_codes.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/whence_codes.h	2020-09-24 09:18:46.000000000 +0000
@@ -11,26 +11,80 @@
 static const struct xlat_data whence_codes_xdata[] = {
 #if defined(SEEK_SET) || (defined(HAVE_DECL_SEEK_SET) && HAVE_DECL_SEEK_SET)
   XLAT(SEEK_SET),
+ #define XLAT_VAL_0 ((unsigned) (SEEK_SET))
+ #define XLAT_STR_0 STRINGIFY(SEEK_SET)
 #endif
 #if defined(SEEK_CUR) || (defined(HAVE_DECL_SEEK_CUR) && HAVE_DECL_SEEK_CUR)
   XLAT(SEEK_CUR),
+ #define XLAT_VAL_1 ((unsigned) (SEEK_CUR))
+ #define XLAT_STR_1 STRINGIFY(SEEK_CUR)
 #endif
 #if defined(SEEK_END) || (defined(HAVE_DECL_SEEK_END) && HAVE_DECL_SEEK_END)
   XLAT(SEEK_END),
+ #define XLAT_VAL_2 ((unsigned) (SEEK_END))
+ #define XLAT_STR_2 STRINGIFY(SEEK_END)
 #endif
 #if defined(SEEK_DATA) || (defined(HAVE_DECL_SEEK_DATA) && HAVE_DECL_SEEK_DATA)
   XLAT(SEEK_DATA),
+ #define XLAT_VAL_3 ((unsigned) (SEEK_DATA))
+ #define XLAT_STR_3 STRINGIFY(SEEK_DATA)
 #endif
 #if defined(SEEK_HOLE) || (defined(HAVE_DECL_SEEK_HOLE) && HAVE_DECL_SEEK_HOLE)
   XLAT(SEEK_HOLE),
+ #define XLAT_VAL_4 ((unsigned) (SEEK_HOLE))
+ #define XLAT_STR_4 STRINGIFY(SEEK_HOLE)
 #endif
 };
 const struct xlat whence_codes[1] = { {
  .data = whence_codes_xdata,
  .size = ARRAY_SIZE(whence_codes_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/xattrflags.h 5.9-0ubuntu2/xlat/xattrflags.h
--- 5.5-3/xlat/xattrflags.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/xattrflags.h	2020-09-24 09:18:46.000000000 +0000
@@ -28,15 +28,39 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data xattrflags_xdata[] = {
  XLAT(XATTR_CREATE),
+ #define XLAT_VAL_0 ((unsigned) (XATTR_CREATE))
+ #define XLAT_STR_0 STRINGIFY(XATTR_CREATE)
  XLAT(XATTR_REPLACE),
+ #define XLAT_VAL_1 ((unsigned) (XATTR_REPLACE))
+ #define XLAT_STR_1 STRINGIFY(XATTR_REPLACE)
 };
 static
 const struct xlat xattrflags[1] = { {
  .data = xattrflags_xdata,
  .size = ARRAY_SIZE(xattrflags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/xdp_flags.h 5.9-0ubuntu2/xlat/xdp_flags.h
--- 5.5-3/xlat/xdp_flags.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/xdp_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -5,38 +5,45 @@
 
 #if defined(XDP_FLAGS_MODES) || (defined(HAVE_DECL_XDP_FLAGS_MODES) && HAVE_DECL_XDP_FLAGS_MODES)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
-static_assert((XDP_FLAGS_MODES) == (0xe), "XDP_FLAGS_MODES != 0xe");
+static_assert((XDP_FLAGS_MODES) == (0x0e), "XDP_FLAGS_MODES != 0x0e");
 DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
-# define XDP_FLAGS_MODES 0xe
+# define XDP_FLAGS_MODES 0x0e
 #endif
 #if defined(XDP_FLAGS_UPDATE_IF_NOEXIST) || (defined(HAVE_DECL_XDP_FLAGS_UPDATE_IF_NOEXIST) && HAVE_DECL_XDP_FLAGS_UPDATE_IF_NOEXIST)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
-static_assert((XDP_FLAGS_UPDATE_IF_NOEXIST) == (0x1), "XDP_FLAGS_UPDATE_IF_NOEXIST != 0x1");
+static_assert((XDP_FLAGS_UPDATE_IF_NOEXIST) == (0x01), "XDP_FLAGS_UPDATE_IF_NOEXIST != 0x01");
 DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
-# define XDP_FLAGS_UPDATE_IF_NOEXIST 0x1
+# define XDP_FLAGS_UPDATE_IF_NOEXIST 0x01
 #endif
 #if defined(XDP_FLAGS_SKB_MODE) || (defined(HAVE_DECL_XDP_FLAGS_SKB_MODE) && HAVE_DECL_XDP_FLAGS_SKB_MODE)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
-static_assert((XDP_FLAGS_SKB_MODE) == (0x2), "XDP_FLAGS_SKB_MODE != 0x2");
+static_assert((XDP_FLAGS_SKB_MODE) == (0x02), "XDP_FLAGS_SKB_MODE != 0x02");
 DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
-# define XDP_FLAGS_SKB_MODE 0x2
+# define XDP_FLAGS_SKB_MODE 0x02
 #endif
 #if defined(XDP_FLAGS_DRV_MODE) || (defined(HAVE_DECL_XDP_FLAGS_DRV_MODE) && HAVE_DECL_XDP_FLAGS_DRV_MODE)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
-static_assert((XDP_FLAGS_DRV_MODE) == (0x4), "XDP_FLAGS_DRV_MODE != 0x4");
+static_assert((XDP_FLAGS_DRV_MODE) == (0x04), "XDP_FLAGS_DRV_MODE != 0x04");
 DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
-# define XDP_FLAGS_DRV_MODE 0x4
+# define XDP_FLAGS_DRV_MODE 0x04
 #endif
 #if defined(XDP_FLAGS_HW_MODE) || (defined(HAVE_DECL_XDP_FLAGS_HW_MODE) && HAVE_DECL_XDP_FLAGS_HW_MODE)
 DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
-static_assert((XDP_FLAGS_HW_MODE) == (0x8), "XDP_FLAGS_HW_MODE != 0x8");
+static_assert((XDP_FLAGS_HW_MODE) == (0x08), "XDP_FLAGS_HW_MODE != 0x08");
 DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 #else
-# define XDP_FLAGS_HW_MODE 0x8
+# define XDP_FLAGS_HW_MODE 0x08
+#endif
+#if defined(XDP_FLAGS_REPLACE) || (defined(HAVE_DECL_XDP_FLAGS_REPLACE) && HAVE_DECL_XDP_FLAGS_REPLACE)
+DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
+static_assert((XDP_FLAGS_REPLACE) == (0x10), "XDP_FLAGS_REPLACE != 0x10");
+DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
+#else
+# define XDP_FLAGS_REPLACE 0x10
 #endif
 
 #ifndef XLAT_MACROS_ONLY
@@ -49,18 +56,83 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data xdp_flags_xdata[] = {
  XLAT(XDP_FLAGS_MODES),
+ #define XLAT_VAL_0 ((unsigned) (XDP_FLAGS_MODES))
+ #define XLAT_STR_0 STRINGIFY(XDP_FLAGS_MODES)
  XLAT(XDP_FLAGS_UPDATE_IF_NOEXIST),
+ #define XLAT_VAL_1 ((unsigned) (XDP_FLAGS_UPDATE_IF_NOEXIST))
+ #define XLAT_STR_1 STRINGIFY(XDP_FLAGS_UPDATE_IF_NOEXIST)
  XLAT(XDP_FLAGS_SKB_MODE),
+ #define XLAT_VAL_2 ((unsigned) (XDP_FLAGS_SKB_MODE))
+ #define XLAT_STR_2 STRINGIFY(XDP_FLAGS_SKB_MODE)
  XLAT(XDP_FLAGS_DRV_MODE),
+ #define XLAT_VAL_3 ((unsigned) (XDP_FLAGS_DRV_MODE))
+ #define XLAT_STR_3 STRINGIFY(XDP_FLAGS_DRV_MODE)
  XLAT(XDP_FLAGS_HW_MODE),
+ #define XLAT_VAL_4 ((unsigned) (XDP_FLAGS_HW_MODE))
+ #define XLAT_STR_4 STRINGIFY(XDP_FLAGS_HW_MODE)
+ XLAT(XDP_FLAGS_REPLACE),
+ #define XLAT_VAL_5 ((unsigned) (XDP_FLAGS_REPLACE))
+ #define XLAT_STR_5 STRINGIFY(XDP_FLAGS_REPLACE)
 };
 static
 const struct xlat xdp_flags[1] = { {
  .data = xdp_flags_xdata,
  .size = ARRAY_SIZE(xdp_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/xdp_flags.in 5.9-0ubuntu2/xlat/xdp_flags.in
--- 5.5-3/xlat/xdp_flags.in	2019-10-12 16:51:55.000000000 +0000
+++ 5.9-0ubuntu2/xlat/xdp_flags.in	2020-04-15 13:39:57.000000000 +0000
@@ -1,5 +1,6 @@
-XDP_FLAGS_MODES			0xe
-XDP_FLAGS_UPDATE_IF_NOEXIST	0x1
-XDP_FLAGS_SKB_MODE		0x2
-XDP_FLAGS_DRV_MODE		0x4
-XDP_FLAGS_HW_MODE		0x8
+XDP_FLAGS_MODES			0x0e
+XDP_FLAGS_UPDATE_IF_NOEXIST	0x01
+XDP_FLAGS_SKB_MODE		0x02
+XDP_FLAGS_DRV_MODE		0x04
+XDP_FLAGS_HW_MODE		0x08
+XDP_FLAGS_REPLACE		0x10
diff -pruN 5.5-3/xlat/xfs_dqblk_flags.h 5.9-0ubuntu2/xlat/xfs_dqblk_flags.h
--- 5.5-3/xlat/xfs_dqblk_flags.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/xfs_dqblk_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -35,16 +35,50 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data xfs_dqblk_flags_xdata[] = {
  XLAT(XFS_USER_QUOTA),
+ #define XLAT_VAL_0 ((unsigned) (XFS_USER_QUOTA))
+ #define XLAT_STR_0 STRINGIFY(XFS_USER_QUOTA)
  XLAT(XFS_PROJ_QUOTA),
+ #define XLAT_VAL_1 ((unsigned) (XFS_PROJ_QUOTA))
+ #define XLAT_STR_1 STRINGIFY(XFS_PROJ_QUOTA)
  XLAT(XFS_GROUP_QUOTA),
+ #define XLAT_VAL_2 ((unsigned) (XFS_GROUP_QUOTA))
+ #define XLAT_STR_2 STRINGIFY(XFS_GROUP_QUOTA)
 };
 static
 const struct xlat xfs_dqblk_flags[1] = { {
  .data = xfs_dqblk_flags_xdata,
  .size = ARRAY_SIZE(xfs_dqblk_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat/xfs_quota_flags.h 5.9-0ubuntu2/xlat/xfs_quota_flags.h
--- 5.5-3/xlat/xfs_quota_flags.h	2020-02-06 16:23:26.000000000 +0000
+++ 5.9-0ubuntu2/xlat/xfs_quota_flags.h	2020-09-24 09:18:46.000000000 +0000
@@ -56,19 +56,83 @@ DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
 
 static const struct xlat_data xfs_quota_flags_xdata[] = {
  XLAT(XFS_QUOTA_UDQ_ACCT),
+ #define XLAT_VAL_0 ((unsigned) (XFS_QUOTA_UDQ_ACCT))
+ #define XLAT_STR_0 STRINGIFY(XFS_QUOTA_UDQ_ACCT)
  XLAT(XFS_QUOTA_UDQ_ENFD),
+ #define XLAT_VAL_1 ((unsigned) (XFS_QUOTA_UDQ_ENFD))
+ #define XLAT_STR_1 STRINGIFY(XFS_QUOTA_UDQ_ENFD)
  XLAT(XFS_QUOTA_GDQ_ACCT),
+ #define XLAT_VAL_2 ((unsigned) (XFS_QUOTA_GDQ_ACCT))
+ #define XLAT_STR_2 STRINGIFY(XFS_QUOTA_GDQ_ACCT)
  XLAT(XFS_QUOTA_GDQ_ENFD),
+ #define XLAT_VAL_3 ((unsigned) (XFS_QUOTA_GDQ_ENFD))
+ #define XLAT_STR_3 STRINGIFY(XFS_QUOTA_GDQ_ENFD)
  XLAT(XFS_QUOTA_PDQ_ACCT),
+ #define XLAT_VAL_4 ((unsigned) (XFS_QUOTA_PDQ_ACCT))
+ #define XLAT_STR_4 STRINGIFY(XFS_QUOTA_PDQ_ACCT)
  XLAT(XFS_QUOTA_PDQ_ENFD),
+ #define XLAT_VAL_5 ((unsigned) (XFS_QUOTA_PDQ_ENFD))
+ #define XLAT_STR_5 STRINGIFY(XFS_QUOTA_PDQ_ENFD)
 };
 static
 const struct xlat xfs_quota_flags[1] = { {
  .data = xfs_quota_flags_xdata,
  .size = ARRAY_SIZE(xfs_quota_flags_xdata),
  .type = XT_NORMAL,
+ .flags_mask = 0
+#  ifdef XLAT_VAL_0
+  | XLAT_VAL_0
+#  endif
+#  ifdef XLAT_VAL_1
+  | XLAT_VAL_1
+#  endif
+#  ifdef XLAT_VAL_2
+  | XLAT_VAL_2
+#  endif
+#  ifdef XLAT_VAL_3
+  | XLAT_VAL_3
+#  endif
+#  ifdef XLAT_VAL_4
+  | XLAT_VAL_4
+#  endif
+#  ifdef XLAT_VAL_5
+  | XLAT_VAL_5
+#  endif
+  ,
+ .flags_strsz = 0
+#  ifdef XLAT_STR_0
+  + sizeof(XLAT_STR_0)
+#  endif
+#  ifdef XLAT_STR_1
+  + sizeof(XLAT_STR_1)
+#  endif
+#  ifdef XLAT_STR_2
+  + sizeof(XLAT_STR_2)
+#  endif
+#  ifdef XLAT_STR_3
+  + sizeof(XLAT_STR_3)
+#  endif
+#  ifdef XLAT_STR_4
+  + sizeof(XLAT_STR_4)
+#  endif
+#  ifdef XLAT_STR_5
+  + sizeof(XLAT_STR_5)
+#  endif
+  ,
 } };
 
+#  undef XLAT_STR_0
+#  undef XLAT_VAL_0
+#  undef XLAT_STR_1
+#  undef XLAT_VAL_1
+#  undef XLAT_STR_2
+#  undef XLAT_VAL_2
+#  undef XLAT_STR_3
+#  undef XLAT_VAL_3
+#  undef XLAT_STR_4
+#  undef XLAT_VAL_4
+#  undef XLAT_STR_5
+#  undef XLAT_VAL_5
 # endif /* !IN_MPERS */
 
 #endif /* !XLAT_MACROS_ONLY */
diff -pruN 5.5-3/xlat.c 5.9-0ubuntu2/xlat.c
--- 5.5-3/xlat.c	2019-07-24 17:12:18.000000000 +0000
+++ 5.9-0ubuntu2/xlat.c	2020-04-03 22:58:26.000000000 +0000
@@ -3,7 +3,7 @@
  * Copyright (c) 1993 Branko Lankester <branko@hacktic.nl>
  * Copyright (c) 1993, 1994, 1995, 1996 Rick Sladkey <jrs@world.std.com>
  * Copyright (c) 1996-1999 Wichert Akkerman <wichert@cistron.nl>
- * Copyright (c) 1999-2018 The strace developers.
+ * Copyright (c) 1999-2020 The strace developers.
  * All rights reserved.
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
@@ -483,7 +483,7 @@ printflags_ex(uint64_t flags, const char
 }
 
 void
-print_xlat_ex(const uint64_t val, const char *str, enum xlat_style style)
+print_xlat_ex(const uint64_t val, const char *str, uint32_t style)
 {
 	bool default_str = style & PXF_DEFAULT_STR;
 	style = get_xlat_style(style);
diff -pruN 5.5-3/xlat.h 5.9-0ubuntu2/xlat.h
--- 5.5-3/xlat.h	2019-11-28 19:30:05.000000000 +0000
+++ 5.9-0ubuntu2/xlat.h	2020-03-30 21:14:24.000000000 +0000
@@ -55,8 +55,10 @@ struct xlat_data {
 
 struct xlat {
 	const struct xlat_data *data;
+	size_t flags_strsz;
 	uint32_t size;
 	enum xlat_type type;
+	uint64_t flags_mask;
 };
 
 # define XLAT(val)			{ (unsigned)(val), #val }
diff -pruN 5.5-3/xmalloc.c 5.9-0ubuntu2/xmalloc.c
--- 5.5-3/xmalloc.c	2019-05-22 11:05:13.000000000 +0000
+++ 5.9-0ubuntu2/xmalloc.c	2020-04-09 12:00:00.000000000 +0000
@@ -53,6 +53,23 @@ xcalloc(size_t nmemb, size_t size)
 #define HALF_SIZE_T	(((size_t) 1) << (sizeof(size_t) * 4))
 
 void *
+xallocarray(size_t nmemb, size_t size)
+{
+	size_t bytes = nmemb * size;
+
+	if ((nmemb | size) >= HALF_SIZE_T &&
+	    size && bytes / size != nmemb)
+		die_out_of_memory();
+
+	void *p = malloc(bytes);
+
+	if (!p)
+		die_out_of_memory();
+
+	return p;
+}
+
+void *
 xreallocarray(void *ptr, size_t nmemb, size_t size)
 {
 	size_t bytes = nmemb * size;
diff -pruN 5.5-3/xmalloc.h 5.9-0ubuntu2/xmalloc.h
--- 5.5-3/xmalloc.h	2019-05-22 11:05:13.000000000 +0000
+++ 5.9-0ubuntu2/xmalloc.h	2020-04-09 12:00:00.000000000 +0000
@@ -38,6 +38,13 @@ xzalloc(size_t size)
 }
 
 /**
+ * Allocate an array, but do not zero it out, die if the allocation
+ * has failed or if the product of nmemb and size is too big.
+ */
+void *xallocarray(size_t nmemb, size_t size)
+	ATTRIBUTE_MALLOC ATTRIBUTE_ALLOC_SIZE((1, 2));
+
+/**
  * Reallocate memory for the array, die if the allocation has failed or
  * if the product of nmemb and size is too big.
  */
